(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  32970101,     742911]*)
(*NotebookOutlinePosition[  33068665,     745989]*)
(*  CellTagsIndexPosition[  33053774,     745541]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
6. Numerical Solution of Linear Partial Differential \
Equations\
\>", "Title",
  CellTags->{"i:1", "c:1"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["6.1 The Galerkin method", "Subtitle",
  CellTags->{"i:2", "c:2"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["6.1.1 Introduction", "Subsubtitle",
  CellTags->"c:3"],

Cell[TextData[{
  " \tThe ",
  ButtonBox["Galerkin",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Galerkin.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " method is a numerical method for the solution of differential equations \
that is based on the ideas of eigenmode analysis. The method can be applied \
to both linear and nonlinear PDEs of any order, for which solutions are \
required in some given spatial domain. The domain can be infinite, but if it \
is finite the method is most efficient when the boundary conditions are \
continuous functions of position along the boundary, and when any edges \
formed by the intersection of the bounding surfaces form convex cusps.  For \
instance, the two-dimensional domain shown in Fig. ",
  ButtonBox["6.1(a)",
    ButtonData:>"Fig. 6.1",
    ButtonStyle->"Hyperlink"],
  " can be easily treated via the Galerkin method. However,  the domain in \
Fig. ",
  ButtonBox["6.1(b)",
    ButtonData:>"Fig. 6.1",
    ButtonStyle->"Hyperlink"],
  " is considerably more difficult to deal with, because it has a concave \
cusp pointing into the domain. The reason for these restrictions will be \
discussed in the next section. "
}], "Text",
  CellTags->"i:57"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P0001NB000`400?l00000o`00003oo`3ooooo
0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00
o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?oo
ool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo
003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?oo
of<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3o
oooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0
ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3o
ool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0
ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo
0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00
g`3oool00`20P80000000820P03o0?ooool0ooooP03oool00=l0oooo0P0000000`30`<00oooo0?oo
o`3o0?ooool0ooooOP3oool00=l0oooo0P00003o0?ooool0ooooP@3oool00=h0oooo00<0P8200000
00000000o`3ooond0?ooo`030<30`020P800oooo0<T0oooo003N0?ooo`80000000<0P8200?ooo`3o
ool0o`3ooon`0?ooo`050820P0000000000000000030`<00b@3oool00=h0oooo0P0000000`20P800
oooo0?ooo`3o0?ooojh0oooo00<0P8200000000000000`0000000`20P800oooo0?ooo`370?ooo`00
g@3oool01020P800000000000030`<3o0?ooojl0oooo00<0P8200000000000000P0000000`10@400
`<300?ooo`390?ooo`00o`3ooooo0?oooi80oooo0P10@4000`20P800oooo0?ooo`3;0?ooo`00o`3o
oooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?oo
o`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooon50?ooo`030820P0000000P8200=X0oooo
003o0?ooool0ooooQ03oool400000=X0oooo003o0?ooool0ooooPP3oool00`20P800000000000002
000000030820P03oool0oooo0=P0oooo003o0?ooool0ooooP03oool00`30`<00P820000000020000
00030820P030`<00oooo0=X0oooo003o0?ooool0ooooP@3oool2000000030820P03oool0oooo0=`0
oooo003o0?ooool0ooooPP3oool00`20P800oooo0?ooo`3M0?ooo`00fP3oool20820P0030<30`03o
ool0oooo0?l0ooooo`3ooon30?ooo`00f@3oool01030`<00000000000020P83o0?ooool0ooooQ@3o
ool00=T0oooo00<0P820000000000000o`3ooooo0?ooohH0oooo003I0?ooo`030820P00000000000
0?l0ooooo`3ooon60?ooo`00f@3oool00`10@40000000000003o0?ooool0ooooQP3oool00=T0oooo
0P0000000`20P800oooo0?ooo`3o0?oooiH0oooo00<0`<3000000020P800jP3oool00=T0oooo0P00
00000`20P800oooo0?ooo`3o0?oooiD0oooo00@0@4100000000000000000jP3oool00=P0oooo00@0
P820000000000000P820o`3ooonF0?ooo`050820P0000000000000000020P800jP3oool00?l0oooo
o`3oooma0?ooo`060<30`020P800000000000010@400P820j`3oool00?l0ooooo`3oooma0?ooo`04
0410@000000000000410@>d0oooo003o0?ooool0ooooLP3oool00`20P800`<300?ooo`3]0?ooo`00
o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooomX0?ooo`030000003oool0
oooo0?L0oooo003G0?ooo`80P820o`3ooon=0?ooo`030820P0000000@4100?P0oooo003G0?ooo`80
0000o`3ooon<0?ooo`040820P000000000000820P?P0oooo003G0?ooo`800000CP3oool20820P080
000000<0@4100?ooo`3oool0o`3ooolf0?ooo`040410@000000000000410@?T0oooo003G0?ooo`80
0000C03oool700000?l0oooo>03oool3000000030820P03oool0oooo0?L0oooo003F0?ooo`030820
P0000000@41004`0oooo00<0@4100000000000000P0000020820P?L0oooo00<0P8200?ooo`3oool0
?03oool01010@400000000000010@43j0?ooo`00eP3oool2000000030820P03oool0oooo04X0oooo
00<0`<300820P030`<00nP3oool01@20P800000000000010@400P82003/0oooo00<0`<300410@000
0000n`3oool00=H0oooo0P0000000`20P800oooo0?ooo`3o0?ooodP0oooo00<0P8200410@0000000
0`00003o0?ooocT0oooo003F0?ooo`80000000<0P8200?ooo`3oool0o`3ooom:0?ooo`040820P000
000000000820P?l0oooo>@3oool00?l0oooo5`3oool01020P800@41000000010@43o0?ooo``0oooo
00<0`<300820P030`<00o`3oooli0?ooo`00o`3ooolC0?ooo`030<30`020P800000000D00000o`3o
oooo0?ooodP0oooo003o0?oooa<0oooo00H0`<3000000000000000000410@020P83o0?ooool0oooo
BP3oool00?l0oooo503oool200000?l0oooo7`3oool00`000000oooo0?ooo`3o0?ooob/0oooo003o
0?ooool0oooo=03oool01@30`<000000000000000000P8200?l0oooo:P3oool00?l0oooo1P3oool2
0820P0030<30`03oool0oooo0?l0oooo:@3oool00`30`<00@41000000003000000030410@020P800
oooo0?l0oooo9P3oool00?l0oooo0P3oool20820P0050410@0000000000000000010@400o`3oool]
0?ooo`030<30`020P800@4100080000000<0P8200?ooo`3oool0o`3ooolU0?ooo`00o`3oool10?oo
o`P00000o`3oool`0?ooo`030820P0000000oooo0240oooo00<0P8200000003oool0o`3oool30?oo
o`00o`3oool10?ooo`040820P0000000000000000080P82000<0`<300?ooo`3oool0o`3ooomC0?oo
o`<00000o`3oool30?ooo`00o`3oool20?ooo`030820P03oool0oooo0?l0ooooE`3oool01020P800
000000000030`<3o0?ooo`<0oooo003o0?ooool0ooooAP3oool00`30`<00P8200?ooo`0C0?ooo`03
0410@0000000P8200?l0oooo103oool00?l0ooooo`3ooom60?ooo`<000004P3oool00`20P8000000
0000003o0?ooo`D0oooo001m0?ooo`80000000<0`<300?ooo`3oool0E03oool2000000030820P03o
ool0oooo01L0oooo00@0P8200410@0000000P820o`3ooom>0?ooo`030<30`0000000000000800000
00<0@4100820P03oool03P3oool00`20P80000000820P03o0?ooo`D0oooo001m0?ooo`030820P000
0000P82005L0oooo0P00000E0?ooo`030<30`020P800000000D00000o`3ooom?0?ooo`030<30`020
P800@41000@000003P3oool2000000030<30`03oool0oooo0?l0oooo0`3oool007d0oooo00<0P820
00000020P800E`3oool2000001D0oooo00<0P8200000000000000`00003o0?oooe@0oooo00@0P820
0000000000000000o`3ooolF0?ooo`00O@3oool00`30`<0000000000001G0?ooo`8000005P3oool0
10000000@4100820P030`<3o0?oooeL0oooo00<0P8200<30`03oool0o`3ooolE0?ooo`00OP3oool2
000005L0oooo00<0@41000000030`<00o`3ooooo0?ooohP0oooo001n0?ooo`030410@00000000000
05H0oooo00<0P82000000020P800o`3ooooo0?ooohP0oooo001n0?ooo`030820P0000000000005H0
oooo00<0P82000000020P8001`3oool2000000030820P03oool0oooo0?l0ooooo`3oooml0?ooo`00
g@3oool00`30`<00P8200410@003000000030410@03oool0oooo0?l0ooooL@3oool2000000030820
P030`<00oooo0?l0oooo1P3oool00=`0oooo00<0@4100000000000000P0000020820P?l0ooooL`3o
ool00`30`<00@41000000003000000030820P03oool0oooo0?l0oooo0`3oool00=`0oooo00@0`<30
000000000000P820o`3ooomg0?ooo`030410@0000000000000D0000000<0P8200?ooo`3oool0o`3o
ool00=D0oooo1P00003o0?ooog`0oooo0`0000000`3oool0P8200000000400000?l0oooo0@3oool0
0=80oooo0P20P80700000?l0ooooN`3oool00`30`<000000000000030?ooo`030<30`020P8000000
00@0000000<0P8200?ooo`3oool0n`3oool00<l0oooo00<0`<300820P00000000`0000001010@400
P8200<30`030`<02000000030820P03oool0oooo0?l0ooooN03oool00`20P8000000000000060?oo
o`030<30`010@400000000<0000000<0P8200<30`03oool0n@3oool00<`0oooo00<0`<300820P000
0000100000000`20P800`<300?ooo`030?ooo`80000000<0P8200?ooo`3oool0o`3ooomh0?ooo`80
000000<0@4100?ooo`3oool01`3oool00`20P800@41000000003000000030820P03oool0oooo0?H0
oooo003;0?ooo`H0000000<0P8200?ooo`3oool01@3oool300000?l0ooooNP3oool2000000030820
P03oool0oooo00T0oooo00<0P8200000000000000`0000000`20P800oooo0?ooo`3d0?ooo`00b03o
ool00`20P800@41000000004000000030820P03oool0oooo00L0oooo00<0P820000000000000EP3o
ool01020P800@41000000010@43o0?ooob00oooo0P0000000`20P800oooo0?ooo`0;0?ooo`030820
P010@400000000<0000000<0P8200?ooo`3oool0lP3oool00<D0oooo0P20P804000000030410@020
P800oooo00/0oooo00@0P820000000000000P820D@3oool00`30`<00P8200000000500000?l0oooo
803oool2000000030<30`03oool0oooo00`0oooo00<0`<300820P0000000100000000`10@400P820
0?ooo`3`0?ooo`00`P3oool20820P0@0000000<0@4100<30`03oool03`3oool300000540oooo00H0
`<3000000000000000000410@020P83o0?ooob80oooo0P00000C0?ooo`030820P010@400000000<0
000000<0P8200<30`03oool0k@3oool00840oooo00<0P82000000020P800?@3oool6000001@0oooo
0P0000000`20P800oooo0?ooo`1?0?ooo`800000o`3ooolT0?ooo`<000005P3oool600000>d0oooo
00210?ooo`030820P0000000P82003T0oooo00<0`<300820P010@400100000000`20P800oooo0?oo
o`0D0?ooo`030410@0000000P8200?l0ooooM`3oool3000001L0oooo00<0P8200410@00000000`00
00000`20P800`<300?ooo`3Y0?ooo`00P@3oool00`30`<0000000000000g0?ooo`030820P010@400
000000<0000000<0P8200?ooo`3oool05`3oool00`30`<000000000000140?ooo`030<30`03oool0
oooo0?l0oooo<03oool2000000030410@03oool0oooo01P0oooo00<0P8200000000000000`000000
0`20P800oooo0?ooo`3V0?ooo`00PP3oool2000003@0oooo00<0P8200410@00000000`0000020820
P1`0oooo00<0@410000000000000@03oool01@30`<00P820000000000000P8200?l0oooo<@3oool2
000000030820P03oool0oooo01X0oooo00<0`<300820P00000000`0000000`10@400P8200?ooo`3T
0?ooo`00PP3oool200000380oooo00<0P8200000000000001000000O0?ooo`040820P00000000000
0820P3h0oooo1@0000000`20P800oooo0?ooo`3o0?ooobl0oooo0P0000000`20P800oooo0?ooo`0M
0?ooo`H00000i03oool00880oooo0P0000000`20P800oooo0?ooo`0]0?ooo`030820P00000000000
008000000P20P8000`30`<00oooo0?ooo`0O0?ooo`80000000<0@4100?ooo`3oool0>P3oool00`20
P800000000000002000000030820P03oool0oooo0?l0oooo<@3oool2000000030820P03oool0oooo
01h0oooo00<0`<300000000000000`0000000`10@400P8200?ooo`3P0?ooo`00PP3oool00`20P800
00000000000/0?ooo`030820P00000000000008000000P20P80U0?ooo`040410@000000000000<30
`3`0oooo0P10@4000`30`<00oooo0?ooo`3o0?oooc<0oooo0P0000000`20P800oooo0?ooo`0P0?oo
o`030<30`020P800000000@0000000<0@4100<30`03oool0g@3oool00:h0oooo00<0P82000000000
00000P0000020820P2T0oooo0P0000000`10@400oooo0?ooo`3o0?ooog80oooo0P0000000`20P800
oooo0?ooo`0S0?ooo`80P8201@0000000`20P800`<300?ooo`3J0?ooo`00[03oool00`20P8000000
00000003000002d0oooo0P0000000`20P800oooo0?ooo`3o0?ooog00oooo00@0P820000000000000
P820:@3oool5000000030820P03oool0oooo0=P0oooo002Y0?ooo`030<30`010@400000000<00000
0P20P80^0?ooo`030820P0000000@4100?l0ooooLP3oool01020P800000000000020P80Z0?ooo`03
0820P0000000000000<0000000<0P8200<30`03oool0eP3oool00:H0oooo00<0`<300820P010@400
100000000`20P800oooo0?ooo`0`0?ooo`030410@0000000000002h0oooo00<0P8200?ooo`3oool0
o`3ooom00?ooo`040820P000000000000820P2d0oooo00<0P8200000000000000P0000000`10@400
P8200?ooo`3D0?ooo`00Y@3oool00`20P800000000000002000000030410@020P800oooo03<0oooo
00@0`<30000000000000@410:P3oool01@30`<00@410000000000000`<300?l0oooo@@3oool01020
P800000000000020P80_0?ooo`80P820100000000`10@400`<300?ooo`3A0?ooo`00Y03oool50000
03P0oooo0`0000000`20P800oooo0?ooo`0W0?ooo`@0000000<0P8200?ooo`3oool0o`3ooolo0?oo
o`040820P000000000000820P380oooo1P00003A0?ooo`00X@3oool00`20P8000000000000020000
00030410@020P800oooo03P0oooo00D0`<3000000000000000000820P00V0?ooo`030820P0000000
00000080000000<0P8200?ooo`3oool0o`3ooom00?ooo`040820P000000000000820P3<0oooo00<0
P8200000000000000`0000000`10@400`<300?ooo`3=0?ooo`00WP3oool20820P0@0000000<0P820
0?ooo`3oool0?03oool01010@400000000000020P80T0?ooo`050410@0000000000000000020P800
o`3ooom50?ooo`80000000<0P8200?ooo`3oool0<`3oool00`30`<00P82000000004000000030820
P030`<00oooo05`0oooo00<0`<300820P030`<00J`3oool009d0oooo1@0000000`20P800oooo0?oo
o`0o0?ooo`<000009@3oool2000000030820P03oool0oooo0?l0ooooA03oool3000003P0oooo1P00
00000`20P800oooo0?ooo`1H0?ooo`D00000J`3oool009X0oooo0P20P804000000030410@030`<00
oooo0440oooo00@0P820000000000000@410903oool20820P?l0ooooA`3oool3000003X0oooo00<0
P8200000000000000`0000000`20P800`<300?ooo`1D0?ooo`L00000J`3oool009P0oooo00<0P820
0000000000000P0000000`10@400`<300?ooo`150?ooo`040820P000000000000410@?l0ooooK03o
ool00`20P80000000000000m0?ooo`030820P000000000000080000000<0@4100820P03oool0DP3o
ool00`20P80000000410@0020820P6d0oooo002E0?ooo`030820P010@400000000@0000000<0P820
0?ooo`3oool0A`3oool01@20P8000000000000000000P8200?l0ooooJ`3oool2000003l0oooo0P20
P804000000030410@030`<00oooo0<40oooo00250?ooo`80000000<0P8200?ooo`3oool02P3oool6
000004d0oooo100000000`20P800oooo0?ooo`3o0?ooofP0oooo0P0000120?ooo`H00000@@3oool2
000000030820P03oool0oooo07/0oooo00250?ooo`030820P0000000P82000T0oooo00<0P8200410
@0000000100000000`20P800oooo0?ooo`1=0?ooo`050820P0000000000000000030`<00o`3ooomY
0?ooo`800000@`3oool00`20P800000000000003000000030410@020P800oooo03X0oooo00<0P820
0410@00000000`00001m0?ooo`00Q@3oool00`20P80000000410@0060?ooo`030<30`010@4000000
00<0000000<0@4100820P03oool0D`3oool01@10@400000000000020P800`<300140oooo00<0`<30
0820P03oool0o`3ooomC0?ooo`80000000<0`<300?ooo`3oool0@P3oool00`30`<00P82000000004
000000030820P030`<00oooo03D0oooo00<0P8200000000000000P0000000`10@400P8200820P01m
0?ooo`00QP3oool2000000<0oooo00<0`<300820P0000000100000000`20P800oooo0?ooo`1F0?oo
o`060<30`0000000000000000020P800`<303P3oool01020P800000000000010@43o0?oooe<0oooo
00<0P82000000020P800A`3oool20820P0@0000000<0@4100820P030`<00=03oool2000000030820
P030`<00oooo07l0oooo00260?ooo`8000000P3oool00`20P800000000000004000005/0oooo00<0
P8200000000000000`00000<0?ooo`050820P0000000000000000020P800o`3ooomC0?ooo`030820
P0000000P82004X0oooo1P0000000`20P800oooo0?ooo`2e0?ooo`00QP3oool2000000030820P010
@400000000<0000000<0P8200?ooo`3oool0G@3oool01P10@4000000000000000000@4100<30`0T0
oooo00D0P820000000000000@4100820P03o0?oooe@0oooo00<0P82000000020P800B`3oool20820
P0@0000000<0@4100820P030`<00]03oool008H0oooo00<0@4100000000000000P0000000`10@400
P8200?ooo`1Q0?ooo`030<30`010@40000000080000000<0@4100820P03oool0103oool01@30`<00
0000000000000000@4100?l0ooooEP3oool00`30`<0000000000001>0?ooo`030820P010@4000000
00<0000000<0@4100<30`03oool07`3oool20820P900oooo00230?ooo`030<30`020P800000000<0
000000<0@4100<30`03oool0I@3oool00`20P800@41000000002000000030410@030`<00oooo00<0
oooo00<0@41000000020P800o`3ooomH0?ooo`800000D@3oool00`20P80000000000000300000003
0410@030`<00oooo01X0oooo00D0P82000000000000000000820P02?0?ooo`00Q03oool500000003
0820P03oool0oooo06L0oooo00<0P8200000000000000`00003o0?oooeh0oooo0P00001C0?ooo`03
0820P0000000000000@000006@3oool5000000030820P03oool0oooo08d0oooo00240?ooo`80P820
00@0oooo000000000000P820JP3oool00`30`<00000000000003000000030410@020P800oooo0?l0
ooooFP3oool2000000030820P03oool0oooo0580oooo00<0P8200000000000000`0000000`10@400
`<300?ooo`0C0?ooo`030820P000000000000080000000<0P8200<30`03oool0S`3oool008L0oooo
0P0000000`20P800oooo0?ooo`1Z0?ooo`030<30`010@400000000<00000o`3ooomK0?ooo`030820
P0000000000005H0oooo00<0`<300820P00000000`0000000`10@400P8200<30`00B0?ooo`030000
0010@400P82009<0oooo00270?ooo`80000000<0@4100?ooo`3oool0JP3oool00`30`<0000000000
00020820P0030<30`03oool0oooo0?l0ooooF@3oool01020P800000000000030`<1H0?ooo`030820
P010@400000000<0000000<0@4100<30`03oool0Y@3oool008L0oooo00<0P820000000000000K03o
ool2000000030820P03oool0oooo0?l0ooooG@3oool2000000030820P03oool0oooo05T0oooo1P00
00000`20P800oooo0?ooo`2R0?ooo`00M`3oool00`30`<00P8200<30`00=0?ooo`030820P0000000
000006/0oooo00<0P82000000010@4003`3oool00`30`<00P8200820P03o0?ooodh0oooo0P000000
0`20P800oooo0?ooo`1J0?ooo`030820P010@400000000<0000000<0@4100<30`03oool0X@3oool0
07H0oooo00@0@41000000000000000003@3oool01020P800000000000030`<1Y0?ooo`040410@000
000000000<30`0l0oooo00D0@41000000000000000000410@0020820P0030<30`03oool0oooo0?l0
ooooA`3oool2000000030410@03oool0oooo05d0oooo00<0P820000000000000100000000`20P800
`<300?ooo`2M0?ooo`00L`3oool00`30`<00P82000000003000000030820P03oool0oooo00`0oooo
0P0000000`20P800oooo0?ooo`1V0?ooo`040410@000000000000<30`100oooo0P20P80500000003
0820P03oool0oooo00T0oooo00<0`<300820P020P8001020P8000`30`<00oooo0?ooo`3o0?oooc@0
oooo00<0P820000000000000H@3oool00`20P800000000000004000000030820P030`<00oooo09/0
oooo001b0?ooo`030820P000000000000080000000<0P8200?ooo`3oool03P3oool2000000030820
P03oool0oooo06D0oooo00<0P8200000000000005P3oool3000000030820P03oool0oooo00T0oooo
00<0P820000000000000100000000`20P800oooo0?ooo`3o0?oooc@0oooo00@0P820000000000000
P820G`3oool;000009/0oooo001c0?ooo`80000000<0P8200<30`03oool0403oool2000000030410
@03oool0oooo06@0oooo00@0P820000000000000@4109@3oool00`10@40000000000000400000003
0820P03oool0oooo0?l0oooo=03oool01030`<00000000000020P81M0?ooo`050820P00000000000
00000010@4000P3oool00`30`<00P82000000004000000030820P030`<00oooo09L0oooo00290?oo
o`800000I@3oool01030`<00000000000010@40V0?ooo`L0P82000<0`<300?ooo`3oool0o`3ooole
0?ooo`030820P0000000000005d0oooo00@0P82000000020P800`<301P3oool00`20P800@4100000
0003000000030410@030`<00oooo0380oooo00<000000410@030`<00H03oool008T0oooo0P00001T
0?ooo`050<30`0000000000000000030`<00o`3ooomV0?ooo`80000000<0P8200?ooo`3oool0I`3o
ool00`20P800000000000003000000030410@030`<00oooo02h0oooo0`00001Q0?ooo`00R@3oool2
000000030820P03oool0oooo0640oooo0`0000000`20P800oooo0?ooo`3o0?ooofD0oooo00<0P820
00000020P800J`3oool00`20P800000000000003000000030820P03oool0oooo02/0oooo00@0P820
000000000000P820H@3oool008T0oooo00<0P82000000020P800HP3oool01020P800000000000020
P83o0?ooofP0oooo00<0P820000000000000K@3oool00`20P800000000000003000000030410@030
`<00oooo02T0oooo0`0000000`30`<00oooo0?ooo`1O0?ooo`00IP3oool00`20P80000000000000P
0?ooo`030820P0000000@4100640oooo00@0P820000000000000`<30o`3ooomZ0?ooo`80000000<0
P8200?ooo`3oool0K03oool00`30`<00P82000000004000000030410@030`<00oooo02D0oooo00@0
@410000000000000P820HP3oool006@0oooo00<0P8200000000000000P0000000`20P800oooo0?oo
o`0M0?ooo`030820P000000000000640oooo0P0000000`20P800oooo0?ooo`3o0?ooofT0oooo00<0
P820000000000000L@3oool7000002D0oooo0`00001S0?ooo`00H`3oool00`20P800000000000002
000000030820P030`<00oooo01h0oooo00<0`<30000000000000H03oool00`10@40000000000003o
0?ooof`0oooo00@0P820000000000000`<30CP3oool00`20P80000000?ooo`0P0?ooo`030<30`020
P800000000@0000000<0@4100<30`03oool0803oool00`30`<00@4100000001T0?ooo`00HP3oool0
1@10@4000000000000000000P82002<0oooo0P0000000`20P800oooo0?ooo`1L0?ooo`040<30`000
000000000<30`?l0ooooK03oool01030`<00000000000010@41<0?ooo`030820P010@40000000080
00008`3oool00`30`<00@41000000003000000030410@020P800oooo08D0oooo001R0?ooo`030<30
`0000000P82002D0oooo00<0P820000000000000GP3oool00`10@40000000820P03o0?ooofh0oooo
00@0@410000000000000`<30BP3oool01@10@4000000000000000000`<3002H0oooo00<0`<300820
P010@400100000000`10@400`<300?ooo`220?ooo`00RP3oool00`20P80000000000001M0?ooo`03
0820P000000000000?l0ooooK`3oool01020P800000000000020P8190?ooo`@00000:`3oool00`20
P80000000000000400000880oooo002:0?ooo`040<30`000000000000820P5`0oooo00<0@4100000
0030`<00o`3ooom`0?ooo`<00000B@3oool00`20P80000000820P00]0?ooo`030<30`020P800@410
00@0000000<0@4100<30`03oool0OP3oool008/0oooo0P0000000`20P800oooo0?ooo`1I0?ooo`80
000000<0@4100?ooo`3oool0o`3ooom`0?ooo`80000000<0`<300?ooo`3oool0N@3oool00`30`<00
@41000000004000000030820P03oool0oooo07/0oooo002;0?ooo`80000000<0@4100?ooo`3oool0
F03oool00`10@40000000000003o0?ooog<0oooo00<0@41000000010@400OP3oool00`30`<00@410
00000003000000030410@020P800oooo07T0oooo001F0?ooo`030820P0000000oooo0380oooo00<0
P820000000000000FP3oool2000000030820P03oool0oooo0?l0ooooL@3oool00`20P80000000000
00200?ooo`030820P0000000000000@00000N@3oool005@0oooo00D0P82000000000000000000<30
`00b0?ooo`030820P0000000000005T0oooo00<0@410000000000000o`3ooome0?ooo`<00000P@3o
ool00`30`<00@41000000003000000030410@020P800oooo07D0oooo001B0?ooo`030<30`0000000
00000080000000<0@4100<30`03oool0<@3oool01020P800000000000030`<1G0?ooo`030<30`000
000000000?l0ooooMP3oool01020P800000000000020P8220?ooo`030<30`020P800@41000@00000
00<0P8200<30`03oool0LP3oool00540oooo00H0P82000000000000000000820P030`<0e0?ooo`80
000000<0P8200?ooo`3oool0E@3oool00`10@40000000<30`03o0?ooogL0oooo0P0000000`10@400
oooo0?ooo`0h0?ooo`030<30`0000000`<3004P0oooo00<0`<300410@0000000100000000`20P800
oooo0?ooo`020?ooo`030820P03oool0oooo06X0oooo001B0?ooo`80000000<0P8200?ooo`3oool0
=@3oool2000000030820P03oool0oooo05D0oooo0P00003o0?ooogP0oooo0`00000i0?ooo`<00000
00<0P8200?ooo`3oool0B@3oool00`20P800000000000003000000030820P03oool0P82000800000
J`3oool00580oooo00<0P8200<30`03oool0=`3oool00`20P80000000000001F0?ooo`<00000o`3o
oomh0?ooo`040820P000000000000820P3L0oooo00D0@41000000000000000000410@01<0?ooo`03
0<30`010@400000000H0000000<0@4100?ooo`3oool0J@3oool008`0oooo00<0P820000000000000
E@3oool01020P800000000000020P83o0?ooogT0oooo0`00000e0?ooo`030<30`010@40000000080
000000<0`<300?ooo`3oool0CP3oool00`30`<00@41000000003000000030820P03oool0oooo06T0
oooo002<0?ooo`040820P000000000000<30`5@0oooo0`00003o0?ooog/0oooo0P0000000`20P800
oooo0?ooo`0b0?ooo`040410@000000000000820P5@0oooo00@0@410000000000000@4100`000000
0`20P800oooo0?ooo`1V0?ooo`00S@3oool2000000030820P03oool0oooo0580oooo0P0000000`20
P800oooo0?ooo`3o0?ooogT0oooo00<0P820000000000000=@3oool00`000000P8200?ooo`1D0?oo
o`<0000000<0P8200000000000001000001V0?ooo`00S@3oool2000000030820P03oool0oooo0540
oooo00@0P820000000000000`<30o`3ooomk0?ooo`040<30`000000000000820P8X0oooo00L0P820
000000000000@4100?ooo`30`<00P82000D00000I@3oool004D0oooo00<0P8200410@020P800A@3o
ool00`20P80000000410@01C0?ooo`80000000<0P8200?ooo`3oool0o`3ooomk0?ooo`040410@000
000000000<30`8T0oooo0`0000000`30`<00oooo0?ooo`020?ooo`040<30`020P80000000820P6D0
oooo00130?ooo`030<30`0000000000000800000A@3oool00`20P80000000000001B0?ooo`800000
00<0@4100?ooo`3oool0o`3oooml0?ooo`040<30`00000000000000008P0oooo00<0P82000000000
0000K`3oool00480oooo00<0P8200000000000000P0000170?ooo`800000DP3oool2000000030820
P03oool0oooo0?l0ooooO@3oool01020P800000000000020P8270?ooo`80000000<0P8200?ooo`3o
ool0K@3oool00400oooo00<0`<300820P00000000P0000000`20P800oooo0?ooo`160?ooo`030410
@000000000000500oooo00<0P820000000000000o`3ooon00?ooo`040<30`000000000000410@8H0
oooo0`0000000`30`<00oooo0?ooo`1]0?ooo`00@@3oool2000000030820P03oool0oooo04P0oooo
00<0P820000000000000D03oool2000000030820P03oool0oooo0?l0ooooO`3oool01020P8000000
00000020P80V0?ooo`030820P03oool0oooo05/0oooo00@0P820000000000000P8205@3oool00`30
`<0000000820P01H0?ooo`00SP3oool01020P800000000000030`<1>0?ooo`030820P00000000000
0?l0ooooP`3oool00`20P80000000000000T0?ooo`040<30`010@40000000820P5`0oooo0`00000F
0?ooo`030410@000000000000080000000<0P8200?ooo`3oool0D`3oool008l0oooo0P0000000`20
P800oooo0?ooo`1<0?ooo`800000o`3ooon50?ooo`<000008`3oool4000005/0oooo00@0P8200000
00000000P8205`3oool6000005@0oooo002?0?ooo`80000000<0P8200?ooo`3oool0B`3oool00`30
`<0000000000003o0?ooohD0oooo00@0@410000000000000`<30803oool01@30`<00000000000000
0000@41005`0oooo00@0@410000000000000`<30603oool00`30`<00P82000000002000005@0oooo
002?0?ooo`80000000<0@4100?ooo`3oool0B`3oool00`20P80000000000003o0?ooohD0oooo00@0
`<3000000000000000007`3oool01@10@4000000000000000000`<3005`0oooo00@0`<3000000000
0000P820703oool20<30`5@0oooo002?0?ooo`030820P0000000000004d0oooo0P0000000`20P800
oooo0?ooo`3o0?oooh@0oooo00@0P820000000000000P8207P3oool01020P800000000000020P81M
0?ooo`<00000L`3oool008l0oooo00<0P820000000000000C@3oool2000000030820P03oool0oooo
0?l0ooooQ03oool01030`<00000000000010@40N0?ooo`030<30`010@400P82005d0oooo00@0P820
000000000000`<30L`3oool008l0oooo00@0`<30000000000000P820B`3oool01020P80000000000
0030`<3o0?ooohL0oooo00@0P820000000000000P820O03oool01030`<00000000000000000[0?oo
o`030<30`020P800oooo04H0oooo002@0?ooo`80000000<0P8200?ooo`3oool0B@3oool300000?l0
ooooR@3oool00`20P80000000000001l0?ooo`040410@000000000000<30`2/0oooo0`0000000`20
P800`<300?ooo`130?ooo`00T03oool2000000030820P03oool0oooo04T0oooo0P0000000`20P800
oooo0?ooo`3o0?ooohP0oooo0`00001k0?ooo`<00000:`3oool00`20P800000000000004000004<0
oooo002@0?ooo`030820P0000000000004X0oooo00@0P820000000000000P820o`3ooon:0?ooo`03
0410@0000000000007X0oooo00@0P820000000000000P820;03oool00`30`<00P820000000040000
0480oooo002A0?ooo`800000BP3oool01020P800000000000030`<3o0?ooohX0oooo00@0`<300000
00000000@410N@3oool300000300oooo00@0`<300410@0000000P820@P3oool00940oooo00<0@410
000000000000B@3oool300000?l0ooooS03oool01010@400000000000020P81g0?ooo`030820P000
0000000007L0oooo002A0?ooo`030820P0000000000004T0oooo0P0000000`20P800oooo0?ooo`3o
0?oooh/0oooo0`00000@0?ooo`0300000020P800oooo06@0oooo0P0000000`20P800oooo0?ooo`1e
0?ooo`00T@3oool01020P800000000000030`<170?ooo`040<30`000000000000820P?l0ooooS@3o
ool01020P800000000000020P80=0?ooo`050<30`010@400000000000030`<00H`3oool01020P800
000000000030`<1g0?ooo`00TP3oool2000000030820P03oool0oooo04D0oooo00<0P82000000000
0000o`3ooon?0?ooo`040<30`000000000000820P0/0oooo00D0P82000000000000000000410@01S
0?ooo`040<30`000000000000410@7P0oooo002B0?ooo`<00000A`3oool00`10@40000000000003o
0?oooi00oooo00@0@410000000000000`<30203oool01@30`<00@410000000000000@41006D0oooo
00@0@410000000000000`<30N03oool00980oooo00<0P820000000000000A`3oool200000?l0oooo
TP3oool3000000P0oooo1000001V0?ooo`<00000N@3oool00980oooo00@0P820000000000000`<30
AP3oool200000?l0ooooTP3oool01010@400000000000020P8070?ooo`040<30`0000000P8200<30
`6D0oooo00@0P820000000000000P820N@3oool009<0oooo0P0000000`20P800oooo0?ooo`140?oo
o`800000o`3ooonC0?ooo`<0000000<0`<300?ooo`3oool0K@3oool3000007X0oooo002C0?ooo`03
0820P0000000000004D0oooo00<0P82000000020P800o`3ooonD0?ooo`030410@0000000000006h0
oooo00<0P820000000000000N`3oool009@0oooo0P0000150?ooo`030820P0000000P8200?l0oooo
U03oool01020P800000000000000001]0?ooo`80000000<0P8200?ooo`3oool0N@3oool009@0oooo
0P0000000`30`<00oooo0?ooo`120?ooo`030410@0000000P8200?l0ooooU@3oool01010@4000000
00000020P81[0?ooo`040820P000000000000<30`7/0oooo002D0?ooo`030820P0000000P82004@0
oooo0P0000000`20P800oooo0?ooo`3o0?oooi@0oooo0`0000000`30`<00oooo0?ooo`1W0?ooo`04
0<30`000000000000410@7`0oooo002D0?ooo`030820P0000000@41004@0oooo0P0000000`30`<00
oooo0?ooo`3o0?oooi<0oooo00D0`<3000000000000000000410@01Y0?ooo`040410@00000000000
0<30`7`0oooo002E0?ooo`800000A03oool200000?l0ooooUP3oool5000000030820P03oool0oooo
06H0oooo0`00001m0?ooo`00U@3oool2000000030820P03oool0oooo0400oooo00<0P82000000000
0000o`3ooonD0?ooo`050820P0000000000000000020P8000P10@41X0?ooo`040820P00000000000
0820P7d0oooo002E0?ooo`030820P000000000000480oooo0`00003o0?oooi<0oooo00D0@4100000
00000000@4100<30`01[0?ooo`<00000OP3oool009D0oooo00@0P820000000000000`<30@@3oool2
000000030820P03oool0oooo0?l0ooooT03oool01010@400000000000010@41/0?ooo`030820P000
0000000007l0oooo002F0?ooo`80000000<0P8200?ooo`3oool0?`3oool2000000030820P03oool0
oooo0?l0ooooS`3oool01020P800000000000000001]0?ooo`80000000<0P8200?ooo`3oool0O@3o
ool009H0oooo0P0000000`10@400oooo0?ooo`0o0?ooo`80000000<0P8200?ooo`3oool0o`3ooon>
0?ooo`040820P000000000000410@6d0oooo00@0P820000000000000`<30O`3oool009H0oooo00<0
P820000000000000@03oool00`20P80000000000003o0?oooi00oooo00@0P820000000000000@410
K@3oool01030`<00000000000010@4200?ooo`00UP3oool01020P800000000000020P80o0?ooo`03
0820P000000000000?l0ooooS`3oool01020P800000000000000001^0?ooo`040820P00000000000
0820P800oooo002G0?ooo`80000000<0@4100?ooo`3oool0?@3oool00`20P80000000000003o0?oo
ohh0oooo00D0`<3000000000000000000<30`01^0?ooo`<00000P@3oool009L0oooo00<0P8200000
00000000?`3oool00`20P80000000000003o0?ooohd0oooo00@0P820000000000000@410K`3oool0
1020P800000000000020P8210?ooo`00V03oool2000000030820P03oool0oooo03`0oooo00<0P820
000000000000o`3ooon<0?ooo`040410@000000000000410@1<0oooo00<0@4100000003oool0FP3o
ool300000880oooo002H0?ooo`030820P0000000P82003h0oooo00<0P820000000000000o`3ooon;
0?ooo`040820P00000000000000001<0oooo0`0000000`20P800oooo0?ooo`1G0?ooo`030820P000
0000000008<0oooo002H0?ooo`030820P0000000@41003h0oooo00<0P820000000000000o`3ooon:
0?ooo`050<30`0000000000000000030`<004`3oool01030`<00000000000000001I0?ooo`030410
@0000000@41008<0oooo002I0?ooo`800000?P3oool00`20P80000000000003o0?ooohT0oooo00@0
P820000000000000@4105P3oool01010@400000000000010@41G0?ooo`040820P000000000000<30
`8<0oooo002I0?ooo`030410@0000000000003d0oooo00<0P820000000000000o`3ooon70?ooo`05
0<30`0000000000000000030`<00603oool01020P800000000000030`<1E0?ooo`040<30`0000000
00000410@8@0oooo002I0?ooo`030820P0000000000003d0oooo00<0P820000000000000o`3ooon7
0?ooo`<0000000<0P8200?ooo`3oool0603oool3000005D0oooo00@0P820000000000000P820Q03o
ool009T0oooo00@0`<30000000000000P820?03oool00`20P80000000000000B0?ooo`030820P030
`<00oooo0?l0ooooL@3oool01010@400000000000020P80K0?ooo`030<30`0000000`<3005D0oooo
00<0@410000000000000Q@3oool009X0oooo0P0000000`10@400oooo0?ooo`0j0?ooo`030820P000
000000000140oooo00@0P820000000000000`<30o`3ooom_0?ooo`050<30`0000000000000000030
`<00L`3oool01030`<00000000000010@4250?ooo`00VP3oool00`20P80000000000000l0?ooo`03
0820P000000000000100oooo00@0`<30000000000000@410o`3ooom_0?ooo`050<30`00000000000
00000030`<00M03oool01010@400000000000030`<250?ooo`00VP3oool01020P800000000000020
P80k0?ooo`030820P000000000000100oooo0`0000000`20P800oooo0?ooo`3o0?ooofd0oooo0`00
00000`20P800oooo0?ooo`1c0?ooo`<00000QP3oool009/0oooo0P0000000`20P800oooo0?ooo`0i
0?ooo`030410@0000000000000l0oooo00@0`<30000000000000@410o`3ooom_0?ooo`040410@000
000000000820P7D0oooo00<0P820000000000000Q`3oool009/0oooo00<0P820000000000000>`3o
ool3000000l0oooo00@0@410000000000000`<30o`3ooom]0?ooo`050<30`0000000000000000030
`<00MP3oool2000000030820P03oool0oooo08D0oooo002L0?ooo`80000000<0P8200?ooo`3oool0
>03oool3000000l0oooo00<0`<300000003oool0o`3ooom]0?ooo`050<30`0000000000000000030
`<00MP3oool3000008P0oooo002L0?ooo`030820P0000000000003X0oooo0`00003o0?ooogl0oooo
0`0000000`20P800oooo0?ooo`1e0?ooo`80000000<0P8200?ooo`3oool0QP3oool009`0oooo00@0
`<30000000000000P820>@3oool00`20P80000000000003o0?ooogd0oooo00D0P820000000000000
00000820P01g0?ooo`040820P000000000000820P8P0oooo002M0?ooo`<00000>@3oool00`20P800
00000000003o0?ooog`0oooo00D0@410000000000000@4100<30`00]0?ooo`040<30`010@4000000
0<30`4L0oooo0`0000290?ooo`00W@3oool01020P800000000000020P80h0?ooo`040<30`0000000
00000<30`?l0ooooNP3oool01010@400000000000010@40`0?ooo`040410@000000000000<30`4D0
oooo00@0P820000000000000P820R@3oool009h0oooo0`00000i0?ooo`80000000<0P8200?ooo`3o
ool0o`3ooomg0?ooo`040820P0000000000000000380oooo0P0000000`20P800oooo0?ooo`130?oo
o`<00000RP3oool009h0oooo0`0000000`30`<00oooo0?ooo`0f0?ooo`80000000<0P8200?ooo`3o
ool0o`3ooomf0?ooo`040820P000000000000410@3@0oooo0P0000000`30`<00oooo0?ooo`110?oo
o`040<30`000000000000820P8X0oooo002N0?ooo`040<30`000000000000410@3P0oooo0P000000
0`20P800oooo0?ooo`3o0?ooogD0oooo00@0@410000000000000@410=@3oool01030`<0000000000
0020P8120?ooo`030410@0000000@41008/0oooo002O0?ooo`040820P000000000000<30`3L0oooo
0P0000000`20P800oooo0?ooo`3o0?ooog@0oooo00@0@410000000000000@410=`3oool00`30`<00
@4100?ooo`110?ooo`040820P000000000000<30`8/0oooo002P0?ooo`80000000<0P8200?ooo`3o
ool0=@3oool2000000030820P03oool0oooo0?l0ooooL`3oool4000007`0oooo0`00002<0?ooo`00
X03oool00`20P80000000000000g0?ooo`80000000<0P8200?ooo`3oool0103oool00`30`<00P820
0?ooo`3o0?ooof/0oooo00@0@410000000000000@410O03oool01030`<00000000000020P82<0?oo
o`00X@3oool3000003H0oooo0P0000000`20P800oooo0?ooo`040?ooo`030410@0000000P8200?l0
ooooJP3oool01010@400000000000010@41m0?ooo`040410@000000000000<30`8`0oooo002Q0?oo
o`040820P000000000000820P3D0oooo0P0000000`20P800oooo0?ooo`030?ooo`<00000o`3ooomZ
0?ooo`040820P00000000000000007h0oooo0`00002=0?ooo`00X@3oool01030`<00000000000010
@40f0?ooo`800000103oool01030`<00000000000020P83o0?ooofP0oooo00D0`<300820P0000000
00000410@01n0?ooo`040820P000000000000820P8d0oooo002R0?ooo`030410@0000000000003H0
oooo0P0000030?ooo`040<30`000000000000410@?l0ooooJ03oool01@30`<000000000000000000
@41007l0oooo0`00002>0?ooo`00XP3oool01030`<00000000000030`<0e0?ooo`8000000`3oool0
1010@400000000000030`<3o0?ooofL0oooo00D0`<3000000000000000000<30`01o0?ooo`<00000
00<0P8200?ooo`3oool0S03oool00:<0oooo0`00000e0?ooo`800000103oool00`000000oooo0?oo
o`3o0?ooofL0oooo0`0000210?ooo`<00000S`3oool00:@0oooo0P0000000`30`<00oooo0?ooo`0b
0?ooo`80000000<0`<300?ooo`3oool0o`3ooomY0?ooo`050<30`0000000000000000030`<00BP3o
ool00`20P80000000<30`00c0?ooo`040820P000000000000820P8l0oooo002T0?ooo`030820P000
0000000003@0oooo0P0000000`20P800oooo0?ooo`3o0?ooofP0oooo00D0`<300000000000000000
0<30`01:0?ooo`050<30`0000000000000000030`<00<P3oool00`10@40000000000002@0?ooo`00
Y@3oool3000003<0oooo00<0P82000000010@400o`3ooomY0?ooo`050<30`0000000000000000030
`<00C@3oool00`10@40000000410@00a0?ooo`040<30`000000000000410@900oooo002U0?ooo`04
0820P000000000000820P380oooo00<0P820000000000000o`3ooomY0?ooo`<00000D03oool30000
0300oooo00@0P820000000000000P820T03oool00:D0oooo00@0`<300000000000000000<P3oool0
0`10@40000000820P03o0?ooofL0oooo00D0`<3000000000000000000<30`01@0?ooo`040410@000
000000000410@2l0oooo0`00002A0?ooo`00YP3oool01010@400000000000020P80_0?ooo`050<30
`0000000000000000030`<00o`3ooomV0?ooo`050410@0000000000000000030`<00DP3oool00`10
@40000000<30`00^0?ooo`030820P000000000000980oooo002W0?ooo`<0000000<0`<300?ooo`3o
ool0:`3oool01@30`<000000000000000000`<300?l0ooooIP3oool01@10@400000000000020P800
`<3008@0oooo00<0@41000000020P800TP3oool00:P0oooo0P0000000`20P800oooo0?ooo`0[0?oo
o`<0000000<0P8200?ooo`3oool0o`3ooomT0?oooc400000F@3oool2000000030820P03oool0oooo
0900oooo002X0?ooo`030<30`0000000000002`0oooo00@0@410000000000000P820o`3ooomU0?oo
od8000001`20P8000`30`<00oooo0?ooo`0o0?ooo`<00000T`3oool00:T0oooo00@0@41000000000
0000`<30:03oool01@10@4000000000000000000`<300?l0ooooD`3oool7000000030820P03oool0
oooo00T0oooo00<0P820000000000000100000000`10@400P8200820P0090820P0030410@0000000
000000@0000000<0@4100820P020P8005P20P80P000000030410@020P800P82000<0P820<@3oool0
1020P800000000000020P82C0?ooo`009`3oool00`10@40000000<30`0200?ooo`040410@0000000
00000<30`2H0oooo00D0@41000000000000000000<30`03B0?ooo`040<30`000000000000<30`6X0
oooo1`0000000`30`<00oooo0?ooo`090?ooo`L0000000<0P8200?ooo`3oool0B`3oool70820P003
0410@0000000000001<000001@20P80V0?ooo`030410@0000000000009@0oooo000X0?ooo`800000
P@3oool3000002D0oooo00D0P82000000000000000000820P03D0?ooo`030820P0000000000005L0
oooo1`00000<0?ooo`L0000000<0P8200?ooo`3oool0K@3oool00`20P80000000000000D00000003
0820P03oool0oooo01l0oooo0`00002D0?ooo`00:03oool01030`<00000000000030`<200?ooo`03
0410@0000000@41002<0oooo00@0P820000000000000@410e`3oool00`20P80000000410@01F0?oo
o`L00000303oool70820P0030<30`03oool0oooo07D0oooo1P20P8000`10@40000000000000:0000
00@0P8206@3oool01020P800000000000020P82D0?ooo`00:@3oool00`10@4000000000000200?oo
o`050<30`0000000000000000030`<007`3oool01@30`<000000000000000000@4100=T0oooo00<0
@410000000000000@@3oool00`20P800000000000005000000`0oooo1`20P82E0?ooo`<0P82000<0
00000820P010@4003@0000001010@400P8200820P020P80?0?ooo`<00000U@3oool001T0oooo00@0
`<300820P020P800`<303@3oool2000000030410@03oool0oooo07h0oooo00D0`<30000000000000
00000<30`00M0?ooo`050<30`0000000000000000030`<00c03oool01030`<00P8200820P020P80;
0?ooo`80000000<0@4100?ooo`3oool0<03oool00`30`<00P8200820P00<0?ooo`L00000?`3oool0
0`20P800`<300?ooo`1X0?ooo`040410@000000000000<30`0<0oooo1020P80;000000@0P8202@3o
ool00`30`<0000000000002F0?ooo`00603oool00`20P800000000000002000000040820P03oool0
oooo0820P080000000<0P8200?ooo`3oool01@3oool200000840oooo00D0P8200000000000000000
0820P00K0?ooo`@000002`3oool01020P800000000000020P82i0?ooo`030820P000000000000080
oooo1P00000:0?ooo`030820P000000000000380oooo00<0P820000000000000D@3oool00`20P800
00000000001Y0?ooo`040820P00000000000000000T0oooo00<0P8200000000000003@0000000`20
P800oooo0?ooo`030?ooo`030820P0000000000009H0oooo000G0?ooo`030<30`0000000000000D0
000000D0`<3000000000000000000<30`0070?ooo`030410@0000000P8200840oooo00D0P8200000
0000000000000820P00H0?ooo`050<30`010@400000000000010@4003@3oool300000;T0oooo00D0
P820000000000000oooo0410@007000000030<30`03oool0oooo00H0oooo00@0`<30000000000000
P820<P3oool200000500oooo00D0`<3000000000000000000<30`01Y0?ooo`040410@00000000000
0410@0h0oooo0`20P80:000000030410@020P800P8200080000000<0P8200?ooo`3oool0U03oool0
01L0oooo00@0@410000000000000P8200P3oool00`20P800000000000003000000P0oooo00<0P820
000000000000PP3oool01P30`<000000000000000000@4100<30`1@0oooo00<0P8200410@0000000
0P0000000`30`<00oooo0?ooo`0=0?ooo`800000^@3oool01P20P800000000000020P80000000820
P0<0oooo00D0P82000000000000000000<30`0080?ooo`<00000P`3oool01@10@400000000000020
P800`<3006/0oooo00@0P820000000000000@410503oool30820P0/00000U03oool001L0oooo0P00
00000`20P800oooo0?ooo`030?ooo`040410@00000000000000000T0oooo0P0000000`20P800oooo
0?ooo`210?ooo`060410@0000000000000000010@400P8203`3oool00`30`<00P820000000030000
00030410@020P800oooo00l0oooo0P0000000`20P800oooo0?ooo`2f0?ooo`050820P00000000000
00000020P8001@3oool01020P800000000000010@4090?ooo`80000000<0`<300?ooo`3oool0OP3o
ool01@30`<000000000000000000`<3006h0oooo00<0`<3000000010@4006P3oool40820P0<00000
00<0@4100?ooo`3oool0TP3oool001L0oooo0P0000000`20P800oooo0?ooo`030?ooo`040820P000
00000000000000T0oooo0`0000250?ooo`030820P00000000000008000003@3oool6000000030820
P03oool0oooo0100oooo00<0P82000000020P800^03oool01020P80000000000000000070?ooo`<0
00002@3oool2000000030820P03oool0oooo07l0oooo0P0000000`20P800oooo0?ooo`1^0?ooo`03
0820P03oool0oooo0;D0oooo000G0?ooo`030410@0000000000000H0oooo0`0000090?ooo`<00000
QP3oool00`20P800000000000003000000030410@020P800`<3000@0oooo0P20P8000`10@4000000
00000003000000030820P030`<00oooo0180oooo00<0P82000000010@400^03oool01020P8000000
0000000000070?ooo`040820P000000000000<30`0P0oooo0P0000000`20P800oooo0?ooo`1o0?oo
o`030820P030`<00oooo09l0oooo00<0P8200000000000000P20P8240?ooo`005`3oool01P30`<00
0000000000000000@4100<30`0<0oooo0`0000090?ooo`040820P000000000000820P8H0oooo00<0
`<300820P00000003P0000000`20P800`<300?ooo`0E0?ooo`030<30`000000000000;P0oooo00<0
P8200000000000002@3oool2000000030820P03oool0oooo00H0oooo00<0P820000000000000o`3o
oolT0?ooo`030410@0000000000000@0000000<0P8200?ooo`3oool0O`3oool001P0oooo00<0P820
00000000000010000000103oool000000000000000090?ooo`040820P000000000000820P8/0oooo
2P00003E0?ooo`030820P0000000000000T0oooo0P0000000`20P800oooo0?ooo`060?ooo`030820
P000000000000?l0oooo903oool7000000030820P03oool0oooo07l0oooo000I0?ooo`80P8202000
00090?ooo`040820P000000000000820P8d0oooo1P20P83G0?ooo`030820P0000000000000T0oooo
0P0000000`20P800oooo0?ooo`060?ooo`030820P000000000000?l0oooo9`3oool01030`<00P820
0820P020P8220?ooo`00703oool00`30`<00P8200820P004000000T0oooo00@0P820000000000000
P820o`3ooom[0?ooo`030820P0000000000000T0oooo0P0000000`20P800oooo0?ooo`060?ooo`03
0820P000000000000?l0oooo[@3oool00200oooo0`0000090?ooo`040820P000000000000820P?l0
ooooJ`3oool01020P800000000000020P8080?ooo`80000000<0P8200?ooo`3oool01P3oool00`20
P80000000000003o0?ooojd0oooo000P0?ooo`<000002@3oool01020P800000000000020P83o0?oo
of/0oooo00@0P82000000000000000001`3oool3000000T0oooo00<0P820000000000000o`3oool0
0`000000oooo0?ooo`2Z0?ooo`005`3oool20820P0030<30`03oool0oooo00@0oooo0`0000090?oo
o`040820P000000000000820P?l0ooooJ`3oool01@20P8000000000000000000`<3000H0oooo0`00
00090?ooo`030820P0000000000007H0oooo00<0P8200000003oool0Q@3oool00`20P80000000410
@02[0?ooo`005`3oool00`10@40000000410@0050?ooo`040<30`00000000000000000T0oooo0`00
003o0?ooof`0oooo00D0P82000000000000000000410@0050?ooo`040410@000000000000820P0T0
oooo0P0000000`20P800oooo0?ooo`1b0?ooo`050<30`0000000000000000030`<00Q03oool01@30
`<000000000000000000@4100:X0oooo000G0?ooo`050<30`0000000000000000010@4000P20P804
000000X0oooo0`00003o0?ooof`0oooo00H0P820000000000000oooo0410@00000030820P0<00000
00<0@4100?ooo`3oool0203oool2000000030820P03oool0oooo0740oooo00D0`<30000000000000
P8200<30`0270?ooo`050<30`0000000000000000030`<002@3oool00`10@40000000<30`02L0?oo
o`00603oool00`20P800000000000006000000030820P03oool0oooo00P0oooo0P00003o0?ooofd0
oooo00D0P820000000000000oooo0820P007000000/0oooo0P00001c0?ooo`<0000000<0P8200?oo
o`3oool0R03oool01020P800000000000020P8090?ooo`80000000<0P8200?ooo`3oool0VP3oool0
01T0oooo0P20P804000000030410@020P800oooo00T0oooo00<0P820000000000000o`3ooom]0?oo
o`030820P000000000000080oooo00<0`<300410@00000000P0000000`20P800oooo0?ooo`090?oo
o`<00000LP3oool01030`<00000000000010@42<0?ooo`030<30`020P800oooo00P0oooo00<0P820
000000000000W@3oool002/0oooo00<0@41000000020P800o`3ooom]0?ooo`030820P00000000000
0180oooo00@0`<30000000000000P820L`3oool00`20P800`<300?ooo`2G0?ooo`800000WP3oool0
02X0oooo00<0P820000000000000]`3oool20820P;@0oooo00<0P8200000000000004P3oool00`10
@40000000000003o0?ooo`h0oooo00<0P82000000020P800WP3oool002X0oooo0P0000000`20P800
oooo0?ooo`2e0?ooo`80000000<0P8200?ooo`3oool0/@3oool00`20P80000000000000B0?ooo`80
000000<0P8200?ooo`3oool0o`3oool<0?ooo`030820P0000000oooo09h0oooo000Y0?ooo`030410
@000000000000;P0oooo00<0P82000000010@400/`3oool00`20P80000000000000A0?ooo`030410
@000000000000?l0oooo3`3oool00`20P80000000?ooo`2N0?ooo`00:03oool01030`<0000000000
0030`<2h0?ooo`040<30`000000000000<30`;80oooo00<0P820000000000000403oool00`20P800
00000410@03o0?oook40oooo000W0?ooo`030<30`0000000@4100;/0oooo0P0000000`20P800oooo
0?ooo`2`0?ooo`030820P0000000000000l0oooo00<0@41000000010@400o`3ooonb0?ooo`009`3o
ool200000;d0oooo0P0000330?ooo`030820P0000000000006d0oooo0P20P83o0?oood@0oooo003V
0?ooo`80000000<0`<300?ooo`3oool0o`3oool_0?ooo`040<30`000000000000410@?l0ooooA03o
ool00>H0oooo00<0`<300820P030`<00o`3oool`0?ooo`050410@000000000000410@030`<00o`3o
oom40?ooo`00o`3ooooo0?oooaP0oooo00D0P8200410@0000000@4100820P03o0?ooodH0oooo003o
0?ooool0oooo6@3oool200000?l0ooooB03oool00?l0ooooo`3ooolI0?ooo`030820P030`<00oooo
0?l0ooooA`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3o
oooo0?oook/0oooo00<0P8200000003oool0Y03oool00?l0ooooo`3ooonk0?ooo`<00000Y03oool0
0?l0ooooo`3ooonj0?ooo`040820P000000000000820P:@0oooo003o0?ooool0oooo^P3oool00`10
@40000000000002U0?ooo`00o`3ooooo0?oookX0oooo0`00002U0?ooo`00j`3oool00`30`<00@410
0000003o0?ooolX0oooo00<0P820000000000000YP3oool00>/0oooo00@0`<30000000000000P820
o`3oooo90?ooo`80000000<0P8200?ooo`3oool0Y03oool00>`0oooo0`00003o0?ooolX0oooo00<0
00000?ooo`3oool0Y@3oool00>`0oooo00@0P820000000000000`<30o`3ooooo0?ooog80oooo003]
0?ooo`80000000<0@4100?ooo`3oool0o`3ooooo0?ooog00oooo003^0?ooo`80000000<0`<300?oo
o`3oool0o`3ooooo0?ooofl0oooo003^0?ooo`030820P0000000P8200?l0ooooo`3oooma0?ooo`00
o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooo0?oook<0oooo00@0`<3000000010@400`<30Z`3oool00?l0ooooo`3o
oonc0?ooo`040820P000000000000820P:/0oooo003o0?ooool0oooo/`3oool2000000030410@03o
ool0oooo0:X0oooo003o0?ooool0oooo/P3oool01020P800000000000030`<2/0?ooo`00m03oool0
0`30`<00P8200000003o0?oookX0oooo0P0000000`20P800oooo0?ooo`2[0?ooo`00m@3oool20000
00030820P03oool0oooo0?l0oooo]`3oool200000:h0oooo003e0?ooo`040820P000000000000<30
`?l0oooo]`3oool00`30`<00@4100820P02^0?ooo`00mP3oool00`10@40000000410@03o0?ooool0
ooooJ@3oool00?L0oooo0`00003o0?ooool0ooooJ03oool00?L0oooo00@0P820000000000000P820
o`3ooooo0?ooofL0oooo003g0?ooo`030<30`020P800oooo0?l0ooooo`3ooomX0?ooo`00o`3ooooo
0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00
o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?oooj`0oooo00<0P8200<30`03oool0/`3oool00?l0ooooo`3ooon[0?ooo`04
0820P000000000000820P;<0oooo003o0?ooool0ooooZ`3oool300000;@0oooo003o0?ooool0oooo
Z`3oool2000000030820P03oool0oooo0;80oooo003o0?ooool0ooooZP3oool01020P80000000000
0020P82d0?ooo`00o`3ooooo0?ooojX0oooo0`00002e0?ooo`00o`3ooooo0?ooojT0oooo00<0P820
000000000000]P3oool00?l0ooooo`3ooonZ0?ooo`80P820]P3oool00?l0ooooo`3ooooo0?ooof<0
oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo
0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0oooo
o`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool0
0?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0oooo
H`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?oo
ool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3o
oooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?oo
o`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3o
oomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0
ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o
0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0
oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo
0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0oooo
o`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool0
0?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0oooo
H`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?oo
ool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3o
oooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?oo
o`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{288, 125.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Fig. 6.1 Spatial domains (shown outlined by solid lines, and \
defined by the smooth dashed curves) for which (a) one can easily apply the \
Galerkin method;  (b) difficulties arise.\
\>", "Caption",
  CellTags->"Fig. 6.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.1.2 Boundary-Value Problems", "Subsubtitle",
  CellTags->{"i:4", "c:4"}],

Cell[CellGroupData[{

Cell["Theory", "Section",
  CellTags->"c:5"],

Cell["\<\
\t  Consider a time-independent boundary-value problem in two \
dimensions, \
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) \(\[Phi](x, y)\)\  = \ \[Rho](x, y)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(6.1.1)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " is some second order linear spatial operator such as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\)]],
  ".  We assume for the moment that the boundary conditions are Dirichlet, \
specified on the boundary ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " of a domain ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(V\)\(\ \)\)\)]],
  "such as that shown in Fig.",
  ButtonBox[" 6.1(a)",
    ButtonData:>"Fig. 6.1",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Phi]\)\( | \_S\)\) = \(\[Phi]\_o\)(x, y)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(6.1.2)"],

Cell[TextData[{
  "for some function  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_o\)(x, y)\)]],
  ". This function must be smoothly varying on the boundary in order for the \
Galerkin method to work efficiently. "
}], "Text"],

Cell[TextData[{
  "\tThe boundary is itself determined by the intersection of  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(M\)\(\ \)\)\)]],
  " smooth curves, each of which is defined by an equation of the form"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(z\_n\)(x, y) = 0, \ n = 1,  ... , M\)]],
  ".  "
}], "NumberedEquation",
  CellTags->"(6.1.3)"],

Cell[TextData[{
  "These curves are the lines shown schematically in Fig. ",
  ButtonBox["6.1(a)",
    ButtonData:>"Fig. 6.1",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tTo solve this problem numerically via the Galerkin method, we will \
expand ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y)\)]],
  " in a set of ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " different ",
  StyleBox["basis functions",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`{v\_\[Alpha]}\)]],
  ", chosen to satisfy homogeneous Dirichlet boundary conditions:"
}], "Text",
  CellTags->"i:5"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(v\_\[Alpha]\)\( | \_S\)\) = 0\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.4)"],

Cell["\<\
We write the solution in the standard form for an eigenmode \
expansion:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y)\  = \ 
        u(x, y)\  + \ \[Sum]\+\[Alpha]\( c\_\[Alpha]\) \(\(v\_\[Alpha]\)(x, 
                y)\)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(6.1.5)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`u(x, y)\)]],
  " is any (smooth) function that satisfies the boundary condition ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(u\)\( | \_S\)\) = \[Phi]\_o\)]],
  ", and where the ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\[Alpha]\)]],
  "'s are the Fourier coefficients that must be determined. In order to find \
these coefficients, we substitute Eq. ",
  ButtonBox["(6.1.5)",
    ButtonData:>"(6.1.5)",
    ButtonStyle->"Hyperlink"],
  " into Eq. ",
  ButtonBox["(6.1.1)",
    ButtonData:>"(6.1.1)",
    ButtonStyle->"Hyperlink"],
  ", yielding"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\[Alpha]\( 
                c\_\[Alpha]\) \(L\&^\) \(\(v\_\[Alpha]\)(x, y)\) = \[Rho](x, 
            y) - \(L\&^\) \(u(x, y)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.6)"],

Cell[TextData[{
  "Next, we take an inner product with respect to one of the basis functions, \
",
  Cell[BoxData[
      \(TraditionalForm\`v\_\[Beta]\)]],
  ": "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\[Alpha]\( c\_\[Alpha]\)(
            v\_\[Beta], \(L\&^\) 
              v\_\[Alpha]) = \((v\_\[Beta], \[Rho] - \(L\&^\) u)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.7)"],

Cell[TextData[{
  "So far, the method is identical to an eigenmode expansion. However,  the \
",
  Cell[BoxData[
      \(TraditionalForm\`v\_\[Alpha]\)]],
  "'s need ",
  StyleBox["not",
    FontSlant->"Italic"],
  " be eigenmodes of ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  "; and they need not even form an orthogonal set. Rather, they can be any \
set of functions that we choose, provided that in the limit as ",
  Cell[BoxData[
      \(TraditionalForm\`N \[Rule] \ \[Infinity]\)]],
  " they form a complete set, and provided that they satisfy Eq. ",
  ButtonBox["(6.1.4)",
    ButtonData:>"(6.1.4)",
    ButtonStyle->"Hyperlink"],
  ". (Also, it is preferable that the functions be as analytically simple in \
form as possible. )"
}], "Text"],

Cell[TextData[{
  "\tFurthermore, the inner product used in Eq. ",
  ButtonBox["(6.1.7)",
    ButtonData:>"(6.1.7)",
    ButtonStyle->"Hyperlink"],
  " can be ",
  StyleBox["any inner product over the domain V. ",
    FontSlant->"Italic"],
  "(Again, however, the simpler the better.)"
}], "Text"],

Cell[TextData[{
  "\tFor example, one possible choice for the ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\[Alpha]\)]],
  "'s is the following: let the iterator ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " equal the set of integers ",
  Cell[BoxData[
      \(TraditionalForm\`\((i, j)\)\)]],
  ", and take"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(v\_\(i\ j\)\)(x, 
          y) = \(\(x\^i\) \(y\^j\) \(\[CapitalPi]\_\(n = 1\)\%M\) \(\(z\_n\)(
              x, y)\)\ \ for\ i = 0\), 1,  ... , P\_x\ ; \ j = 0, 1,  ... , 
      P\_y\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.8)"],

Cell["With this choice, the total number of functions is", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`N = \((P\_x + 1)\) \((P\_y + 1)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.9)"],

Cell[TextData[{
  "The product of ",
  Cell[BoxData[
      \(TraditionalForm\`z\_n\)]],
  "'s implies that the ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\(i\ j\)\)]],
  "'s  are zero on the boundary surface, and the polynomial form in ",
  Cell[BoxData[
      FormBox[
        RowBox[{"x", Cell[""]}], TraditionalForm]]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " provides a sufficient range of variation so that in the limit as ",
  Cell[BoxData[
      \(TraditionalForm\`P\_x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`P\_y\)]],
  " approach infinity, the basis functions form a complete set. "
}], "Text"],

Cell["\tFor the inner product, one simple choice is", "Text",
  CellTags->"i:6"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\) = \ \[Integral]\+V\(\( f\^*\)(x, y)\)\ \(g(x, 
              y)\) \[DifferentialD]x\ \[DifferentialD]y\)]],
  ","
}], "NumberedEquation",
  CellTags->"(6.1.10)"],

Cell[TextData[{
  "where the integral runs over the domain ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  " of the problem. One could also choose ",
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\) = \ \[Integral]\+V\(\( f\^*\)(x, y)\)\ \(g(x, y)\) \(p(x, 
              y)\) \[DifferentialD]x\ \[DifferentialD]y\)]],
  " for some choice of weighting function ",
  Cell[BoxData[
      \(TraditionalForm\`p(x, y) > 0\)]],
  ". But it is preferable that ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " does not weight any one region of the domain disproportionately (unless \
there are regions of the domain where the solution is zero, or nearly zero). \
Otherwise, the solution may not converge well."
}], "Text"],

Cell[TextData[{
  "\t There is a certain art to finding good choices for the basis functions \
and the inner product. What we are looking for are choices that minimize the \
number of terms required to get a well-converged expansion for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  ", and that are sufficiently simple so that inner products in Eq. ",
  ButtonBox["(6.1.7)",
    ButtonData:>"(6.1.7)",
    ButtonStyle->"Hyperlink"],
  " can be easily evaluated. In other words, we want  a small number of ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\[Alpha]\)]],
  "'s to sum to something close to the exact solution."
}], "Text"],

Cell["\<\
\t   The best way to learn how to make good choices  is  by gaining \
experience with the method. We will work through several examples in this and \
later sections. \
\>", "Text"],

Cell[TextData[{
  "\t We now solve for the Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\[Alpha]\)]],
  ". To do so, we note that for different ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\)]],
  "-values, Eq. ",
  ButtonBox["(6.1.7)",
    ButtonData:>"(6.1.7)",
    ButtonStyle->"Hyperlink"],
  " forms a set of ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  Cell[BoxData[
      FormBox["", TraditionalForm]]],
  " linear equations in the ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " unknowns ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["c", Cell["\[Alpha]"]], TraditionalForm]]],
  ". Taking ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = \((k, l)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] = \((i, j)\)\)]],
  ", these equations are rewritten explicitly in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`\((i, j)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\((k, l)\)\)]],
  ":\t \t"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(k = 0\)\%\(P\_x\)\(\[Sum]\+\(l = \
0\)\%\(P\_y\)\((v\_\(i\ j\), \(L\&^\) v\_\(k\ l\))\) 
              c\_\(k\ l\)\) = \((v\_\(i\ j\), \[Rho] - \(L\&^\) u)\)\)]],
  ",   ",
  Cell[BoxData[
      \(TraditionalForm\`i = 0, 1,  ... , P\_x, \ \ \ \ j = 0, 1,  ... , 
      P\_y\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.11)"],

Cell[TextData[{
  "Since the inner products in Eq. ",
  ButtonBox["(6.1.11)",
    ButtonData:>"(6.1.11)",
    ButtonStyle->"Hyperlink"],
  " are merely some integrals that we can find once we have chosen the basis \
functions, we know everything that we need in  order to solve these ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " coupled linear equations for the  ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(k\ l\)\)]],
  "'s. "
}], "Text"],

Cell[TextData[{
  "\tFrom a theory perspective, it may be of use to note that the inner \
product ",
  Cell[BoxData[
      \(TraditionalForm\`\((v\_\[Beta], \(L\&^\) v\_\[Alpha])\)\)]],
  " is the projection of the operator ",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          FormBox["L",
            "TraditionalForm"], "^"], TraditionalForm]]],
  " onto the basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\[Beta]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\[Alpha]\)]],
  ", and that this projection is just another way to represent the operator \
numerically. We can think of this inner product as a square matrix ",
  Cell[BoxData[
      \(TraditionalForm\`L\_\(\[Beta]\ \[Alpha]\)\)]],
  ", so that Eq. ",
  ButtonBox["(6.1.7)",
    ButtonData:>"(6.1.7)",
    ButtonStyle->"Hyperlink"],
  " becomes the matrix equation"
}], "Text",
  CellTags->"i:3"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\[Alpha]\( L\_\(\[Beta]\ \[Alpha]\)\) 
            c\_\[Alpha] = \[Rho]\&_\_\[Beta]\)]],
  ", "
}], "NumberedEquation",
  CellTags->"(6.1.12)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\&_\_\[Beta] = \((v\_\[Beta], \ \[Rho] - \
\(L\&^\) u)\)\)]],
  ". We need merely invert the matrix to solve for the ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\[Alpha]\)]],
  "'s: ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(c\_\[Alpha]\), "=", 
          RowBox[{
            SubscriptBox[
              RowBox[{"(", 
                SuperscriptBox[
                  StyleBox["L",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], \(-1\)], 
                ")"}], \(\[Alpha]\ \[Beta]\)], \(\[Rho]\&_\_\[Beta]\)}]}], 
        TraditionalForm]]],
  ". Thus, this method has much in common with the matrix inversion methods \
that we employed in solving linear boundary-value problems in Chapter ",
  ButtonBox["2",
    ButtonData:>{"Chapter2.nb", "c:48"},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\tWe can now see why the boundary shown in Fig. ",
  ButtonBox["6.1(b)",
    ButtonData:>"Fig. 6.1",
    ButtonStyle->"Hyperlink"],
  " are more difficult to treat. The basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_\[Alpha]\)(x, y)\)]],
  " are zero along the smooth curves ",
  Cell[BoxData[
      \(TraditionalForm\`\(z\_n\)(x, y) = 0\)]],
  " that define the bounding surface. These curves are displayed as the \
dashed lines in the figure. Because of the shape of the cusp in Fig. ",
  ButtonBox["6.1(b)",
    ButtonData:>"Fig. 6.1",
    ButtonStyle->"Hyperlink"],
  ", two of the curves penetrate into the interior of the region, and so the \
functions ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\[Alpha]\)]],
  " are all zero along these curves. Therefore, they cannot form a complete \
set, since they must be able to represent arbitrary functions within the \
domain."
}], "Text"],

Cell[TextData[{
  "\tWhile it is possible to define boundary curves ",
  Cell[BoxData[
      \(TraditionalForm\`\(z\_n\)(x, y) = 0\)]],
  " that are not smooth,  forming concave cusps as shown in Fig. ",
  ButtonBox["6.1(b)",
    ButtonData:>"Fig. 6.1",
    ButtonStyle->"Hyperlink"],
  " without continuing into the interior of the domain (using nonanalytic \
functions in the definition of ",
  Cell[BoxData[
      \(TraditionalForm\`z\_n\)]],
  ": see Example 3 below), such boundary curves introduce singular behavior \
into the ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\[Alpha]\)]],
  "'s through Eq. ",
  ButtonBox["(6.1.8)",
    ButtonData:>"(6.1.8)",
    ButtonStyle->"Hyperlink"],
  ", and therefore the functions may not behave well when acted upon by ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " . Unless the functions ",
  Cell[BoxData[
      \(TraditionalForm\`z\_n\)]],
  " are carefully chosen to minimize the singular behavior, derivatives of \
these basis functions are not well behaved, and the generalized Fourier \
series solution does not converge very well.  "
}], "Text",
  CellTags->"i:7"],

Cell[TextData[{
  "\tHowever, we will see in Example 3 that even if care is taken in choosing \
mathematical forms for the boundary curves so as to minimize the singular \
behavior, the Galerkin method still faces difficulties when concave cusps are \
present. The reason is simple: such cusps introduce rapid variation in the \
solution.  Taking Poisson's equation as an example,  we noted in Exercise \
(5)(b) of Sec. ",
  ButtonBox["3.2",
    ButtonData:>{"Chapter3.nb", "c:43"},
    ButtonStyle->"Hyperlink"],
  " that  the electric field near the point of a concave cusp becomes \
infinite. Such rapid variation in the derivative of \[Phi] requires a \
Galerkin solution that keeps a large number of basis functions.  "
}], "Text"],

Cell[TextData[{
  "\tFor essentially the same reason, it is difficult to deal with boundary \
conditions that are discontinuous. A situation where one electrode is held at \
potential ",
  Cell[BoxData[
      \(TraditionalForm\`V\_1\)]],
  "  and an adjacent electrode is held at potential ",
  Cell[BoxData[
      \(TraditionalForm\`V\_2\)]],
  " is difficult to treat with the Galerkin method, because the discontinuous \
boundary condition causes rapid variation in the solution that requires many \
basis functions to resolve."
}], "Text"],

Cell[TextData[{
  "\t When dealing with boundary conditions of the sort that cause rapid \
variation in the solution, it is often easier to use other methods, such as \
the grid methods discussed in Sec. ",
  ButtonBox["6.2",
    ButtonData:>"c:13",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 1", "Section",
  CellTags->"c:6"],

Cell[TextData[{
  "As an example of the Galerkin method, we will solve a problem that we \
could also do analytically, so that we can compare the numerical solution \
with the exact solution. The problem is to find the solution to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\( \[Phi](x, y)\) = 0\)]],
  " in a square box with the boundary condition that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\  = \ 0\)]],
  " on the edges, except along ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(y = 0\)\(,\)\)\)]],
  " where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{Cell[""], \(\[Phi](x, 0)\)}], 
          "=", \(\(sin\)\(\ \)\(\[Pi]\)\(\ \)\(x\)\(\ \)\)}], 
        TraditionalForm]]],
  ".  The exact solution for \[Phi], found by separation of variables, is "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_exact\)(x, y)\  = \ 
        sin\ \[Pi]\ x\ \(sinh\ \(\[Pi](1 - y)\)\)\/\(sinh\ \[Pi]\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.13)"],

Cell[TextData[{
  "To find the solution via the Galerkin method, we first choose functions ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\(i\ j\)\)]],
  "  according to Eq. ",
  ButtonBox["(6.1.8)",
    ButtonData:>"(6.1.8)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(v[i_, j_, x_, y_]\  = \ \(x\^i\) 
          y\^j\ \ \ \ x\ y\ \((1 - x)\) \((1 - y)\);\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.1"],

Cell[TextData[{
  "These functions are zero along each edge of the box. Next, we define an \
inner product. Sometimes it is more convenient to evaluate these inner \
product integrals numerically rather than analytically, but in this case, \
analytic evaluation is faster.  However, even if one performs the integrals \
analytically, it is usually  best to convert any exact numbers to approximate \
numbers using ",
  StyleBox["N",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ",",
  StyleBox[" ",
    FontWeight->"Bold"],
  "so that the solutions to the equations are not too complicated:"
}], "Text"],

Cell[BoxData[
    \(norm[f_, g_]\  := \ 
      Integrate[f\ \ g, {x, 0, 1}, {y, 0, 1}]\ \  // N\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.2"],

Cell[TextData[{
  " (Note the use of a delayed equal sign, since the integral cannot be \
performed until ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, y)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g(x, y)\)]],
  " are known.) "
}], "Text"],

Cell[TextData[{
  "\tNext, we choose a function ",
  Cell[BoxData[
      \(TraditionalForm\`u(x, y)\)]],
  " that matches the boundary conditions:"
}], "Text"],

Cell[BoxData[
    \(\(u[x_, y_]\  = \ \((1 - y)\)\ Sin[\ Pi\ x];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.3"],

Cell[TextData[{
  "This function is indeed zero on the three sides defined by ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0, \ x = 1\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`y = 1\)]],
  ", and it equals ",
  Cell[BoxData[
      \(TraditionalForm\`sin\ \[Pi]\ x\)]],
  " on the remaining side ",
  Cell[BoxData[
      \(TraditionalForm\`y = 0\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tIt is also useful to define the operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^ = \[Del]\^2\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(L[f_]\  := \ D[f, {x, 2}]\  + \ D[f, {y, 2}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.4"],

Cell[TextData[{
  "We can now define the inner product ",
  Cell[BoxData[
      \(TraditionalForm\`L\_\(i\ j\ k\ l\) = \ \((v\_\(i\ j\), \(L\&^\) 
            v\_\(k\ l\))\)\)]],
  ","
}], "Text"],

Cell[BoxData[
    \(Lmat[i_, j_, k_, l_]\  := \ 
      norm[v[i, j, x, y], \ L[v[k, l, x, y]]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.5"],

Cell[TextData[{
  "and the inner product ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\&_\_\(i\ j\) = \((v\_\(i\ j\), \[Rho] - \
\(L\&^\) u)\)\)]],
  " (in this example, \[Rho]=0):"
}], "Text"],

Cell[BoxData[
    \(\(\[Rho]vec[i_, j_]\  := \ 
        norm[v[i, j, x, y], \ \(-L[u[x, y]]\)];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.6"],

Cell[TextData[{
  "Next, we create the coupled equations for the Fourier coefficients  ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(k\ l\)\)]],
  ". We will refer to these coefficients as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["c",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["k",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["l",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ", and we will give each equation a name, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["eq",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["i",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["j",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ", so that we may refer to it later:"
}], "Text"],

Cell[BoxData[
    \(eq[i_, j_]\  := \(eq[i, j]\  = \ 
        Sum[Lmat[i, j, k, l] c[k, l], {k, 0, Px}, {l, 0, 
              Py}]\  \[Equal] \ \[Rho]vec[i, j]\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.7"],

Cell[TextData[{
  "Here we made ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " remember each equation. Since each equation takes some time to create, we \
only want to do it once. At this point it is useful to check that everything \
is working, so we will use a ",
  StyleBox["Do",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " statement that prints out each equation. We choose values of ",
  Cell[BoxData[
      \(TraditionalForm\`P\_x = 3\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`P\_y = 3\)]],
  " so as to create 16 equations; see Eq. ",
  ButtonBox["(6.1.9)",
    ButtonData:>"(6.1.9)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text",
  CellTags->"i:59"],

Cell[BoxData[{
    \(Px\  = \ 3; Py\  = 3;\), "\n", 
    \(\(Do[
        Print["\<eq\>", {i, j}, "\< = \>", eq[i, j]], {i, 0, Px}, {j, 0, 
          Py}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.8"],

Cell[TextData[{
  "We omit the results in order to save space. But the reader can perform the \
evaluations to confirm that everything appears to be working properly. We now \
solve for the ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(k\ l\)\)]],
  "'s using ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".",
  StyleBox[" Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " takes arguments of the form ",
  StyleBox["Solve[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["equations",
    FontSlant->"Italic"],
  StyleBox["},{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["variables",
    FontSlant->"Italic"],
  StyleBox["}] ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " so we need to create a one-dimensional list of equations and another list \
of the variables. The list of equations can be created using a ",
  StyleBox["Table",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command:"
}], "Text"],

Cell[BoxData[
    \(\(eqns\  = \ 
        Flatten[Table[eq[i, j], {i, 0, Px}, {j, 0, Py}]];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.9"],

Cell[TextData[{
  " We flattened the two-dimensional table into a one-dimensional list using \
the ",
  StyleBox["Flatten",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command, in order for the list to obey the proper syntax for ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Text"],

Cell["\<\
\tTo create the variable list, we use another flattened \
table:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(vars\  = \ Flatten[Table[c[k, l], {k, 0, Px}, {l, 0, Py}]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.10"],

Cell[BoxData[
    \({c[0, 0], c[0, 1], c[0, 2], c[0, 3], c[1, 0], c[1, 1], c[1, 2], 
      c[1, 3], c[2, 0], c[2, 1], c[2, 2], c[2, 3], c[3, 0], c[3, 1], c[3, 2], 
      c[3, 3]}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now we solve for the ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(m\ n\)\)]],
  "'s:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(coefficients\  = \ \(Solve[eqns, vars]\)[\([1]\)]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.11"],

Cell[BoxData[
    \({c[0, 0] \[Rule] \(-6.672864966996882`\), 
      c[0, 1] \[Rule] 8.25579817335386`, 
      c[0, 2] \[Rule] \(-5.744315958913533`\), 
      c[0, 3] \[Rule] 1.9140259028223998`, 
      c[1, 0] \[Rule] \(-7.600798617306996`\), 
      c[1, 1] \[Rule] 9.477858343413233`, 
      c[1, 2] \[Rule] \(-6.673731026639963`\), 
      c[1, 3] \[Rule] 2.2473923269692193`, 
      c[2, 0] \[Rule] 7.600798617438556`, 
      c[2, 1] \[Rule] \(-9.477858344365645`\), 
      c[2, 2] \[Rule] 6.6737310286197715`, 
      c[2, 3] \[Rule] \(-2.2473923282040036`\), 
      c[3, 0] \[Rule] \(-1.5725707046178837`*^-10\), 
      c[3, 1] \[Rule] 1.1387185497220327`*^-9, 
      c[3, 2] \[Rule] \(-2.3675957234506418`*^-9\), 
      c[3, 3] \[Rule] 1.4769766960460618`*^-9}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This list of substitutions is used to construct ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[Phi]",
            "TraditionalForm"], "(", \(x, y\), ")"}], TraditionalForm]]],
  "  as follows:"
}], "Text"],

Cell[BoxData[
    \(\(\[Phi][x_, y_]\  = \ 
        u[x, y]\  + \ Sum[c[k, l]\ v[k, l, x, y], {k, 0, Px}, {l, 0, Py}] /. 
          coefficients;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.12"],

Cell[TextData[{
  "The result is plotted in Cell ",
  ButtonBox["6.13",
    ButtonData:>"Cell 6.13",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot3D[\[Phi][x, y], {x, 0, 1}, {y, 0, 1}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\[Phi]\>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.13"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.1978e-17 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.29165 .07573 -9.31117 -12 ]
[.29165 .07573 .68883 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.91861 .21225 0 -8.04169 ]
[.91861 .21225 10 3.95831 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01568 .31795 -24 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00696 .37264 -18 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00208 .42927 -24 -2.88161 ]
[-0.00208 .42927 0 6.11839 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[-0.05457 .39542 -10 -3.77786 ]
[-0.05457 .39542 0 8.22214 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
gsave
.91861 .21225 -61 -12.0417 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02795 .31328 m
.03408 .31095 L
s
[(0.25)] .01568 .31795 1 -0.38067 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0.5)] .00696 .37264 1 -0.37036 Mshowa
.01027 .42483 m
.01644 .42261 L
s
[(0.75)] -0.00208 .42927 1 -0.35964 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.03468 .27078 m
.03835 .26935 L
s
.03301 .2813 m
.03669 .27988 L
s
.03134 .29189 m
.03501 .29047 L
s
.02965 .30255 m
.03332 .30114 L
s
.02623 .32409 m
.02991 .3227 L
s
.02451 .33497 m
.02819 .33359 L
s
.02277 .34593 m
.02646 .34455 L
s
.02102 .35697 m
.02471 .35559 L
s
.01749 .37927 m
.02118 .37791 L
s
.0157 .39054 m
.0194 .38919 L
s
.0139 .40189 m
.0176 .40054 L
s
.01209 .41332 m
.01579 .41198 L
s
.00843 .43642 m
.01214 .4351 L
s
.00658 .4481 m
.01029 .44678 L
s
.00472 .45986 m
.00843 .45855 L
s
.00284 .4717 m
.00656 .4704 L
s
gsave
-0.05457 .39542 -71 -7.77786 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.655 .739 .912 r
.38313 .58323 .40512 .60371 .44189 .59268 .42018 .57277 Metetra
.655 .747 .918 r
.42018 .57277 .44189 .59268 .47916 .5815 .45778 .5621 Metetra
.655 .755 .923 r
.45778 .5621 .47916 .5815 .51695 .57017 .49592 .5512 Metetra
.655 .762 .928 r
.49592 .5512 .51695 .57017 .55526 .55867 .53461 .54002 Metetra
.656 .769 .932 r
.53461 .54002 .55526 .55867 .59412 .54701 .57387 .52854 Metetra
.657 .774 .935 r
.57387 .52854 .59412 .54701 .63352 .53519 .6137 .51671 Metetra
.659 .778 .936 r
.6137 .51671 .63352 .53519 .67349 .5232 .65411 .50451 Metetra
.661 .779 .936 r
.65411 .50451 .67349 .5232 .71403 .51104 .69509 .49193 Metetra
.663 .779 .935 r
.69509 .49193 .71403 .51104 .75515 .4987 .73667 .47898 Metetra
.665 .776 .932 r
.73667 .47898 .75515 .4987 .79688 .48619 .77883 .46566 Metetra
.667 .772 .928 r
.77883 .46566 .79688 .48619 .83921 .47349 .8216 .45199 Metetra
.669 .767 .923 r
.8216 .45199 .83921 .47349 .88217 .4606 .86498 .43801 Metetra
.67 .76 .918 r
.86498 .43801 .88217 .4606 .92578 .44752 .90898 .42374 Metetra
.671 .752 .912 r
.90898 .42374 .92578 .44752 .97003 .43424 .95362 .4092 Metetra
.646 .737 .915 r
.36056 .56222 .38313 .58323 .42018 .57277 .3979 .55236 Metetra
.646 .745 .922 r
.3979 .55236 .42018 .57277 .45778 .5621 .43581 .54224 Metetra
.647 .753 .927 r
.43581 .54224 .45778 .5621 .49592 .5512 .4743 .53179 Metetra
.648 .761 .932 r
.4743 .53179 .49592 .5512 .53461 .54002 .51338 .52095 Metetra
.651 .768 .935 r
.51338 .52095 .53461 .54002 .57387 .52854 .55305 .50965 Metetra
.654 .774 .937 r
.55305 .50965 .57387 .52854 .6137 .51671 .59331 .49782 Metetra
.658 .779 .938 r
.59331 .49782 .6137 .51671 .65411 .50451 .63416 .4854 Metetra
.662 .781 .937 r
.63416 .4854 .65411 .50451 .69509 .49193 .67561 .4724 Metetra
.666 .781 .935 r
.67561 .4724 .69509 .49193 .73667 .47898 .71764 .45879 Metetra
.67 .779 .931 r
.71764 .45879 .73667 .47898 .77883 .46566 .76026 .44463 Metetra
.674 .776 .927 r
.76026 .44463 .77883 .46566 .8216 .45199 .80347 .42995 Metetra
.676 .77 .921 r
.80347 .42995 .8216 .45199 .86498 .43801 .84728 .41482 Metetra
.678 .763 .916 r
.84728 .41482 .86498 .43801 .90898 .42374 .89171 .3993 Metetra
.679 .756 .909 r
.89171 .3993 .90898 .42374 .95362 .4092 .93675 .38345 Metetra
.635 .734 .92 r
.33741 .54067 .36056 .56222 .3979 .55236 .37502 .5315 Metetra
.635 .743 .926 r
.37502 .5315 .3979 .55236 .43581 .54224 .41324 .522 Metetra
.637 .752 .932 r
.41324 .522 .43581 .54224 .4743 .53179 .45207 .51209 Metetra
.64 .761 .936 r
.45207 .51209 .4743 .53179 .51338 .52095 .49153 .50166 Metetra
.644 .77 .94 r
.49153 .50166 .51338 .52095 .55305 .50965 .53161 .49058 Metetra
.65 .777 .941 r
.53161 .49058 .55305 .50965 .59331 .49782 .57231 .47877 Metetra
.656 .782 .941 r
.57231 .47877 .59331 .49782 .63416 .4854 .61363 .46614 Metetra
.663 .785 .939 r
.61363 .46614 .63416 .4854 .67561 .4724 .65555 .45268 Metetra
.669 .786 .936 r
.65555 .45268 .67561 .4724 .71764 .45879 .69806 .43838 Metetra
.675 .785 .932 r
.69806 .43838 .71764 .45879 .76026 .44463 .74115 .4233 Metetra
.68 .781 .926 r
.74115 .4233 .76026 .44463 .80347 .42995 .78483 .40751 Metetra
.684 .775 .92 r
.78483 .40751 .80347 .42995 .84728 .41482 .82908 .39113 Metetra
.686 .768 .914 r
.82908 .39113 .84728 .41482 .89171 .3993 .87393 .37425 Metetra
.687 .76 .907 r
.87393 .37425 .89171 .3993 .93675 .38345 .91939 .35695 Metetra
.622 .73 .924 r
.31365 .51855 .33741 .54067 .37502 .5315 .35151 .51021 Metetra
.623 .741 .932 r
.35151 .51021 .37502 .5315 .41324 .522 .39002 .50149 Metetra
.625 .752 .938 r
.39002 .50149 .41324 .522 .45207 .51209 .42919 .49224 Metetra
.629 .763 .943 r
.42919 .49224 .45207 .51209 .49153 .50166 .46903 .48232 Metetra
.636 .773 .946 r
.46903 .48232 .49153 .50166 .53161 .49058 .50953 .47155 Metetra
.644 .781 .947 r
.50953 .47155 .53161 .49058 .57231 .47877 .55069 .45979 Metetra
.653 .788 .946 r
.55069 .45979 .57231 .47877 .61363 .46614 .59248 .44696 Metetra
.663 .792 .944 r
.59248 .44696 .61363 .46614 .65555 .45268 .63489 .433 Metetra
.673 .794 .939 r
.63489 .433 .65555 .45268 .69806 .43838 .6779 .41794 Metetra
.681 .792 .934 r
.6779 .41794 .69806 .43838 .74115 .4233 .72149 .40184 Metetra
.688 .788 .927 r
.72149 .40184 .74115 .4233 .78483 .40751 .76564 .38482 Metetra
.692 .782 .92 r
.76564 .38482 .78483 .40751 .82908 .39113 .81036 .36702 Metetra
.695 .774 .912 r
.81036 .36702 .82908 .39113 .87393 .37425 .85565 .3486 Metetra
.697 .765 .904 r
.85565 .3486 .87393 .37425 .91939 .35695 .90152 .32967 Metetra
.605 .725 .93 r
.28926 .49583 .31365 .51855 .35151 .51021 .32734 .48854 Metetra
.606 .738 .938 r
.32734 .48854 .35151 .51021 .39002 .50149 .36612 .48078 Metetra
.61 .751 .945 r
.36612 .48078 .39002 .50149 .42919 .49224 .40562 .47238 Metetra
.616 .764 .951 r
.40562 .47238 .42919 .49224 .46903 .48232 .44583 .46312 Metetra
.625 .777 .954 r
.44583 .46312 .46903 .48232 .50953 .47155 .48676 .45276 Metetra
.636 .788 .954 r
.48676 .45276 .50953 .47155 .55069 .45979 .52838 .44114 Metetra
.65 .796 .953 r
.52838 .44114 .55069 .45979 .59248 .44696 .57067 .42811 Metetra
.663 .802 .949 r
.57067 .42811 .59248 .44696 .63489 .433 .61361 .41363 Metetra
.676 .804 .943 r
.61361 .41363 .63489 .433 .6779 .41794 .65714 .39771 Metetra
.688 .803 .936 r
.65714 .39771 .6779 .41794 .72149 .40184 .70125 .38045 Metetra
.696 .798 .928 r
.70125 .38045 .72149 .40184 .76564 .38482 .7459 .362 Metetra
.703 .791 .919 r
.7459 .362 .76564 .38482 .81036 .36702 .7911 .34258 Metetra
.706 .782 .91 r
.7911 .34258 .81036 .36702 .85565 .3486 .83683 .32238 Metetra
.708 .771 .901 r
.83683 .32238 .85565 .3486 .90152 .32967 .88312 .30158 Metetra
.584 .718 .936 r
.2642 .4725 .28926 .49583 .32734 .48854 .30247 .46652 Metetra
.585 .734 .946 r
.30247 .46652 .32734 .48854 .36612 .48078 .3415 .46 Metetra
.589 .75 .954 r
.3415 .46 .36612 .48078 .40562 .47238 .3813 .45269 Metetra
.597 .766 .96 r
.3813 .45269 .40562 .47238 .44583 .46312 .42188 .44429 Metetra
.61 .782 .963 r
.42188 .44429 .44583 .46312 .48676 .45276 .46324 .4345 Metetra
.626 .796 .964 r
.46324 .4345 .48676 .45276 .52838 .44114 .50535 .42309 Metetra
.644 .807 .961 r
.50535 .42309 .52838 .44114 .57067 .42811 .54816 .4099 Metetra
.663 .814 .956 r
.54816 .4099 .57067 .42811 .61361 .41363 .59164 .39484 Metetra
.681 .817 .949 r
.59164 .39484 .61361 .41363 .65714 .39771 .63573 .37794 Metetra
.695 .816 .94 r
.63573 .37794 .65714 .39771 .70125 .38045 .68039 .35934 Metetra
.707 .811 .929 r
.68039 .35934 .70125 .38045 .7459 .362 .72558 .33924 Metetra
.715 .802 .919 r
.72558 .33924 .7459 .362 .7911 .34258 .77127 .31791 Metetra
.719 .79 .908 r
.77127 .31791 .7911 .34258 .83683 .32238 .81746 .29563 Metetra
.72 .778 .898 r
.81746 .29563 .83683 .32238 .88312 .30158 .86416 .27265 Metetra
.555 .708 .942 r
.23846 .44853 .2642 .4725 .30247 .46652 .27686 .44422 Metetra
.556 .727 .954 r
.27686 .44422 .30247 .46652 .3415 .46 .31609 .43929 Metetra
.561 .747 .964 r
.31609 .43929 .3415 .46 .3813 .45269 .35617 .43338 Metetra
.572 .768 .971 r
.35617 .43338 .3813 .45269 .42188 .44429 .39711 .4261 Metetra
.589 .788 .975 r
.39711 .4261 .42188 .44429 .46324 .4345 .43891 .41709 Metetra
.611 .806 .975 r
.43891 .41709 .46324 .4345 .50535 .42309 .48152 .40602 Metetra
.636 .82 .971 r
.48152 .40602 .50535 .42309 .54816 .4099 .52489 .39269 Metetra
.662 .83 .964 r
.52489 .39269 .54816 .4099 .59164 .39484 .56895 .37699 Metetra
.685 .834 .955 r
.56895 .37699 .59164 .39484 .63573 .37794 .61364 .35897 Metetra
.705 .832 .943 r
.61364 .35897 .63573 .37794 .68039 .35934 .65889 .3388 Metetra
.72 .826 .931 r
.65889 .3388 .68039 .35934 .72558 .33924 .70463 .31674 Metetra
.729 .815 .918 r
.70463 .31674 .72558 .33924 .77127 .31791 .75084 .29315 Metetra
.734 .801 .905 r
.75084 .29315 .77127 .31791 .81746 .29563 .79751 .2684 Metetra
.735 .785 .893 r
.79751 .2684 .81746 .29563 .86416 .27265 .84462 .24283 Metetra
.516 .694 .949 r
.212 .42389 .23846 .44853 .27686 .44422 .25045 .42171 Metetra
.515 .716 .963 r
.25045 .42171 .27686 .44422 .31609 .43929 .28983 .41881 Metetra
.52 .741 .975 r
.28983 .41881 .31609 .43929 .35617 .43338 .33015 .41473 Metetra
.535 .767 .983 r
.33015 .41473 .35617 .43338 .39711 .4261 .37144 .40894 Metetra
.558 .794 .987 r
.37144 .40894 .39711 .4261 .43891 .41709 .41367 .40096 Metetra
.589 .818 .987 r
.41367 .40096 .43891 .41709 .48152 .40602 .4568 .3904 Metetra
.624 .837 .982 r
.4568 .3904 .48152 .40602 .52489 .39269 .50076 .37698 Metetra
.659 .85 .973 r
.50076 .37698 .52489 .39269 .56895 .37699 .54546 .36057 Metetra
.69 .855 .961 r
.54546 .36057 .56895 .37699 .61364 .35897 .5908 .34124 Metetra
.716 .853 .947 r
.5908 .34124 .61364 .35897 .65889 .3388 .63668 .3192 Metetra
.735 .845 .932 r
.63668 .3192 .65889 .3388 .70463 .31674 .68304 .29479 Metetra
.747 .831 .916 r
.68304 .29479 .70463 .31674 .75084 .29315 .7298 .26848 Metetra
.752 .814 .901 r
.7298 .26848 .75084 .29315 .79751 .2684 .77695 .24075 Metetra
.753 .795 .887 r
.77695 .24075 .79751 .2684 .84462 .24283 .82447 .21208 Metetra
.461 .671 .954 r
.18479 .39856 .212 .42389 .25045 .42171 .2232 .3991 Metetra
.455 .697 .971 r
.2232 .3991 .25045 .42171 .28983 .41881 .26264 .39883 Metetra
.46 .728 .984 r
.26264 .39883 .28983 .41881 .33015 .41473 .30314 .39711 Metetra
.478 .761 .993 r
.30314 .39711 .33015 .41473 .37144 .40894 .34474 .39327 Metetra
.511 .796 .997 r
.34474 .39327 .37144 .40894 .41367 .40096 .38741 .38669 Metetra
.554 .829 .997 r
.38741 .38669 .41367 .40096 .4568 .3904 .43109 .37685 Metetra
.603 .856 .992 r
.43109 .37685 .4568 .3904 .50076 .37698 .47568 .36341 Metetra
.652 .874 .981 r
.47568 .36341 .50076 .37698 .54546 .36057 .52107 .34621 Metetra
.695 .881 .967 r
.52107 .34621 .54546 .36057 .5908 .34124 .56713 .32532 Metetra
.729 .879 .95 r
.56713 .32532 .5908 .34124 .63668 .3192 .61372 .30102 Metetra
.753 .868 .932 r
.61372 .30102 .63668 .3192 .68304 .29479 .66074 .27376 Metetra
.768 .85 .913 r
.66074 .27376 .68304 .29479 .7298 .26848 .70809 .24413 Metetra
.774 .829 .895 r
.70809 .24413 .7298 .26848 .77695 .24075 .75575 .21278 Metetra
.773 .805 .879 r
.75575 .21278 .77695 .24075 .82447 .21208 .80369 .18035 Metetra
.381 .634 .954 r
.1568 .3725 .18479 .39856 .2232 .3991 .19503 .37653 Metetra
.365 .663 .971 r
.19503 .37653 .2232 .3991 .26264 .39883 .23441 .37966 Metetra
.366 .699 .984 r
.23441 .37966 .26264 .39883 .30314 .39711 .27501 .38101 Metetra
.388 .742 .992 r
.27501 .38101 .30314 .39711 .34474 .39327 .31687 .37974 Metetra
.433 .789 .997 r
.31687 .37974 .34474 .39327 .38741 .38669 .35997 .37503 Metetra
.496 .835 .998 r
.35997 .37503 .38741 .38669 .43109 .37685 .40422 .36621 Metetra
.567 .874 .994 r
.40422 .36621 .43109 .37685 .47568 .36341 .4495 .35285 Metetra
.637 .9 .985 r
.4495 .35285 .47568 .36341 .52107 .34621 .49567 .33474 Metetra
.697 .912 .969 r
.49567 .33474 .52107 .34621 .56713 .32532 .54253 .31197 Metetra
.744 .909 .95 r
.54253 .31197 .56713 .32532 .61372 .30102 .58992 .2849 Metetra
.775 .895 .928 r
.58992 .2849 .61372 .30102 .66074 .27376 .63768 .25413 Metetra
.792 .873 .907 r
.63768 .25413 .66074 .27376 .70809 .24413 .68569 .22043 Metetra
.799 .846 .886 r
.68569 .22043 .70809 .24413 .75575 .21278 .73388 .18463 Metetra
.796 .816 .868 r
.73388 .18463 .75575 .21278 .80369 .18035 .78223 .14761 Metetra
.26 .572 .939 r
.128 .34568 .1568 .3725 .19503 .37653 .16585 .3542 Metetra
.225 .597 .949 r
.16585 .3542 .19503 .37653 .23441 .37966 .20501 .3617 Metetra
.217 .636 .954 r
.20501 .3617 .23441 .37966 .27501 .38101 .24559 .36708 Metetra
.243 .687 .957 r
.24559 .36708 .27501 .38101 .31687 .37974 .28764 .36918 Metetra
.305 .751 .962 r
.28764 .36918 .31687 .37974 .35997 .37503 .33114 .36697 Metetra
.396 .818 .969 r
.33114 .36697 .35997 .37503 .40422 .36621 .37599 .35957 Metetra
.502 .879 .974 r
.37599 .35957 .40422 .36621 .4495 .35285 .42204 .34642 Metetra
.605 .922 .972 r
.42204 .34642 .4495 .35285 .49567 .33474 .46908 .32725 Metetra
.693 .943 .961 r
.46908 .32725 .49567 .33474 .54253 .31197 .51687 .30218 Metetra
.758 .943 .942 r
.51687 .30218 .54253 .31197 .58992 .2849 .56517 .27169 Metetra
.799 .926 .92 r
.56517 .27169 .58992 .2849 .63768 .25413 .61378 .23656 Metetra
.821 .898 .896 r
.61378 .23656 .63768 .25413 .68569 .22043 .66252 .19777 Metetra
.827 .864 .873 r
.66252 .19777 .68569 .22043 .73388 .18463 .7113 .15647 Metetra
.822 .828 .853 r
.7113 .15647 .73388 .18463 .78223 .14761 .76008 .1138 Metetra
.079 .464 .888 r
.09834 .31807 .128 .34568 .16585 .3542 .13555 .33233 Metetra
.014 .475 .873 r
.13555 .33233 .16585 .3542 .20501 .3617 .17427 .3455 Metetra
0 .507 .853 r
.17427 .3455 .20501 .3617 .24559 .36708 .21465 .35611 Metetra
.022 .564 .842 r
.21465 .35611 .24559 .36708 .28764 .36918 .25678 .36267 Metetra
.106 .646 .848 r
.25678 .36267 .28764 .36918 .33114 .36697 .30064 .3638 Metetra
.234 .746 .871 r
.30064 .3638 .33114 .36697 .37599 .35957 .34612 .35837 Metetra
.388 .844 .9 r
.34612 .35837 .37599 .35957 .42204 .34642 .39302 .34561 Metetra
.542 .922 .922 r
.39302 .34561 .42204 .34642 .46908 .32725 .44106 .3252 Metetra
.673 .966 .928 r
.44106 .3252 .46908 .32725 .51687 .30218 .48994 .29728 Metetra
.767 .975 .919 r
.48994 .29728 .51687 .30218 .56517 .27169 .53933 .26249 Metetra
.824 .957 .9 r
.53933 .26249 .56517 .27169 .61378 .23656 .58893 .22185 Metetra
.852 .924 .878 r
.58893 .22185 .61378 .23656 .66252 .19777 .63852 .1767 Metetra
.858 .883 .855 r
.63852 .1767 .66252 .19777 .7113 .15647 .68796 .12853 Metetra
.851 .84 .834 r
.68796 .12853 .7113 .15647 .76008 .1138 .73719 .07886 Metetra
0 .29 .764 r
.0678 .28963 .09834 .31807 .13555 .33233 .10401 .31123 Metetra
0 .275 .698 r
.10401 .31123 .13555 .33233 .17427 .3455 .14196 .33173 Metetra
.289 0 0 r
.14196 .33173 .17427 .3455 .21465 .35611 .18189 .34919 Metetra
.248 0 0 r
.18189 .34919 .21465 .35611 .25678 .36267 .22392 .36163 Metetra
.146 0 0 r
.22392 .36163 .25678 .36267 .30064 .3638 .26807 .36724 Metetra
.26807 .36724 .30064 .3638 .34612 .35837 .31421 .36451 Metetra
.214 .734 .734 r
.31421 .36451 .34612 .35837 .39302 .34561 .36207 .3524 Metetra
.431 .87 .804 r
.36207 .3524 .39302 .34561 .44106 .3252 .4113 .33049 Metetra
.623 .96 .852 r
.4113 .33049 .44106 .3252 .48994 .29728 .46148 .29898 Metetra
.762 .994 .87 r
.46148 .29898 .48994 .29728 .53933 .26249 .51218 .25872 Metetra
.845 .984 .865 r
.51218 .25872 .53933 .26249 .58893 .22185 .56299 .2111 Metetra
.883 .948 .848 r
.56299 .2111 .58893 .22185 .63852 .1767 .6136 .15789 Metetra
.891 .901 .828 r
.6136 .15789 .63852 .1767 .68796 .12853 .6638 .10109 Metetra
.881 .851 .809 r
.6638 .10109 .68796 .12853 .73719 .07886 .71353 .04274 Metetra
0 .057 .546 r
.03634 .26033 .0678 .28963 .10401 .31123 .07105 .29127 Metetra
.534 0 0 r
.07105 .29127 .10401 .31123 .14196 .33173 .10779 .32124 Metetra
.537 0 0 r
.10779 .32124 .14196 .33173 .18189 .34919 .1469 .34765 Metetra
.479 0 0 r
.1469 .34765 .18189 .34919 .22392 .36163 .18859 .3679 Metetra
.37 0 0 r
.18859 .3679 .22392 .36163 .26807 .36724 .23291 .37953 Metetra
.207 0 0 r
.23291 .37953 .26807 .36724 .31421 .36451 .27971 .38051 Metetra
.27971 .38051 .31421 .36451 .36207 .3524 .32868 .36942 Metetra
.32868 .36942 .36207 .3524 .4113 .33049 .37934 .34567 Metetra
.534 .903 .716 r
.37934 .34567 .4113 .33049 .46148 .29898 .43112 .30957 Metetra
.735 .986 .781 r
.43112 .30957 .46148 .29898 .51218 .25872 .48345 .26226 Metetra
.856 .997 .806 r
.48345 .26226 .51218 .25872 .56299 .2111 .53576 .20567 Metetra
.91 .965 .804 r
.53576 .20567 .56299 .2111 .6136 .15789 .58762 .1422 Metetra
.922 .915 .792 r
.58762 .1422 .6136 .15789 .6638 .10109 .63876 .07454 Metetra
.91 .859 .778 r
.63876 .07454 .6638 .10109 .71353 .04274 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{311.938, 252.812},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000650001?2000`400?l00000o`00003ooooooon6
ooooo`00oooooon6ooooo`00oooooon6ooooo`00oooooon6ooooo`00oooooon6ooooo`00oooooon6
ooooo`00oooooon6ooooo`00oooooon6ooooo`00ooooool>ooooo`Co000000?o410@ooooooooool0
LOooool00?oooooo4?ooool00ol0003oooooooooo`1cooooo`00ooooool@ooooo`03o`000?oooooo
oooo07?ooooo003ooooooa3ooooo00?o0000ooooooooool0Loooool00?oooooo4?ooool00ol0003o
ooooooooo`1cooooo`00ooooool@ooooo`03o`000?oooooooooo07?ooooo003ooooooa3ooooo00?o
0000ooooooooool0Loooool00?oooooo3_ooool00omEEEGoIVIVo`00000:ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0I_ooool00?oooooo6oooool01OmgMgOoV9RHoooooonHV9SoMgMg06Kooooo003o
oooooa_ooooo00Go410@oooooooooooooooooa0@401Vooooo`00oooooolKooooo`05o`000?oooooo
ooooooooool00000I_ooool00?oooooo6oooool01Ol0003ooooooooooooooooo000006Kooooo003o
oooooa_ooooo00Go410@oooooooooooooooooa0@401Vooooo`00oooooolEooooo`;o00001?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg06Kooooo003ooooooa;ooooo0ol000000ooooooo0000ooooo`03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0I_ooool00?oooooo4?ooool2o`0000Cooooo0_l0001^
ooooo`00ooooool=ooooo`?o00001_ooool00ol0003oooooo`00001]ooooo`00ooooool;ooooo`;o
00002?ooool4o`0006gooooo003oooooo`Sooooo0ol00009ooooo`04o`000?oXflOo0000onSKa`;o
0000K?ooool00?oooooo1Oooool3o`000003ooooool0003ooooo00Sooooo00So0000onSKaooXflOo
0000onSKaol0003oooooo`0006_ooooo003;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Rooooo`;o00003_ooool01?l0003oj=_7onSK
aol00002onSKa`;o0000Joooool00<_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01oooooo0ol0000?ooooo`05o`000?oXflOoj=_7onSK
aol000000_oXflL00ol0003oooooo`00001Zooooo`00boooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`00000Mooooo`;o00004Oooool00ol0003oj=_7onSKa`02
onSKa`07o`000?oXflOoj=_7onSKaol0003oooooo`00001Yooooo`00boooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Jooooo`?o00004oooool00ol0003o
j=_7onSKa`03onSKa`04o`000?oXflOoj=_7onSKa`;o0000JOooool00<_ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`06?ooool2o`000003ooooool0003o
oooo01;ooooo00?o0000onSKaooXflL01?oXflL01ol0003oj=_7onSKaooXflOo0000ooooool00000
J?ooool00<_ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
41005Oooool3o`0000?ooooo00?o0000ooooooooool04?ooool00ol0003oj=_7onSKa`05onSKa`03
o`000?oXflOoj=_700;oj=_70_l0001Xooooo`00boooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_oooooo^[Zjo`00000Cooooo`;o00006?ooool00ol0003oj=_7onSKa`06onSK
a`03o`000?oXflOoj=_700;oj=_700?o0000ooooool00000Ioooool00<_ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT04?ooool3o`0001[ooooo00?o0000
onSKaooXflL01_oXflL00ol0003oj=_7onSKa`03onSKa`03o`000?oooooo000006Kooooo003]oooo
o`?o00007?ooool00ol0003oj=_7onSKa`07onSKa`03o`000?oXflOoj=_700Coj=_70_l0001Voooo
o`00joooool2o`0000;ooooo00?o0000ooooooooool06Oooool00ol0003oj=_7onSKa`08onSKa`03
o`000?oXflOoj=_700Coj=_700?o0000ooooool00000IOooool007oooooo0_l00002ooooo`;o0000
Hoooool3o`00023ooooo00?o0000onSKaooXflL02?oXflL00ol0003oj=_7onSKa`03onSKa`05o`00
0?oQfLoo0000ooooool00000I?ooool007oooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMeQoooo
o`;o00008_ooool00ol0003oj=_7onSKa`09onSKa`03o`000?oXflOoj=_700;oj=_700Co0000on7I
cooQfLoohMW?0_l0001Tooooo`00P?ooool01?oMgMgo0000oa0@4?o<c<aOooooo`?o00008oooool0
0ol0003oj=_7onSKa`0:onSKa`05o`000?oXflOoj=_7onSKaol000001?oQfLl3o`0006?ooooo0020
ooooo`04onk^k_lQ8B7o410@onk^kUgooooo0_l0000Uooooo`03o`000?oXflOoj=_700_oj=_700Co
0000onSKaooXflOo00001_oQfLl00ol0003oooooo`00001Rooooo`00P?ooool01?lQ8B7oMgMgogMg
Molb<S9Jooooo`?o000000?oooooo`000?ooool09?ooool00ol0003oj=_7onSKa`0;onSKa`04o`00
0?oXflOoj=_7o`0000OohMW?0_l0001Rooooo`00Ooooool2o`0000;ooooo0_l0001Gooooo`;o0000
1Oooool00ol0003oooooooooo`0Qooooo`03o`000?oXflOoj=_700coj=_700?o0000onSKaol00000
2OoQfLl2o`00067ooooo003Iooooo`?o0000:_ooool00ol0003oj=_7onSKa`0=onSKa`;o00002_oQ
fLl00ol0003oooooo`00001Pooooo`00eoooool2o`0002gooooo00?o0000onSKaooXflL03OoXflL0
0ol0003ohMW?on7Ic`0:on7Ic`;o0000H?ooool00=Cooooo0ol0000^ooooo`03o`000?oXflOoj=_7
00goj=_70_l0000=on7Ic`;o0000Goooool00=7ooooo0ol00002ooooo`03o`000?oooooooooo02_o
oooo00?o0000onSKaooXflL03OoXflL00ol0003ohMW?o`00000=on7Ic`03o`000?oooooo000005ko
oooo002Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0
003o410@olc<c00Qooooo`;o0000<_ooool00ol0003oj=_7onSKa`0>onSKa`04o`000?oQfLoohMW?
o`0000gohMW?0_l0001Nooooo`00VOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407_ooool3o`0003Cooooo0_l0000>onSKa`05o`000?oQ
fLoohMW?on7Icol000003_oQfLl2o`0005gooooo002Iooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000001cooooo0_l0000fooooo`04o`000?o/j/[ok>[:o`00
00coj=_700?o0000on7IcooQfLl00_oQfLl00ol0003ohMW?on7Ic`0;on7Ic`?o0000GOooool009Wo
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B406Oooool3
o`0003Oooooo00?o0000oncZb_o/j/X00_o/j/X00ol0003oj=_7onSKa`08onSKa`03o`000?oQfLoo
hMW?00?ohMW?00?o0000on7IcooQfLl02_oQfLl00ol0003ofMOEomWGe@02o`0000Wooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0003kooooo002Iooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<01Oooooo0_l00003ooooo`03o`00
0?oooooooooo03?ooooo00?o0000oncZb_o/j/X01?o/j/X00ol0003oj=_7onSKa`06onSKa`03o`00
0?oQfLoohMW?00CohMW?00?o0000on7IcooQfLl02OoQfLl00ol0003ofMOEomWGe@02omWGe@;o0000
2?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@0?_ooool009Wooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo
01Kooooo0ol0000kooooo`03o`000?o/j/[ok>[:00Gok>[:00?o0000onSKaooXflL01OoXflL00ol0
003ohMW?on7Ic`04on7Ic`03o`000?oQfLoohMW?00SohMW?00?o0000omWGeOoIemD00ooIemD2o`00
00Sooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^03oooooo002Ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00Dooooo`;o0000?Oooool0
0ol0003ok>[:oncZbP07oncZbP03o`000?oXflOoj=_700?oj=_700?o0000on7IcooQfLl01OoQfLl0
0ol0003ohMW?on7Ic`07on7Ic`03o`000?oIemGofMOE00GofMOE0_l00007ooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP0nooooo`00VOooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@3oooool3o`0003kooooo00?o0000oncZb_o/j/X0
2Oo/j/X01Ol0003oj=_7onSKaooXflOo000000SohMW?00?o0000on7IcooQfLl01_oQfLl00ol0003o
fMOEomWGe@06omWGe@03o`000?oooooo000000Kooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo03gooooo002jooooo`Co0000?oooool00ol0003ok>[:oncZbP0;oncZbP03
o`000?oXflOo000000WohMW?00?o0000on7IcooQfLl01OoQfLl00ol0003ofMOEomWGe@08omWGe@;o
00001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00;So
oooo0_l00004ooooo`03o`000?oooooooooo03cooooo00?o0000oncZb_o/j/X03?o/j/X00ol0003o
hMW?on7Ic`08on7Ic`03o`000?oQfLoohMW?00CohMW?00?o0000omWGeOoIemD02_oIemD2o`0000Go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100?_ooool0
0;Gooooo0ol00014ooooo`03o`000?o/j/[ok>[:00gok>[:00?o0000on7IcooQfLl02?oQfLl00ol0
003ohMW?on7Ic`03on7Ic`03o`000?oIemGofMOE00_ofMOE00?o0000ooooool000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00/oooool2
o`0004Kooooo00?o0000oncZb_o/j/X03Oo/j/X00ol0003oi>KCo`000009on7Ic`03o`000?oQfLoo
hMW?00;ohMW?00?o0000omWGeOoIemD03OoIemD2o`0005Oooooo002`ooooo`?o0000Aoooool00ol0
003ok>[:oncZbP0=oncZbP05o`000?oTi]?oi>KConCVdol000002?oQfLl01Ol0003ohMW?on7IcooQ
fLoo0000013ofMOE00?o0000ooooool00000E_ooool00:kooooo0_l000000ooooooo0000ooooo`17
ooooo`03o`000?o/j/[ok>[:00cok>[:00?o0000onCVdooTi]<00ooTi]<00ol0003ohMW?on7Ic`05
on7Ic`04o`000?oQfLoohMW?o`0001;ofMOE00?o0000ooooool00000EOooool00:_ooooo0ol00004
ooooo`03o`000?oooooooooo04Cooooo00?o0000oncZb_o/j/X03?o/j/X00ol0003oi>KConCVd`05
onCVd`03o`000?oQfLoohMW?00CohMW?00?o0000on7Icol000004ooIemD3o`0005Gooooo002Yoooo
o`;o0000COooool00ol0003ok>[:oncZbP0<oncZbP03o`000?oTi]?oi>KC00Koi>KC00?o0000on7I
cooQfLl01?oQfLl2o`0001?ofMOE00Go0000om;Cf_l0003oooooo`00001Dooooo`00Y_ooool3o`00
04kooooo00?o0000oncZb_o/j/X03?o/j/X00ol0003oi>KConCVd`08onCVd`03o`000?oQfLoohMW?
00?ohMW?00?o0000omWGeOoIemD04OoIemD01ol0003od]?Jom;Cf_oBdm[o0000ooooool00000Dooo
ool00:Cooooo0_l0001Aooooo`03o`000?o/j/[ok>[:00_ok>[:00?o0000onCVdooTi]<02_oTi]<0
1?l0003ohMW?on7IcooQfLl2o`0001;ofMOE00?o0000om;Cf_oBdmX00ooBdmX2o`0005?ooooo001Z
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`0Pooooo`?o00000_ooool00ol0003oooooooooo`1=ooooo`03o`000?o/j/[ok>[:00_ok>[:00?o
0000onCVdooTi]<03?oTi]<00ol0003ohMW?o`000002omWGe@03o`000?oIemGofMOE00kofMOE00?o
0000om;Cf_oBdmX01?oBdmX3o`0005;ooooo001Zooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool07_ooool3o`0005Cooooo00?o0000oncZb_o/j/X02oo/
j/X00ol0003oi>KConCVd`0>onCVd`05o`000?oIemGofMOEomWGeOl000003ooIemD00ol0003od]?J
om;CfP06om;CfP;o0000D_ooool006[ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000
7Oooool2o`0005Kooooo00?o0000oncZb_o/j/X03?o/j/X00ol0003oi>KConCVd`0=onCVd`;o0000
0ooIemD00ol0003ofMOEomWGe@0<omWGe@03o`000?oBdm[od]?J00Sod]?J0_l0001Aooooo`00J_oo
ool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00006oooool3o`0005So
oooo00?o0000oncZb_o/j/X02oo/j/X00ol0003oi>KConCVd`0=onCVd`04o`000?oKh][ofn;Jo`00
00;ofMOE00?o0000omWGeOoIemD02_oIemD2o`0000_od]?J00?o0000ooooool00000D?ooool006[o
oooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0001Wooooo0_l00000
0ooooooo0000ooooo`1Gooooo`03o`000?o/j/[ok>[:00_ok>[:00?o0000onCVdooTi]<03OoTi]<0
0ol0003ofn;Jom_RfP02om_RfP03o`000?oIemGo000000_ofMOE00?o0000om;Cf_oBdmX03?oBdmX2
o`00053ooooo001Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000F
ooooo`?o0000Foooool00ol0003ok>[:oncZbP0;oncZbP03o`000?oTi]?oi>KC00goi>KC00?o0000
om_Rf_oKh]X01?oKh]X2o`0000[ofMOE00?o0000om;Cf_oBdmX03_oBdmX2o`0004oooooo001Zoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000Dooooo`;o0000GOooool2
o`0000cok>[:00?o0000onCVdooTi]<03OoTi]<00ol0003ofn;Jom_RfP06om_RfP03o`000?oIemGo
fMOE00OofMOE00?o0000om;Cf_oBdmX03ooBdmX00ol0003oooooo`00001>ooooo`00J_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool04?ooool3o`0005oooooo00Co0000
onSgcOl0003o00002Oo/j/X00ol0003oi>KConCVd`0=onCVd`03o`000?oKh][ofn;J00Oofn;J0_l0
0007omWGe@03o`000?oBdm[od]?J017od]?J0_l0001>ooooo`00SOooool2o`00067ooooo00?o0000
onSgcOoXmld00_oXmld2o`0000Kok>[:00?o0000onCVdooTi]<03OoTi]<00ol0003ofn;Jom_RfP08
om_RfP03o`000?oKh][o000000GofMOE00?o0000om;Cf_oBdmX04_oBdmX3o`0004gooooo002:oooo
o`?o00000_ooool00ol0003oooooooooo`1Mooooo`03o`000?oXmlgoj?O=00Goj?O=00?o0000oncZ
b_o/j/X00_o/j/X00ol0003oi>KConCVd`0=onCVd`03o`000?oKh][ofn;J00Wofn;J00Co0000om_R
f_oKh][o00000ooIemD00ol0003od]?Jom;CfP0Bom;CfP05o`000?o;d=ko0000ooooool00000C?oo
ool008Sooooo0_l0001Tooooo`03o`000?oXmlgoj?O=00Ooj?O=0_l000000oo/j/[o0000onCVd`0>
onCVd`03o`000?oKh][ofn;J00[ofn;J00Oo0000om_Rf_oKh][ofn;Jo`000?oIemGo000001Cod]?J
00Co0000ol_@g_o;d=kobm3N0_l0001<ooooo`00QOooool3o`0006Gooooo00?o0000onSgcOoXmld0
2_oXmld2o`0000koi>KC00?o0000om_Rf_oKh]X02ooKh]X01?l0003ofn;Jom_Rf_oKh]X2o`0001?o
d]?J0_l00005ol_@gP;o0000Boooool008;ooooo0ol0001Wooooo`03o`000?oXmlgoj?O=00_oj?O=
00?o0000on;bfOl000003?oTi]<00ol0003ofn;Jom_RfP0<om_RfP06o`000?oKh][ofn;Jo`000?oC
gMoo00004_oBdmX00ol0003obm3Nol_@gP05ol_@gP03o`000?oooooo000004[ooooo0020ooooo`;o
000000?oooooo`000?ooool0I_ooool00ol0003oj?O=onSgc@0;onSgc@05o`000?oRl]Woh_;Ion;b
fOl000002_oTi]<00ol0003ofn;Jom_RfP0=om_RfP03o`000?oKh][o000000?odmgO00?o0000om;C
f_oBdmX03_oBdmX00ol0003obm3Nol_@gP07ol_@gP;o0000B_ooool007gooooo0ol00004ooooo`03
o`000?oooooooooo06Cooooo00?o0000onSgcOoXmld02_oXmld00ol0003oh_;Ion;bf@03on;bf@;o
00001ooTi]<00ol0003ofn;Jom_RfP0>om_RfP;o00001OoCgMl00ol0003od]?Jom;CfP0;om;CfP;o
00002oo;d=h2o`0004Wooooo001kooooo`;o0000KOooool00ol0003oj?O=onSgc@0:onSgc@03o`00
0?oRl]Woh_;I00Koh_;I00?o0000onCVdooTi]<00ooTi]<00ol0003ofn;Jom_RfP0?om_RfP03o`00
0?oCgMoodmgO00GodmgO00?o0000om;Cf_oBdmX02OoBdmX00ol0003obm3Nol_@gP0;ol_@gP03o`00
0?oooooo000004Sooooo001hooooo`?o0000K_ooool00ol0003oj?O=onSgc@0:onSgc@03o`000?oR
l]Woh_;I00Soh_;I00Go0000onCVdooTi]?oi>KCo`00000@om_RfP?o00002?oCgMl00ol0003od]?J
om;CfP07om;CfP03o`000?o;d=kobm3N00gobm3N0ol00017ooooo`00?Oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00009?ooool2o`00073ooooo00?o0000onSgcOoXmld0
2_oXmld00ol0003oh_;Ion;bf@0:on;bf@03o`000?oTi]?o0000013ofn;J00Co0000om?MgooCgMoo
00002?oCgMl00ol0003od]?Jom;CfP06om;CfP03o`000?o;d=kobm3N00kobm3N00?o0000ooooool0
0000Aoooool003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A4027ooooo0ol00002ooooo`03o`000?oooooooooo06cooooo00?o0000onSg
cOoXmld02_oXmld00ol0003oh_;Ion;bf@0;on;bf@;o00004?oKh]X00ol0003odmgOom?Mg`02om?M
g`03o`000?oCgMoodmgO00KodmgO00?o0000om;Cf_oBdmX00ooBdmX2o`0001;obm3N0_l00009oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`0W
ooooo`00?Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h08?ooool2
o`0007?ooooo00?o0000onSgcOoXmld02_oXmld00ol0003oh_;Ion;bf@0;on;bf@04o`000?oJk>3o
f^cPo`0000kofn;J00?o0000om?MgooCgMl00ooCgMl00ol0003odmgOom?Mg`07om?Mg`05o`000?oB
dm[od]?Jom;Cf_l000005?o;d=h3o`0000Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1oooool00ol0003oooooooooo`0Xooooo`00?Oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h07?ooool3o`0007Cooooo00?o0000onSgcOoXmld02_oXmld00ol0003o
h_;Ion;bf@0;on;bf@03o`000?oJk>3of^cP00;of^cP00?o0000om_Rf_oKh]X02_oKh]X00ol0003o
dmgOom?Mg`04om?Mg`03o`000?oCgMoodmgO00SodmgO00?o0000om;Cf_l000005?o;d=h01Ol0003o
aLkQo`000?oooooo000000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000:Oooool0
03gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo01Sooooo0ol0001f
ooooo`03o`000?oXmlgoj?O=00[oj?O=00?o0000on;bfOoRl]T02ooRl]T00ol0003of^cPom[/h004
om[/h003o`000?oKh][ofn;J00Oofn;J0_l00007om?Mg`03o`000?oCgMoodmgO00SodmgO0_l0000C
ol_@gP;o00000oo5c^42o`0000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oM
gMgoooooo`0002[ooooo000mooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Eooooo`;o00000_ooool00ol0003oooooooooo`1dooooo`03o`000?oXmlgoj?O=00Woj?O=
00?o0000on;bfOoRl]T02ooRl]T00ol0003of^cPom[/h006om[/h003o`000?oKh][ofn;J00Gofn;J
00?o0000om?MgooCgMl01ooCgMl00ol0003odmgOom?Mg`07om?Mg`03o`000?o<f>;o000001;obm3N
00?o0000olG>hOo5c^401?o5c^42o`0000Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04
omgMgOmEEEGoooooo`0000kooooo0ol000000ol@413oooooooooo`0Fooooo`00?Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Dooooo`?o0000N_ooool0
0ol0003oj?O=onSgc@09onSgc@03o`000?oRl]Woh_;I00_oh_;I00?o0000om[/h?oJk>002?oJk>00
0ol0003ofn;Jom_RfP03om_RfP03o`000?oCgMoodmgO00SodmgO00?o0000om?MgooCgMl01_oCgMl0
1Ol0003oc=SRolcHh_o<f>;o0000013obm3N00?o0000olG>hOo5c^401Oo5c^400ol0003oooooo`00
0005ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000@ooooo`03oa0@
4?nj^[[ooooo01Oooooo000mooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<01;ooooo0_l0001looooo`03o`000?oXmlgoj?O=00Woj?O=00?o0000on;bfOoR
l]T02ooRl]T00ol0003of^cPom[/h00:om[/h005o`000?oKh][ofn;Jom_Rf_l000002ooCgMl00ol0
003odmgOom?Mg`04om?Mg`;o00001Oo<f>800ol0003obm3Nol_@gP0;ol_@gP;o00002Oo5c^43o`00
00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co0000013ooooo00?oV9RH
oc8b<_ooool05oooool0067ooooo0ol0001mooooo`03o`000?oXmlgoj?O=00Woj?O=00?o0000on;b
fOoRl]T02ooRl]T00ol0003of^cPom[/h00<om[/h003o`000?oKh][o000000codmgO00?o0000om?M
gooCgMl00ooCgMl00ol0003oc=SRolcHhP05olcHhP03o`000?o;d=kobm3N00[obm3N00?o0000olG>
hOo5c^402_o5c^42o`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003o
oooo00oooooo00?ogMgMo`000?nj^[X05oooool005oooooo0_l000000ooooooo0000ooooo`1loooo
o`03o`000?oXmlgoj?O=00Woj?O=00?o0000on;bfOoRl]T02_oRl]T2o`0000oof^cP0_l0000=om?M
g`04o`000?oCgMoodmgOom?Mg`;o00002Oo<f>800ol0003obm3Nol_@gP07ol_@gP;o00003Oo5c^40
0ol0003oooooo`00000Wooooo`03oeEEEOmgMgOoA4A401Oooooo001Looooo`?o0000P?ooool00ol0
003oj?O=onSgc@09onSgc@03o`000?oRl]Woh_;I00[oh_;I00?o0000om[/h?oJk>003_oJk>001?l0
003od^GUom;UiOl0000<om?Mg`04o`000?oCgMoodmgOo`0000coc=SR00?o0000ol_@g_o;d=h01Oo;
d=h00ol0003oaLkQolG>h@0>olG>h@;o00009_ooool01OoMgMgo410@oooooolQ8B7ogMgM01Kooooo
001Jooooo`;o0000P_ooool4o`0000Soj?O=00?o0000on;bfOoRl]T02_oRl]T00ol0003of^cPom[/
h00>om[/h003o`000?oBiNGod^GU00;od^GU00?o0000om?MgooCgMl02OoCgMl00ol0003odmgOo`00
000>olcHhP03o`000?o;d=kobm3N00?obm3N00?o0000olG>hOo5c^404?o5c^42o`0002Gooooo00Go
IVIVohN7QoooooooV9RHoeEEE@0Fooooo`00Eoooool3o`0008Cooooo00Co0000om_oc_oKolkofoo>
1Ol00002onSgc@03o`000?oRl]Woh_;I00[oh_;I00?o0000om[/h?oJk>003OoJk>02o`0000Kod^GU
00?o0000om?MgooCgMl02?oCgMl2o`0000ooc=SR00Co0000ol_@g_o;d=kobm3N0_l0000ColG>h@03
o`000?oooooo000002?ooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`0Dooooo`00
EOooool3o`0008Gooooo00?o0000om_oc_oKolh01ooKolh3o`0000_oh_;I00?o0000om[/h?oJk>00
3OoJk>000ol0003od^GUom;Ui@07om;Ui@03o`000?oCgMoodmgO00KodmgO0_l0000AolcHhP03o`00
0?o;d=ko000001KoaLkQ0_l0000Sooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooooooo
ool04oooool005;ooooo0ol00003ooooo`03o`000?oooooooooo087ooooo00?o0000om_oc_oKolh0
1ooKolh01?l0003of?_MomSkgOoHnmd2o`0000Soh_;I00?o0000om[/h?oJk>003OoJk>000ol0003o
d^GUom;Ui@09om;Ui@03o`000?oCgMoodmgO00?odmgO0_l000000oo<f>;o0000olcHhP0@olcHhP;o
00005oo5c^43o`0003kooooo001?ooooo`?o0000ROooool00ol0003ofoo>om_ocP07om_ocP03o`00
0?oHnmgof?_M00Cof?_M0ol00004on;bf@03o`000?oJk>3of^cP00cof^cP0_l0000=om;Ui@05o`00
0?oCgMoodmgOom?Mgol000000oo<f>800ol0003oc=SRolcHhP0>olcHhP03o`000?o6e>Go000001Go
aLkQ0_l000001?o0bn?o0000ooooool0000mooooo`00COooool2o`0008_ooooo00?o0000om_oc_oK
olh01ooKolh00ol0003of?_MomSkg@08omSkg@;o000000?oh_;Io`000?oJk>003OoJk>000ol0003o
d^GUom;Ui@0>om;Ui@03o`000?oCgMoo000000Coc=SR00?o0000olcHh_o<f>803?o<f>82o`0000?o
a]CU00?o0000olG>hOo5c^404Oo5c^400ol0003o`<_Sol3;h`02ol3;h`;o0000?Oooool002;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Sooooo`?o0000S?ooool00ol0003ofoo>om_ocP07om_ocP03
o`000?oHnmgof?_M00[of?_M0ol0000=om[/h003o`000?oBiNGod^GU00ood^GU0_l00005olcHhP03
o`000?o<f>;oc=SR00_oc=SR00?o0000olKDiOo6e>D01?o6e>D00ol0003oaLkQolG>h@0>olG>h@;o
00001_o0bn<2o`0003cooooo000Rooooo`05ogMgMonHV9SooooooiRHV?mgMgL08Oooool2o`0000?o
oooo00?o0000ooooooooool0R?ooool00ol0003ofoo>om_ocP07om_ocP03o`000?oHnmgof?_M00[o
f?_M00Co0000om;di_oBm>Kod_CV0_l0000:om[/h003o`000?oBiNGod^GU00ood^GU00Co0000ol[O
j?o:gnSo00001Oo<f>800ol0003oc=SRolcHhP08olcHhP;o00002?o6e>D00ol0003oaLkQolG>h@0;
olG>h@;o00002?o0bn<2o`0003cooooo000Rooooo`05oa0@4?ooooooooooooooool@41007_ooool3
o`0008oooooo00?o0000om_oc_oKolh01ooKolh00ol0003of?_MomSkg@0:omSkg@03o`000?oBm>Ko
d_CV00Cod_CV0_l00006om[/h0;o00004?oBiND2o`0000Cob]oX00?o0000olcHh_o<f>800_o<f>80
0ol0003oc=SRolcHhP06olcHhP;o00002oo6e>D00ol0003oaLkQolG>h@09olG>h@03o`000?o0bn?o
`<_S00Wo`<_S0_l0000kooooo`008_ooool01Ol0003ooooooooooooooooo000001cooooo0_l0002A
ooooo`03o`000?oKolkofoo>00Oofoo>00?o0000omSkgOoHnmd02_oHnmd00ol0003od_CVom;diP07
om;diP03o`000?oJk>3of^cP00;of^cP00?o0000om;UiOoBiND03ooBiND00ol0003ob]oXol[Oj005
ol[Oj005o`000?o<f>;oc=SRolcHh_l000001oo<f>800ol0003oa]CUolKDi@0;olKDi@03o`000?o5
c^7oaLkQ00OoaLkQ0_l0000=ol3;h`;o0000>_ooool002;ooooo00Go0000ooooooooooooooooo`00
000Iooooo`?o0000T_ooool00ol0003ofoo>om_ocP07om_ocP03o`000?oHnmgof?_M00[of?_M00?o
0000om;di_oBm>H02OoBm>H2o`000003om[/h?l0003od^GU013od^GU00?o0000ol[Oj?o:gnP01oo:
gnP01?l0003oc=SRolcHh_l00005olcHhP;o00003oo6e>D00ol0003oaLkQolG>h@04olG>h@;o0000
3oo0bn<2o`0003[ooooo000Rooooo`05oa0@4?ooooooooooooooool@41005oooool2o`0000;ooooo
00?o0000ooooooooool0Soooool00ol0003ofoo>om_ocP07om_ocP03o`000?oHnmgof?_M00Wof?_M
0_l0000=om;diP?o00003ooBiND2o`0000_ob]oX00?o0000olcHh_l000001?o<f>800ol0003oa]CU
olKDi@0@olKDi@03o`000?o5c^7oaLkQ00;oaLkQ00?o0000ol3;hoo0bn<04?o0bn<2o`0003Wooooo
000Rooooo`05ogMgMonHV9SooooooiRHV?mgMgL05?ooool3o`0009Kooooo00?o0000om_oc_oKolh0
1_oKolh00ol0003of?_MomSkg@09omSkg@03o`000?oBm>Kod_CV00cod_CV00Go0000olc]joo<kN_o
c>g[o`00000=om;Ui@03o`000?o:gnSob]oX00cob]oX0_l00002olcHhP;o00005?o6e>D01?l0003o
aLkQo`000?l0000Col3;h`?o0000>?ooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aoooo
o`?o0000V?ooool00ol0003ofoo>om_ocP06om_ocP03o`000?oHnmgof?_M00Wof?_M00?o0000om;d
i_oBm>H03?oBm>H00ol0003oc>g[olc]j`03olc]j`03o`000?oBiNGod^GU00Sod^GU0_l0000@ol[O
j003o`000?o<f>;o000001Koa]CU0_l0000Fol3;h`;o0000>?ooool003Kooooo0_l0002Jooooo`03
o`000?oKolkofoo>00Kofoo>00?o0000omSkgOoHnmd02OoHnmd00ol0003od_CVom;diP0;om;diP;o
00001oo<kN/00ol0003od^GUom;Ui@06om;Ui@03o`000?o:gnSob]oX013ob]oX0_l0000EolKDi@;o
000000?o`=3Vo`000?o0bn<05Oo0bn<3o`0003Oooooo000cooooo`?o00000_ooool00ol0003ooooo
ooooo`2Fooooo`03o`000?oKolkofoo>00Kofoo>00?o0000omSkgOoHnmd02OoHnmd00ol0003od_CV
om;diP0;om;diP03o`000?o<kN_oc>g[00Soc>g[00?o0000om;UiOoBiND01?oBiND00ol0003ob]oX
ol[Oj00@ol[Oj0?o00005?o6e>D00ol0003o`=3Vol3@iP02ol3@iP03o`000?o0bn?o`<_S017o`<_S
0_l000001?nlb>Co0000ooooool0000fooooo`00<Oooool2o`0009gooooo00?o0000om_oc_oKolh0
1_oKolh00ol0003of?_MomSkg@08omSkg@;o00003OoBm>H00ol0003oc>g[olc]j`0:olc]j`04o`00
0?oBiNGod^GUom;Ui@;o00004?o:gnP3o`000004olCIjOl0003oa=WYo`00017oa]CU0_l00006ol3@
iP03o`000?o0bn?o`<_S00ko`<_S0_l00004okc8i0;o0000=_ooool002kooooo0ol0002Nooooo`03
o`000?oKolkofoo>00Kofoo>00?o0000omSkgOoHnmd02?oHnmd00ol0003od_CVom;diP0;om;diP;o
00003_o<kN/00ol0003od^GUo`00000?ol[Oj0Co00001?o4fNT00ol0003oa=WYo`00000>olKDi@;o
00002?o0d>H00ol0003o`<_Sol3;h`0<ol3;h`;o00001onlb>@2o`0003Gooooo000]ooooo`;o0000
Woooool00ol0003ofoo>om_ocP06om_ocP03o`000?oHnmgof?_M00Sof?_M00?o0000om;di_oBm>H0
2ooBm>H00ol0003oc>g[olc]j`0>olc]j`?o00003?o:gnP3o`000003ol[Oj?l0003o000000Koa=WY
00?o0000olCIjOl000003?o6e>D00ol0003o`=3Vol3@iP09ol3@iP03o`000?o0bn?o`<_S00Wo`<_S
0_l00009okc8i003o`000?oooooo000003Cooooo000]ooooo`?o0000WOooool00ol0003ofoo>om_o
cP03om_ocPKo00002?oHnmd00ol0003od_CVom;diP0;om;diP03o`000?o<kN_oc>g[00koc>g[00Go
0000olKUkOo6iNgoa^G]o`000008ol[Oj0?o00000oo:gnP00ol0003oa=WYolCIj@07olCIj@03o`00
0?o4fNWo000000Woa]CU0_l0000=ol3@iP03o`000?o0bn?o`<_S00Oo`<_S00?o0000okc8i?nlb>@0
2_nlb>@3o`0003?ooooo000/ooooo`?o000000?oooooo`000?ooool0V_ooool00ol0003ofoo>o`00
0004o`000003okclaol0003o`okN00?o`okN1Ol00002omSkg@03o`000?oBm>Kod_CV00_od_CV00?o
0000olc]joo<kN/03Oo<kN/2o`0000Goa^G]00?o0000ol[Oj?o:gnP00_o:gnP3o`0000Gob]oX00?o
0000olCIjOo4fNT02?o4fNT01?l0003oa=WYolCIjOl00006olKDi@;o00004?o0d>H00ol0003o`<_S
ol3;h`04ol3;h`;o00003_nlb>@2o`0000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<01Gooooo000]ooooo`;o00000_ooool00ol0003o
ooooooooo`2Fooooo`Co00001Onlo<L00ol0003o`okNol?ngP08ol?ngPCo00002_oBm>H2o`0000oo
c>g[00?o0000olKUkOo6iNd01_o6iNd4o`0000Kob]oX0_l0000<olCIj@04o`000?o4fNWoa=WYo`00
00Coa]CU00?o0000ol3@i_o0d>H04?o0d>H00ol0003o`<_Sol3;h`02ol3;h`;o00004Onlb>@2o`00
00Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonH
V9So8B4Q01Gooooo000Qooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo09Cooooo00?o0000okclaonlo<L01_nlo<L00ol0003o`okN
ol?ngP08ol?ngP03o`000?o4nN_oa?W[00;oa?W[0ol00006om;diP03o`000?o<kN_oc>g[00goc>g[
0_l00007olKUk@?o000000?oa^G]o`000?o:gnP01Oo:gnP00ol0003oa=WYolCIj@0=olCIj@05o`00
0?o4fNWoa=WYo`000?o6e>D00_l0000Dol3@iP04o`000?o0bn?o0000o`0001?o_<ST0_l00008oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001Gooooo000Q
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool2o`0000;ooooo00Co0000oooooooooooo0000
U?ooool00ol0003o_?c7okcla`06okcla`03o`000?o3o]ko`okN00Oo`okN0_l00008olCij`?o0000
0_oBm>H00ol0003oc>g[olc]j`0<olc]j`;o00001_o6iNd3o`0000Goa^G]00Co0000ol[Oj?o:gnSo
b]oX0_l0000@olCIj@03o`000?o4fNWoa=WY00;o00005_o0d>H2o`0001Ko_<ST0_l00007ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q01Gooooo000Qoooo
o`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0009;ooooo00?o0000okclaonlo<L01Onlo<L2o`0000Wo`okN00?o0000olCijoo4nN/02oo4
nN/3o`0000goc>g[00?o0000olKUkOo6iNd00oo6iNd3o`0000Woa^G]00?o0000ol[Oj?l000004oo4
fNT2o`000003okoDj_l0003o`=3V01?o`=3V0_l000000onkcNOo0000okc8i00Eokc8i0;o00001ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Eooooo`00
8Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool2o`000003
ooooool0003ooooo08oooooo00?o0000okclaonlo<L01Onlo<L00ol0003o`okNol?ngP08ol?ngP03
o`000?o4nN_oa?W[00_oa?W[00Go0000ol;alOo2lO7o`_7ao`00000:olc]j`;o00000oo6iNd3o`00
00coa^G]0ol0000BolCIj@03o`000?noe>[o000000;o_mCZ00?o0000ol3@i_o0d>H04?o0d>H00ol0
003o^lgWok_=i`02ok_=i`03o`000?nlb>Co_<ST017o_<ST0_l000000onhanGo0000o`000006oooo
o`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Gooooo`008Oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00002>
ooooo`03o`000?nlo<Oo_?c700Go_?c700?o0000ol?ng_o3o]h01oo3o]h2o`0000coa?W[0_l00005
ol;al@;o00001oo<kN/00ol0003oa^G]olKUk@03o`0000goa^G]0_l00003ol3NkP03o`000?o4fNWo
a=WY00goa=WY0_l00003okoDjP04o`000?noe>[o_mCZo`0000oo`=3V0_l00006ok_=i`03o`000?nl
b>Co_<ST00ko_<ST0_l00004okS7i@;o00001Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00?ogMgMoa0@4?nHV9P05oooool0027ooooo00Go410@oooooooooooooooooa0@4005ooooo`;o0000
2?ooool00ol0003oooooo`00002<ooooo`03o`000?nlo<Oo_?c700Go_?c700?o0000ol?ng_o3o]h0
1oo3o]h00ol0003oa?W[olCij`0:olCij`;o00002Oo2lO42o`0000?oc>g[0_l000000oo6iNgo0000
o`00000>olKUk@;o00001_o0g^h00ol0003oa=WYolCIj@0:olCIj@;o00001Onoe>X01Ol0003o_mCZ
okoDj_noe>[o000000co`=3V0_l00009ok_=i`03o`000?nlb>Co_<ST00_o_<ST0_l00007okS7i@03
o`000?oooooooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000
oa0@41Gooooo000Qooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooo000008[ooooo00?o0000okclaonlo<L01Onlo<L00ol0003o`okNol?ngP06
ol?ngP;o00003?o4nN/00ol0003o`_7aol;al@0;ol;al@03o`000?o<kN_o000000?o00003_o6iNd2
o`0000Wo`=k^00?o0000olCIjOo4fNT01oo4fNT2o`0000So_mCZ00Go0000okoDj_noe>[o_mCZo`00
0009ol3@iP;o00003?nkcNL00ol0003o_<STokc8i007okc8i0?o00002OnhanD2o`0002kooooo000Q
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooo000008Oooooo0_l00006okcla`;o00002?o3o]h00ol0003oa?W[olCij`0:olCij`;o00003_o2
lO43o`0000ooa^G]0_l0000<ol3NkP03o`000?o4fNWoa=WY00Coa=WY0_l0000;okoDjP05o`000?no
e>[o_mCZokoDj_l000001_o0d>H2o`0000ko^lgW00?o0000okc8i?nlb>@01Onlb>@2o`0000go^<OU
0_l0000]ooooo`00:oooool00ol0003oooooooooo`0:ooooo`?o0000QOooool00ol0003o_?c7okcl
a`05okcla`03o`000?o3o]ko`okN00Oo`okN00?o0000olCijoo4nN/02Oo4nN/2o`0000go`_7a0ol0
0003okkXl`;o00003?o6iNd00ol0003o`=k^ol3NkP0=ol3NkP03o`000?o4fNWoa=WY00;oa=WY00?o
0000okoDj_noe>X03?noe>X01Ol0003o_mCZokoDj_noe>[o000000Co`=3V00?o0000ok_=ionkcNL0
3onkcNL00ol0003o_<STokc8i002okc8i0;o00004?nhanD00ol0003oooooooooo`0[ooooo`00:ooo
ool2o`0000cooooo0ol00023ooooo`03o`000?nlo<Oo_?c700Go_?c700?o0000ol?ng_o3o]h01_o3
o]h2o`0000_oa?W[00?o0000ol;alOo2lO402_o2lO44o`0000Oo_^Sc0_l00008olKUk@;o00004Oo0
g^h01?l0003oa=WYo`000?l0000?okoDjP03o`000?noe>[o_mCZ00;o_mCZ00Co0000ol3@i_l0003o
00004onkcNL01?l0003o_<STo`000?l0000BokS7i@;o0000;?ooool002_ooooo00?o0000oooooooo
ool03?ooool4o`00083ooooo00?o0000okclaonlo<L01Onlo<L00ol0003o`okNol?ngP06ol?ngP03
o`000?o4nN_oa?W[00Woa?W[0_l0000:ol;al@?o000000?o`_7ao`000?l000002_nnj?<00ol0003o
a^G]olKUk@03olKUk@;o00004oo0g^h2o`0001;o_mCZ00Co0000okoDj_noe>[o_mCZ0_l0000Eok_=
i`;o00005OnhanD2o`0002_ooooo000[ooooo`03o`000?oooooooooo00gooooo1?l0001nooooo`03
o`000?nlo<Oo_?c700Go_?c700Co0000ol?ng_o3o]ko`okN2?l00008olCij`;o00002Oo2lO43o`00
00;o`_7a0_l0000=okkXl`;o000000?oa^G]o`000?l000004oo0g^h2o`000003okcHk_l0003o_mCZ
01;o_mCZ0ol000000onjd>_o0000ok_=i`0Bok_=i`;o000000?o^<[Xo`000?nhanD05?nhanD2o`00
02_ooooo000Zooooo`;o00004?ooool4o`0007cooooo00?o0000okclaonlo<L00onlo<L7o`0000;o
WoGJ0_l00004ojcgk@Go00000_o4nN/00ol0003o`_7aol;al@06ol;al@?o00000oo2lO42o`00013o
_^Sc0ol0000Bol3NkP;o00001?nlf>h00ol0003o_mCZokoDjP0?okoDjP;o00001?njd>/00ol0003o
^lgWok_=i`0>ok_=i`;o00001?nhb^P00ol0003o^<OUokS7i@0CokS7i@;o0000:_ooool002[ooooo
00?o0000ooooooooool04?ooool2o`000003ohP00?l0003ooooo07Wooooo00?o0000okclaonlo<L0
1Ol00006oioefP;o00002on/mnd4o`0000Co`_7a0ol00004ol;al@;o00004?nnj?<2o`0000?o^^7c
00?o0000ol3Nk_o0g^h03Oo0g^h2o`0000Oo_=S^00?o0000okoDj_noe>X03?noe>X2o`0000;o^]3[
00?o0000ok[@jonjd>/00_njd>/00ol0003o^lgWok_=i`0;ok_=i`;o00001onhb^P00ol0003o^<OU
okS7i@0BokS7i@?o0000:Oooool002[ooooo00?o0000ooooooooool04Oooool5o`0007Oooooo1?l0
0002ohSW]`;o00001_nOmMX00ol0003o[?O]ojcgk@09ojcgk@;o00001?nalOH4o`0000Ko`_7a00?o
0000okkXlonnj?<03_nnj?<2o`0000Ko^^7c00?o0000ol3Nk_o0g^h02_o0g^h2o`0000[o_=S^00?o
0000okoDj_noe>X02?noe>X3o`0000Go^]3[00?o0000ok[@jonjd>/00_njd>/00ol0003o^lgWok_=
i`08ok_=i`;o00002Onhb^P00ol0003o^<OUokS7i@0?okS7i@?o000000?o]LGVo`000?l00000:Ooo
ool002[ooooo00?o0000ooooooooool04_ooool01Ol0003o04[3o`000?n8003o000007Cooooo0ol0
0003ohSW]`;o00001_nOmMX2o`0000[o[?O]0_l00004ok7amP?o00000_nalOH3o`0000;o`_7a0_l0
000?okkXl`;o00002OnjhO<00ol0003o`=k^ol3NkP08ol3NkP03o`000?nlf>ko_=S^00_o_=S^00?o
0000okoDj_noe>X01Onoe>X2o`0000Wo^]3[00?o0000ok[@jonjd>/00_njd>/00ol0003o^lgWok_=
i`05ok_=i`;o00003?nhb^P00ol0003o^<OUokS7i@0<okS7i@;o00001OneaNH2o`0002Sooooo000Z
ooooo`?o00004oooool01?l0003o04[3o`000?n80002o`00077ooooo00?o0000ohSW]on8ikL00on8
ikL00ol0003oWoGJoioefP04oioefP;o00002_n/mnd2o`0000?o/O7f0ol00008ok7amP?o00003_nn
j?<2o`0000co^^7c00?o0000ol3Nk_o0g^h01Oo0g^h2o`0000oo_=S^00?o0000okoDj_noe>X00_no
e>X2o`0000_o^]3[00?o0000ok[@jonjd>/00onjd>/00ol0003o^lgWok_=i`02ok_=i`;o00003onh
b^P00ol0003o^<OUokS7i@08okS7i@?o00002?neaNH2o`0002Oooooo000Yooooo`;o00005_ooool0
0ol0003o04[3o`000002ohP000;o0000KOooool2o`0000CoR>Ng0_l00005oioefP;o00002_n/mnd2
o`0000;o/O7f0ol00009ok7amP;o00000onbjOP00ol0003o_^ScokkXl`0:okkXl`03o`000?njhO?o
^^7c00go^^7c00?o0000ol3Nk_o0g^h00_o0g^h2o`0001;o_=S^00Co0000okoDj_l0003o00003_nj
d>/00ol0003o^]3[ok[@j`03ok[@j`04o`000?nkcNOo0000o`0001;o^<[X00?o0000okS7iOnhanD0
1OnhanD2o`0000_o]LGV0_l0000Wooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool05_ooool3o`0000?oR0000_l0001Zooooo`03o`000?n8ikOoR>Ng00;oR>Ng0_l00005oioefP;o
00002on/mnd00ol0003o/O7fok7amP02o`0000[o/O7f0_l00006ok;Yn0;o00002?nnj?<2o`00017o
^^7c00Co0000ol3Nk_l0003o00005?nlf>h2o`00017o^]3[00?o0000ok[@jonjd>/00_njd>/2o`00
01Co^<[X00?o0000okS7iOnhanD00onhanD2o`0000ko]LGV0_l0000Vooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01Sooooo0_l00004ohP000;o0000I_ooool2
o`0000CoR>Ng00?o0000oioef_nOmMX01?nOmMX00ol0003o[?O]ojcgk@09ojcgk@Go00002_nalOH2
o`0000[o/^Wh0_l00004okkXl`;o00004onjhO<3o`0001?o_=S^0_l00002okSCkP03o`000?njd>_o
^]3[00ko^]3[00?o0000ok[@jonjd>/00_l000000ongcN_o0000okS:j00DokS:j003o`000?nhanGo
000000;o00004?neaNH3o`0002Gooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0_l0000Jooooo`Co00000on80002
o`0006?ooooo00?o0000ohSW]on8ikL00_n8ikL2o`0000GoWoGJ0_l0000:ojcgk@Co00002_nalOH3
o`0000ko/^Wh00Co0000okkXlol0003o00004onjhO<2o`0000?o]m[b00?o0000okcHk_nlf>h03_nl
f>h2o`0000Go^=?^00?o0000ok[@jonjd>/03_njd>/2o`0000Co]lg[00?o0000okS:j?nhb^P04_nh
b^P2o`0001Co]LGV0_l0000Uooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01[ooooo00?o
0000oaAfhol000001?l000000on8003o0000o`00001Oooooo`;o00000on8ikL2o`0000CoWoGJ2?l0
0005ojcgk@?o00002onalOH2o`00017o/^Wh0ol0000Bok[Ql`;o00001_ngf_800ol0003o_=S^okcH
kP0;okcHkP;o00002?nhdnh00ol0003o^]3[ok[@j`0;ok[@j`;o000000?o]lg[o`000?ngcN/01?ng
cN/00ol0003o^<[XokS:j00?okS:j0;o000000?o]<SXo`000?neaNH05?neaNH2o`0002Cooooo0006
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Kooooo`04o`000?lDM^?o0000o`0000;o
R@001Ol0001Looooo`03o`000?n8ikOoR>Ng00;oR>Ng00?o0000oioef_l000001Ol00007oh[/k0So
00002OnalOH2o`00017o/^Wh0_l00003ok7Qm`03o`000?njhO?o^^7c00go^^7c0_l00009okOJlP03
o`000?nlf>ko_=S^00So_=S^0_l0000;okSCkP03o`000?njd>_o^]3[00So^]3[0_l00004okO=j`03
o`000?ngcN_o]lg[00?o]lg[00?o0000okS:j?nhb^P02onhb^P3o`0000Co]<SX00?o0000okG5i_ne
aNH04_neaNH2o`0002Cooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool01?l0003o
57KSoaAfhol00005ohT000?o0000FOooool01?l0003oR>NgohSW]on8ikL4o`000003ofkNcOl0003o
000000WoR^c/1?l00005oi[/n0Go00000_nalOH2o`00013o/^Wh0ol00006ok7Qm`;o00002onjhO<2
o`0000co]m[b00?o0000okcHk_nlf>h01Onlf>h2o`0000ko^=?^00?o0000ok[@jonjd>/01Onjd>/2
o`0000Ko]lg[00?o0000okO=jongcN/01?ngcN/00ol0003o^<[XokS:j008okS:j0;o00002?ndb>P0
0ol0003o]LGVokG5iP0AokG5iP?o00008oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`06ooooo`;o00007ooo
ool00ol0003o57KSoaAfh`02o`0000KoR@000_l0001Eooooo`;o000000CoR>Ngo`000?l0003o0000
0_m^g/d3o`0000SoR^c/1Ol0000<oi[/n0?o00003onbjOP2o`0000_o/N7g00?o0000ok[QlonjhO<0
1_njhO<2o`0000oo]m[b00?o0000okcHk_nlf>h00_nlf>h2o`00017o^=?^00?o0000ok[@jonjd>/0
0_njd>/2o`0000Wo]lg[00?o0000okO=jongcN/00ongcN/00ol0003o^<[XokS:j006okS:j0;o0000
2ondb>P00ol0003o]LGVokG5iP0=okG5iP?o000000Co//?Wo`000?oooooo00008_ooool000Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
00Gooooo00?o0000ooooooooool07oooool01?l0003o57KSoaAfholDM^<2o`0000KoR@000ol0001A
ooooo`03o`000?n8ikOo000000;o00000_m^g/d2o`0000SoR^c/1Ol0000<oi[/n0?o00000onSi_`2
o`0000_o/^Wh0_l0000>ok7Qm`;o00001?njhO<2o`0001;o]m[b00Co0000okcHk_l0003o00005?nh
dnh01?l0003o^]3[o`000?l0000<okO=j`03o`000?ngcN_o]lg[00?o]lg[00?o0000okS:j?nhb^P0
0_nhb^P3o`0000ko]<SX00?o0000okG5i_neaNH02OneaNH3o`0000Go//?W0_l0000Rooooo`00:?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?lDM^?o57KS00;o57KS00?o0000ohT00?n900001On9
0003o`0004gooooo1?l00003ofkNc@;o00001on:k>`3o`000003oh[/k?l0003o000000coV^ch0_l0
0008oj?Vo0?o00001OnbjOP3o`0001;o/N7g00Co0000ok[Qlol0003o00005?ngf_83o`0001Go^=?^
0_l0000?okO=j`03o`000?ngcN_o]lg[00?o]lg[00Co0000okS:j?l0003o00004Ondb>P00ol0003o
]LGVokG5iP07okG5iP;o00002Onb`nL2o`0000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00?ooooo000Xooooo`03o`000?oooooooooo
027ooooo00?o0000oaAfholDM^<00_lDM^<2o`0000OoR@000ol0001:ooooo`?o00000_m^g/d3o`00
00KoR^c/0ol000001?n:k>co0000o`000?l0000;oi[/n0?o00003OnSi_`2o`000003ok;Yn?l0003o
000001Go/N7g0ol0000CokOJlP;o00000onde?400ol0003o^=?^okSCkP0@okSCkP;o000000?o]<o]
o`000?ngcN/03_ngcN/00ol0003o]lg[okO=j`03okO=j`;o00005?ndb>P00ol0003o]LGVokG5iP03
okG5iP?o00003?nb`nL2o`0000Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OlQ8B7oV9RHoooooonHV9So8B4Q00?ooooo000Xooooo`;o00008oooool3o`0000?o57KS00?o
0000ohT00?n900001_n90004o`0004Gooooo0ol000000om^g/go0000o`00000:o`0000;oR^c/0_l0
000<oi[/n0;o00004OnSi_`3o`0001Co/N7g0_l00003ok3JmP03o`000?ngf_;o]m[b00go]m[b0ol0
0006okCDl@03o`000?nhdnko^=?^00co^=?^0ol00004okC?k@03o`000?ngcN_o]lg[00go]lg[00?o
0000okO=jongcN/00_l000000oncb^_o0000okC8j00DokC8j003o`000?neaNKo000000;o00004?nb
`nL00ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000000?ooooo000Xooooo`03o`000?oooooooooo02?ooooo00?o0000od:Bl?l00000
2_l00003ohT000Ko0000?oooool6o`0000KoHmSV2_l0000:oi[/n0;o00004OnSi_`2o`0000?oY]ok
00?o0000ok7QmonahOL03_nahOL3o`0000Ko/=[f00?o0000okOJl_ngf_802_ngf_82o`0000[o]=Ca
00?o0000okSCk_nhdnh02Onhdnh2o`0000So]<o]00?o0000okO=jongcN/03?ngcN/3o`0000Co/l[[
00?o0000okC8j?ndb>P04_ndb>P2o`0001?o//?W0_l00007ooooo`05o`000?ooooooooooooooool0
00002oooool01Olb<S;oV9RHoooooonHV9So<S8b00?ooooo000Wooooo`03o`000?oooooooooo02Go
oooo00?o0000od:Bl?m2T_000om2T_03o`0000?oNP003?l0000jooooo`Go00001omSf>H2o`000003
of?Hi_l0003o000000;o00001On0hOT5o`0000;oV^ch0ol0000@oj?Vo0?o00001_nVgo/2o`0000co
/N7g0_l0000:ok3JmP;o00002?ngf_82o`0000go]=Ca00?o0000okSCk_nhdnh01_nhdnh2o`0000_o
]<o]00?o0000okO=jongcN/02OngcN/2o`000003ok?:jol0003o/l[[00Go/l[[00?o0000okC8j?nd
b>P03ondb>P2o`000003ok76jOl0003o//?W01?o//?W0_l00006ooooo`05o`000?oooooooooooooo
ool000002oooool01Oo<c<co0000o`000?l0003oc<c<00?ooooo000Wooooo`03o`000?oooooooooo
02Kooooo00?o0000od:Bl?m2T_001Om2T_02o`0000WoNP002?l0000cooooo`Go00001omSf>H6o`00
00goP>7i1?l0000@oj?Vo0;o00002onVgo/00ol0003o/N7gok7Qm`07ok7Qm`;o00003_n`f_H00ol0
003o]m[bokOJlP02okOJlP?o00004?nde?400ol0003o^=?^okSCkP02okSCkP?o00003_ndcnd00ol0
003o]lg[okO=j`06okO=j`;o00001?ncb^/00ol0003o/l[[ok?:j`04ok?:j`03o`000?ndb>So]<SX
00_o]<SX0ol00004ok76j@03o`000?nb`nOo//?W01;o//?W00?o0000ooooooooool01?ooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4003ooooo`009oooool2
o`0002Sooooo00?o0000od:Bl?m2T_001_m2T_03o`0000[oNP002_l0000Yooooo`Ko00001omSf>H4
o`0000ooP>7i0ol00004oi7OoP?o00002onSi_`2o`0000koY]ok0_l00004ok7Qm`?o00004On`f_H0
1?l0003o]m[bo`000?l0000DokCDl@04o`000?nhdnko0000o`0001;o]<o]00?o0000okO=jongcN/0
0_ngcN/3o`0000Oo/l[[00?o0000ok?:joncb^/01?ncb^/00ol0003o]<SXokC8j008okC8j0;o0000
2?naa^T00ol0003o//?Wok;3i`0Aok;3i`?o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_oooooo^[Zjo`000003ooooo`009oooool00ol0003oooooooooo`0Xooooo`03
o`000?m2T_3o@Y;`00So@Y;`0_l0000;ogX000Co00000olo0007o`0001gooooo4ol0000?oh3Qn@?o
00002_nAgoh2o`0000KoXnKl0ol0000BojKOn`04o`000?nahOOo0000o`0001Co/=[f0ol0000EokCD
l@;o00005Ondcnd01?l0003o]lg[o`000?l0000;ok?:j`03o`000?ncb^_o/l[[00?o/l[[00?o0000
okC8j?ndb>P01_ndb>P2o`0000[o/LKY00?o0000ok;3ionb`nL03_nb`nL3o`000003ojo2j?l0003o
000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
0oooool002Oooooo00?o0000ooooooooool0:Oooool00ol0003o@Y;`od:Bl008od:Bl0?o00002omj
000Ho`0000[ooooo3Ol00002oc^ngPOo00001?mUdOP3o`0000WoP>7i0ol0000?oi7OoP?o000000?o
XnKlo`000?l000005?nVgo/4o`0001;o/=[f0ol00003ojoEm003o`000?nde?7o]=Ca013o]=Ca0_l0
00000onad?3o0000okC?k@0DokC?k@;o00003Oncb^/00ol0003o/l[[ok?:j`04ok?:j`03o`000?nd
b>So]<SX00;o]<SX0ol0000=ok76j@03o`000?nb`nOo//?W00[o//?W0ol00005ojo2j003o`000?oo
oooooooo01[ooooo000Wooooo`;o0000:oooool00ol0003o@Y;`od:Bl009od:Bl0?o00000omj0006
o`0000SoGP002?l00008obD001Wo000000CoIM7ho`000?l0003o00002_mUdOP3o`0000?oP>7i0ol0
000Coi7OoPCo00004_nVgo/3o`0000CoZ=Wi00?o0000ok3Jm_n`f_H03?n`f_H3o`0000Oo[mGd00?o
0000okCDlOnde?403?nde?43o`0000Co/M3`00?o0000okC?kOndcnd04?ndcnd2o`000003ok;<kOl0
003o/l[[00go/l[[00?o0000ok?:joncb^/01?ncb^/01?l0003o]<SXo`000?l0000Aok76j@03o`00
0?nb`nOo//?W00Ko//?W0ol00009ojo2j003o`000?oooooooooo01Wooooo000Vooooo`03o`000?oo
oooooooo02cooooo00?o0000od:Bl?m2T_002Om2T_05o`0001KoGP002ol00005oc@000co00000omU
dOP3o`0000ooIM7h1Ol0000Aoi7OoPCo00001?nJfod2o`0000goY]ok0ol00008ojSIn@;o00002_n`
f_H2o`0000_o[mGd00?o0000okCDlOnde?402Onde?42o`0000So/M3`00?o0000okC?kOndcnd03?nd
cnd3o`0000Co//c]00?o0000ok?:joncb^/03?ncb^/00ol0003o/l[[ok?:j`03ok?:j`;o00004ona
a^T00ol0003o//?Wok;3i`03ok;3i`?o00003?n_`^P00ol0003oooooooooo`0Iooooo`009_ooool0
0ol0003oooooooooo`0]ooooo`03o`000?m2T_3o@Y;`00[o@Y;`00?o0000ocVHl_liV?801?l0000@
oeh000?o00003Old000;o`0000?oC/3f1?l0000<ofGAn0Go00001OmneOl3o`0000[oTMon1?l0000:
oi[Ko@?o00001onVgo/3o`0000goZ=Wi0_l00005ok3JmP?o00003_n_eO@00ol0003o]=CaokCDl@06
okCDl@;o00002onad?000ol0003o]<o]okC?k@09okC?k@;o00002?nbc>d00ol0003o/l[[ok?:j`0<
ok?:j`03o`000?ncb^_o000000;o000000?o/LS[o`000?naa^T04onaa^T00ol0003o//?Wo`000002
o`00013o[l;X00?o0000ooooooooool06?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0;_oo
ool8o`0000Go@Y;`00?o0000ocVHl_liV?800oliV?83o`0000[oGP000ol0000>oc@000[o00000om>
`?H3o`0000CoC/3f0ol00004ofGAn0Go00003OmneOl3o`0000?oTMon1?l0000Aoi[Ko@;o00000_nV
go/3o`0001;oZ=Wi00?o0000ok3Jm_l000000_l0000BojoEm003o`000?nde?7o]=Ca00;o]=Ca0ol0
000>ok7@l003o`000?ndcngo]<o]00Ko]<o]0_l0000;ok;<k@03o`000?ncb^_o/l[[00[o/l[[0ol0
0005ok78j`03o`000?naa^Wo/LKY017o/LKY0_l0000Cojo2j0;o00006Oooool000_ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo033ooooo00?o0000of6Rm?mQX_@00omQX_@Bo`0000?oGP000ol0000?oc@000Wo00000om>
`?H3o`0000?oC/3f2ol0000DogkEo`Co00005OnJfod4o`0001GoZ=Wi0ol0000EojoEm004o`000?nd
e?7o0000o`0001;o/M3`00?o0000okC?kOndcnd00_ndcnd3o`0000ko//c]00?o0000ok?:joncb^/0
1oncb^/2o`0000;o/LS[00?o0000ok78jonab>/01?nab>/00ol0003o/LKYok76j@0=ok76j@?o0000
00?o[lCYo`000?n_`^P04on_`^P2o`0001Sooooo000;ooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol0003oooooooooo`03ooooo`;o0000<_ooool00ol0003oHJ;dof6Rm00:of6Rm003o`00
0?mMZOSoGJWh00?oGJWh3ol00008oc@001Co00002_m^bOl2o`0000ooO]Go1?l00004ohgDo`;o0000
4?nJfod3o`0000CoWmKk00?o0000ojSInOnXfOT03onXfOT3o`0000?oZMCf00?o0000ojoEm?n_eO@0
4_n_eO@2o`0001Go/M3`00Co0000okC?kOl0003o00004_nbc>d00ol0003o/l[[ok?:j`03ok?:j`?o
00001Onab>/00ol0003o/LS[ok78j`04ok78j`03o`000?naa^Wo/LKY00Wo/LKY0ol00005ojo4j@03
o`000?n_`^So[l;X01;o[l;X00?o0000ooooooooool05_ooool000_ooooo00Go0000oooooooooooo
ooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0<oooool00ol0003o
HJ;dof6Rm00:of6Rm003o`000?mMZOSoGJWh00[oGJWh00?o0000oefbnomM/_/00omM/_/>o`0000?o
Hkgm0ol00003of>mo@;o00004?m^bOl3o`0000SoO]Go1?l0000:ohgDo`;o00002onJfod3o`0000So
WmKk00?o0000ojSInOnXfOT02onXfOT3o`0000OoZMCf00?o0000ojoEm?n_eO@03_n_eO@3o`0000;o
[]7b00?o0000ok7@l?nad?004_nad?02o`0001Go//c]00?o0000ok?:jol000000_l00008ok78j`03
o`000?nab>_o/LS[00Co/LS[00?o0000ok76jOnaa^T01onaa^T2o`0000Wo[lCY00?o0000ojo2j?n_
`^P04On_`^P2o`0001Oooooo000;ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0=?ooool00ol0003oHJ;dof6Rm00:of6R
m003o`000?mMZOSoGJWh00[oGJWh0_l0000;oefbn`;o00001OmS_Od2o`0000SoHkgm0_l0000Aofk9
o`;o00000_mneOl4o`00013oSMCo00?o0000oi[KoOnJfod01OnJfod3o`0000coWmKk0_l00009ojSI
n@;o00002onYe?H00ol0003o[mGdojoEm00:ojoEm0?o00001_n^dO800ol0003o/M3`ok7@l00>ok7@
l0?o00000_n`cNl00ol0003o//c]ok;<k@0Bok;<k@;o00003?nab>/00ol0003o/LS[ok78j`04ok78
j`03o`000?naa^Wo/LKY00?o/LKY0ol0000<ojo4j@03o`000?n_`^So[l;X00oo[l;X0ol0000Goooo
o`002oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0eooooo`03o`000?mQX_CoHJ;d00[oHJ;d0_l0000<oefYn003o`000?mM/__oGK;k
00[oGK;k00?o0000of>moOl000000_l0000<of>mo@;o00003Om^bOl6o`0001GoSMCo0_l00002oi[K
o@?o00004OnOe_/00ol0003oZ=WiojSIn@03ojSIn@?o00003_nYe?H00ol0003o[mGdojoEm007ojoE
m0;o00002_n^dO800ol0003o/M3`ok7@l00:ok7@l0?o00001_n`cNl00ol0003o//c]ok;<k@0>ok;<
k@?o000000?o/<W]o`000?nab>/03?nab>/00ol0003o/LS[ok78j`04ok78j`03o`000?naa^Wo0000
00;o00004?n_a>T00ol0003o[l;Xojo2j00;ojo2j0?o00000_n]`NP2o`0001Kooooo0005ooooo`03
o`000?oooooooooo00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00Kooooo0_l0000gooooo`03o`000?mQX_CoHJ;d00_oHJ;d00?o0000oefYn?mMZOP02_mMZOP00ol0
003oGK;koefbn`08oefbn`Co00004?mS_Od2o`0000CoK/Wo1ol00006oh;;o`;o00004on=e?l4o`00
01GoWmKk00?o0000ojSInOl000000_l0000BojWDmP03o`000?n_eOCo[mGd00?o[mGd0ol0000=ojkA
lP03o`000?nad?3o/M3`00Oo/M3`0_l0000:ok3=k`03o`000?nbc>go//c]00[o//c]0ol00005ok39
k@03o`000?nab>_o/LS[00_o/LS[00?o0000ok78jonab>/00onab>/2o`0001?o[lCY00?o0000ojo2
j?n_`^P02?n_`^P3o`0000Ko[L7X0_l0000Eooooo`001Oooool00ol@413ogMgMooooo`03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0=oooool00ol0
003oHJ;dof6Rm00;of6Rm003o`000?mMZOSoGJWh00[oGJWh0_l00005oefbn`?o00001?mM/_/2o`00
00coHkgm2?l0000?oh;;o`;o00003On=e?l4o`0000CoU]7l00?o0000oioFnonOe_/04_nOe_/3o`00
01GoZMCf00?o0000ojoEm?l000000_l0000AojkAlP03o`000?nad?3o/M3`00?o/M3`0ol0000=ok3=
k`03o`000?nbc>go//c]00Oo//c]0_l00009ok39k@03o`000?nab>_o/LS[00[o/LS[00?o0000ok78
jonab>/00ol000000on_a^_o0000ojo4j@0Cojo4j@03o`000?n_`^So[l;X00Co[l;X0ol0000:ojg1
j0;o00005?ooool000?ooooo00Goc<c<oa0@4?l0003o0000ohN7Q`0Mooooo`03o`000?oooooooooo
03Sooooo00?o0000of6Rm?mQX_@02omQX_@00ol0003oGJWhoefYn00;oefYn003o`000?mM/__o0000
00;o00002OmM/_/00ol0003oHkgmof>mo@02of>mo@Oo00001_mj`_h2o`00017oP/_o0_l00008ohgD
o`?o00002OnFdO`2o`0000ooWmKk0ol00003oj;An003o`000?nYe?KoZMCf01;oZMCf0ol0000DojkA
lP03o`000?nad?3o000000;o00004On`cNl00ol0003o//c]ok;<k@03ok;<k@?o00003?n`bNd00ol0
003o/LS[ok78j`0:ok78j`;o00001On_a^/00ol0003o[lCYojo4j@0Bojo4j@03o`000?n_`^So[l;X
00?o00003On]`NP2o`0001Cooooo0003ooooo`06ob4Q8On7QhOo<S8bojVYZOm4A4CoQhN76oooool0
0ol0003oooooooooo`0jooooobko00003omj`_h00ol0003oP/_ooh;;o`0@oh;;o`;o00000_n=e?l4
o`0000koU]7l00?o0000oioFnonOe_/02OnOe_/3o`0000OoX]7h0_l0000?ojWDmP?o00000onYd?@0
0ol0003o[]7bojkAlP0AojkAlP?o00005?n`cNl00ol0003o//c]o`000002o`00013o/<W]00?o0000
ok78jonab>/01_nab>/3o`000003ojo6jol0003o[lK[00Go[lK[00?o0000ojo4jOn_a>T04On_a>T3
o`00017o[L7X0_l0000Cooooo`000oooool01_l0003oooooofIVI_n7QhOogMgMoa0@41_ooooo0ol0
000looooo`03o`000?mfZoCoMZ_d00_oMZ_d00?o0000ogBbn?md/_P01?md/_P3o`0000CoM;;h00?o
0000ogFjnome^_/02ome^_/2o`00013oN/;n0_l0000@oh;;o`Co00004onFdO`2o`0000KoWmKk0ol0
000<oj;An003o`000?nYe?KoZMCf00WoZMCf0ol00007ojW@m003o`000?n^dO;o[]7b00go[]7b0ol0
0003ojg=l@03o`000?n`cNoo/<g_017o/<g_0_l0000Dok39k@03o`000?nab>_o/LS[00?o/LS[0_l0
0004ojo6j`03o`000?n_a^_o[lK[00Go[lK[00?o0000ojo4jOn_a>T03On_a>T3o`000003ojg3j_l0
003o[L7X01;o[L7X00?o0000ooooooooool04Oooool000?ooooo00Ko410@omgMgOmgMgOoMgMgoooo
ool0000Kooooo`03o`000?oooooooooo03gooooo00?o0000ogJ[m?mfZo@02omfZo@00ol0003oM;;h
ogBbn003o`0000SoM;;h0_l0000=ogFjn`03o`000?mj`_koN/;n00ooN/;n0_l00009oh;;o`Go0000
1?n>bo`00ol0003oU]7loiKAo00BoiKAo003o`000?nOe__oWmKk00?o00004?nRdOP2o`0000KoZMCf
0ol0000;ojW@m0;o00002_n^dO83o`0000Oo[Lga00?o0000ok3=kon`cNl03On`cNl3o`000003ojk:
kol0003o/<W]01Co/<W]00?o0000ok78jol000000_l00007ojo6j`03o`000?n_a^_o[lK[00Go[lK[
00?o0000ojo4jOn_a>T02On_a>T3o`0000Go[L?Z00?o0000ojg1j?n]`NP04?n]`NP2o`0001;ooooo
0003ooooo`06ojVYZOm4A4CoV9RHodA4A?nHV9So410@6oooool00ol0003oooooooooo`0nooooo`03
o`000?mfZoCoMZ_d00[oMZ_d0ol0000=ogBbn003o`000?me^__oMK[k00_oMK[k0_l0000Aog[2oP04
o`000?n2boooP/_ooh;;o`Go00002_n>bo`2o`00017oU]7l1?l0000Eoj;An003o`000?nYe?KoZMCf
00?o00004?nYd?@00ol0003o[]7bojkAlP04ojkAlP?o00002on]cO400ol0003o/<g_ok3=k`0:ok3=
k`;o00001On^b^l00ol0003o/<W]ok39k@0Bok39k@;o00002on_a^/00ol0003o[lK[ojo6j`04ojo6
j`03o`000?n_a>Wo[lCY00Oo[lCY0_l00009ojg3jP03o`000?n]`NSo[L7X013o[L7X0_l0000Aoooo
o`001?ooool01OnHV9So0000o`000?l@413oc<c<01_ooooo00?o0000ooooooooool0?oooool00ol0
003oMZ_dogJ[m006ogJ[m0?o00000_mfZo@2o`0000goM;;h00?o0000ogFjnome^_/03?me^_/2o`00
00coN/;n1ol0000Aohk;o003o`000?nFdOcoU]7l00[oU]7l1?l00004oic>n@03o`000?nRdOSoX]7h
017oX]7h1?l0000DojW@m003o`000?n^dO;o[]7b00?o00003on]cO400ol0003o/<g_ok3=k`06ok3=
k`?o00002?n^b^l00ol0003o/<W]ok39k@0>ok39k@?o000000?o[/O]o`000?n_a^/02on_a^/00ol0
003o[lK[ojo6j`04ojo6j`03o`000?n_a>Wo[lCY00?o[lCY0ol0000;ojg3jP03o`000?n]`NSo[L7X
00oo[L7X0ol0000Aooooo`001Oooool00onj^[[o<S8booooo`0Looooo`;o0000@Oooool00ol0003o
MZ_dogJ[m002ogJ[m0?o00001omfZo@00ol0003oM;;hogBbn00;ogBbn0;o00003_me^_/00ol0003o
N/;nog[2oP02og[2oPOo00001_n8a?/00ol0003oS/_lohk;o00@ohk;o0;o00001onFdO`3o`0000Wo
W<ki00?o0000oj;An?nRdOP03OnRdOP3o`0000CoY<kf00?o0000ojW@m?nYd?@04OnYd?@3o`0001?o
[Lga00?o0000ok3=kon`cNl00on`cNl2o`0000co[/[_00?o0000ok39kOn`bNd02_n`bNd3o`0000Go
[/O]00?o0000ojo6jon_a^/02On_a^/00ol0003o[lK[ojo6j`05ojo6j`03o`000?n_a>Wo000000;o
00003on]`nX00ol0003o[L7Xojg1j00;ojg1j0?o00000_n[`>T2o`0000[ooooo1?l00001oa0@407o
oooo0006ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@_ooool4o`0000_oMZ_d
00?o0000ogBbn?md/_P03?md/_P00ol0003oMK[kogFjn`05ogFjn`_o00003_n8a?/2o`0001;oS/_l
00?o0000oiKAo?nFdO`01?l0000=oic>n@;o00002_nRdOP3o`0000SoY<kf00?o0000ojW@m?nYd?@0
3OnYd?@3o`0000;oZLgb00?o0000ojg=lOn]cO404_n]cO400ol0003o/<g_o`000002o`0000oo[/[_
00?o0000ok39kOn`bNd01on`bNd2o`0000Wo[/O]00?o0000ojo6jon_a^/02On_a^/00ol0003o[lK[
ojo6j`03ojo6j`?o00004on]`nX00ol0003o[L7Xojg1j007ojg1j0?o00001_n[`>T00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo007ooooo000Sooooo`03o`000?oooooooooo047ooooo0ol0
000>ogJ[m003o`000?md/_SoM;;h00GoM;;h3_l00009ohFmn@03o`000?n8a?_oR<Ck00ooR<Ck00?o
0000ohk;o?n>bo`03_n>bo`4o`0001?oW<ki00?o0000oj;An?nRdOP01?nRdOP3o`0000coY<kf00?o
0000ojW@m?nYd?@02_nYd?@2o`0000KoZLgb00?o0000ojg=lOn]cO404?n]cO43o`0001?o[/[_00?o
0000ok39kOn`bNd00on`bNd3o`0000co[/O]00?o0000ojo6jon_a^/02On_a^/00ol0003o[lK[o`00
0002o`0000;o[LG[00?o0000ojg3j_n]`nX04On]`nX00ol0003o[L7Xojg1j004ojg1j0?o00002_n[
`>T00ol0003oooooooooo`09ooooo`03o`000?oooooooooo007ooooo000Sooooo`03o`000?oooooo
oooo03kooooo0ol00003ooooo`03o`000?mfZoCoMZ_d00GoMZ_d3_l00009oh>gmP03o`000?n5_OWo
QKgi00coQKgi0_l0000@ohS4n`;o00002On>bo`5o`0000CoU/Wi00?o0000oic>nOnLc_T04OnLc_T0
0ol0003oX]7hoj;An003o`00013oY<kf00?o0000ojW@m?nYd?@01_nYd?@3o`0000WoZLgb00?o0000
ojg=lOn]cO403?n]cO43o`0000?o[<_`00?o0000ojk:kon^b^l04On^b^l00ol0003o/<W]o`000002
o`0000oo[/O]00?o0000ojo6jon_a^/02?n_a^/3o`0000Ko[LG[00?o0000ojg3j_n]`nX04On]`nX0
0ol0003o[L7Xojg1j003o`0000goZl3Y0_l0000:ooooo`03o`000?oooooooooo007ooooo000Soooo
o`?o0000>oooool3o`0000Oooooo1ol00009ohBalP03o`000?n3]oKoPkOf00coPkOf00?o0000ohFm
nOn5_OT03On5_OT00ol0003oR<CkohS4n`0?ohS4n`04o`000?n>bocoS/_lohk;o0Go00002_nFbOT0
0ol0003oW<kioic>n@0?oic>n@Co00005?nTc_H00ol0003oZM3dojW@m003ojW@m0;o00003OnYcO80
0ol0003o[Lgaojg=l@08ojg=l@?o00001on/bo000ol0003o[/[_ojk:k`0@ojk:k`;o00004on^and0
0ol0003o[lK[ojo6j`04ojo6j`?o00000_n]aN/00ol0003o[LG[ojg5j`05ojg5j`03o`000?n]`n[o
[L?Z00oo[L?Z1?l0000Aoj_0j@03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool0
02?ooooo00?o0000ooooooooool0>?ooool3o`0000_ooooo00?o0000ohBal_n4/O803On4/O800ol0
003oPkOfoh>gmP0<oh>gmP03o`000?n5_OWoQKgi00goQKgi0_l0000<ohS4n`Oo00004?nFbOT2o`00
00_oW<ki1?l00004oj3;mP03o`000?nTc_KoY<kf01;oY<kf00?o0000ojW@m?l000000_l0000@ojW=
lP03o`000?n]cO7o[Lga00Co[Lga0ol0000;ojc;l003o`000?n^b^oo[/[_00co[/[_0ol00002ojc8
kP03o`000?n^ango[/O]017o[/O]00?o0000ojo6jon_a^/00ol00006ojg5j`03o`000?n]aN_o[LG[
00Go[LG[00?o0000ojg3j_n]`nX02on]`nX3o`0000;oZl;[00?o0000oj_0jOn[`>T04On[`>T00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo007ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo03Gooooo0ol0000?ooooo`03o`000?n4/O;oQ;7b00goQ;7b00?o0000
oh>gm_n3]oH03?n3]oH00ol0003oQKgiohFmn@0>ohFmn@03o`000?n8a?_oR<Ck00;oR<Ck1ol00006
oi;4n003o`000?nFbOWoU/Wi013oU/Wi00?o0000oic>nOnLc_T01OnLc_T3o`0000WoX<_f00?o0000
ojC>m_nTc_H04?nTc_H4o`0001?oZLgb00?o0000ojg=lOn]cO400ol0000?ojc;l003o`000?n^b^oo
[/[_00So[/[_0ol00006ojc8kP03o`000?n^ango[/O]013o[/O]0ol0000:ojg5j`03o`000?n]aN_o
[LG[00Co[LG[00?o0000ojg3j_n]`nX02?n]`nX3o`0000KoZl;[00?o0000oj_0jOn[`>T04?n[`>T2
o`0000Sooooo00?o0000ooooooooool00Oooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo03?ooooo0ol0000Cooooo`03o`000?n4/O;oQ;7b00goQ;7b00?o0000oh>gm_n3]oH03?n3]oH0
0ol0003oQKgiohFmn@0<ohFmn@Ko00003_nBa?P2o`00017oU/Wi00?o0000oic>nOnLc_T01?l0000=
oj3;mP;o00003?nTc_H4o`0000CoY/_c00?o0000ojW=l_nYcO804?nYcO83o`0001?o[<_`00?o0000
ojk:kon^b^l01?n^b^l3o`0000[o[<S^00?o0000ojk7kOn^and03?n^and3o`000003ojc6kOl0003o
[LG[00[o[LG[00?o0000ojg5jon]aN/01On]aN/00ol0003o[L?Zojg3jP04ojg3jP?o00002_n[`^/0
0ol0003oZl3Yoj_0j@0@oj_0j@03o`000?oooooooooo00Cooooo00?oEEEEofIVI_l000000oooool0
0005oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooo
oooo00;ooooo0ol0000`ooooo`?o00005oooool00ol0003oQ;7bohBalP0=ohBalP03o`000?n3]oKo
PkOf00coPkOf00?o0000ohFmnOn5_OT01_n5_OT5o`0000CoSkof00?o0000oi;4n?nBa?P03onBa?P0
0ol0003oU/WioiK9n@0=oiK9n@Co00004onPboH00ol0003oY<kfojC>mP05ojC>mPCo00002OnVbo<0
0ol0003oZLgbojW=lP0<ojW=lP?o00000onYb_400ol0003o[<_`ojc;l00Aojc;l003o`000?n^b^oo
[/[_00?o00003_n/b>h00ol0003o[/O]ojk7k@08ojk7k@?o00001On/a^d00ol0003o[LG[ojg5j`09
ojg5j`03o`000?n]aN_o[LG[00Go[LG[00?o0000ojg3j_n]`nX00ol0000=oj_2j`03o`000?n[`>Wo
Zl3Y00ooZl3Y0ol0000;ooooo`0000Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooo
oooo00Kooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0]ooooo`?o00006oooool0
0ol0003oQ;7bohBalP0=ohBalP03o`000?n3]oKoPkOf00coPkOf00?o0000ohFmnOn5_OT01Ol0000:
ohnomP03o`000?nBa?SoT/Ch00ooT/Ch0_l00008oiK9n@Go00001?nLb?H00ol0003oX<_foj3;mP0A
oj3;mP03o`000?nTc_KoY<kf00Co00003_nVbo<00ol0003oZLgbojW=lP08ojW=lP?o00001onYb_40
0ol0003o[<_`ojc;l00@ojc;l0?o00004_n/b>h00ol0003o[/O]ojk7k@04ojk7k@?o00002On/a^d0
0ol0003o[LG[ojg5j`09ojg5j`03o`000?n]aN_o[LG[00Co[LG[0ol0000Aoj_2j`03o`000?n[`>Wo
Zl3Y00_oZl3Y0ol000000ooooooo0000ooooo`0;ooooo`0000Go0000ooooooooooooooooo`00000>
ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oo
oooooooo02[ooooo0ol0000Oooooo`03o`000?n4/O;oQ;7b00goQ;7b00?o0000oh>gm_n3]oH01On3
]oH9o`00013oSkof0_l0000Aoi;4n003o`000?nFbOWoU/Wi00Go00002_nLb?H2o`00013oX<_f1?l0
000CojK;l`03o`000?nYcO;oZLgb00CoZLgb0ol0000;ojW:l@03o`000?n/bo3o[<_`00co[<_`0ol0
00000on[bNoo0000ojc8kP0Cojc8kP03o`000?n^ango[/O]00?o00003On/a^d00ol0003o[LG[ojg5
j`09ojg5j`03o`000?n]aN_o[LG[00?o000000?oZlC/o`000?n[`^/04_n[`^/00ol0003oZl3Yoj_0
j@07oj_0j@?o00001?ooool00ol0003oooooooooo`0:ooooo`0000Go410@oooooooooooooooooa0@
400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Wooooo`?o00008oooool00ol0003oQ;7bohBalP0:ohBalP[o00002On>^_@00ol0003oSkofohno
mP0?ohnomP03o`000?nBa?SoT/Ch00goT/Ch1?l0000Aoic8mP03o`000?nPboKoX<_f00[oX<_f0ol0
0004oj;9m003o`000?nVbo?oY/_c017oY/_c00?o0000ojW=l_nYcO800ol0000?ojW:l@03o`000?n/
bo3o[<_`00So[<_`0ol00005oj_9k`03o`000?n/b>ko[<S^017o[<S^0ol0000Aojc6k@03o`000?n]
aN_o[LG[00So[LG[0ol00005oj_4k003o`000?n[`^_oZl;[013oZl;[00?o0000oj_0jOn[`>T01?n[
`>T3o`0000Sooooo00?o0000ooooooooool02Oooool00005ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01_ooool2o`0002Gooooo
0ol0000Wooooo`03o`000?n4/O;oQ;7b00;oQ;7b1ol00005ohjel@03o`000?n>^_CoS[[d00coS[[d
00?o0000ohnom_n?_oH03on?_oH00ol0003oT/Choi;4n007oi;4n0Go00001?nHa?D00ol0003oW<Sf
oic8mP0?oic8mP;o00001_nPboH4o`0000SoX/Wd00?o0000ojK;lonVbo<04?nVbo<3o`0001?oZL[a
00?o0000ojc;l?n/bo001?n/bo03o`0000WoZlW_00?o0000ojc8k_n/b>h03On/b>h3o`000003oj_7
k_l0003o[<K]01;o[<K]00?o0000ojg5jon]aN/01?n]aN/3o`000003oj_4k?l0003oZlC/00KoZlC/
00?o0000oj_2jon[`^/04?n[`^/00ol0003oZl3Yoj_0j@03o`0000_ooooo00?o0000ooooooooool0
2Oooool00005onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00004ooooo`;o0000
8oooool3o`0002_ooooo1?l0000=ohjel@03o`000?n>^_CoS[[d00coS[[d0_l0000@ohnomP04o`00
0?nBa?SoT/Choi;4n0Go00002_nHa?D00ol0003oW<Sfoic8mP0@oic8mP03o`000?nPboKoX<_f00?o
00003OnRbO@00ol0003oY/_cojK;l`0<ojK;l`?o00000onWbO800ol0003oZL[aojW:l@0AojW:l@03
o`000?n/bo3o[<_`00?o00003On[bNl00ol0003o[<S^ojc8kP0:ojc8kP;o00001On[anh00ol0003o
[<K]ojc6k@0Aojc6k@03o`000?n]aN_o[LG[00?o00001On[a>`00ol0003oZlC/oj_4k005oj_4k003
o`000?n[`^_oZl;[00koZl;[1?l0000>ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`00
0?oooooooooo01oooooo0ol0000`ooooo`03o`000?n>]O7oS[Ga00goS[Ga00?o0000ohjjm?n>^_@0
3On>^_@00ol0003oSkofohnomP0<ohnomPGo00004?nHa?D00ol0003oW<Sfoic8mP0>oic8mPCo0000
4OnRbO@00ol0003oY/_cojK;l`08ojK;l`?o00001onWbO800ol0003oZL[aojW:l@0@ojW:l@?o0000
4On[bNl00ol0003o[<S^ojc8kP06ojc8kP?o00002?n[anh00ol0003o[<K]ojc6k@0@ojc6k@?o0000
2On[a>`00ol0003oZlC/oj_4k004oj_4k003o`000?n[`^_oZl;[00[oZl;[1?l0000Booooo`03o`00
0?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo01gooooo0_l0000dooooo`03o`000?n>
]O7oS[Ga00goS[Ga00?o0000ohjjm?n>^_@03On>^_@00ol0003oSkofohnomP06ohnomPGo00001?nF
_o@00ol0003oV<CeoiS4m@0?oiS4m@03o`000?nLb?KoW<Sf00WoW<Sf1?l00004oio6m003o`000?nR
bOCoX/Wd00ooX/Wd00?o0000ojK;lonVbo<01?nVbo<3o`0000_oYlWb00?o0000ojW:lOnYb_403?nY
b_43o`0000;oZLS`00?o0000oj_9kon[bNl04?n[bNl00ol0003o[<S^ojc8kP03ojc8kP;o00003?n[
anh00ol0003o[<K]ojc6k@0<ojc6k@?o000000?oZ/G]o`000?n[a>`02On[a>`00ol0003oZlC/oj_4
k005oj_4k003o`000?n[`^_oZl;[00GoZl;[1?l0000Fooooo`03o`000?oooooooooo00Wooooo000Q
ooooo`;o00006oooool3o`0003Oooooo00?o0000ohjelOn>]O403On>]O400ol0003oS[[dohjjm00=
ohjjm003o`000?n?_oKoSkof00Go00002_nF_o@00ol0003oV<CeoiS4m@0?oiS4m@03o`000?nLb?Ko
W<Sf00GoW<Sf0ol00009oio6m003o`000?nRbOCoX/Wd00ooX/Wd00?o0000ojK;lonVbo<00ol0000?
ojO9lP03o`000?nYb_7oZL[a00SoZL[a0ol00006ojW8l003o`000?n[bNooZlW_013oZlW_00?o0000
ojc8k_l000000_l0000?oj_7kP03o`000?n/a^go[<K]00So[<K]0ol00005oj[5k@03o`000?n[a>co
ZlC/00SoZlC/00?o0000oj_4k?n[a>`01On[a>`00ol0003oZl;[oj_2j`04o`0001[ooooo00?o0000
ooooooooool02Oooool0027ooooo00?o0000ooooooooool05oooool3o`0003_ooooo00?o0000ohje
lOn>]O403On>]O400ol0003oS[[dohjjm00:ohjjm0Go00004?nF_o@2o`00013oV<Ce00?o0000oic8
m_nLb?H01?l0000=oio6m003o`000?nRbOCoX/Wd00goX/Wd1?l0000CojO9lP03o`000?nYb_7oZL[a
00CoZL[a0ol0000:ojW8l003o`000?n[bNooZlW_00koZlW_0ol0000Coj_7kP03o`000?n/a^go[<K]
00Co[<K]0ol00009oj[5k@03o`000?n[a>coZlC/00SoZlC/00?o0000oj_4k?n[a>`01?n[a>`3o`00
01kooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool05?ooool3o`0003oo
oooo00?o0000ohjelOn>]O403On>]O400ol0003oS[[dohjjm002ohjjm0Oo00001OnE^o800ol0003o
U[odoiJom00?oiJom003o`000?nHa?GoV<Ce00coV<Ce1?l0000Boio6m003o`000?nRbOCoX/Wd00Wo
X/Wd0ol00004ojC7lP03o`000?nWbO;oYlWb017oYlWb00?o0000ojW:lOnYb_400ol0000>ojW8l003
o`000?n[bNooZlW_00WoZlW_1?l00003oj[7k`03o`000?n[ankoZlO^017oZlO^00?o0000ojc6kOn/
a^d00ol0000=oj[5k@03o`000?n[a>coZlC/00OoZlC/00Co0000oj_4k?n[a>coZlC/0ol0000Roooo
o`03o`000?oooooooooo00Sooooo000Pooooo`03o`000?oooooooooo01;ooooo0ol00013ooooo`03
o`000?n>]O7oS[Ga00[oS[Ga1ol0000=oiFklP03o`000?nF_oCoU[od00ooU[od00?o0000oiS4mOnH
a?D01_nHa?D5o`0000CoWL?c00?o0000oio6m?nOa_@04?nOa_@00ol0003oX/Wdoj;9m004oj;9m0Co
00002?nTao800ol0003oYlWbojO9lP0@ojO9lP?o00004_nYb?000ol0003oZlW_oj_9k`05oj_9k`?o
00002?nZanl00ol0003oZlO^oj_7kP0@oj_7kP?o00004?nZaNd00ol0003oZlC/oj_4k008oj_4k0?o
00009Oooool00ol0003oooooooooo`08ooooo`008?ooool00ol0003oooooooooo`0?ooooo`?o0000
Aoooool00ol0003oS[Gaohjel@02ohjel@Oo00001OnE]nl00ol0003oUK_boiFklP0=oiFklP;o0000
4?nF_o@00ol0003oV<CeoiS4m@05o`0000[oWL?c00?o0000oio6m?nOa_@04?nOa_@00ol0003oX/Wd
oj;9m003o`0000goY<Ob00?o0000ojO9l_nWbO803?nWbO83o`0000;oYlS`00?o0000ojW8l?nYb?00
4OnYb?000ol0003oZlW_oj_9k`04o`0000coZ/O_00?o0000oj_7k_n[anh03?n[anh3o`000003oj[6
k_l0003oZ/G]017oZ/G]00?o0000oj_4k?n[a>`01?n[a>`3o`000003ooooool0003ooooo02Gooooo
00?o0000ooooooooool02?ooool0023ooooo0ol0000<ooooo`?o0000Boooool4o`0000goUKO_00?o
0000oiFkl_nE^o803_nE^o800ol0003oU[odoiJom00<oiJom0Co00004?nM`o<00ol0003oWlKdoio6
m00>oio6m0Co00004OnTao800ol0003oYlWbojO9lP08ojO9lP?o00001_nWb?000ol0003oZLS`ojW8
l00@ojW8l0?o00004OnZanl00ol0003oZlO^oj_7kP08oj_7kP?o00001OnZa^h00ol0003oZ/G]oj[5
k@0@oj[5k@03o`000?n[a>coZlC/00?o00001Oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo00Sooooo000Pooooo`03o`000?oooooooooo00Wooooo0ol0001?ooooo`03o`000?nE]noo
UKO_00koUKO_00?o0000oiFkl_nE^o803_nE^o800ol0003oU[odoiJom006oiJom0Go00001?nL`?40
0ol0003oWL?coig3l`0>oig3l`03o`000?nOa_CoWlKd00WoWlKd1?l00004oj;5lP03o`000?nTao;o
Y<Ob00ooY<Ob00?o0000ojO9l_nWbO801?nWbO83o`0000[oYlS`00?o0000ojW8l?nYb?003?nYb?03
o`0000;oZLO_00?o0000oj[7konZanl04?nZanl00ol0003oZlO^oj_7kP04oj_7kP?o00002OnZa^h0
0ol0003oZ/G]oj[5k@0>oj[5k@Co00002?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00Sooooo000Pooooo`03o`000?oooooooooo00Kooooo0ol0001Cooooo`03o`000?nE]nooUKO_
00koUKO_00?o0000oiFkl_nE^o803_nE^o800ol0003oU[odoiJom005o`0000[oW<3a00?o0000oig3
lonM`o<03_nM`o<00ol0003oWlKdoio6m005oio6m0?o00002OnRaO800ol0003oY<ObojC7lP0?ojC7
lP03o`000?nWbO;oYlWb00?o00003_nWb?000ol0003oZLS`ojW8l008ojW8l0?o00001_nYanl00ol0
003oZ/O_oj[7k`0@oj[7k`03o`000?n[ankoZlO^00?o00003OnZa^h00ol0003oZ/G]oj[5k@09oj[5
k@Co00003Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo000Pooooo`03
o`000?oooooooooo00?ooooo0ol0001Gooooo`03o`000?nE]nooUKO_00koUKO_00?o0000oiFkl_nE
^o803?nE^o84o`00013oW<3a00?o0000oig3lonM`o<03_nM`o<00ol0003oWlKdoio6m004o`0000go
X/Gb00?o0000ojC7l_nTao803OnTao84o`0001;oYlS`00?o0000ojW8l?nYb?001?nYb?03o`0000[o
ZLO_00?o0000oj[7konZanl03_nZanl4o`00017oZ/K^00?o0000oj[5kOnZaNd01OnZaNd3o`0001;o
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`08ooooo`007oooool7o`0005_ooooo
00?o0000oiFgkonE]nl03_nE]nl00ol0003oUK_boiFklP06oiFklPGo00000onK_?000ol0003oW<3a
oic0l@0?oic0l@03o`000?nM`o?oWL?c00coWL?c1?l0000Boj;5lP03o`000?nTao;oY<Ob00WoY<Ob
0ol00004ojK6l003o`000?nWb?3oYlS`013oYlS`00?o0000ojW8l?nYb?000ol0000>ojW7k`03o`00
0?nZanooZ/O_00WoZ/O_1?l00002ojW7k`03o`000?nZa^koZ/K^017oZ/K^00?o0000oj[5kOnZaNd0
1?l0000Eooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool001oooooo1?l0
001Oooooo`03o`000?nE]nooUKO_00koUKO_00?o0000oiFkl_nE^o801Ol00009oi^ll003o`000?nL
`?7oW<3a00ooW<3a00?o0000oig3lonM`o<01_nM`o<5o`0000CoXL?a00?o0000oj;5l_nRaO804?nR
aO800ol0003oY<ObojC7lP04ojC7lPCo00002?nVa_000ol0003oYlS`ojO8l00>ojO8l0Co00004_nY
anl00ol0003oZ/O_oj[7k`05oj[7k`?o00001onYanl00ol0003oZ/K^oj[6kP0@oj[6kP?o00006_oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo000Eooooo`Co000000?o410@
ooooooooool00oooool2o`0006;ooooo00?o0000oiFgkonE]nl03?nE]nl4o`0000ooVkc`00?o0000
oic0lOnL`?403onL`?400ol0003oWL?coig3l`05o`0000[oXL?a00?o0000oj;5l_nRaO804?nRaO80
0ol0003oY<ObojC7lP03o`0000goY/K`0_l0000;ojO8l0?o00000onXao000ol0003oZLO_ojW7k`0A
ojW7k`03o`000?nZanooZ/O_00Co00002onYanl00ol0003oZ/K^oj[6kP0<oj[6kP?o00007_ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Oooooo000Gooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0H?ooool00ol0003oUKO_oiFgk`06oiFgk`Go00001?nJ^Nh00ol0
003oVkc`oi^ll00=oi^ll003o`000?nL`?7oW<3a00goW<3a1?l0000@oj73l@03o`000?nRaO;oX/Gb
00koX/Gb1?l0000BojK6l003o`000?nWb?3oYlS`00CoYlS`1?l00007ojS7l003o`000?nYanooZLO_
013oZLO_0ol0000@ojW7k`03o`000?nZa^koZ/K^00SoZ/K^0ol0000Rooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool01oooool001Oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1Pooooo`03o`000?nE]nooUKO_00Go00002_nJ^Nh00ol0003oVkc`oi^ll00=oi^ll003
o`000?nL`?7oW<3a00WoW<3a0ol00004oio0l003o`000?nQ`o7oXL?a00koXL?a00?o0000oj;5l_nR
aO802OnRaO84o`0000?oY<G`00?o0000ojK6l?nVa_004OnVa_000ol0003oYlS`ojO8l003o`0000co
Z<O`00?o0000ojW7konYanl03?nYanl3o`0000;oZLO_00?o0000ojW7konYanl03onYanl00ol0003o
Z/K^oj[6kP04oj[6kP?o00009Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Oo
oooo000Gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0H?ooool2o`00013oV[W^
00?o0000oi^ll?nK_?003OnK_?000ol0003oW<3aoic0l@04oic0l@Co00002?nO`?000ol0003oXL?a
oj73l@0>oj73l@03o`000?nRaO;oX/Gb00GoX/Gb0ol00008ojC5l003o`000?nVa_3oY/K`013oY/K`
0ol0000@ojS7l003o`000?nYanooZLO_00SoZLO_0ol00006ojW7k`03o`000?nYanooZLO_00ooZLO_
00?o0000oj[6k_nZa^h00ol0000Yooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
1oooool001Oooooo00?o0000ooooooooool02_ooool2o`0006;ooooo00?o0000oiZik_nJ^Nh03_nJ
^Nh00ol0003oVkc`oi^ll00=oi^ll003o`000?nL`?7oW<3a00?o00003OnO`?000ol0003oXL?aoj73
l@0>oj73l@03o`000?nRaO;oX/Gb00Co00003?nTaO000ol0003oY/K`ojK6l00<ojK6l0?o00000_nW
a^l00ol0003oZ<O`ojS7l00?ojS7l003o`000?nYanooZLO_00CoZLO_0ol0000:ojW7k`03o`000?nY
anooZLO_00goZLO_1?l0000]ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01ooo
ool001Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Pooooo`03o`000?nJ^Nko
V[W^00koV[W^00?o0000oi^ll?nK_?002onK_?04o`00017oWl3`00?o0000oj73lOnQ`o403?nQ`o44
o`00017oY<G`00?o0000ojK6l?nVa_002?nVa_03o`0000KoYlK_00?o0000ojS7l?nXao003onXao00
0ol0003oZLO_ojW7k`03o`0000koZLO_00?o0000ojW7konYanl02OnYanl3o`0003;ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`06ooooo`005oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo063ooooo00?o0000oiZik_nJ^Nh03_nJ^Nh00ol0003oVkc`oi^ll005oi^l
l0Go00001?nO_Nh00ol0003oWl3`oio0l00?oio0l003o`000?nQ`o7oXL?a00KoXL?a1Ol00004oj?2
k`03o`000?nTaO3oY<G`00ooY<G`00?o0000ojK6l?nVa_001?nVa_03o`0000[oYlK_00?o0000ojS7
l?nXao003OnXao04o`0001;oZLO_00?o0000ojW7konYanl01?nYanl4o`0003Gooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`06ooooo`005Oooool00omEEEGoIVIVo`00000@ooooo`03
o`000?oooooooooo063ooooo00?o0000oiZik_nJ^Nh03_nJ^Nh00ol0003oVkc`oi^ll004o`0000[o
Wkg^00?o0000oio0l?nO`?003onO`?000ol0003oXL?aoj73l@05o`0000[oXl;_00?o0000ojC5l?nT
aO003onTaO000ol0003oY/K`ojK6l003o`0000koYlK_00?o0000ojS7l?nXao002OnXao03o`0000Co
Z<O_00?o0000ojW7konYanl04?nYanl00ol0003oZLO_ojW7k`03o`0003[ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`06ooooo`00:Oooool00ol0003oooooooooo`1Pooooo`03o`00
0?nJ^NkoV[W^00coV[W^1?l0000?oinmkP03o`000?nO`?3oWl3`00goWl3`1?l0000@oj?2k`03o`00
0?nTaO3oY<G`00goY<G`1?l0000BojO6k`03o`000?nXao3oZ<O`00CoZ<O`1?l00008ojS7k`03o`00
0?nYanooZLO_00koZLO_1?l0000nooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
1_ooool002[ooooo0_l0001Qooooo`03o`000?nJ^NkoV[W^00KoV[W^1Ol00004oinjk003o`000?nO
_NkoWkg^00goWkg^00?o0000oio0l?nO`?002OnO`?03o`0000CoXl3^00?o0000oj?2konS`^l03_nS
`^l00ol0003oY<G`ojC5l009ojC5l0?o00001?nVa>l00ol0003oYlK_ojO6k`0@ojO6k`03o`000?nX
ao3oZ<O`00?o00003OnXanl00ol0003oZLO_ojW7k`09ojW7k`Co0000@_ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00Kooooo000/ooooo`03o`000?oooooooooo05oooooo00?o0000
oiZik_nJ^Nh01Ol0000:oinjk003o`000?nO_NkoWkg^00goWkg^00?o0000oio0l?nO`?001?nO`?04
o`0000SoXl3^00?o0000oj?2konS`^l03_nS`^l00ol0003oY<G`ojC5l004ojC5l0Co00002?nVa>l0
0ol0003oYlK_ojO6k`0>ojO6k`Co00004OnXanl00ol0003oZLO_ojW7k`05ojW7k`?o0000Aoooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Kooooo000]ooooo`03o`000?oooooooooo
05oooooo0_l0000@oinjk003o`000?nO_NkoWkg^00goWkg^00?o0000oio0l?nO`?000ol0000=oj?0
kP03o`000?nS`^ooXl;_00koXl;_00?o0000ojC5l?nTaO000ol0000=ojK4k`;o00002onWa^l3o`00
00?oZ<K_00?o0000ojS7konXanl04?nXanl00ol0003oZLO_ojW7k`04o`0004_ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`06ooooo`00;_ooool00ol0003oooooooooo`1Pooooo`03
o`000?nO^^coWk[/00koWk[/00?o0000oinmk_nO_Nh02onO_Nh4o`00017oXl3^00?o0000oj?2konS
`^l03?nS`^l4o`0001;oY/C_00?o0000ojO6konWa^l01?nWa^l4o`0000OoZ<K_00?o0000ojS7konX
anl03onXanl3o`00053ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`06ooooo`00
;oooool2o`00067ooooo00?o0000oinjk?nO^^`03_nO^^`00ol0003oWkg^oinmkP05oinmkPGo0000
1?nR_^d00ol0003oXl3^oj?0kP0?oj?0kP03o`000?nS`^ooXl;_00KoXl;_1Ol00004ojG2kP03o`00
0?nVa>ooY/C_013oY/C_00?o0000ojO6konWa^l00ol0000<ojS6k`03o`000?nXanooZ<O_00_oZ<O_
0ol0001Cooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01Oooool0037ooooo00?o
0000ooooooooool0Goooool00ol0003oWk[/oinjk00>oinjk003o`000?nO_NkoWkg^00Co00002_nR
_^d00ol0003oXl3^oj?0kP0?oj?0kP03o`000?nS`^ooXl;_00Go00002_nU`^h00ol0003oY/C_ojK4
k`0>ojK4k`Co00004?nXa^l00ol0003oZ<O_ojS7k`07ojS7k`?o0000Eoooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00Gooooo000booooo`03o`000?oooooooooo05oooooo00?o0000
oinjk?nO^^`03?nO^^`4o`0000ooX[k]0_l0000>oj?0kPCo00004?nU`^h2o`0000_oY/C_0ol00003
ojO4kP03o`000?nXa^ooZ<K_00ooZ<K_00?o0000ojS7konXanl00onXanl3o`0005_ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`05ooooo`00<oooool00ol0003oooooooooo`1Ooooo
o`03o`000?nO^^coWk[/00SoWk[/0ol00003oj:kj`03o`000?nR_^goX[k]00ooX[k]00?o0000oj?0
k_nS`>h02?nS`>h3o`0000CoYL3]00?o0000ojG2k_nU`^h03onU`^h00ol0003oY/C_ojK4k`04ojK4
k`Co00001onWa>h00ol0003oZ<K_ojS6k`0?ojS6k`03o`000?nXanoo000000;o0000Goooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00Gooooo000dooooo`;o0000H?ooool00ol0003o
Wk[/oinjk004oinjk0?o00001onR^n/00ol0003oX[k]oj:nk@0?oj:nk@03o`000?nS`>koXl3^00Co
Xl3^0ol00008ojG0k@03o`000?nU`^koYL;^00ooYL;^00?o0000ojK4konVa>l00ol0000<ojO4kP03
o`000?nXa^ooZ<K_00goZ<K_0ol0001Rooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool01Oooool003Kooooo00?o0000ooooooooool0G_ooool00ol0003oWk[/oinjk003o`0000_oX[_[
00?o0000oj:nkOnR_^d03onR_^d00ol0003oXl3^oj?0kP03o`0000coYL3]00?o0000ojG2k_nU`^h0
3OnU`^h4o`00013oYlC^00?o0000ojS6konXa^l02OnXa^l3o`0006Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`05ooooo`00=oooool00ol0003oooooooooo`1Nooooo`;o00003onR
^n/00ol0003oX[k]oj:nk@0=oj:nk@Co00004?nU`>d00ol0003oYL;^ojG2kP09ojG2kP?o00000onW
`nd00ol0003oYlC^ojO4kP0?ojO4kP03o`000?nXa^ooZ<K_00CoZ<K_1?l0001Zooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool01Oooool003Sooooo00?o0000ooooooooool0Goooool0
0ol0003oX[_[oj:kj`0=oj:kj`03o`000?nR_^goX[k]00WoX[k]0ol00003ojFnk003o`000?nU`>go
YL3]00ooYL3]00?o0000ojG2k_nU`^h01?nU`^h4o`0000OoYl?]00?o0000ojO4k_nWa>h03onWa>h0
0ol0003oZ<K_ojS6k`03o`0006kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04
ooooo`00>Oooool2o`00063ooooo00?o0000oj:kjonR^n/03OnR^n/00ol0003oX[k]oj:nk@04oj:n
k@Co00001onU_^`00ol0003oYL3]ojG0k@0?ojG0k@03o`000?nU`^koYL;^00?o00003?nW`nd00ol0
003oYlC^ojO4kP0=ojO4kPCo0000L_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00Cooooo000kooooo`03o`000?oooooooooo05kooooo00?o0000oj:kjonR^n/03OnR^n/00ol0003o
X[k]oj:nk@03o`0000coYKk/00?o0000ojG0kOnU`>d03OnU`>d4o`00013oYl?]00?o0000ojO4k_nW
a>h02OnWa>h3o`0007Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`04ooooo`00
??ooool00ol0003oooooooooo`1Nooooo`03o`000?nR^n_oX[_[00_oX[_[1?l0000@ojFnk003o`00
0?nU`>goYL3]00WoYL3]0ol00003ojO1k003o`000?nW`ngoYl?]00ooYl?]00?o0000ojO4k_nWa>h0
1?nWa>h4o`0007_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`04ooooo`00?Ooo
ool00ol0003oooooooooo`1Nooooo`03o`000?nR^n_oX[_[00GoX[_[1Ol00004ojFljP03o`000?nU
_^coYKk/00koYKk/00?o0000ojG0kOnU`>d01?nU`>d4o`0000OoYl7/00?o0000ojO3kOnW`nd03onW
`nd00ol0003oYlC^ojO4kP03o`0007oooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`04ooooo`00?_ooool00ol0003oooooooooo`1Nooooo`03o`000?nR^n_oX[_[00Co00002_nU_>X0
0ol0003oYKk/ojFnk00>ojFnk003o`000?nU`>goYL3]00?o00003?nW`N`00ol0003oYl?]ojO3k@0=
ojO3k@Co0000Poooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo000ooooo
o`;o0000Goooool2o`0000ooYKcZ00?o0000ojFnk?nU_^`03?nU_^`4o`00013oYl7/00?o0000ojO3
kOnW`nd02OnW`nd3o`0008Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04oooo
o`00@Oooool00ol0003oooooooooo`1Mooooo`03o`000?nU_>[oYKcZ00koYKcZ00?o0000ojFnk?nU
_^`02?nU_^`3o`0000CoYko[00?o0000ojO1k?nW`N`03_nW`N`00ol0003oYl?]ojO3k@04ojO3k@Co
0000Roooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo0012ooooo`03o`00
0?oooooooooo05gooooo00?o0000ojFlj_nU_>X03_nU_>X00ol0003oYKk/ojFnk004ojFnk0?o0000
2?nW_n/00ol0003oYl7/ojO1k00>ojO1k003o`000?nW`ngoYl?]00?o0000T?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00?ooooo0013ooooo`03o`000?oooooooooo05gooooo00?o
0000ojFlj_nU_>X03_nU_>X00ol0003oYKk/ojFnk003o`0000coYko[00?o0000ojO1k?nW`N`03?nW
`N`4o`0009Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`00A?ooool2
o`0005kooooo00?o0000ojFlj_nU_>X03?nU_>X4o`00013oYko[00?o0000ojO1k?nW`N`02?nW`N`3
o`0009Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`00A_ooool00ol0
003oooooooooo`1Looooo`03o`000?nU_>[oYKcZ00SoYKcZ0ol00004ojNmj@03o`000?nW_n_oYko[
00koYko[00?o0000ojO1k?nW`N`01?nW`N`3o`0009cooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`03ooooo`00Aoooool00ol0003oooooooooo`1Looooo`03o`000?nU_>[oYKcZ00Co
YKcZ0ol00008ojNmj@03o`000?nW_n_oYko[00koYko[00?o0000ojO1k?nW`N`00ol0002Pooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool004Sooooo00?o0000ooooooooool0
G?ooool00ol0003oYKcZojFljP03o`0000coYkgY00?o0000ojNojonW_n/03?nW_n/4o`000:Cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`00BOooool2o`0005gooooo0_l0
000@ojNmj@03o`000?nW_n_oYko[00SoYko[0ol0002Yooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool00oooool004_ooooo00?o0000ooooooooool0G?ooool00ol0003oYkgYojNmj@0>
ojNmj@03o`000?nW_n_oYko[00CoYko[0ol0002/ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool00_ooool004cooooo00?o0000ooooooooool0G?ooool00ol0003oYkgYojNmj@0>ojNm
j@03o`000?nW_n_oYko[00?o0000/?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00;ooooo001=ooooo`03o`000?oooooooooo05cooooo00?o0000ojNmjOnW_NT03?nW_NT4o`000;Co
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`00C_ooool2o`0005gooooo
00?o0000ojNmjOnW_NT02?nW_NT3o`000;Sooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`02ooooo`00D?ooool00ol0003oooooooooo`1Kooooo`03o`000?nW_NWoYkgY00CoYkgY0ol0
002looooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool0057ooooo00?o0000
ooooooooool0Foooool00ol0003oYkgYojNmj@03o`000<3ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`02ooooo`00D_ooool00ol0003oooooooooo`1Kooooo`;o0000a?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo001Cooooo`03o`000?oooooooooo05[o
oooo00?o0000ooooooooool0`oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo007o
oooo001Dooooo`;o0000F_ooool00ol0003oooooooooo`34ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00Oooool005Kooooo00?o0000ooooooooool0Eoooool00ol0003ooooooooo
o`35ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00Oooool005Oooooo00?o0000
ooooooooool0E_ooool00ol0003oooooooooo`36ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00Oooool005Sooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`36oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00Oooool005Wooooo0_l0001Eooooo`03
o`000?oooooooooo0<Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`01ooooo`00
Foooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo0<Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`01ooooo`00G?ooool00ol0003oooooooooo`1Aooooo`03o`000?oo
oooooooo0<Sooooo00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool005gooooo00?o0000
ooooooooool0D?ooool00ol0003oooooooooo`39ooooo`03o`000?oooooooooo00?ooooo0Ol00001
ooooo`7ooooo001Nooooo`;o0000D?ooool00ol0003oooooooooo`3:ooooo`03o`000?oooooooooo
00;ooooo0Ol00001ooooo`7ooooo001Pooooo`03o`000?oooooooooo04gooooo00?o0000oooooooo
ool0boooool01Ol0003ooooooooooooooooo000000;ooooo001Qooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool0c?ooool01Ol0003ooooooooooooooooo000000;ooooo001Rooooo`03
o`000?oooooooooo04[ooooo00?o0000ooooooooool0cOooool01?l0003oooooooooool00002oooo
o`00Hoooool2o`0004[ooooo00?o0000ooooooooool0c_ooool00ol0003oooooo`000002ooooo`00
IOooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo0<kooooo00Co0000oooooooooooo
00000Oooool006Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`3?ooooo`03o`00
0?oooooo0000007ooooo001Wooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0d?oo
ool2o`00007ooooo001Xooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0coooool3
o`00007ooooo001Yooooo`;o0000A?ooool00ol0003oooooooooo`3;ooooo`Co00001?ooool006_o
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`37ooooo`Co00002?ooool006cooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`34ooooo`?o00003?ooool006gooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`30ooooo`Co00003oooool006kooooo0_l0000o
ooooo`03o`000?oooooooooo0;cooooo1?l0000Cooooo`00L?ooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo0;Sooooo1?l0000Gooooo`00LOooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0;Cooooo1?l0000Kooooo`00L_ooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo0;7ooooo0ol0000Oooooo`00Loooool2o`0003[ooooo00?o0000ooooooooool0[Ooo
ool4o`0002;ooooo001eooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0ZOooool4
o`0002Kooooo001fooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0YOooool4o`00
02[ooooo001gooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0XOooool4o`0002ko
oooo001hooooo`;o0000=Oooool00ol0003oooooooooo`2Mooooo`Co0000<_ooool007[ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`2Jooooo`?o0000=_ooool007_ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`2Fooooo`Co0000>Oooool007cooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`2Booooo`Co0000?Oooool007gooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`2>ooooo`Co0000@Oooool007kooooo0_l0000_ooooo`03o`00
0?oooooooooo08[ooooo1?l00015ooooo`00P?ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo08Oooooo1?l00019ooooo`00POooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo08Cooooo0ol0001=ooooo`00P_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
083ooooo1?l0001@ooooo`00Poooool2o`0002Wooooo00?o0000ooooooooool0O?ooool4o`0005Co
oooo0025ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0N?ooool4o`0005Sooooo
0026ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0M?ooool4o`0005cooooo0027
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0LOooool3o`00063ooooo0028oooo
o`;o00009?ooool00ol0003oooooooooo`1]ooooo`Co0000Hoooool008[ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`1Yooooo`Co0000Ioooool008_ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`1Uooooo`Co0000Joooool008cooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`1Qooooo`Co0000Koooool008gooooo0_l0000Oooooo`03o`000?oooooo
oooo05gooooo1?l0001cooooo`00Soooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
05[ooooo0ol0001gooooo`00T?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Ko
oooo1?l0001jooooo`00TOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05;ooooo
1?l0001nooooo`00T_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04kooooo1?l0
0022ooooo`00Toooool2o`0001Wooooo00?o0000ooooooooool0B_ooool4o`0008Kooooo002Eoooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool3o`0008[ooooo002Fooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0@oooool4o`0008gooooo002Gooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0?oooool4o`00097ooooo002Hooooo`;o00005?oo
ool00ol0003oooooooooo`0kooooo`Co0000UOooool009[ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0gooooo`Co0000VOooool009_ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0cooooo`Co0000WOooool009cooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0`ooooo`?o0000XOooool009gooooo0_l0000?ooooo`03o`000?oooooooooo02cooooo
1?l0002Tooooo`00Woooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo1?l0
002Xooooo`00X?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo1?l0002/
ooooo`00XOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo1?l0002`oooo
o`00X_ooool2o`0000Wooooo00?o0000ooooooooool07Oooool4o`000;Cooooo002Tooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool06_ooool3o`000;Sooooo002Uooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool05_ooool4o`000;_ooooo002Vooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool04_ooool4o`000;oooooo002Wooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool03_ooool4o`000<?ooooo002Xooooo`;o00000oooool00ol0003o
ooooooooo`0:ooooo`Co0000aoooool00:[ooooo00Co0000oooooooooooo00002Oooool3o`000<_o
oooo002[ooooo`03o`000?oooooo000000Gooooo1?l0003>ooooo`00[?ooool2o`000003ooooool0
003o000000;o0000d_ooool00:gooooo0_l0003Fooooo`00oooooon6ooooo`00oooooon6ooooo`00
oooooon6ooooo`00oooooon6ooooo`00oooooon6ooooo`00\
\>"],
  ImageRangeCache->{{{0, 388.875}, {315, 0}} -> {0, 0, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "This solution appears to match the analytic solution given by Eq. ",
  ButtonBox["(6.1.13)",
    ButtonData:>"(6.1.13)",
    ButtonStyle->"Hyperlink"],
  ". The error ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Phi] = \[Phi] - \[Phi]\_exact\)]],
  " is, in fact, quite small, as shown in Cell ",
  ButtonBox["6.14",
    ButtonData:>"Cell 6.14",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Phi]exact[x_, y_]\  = \ Sin[Pi\ x]\ Sinh[Pi \((1 - y)\)]/Sinh[Pi]; 
    Plot3D[\[Phi][x, y] - \[Phi]exact[x, y], {x, 0, 1}, {y, 0, 1}, 
      AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\[CapitalDelta]\[Phi]\>"}, 
      PlotPoints \[Rule] 50];\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.14"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
4.2768e-17 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.29165 .07573 -9.31117 -12 ]
[.29165 .07573 .68883 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.91861 .21225 0 -8.04169 ]
[.91861 .21225 10 3.95831 ]
[.01723 .30827 -42 -2.7788 ]
[.01723 .30827 0 6.2212 ]
[.00908 .35932 -6 -2.82208 ]
[.00908 .35932 0 6.17792 ]
[.00067 .41207 -36 -2.86695 ]
[.00067 .41207 0 6.13305 ]
[-0.00803 .4666 -36 -2.91349 ]
[-0.00803 .4666 0 6.08651 ]
[-0.05457 .39542 -16 -3.77786 ]
[-0.05457 .39542 0 8.22214 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
gsave
.91861 .21225 -61 -12.0417 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02948 .30358 m
.03561 .30124 L
s
[(-0.0002)] .01723 .30827 1 -0.38249 Mshowa
.02138 .35474 m
.02752 .35245 L
s
[(0)] .00908 .35932 1 -0.37287 Mshowa
.013 .40759 m
.01917 .40536 L
s
[(0.0002)] .00067 .41207 1 -0.3629 Mshowa
.00434 .46224 m
.01053 .46006 L
s
[(0.0004)] -0.00803 .4666 1 -0.35256 Mshowa
.125 Mabswid
.03539 .26629 m
.03906 .26486 L
s
.03344 .27862 m
.03711 .2772 L
s
.03147 .29105 m
.03514 .28964 L
s
.02748 .31622 m
.03116 .31482 L
s
.02546 .32895 m
.02915 .32756 L
s
.02343 .34179 m
.02711 .34041 L
s
.01931 .36779 m
.023 .36642 L
s
.01722 .38095 m
.02092 .37959 L
s
.01512 .39422 m
.01882 .39286 L
s
.01086 .42108 m
.01457 .41975 L
s
.00871 .43469 m
.01241 .43336 L
s
.00653 .4484 m
.01024 .44709 L
s
.00213 .47619 m
.00585 .47489 L
s
gsave
-0.05457 .39542 -77 -7.77786 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Df) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.517 .706 .956 r
.39572 .68414 .40211 .68976 .41282 .68672 .40636 .68394 Metetra
.466 .802 .999 r
.40636 .68394 .41282 .68672 .42358 .68366 .41709 .68282 Metetra
.369 .819 .94 r
.41709 .68282 .42358 .68366 .43437 .6806 .42789 .68103 Metetra
.268 .775 .827 r
.42789 .68103 .43437 .6806 .44521 .67752 .43875 .6788 Metetra
.187 .716 .722 r
.43875 .6788 .44521 .67752 .4561 .67442 .44967 .67628 Metetra
.44967 .67628 .4561 .67442 .46702 .67132 .46064 .67364 Metetra
.46064 .67364 .46702 .67132 .478 .6682 .47166 .67096 Metetra
.001 0 0 r
.47166 .67096 .478 .6682 .48901 .66507 .48273 .66833 Metetra
.072 0 0 r
.48273 .66833 .48901 .66507 .50007 .66193 .49384 .66581 Metetra
.148 0 0 r
.49384 .66581 .50007 .66193 .51118 .65877 .505 .66341 Metetra
.222 0 0 r
.505 .66341 .51118 .65877 .52233 .6556 .51621 .66117 Metetra
.289 0 0 r
.51621 .66117 .52233 .6556 .53352 .65242 .52747 .65907 Metetra
.345 0 .014 r
.52747 .65907 .53352 .65242 .54476 .64923 .53879 .65709 Metetra
.389 0 .093 r
.53879 .65709 .54476 .64923 .55605 .64602 .55016 .65521 Metetra
.421 .014 .158 r
.55016 .65521 .55605 .64602 .56738 .6428 .56159 .65339 Metetra
.445 .058 .21 r
.56159 .65339 .56738 .6428 .57876 .63957 .57308 .65159 Metetra
.463 .093 .251 r
.57308 .65159 .57876 .63957 .59019 .63632 .58462 .64977 Metetra
.475 .12 .283 r
.58462 .64977 .59019 .63632 .60166 .63306 .59622 .64788 Metetra
.483 .14 .308 r
.59622 .64788 .60166 .63306 .61318 .62979 .60787 .64587 Metetra
.488 .155 .327 r
.60787 .64587 .61318 .62979 .62475 .6265 .61958 .64372 Metetra
.491 .165 .341 r
.61958 .64372 .62475 .6265 .63637 .6232 .63134 .64137 Metetra
.492 .172 .352 r
.63134 .64137 .63637 .6232 .64803 .61988 .64315 .6388 Metetra
.492 .176 .359 r
.64315 .6388 .64803 .61988 .65975 .61655 .655 .63599 Metetra
.49 .177 .363 r
.655 .63599 .65975 .61655 .67151 .61321 .6669 .63291 Metetra
.487 .176 .364 r
.6669 .63291 .67151 .61321 .68332 .60985 .67884 .62955 Metetra
.482 .172 .363 r
.67884 .62955 .68332 .60985 .69518 .60648 .69081 .62593 Metetra
.476 .165 .359 r
.69081 .62593 .69518 .60648 .7071 .6031 .70283 .62203 Metetra
.469 .156 .352 r
.70283 .62203 .7071 .6031 .71906 .5997 .71487 .61788 Metetra
.46 .143 .341 r
.71487 .61788 .71906 .5997 .73107 .59629 .72695 .61351 Metetra
.449 .127 .327 r
.72695 .61351 .73107 .59629 .74313 .59286 .73906 .60894 Metetra
.436 .107 .308 r
.73906 .60894 .74313 .59286 .75525 .58942 .75121 .6042 Metetra
.42 .082 .284 r
.75121 .6042 .75525 .58942 .76741 .58596 .7634 .59935 Metetra
.4 .05 .253 r
.7634 .59935 .76741 .58596 .77963 .58249 .77562 .59442 Metetra
.375 .011 .213 r
.77562 .59442 .77963 .58249 .7919 .579 .78788 .58945 Metetra
.345 0 .163 r
.78788 .58945 .7919 .579 .80422 .5755 .80019 .5845 Metetra
.307 0 .101 r
.80019 .5845 .80422 .5755 .81659 .57198 .81254 .57961 Metetra
.261 0 .025 r
.81254 .57961 .81659 .57198 .82902 .56845 .82495 .5748 Metetra
.207 0 0 r
.82495 .5748 .82902 .56845 .8415 .56491 .83742 .57012 Metetra
.145 0 0 r
.83742 .57012 .8415 .56491 .85403 .56134 .84994 .56558 Metetra
.079 0 0 r
.84994 .56558 .85403 .56134 .86662 .55777 .86254 .56118 Metetra
.014 0 0 r
.86254 .56118 .86662 .55777 .87927 .55417 .87519 .55691 Metetra
.87519 .55691 .87927 .55417 .89196 .55057 .88791 .55275 Metetra
.88791 .55275 .89196 .55057 .90472 .54694 .90069 .54863 Metetra
.90069 .54863 .90472 .54694 .91753 .5433 .91351 .54448 Metetra
.245 .748 .694 r
.91351 .54448 .91753 .5433 .93039 .53965 .92638 .54018 Metetra
.351 .825 .788 r
.92638 .54018 .93039 .53965 .94331 .53598 .93926 .53559 Metetra
.493 .904 .891 r
.93926 .53559 .94331 .53598 .95629 .53229 .95213 .53051 Metetra
.644 .941 .961 r
.95213 .53051 .95629 .53229 .96933 .52858 .96496 .52472 Metetra
.741 .893 .948 r
.96496 .52472 .96933 .52858 .98242 .52486 .9777 .51795 Metetra
.359 .636 .96 r
.38927 .67847 .39572 .68414 .40636 .68394 .39986 .68032 Metetra
.407 .744 .993 r
.39986 .68032 .40636 .68394 .41709 .68282 .41058 .68033 Metetra
.459 .812 .997 r
.41058 .68033 .41709 .68282 .42789 .68103 .42141 .67903 Metetra
.51 .851 .995 r
.42141 .67903 .42789 .68103 .43875 .6788 .43231 .67684 Metetra
.553 .868 .995 r
.43231 .67684 .43875 .6788 .44967 .67628 .44327 .67411 Metetra
.581 .87 .995 r
.44327 .67411 .44967 .67628 .46064 .67364 .45428 .67113 Metetra
.596 .862 .993 r
.45428 .67113 .46064 .67364 .47166 .67096 .46534 .66813 Metetra
.597 .851 .992 r
.46534 .66813 .47166 .67096 .48273 .66833 .47645 .66525 Metetra
.588 .839 .992 r
.47645 .66525 .48273 .66833 .49384 .66581 .4876 .66262 Metetra
.57 .83 .994 r
.4876 .66262 .49384 .66581 .505 .66341 .4988 .6603 Metetra
.542 .824 .998 r
.4988 .6603 .505 .66341 .51621 .66117 .51004 .65832 Metetra
.501 .82 1 r
.51004 .65832 .51621 .66117 .52747 .65907 .52134 .65667 Metetra
.443 .813 .994 r
.52134 .65667 .52747 .65907 .53879 .65709 .5327 .65531 Metetra
.362 .794 .967 r
.5327 .65531 .53879 .65709 .55016 .65521 .54412 .65421 Metetra
.252 .751 .901 r
.54412 .65421 .55016 .65521 .56159 .65339 .5556 .65328 Metetra
.122 .672 .786 r
.5556 .65328 .56159 .65339 .57308 .65159 .56715 .65245 Metetra
.009 0 0 r
.56715 .65245 .57308 .65159 .58462 .64977 .57876 .65164 Metetra
.118 0 0 r
.57876 .65164 .58462 .64977 .59622 .64788 .59044 .65075 Metetra
.198 0 0 r
.59044 .65075 .59622 .64788 .60787 .64587 .60217 .6497 Metetra
.249 0 0 r
.60217 .6497 .60787 .64587 .61958 .64372 .61397 .64841 Metetra
.279 0 0 r
.61397 .64841 .61958 .64372 .63134 .64137 .62582 .6468 Metetra
.293 0 0 r
.62582 .6468 .63134 .64137 .64315 .6388 .63772 .64481 Metetra
.295 0 0 r
.63772 .64481 .64315 .6388 .655 .63599 .64966 .64239 Metetra
.286 0 0 r
.64966 .64239 .655 .63599 .6669 .63291 .66165 .63951 Metetra
.268 0 0 r
.66165 .63951 .6669 .63291 .67884 .62955 .67366 .63614 Metetra
.24 0 0 r
.67366 .63614 .67884 .62955 .69081 .62593 .68571 .63229 Metetra
.2 0 0 r
.68571 .63229 .69081 .62593 .70283 .62203 .69778 .62798 Metetra
.147 0 0 r
.69778 .62798 .70283 .62203 .71487 .61788 .70988 .62322 Metetra
.075 0 0 r
.70988 .62322 .71487 .61788 .72695 .61351 .722 .61808 Metetra
.722 .61808 .72695 .61351 .73906 .60894 .73413 .6126 Metetra
.73413 .6126 .73906 .60894 .75121 .6042 .74629 .60687 Metetra
.74629 .60687 .75121 .6042 .7634 .59935 .75848 .60096 Metetra
.412 .851 .741 r
.75848 .60096 .7634 .59935 .77562 .59442 .7707 .59497 Metetra
.529 .922 .855 r
.7707 .59497 .77562 .59442 .78788 .58945 .78295 .58897 Metetra
.61 .948 .926 r
.78295 .58897 .78788 .58945 .80019 .5845 .79524 .58307 Metetra
.655 .943 .961 r
.79524 .58307 .80019 .5845 .81254 .57961 .80759 .57733 Metetra
.675 .922 .973 r
.80759 .57733 .81254 .57961 .82495 .5748 .82 .57184 Metetra
.679 .898 .975 r
.82 .57184 .82495 .5748 .83742 .57012 .83248 .56665 Metetra
.674 .878 .975 r
.83248 .56665 .83742 .57012 .84994 .56558 .84503 .56179 Metetra
.664 .863 .975 r
.84503 .56179 .84994 .56558 .86254 .56118 .85766 .55727 Metetra
.651 .855 .978 r
.85766 .55727 .86254 .56118 .87519 .55691 .87038 .55307 Metetra
.637 .853 .982 r
.87038 .55307 .87519 .55691 .88791 .55275 .88318 .54911 Metetra
.623 .858 .987 r
.88318 .54911 .88791 .55275 .90069 .54863 .89604 .54529 Metetra
.614 .868 .99 r
.89604 .54529 .90069 .54863 .91351 .54448 .90896 .54143 Metetra
.616 .882 .99 r
.90896 .54143 .91351 .54448 .92638 .54018 .92191 .53731 Metetra
.637 .898 .985 r
.92191 .53731 .92638 .54018 .93926 .53559 .93484 .53263 Metetra
.683 .911 .974 r
.93484 .53263 .93926 .53559 .95213 .53051 .94771 .527 Metetra
.746 .908 .948 r
.94771 .527 .95213 .53051 .96496 .52472 .96044 .51997 Metetra
.802 .873 .899 r
.96044 .51997 .96496 .52472 .9777 .51795 .97294 .51098 Metetra
.21 .556 .934 r
.38278 .67275 .38927 .67847 .39986 .68032 .39333 .67607 Metetra
.39 .711 .986 r
.39333 .67607 .39986 .68032 .41058 .68033 .40406 .67664 Metetra
.531 .793 .993 r
.40406 .67664 .41058 .68033 .42141 .67903 .41491 .67522 Metetra
.619 .815 .976 r
.41491 .67522 .42141 .67903 .43231 .67684 .42586 .67248 Metetra
.663 .804 .951 r
.42586 .67248 .43231 .67684 .44327 .67411 .43688 .66896 Metetra
.68 .779 .926 r
.43688 .66896 .44327 .67411 .45428 .67113 .44794 .66508 Metetra
.68 .75 .904 r
.44794 .66508 .45428 .67113 .46534 .66813 .45905 .66118 Metetra
.672 .722 .887 r
.45905 .66118 .46534 .66813 .47645 .66525 .47019 .65752 Metetra
.659 .697 .875 r
.47019 .65752 .47645 .66525 .4876 .66262 .48137 .65425 Metetra
.643 .677 .867 r
.48137 .65425 .4876 .66262 .4988 .6603 .49259 .65149 Metetra
.627 .661 .863 r
.49259 .65149 .4988 .6603 .51004 .65832 .50386 .64928 Metetra
.611 .65 .864 r
.50386 .64928 .51004 .65832 .52134 .65667 .51517 .64761 Metetra
.595 .643 .868 r
.51517 .64761 .52134 .65667 .5327 .65531 .52655 .64644 Metetra
.579 .641 .877 r
.52655 .64644 .5327 .65531 .54412 .65421 .53799 .64569 Metetra
.564 .645 .888 r
.53799 .64569 .54412 .65421 .5556 .65328 .54949 .64527 Metetra
.551 .653 .903 r
.54949 .64527 .5556 .65328 .56715 .65245 .56107 .64506 Metetra
.539 .667 .92 r
.56107 .64506 .56715 .65245 .57876 .65164 .57271 .64494 Metetra
.529 .685 .938 r
.57271 .64494 .57876 .65164 .59044 .65075 .58443 .64476 Metetra
.522 .708 .956 r
.58443 .64476 .59044 .65075 .60217 .6497 .59621 .64442 Metetra
.519 .734 .972 r
.59621 .64442 .60217 .6497 .61397 .64841 .60805 .64378 Metetra
.522 .762 .984 r
.60805 .64378 .61397 .64841 .62582 .6468 .61995 .64273 Metetra
.533 .79 .992 r
.61995 .64273 .62582 .6468 .63772 .64481 .63191 .64119 Metetra
.552 .817 .995 r
.63191 .64119 .63772 .64481 .64966 .64239 .6439 .63907 Metetra
.578 .84 .994 r
.6439 .63907 .64966 .64239 .66165 .63951 .65594 .63633 Metetra
.61 .857 .99 r
.65594 .63633 .66165 .63951 .67366 .63614 .668 .63294 Metetra
.644 .867 .983 r
.668 .63294 .67366 .63614 .68571 .63229 .68009 .6289 Metetra
.677 .869 .972 r
.68009 .6289 .68571 .63229 .69778 .62798 .69219 .62423 Metetra
.704 .862 .957 r
.69219 .62423 .69778 .62798 .70988 .62322 .70431 .61898 Metetra
.724 .848 .94 r
.70431 .61898 .70988 .62322 .722 .61808 .71644 .61322 Metetra
.737 .829 .921 r
.71644 .61322 .722 .61808 .73413 .6126 .72858 .60703 Metetra
.743 .806 .903 r
.72858 .60703 .73413 .6126 .74629 .60687 .74074 .60054 Metetra
.743 .783 .885 r
.74074 .60054 .74629 .60687 .75848 .60096 .75292 .59385 Metetra
.739 .76 .87 r
.75292 .59385 .75848 .60096 .7707 .59497 .76512 .58709 Metetra
.732 .739 .857 r
.76512 .58709 .7707 .59497 .78295 .58897 .77736 .58041 Metetra
.723 .72 .847 r
.77736 .58041 .78295 .58897 .79524 .58307 .78965 .57393 Metetra
.713 .704 .841 r
.78965 .57393 .79524 .58307 .80759 .57733 .802 .56777 Metetra
.702 .692 .837 r
.802 .56777 .80759 .57733 .82 .57184 .81442 .56203 Metetra
.69 .683 .838 r
.81442 .56203 .82 .57184 .83248 .56665 .82692 .55679 Metetra
.678 .677 .842 r
.82692 .55679 .83248 .56665 .84503 .56179 .83952 .55211 Metetra
.666 .676 .85 r
.83952 .55211 .84503 .56179 .85766 .55727 .85223 .54799 Metetra
.654 .681 .863 r
.85223 .54799 .85766 .55727 .87038 .55307 .86504 .54438 Metetra
.644 .691 .879 r
.86504 .54438 .87038 .55307 .88318 .54911 .87795 .54119 Metetra
.636 .708 .899 r
.87795 .54119 .88318 .54911 .89604 .54529 .89095 .53824 Metetra
.633 .734 .921 r
.89095 .53824 .89604 .54529 .90896 .54143 .90402 .53527 Metetra
.639 .768 .941 r
.90402 .53527 .90896 .54143 .92191 .53731 .9171 .53193 Metetra
.662 .807 .953 r
.9171 .53193 .92191 .53731 .93484 .53263 .93015 .52777 Metetra
.706 .844 .948 r
.93015 .52777 .93484 .53263 .94771 .527 .94309 .52221 Metetra
.769 .865 .92 r
.94309 .52221 .94771 .527 .96044 .51997 .95579 .51455 Metetra
.828 .854 .866 r
.95579 .51455 .96044 .51997 .97294 .51098 .96814 .50396 Metetra
.084 .48 .894 r
.37624 .667 .38278 .67275 .39333 .67607 .38676 .67139 Metetra
.4 .699 .982 r
.38676 .67139 .39333 .67607 .40406 .67664 .39751 .6721 Metetra
.587 .778 .97 r
.39751 .6721 .40406 .67664 .41491 .67522 .40841 .67017 Metetra
.673 .781 .931 r
.40841 .67017 .41491 .67522 .42586 .67248 .41941 .66648 Metetra
.705 .756 .892 r
.41941 .66648 .42586 .67248 .43688 .66896 .43049 .66175 Metetra
.71 .725 .862 r
.43049 .66175 .43688 .66896 .44794 .66508 .44161 .65658 Metetra
.702 .693 .838 r
.44161 .65658 .44794 .66508 .45905 .66118 .45276 .65142 Metetra
.688 .663 .821 r
.45276 .65142 .45905 .66118 .47019 .65752 .46394 .64659 Metetra
.671 .637 .808 r
.46394 .64659 .47019 .65752 .48137 .65425 .47515 .64234 Metetra
.653 .615 .799 r
.47515 .64234 .48137 .65425 .49259 .65149 .48639 .63879 Metetra
.635 .596 .793 r
.48639 .63879 .49259 .65149 .50386 .64928 .49767 .63602 Metetra
.618 .581 .79 r
.49767 .63602 .50386 .64928 .51517 .64761 .50899 .63401 Metetra
.603 .569 .789 r
.50899 .63401 .51517 .64761 .52655 .64644 .52037 .63272 Metetra
.589 .561 .791 r
.52037 .63272 .52655 .64644 .53799 .64569 .53181 .63204 Metetra
.577 .557 .795 r
.53181 .63204 .53799 .64569 .54949 .64527 .54331 .63186 Metetra
.568 .556 .8 r
.54331 .63186 .54949 .64527 .56107 .64506 .55489 .63202 Metetra
.563 .558 .807 r
.55489 .63202 .56107 .64506 .57271 .64494 .56655 .63235 Metetra
.561 .565 .814 r
.56655 .63235 .57271 .64494 .58443 .64476 .57827 .63269 Metetra
.563 .574 .823 r
.57827 .63269 .58443 .64476 .59621 .64442 .59007 .63286 Metetra
.57 .587 .831 r
.59007 .63286 .59621 .64442 .60805 .64378 .60194 .63272 Metetra
.581 .602 .838 r
.60194 .63272 .60805 .64378 .61995 .64273 .61387 .63211 Metetra
.596 .618 .844 r
.61387 .63211 .61995 .64273 .63191 .64119 .62585 .63091 Metetra
.614 .634 .847 r
.62585 .63091 .63191 .64119 .6439 .63907 .63787 .62904 Metetra
.633 .647 .846 r
.63787 .62904 .6439 .63907 .65594 .63633 .64993 .6264 Metetra
.652 .658 .843 r
.64993 .6264 .65594 .63633 .668 .63294 .66202 .62298 Metetra
.67 .666 .837 r
.66202 .62298 .668 .63294 .68009 .6289 .67412 .61877 Metetra
.685 .669 .829 r
.67412 .61877 .68009 .6289 .69219 .62423 .68624 .6138 Metetra
.696 .669 .819 r
.68624 .6138 .69219 .62423 .70431 .61898 .69836 .60814 Metetra
.704 .666 .809 r
.69836 .60814 .70431 .61898 .71644 .61322 .71049 .60187 Metetra
.709 .66 .799 r
.71049 .60187 .71644 .61322 .72858 .60703 .72262 .59511 Metetra
.71 .653 .79 r
.72262 .59511 .72858 .60703 .74074 .60054 .73477 .58802 Metetra
.709 .644 .783 r
.73477 .58802 .74074 .60054 .75292 .59385 .74693 .58074 Metetra
.706 .636 .776 r
.74693 .58074 .75292 .59385 .76512 .58709 .75911 .57345 Metetra
.7 .627 .772 r
.75911 .57345 .76512 .58709 .77736 .58041 .77134 .56633 Metetra
.693 .619 .769 r
.77134 .56633 .77736 .58041 .78965 .57393 .78362 .55953 Metetra
.684 .611 .768 r
.78362 .55953 .78965 .57393 .802 .56777 .79597 .55323 Metetra
.674 .605 .77 r
.79597 .55323 .802 .56777 .81442 .56203 .80841 .54754 Metetra
.663 .6 .774 r
.80841 .54754 .81442 .56203 .82692 .55679 .82095 .54258 Metetra
.652 .598 .781 r
.82095 .54258 .82692 .55679 .83952 .55211 .83362 .5384 Metetra
.639 .598 .792 r
.83362 .5384 .83952 .55211 .85223 .54799 .84641 .53502 Metetra
.626 .602 .806 r
.84641 .53502 .85223 .54799 .86504 .54438 .85933 .53238 Metetra
.615 .611 .824 r
.85933 .53238 .86504 .54438 .87795 .54119 .87239 .53032 Metetra
.605 .627 .846 r
.87239 .53032 .87795 .54119 .89095 .53824 .88555 .52863 Metetra
.602 .652 .872 r
.88555 .52863 .89095 .53824 .90402 .53527 .89879 .52695 Metetra
.61 .689 .899 r
.89879 .52695 .90402 .53527 .9171 .53193 .91206 .52481 Metetra
.639 .738 .921 r
.91206 .52481 .9171 .53193 .93015 .52777 .92527 .52159 Metetra
.694 .792 .926 r
.92527 .52159 .93015 .52777 .94309 .52221 .93831 .51651 Metetra
.77 .834 .902 r
.93831 .51651 .94309 .52221 .95579 .51455 .95105 .50865 Metetra
.842 .842 .844 r
.95105 .50865 .95579 .51455 .96814 .50396 .9633 .49687 Metetra
0 .412 .85 r
.36965 .6612 .37624 .667 .38676 .67139 .38015 .66641 Metetra
.421 .699 .979 r
.38015 .66641 .38676 .67139 .39751 .6721 .39092 .66702 Metetra
.632 .771 .947 r
.39092 .66702 .39751 .6721 .40841 .67017 .40188 .66432 Metetra
.709 .763 .894 r
.40188 .66432 .40841 .67017 .41941 .66648 .41295 .65944 Metetra
.732 .734 .853 r
.41295 .65944 .41941 .66648 .43049 .66175 .42409 .65328 Metetra
.73 .702 .823 r
.42409 .65328 .43049 .66175 .44161 .65658 .43528 .64658 Metetra
.718 .67 .802 r
.43528 .64658 .44161 .65658 .45276 .65142 .44648 .63992 Metetra
.701 .642 .787 r
.44648 .63992 .45276 .65142 .46394 .64659 .4577 .63372 Metetra
.682 .616 .775 r
.4577 .63372 .46394 .64659 .47515 .64234 .46894 .62827 Metetra
.662 .593 .767 r
.46894 .62827 .47515 .64234 .48639 .63879 .48019 .62373 Metetra
.642 .573 .762 r
.48019 .62373 .48639 .63879 .49767 .63602 .49148 .62019 Metetra
.623 .556 .758 r
.49148 .62019 .49767 .63602 .50899 .63401 .5028 .61766 Metetra
.606 .542 .757 r
.5028 .61766 .50899 .63401 .52037 .63272 .51417 .61606 Metetra
.591 .531 .757 r
.51417 .61606 .52037 .63272 .53181 .63204 .5256 .61528 Metetra
.578 .524 .758 r
.5256 .61528 .53181 .63204 .54331 .63186 .5371 .61517 Metetra
.569 .519 .76 r
.5371 .61517 .54331 .63186 .55489 .63202 .54867 .61553 Metetra
.563 .518 .764 r
.54867 .61553 .55489 .63202 .56655 .63235 .56032 .61618 Metetra
.561 .521 .768 r
.56032 .61618 .56655 .63235 .57827 .63269 .57205 .6169 Metetra
.563 .526 .773 r
.57205 .6169 .57827 .63269 .59007 .63286 .58385 .61748 Metetra
.569 .535 .777 r
.58385 .61748 .59007 .63286 .60194 .63272 .59572 .61773 Metetra
.579 .545 .781 r
.59572 .61773 .60194 .63272 .61387 .63211 .60765 .61748 Metetra
.592 .557 .784 r
.60765 .61748 .61387 .63211 .62585 .63091 .61964 .61657 Metetra
.608 .569 .785 r
.61964 .61657 .62585 .63091 .63787 .62904 .63168 .61488 Metetra
.625 .581 .784 r
.63168 .61488 .63787 .62904 .64993 .6264 .64375 .61233 Metetra
.641 .59 .782 r
.64375 .61233 .64993 .6264 .66202 .62298 .65584 .60888 Metetra
.657 .598 .778 r
.65584 .60888 .66202 .62298 .67412 .61877 .66795 .60451 Metetra
.67 .603 .772 r
.66795 .60451 .67412 .61877 .68624 .6138 .68006 .59928 Metetra
.68 .606 .766 r
.68006 .59928 .68624 .6138 .69836 .60814 .69218 .59325 Metetra
.688 .606 .76 r
.69218 .59325 .69836 .60814 .71049 .60187 .7043 .58655 Metetra
.692 .605 .754 r
.7043 .58655 .71049 .60187 .72262 .59511 .71642 .57932 Metetra
.694 .601 .748 r
.71642 .57932 .72262 .59511 .73477 .58802 .72854 .57173 Metetra
.693 .597 .744 r
.72854 .57173 .73477 .58802 .74693 .58074 .74068 .56399 Metetra
.69 .592 .74 r
.74068 .56399 .74693 .58074 .75911 .57345 .75285 .55631 Metetra
.685 .586 .739 r
.75285 .55631 .75911 .57345 .77134 .56633 .76506 .54889 Metetra
.678 .58 .738 r
.76506 .54889 .77134 .56633 .78362 .55953 .77733 .54195 Metetra
.669 .574 .74 r
.77733 .54195 .78362 .55953 .79597 .55323 .78969 .53567 Metetra
.659 .569 .743 r
.78969 .53567 .79597 .55323 .80841 .54754 .80215 .53022 Metetra
.646 .564 .748 r
.80215 .53022 .80841 .54754 .82095 .54258 .81474 .52572 Metetra
.633 .561 .756 r
.81474 .52572 .82095 .54258 .83362 .5384 .82747 .52226 Metetra
.617 .56 .767 r
.82747 .52226 .83362 .5384 .84641 .53502 .84036 .51982 Metetra
.601 .561 .781 r
.84036 .51982 .84641 .53502 .85933 .53238 .85341 .51835 Metetra
.586 .567 .8 r
.85341 .51835 .85933 .53238 .87239 .53032 .86661 .51765 Metetra
.572 .579 .822 r
.86661 .51765 .87239 .53032 .88555 .52863 .87995 .51745 Metetra
.565 .602 .849 r
.87995 .51745 .88555 .52863 .89879 .52695 .89339 .51729 Metetra
.572 .638 .878 r
.89339 .51729 .89879 .52695 .91206 .52481 .90685 .51659 Metetra
.604 .692 .905 r
.90685 .51659 .91206 .52481 .92527 .52159 .92025 .51456 Metetra
.671 .758 .916 r
.92025 .51456 .92527 .52159 .93831 .51651 .93343 .51024 Metetra
.764 .815 .893 r
.93343 .51024 .93831 .51651 .95105 .50865 .94623 .50243 Metetra
.852 .835 .829 r
.94623 .50243 .95105 .50865 .9633 .49687 .95842 .48973 Metetra
0 .349 .804 r
.36302 .65536 .36965 .6612 .38015 .66641 .37349 .66127 Metetra
.445 .704 .977 r
.37349 .66127 .38015 .66641 .39092 .66702 .38429 .66165 Metetra
.668 .771 .927 r
.38429 .66165 .39092 .66702 .40188 .66432 .39531 .65807 Metetra
.738 .757 .868 r
.39531 .65807 .40188 .66432 .41295 .65944 .40646 .65187 Metetra
.755 .727 .827 r
.40646 .65187 .41295 .65944 .42409 .65328 .41768 .64417 Metetra
.75 .696 .8 r
.41768 .64417 .42409 .65328 .43528 .64658 .42893 .63585 Metetra
.736 .666 .781 r
.42893 .63585 .43528 .64658 .44648 .63992 .44019 .6276 Metetra
.717 .638 .768 r
.44019 .6276 .44648 .63992 .4577 .63372 .45146 .61992 Metetra
.696 .612 .759 r
.45146 .61992 .4577 .63372 .46894 .62827 .46273 .61317 Metetra
.673 .589 .753 r
.46273 .61317 .46894 .62827 .48019 .62373 .474 .60756 Metetra
.651 .568 .748 r
.474 .60756 .48019 .62373 .49148 .62019 .48529 .60317 Metetra
.63 .55 .745 r
.48529 .60317 .49148 .62019 .5028 .61766 .49661 .60003 Metetra
.611 .534 .744 r
.49661 .60003 .5028 .61766 .51417 .61606 .50798 .59803 Metetra
.593 .521 .743 r
.50798 .59803 .51417 .61606 .5256 .61528 .51939 .59707 Metetra
.578 .512 .744 r
.51939 .59707 .5256 .61528 .5371 .61517 .53088 .59694 Metetra
.567 .505 .746 r
.53088 .59694 .5371 .61517 .54867 .61553 .54243 .59744 Metetra
.559 .502 .748 r
.54243 .59744 .54867 .61553 .56032 .61618 .55407 .59832 Metetra
.556 .503 .751 r
.55407 .59832 .56032 .61618 .57205 .6169 .56578 .59935 Metetra
.558 .507 .755 r
.56578 .59935 .57205 .6169 .58385 .61748 .57758 .60028 Metetra
.564 .514 .758 r
.57758 .60028 .58385 .61748 .59572 .61773 .58944 .60088 Metetra
.574 .523 .761 r
.58944 .60088 .59572 .61773 .60765 .61748 .60138 .60093 Metetra
.587 .534 .763 r
.60138 .60093 .60765 .61748 .61964 .61657 .61337 .60027 Metetra
.603 .546 .764 r
.61337 .60027 .61964 .61657 .63168 .61488 .62541 .59875 Metetra
.62 .557 .763 r
.62541 .59875 .63168 .61488 .64375 .61233 .63748 .59627 Metetra
.636 .567 .76 r
.63748 .59627 .64375 .61233 .65584 .60888 .64957 .59278 Metetra
.651 .575 .757 r
.64957 .59278 .65584 .60888 .66795 .60451 .66168 .58827 Metetra
.665 .581 .752 r
.66168 .58827 .66795 .60451 .68006 .59928 .67379 .58279 Metetra
.675 .585 .747 r
.67379 .58279 .68006 .59928 .69218 .59325 .68589 .57643 Metetra
.683 .587 .741 r
.68589 .57643 .69218 .59325 .7043 .58655 .698 .56933 Metetra
.688 .586 .737 r
.698 .56933 .7043 .58655 .71642 .57932 .7101 .56168 Metetra
.69 .584 .732 r
.7101 .56168 .71642 .57932 .72854 .57173 .7222 .55366 Metetra
.689 .581 .729 r
.7222 .55366 .72854 .57173 .74068 .56399 .73432 .54553 Metetra
.686 .577 .727 r
.73432 .54553 .74068 .56399 .75285 .55631 .74647 .53752 Metetra
.68 .571 .726 r
.74647 .53752 .75285 .55631 .76506 .54889 .75866 .52988 Metetra
.672 .566 .727 r
.75866 .52988 .76506 .54889 .77733 .54195 .77093 .52287 Metetra
.662 .56 .729 r
.77093 .52287 .77733 .54195 .78969 .53567 .78329 .5167 Metetra
.649 .554 .733 r
.78329 .5167 .78969 .53567 .80215 .53022 .79578 .51158 Metetra
.635 .548 .739 r
.79578 .51158 .80215 .53022 .81474 .52572 .80841 .50763 Metetra
.618 .543 .748 r
.80841 .50763 .81474 .52572 .82747 .52226 .82121 .50496 Metetra
.599 .539 .759 r
.82121 .50496 .82747 .52226 .84036 .51982 .83419 .50356 Metetra
.578 .537 .773 r
.83419 .50356 .84036 .51982 .85341 .51835 .84737 .50335 Metetra
.556 .539 .791 r
.84737 .50335 .85341 .51835 .86661 .51765 .86073 .50411 Metetra
.536 .548 .814 r
.86073 .50411 .86661 .51765 .87995 .51745 .87425 .50549 Metetra
.523 .566 .841 r
.87425 .50549 .87995 .51745 .89339 .51729 .88789 .50696 Metetra
.528 .602 .871 r
.88789 .50696 .89339 .51729 .90685 .51659 .90155 .50781 Metetra
.564 .659 .9 r
.90155 .50781 .90685 .51659 .92025 .51456 .91514 .5071 Metetra
.644 .735 .915 r
.91514 .5071 .92025 .51456 .93343 .51024 .92847 .50365 Metetra
.757 .805 .891 r
.92847 .50365 .93343 .51024 .94623 .50243 .94135 .49602 Metetra
.86 .832 .818 r
.94135 .49602 .94623 .50243 .95842 .48973 .95351 .48253 Metetra
0 .285 .752 r
.35633 .64948 .36302 .65536 .37349 .66127 .36678 .65606 Metetra
.464 .711 .976 r
.36678 .65606 .37349 .66127 .38429 .66165 .37762 .6562 Metetra
.698 .775 .911 r
.37762 .6562 .38429 .66165 .39531 .65807 .3887 .65172 Metetra
.762 .758 .849 r
.3887 .65172 .39531 .65807 .40646 .65187 .39992 .6442 Metetra
.776 .729 .81 r
.39992 .6442 .40646 .65187 .41768 .64417 .41122 .63494 Metetra
.77 .699 .785 r
.41122 .63494 .41768 .64417 .42893 .63585 .42255 .62499 Metetra
.754 .671 .769 r
.42255 .62499 .42893 .63585 .44019 .6276 .43388 .61515 Metetra
.734 .644 .759 r
.43388 .61515 .44019 .6276 .45146 .61992 .4452 .606 Metetra
.711 .619 .752 r
.4452 .606 .45146 .61992 .46273 .61317 .4565 .59796 Metetra
.687 .595 .747 r
.4565 .59796 .46273 .61317 .474 .60756 .4678 .59126 Metetra
.663 .573 .744 r
.4678 .59126 .474 .60756 .48529 .60317 .4791 .58603 Metetra
.639 .554 .742 r
.4791 .58603 .48529 .60317 .49661 .60003 .49042 .58226 Metetra
.616 .536 .742 r
.49042 .58226 .49661 .60003 .50798 .59803 .50177 .57987 Metetra
.596 .522 .742 r
.50177 .57987 .50798 .59803 .51939 .59707 .51318 .5787 Metetra
.578 .51 .743 r
.51318 .5787 .51939 .59707 .53088 .59694 .52465 .57855 Metetra
.564 .502 .745 r
.52465 .57855 .53088 .59694 .54243 .59744 .53619 .57916 Metetra
.554 .498 .747 r
.53619 .57916 .54243 .59744 .55407 .59832 .54781 .58027 Metetra
.55 .498 .75 r
.54781 .58027 .55407 .59832 .56578 .59935 .55951 .58159 Metetra
.55 .501 .754 r
.55951 .58159 .56578 .59935 .57758 .60028 .57129 .58284 Metetra
.556 .508 .757 r
.57129 .58284 .57758 .60028 .58944 .60088 .58316 .58377 Metetra
.567 .518 .76 r
.58316 .58377 .58944 .60088 .60138 .60093 .59509 .58413 Metetra
.582 .529 .761 r
.59509 .58413 .60138 .60093 .61337 .60027 .60708 .58371 Metetra
.599 .542 .762 r
.60708 .58371 .61337 .60027 .62541 .59875 .61911 .58235 Metetra
.617 .554 .76 r
.61911 .58235 .62541 .59875 .63748 .59627 .63119 .57993 Metetra
.636 .565 .758 r
.63119 .57993 .63748 .59627 .64957 .59278 .64328 .5764 Metetra
.652 .574 .754 r
.64328 .5764 .64957 .59278 .66168 .58827 .65538 .57174 Metetra
.667 .58 .749 r
.65538 .57174 .66168 .58827 .67379 .58279 .66749 .56602 Metetra
.678 .585 .744 r
.66749 .56602 .67379 .58279 .68589 .57643 .67958 .55935 Metetra
.686 .587 .738 r
.67958 .55935 .68589 .57643 .698 .56933 .69167 .55187 Metetra
.691 .587 .733 r
.69167 .55187 .698 .56933 .7101 .56168 .70376 .5438 Metetra
.693 .585 .729 r
.70376 .5438 .7101 .56168 .7222 .55366 .71584 .53537 Metetra
.692 .581 .726 r
.71584 .53537 .7222 .55366 .73432 .54553 .72794 .52686 Metetra
.688 .577 .725 r
.72794 .52686 .73432 .54553 .74647 .53752 .74007 .51854 Metetra
.681 .571 .724 r
.74007 .51854 .74647 .53752 .75866 .52988 .75225 .51071 Metetra
.672 .564 .725 r
.75225 .51071 .75866 .52988 .77093 .52287 .76451 .50364 Metetra
.66 .557 .728 r
.76451 .50364 .77093 .52287 .78329 .5167 .77688 .4976 Metetra
.644 .55 .733 r
.77688 .4976 .78329 .5167 .79578 .51158 .78939 .4928 Metetra
.626 .542 .74 r
.78939 .4928 .79578 .51158 .80841 .50763 .80206 .48941 Metetra
.605 .534 .749 r
.80206 .48941 .80841 .50763 .82121 .50496 .81493 .48753 Metetra
.58 .527 .76 r
.81493 .48753 .82121 .50496 .83419 .50356 .828 .48717 Metetra
.553 .522 .775 r
.828 .48717 .83419 .50356 .84737 .50335 .8413 .48822 Metetra
.523 .519 .793 r
.8413 .48822 .84737 .50335 .86073 .50411 .85481 .49043 Metetra
.495 .523 .815 r
.85481 .49043 .86073 .50411 .87425 .50549 .86851 .49339 Metetra
.475 .538 .842 r
.86851 .49339 .87425 .50549 .88789 .50696 .88234 .4965 Metetra
.476 .572 .872 r
.88234 .4965 .88789 .50696 .90155 .50781 .89621 .49891 Metetra
.517 .633 .904 r
.89621 .49891 .90155 .50781 .91514 .5071 .90998 .49953 Metetra
.615 .72 .92 r
.90998 .49953 .91514 .5071 .92847 .50365 .92347 .49696 Metetra
.752 .801 .893 r
.92347 .49696 .92847 .50365 .94135 .49602 .93643 .48953 Metetra
.868 .831 .809 r
.93643 .48953 .94135 .49602 .95351 .48253 .94855 .47527 Metetra
0 .216 .691 r
.34959 .64355 .35633 .64948 .36678 .65606 .36002 .65086 Metetra
.475 .717 .976 r
.36002 .65086 .36678 .65606 .37762 .6562 .37088 .65082 Metetra
.721 .782 .901 r
.37088 .65082 .37762 .6562 .3887 .65172 .38203 .64551 Metetra
.783 .764 .836 r
.38203 .64551 .3887 .65172 .39992 .6442 .39333 .63673 Metetra
.795 .737 .798 r
.39333 .63673 .39992 .6442 .41122 .63494 .40472 .62599 Metetra
.789 .709 .776 r
.40472 .62599 .41122 .63494 .42255 .62499 .41613 .61448 Metetra
.773 .682 .763 r
.41613 .61448 .42255 .62499 .43388 .61515 .42753 .60312 Metetra
.753 .657 .755 r
.42753 .60312 .43388 .61515 .4452 .606 .43891 .59257 Metetra
.729 .632 .75 r
.43891 .59257 .4452 .606 .4565 .59796 .45025 .58331 Metetra
.703 .608 .748 r
.45025 .58331 .4565 .59796 .4678 .59126 .46157 .5756 Metetra
.676 .586 .747 r
.46157 .5756 .4678 .59126 .4791 .58603 .47289 .56958 Metetra
.649 .565 .747 r
.47289 .56958 .4791 .58603 .49042 .58226 .48421 .56524 Metetra
.623 .546 .748 r
.48421 .56524 .49042 .58226 .50177 .57987 .49556 .5625 Metetra
.598 .53 .749 r
.49556 .5625 .50177 .57987 .51318 .5787 .50696 .56117 Metetra
.576 .516 .751 r
.50696 .56117 .51318 .5787 .52465 .57855 .51841 .56103 Metetra
.559 .507 .754 r
.51841 .56103 .52465 .57855 .53619 .57916 .52994 .56178 Metetra
.546 .501 .757 r
.52994 .56178 .53619 .57916 .54781 .58027 .54155 .56314 Metetra
.539 .5 .761 r
.54155 .56314 .54781 .58027 .55951 .58159 .55324 .56477 Metetra
.539 .504 .765 r
.55324 .56477 .55951 .58159 .57129 .58284 .56502 .56638 Metetra
.546 .511 .768 r
.56502 .56638 .57129 .58284 .58316 .58377 .57687 .56765 Metetra
.558 .522 .772 r
.57687 .56765 .58316 .58377 .59509 .58413 .5888 .56831 Metetra
.575 .536 .773 r
.5888 .56831 .59509 .58413 .60708 .58371 .6008 .56814 Metetra
.595 .55 .774 r
.6008 .56814 .60708 .58371 .61911 .58235 .61284 .56694 Metetra
.617 .564 .772 r
.61284 .56694 .61911 .58235 .63119 .57993 .62491 .56459 Metetra
.638 .576 .769 r
.62491 .56459 .63119 .57993 .64328 .5764 .63701 .56102 Metetra
.658 .586 .764 r
.63701 .56102 .64328 .5764 .65538 .57174 .64911 .55623 Metetra
.674 .594 .758 r
.64911 .55623 .65538 .57174 .66749 .56602 .66122 .55026 Metetra
.687 .598 .751 r
.66122 .55026 .66749 .56602 .67958 .55935 .67331 .54326 Metetra
.696 .6 .745 r
.67331 .54326 .67958 .55935 .69167 .55187 .68539 .53539 Metetra
.701 .6 .74 r
.68539 .53539 .69167 .55187 .70376 .5438 .69746 .5269 Metetra
.703 .598 .735 r
.69746 .5269 .70376 .5438 .71584 .53537 .70953 .51804 Metetra
.701 .593 .732 r
.70953 .51804 .71584 .53537 .72794 .52686 .72161 .50913 Metetra
.696 .588 .73 r
.72161 .50913 .72794 .52686 .74007 .51854 .73372 .50048 Metetra
.688 .581 .73 r
.73372 .50048 .74007 .51854 .75225 .51071 .74589 .49242 Metetra
.676 .573 .732 r
.74589 .49242 .75225 .51071 .76451 .50364 .75815 .48527 Metetra
.661 .564 .735 r
.75815 .48527 .76451 .50364 .77688 .4976 .77052 .4793 Metetra
.643 .555 .74 r
.77052 .4793 .77688 .4976 .78939 .4928 .78305 .47478 Metetra
.62 .545 .748 r
.78305 .47478 .78939 .4928 .80206 .48941 .79577 .4719 Metetra
.593 .534 .758 r
.79577 .4719 .80206 .48941 .81493 .48753 .80869 .47075 Metetra
.561 .523 .77 r
.80869 .47075 .81493 .48753 .828 .48717 .82186 .47136 Metetra
.524 .512 .785 r
.82186 .47136 .828 .48717 .8413 .48822 .83527 .47359 Metetra
.485 .504 .802 r
.83527 .47359 .8413 .48822 .85481 .49043 .84892 .47718 Metetra
.446 .502 .823 r
.84892 .47718 .85481 .49043 .86851 .49339 .86278 .48165 Metetra
.417 .512 .848 r
.86278 .48165 .86851 .49339 .88234 .4965 .87679 .48631 Metetra
.414 .544 .878 r
.87679 .48631 .88234 .4965 .89621 .49891 .89085 .49021 Metetra
.463 .611 .911 r
.89085 .49021 .89621 .49891 .90998 .49953 .9048 .49208 Metetra
.584 .711 .931 r
.9048 .49208 .90998 .49953 .92347 .49696 .91844 .49033 Metetra
.748 .804 .897 r
.91844 .49033 .92347 .49696 .93643 .48953 .93147 .48303 Metetra
.877 .833 .8 r
.93147 .48303 .93643 .48953 .94855 .47527 .94355 .46794 Metetra
0 .136 .616 r
.3428 .63757 .34959 .64355 .36002 .65086 .35319 .64573 Metetra
.474 .721 .978 r
.35319 .64573 .36002 .65086 .37088 .65082 .36408 .64562 Metetra
.74 .792 .894 r
.36408 .64562 .37088 .65082 .38203 .64551 .37529 .6396 Metetra
.802 .773 .827 r
.37529 .6396 .38203 .64551 .39333 .63673 .38668 .62969 Metetra
.814 .747 .79 r
.38668 .62969 .39333 .63673 .40472 .62599 .39816 .6176 Metetra
.808 .722 .77 r
.39816 .6176 .40472 .62599 .41613 .61448 .40966 .60466 Metetra
.793 .698 .76 r
.40966 .60466 .41613 .61448 .42753 .60312 .42113 .5919 Metetra
.772 .674 .755 r
.42113 .5919 .42753 .60312 .43891 .59257 .43256 .58008 Metetra
.748 .65 .753 r
.43256 .58008 .43891 .59257 .45025 .58331 .44396 .56971 Metetra
.72 .627 .753 r
.44396 .56971 .45025 .58331 .46157 .5756 .45531 .5611 Metetra
.691 .605 .755 r
.45531 .5611 .46157 .5756 .47289 .56958 .46664 .55439 Metetra
.66 .583 .757 r
.46664 .55439 .47289 .56958 .48421 .56524 .47798 .54959 Metetra
.629 .562 .76 r
.47798 .54959 .48421 .56524 .49556 .5625 .48933 .54658 Metetra
.6 .544 .764 r
.48933 .54658 .49556 .5625 .50696 .56117 .50072 .54518 Metetra
.572 .529 .768 r
.50072 .54518 .50696 .56117 .51841 .56103 .51216 .54511 Metetra
.55 .517 .772 r
.51216 .54511 .51841 .56103 .52994 .56178 .52368 .54608 Metetra
.532 .51 .777 r
.52368 .54608 .52994 .56178 .54155 .56314 .53528 .54774 Metetra
.523 .509 .782 r
.53528 .54774 .54155 .56314 .55324 .56477 .54697 .54974 Metetra
.521 .513 .787 r
.54697 .54974 .55324 .56477 .56502 .56638 .55874 .55173 Metetra
.528 .522 .793 r
.55874 .55173 .56502 .56638 .57687 .56765 .5706 .55338 Metetra
.543 .536 .797 r
.5706 .55338 .57687 .56765 .5888 .56831 .58254 .55438 Metetra
.565 .553 .8 r
.58254 .55438 .5888 .56831 .6008 .56814 .59454 .55448 Metetra
.59 .571 .8 r
.59454 .55448 .6008 .56814 .61284 .56694 .60659 .55347 Metetra
.618 .588 .797 r
.60659 .55347 .61284 .56694 .62491 .56459 .61868 .55119 Metetra
.644 .602 .792 r
.61868 .55119 .62491 .56459 .63701 .56102 .63078 .54759 Metetra
.667 .614 .785 r
.63078 .54759 .63701 .56102 .64911 .55623 .6429 .54264 Metetra
.687 .622 .777 r
.6429 .54264 .64911 .55623 .66122 .55026 .655 .53642 Metetra
.702 .626 .769 r
.655 .53642 .66122 .55026 .67331 .54326 .6671 .52907 Metetra
.712 .627 .761 r
.6671 .52907 .67331 .54326 .68539 .53539 .67918 .52079 Metetra
.718 .626 .754 r
.67918 .52079 .68539 .53539 .69746 .5269 .69124 .51184 Metetra
.719 .622 .748 r
.69124 .51184 .69746 .5269 .70953 .51804 .7033 .50251 Metetra
.717 .617 .745 r
.7033 .50251 .70953 .51804 .72161 .50913 .71537 .49316 Metetra
.71 .61 .743 r
.71537 .49316 .72161 .50913 .73372 .50048 .72747 .48412 Metetra
.7 .601 .743 r
.72747 .48412 .73372 .50048 .74589 .49242 .73964 .47577 Metetra
.686 .592 .744 r
.73964 .47577 .74589 .49242 .75815 .48527 .75189 .46845 Metetra
.667 .58 .749 r
.75189 .46845 .75815 .48527 .77052 .4793 .76427 .4625 Metetra
.644 .568 .755 r
.76427 .4625 .77052 .4793 .78305 .47478 .77682 .45817 Metetra
.615 .554 .763 r
.77682 .45817 .78305 .47478 .79577 .4719 .78957 .45569 Metetra
.58 .539 .774 r
.78957 .45569 .79577 .4719 .80869 .47075 .80255 .45517 Metetra
.539 .523 .786 r
.80255 .45517 .80869 .47075 .82186 .47136 .81579 .45663 Metetra
.491 .506 .801 r
.81579 .45663 .82186 .47136 .83527 .47359 .82931 .45993 Metetra
.437 .491 .817 r
.82931 .45993 .83527 .47359 .84892 .47718 .84309 .46476 Metetra
.385 .481 .835 r
.84309 .46476 .84892 .47718 .86278 .48165 .8571 .47061 Metetra
.345 .484 .856 r
.8571 .47061 .86278 .48165 .87679 .48631 .87128 .4767 Metetra
.339 .515 .884 r
.87128 .4767 .87679 .48631 .89085 .49021 .88551 .48195 Metetra
.401 .59 .92 r
.88551 .48195 .89085 .49021 .9048 .49208 .89963 .48494 Metetra
.552 .708 .944 r
.89963 .48494 .9048 .49208 .91844 .49033 .91339 .48387 Metetra
.748 .812 .903 r
.91339 .48387 .91844 .49033 .93147 .48303 .92648 .47659 Metetra
.887 .836 .79 r
.92648 .47659 .93147 .48303 .94355 .46794 .9385 .46056 Metetra
.471 0 0 r
.33596 .63155 .3428 .63757 .35319 .64573 .3463 .6407 Metetra
.46 .721 .981 r
.3463 .6407 .35319 .64573 .36408 .64562 .35721 .64068 Metetra
.754 .802 .892 r
.35721 .64068 .36408 .64562 .37529 .6396 .36848 .63411 Metetra
.818 .784 .821 r
.36848 .63411 .37529 .6396 .38668 .62969 .37996 .62324 Metetra
.831 .76 .785 r
.37996 .62324 .38668 .62969 .39816 .6176 .39153 .60996 Metetra
.826 .737 .767 r
.39153 .60996 .39816 .6176 .40966 .60466 .40311 .59575 Metetra
.812 .716 .759 r
.40311 .59575 .40966 .60466 .42113 .5919 .41466 .58175 Metetra
.792 .694 .757 r
.41466 .58175 .42113 .5919 .43256 .58008 .42616 .56881 Metetra
.767 .673 .758 r
.42616 .56881 .43256 .58008 .44396 .56971 .4376 .55749 Metetra
.739 .651 .762 r
.4376 .55749 .44396 .56971 .45531 .5611 .44899 .54812 Metetra
.707 .629 .767 r
.44899 .54812 .45531 .5611 .46664 .55439 .46035 .54086 Metetra
.672 .607 .774 r
.46035 .54086 .46664 .55439 .47798 .54959 .4717 .53571 Metetra
.636 .585 .781 r
.4717 .53571 .47798 .54959 .48933 .54658 .48306 .53255 Metetra
.599 .565 .788 r
.48306 .53255 .48933 .54658 .50072 .54518 .49445 .53117 Metetra
.564 .548 .794 r
.49445 .53117 .50072 .54518 .51216 .54511 .50589 .53128 Metetra
.533 .534 .801 r
.50589 .53128 .51216 .54511 .52368 .54608 .51741 .53255 Metetra
.508 .525 .809 r
.51741 .53255 .52368 .54608 .53528 .54774 .529 .53459 Metetra
.493 .523 .816 r
.529 .53459 .53528 .54774 .54697 .54974 .54069 .53702 Metetra
.489 .528 .824 r
.54069 .53702 .54697 .54974 .55874 .55173 .55247 .53946 Metetra
.497 .541 .832 r
.55247 .53946 .55874 .55173 .5706 .55338 .56434 .54154 Metetra
.517 .56 .839 r
.56434 .54154 .5706 .55338 .58254 .55438 .57629 .54293 Metetra
.546 .582 .843 r
.57629 .54293 .58254 .55438 .59454 .55448 .58831 .54333 Metetra
.58 .606 .843 r
.58831 .54333 .59454 .55448 .60659 .55347 .60038 .54252 Metetra
.617 .628 .839 r
.60038 .54252 .60659 .55347 .61868 .55119 .61248 .54033 Metetra
.652 .646 .831 r
.61248 .54033 .61868 .55119 .63078 .54759 .62461 .53669 Metetra
.682 .659 .821 r
.62461 .53669 .63078 .54759 .6429 .54264 .63674 .53159 Metetra
.706 .667 .809 r
.63674 .53159 .6429 .54264 .655 .53642 .64886 .5251 Metetra
.724 .67 .797 r
.64886 .5251 .655 .53642 .6671 .52907 .66097 .51738 Metetra
.736 .67 .785 r
.66097 .51738 .6671 .52907 .67918 .52079 .67306 .50864 Metetra
.742 .666 .776 r
.67306 .50864 .67918 .52079 .69124 .51184 .68512 .49918 Metetra
.743 .66 .769 r
.68512 .49918 .69124 .51184 .7033 .50251 .69718 .48934 Metetra
.739 .653 .764 r
.69718 .48934 .7033 .50251 .71537 .49316 .70925 .47947 Metetra
.731 .643 .761 r
.70925 .47947 .71537 .49316 .72747 .48412 .72135 .46997 Metetra
.718 .632 .761 r
.72135 .46997 .72747 .48412 .73964 .47577 .7335 .46125 Metetra
.7 .62 .764 r
.7335 .46125 .73964 .47577 .75189 .46845 .74576 .45368 Metetra
.677 .606 .769 r
.74576 .45368 .75189 .46845 .76427 .4625 .75815 .44762 Metetra
.648 .59 .776 r
.75815 .44762 .76427 .4625 .77682 .45817 .77071 .44337 Metetra
.612 .572 .786 r
.77071 .44337 .77682 .45817 .78957 .45569 .78349 .44117 Metetra
.567 .552 .797 r
.78349 .44117 .78957 .45569 .80255 .45517 .79652 .44114 Metetra
.513 .528 .81 r
.79652 .44114 .80255 .45517 .81579 .45663 .80983 .44331 Metetra
.449 .503 .822 r
.80983 .44331 .81579 .45663 .82931 .45993 .82344 .44753 Metetra
.378 .477 .835 r
.82344 .44753 .82931 .45993 .84309 .46476 .83734 .45346 Metetra
.307 .456 .846 r
.83734 .45346 .84309 .46476 .8571 .47061 .85148 .46052 Metetra
.255 .452 .861 r
.85148 .46052 .8571 .47061 .87128 .4767 .86581 .46786 Metetra
.249 .482 .885 r
.86581 .46786 .87128 .4767 .88551 .48195 .8802 .47429 Metetra
.329 .568 .926 r
.8802 .47429 .88551 .48195 .89963 .48494 .89446 .47822 Metetra
.52 .709 .957 r
.89446 .47822 .89963 .48494 .91339 .48387 .90833 .47768 Metetra
.752 .823 .907 r
.90833 .47768 .91339 .48387 .92648 .47659 .92146 .47024 Metetra
.899 .839 .778 r
.92146 .47024 .92648 .47659 .9385 .46056 .93342 .45311 Metetra
.567 .045 0 r
.32906 .62548 .33596 .63155 .3463 .6407 .33934 .63578 Metetra
.43 .715 .984 r
.33934 .63578 .3463 .6407 .35721 .64068 .35026 .63604 Metetra
.763 .813 .892 r
.35026 .63604 .35721 .64068 .36848 .63411 .36159 .6291 Metetra
.831 .796 .818 r
.36159 .6291 .36848 .63411 .37996 .62324 .37315 .61746 Metetra
.846 .774 .782 r
.37315 .61746 .37996 .62324 .39153 .60996 .38481 .60317 Metetra
.843 .754 .765 r
.38481 .60317 .39153 .60996 .40311 .59575 .39648 .58788 Metetra
.83 .735 .759 r
.39648 .58788 .40311 .59575 .41466 .58175 .40811 .57283 Metetra
.812 .717 .76 r
.40811 .57283 .41466 .58175 .42616 .56881 .41968 .55894 Metetra
.788 .698 .765 r
.41968 .55894 .42616 .56881 .4376 .55749 .43118 .54683 Metetra
.759 .679 .774 r
.43118 .54683 .4376 .55749 .44899 .54812 .44261 .53685 Metetra
.724 .659 .784 r
.44261 .53685 .44899 .54812 .46035 .54086 .454 .52919 Metetra
.685 .638 .796 r
.454 .52919 .46035 .54086 .4717 .53571 .46536 .52383 Metetra
.641 .616 .809 r
.46536 .52383 .4717 .53571 .48306 .53255 .47673 .52065 Metetra
.595 .594 .821 r
.47673 .52065 .48306 .53255 .49445 .53117 .48813 .51942 Metetra
.547 .573 .833 r
.48813 .51942 .49445 .53117 .50589 .53128 .49958 .51981 Metetra
.502 .556 .844 r
.49958 .51981 .50589 .53128 .51741 .53255 .5111 .52147 Metetra
.463 .545 .854 r
.5111 .52147 .51741 .53255 .529 .53459 .5227 .52398 Metetra
.437 .541 .865 r
.5227 .52398 .529 .53459 .54069 .53702 .5344 .52693 Metetra
.426 .548 .876 r
.5344 .52693 .54069 .53702 .55247 .53946 .54619 .52989 Metetra
.434 .566 .888 r
.54619 .52989 .55247 .53946 .56434 .54154 .55808 .53246 Metetra
.461 .593 .898 r
.55808 .53246 .56434 .54154 .57629 .54293 .57005 .53427 Metetra
.503 .627 .906 r
.57005 .53427 .57629 .54293 .58831 .54333 .58209 .53501 Metetra
.555 .661 .907 r
.58209 .53501 .58831 .54333 .60038 .54252 .59419 .53443 Metetra
.608 .691 .901 r
.59419 .53443 .60038 .54252 .61248 .54033 .60633 .53235 Metetra
.658 .713 .889 r
.60633 .53235 .61248 .54033 .62461 .53669 .61848 .52868 Metetra
.7 .728 .872 r
.61848 .52868 .62461 .53669 .63674 .53159 .63065 .52341 Metetra
.731 .734 .853 r
.63065 .52341 .63674 .53159 .64886 .5251 .6428 .51663 Metetra
.754 .734 .835 r
.6428 .51663 .64886 .5251 .66097 .51738 .65492 .5085 Metetra
.768 .73 .818 r
.65492 .5085 .66097 .51738 .67306 .50864 .66703 .49927 Metetra
.774 .723 .805 r
.66703 .49927 .67306 .50864 .68512 .49918 .67911 .48925 Metetra
.775 .714 .795 r
.67911 .48925 .68512 .49918 .69718 .48934 .69117 .47881 Metetra
.769 .702 .788 r
.69117 .47881 .69718 .48934 .70925 .47947 .70324 .46836 Metetra
.759 .69 .785 r
.70324 .46836 .70925 .47947 .72135 .46997 .71534 .45832 Metetra
.743 .676 .786 r
.71534 .45832 .72135 .46997 .7335 .46125 .7275 .44912 Metetra
.721 .661 .789 r
.7275 .44912 .7335 .46125 .74576 .45368 .73976 .44119 Metetra
.693 .643 .795 r
.73976 .44119 .74576 .45368 .75815 .44762 .75215 .43492 Metetra
.656 .623 .805 r
.75215 .43492 .75815 .44762 .77071 .44337 .76473 .43062 Metetra
.61 .6 .816 r
.76473 .43062 .77071 .44337 .78349 .44117 .77754 .42856 Metetra
.552 .572 .828 r
.77754 .42856 .78349 .44117 .79652 .44114 .79062 .42888 Metetra
.48 .538 .84 r
.79062 .42888 .79652 .44114 .80983 .44331 .80399 .4316 Metetra
.394 .5 .848 r
.80399 .4316 .80983 .44331 .82344 .44753 .81768 .43656 Metetra
.3 .46 .852 r
.81768 .43656 .82344 .44753 .83734 .45346 .83167 .44341 Metetra
.21 .425 .852 r
.83167 .44341 .83734 .45346 .85148 .46052 .84594 .4515 Metetra
.147 .411 .855 r
.84594 .4515 .85148 .46052 .86581 .46786 .86041 .4599 Metetra
.145 .442 .876 r
.86041 .4599 .86581 .46786 .8802 .47429 .87493 .46732 Metetra
.25 .545 .926 r
.87493 .46732 .8802 .47429 .89446 .47822 .88931 .47201 Metetra
.489 .713 .97 r
.88931 .47201 .89446 .47822 .90833 .47768 .90326 .47179 Metetra
.761 .838 .91 r
.90326 .47179 .90833 .47768 .92146 .47024 .91641 .464 Metetra
.91 .842 .765 r
.91641 .464 .92146 .47024 .93342 .45311 .92829 .4456 Metetra
.653 .137 0 r
.32212 .61937 .32906 .62548 .33934 .63578 .33232 .631 Metetra
.379 .698 .983 r
.33232 .631 .33934 .63578 .35026 .63604 .34324 .63171 Metetra
.768 .825 .897 r
.34324 .63171 .35026 .63604 .36159 .6291 .35462 .62461 Metetra
.843 .809 .817 r
.35462 .62461 .36159 .6291 .37315 .61746 .36625 .61238 Metetra
.859 .789 .78 r
.36625 .61238 .37315 .61746 .38481 .60317 .378 .59729 Metetra
.858 .771 .765 r
.378 .59729 .38481 .60317 .39648 .58788 .38976 .5811 Metetra
.848 .755 .761 r
.38976 .5811 .39648 .58788 .40811 .57283 .40148 .56518 Metetra
.831 .741 .765 r
.40148 .56518 .40811 .57283 .41968 .55894 .41312 .55052 Metetra
.808 .726 .774 r
.41312 .55052 .41968 .55894 .43118 .54683 .42467 .53779 Metetra
.779 .711 .788 r
.42467 .53779 .43118 .54683 .44261 .53685 .43615 .52737 Metetra
.742 .694 .806 r
.43615 .52737 .44261 .53685 .454 .52919 .44757 .51945 Metetra
.697 .676 .825 r
.44757 .51945 .454 .52919 .46536 .52383 .45896 .51403 Metetra
.643 .655 .846 r
.45896 .51403 .46536 .52383 .47673 .52065 .47034 .51096 Metetra
.581 .631 .866 r
.47034 .51096 .47673 .52065 .48813 .51942 .48175 .50999 Metetra
.511 .606 .884 r
.48175 .50999 .48813 .51942 .49958 .51981 .49321 .51078 Metetra
.439 .581 .898 r
.49321 .51078 .49958 .51981 .5111 .52147 .50474 .51294 Metetra
.373 .561 .908 r
.50474 .51294 .5111 .52147 .5227 .52398 .51636 .51602 Metetra
.321 .551 .917 r
.51636 .51602 .5227 .52398 .5344 .52693 .52807 .51956 Metetra
.293 .556 .926 r
.52807 .51956 .5344 .52693 .54619 .52989 .53988 .52311 Metetra
.296 .579 .939 r
.53988 .52311 .54619 .52989 .55808 .53246 .55179 .52624 Metetra
.331 .62 .956 r
.55179 .52624 .55808 .53246 .57005 .53427 .5638 .52854 Metetra
.396 .673 .971 r
.5638 .52854 .57005 .53427 .58209 .53501 .57588 .52966 Metetra
.48 .728 .98 r
.57588 .52966 .58209 .53501 .59419 .53443 .58801 .52934 Metetra
.568 .776 .977 r
.58801 .52934 .59419 .53443 .60633 .53235 .60019 .52738 Metetra
.648 .808 .96 r
.60019 .52738 .60633 .53235 .61848 .52868 .61239 .52368 Metetra
.711 .825 .935 r
.61239 .52368 .61848 .52868 .63065 .52341 .6246 .51824 Metetra
.757 .828 .907 r
.6246 .51824 .63065 .52341 .6428 .51663 .63678 .51114 Metetra
.787 .822 .88 r
.63678 .51114 .6428 .51663 .65492 .5085 .64895 .50257 Metetra
.805 .812 .856 r
.64895 .50257 .65492 .5085 .66703 .49927 .66108 .49279 Metetra
.813 .798 .838 r
.66108 .49279 .66703 .49927 .67911 .48925 .67318 .48215 Metetra
.813 .783 .825 r
.67318 .48215 .67911 .48925 .69117 .47881 .68527 .47105 Metetra
.807 .767 .817 r
.68527 .47105 .69117 .47881 .70324 .46836 .69735 .45993 Metetra
.794 .751 .813 r
.69735 .45993 .70324 .46836 .71534 .45832 .70946 .44925 Metetra
.775 .733 .814 r
.70946 .44925 .71534 .45832 .7275 .44912 .72162 .43948 Metetra
.749 .714 .82 r
.72162 .43948 .7275 .44912 .73976 .44119 .73388 .43108 Metetra
.714 .693 .829 r
.73388 .43108 .73976 .44119 .75215 .43492 .74629 .42446 Metetra
.668 .668 .841 r
.74629 .42446 .75215 .43492 .76473 .43062 .75889 .41999 Metetra
.609 .638 .854 r
.75889 .41999 .76473 .43062 .77754 .42856 .77172 .41793 Metetra
.532 .6 .867 r
.77172 .41793 .77754 .42856 .79062 .42888 .78483 .41844 Metetra
.437 .552 .875 r
.78483 .41844 .79062 .42888 .80399 .4316 .79826 .42155 Metetra
.323 .496 .874 r
.79826 .42155 .80399 .4316 .81768 .43656 .81202 .42709 Metetra
.202 .435 .862 r
.81202 .42709 .81768 .43656 .83167 .44341 .8261 .43467 Metetra
.092 .383 .843 r
.8261 .43467 .83167 .44341 .84594 .4515 .84048 .4436 Metetra
.022 .36 .832 r
.84048 .4436 .84594 .4515 .86041 .4599 .85505 .45287 Metetra
.031 .394 .852 r
.85505 .45287 .86041 .4599 .87493 .46732 .86969 .46107 Metetra
.167 .519 .917 r
.86969 .46107 .87493 .46732 .88931 .47201 .88417 .46631 Metetra
.464 .722 .981 r
.88417 .46631 .88931 .47201 .90326 .47179 .89819 .46621 Metetra
.775 .853 .909 r
.89819 .46621 .90326 .47179 .91641 .464 .91134 .45789 Metetra
.922 .844 .749 r
.91134 .45789 .91641 .464 .92829 .4456 .92311 .43803 Metetra
.726 .221 0 r
.31512 .61321 .32212 .61937 .33232 .631 .32523 .62633 Metetra
.302 .666 .973 r
.32523 .62633 .33232 .631 .34324 .63171 .33614 .62768 Metetra
.769 .836 .904 r
.33614 .62768 .34324 .63171 .35462 .62461 .34755 .6206 Metetra
.851 .821 .819 r
.34755 .6206 .35462 .62461 .36625 .61238 .35926 .60799 Metetra
.871 .802 .78 r
.35926 .60799 .36625 .61238 .378 .59729 .3711 .59227 Metetra
.872 .787 .765 r
.3711 .59227 .378 .59729 .38976 .5811 .38295 .57538 Metetra
.863 .775 .763 r
.38295 .57538 .38976 .5811 .40148 .56518 .39475 .55877 Metetra
.849 .765 .77 r
.39475 .55877 .40148 .56518 .41312 .55052 .40646 .54352 Metetra
.827 .755 .784 r
.40646 .54352 .41312 .55052 .42467 .53779 .41807 .53032 Metetra
.798 .746 .804 r
.41807 .53032 .42467 .53779 .43615 .52737 .4296 .51962 Metetra
.759 .735 .83 r
.4296 .51962 .43615 .52737 .44757 .51945 .44105 .51159 Metetra
.707 .721 .861 r
.44105 .51159 .44757 .51945 .45896 .51403 .45247 .50624 Metetra
.637 .702 .893 r
.45247 .50624 .45896 .51403 .47034 .51096 .46388 .50341 Metetra
.547 .675 .922 r
.46388 .50341 .47034 .51096 .48175 .50999 .4753 .50283 Metetra
.436 .638 .941 r
.4753 .50283 .48175 .50999 .49321 .51078 .48678 .50413 Metetra
.31 .591 .944 r
.48678 .50413 .49321 .51078 .50474 .51294 .49832 .50688 Metetra
.186 .542 .928 r
.49832 .50688 .50474 .51294 .51636 .51602 .50995 .51062 Metetra
.085 .503 .901 r
.50995 .51062 .51636 .51602 .52807 .51956 .52169 .51485 Metetra
.023 .487 .877 r
.52169 .51485 .52807 .51956 .53988 .52311 .53353 .51907 Metetra
.011 .503 .869 r
.53353 .51907 .53988 .52311 .55179 .52624 .54548 .52282 Metetra
.051 .553 .882 r
.54548 .52282 .55179 .52624 .5638 .52854 .55752 .52565 Metetra
.141 .633 .914 r
.55752 .52565 .5638 .52854 .57588 .52966 .56965 .5272 Metetra
.273 .731 .953 r
.56965 .5272 .57588 .52966 .58801 .52934 .58183 .52717 Metetra
.424 .823 .981 r
.58183 .52717 .58801 .52934 .60019 .52738 .59407 .52534 Metetra
.566 .891 .987 r
.59407 .52534 .60019 .52738 .61239 .52368 .60632 .52162 Metetra
.68 .925 .971 r
.60632 .52162 .61239 .52368 .6246 .51824 .61858 .51599 Metetra
.759 .932 .943 r
.61858 .51599 .6246 .51824 .63678 .51114 .63081 .50855 Metetra
.809 .923 .912 r
.63081 .50855 .63678 .51114 .64895 .50257 .64302 .4995 Metetra
.837 .906 .885 r
.64302 .4995 .64895 .50257 .66108 .49279 .65519 .48913 Metetra
.85 .886 .864 r
.65519 .48913 .66108 .49279 .67318 .48215 .66733 .47781 Metetra
.853 .865 .85 r
.66733 .47781 .67318 .48215 .68527 .47105 .67944 .46598 Metetra
.846 .844 .842 r
.67944 .46598 .68527 .47105 .69735 .45993 .69155 .4541 Metetra
.833 .823 .84 r
.69155 .4541 .69735 .45993 .70946 .44925 .70367 .4427 Metetra
.811 .803 .843 r
.70367 .4427 .70946 .44925 .72162 .43948 .71585 .43226 Metetra
.781 .78 .852 r
.71585 .43226 .72162 .43948 .73388 .43108 .72812 .42328 Metetra
.739 .755 .866 r
.72812 .42328 .73388 .43108 .74629 .42446 .74054 .4162 Metetra
.683 .725 .882 r
.74054 .4162 .74629 .42446 .75889 .41999 .75316 .41142 Metetra
.607 .687 .899 r
.75316 .41142 .75889 .41999 .77172 .41793 .76601 .40922 Metetra
.507 .635 .911 r
.76601 .40922 .77172 .41793 .78483 .41844 .77916 .40979 Metetra
.38 .568 .911 r
.77916 .40979 .78483 .41844 .79826 .42155 .79263 .41313 Metetra
.233 .486 .892 r
.79263 .41313 .79826 .42155 .81202 .42709 .80645 .41908 Metetra
.083 .4 .855 r
.80645 .41908 .81202 .42709 .8261 .43467 .82061 .4272 Metetra
0 .329 .812 r
.82061 .4272 .8261 .43467 .84048 .4436 .83507 .43679 Metetra
0 .3 .788 r
.83507 .43679 .84048 .4436 .85505 .45287 .84975 .44674 Metetra
0 .342 .81 r
.84975 .44674 .85505 .45287 .86969 .46107 .86448 .45553 Metetra
.088 .492 .899 r
.86448 .45553 .86969 .46107 .88417 .46631 .87905 .46111 Metetra
.446 .734 .988 r
.87905 .46111 .88417 .46631 .89819 .46621 .89311 .46093 Metetra
.792 .869 .905 r
.89311 .46093 .89819 .46621 .91134 .45789 .90624 .45188 Metetra
.933 .845 .732 r
.90624 .45188 .91134 .45789 .92311 .43803 .91789 .43038 Metetra
.783 .294 0 r
.30806 .607 .31512 .61321 .32523 .62633 .31807 .62176 Metetra
.198 .612 .947 r
.31807 .62176 .32523 .62633 .33614 .62768 .32895 .62392 Metetra
.764 .847 .913 r
.32895 .62392 .33614 .62768 .34755 .6206 .3404 .61704 Metetra
.858 .833 .821 r
.3404 .61704 .34755 .6206 .35926 .60799 .35218 .60422 Metetra
.88 .815 .78 r
.35218 .60422 .35926 .60799 .3711 .59227 .36409 .58806 Metetra
.883 .803 .765 r
.36409 .58806 .3711 .59227 .38295 .57538 .37603 .57064 Metetra
.877 .794 .765 r
.37603 .57064 .38295 .57538 .39475 .55877 .38791 .55351 Metetra
.864 .789 .775 r
.38791 .55351 .39475 .55877 .40646 .54352 .3997 .53782 Metetra
.844 .785 .794 r
.3997 .53782 .40646 .54352 .41807 .53032 .41137 .52432 Metetra
.815 .782 .821 r
.41137 .52432 .41807 .53032 .4296 .51962 .42295 .51347 Metetra
.773 .778 .857 r
.42295 .51347 .4296 .51962 .44105 .51159 .43445 .50547 Metetra
.71 .771 .9 r
.43445 .50547 .44105 .51159 .45247 .50624 .44589 .50032 Metetra
.614 .753 .944 r
.44589 .50032 .45247 .50624 .46388 .50341 .45732 .49784 Metetra
.473 .713 .975 r
.45732 .49784 .46388 .50341 .4753 .50283 .46877 .49776 Metetra
.283 .638 .965 r
.46877 .49776 .4753 .50283 .48678 .50413 .48026 .49967 Metetra
.069 .529 .898 r
.48026 .49967 .48678 .50413 .49832 .50688 .49182 .50312 Metetra
0 .414 .791 r
.49182 .50312 .49832 .50688 .50995 .51062 .50348 .50761 Metetra
0 .325 .682 r
.50348 .50761 .50995 .51062 .52169 .51485 .51525 .51259 Metetra
.314 0 0 r
.51525 .51259 .52169 .51485 .53353 .51907 .52712 .51755 Metetra
.324 0 0 r
.52712 .51755 .53353 .51907 .54548 .52282 .53911 .52198 Metetra
.284 0 0 r
.53911 .52198 .54548 .52282 .55752 .52565 .5512 .5254 Metetra
.195 0 0 r
.5512 .5254 .55752 .52565 .56965 .5272 .56338 .52741 Metetra
.055 0 0 r
.56338 .52741 .56965 .5272 .58183 .52717 .57563 .52769 Metetra
.131 .679 .743 r
.57563 .52769 .58183 .52717 .59407 .52534 .58792 .52602 Metetra
.34 .821 .822 r
.58792 .52602 .59407 .52534 .60632 .52162 .60024 .52228 Metetra
.534 .924 .873 r
.60024 .52228 .60632 .52162 .61858 .51599 .61256 .51645 Metetra
.681 .977 .891 r
.61256 .51645 .61858 .51599 .63081 .50855 .62486 .50865 Metetra
.779 .991 .887 r
.62486 .50865 .63081 .50855 .64302 .4995 .63712 .49908 Metetra
.836 .982 .874 r
.63712 .49908 .64302 .4995 .65519 .48913 .64935 .48807 Metetra
.866 .964 .862 r
.64935 .48807 .65519 .48913 .66733 .47781 .66153 .47602 Metetra
.878 .942 .853 r
.66153 .47602 .66733 .47781 .67944 .46598 .67368 .46339 Metetra
.878 .92 .85 r
.67368 .46339 .67944 .46598 .69155 .4541 .68581 .45069 Metetra
.866 .898 .854 r
.68581 .45069 .69155 .4541 .70367 .4427 .69796 .43847 Metetra
.845 .876 .864 r
.69796 .43847 .70367 .4427 .71585 .43226 .71016 .42726 Metetra
.813 .853 .879 r
.71016 .42726 .71585 .43226 .72812 .42328 .72245 .4176 Metetra
.765 .827 .9 r
.72245 .4176 .72812 .42328 .74054 .4162 .73488 .40996 Metetra
.698 .792 .923 r
.73488 .40996 .74054 .4162 .75316 .41142 .74752 .40476 Metetra
.603 .744 .944 r
.74752 .40476 .75316 .41142 .76601 .40922 .7604 .4023 Metetra
.473 .675 .953 r
.7604 .4023 .76601 .40922 .77916 .40979 .77357 .40277 Metetra
.308 .581 .938 r
.77357 .40277 .77916 .40979 .79263 .41313 .78709 .4062 Metetra
.124 .467 .892 r
.78709 .4062 .79263 .41313 .80645 .41908 .80096 .4124 Metetra
0 .353 .823 r
.80096 .4124 .80645 .41908 .82061 .4272 .81519 .42092 Metetra
0 .268 .757 r
.81519 .42092 .82061 .4272 .83507 .43679 .82972 .43099 Metetra
0 .238 .725 r
.82972 .43099 .83507 .43679 .84975 .44674 .84448 .44143 Metetra
0 .291 .757 r
.84448 .44143 .84975 .44674 .86448 .45553 .8593 .45062 Metetra
.019 .468 .874 r
.8593 .45062 .86448 .45553 .87905 .46111 .87392 .45637 Metetra
.439 .75 .994 r
.87392 .45637 .87905 .46111 .89311 .46093 .88802 .45592 Metetra
.812 .883 .896 r
.88802 .45592 .89311 .46093 .90624 .45188 .90111 .44596 Metetra
.943 .844 .715 r
.90111 .44596 .90624 .45188 .91789 .43038 .91263 .42268 Metetra
.825 .354 0 r
.30095 .60075 .30806 .607 .31807 .62176 .31084 .61726 Metetra
.066 .534 .897 r
.31084 .61726 .31807 .62176 .32895 .62392 .32168 .62038 Metetra
.755 .856 .925 r
.32168 .62038 .32895 .62392 .3404 .61704 .33316 .61384 Metetra
.862 .844 .825 r
.33316 .61384 .3404 .61704 .35218 .60422 .34499 .60098 Metetra
.887 .827 .782 r
.34499 .60098 .35218 .60422 .36409 .58806 .35699 .58454 Metetra
.892 .816 .766 r
.35699 .58454 .36409 .58806 .37603 .57064 .36901 .56674 Metetra
.888 .811 .767 r
.36901 .56674 .37603 .57064 .38791 .55351 .38098 .54924 Metetra
.877 .81 .779 r
.38098 .54924 .38791 .55351 .3997 .53782 .39283 .53325 Metetra
.858 .812 .803 r
.39283 .53325 .3997 .53782 .41137 .52432 .40457 .51959 Metetra
.829 .817 .838 r
.40457 .51959 .41137 .52432 .42295 .51347 .4162 .50872 Metetra
.781 .822 .884 r
.4162 .50872 .42295 .51347 .43445 .50547 .42774 .50087 Metetra
.7 .821 .94 r
.42774 .50087 .43445 .50547 .44589 .50032 .43922 .49602 Metetra
.56 .797 .988 r
.43922 .49602 .44589 .50032 .45732 .49784 .45067 .494 Metetra
.331 .714 .983 r
.45067 .494 .45732 .49784 .46877 .49776 .46214 .49451 Metetra
.035 .549 .871 r
.46214 .49451 .46877 .49776 .48026 .49967 .47365 .49712 Metetra
0 .354 .68 r
.47365 .49712 .48026 .49967 .49182 .50312 .48524 .50135 Metetra
.398 0 0 r
.48524 .50135 .49182 .50312 .50348 .50761 .49692 .50666 Metetra
.485 0 0 r
.49692 .50666 .50348 .50761 .51525 .51259 .50872 .51247 Metetra
.516 0 0 r
.50872 .51247 .51525 .51259 .52712 .51755 .52064 .51823 Metetra
.508 0 0 r
.52064 .51823 .52712 .51755 .53911 .52198 .53267 .52339 Metetra
.468 0 0 r
.53267 .52339 .53911 .52198 .5512 .5254 .54482 .52744 Metetra
.395 0 0 r
.54482 .52744 .5512 .5254 .56338 .52741 .55706 .52995 Metetra
.282 0 0 r
.55706 .52995 .56338 .52741 .57563 .52769 .56938 .53058 Metetra
.124 0 0 r
.56938 .53058 .57563 .52769 .58792 .52602 .58174 .52907 Metetra
.58174 .52907 .58792 .52602 .60024 .52228 .59413 .5253 Metetra
.59413 .5253 .60024 .52228 .61256 .51645 .60653 .51927 Metetra
.512 .893 .716 r
.60653 .51927 .61256 .51645 .62486 .50865 .6189 .51108 Metetra
.672 .967 .769 r
.6189 .51108 .62486 .50865 .63712 .49908 .63123 .50098 Metetra
.778 .996 .797 r
.63123 .50098 .63712 .49908 .64935 .48807 .64351 .48929 Metetra
.841 .999 .811 r
.64351 .48929 .64935 .48807 .66153 .47602 .65575 .47645 Metetra
.874 .989 .82 r
.65575 .47645 .66153 .47602 .67368 .46339 .66795 .46296 Metetra
.887 .974 .83 r
.66795 .46296 .67368 .46339 .68581 .45069 .68012 .44937 Metetra
.884 .957 .844 r
.68012 .44937 .68581 .45069 .69796 .43847 .6923 .43626 Metetra
.868 .94 .864 r
.6923 .43626 .69796 .43847 .71016 .42726 .70452 .42422 Metetra
.837 .92 .89 r
.70452 .42422 .71016 .42726 .72245 .4176 .71684 .41379 Metetra
.787 .895 .921 r
.71684 .41379 .72245 .4176 .73488 .40996 .72929 .40549 Metetra
.709 .86 .954 r
.72929 .40549 .73488 .40996 .74752 .40476 .74194 .39975 Metetra
.593 .803 .98 r
.74194 .39975 .74752 .40476 .7604 .4023 .75485 .39692 Metetra
.43 .713 .983 r
.75485 .39692 .7604 .4023 .77357 .40277 .76805 .39718 Metetra
.225 .585 .945 r
.76805 .39718 .77357 .40277 .78709 .4062 .7816 .40057 Metetra
.011 .436 .865 r
.7816 .40057 .78709 .4062 .80096 .4124 .79552 .40688 Metetra
0 .3 .767 r
.79552 .40688 .80096 .4124 .81519 .42092 .80981 .41565 Metetra
0 .209 .688 r
.80981 .41565 .81519 .42092 .82972 .43099 .82441 .42605 Metetra
0 .182 .657 r
.82441 .42605 .82972 .43099 .84448 .44143 .83924 .43683 Metetra
0 .246 .703 r
.83924 .43683 .84448 .44143 .8593 .45062 .85412 .44625 Metetra
0 .45 .849 r
.85412 .44625 .8593 .45062 .87392 .45637 .86879 .452 Metetra
.444 .77 .997 r
.86879 .452 .87392 .45637 .88802 .45592 .8829 .45113 Metetra
.834 .894 .883 r
.8829 .45113 .88802 .45592 .90111 .44596 .89594 .4401 Metetra
.952 .841 .697 r
.89594 .4401 .90111 .44596 .91263 .42268 .90732 .41491 Metetra
.856 .403 .035 r
.29379 .59444 .30095 .60075 .31084 .61726 .30353 .6128 Metetra
0 .43 .817 r
.30353 .6128 .31084 .61726 .32168 .62038 .31434 .61698 Metetra
.739 .862 .938 r
.31434 .61698 .32168 .62038 .33316 .61384 .32583 .61093 Metetra
.864 .853 .83 r
.32583 .61093 .33316 .61384 .34499 .60098 .33772 .59815 Metetra
.893 .836 .783 r
.33772 .59815 .34499 .60098 .35699 .58454 .34979 .58156 Metetra
.899 .827 .767 r
.34979 .58156 .35699 .58454 .36901 .56674 .36189 .56351 Metetra
.896 .825 .769 r
.36189 .56351 .36901 .56674 .38098 .54924 .37394 .54577 Metetra
.887 .828 .784 r
.37394 .54577 .38098 .54924 .39283 .53325 .38587 .52961 Metetra
.869 .836 .811 r
.38587 .52961 .39283 .53325 .40457 .51959 .39767 .51588 Metetra
.838 .848 .853 r
.39767 .51588 .40457 .51959 .4162 .50872 .40935 .5051 Metetra
.782 .862 .909 r
.40935 .5051 .4162 .50872 .42774 .50087 .42093 .49749 Metetra
.673 .863 .972 r
.42093 .49749 .42774 .50087 .43922 .49602 .43244 .49304 Metetra
.461 .81 .998 r
.43244 .49304 .43922 .49602 .45067 .494 .44392 .49157 Metetra
.122 .635 .894 r
.44392 .49157 .45067 .494 .46214 .49451 .45541 .49274 Metetra
.22 0 0 r
.45541 .49274 .46214 .49451 .47365 .49712 .46695 .49612 Metetra
.437 0 0 r
.46695 .49612 .47365 .49712 .48524 .50135 .47856 .5012 Metetra
.546 0 0 r
.47856 .5012 .48524 .50135 .49692 .50666 .49027 .50738 Metetra
.593 .035 0 r
.49027 .50738 .49692 .50666 .50872 .51247 .50211 .51408 Metetra
.602 .059 0 r
.50211 .51408 .50872 .51247 .52064 .51823 .51407 .52069 Metetra
.586 .052 0 r
.51407 .52069 .52064 .51823 .53267 .52339 .52615 .52662 Metetra
.547 .017 0 r
.52615 .52662 .53267 .52339 .54482 .52744 .53836 .53134 Metetra
.483 0 0 r
.53836 .53134 .54482 .52744 .55706 .52995 .55066 .53438 Metetra
.39 0 0 r
.55066 .53438 .55706 .52995 .56938 .53058 .56305 .53536 Metetra
.259 0 0 r
.56305 .53536 .56938 .53058 .58174 .52907 .5755 .53404 Metetra
.086 0 0 r
.5755 .53404 .58174 .52907 .59413 .5253 .58797 .53025 Metetra
.58797 .53025 .59413 .5253 .60653 .51927 .60045 .524 Metetra
.60045 .524 .60653 .51927 .6189 .51108 .6129 .51542 Metetra
.541 .877 .616 r
.6129 .51542 .6189 .51108 .63123 .50098 .62531 .50474 Metetra
.688 .95 .683 r
.62531 .50474 .63123 .50098 .64351 .48929 .63766 .49234 Metetra
.785 .984 .726 r
.63766 .49234 .64351 .48929 .65575 .47645 .64996 .47868 Metetra
.843 .995 .757 r
.64996 .47868 .65575 .47645 .66795 .46296 .66222 .46428 Metetra
.873 .994 .784 r
.66222 .46428 .66795 .46296 .68012 .44937 .67444 .44975 Metetra
.882 .988 .81 r
.67444 .44975 .68012 .44937 .6923 .43626 .68666 .4357 Metetra
.874 .979 .841 r
.68666 .4357 .6923 .43626 .70452 .42422 .69891 .42274 Metetra
.848 .966 .878 r
.69891 .42274 .70452 .42422 .71684 .41379 .71125 .41147 Metetra
.798 .948 .92 r
.71125 .41147 .71684 .41379 .72929 .40549 .72373 .40243 Metetra
.714 .914 .963 r
.72373 .40243 .72929 .40549 .74194 .39975 .73641 .39609 Metetra
.579 .851 .995 r
.73641 .39609 .74194 .39975 .75485 .39692 .74934 .39279 Metetra
.384 .74 .991 r
.74934 .39279 .75485 .39692 .76805 .39718 .76257 .39275 Metetra
.145 .579 .929 r
.76257 .39275 .76805 .39718 .7816 .40057 .77615 .39599 Metetra
0 .401 .819 r
.77615 .39599 .7816 .40057 .79552 .40688 .79011 .40231 Metetra
0 .251 .703 r
.79011 .40231 .79552 .40688 .80981 .41565 .80445 .4112 Metetra
0 .16 .621 r
.80445 .4112 .80981 .41565 .82441 .42605 .81911 .4218 Metetra
0 .139 .597 r
.81911 .4218 .82441 .42605 .83924 .43683 .83399 .43278 Metetra
0 .214 .657 r
.83399 .43278 .83924 .43683 .85412 .44625 .84893 .4423 Metetra
0 .442 .83 r
.84893 .4423 .85412 .44625 .86879 .452 .86364 .44791 Metetra
.462 .792 .999 r
.86364 .44791 .86879 .452 .8829 .45113 .87775 .44647 Metetra
.855 .9 .867 r
.87775 .44647 .8829 .45113 .89594 .4401 .89073 .43427 Metetra
.959 .838 .679 r
.89073 .43427 .89594 .4401 .90732 .41491 .90197 .40707 Metetra
.878 .441 .092 r
.28657 .58809 .29379 .59444 .30353 .6128 .29616 .60835 Metetra
0 .311 .714 r
.29616 .60835 .30353 .6128 .31434 .61698 .30691 .61367 Metetra
.718 .865 .951 r
.30691 .61367 .31434 .61698 .32583 .61093 .31841 .60819 Metetra
.863 .859 .835 r
.31841 .60819 .32583 .61093 .33772 .59815 .33035 .59559 Metetra
.895 .843 .785 r
.33035 .59559 .33772 .59815 .34979 .58156 .3425 .57896 Metetra
.903 .835 .768 r
.3425 .57896 .34979 .58156 .36189 .56351 .35468 .56076 Metetra
.902 .835 .77 r
.35468 .56076 .36189 .56351 .37394 .54577 .3668 .54287 Metetra
.893 .842 .787 r
.3668 .54287 .37394 .54577 .38587 .52961 .37881 .52663 Metetra
.876 .854 .818 r
.37881 .52663 .38587 .52961 .39767 .51588 .39067 .51293 Metetra
.842 .873 .865 r
.39067 .51293 .39767 .51588 .40935 .5051 .4024 .50232 Metetra
.774 .892 .928 r
.4024 .50232 .40935 .5051 .42093 .49749 .41402 .49502 Metetra
.626 .886 .988 r
.41402 .49502 .42093 .49749 .43244 .49304 .42556 .49103 Metetra
.325 .774 .958 r
.42556 .49103 .43244 .49304 .44392 .49157 .43707 .49016 Metetra
0 .498 .733 r
.43707 .49016 .44392 .49157 .45541 .49274 .44859 .49206 Metetra
.391 0 0 r
.44859 .49206 .45541 .49274 .46695 .49612 .46014 .49626 Metetra
.547 0 0 r
.46014 .49626 .46695 .49612 .47856 .5012 .47178 .50222 Metetra
.617 .071 0 r
.47178 .50222 .47856 .5012 .49027 .50738 .48352 .50933 Metetra
.642 .118 0 r
.48352 .50933 .49027 .50738 .50211 .51408 .49539 .51695 Metetra
.642 .132 .019 r
.49539 .51695 .50211 .51408 .51407 .52069 .5074 .52444 Metetra
.622 .121 .038 r
.5074 .52444 .51407 .52069 .52615 .52662 .51953 .53117 Metetra
.584 .086 .037 r
.51953 .53117 .52615 .52662 .53836 .53134 .5318 .53658 Metetra
.526 .029 .018 r
.5318 .53658 .53836 .53134 .55066 .53438 .54418 .54017 Metetra
.442 0 0 r
.54418 .54017 .55066 .53438 .56305 .53536 .55665 .54153 Metetra
.325 0 0 r
.55665 .54153 .56305 .53536 .5755 .53404 .56918 .54038 Metetra
.168 0 0 r
.56918 .54038 .5755 .53404 .58797 .53025 .58174 .53658 Metetra
.58174 .53658 .58797 .53025 .60045 .524 .5943 .53012 Metetra
.5943 .53012 .60045 .524 .6129 .51542 .60684 .52112 Metetra
.60684 .52112 .6129 .51542 .62531 .50474 .61934 .50986 Metetra
.617 .895 .587 r
.61934 .50986 .62531 .50474 .63766 .49234 .63177 .49672 Metetra
.735 .952 .649 r
.63177 .49672 .63766 .49234 .64996 .47868 .64414 .4822 Metetra
.81 .98 .694 r
.64414 .4822 .64996 .47868 .66222 .46428 .65646 .46687 Metetra
.853 .991 .732 r
.65646 .46687 .66222 .46428 .67444 .44975 .66873 .45136 Metetra
.872 .994 .767 r
.66873 .45136 .67444 .44975 .68666 .4357 .681 .43632 Metetra
.871 .993 .806 r
.681 .43632 .68666 .4357 .69891 .42274 .6933 .42241 Metetra
.85 .989 .85 r
.6933 .42241 .69891 .42274 .71125 .41147 .70567 .41026 Metetra
.803 .977 .901 r
.70567 .41026 .71125 .41147 .72373 .40243 .71818 .40043 Metetra
.716 .949 .953 r
.71818 .40043 .72373 .40243 .73641 .39609 .73088 .39341 Metetra
.569 .884 .991 r
.73088 .39341 .73641 .39609 .74934 .39279 .74383 .38959 Metetra
.35 .757 .982 r
.74383 .38959 .74934 .39279 .76257 .39275 .75709 .38917 Metetra
.085 .57 .901 r
.75709 .38917 .76257 .39275 .77615 .39599 .77071 .39218 Metetra
0 .372 .772 r
.77071 .39218 .77615 .39599 .79011 .40231 .78471 .39841 Metetra
0 .216 .649 r
.78471 .39841 .79011 .40231 .80445 .4112 .79908 .40733 Metetra
.418 0 0 r
.79908 .40733 .80445 .4112 .81911 .4218 .81379 .41803 Metetra
.435 0 0 r
.81379 .41803 .81911 .4218 .83399 .43278 .82873 .42911 Metetra
0 .195 .626 r
.82873 .42911 .83399 .43278 .84893 .4423 .84371 .43862 Metetra
0 .445 .822 r
.84371 .43862 .84893 .4423 .86364 .44791 .85845 .44398 Metetra
.491 .815 1 r
.85845 .44398 .86364 .44791 .87775 .44647 .87255 .44189 Metetra
.874 .903 .848 r
.87255 .44189 .87775 .44647 .89073 .43427 .88548 .42842 Metetra
.965 .833 .662 r
.88548 .42842 .89073 .43427 .90197 .40707 .89657 .39916 Metetra
.894 .471 .139 r
.27929 .58169 .28657 .58809 .29616 .60835 .28873 .60385 Metetra
.37 0 0 r
.28873 .60385 .29616 .60835 .30691 .61367 .29941 .61035 Metetra
.691 .864 .964 r
.29941 .61035 .30691 .61367 .31841 .60819 .31091 .6055 Metetra
.861 .863 .84 r
.31091 .6055 .31841 .60819 .33035 .59559 .3229 .59315 Metetra
.896 .847 .787 r
.3229 .59315 .33035 .59559 .3425 .57896 .33511 .57655 Metetra
.906 .84 .769 r
.33511 .57655 .3425 .57896 .35468 .56076 .34738 .55828 Metetra
.905 .841 .772 r
.34738 .55828 .35468 .56076 .3668 .54287 .35958 .5403 Metetra
.897 .85 .789 r
.35958 .5403 .3668 .54287 .37881 .52663 .37165 .52404 Metetra
.878 .866 .823 r
.37165 .52404 .37881 .52663 .39067 .51293 .38358 .51043 Metetra
.841 .889 .875 r
.38358 .51043 .39067 .51293 .4024 .50232 .39536 .50003 Metetra
.759 .911 .942 r
.39536 .50003 .4024 .50232 .41402 .49502 .40702 .49309 Metetra
.567 .887 .989 r
.40702 .49309 .41402 .49502 .42556 .49103 .41859 .48961 Metetra
.188 .703 .887 r
.41859 .48961 .42556 .49103 .43707 .49016 .43013 .48937 Metetra
.235 0 0 r
.43013 .48937 .43707 .49016 .44859 .49206 .44166 .49202 Metetra
.488 0 0 r
.44166 .49202 .44859 .49206 .46014 .49626 .45324 .49706 Metetra
.605 .053 0 r
.45324 .49706 .46014 .49626 .47178 .50222 .4649 .50393 Metetra
.655 .132 0 r
.4649 .50393 .47178 .50222 .48352 .50933 .47667 .51199 Metetra
.671 .168 .042 r
.47667 .51199 .48352 .50933 .49539 .51695 .48858 .52055 Metetra
.666 .176 .075 r
.48858 .52055 .49539 .51695 .5074 .52444 .50062 .52893 Metetra
.645 .161 .089 r
.50062 .52893 .5074 .52444 .51953 .53117 .51282 .53648 Metetra
.607 .126 .086 r
.51282 .53648 .51953 .53117 .5318 .53658 .52515 .54259 Metetra
.55 .069 .066 r
.52515 .54259 .5318 .53658 .54418 .54017 .5376 .54673 Metetra
.469 0 .027 r
.5376 .54673 .54418 .54017 .55665 .54153 .55014 .54847 Metetra
.355 0 0 r
.55014 .54847 .55665 .54153 .56918 .54038 .56276 .54751 Metetra
.203 0 0 r
.56276 .54751 .56918 .54038 .58174 .53658 .57541 .5437 Metetra
.01 0 0 r
.57541 .5437 .58174 .53658 .5943 .53012 .58807 .53701 Metetra
.58807 .53701 .5943 .53012 .60684 .52112 .6007 .5276 Metetra
.6007 .5276 .60684 .52112 .61934 .50986 .61329 .51575 Metetra
.594 .869 .541 r
.61329 .51575 .61934 .50986 .63177 .49672 .62581 .50187 Metetra
.719 .933 .607 r
.62581 .50187 .63177 .49672 .64414 .4822 .63826 .48648 Metetra
.799 .967 .656 r
.63826 .48648 .64414 .4822 .65646 .46687 .65064 .4702 Metetra
.847 .983 .697 r
.65064 .4702 .65646 .46687 .66873 .45136 .66298 .45369 Metetra
.87 .991 .735 r
.66298 .45369 .66873 .45136 .681 .43632 .6753 .43765 Metetra
.873 .994 .776 r
.6753 .43765 .681 .43632 .6933 .42241 .68764 .42276 Metetra
.855 .995 .823 r
.68764 .42276 .6933 .42241 .70567 .41026 .70005 .4097 Metetra
.811 .99 .878 r
.70005 .4097 .70567 .41026 .71818 .40043 .71259 .39905 Metetra
.725 .967 .936 r
.71259 .39905 .71818 .40043 .73088 .39341 .72532 .39133 Metetra
.573 .904 .979 r
.72532 .39133 .73088 .39341 .74383 .38959 .7383 .38693 Metetra
.34 .771 .97 r
.7383 .38693 .74383 .38959 .75709 .38917 .7516 .38609 Metetra
.059 .569 .881 r
.7516 .38609 .75709 .38917 .77071 .39218 .76524 .38882 Metetra
0 .358 .742 r
.76524 .38882 .77071 .39218 .78471 .39841 .77928 .39491 Metetra
0 .197 .616 r
.77928 .39491 .78471 .39841 .79908 .40733 .79369 .4038 Metetra
.445 0 0 r
.79369 .4038 .79908 .40733 .81379 .41803 .80845 .41452 Metetra
.455 0 0 r
.80845 .41452 .81379 .41803 .82873 .42911 .82343 .42562 Metetra
0 .19 .613 r
.82343 .42562 .82873 .42911 .84371 .43862 .83845 .43506 Metetra
0 .458 .826 r
.83845 .43506 .84371 .43862 .85845 .44398 .85321 .44009 Metetra
.529 .836 .999 r
.85321 .44009 .85845 .44398 .87255 .44189 .8673 .43728 Metetra
.89 .902 .829 r
.8673 .43728 .87255 .44189 .88548 .42842 .88017 .42251 Metetra
.97 .828 .647 r
.88017 .42251 .88548 .42842 .89657 .39916 .89112 .39118 Metetra
.905 .495 .176 r
.27195 .57523 .27929 .58169 .28873 .60385 .28123 .59927 Metetra
.48 0 0 r
.28123 .59927 .28873 .60385 .29941 .61035 .29184 .60694 Metetra
.661 .858 .975 r
.29184 .60694 .29941 .61035 .31091 .6055 .30334 .60274 Metetra
.857 .864 .845 r
.30334 .60274 .31091 .6055 .3229 .59315 .31537 .59067 Metetra
.895 .847 .789 r
.31537 .59067 .3229 .59315 .33511 .57655 .32766 .57413 Metetra
.906 .841 .77 r
.32766 .57413 .33511 .57655 .34738 .55828 .34 .55583 Metetra
.905 .843 .772 r
.34 .55583 .34738 .55828 .35958 .5403 .35227 .53781 Metetra
.897 .853 .791 r
.35227 .53781 .35958 .5403 .37165 .52404 .36442 .52156 Metetra
.878 .871 .826 r
.36442 .52156 .37165 .52404 .38358 .51043 .3764 .50806 Metetra
.837 .896 .881 r
.3764 .50806 .38358 .51043 .39536 .50003 .38823 .4979 Metetra
.742 .916 .951 r
.38823 .4979 .39536 .50003 .40702 .49309 .39993 .49134 Metetra
.513 .872 .985 r
.39993 .49134 .40702 .49309 .41859 .48961 .41154 .48837 Metetra
.083 .633 .826 r
.41154 .48837 .41859 .48961 .43013 .48937 .4231 .48877 Metetra
.327 0 0 r
.4231 .48877 .43013 .48937 .44166 .49202 .43465 .49217 Metetra
.544 0 0 r
.43465 .49217 .44166 .49202 .45324 .49706 .44625 .49806 Metetra
.64 .102 0 r
.44625 .49806 .45324 .49706 .4649 .50393 .45793 .50584 Metetra
.68 .17 .018 r
.45793 .50584 .4649 .50393 .47667 .51199 .46973 .51483 Metetra
.692 .199 .071 r
.46973 .51483 .47667 .51199 .48858 .52055 .48166 .52432 Metetra
.684 .202 .099 r
.48166 .52432 .48858 .52055 .50062 .52893 .49375 .53359 Metetra
.662 .185 .109 r
.49375 .53359 .50062 .52893 .51282 .53648 .50599 .54196 Metetra
.624 .147 .103 r
.50599 .54196 .51282 .53648 .52515 .54259 .51838 .54876 Metetra
.566 .088 .08 r
.51838 .54876 .52515 .54259 .5376 .54673 .5309 .55346 Metetra
.483 .002 .039 r
.5309 .55346 .5376 .54673 .55014 .54847 .54353 .55557 Metetra
.365 0 0 r
.54353 .55557 .55014 .54847 .56276 .54751 .55623 .5548 Metetra
.204 0 0 r
.55623 .5548 .56276 .54751 .57541 .5437 .56898 .55097 Metetra
.56898 .55097 .57541 .5437 .58807 .53701 .58173 .54407 Metetra
.58173 .54407 .58807 .53701 .6007 .5276 .59446 .53424 Metetra
.59446 .53424 .6007 .5276 .61329 .51575 .60714 .5218 Metetra
.623 .881 .546 r
.60714 .5218 .61329 .51575 .62581 .50187 .61975 .50718 Metetra
.743 .939 .607 r
.61975 .50718 .62581 .50187 .63826 .48648 .63228 .49093 Metetra
.818 .967 .651 r
.63228 .49093 .63826 .48648 .65064 .4702 .64474 .47371 Metetra
.862 .98 .687 r
.64474 .47371 .65064 .4702 .66298 .45369 .65715 .45621 Metetra
.883 .987 .722 r
.65715 .45621 .66298 .45369 .6753 .43765 .66953 .43916 Metetra
.886 .991 .761 r
.66953 .43916 .6753 .43765 .68764 .42276 .68192 .42331 Metetra
.869 .994 .807 r
.68192 .42331 .68764 .42276 .70005 .4097 .69438 .40933 Metetra
.828 .992 .862 r
.69438 .40933 .70005 .4097 .71259 .39905 .70695 .39785 Metetra
.746 .975 .923 r
.70695 .39785 .71259 .39905 .72532 .39133 .71972 .38943 Metetra
.597 .919 .972 r
.71972 .38943 .72532 .39133 .7383 .38693 .73273 .38445 Metetra
.36 .789 .97 r
.73273 .38445 .7383 .38693 .7516 .38609 .74605 .38316 Metetra
.068 .582 .881 r
.74605 .38316 .7516 .38609 .76524 .38882 .75973 .3856 Metetra
0 .361 .738 r
.75973 .3856 .76524 .38882 .77928 .39491 .7738 .39151 Metetra
0 .195 .609 r
.7738 .39151 .77928 .39491 .79369 .4038 .78825 .40033 Metetra
.45 0 0 r
.78825 .40033 .79369 .4038 .80845 .41452 .80305 .41104 Metetra
.457 0 0 r
.80305 .41104 .80845 .41452 .82343 .42562 .81807 .42212 Metetra
0 .197 .618 r
.81807 .42212 .82343 .42562 .83845 .43506 .83313 .43143 Metetra
0 .481 .842 r
.83313 .43143 .83845 .43506 .85321 .44009 .84791 .43612 Metetra
.569 .853 .997 r
.84791 .43612 .85321 .44009 .8673 .43728 .86199 .43257 Metetra
.904 .897 .811 r
.86199 .43257 .8673 .43728 .88017 .42251 .8748 .4165 Metetra
.973 .822 .633 r
.8748 .4165 .88017 .42251 .89112 .39118 .88562 .38313 Metetra
.913 .513 .207 r
.26456 .56873 .27195 .57523 .28123 .59927 .27367 .59456 Metetra
.564 .006 0 r
.27367 .59456 .28123 .59927 .29184 .60694 .28421 .60337 Metetra
.63 .847 .983 r
.28421 .60337 .29184 .60694 .30334 .60274 .29571 .59979 Metetra
.852 .862 .848 r
.29571 .59979 .30334 .60274 .31537 .59067 .30778 .588 Metetra
.893 .844 .789 r
.30778 .588 .31537 .59067 .32766 .57413 .32013 .57153 Metetra
.904 .838 .77 r
.32013 .57153 .32766 .57413 .34 .55583 .33255 .55319 Metetra
.903 .84 .772 r
.33255 .55319 .34 .55583 .35227 .53781 .3449 .53514 Metetra
.895 .85 .791 r
.3449 .53514 .35227 .53781 .36442 .52156 .35711 .5189 Metetra
.875 .868 .828 r
.35711 .5189 .36442 .52156 .3764 .50806 .36916 .50552 Metetra
.831 .893 .885 r
.36916 .50552 .3764 .50806 .38823 .4979 .38104 .49559 Metetra
.729 .911 .957 r
.38104 .49559 .38823 .4979 .39993 .49134 .39277 .4894 Metetra
.478 .853 .985 r
.39277 .4894 .39993 .49134 .41154 .48837 .40441 .48692 Metetra
.024 .586 .802 r
.40441 .48692 .41154 .48837 .4231 .48877 .41599 .48794 Metetra
.375 0 0 r
.41599 .48794 .4231 .48877 .43465 .49217 .42756 .49207 Metetra
.576 .006 0 r
.42756 .49207 .43465 .49217 .44625 .49806 .43917 .49877 Metetra
.664 .13 0 r
.43917 .49877 .44625 .49806 .45793 .50584 .45087 .50742 Metetra
.7 .192 .026 r
.45087 .50742 .45793 .50584 .46973 .51483 .46269 .51732 Metetra
.709 .218 .075 r
.46269 .51732 .46973 .51483 .48166 .52432 .47465 .52771 Metetra
.701 .218 .099 r
.47465 .52771 .48166 .52432 .49375 .53359 .48677 .53785 Metetra
.677 .198 .105 r
.48677 .53785 .49375 .53359 .50599 .54196 .49906 .547 Metetra
.637 .156 .095 r
.49906 .547 .50599 .54196 .51838 .54876 .51151 .55448 Metetra
.576 .092 .067 r
.51151 .55448 .51838 .54876 .5309 .55346 .5241 .5597 Metetra
.487 0 .018 r
.5241 .5597 .5309 .55346 .54353 .55557 .5368 .56219 Metetra
.357 0 0 r
.5368 .56219 .54353 .55557 .55623 .5548 .54959 .5616 Metetra
.175 0 0 r
.54959 .5616 .55623 .5548 .56898 .55097 .56243 .55775 Metetra
.56243 .55775 .56898 .55097 .58173 .54407 .57528 .55063 Metetra
.57528 .55063 .58173 .54407 .59446 .53424 .5881 .54041 Metetra
.532 .838 .522 r
.5881 .54041 .59446 .53424 .60714 .5218 .60088 .52739 Metetra
.694 .922 .594 r
.60088 .52739 .60714 .5218 .61975 .50718 .61358 .51204 Metetra
.798 .961 .64 r
.61358 .51204 .61975 .50718 .63228 .49093 .6262 .49496 Metetra
.859 .976 .672 r
.6262 .49496 .63228 .49093 .64474 .47371 .63874 .47682 Metetra
.893 .981 .699 r
.63874 .47682 .64474 .47371 .65715 .45621 .65122 .45836 Metetra
.907 .982 .727 r
.65122 .45836 .65715 .45621 .66953 .43916 .66366 .44035 Metetra
.907 .984 .76 r
.66366 .44035 .66953 .43916 .68192 .42331 .67611 .42355 Metetra
.89 .986 .803 r
.67611 .42355 .68192 .42331 .69438 .40933 .68861 .40868 Metetra
.852 .985 .856 r
.68861 .40868 .69438 .40933 .70695 .39785 .70123 .39642 Metetra
.776 .974 .917 r
.70123 .39642 .70695 .39785 .71972 .38943 .71403 .3873 Metetra
.637 .928 .972 r
.71403 .3873 .71972 .38943 .73273 .38445 .72707 .38176 Metetra
.407 .81 .982 r
.72707 .38176 .73273 .38445 .74605 .38316 .74042 .38004 Metetra
.109 .608 .903 r
.74042 .38004 .74605 .38316 .75973 .3856 .75414 .38218 Metetra
0 .382 .76 r
.75414 .38218 .75973 .3856 .7738 .39151 .76824 .38792 Metetra
0 .209 .627 r
.76824 .38792 .7738 .39151 .78825 .40033 .78273 .39666 Metetra
.436 0 0 r
.78273 .39666 .78825 .40033 .80305 .41104 .79757 .40735 Metetra
.443 0 0 r
.79757 .40735 .80305 .41104 .81807 .42212 .81264 .41841 Metetra
0 .214 .638 r
.81264 .41841 .81807 .42212 .83313 .43143 .82773 .4276 Metetra
.008 .508 .866 r
.82773 .4276 .83313 .43143 .84791 .43612 .84254 .43193 Metetra
.609 .864 .991 r
.84254 .43193 .84791 .43612 .86199 .43257 .85661 .42767 Metetra
.914 .89 .794 r
.85661 .42767 .86199 .43257 .8748 .4165 .86937 .41034 Metetra
.975 .817 .622 r
.86937 .41034 .8748 .4165 .88562 .38313 .88007 .37501 Metetra
.919 .528 .231 r
.25711 .56217 .26456 .56873 .27367 .59456 .26604 .58969 Metetra
.625 .077 0 r
.26604 .58969 .27367 .59456 .28421 .60337 .27651 .59955 Metetra
.6 .832 .988 r
.27651 .59955 .28421 .60337 .29571 .59979 .28801 .59654 Metetra
.846 .856 .85 r
.28801 .59654 .29571 .59979 .30778 .588 .30013 .58498 Metetra
.889 .838 .789 r
.30013 .58498 .30778 .588 .32013 .57153 .31254 .56855 Metetra
.9 .831 .769 r
.31254 .56855 .32013 .57153 .33255 .55319 .32504 .55016 Metetra
.9 .833 .771 r
.32504 .55016 .33255 .55319 .3449 .53514 .33747 .53205 Metetra
.891 .842 .79 r
.33747 .53205 .3449 .53514 .35711 .5189 .34976 .51581 Metetra
.87 .858 .827 r
.34976 .51581 .35711 .5189 .36916 .50552 .36186 .50251 Metetra
.825 .88 .885 r
.36186 .50251 .36916 .50552 .38104 .49559 .37379 .49278 Metetra
.72 .894 .959 r
.37379 .49278 .38104 .49559 .39277 .4894 .38556 .48691 Metetra
.467 .833 .993 r
.38556 .48691 .39277 .4894 .40441 .48692 .39722 .48488 Metetra
.012 .567 .819 r
.39722 .48488 .40441 .48692 .41599 .48794 .40882 .48647 Metetra
.389 0 0 r
.40882 .48647 .41599 .48794 .42756 .49207 .4204 .49127 Metetra
.591 .02 0 r
.4204 .49127 .42756 .49207 .43917 .49877 .43203 .49873 Metetra
.679 .143 0 r
.43203 .49873 .43917 .49877 .45087 .50742 .44373 .5082 Metetra
.715 .203 .007 r
.44373 .5082 .45087 .50742 .46269 .51732 .45557 .51893 Metetra
.724 .227 .054 r
.45557 .51893 .46269 .51732 .47465 .52771 .46755 .53017 Metetra
.716 .225 .076 r
.46755 .53017 .47465 .52771 .48677 .53785 .4797 .54112 Metetra
.691 .201 .078 r
.4797 .54112 .48677 .53785 .49906 .547 .49203 .55101 Metetra
.649 .154 .062 r
.49203 .55101 .49906 .547 .51151 .55448 .50453 .55913 Metetra
.582 .079 .024 r
.50453 .55913 .51151 .55448 .5241 .5597 .51718 .56486 Metetra
.48 0 0 r
.51718 .56486 .5241 .5597 .5368 .56219 .52996 .56769 Metetra
.326 0 0 r
.52996 .56769 .5368 .56219 .54959 .5616 .54283 .56727 Metetra
.106 0 0 r
.54283 .56727 .54959 .5616 .56243 .55775 .55575 .5634 Metetra
.55575 .5634 .56243 .55775 .57528 .55063 .5687 .55608 Metetra
.5687 .55608 .57528 .55063 .5881 .54041 .58162 .54547 Metetra
.655 .921 .625 r
.58162 .54547 .5881 .54041 .60088 .52739 .59449 .5319 Metetra
.788 .969 .668 r
.59449 .5319 .60088 .52739 .61358 .51204 .60728 .51588 Metetra
.864 .981 .69 r
.60728 .51588 .61358 .51204 .6262 .49496 .61999 .498 Metetra
.905 .98 .705 r
.61999 .498 .6262 .49496 .63874 .47682 .63261 .47899 Metetra
.925 .974 .72 r
.63261 .47899 .63874 .47682 .65122 .45836 .64517 .45962 Metetra
.931 .97 .739 r
.64517 .45962 .65122 .45836 .66366 .44035 .65768 .4407 Metetra
.926 .968 .766 r
.65768 .4407 .66366 .44035 .67611 .42355 .67018 .42301 Metetra
.909 .968 .803 r
.67018 .42301 .67611 .42355 .68861 .40868 .68274 .40732 Metetra
.873 .968 .852 r
.68274 .40732 .68861 .40868 .70123 .39642 .6954 .39431 Metetra
.805 .959 .912 r
.6954 .39431 .70123 .39642 .71403 .3873 .70824 .38456 Metetra
.68 .923 .972 r
.70824 .38456 .71403 .3873 .72707 .38176 .72132 .3785 Metetra
.467 .824 .996 r
.72132 .3785 .72707 .38176 .74042 .38004 .7347 .37639 Metetra
.175 .637 .936 r
.7347 .37639 .74042 .38004 .75414 .38218 .74845 .37826 Metetra
0 .413 .801 r
.74845 .37826 .75414 .38218 .76824 .38792 .76259 .38386 Metetra
0 .234 .664 r
.76259 .38386 .76824 .38792 .78273 .39666 .77712 .39255 Metetra
0 .136 .58 r
.77712 .39255 .78273 .39666 .79757 .40735 .792 .40324 Metetra
0 .127 .573 r
.792 .40324 .79757 .40735 .81264 .41841 .80711 .4143 Metetra
0 .237 .671 r
.80711 .4143 .81264 .41841 .82773 .4276 .82224 .42338 Metetra
.06 .536 .893 r
.82224 .42338 .82773 .4276 .84254 .43193 .83707 .42741 Metetra
.644 .867 .983 r
.83707 .42741 .84254 .43193 .85661 .42767 .85115 .42248 Metetra
.921 .881 .779 r
.85115 .42248 .85661 .42767 .86937 .41034 .86386 .40398 Metetra
.977 .811 .612 r
.86386 .40398 .86937 .41034 .88007 .37501 .87448 .36682 Metetra
.923 .539 .249 r
.2496 .55556 .25711 .56217 .26604 .58969 .25837 .5846 Metetra
.668 .13 0 r
.25837 .5846 .26604 .58969 .27651 .59955 .26877 .5954 Metetra
.576 .815 .989 r
.26877 .5954 .27651 .59955 .28801 .59654 .28026 .59287 Metetra
.84 .846 .85 r
.28026 .59287 .28801 .59654 .30013 .58498 .29242 .58149 Metetra
.884 .829 .787 r
.29242 .58149 .30013 .58498 .31254 .56855 .30491 .56503 Metetra
.895 .821 .766 r
.30491 .56503 .31254 .56855 .32504 .55016 .31749 .54654 Metetra
.894 .821 .768 r
.31749 .54654 .32504 .55016 .33747 .53205 .33 .52832 Metetra
.884 .828 .787 r
.33 .52832 .33747 .53205 .34976 .51581 .34236 .51203 Metetra
.862 .842 .823 r
.34236 .51203 .34976 .51581 .36186 .50251 .35452 .49876 Metetra
.817 .859 .879 r
.35452 .49876 .36186 .50251 .37379 .49278 .3665 .48917 Metetra
.715 .867 .954 r
.3665 .48917 .37379 .49278 .38556 .48691 .3783 .48355 Metetra
.478 .81 1 r
.3783 .48355 .38556 .48691 .39722 .48488 .38999 .4819 Metetra
.044 .57 .865 r
.38999 .4819 .39722 .48488 .40882 .48647 .4016 .48398 Metetra
.369 0 0 r
.4016 .48398 .40882 .48647 .4204 .49127 .41319 .48937 Metetra
.588 .013 0 r
.41319 .48937 .4204 .49127 .43203 .49873 .42482 .49751 Metetra
.684 .14 0 r
.42482 .49751 .43203 .49873 .44373 .5082 .43654 .5077 Metetra
.724 .203 0 r
.43654 .5077 .44373 .5082 .45557 .51893 .44838 .5192 Metetra
.735 .226 .009 r
.44838 .5192 .45557 .51893 .46755 .53017 .46038 .53121 Metetra
.727 .222 .028 r
.46038 .53121 .46755 .53017 .4797 .54112 .47255 .54289 Metetra
.702 .194 .024 r
.47255 .54289 .4797 .54112 .49203 .55101 .48492 .55346 Metetra
.656 .139 0 r
.48492 .55346 .49203 .55101 .50453 .55913 .49746 .56216 Metetra
.58 .048 0 r
.49746 .56216 .50453 .55913 .51718 .56486 .51016 .56835 Metetra
.456 0 0 r
.51016 .56835 .51718 .56486 .52996 .56769 .523 .57149 Metetra
.259 0 0 r
.523 .57149 .52996 .56769 .54283 .56727 .53595 .57122 Metetra
.53595 .57122 .54283 .56727 .55575 .5634 .54896 .56733 Metetra
.54896 .56733 .55575 .5634 .5687 .55608 .56199 .55982 Metetra
.619 .934 .704 r
.56199 .55982 .5687 .55608 .58162 .54547 .575 .54885 Metetra
.783 .986 .736 r
.575 .54885 .58162 .54547 .59449 .5319 .58796 .53478 Metetra
.871 .991 .739 r
.58796 .53478 .59449 .5319 .60728 .51588 .60085 .51812 Metetra
.916 .98 .735 r
.60085 .51812 .60728 .51588 .61999 .498 .61365 .49951 Metetra
.937 .965 .734 r
.61365 .49951 .61999 .498 .63261 .47899 .62635 .47971 Metetra
.946 .953 .738 r
.62635 .47971 .63261 .47899 .64517 .45962 .63898 .45951 Metetra
.945 .944 .75 r
.63898 .45951 .64517 .45962 .65768 .4407 .65156 .43976 Metetra
.937 .939 .77 r
.65156 .43976 .65768 .4407 .67018 .42301 .66413 .42127 Metetra
.918 .938 .802 r
.66413 .42127 .67018 .42301 .68274 .40732 .67673 .40484 Metetra
.885 .936 .845 r
.67673 .40484 .68274 .40732 .6954 .39431 .68945 .39116 Metetra
.825 .93 .901 r
.68945 .39116 .6954 .39431 .70824 .38456 .70233 .38085 Metetra
.715 .901 .962 r
.70233 .38085 .70824 .38456 .72132 .3785 .71544 .37434 Metetra
.526 .821 .999 r
.71544 .37434 .72132 .3785 .7347 .37639 .72887 .3719 Metetra
.252 .659 .964 r
.72887 .3719 .7347 .37639 .74845 .37826 .74265 .37357 Metetra
0 .447 .847 r
.74265 .37357 .74845 .37826 .76259 .38386 .75683 .37907 Metetra
0 .266 .712 r
.75683 .37907 .76259 .38386 .77712 .39255 .7714 .38776 Metetra
0 .162 .624 r
.7714 .38776 .77712 .39255 .792 .40324 .78632 .3985 Metetra
0 .151 .614 r
.78632 .3985 .792 .40324 .80711 .4143 .80147 .4096 Metetra
0 .264 .709 r
.80147 .4096 .80711 .4143 .82224 .42338 .81664 .41865 Metetra
.115 .56 .918 r
.81664 .41865 .82224 .42338 .83707 .42741 .8315 .42243 Metetra
.672 .862 .972 r
.8315 .42243 .83707 .42741 .85115 .42248 .84559 .41694 Metetra
.925 .872 .766 r
.84559 .41694 .85115 .42248 .86386 .40398 .85829 .39739 Metetra
.978 .806 .603 r
.85829 .39739 .86386 .40398 .87448 .36682 .86883 .35855 Metetra
.926 .548 .264 r
.24203 .5489 .2496 .55556 .25837 .5846 .25064 .57928 Metetra
.696 .168 0 r
.25064 .57928 .25837 .5846 .26877 .5954 .26097 .59086 Metetra
.561 .798 .988 r
.26097 .59086 .26877 .5954 .28026 .59287 .27248 .5887 Metetra
.834 .834 .847 r
.27248 .5887 .28026 .59287 .29242 .58149 .28469 .57738 Metetra
.879 .817 .783 r
.28469 .57738 .29242 .58149 .30491 .56503 .29725 .56083 Metetra
.889 .808 .763 r
.29725 .56083 .30491 .56503 .31749 .54654 .30991 .54217 Metetra
.888 .807 .764 r
.30991 .54217 .31749 .54654 .33 .52832 .3225 .52377 Metetra
.877 .812 .781 r
.3225 .52377 .33 .52832 .34236 .51203 .33493 .50734 Metetra
.854 .821 .816 r
.33493 .50734 .34236 .51203 .35452 .49876 .34716 .49403 Metetra
.808 .831 .869 r
.34716 .49403 .35452 .49876 .3665 .48917 .35918 .4845 Metetra
.711 .833 .94 r
.35918 .4845 .3665 .48917 .3783 .48355 .37103 .47906 Metetra
.501 .78 .995 r
.37103 .47906 .3783 .48355 .38999 .4819 .38273 .47769 Metetra
.111 .58 .914 r
.38273 .47769 .38999 .4819 .4016 .48398 .39436 .48016 Metetra
0 .263 .646 r
.39436 .48016 .4016 .48398 .41319 .48937 .40596 .48604 Metetra
.556 0 0 r
.40596 .48604 .41319 .48937 .42482 .49751 .41759 .49473 Metetra
.671 .121 0 r
.41759 .49473 .42482 .49751 .43654 .5077 .4293 .50555 Metetra
.721 .189 0 r
.4293 .50555 .43654 .5077 .44838 .5192 .44115 .51771 Metetra
.737 .214 0 r
.44115 .51771 .44838 .5192 .46038 .53121 .45315 .53037 Metetra
.73 .208 0 r
.45315 .53037 .46038 .53121 .47255 .54289 .46534 .5427 Metetra
.703 .173 0 r
.46534 .5427 .47255 .54289 .48492 .55346 .47773 .55385 Metetra
.65 .104 0 r
.47773 .55385 .48492 .55346 .49746 .56216 .4903 .56306 Metetra
.556 0 0 r
.4903 .56306 .49746 .56216 .51016 .56835 .50305 .56964 Metetra
.393 0 0 r
.50305 .56964 .51016 .56835 .523 .57149 .51595 .57306 Metetra
.123 0 0 r
.51595 .57306 .523 .57149 .53595 .57122 .52896 .57292 Metetra
.241 .75 .722 r
.52896 .57292 .53595 .57122 .54896 .56733 .54205 .56901 Metetra
.569 .938 .826 r
.54205 .56901 .54896 .56733 .56199 .55982 .55516 .56132 Metetra
.77 .997 .836 r
.55516 .56132 .56199 .55982 .575 .54885 .56826 .55003 Metetra
.869 .993 .811 r
.56826 .55003 .575 .54885 .58796 .53478 .58131 .5355 Metetra
.917 .971 .783 r
.58131 .5355 .58796 .53478 .60085 .51812 .59428 .51828 Metetra
.939 .949 .762 r
.59428 .51828 .60085 .51812 .61365 .49951 .60716 .49903 Metetra
.948 .93 .75 r
.60716 .49903 .61365 .49951 .62635 .47971 .61995 .47852 Metetra
.949 .916 .747 r
.61995 .47852 .62635 .47971 .63898 .45951 .63266 .4576 Metetra
.944 .906 .753 r
.63266 .4576 .63898 .45951 .65156 .43976 .6453 .43712 Metetra
.934 .9 .769 r
.6453 .43712 .65156 .43976 .66413 .42127 .65793 .41794 Metetra
.915 .897 .795 r
.65793 .41794 .66413 .42127 .67673 .40484 .6706 .40087 Metetra
.884 .895 .833 r
.6706 .40087 .67673 .40484 .68945 .39116 .68336 .38664 Metetra
.83 .887 .884 r
.68336 .38664 .68945 .39116 .70233 .38085 .69628 .37586 Metetra
.734 .863 .941 r
.69628 .37586 .70233 .38085 .71544 .37434 .70944 .36899 Metetra
.57 .798 .985 r
.70944 .36899 .71544 .37434 .72887 .3719 .7229 .36632 Metetra
.323 .663 .974 r
.7229 .36632 .72887 .3719 .74265 .37357 .73673 .36786 Metetra
.043 .473 .883 r
.73673 .36786 .74265 .37357 .75683 .37907 .75094 .37334 Metetra
0 .297 .759 r
.75094 .37334 .75683 .37907 .7714 .38776 .76555 .3821 Metetra
0 .19 .671 r
.76555 .3821 .7714 .38776 .78632 .3985 .78052 .39296 Metetra
0 .177 .657 r
.78052 .39296 .78632 .3985 .80147 .4096 .79571 .40418 Metetra
0 .288 .747 r
.79571 .40418 .80147 .4096 .81664 .41865 .81093 .41326 Metetra
.167 .575 .935 r
.81093 .41326 .81664 .41865 .8315 .42243 .82583 .41691 Metetra
.691 .852 .96 r
.82583 .41691 .8315 .42243 .84559 .41694 .83995 .41097 Metetra
.927 .861 .756 r
.83995 .41097 .84559 .41694 .85829 .39739 .85264 .39053 Metetra
.978 .801 .597 r
.85264 .39053 .85829 .39739 .86883 .35855 .86314 .35021 Metetra
.928 .554 .275 r
.23439 .54218 .24203 .5489 .25064 .57928 .24285 .57369 Metetra
.714 .192 0 r
.24285 .57369 .25064 .57928 .26097 .59086 .25314 .58588 Metetra
.555 .782 .984 r
.25314 .58588 .26097 .59086 .27248 .5887 .26465 .58394 Metetra
.829 .82 .841 r
.26465 .58394 .27248 .5887 .28469 .57738 .27692 .57258 Metetra
.873 .803 .778 r
.27692 .57258 .28469 .57738 .29725 .56083 .28956 .55583 Metetra
.883 .794 .757 r
.28956 .55583 .29725 .56083 .30991 .54217 .30231 .5369 Metetra
.88 .791 .758 r
.30231 .5369 .30991 .54217 .3225 .52377 .31499 .51824 Metetra
.868 .793 .774 r
.31499 .51824 .3225 .52377 .33493 .50734 .3275 .5016 Metetra
.844 .797 .805 r
.3275 .5016 .33493 .50734 .34716 .49403 .33979 .48815 Metetra
.798 .8 .854 r
.33979 .48815 .34716 .49403 .35918 .4845 .35186 .47858 Metetra
.708 .793 .917 r
.35186 .47858 .35918 .4845 .37103 .47906 .36374 .4732 Metetra
.526 .743 .974 r
.36374 .4732 .37103 .47906 .38273 .47769 .37547 .472 Metetra
.195 .583 .942 r
.37547 .472 .38273 .47769 .39436 .48016 .3871 .47475 Metetra
0 .312 .746 r
.3871 .47475 .39436 .48016 .40596 .48604 .39871 .48098 Metetra
.482 0 0 r
.39871 .48098 .40596 .48604 .41759 .49473 .41034 .49011 Metetra
.626 .081 0 r
.41034 .49011 .41759 .49473 .4293 .50555 .42205 .50142 Metetra
.692 .157 0 r
.42205 .50142 .4293 .50555 .44115 .51771 .43388 .5141 Metetra
.716 .184 0 r
.43388 .5141 .44115 .51771 .45315 .53037 .44589 .52731 Metetra
.711 .175 0 r
.44589 .52731 .45315 .53037 .46534 .5427 .45809 .54015 Metetra
.679 .131 0 r
.45809 .54015 .46534 .5427 .47773 .55385 .47048 .55179 Metetra
.61 .042 0 r
.47048 .55179 .47773 .55385 .4903 .56306 .48308 .56142 Metetra
.481 0 0 r
.48308 .56142 .4903 .56306 .50305 .56964 .49587 .56834 Metetra
.249 0 0 r
.49587 .56834 .50305 .56964 .51595 .57306 .50881 .57198 Metetra
.107 .654 .825 r
.50881 .57198 .51595 .57306 .52896 .57292 .52188 .57194 Metetra
.477 .883 .946 r
.52188 .57194 .52896 .57292 .54205 .56901 .53503 .568 Metetra
.719 .965 .939 r
.53503 .568 .54205 .56901 .55516 .56132 .54821 .56015 Metetra
.839 .966 .885 r
.54821 .56015 .55516 .56132 .56826 .55003 .56139 .54858 Metetra
.895 .943 .833 r
.56139 .54858 .56826 .55003 .58131 .5355 .57452 .53367 Metetra
.922 .919 .794 r
.57452 .53367 .58131 .5355 .59428 .51828 .58758 .51597 Metetra
.934 .898 .767 r
.58758 .51597 .59428 .51828 .60716 .49903 .60054 .49617 Metetra
.938 .882 .752 r
.60054 .49617 .60716 .49903 .61995 .47852 .61341 .47507 Metetra
.937 .87 .746 r
.61341 .47507 .61995 .47852 .63266 .4576 .62619 .45354 Metetra
.931 .861 .75 r
.62619 .45354 .63266 .4576 .6453 .43712 .6389 .43246 Metetra
.92 .856 .762 r
.6389 .43246 .6453 .43712 .65793 .41794 .65159 .41272 Metetra
.902 .852 .784 r
.65159 .41272 .65793 .41794 .6706 .40087 .66432 .39514 Metetra
.872 .848 .816 r
.66432 .39514 .6706 .40087 .68336 .38664 .67713 .38047 Metetra
.823 .839 .861 r
.67713 .38047 .68336 .38664 .69628 .37586 .6901 .36935 Metetra
.739 .817 .913 r
.6901 .36935 .69628 .37586 .70944 .36899 .7033 .36224 Metetra
.596 .762 .958 r
.7033 .36224 .70944 .36899 .7229 .36632 .7168 .35943 Metetra
.379 .651 .963 r
.7168 .35943 .7229 .36632 .73673 .36786 .73066 .36095 Metetra
.117 .486 .9 r
.73066 .36095 .73673 .36786 .75094 .37334 .74492 .3665 Metetra
0 .321 .795 r
.74492 .3665 .75094 .37334 .76555 .3821 .75958 .37541 Metetra
0 .215 .711 r
.75958 .37541 .76555 .3821 .78052 .39296 .77459 .38648 Metetra
0 .2 .695 r
.77459 .38648 .78052 .39296 .79571 .40418 .78983 .39791 Metetra
0 .308 .777 r
.78983 .39791 .79571 .40418 .81093 .41326 .8051 .40713 Metetra
.211 .581 .943 r
.8051 .40713 .81093 .41326 .82583 .41691 .82005 .41076 Metetra
.703 .837 .947 r
.82005 .41076 .82583 .41691 .83995 .41097 .8342 .40451 Metetra
.927 .851 .748 r
.8342 .40451 .83995 .41097 .85264 .39053 .84691 .38336 Metetra
.978 .797 .592 r
.84691 .38336 .85264 .39053 .86314 .35021 .85739 .3418 Metetra
.929 .559 .283 r
.2267 .53541 .23439 .54218 .24285 .57369 .23502 .5678 Metetra
.723 .206 0 r
.23502 .5678 .24285 .57369 .25314 .58588 .24526 .58041 Metetra
.559 .768 .976 r
.24526 .58041 .25314 .58588 .26465 .58394 .2568 .57853 Metetra
.825 .805 .832 r
.2568 .57853 .26465 .58394 .27692 .57258 .26914 .56701 Metetra
.867 .789 .771 r
.26914 .56701 .27692 .57258 .28956 .55583 .28187 .54994 Metetra
.876 .779 .751 r
.28187 .54994 .28956 .55583 .30231 .5369 .29471 .53065 Metetra
.872 .775 .751 r
.29471 .53065 .30231 .5369 .31499 .51824 .30748 .51163 Metetra
.859 .773 .765 r
.30748 .51163 .31499 .51824 .3275 .5016 .32007 .49467 Metetra
.834 .772 .793 r
.32007 .49467 .3275 .5016 .33979 .48815 .33243 .48099 Metetra
.788 .769 .836 r
.33243 .48099 .33979 .48815 .35186 .47858 .34455 .47127 Metetra
.704 .754 .891 r
.34455 .47127 .35186 .47858 .36374 .4732 .35646 .46584 Metetra
.547 .703 .943 r
.35646 .46584 .36374 .4732 .37547 .472 .36821 .46469 Metetra
.277 .575 .939 r
.36821 .46469 .37547 .472 .3871 .47475 .37986 .46757 Metetra
0 .356 .818 r
.37986 .46757 .3871 .47475 .39871 .48098 .39146 .47402 Metetra
0 .133 .626 r
.39146 .47402 .39871 .48098 .41034 .49011 .40308 .48344 Metetra
.535 .021 0 r
.40308 .48344 .41034 .49011 .42205 .50142 .41478 .49509 Metetra
.62 .103 0 r
.41478 .49509 .42205 .50142 .43388 .5141 .42661 .50816 Metetra
.652 .132 0 r
.42661 .50816 .43388 .5141 .44589 .52731 .43861 .52176 Metetra
.646 .118 0 r
.43861 .52176 .44589 .52731 .45809 .54015 .4508 .535 Metetra
.6 .06 0 r
.4508 .535 .45809 .54015 .47048 .55179 .46321 .547 Metetra
.5 0 0 r
.46321 .547 .47048 .55179 .48308 .56142 .47582 .55694 Metetra
0 .242 .651 r
.47582 .55694 .48308 .56142 .49587 .56834 .48863 .56411 Metetra
0 .497 .852 r
.48863 .56411 .49587 .56834 .50881 .57198 .5016 .56792 Metetra
.337 .733 .983 r
.5016 .56792 .50881 .57198 .52188 .57194 .51472 .56795 Metetra
.609 .857 .99 r
.51472 .56795 .52188 .57194 .53503 .568 .52792 .56398 Metetra
.763 .889 .934 r
.52792 .56398 .53503 .568 .54821 .56015 .54116 .556 Metetra
.842 .885 .872 r
.54116 .556 .54821 .56015 .56139 .54858 .55441 .5442 Metetra
.882 .87 .821 r
.55441 .5442 .56139 .54858 .57452 .53367 .56762 .52897 Metetra
.903 .854 .784 r
.56762 .52897 .57452 .53367 .58758 .51597 .58075 .51089 Metetra
.913 .841 .76 r
.58075 .51089 .58758 .51597 .60054 .49617 .59379 .49065 Metetra
.917 .83 .745 r
.59379 .49065 .60054 .49617 .61341 .47507 .60673 .46909 Metetra
.916 .822 .739 r
.60673 .46909 .61341 .47507 .62619 .45354 .61958 .44709 Metetra
.91 .815 .741 r
.61958 .44709 .62619 .45354 .6389 .43246 .63236 .42555 Metetra
.9 .811 .751 r
.63236 .42555 .6389 .43246 .65159 .41272 .64511 .40539 Metetra
.882 .806 .77 r
.64511 .40539 .65159 .41272 .66432 .39514 .65789 .38745 Metetra
.854 .801 .798 r
.65789 .38745 .66432 .39514 .67713 .38047 .67076 .37249 Metetra
.809 .791 .836 r
.67076 .37249 .67713 .38047 .6901 .36935 .68377 .36116 Metetra
.733 .769 .882 r
.68377 .36116 .6901 .36935 .7033 .36224 .69702 .35393 Metetra
.607 .721 .925 r
.69702 .35393 .7033 .36224 .7168 .35943 .71056 .3511 Metetra
.417 .627 .94 r
.71056 .3511 .7168 .35943 .73066 .36095 .72447 .3527 Metetra
.179 .485 .9 r
.72447 .3527 .73066 .36095 .74492 .3665 .73876 .35843 Metetra
0 .336 .816 r
.73876 .35843 .74492 .3665 .75958 .37541 .75346 .36759 Metetra
0 .234 .74 r
.75346 .36759 .75958 .37541 .77459 .38648 .76852 .37896 Metetra
0 .217 .723 r
.76852 .37896 .77459 .38648 .78983 .39791 .78382 .39069 Metetra
0 .319 .797 r
.78382 .39069 .78983 .39791 .8051 .40713 .79914 .40017 Metetra
.245 .576 .942 r
.79914 .40017 .8051 .40713 .82005 .41076 .81415 .40391 Metetra
.707 .818 .934 r
.81415 .40391 .82005 .41076 .8342 .40451 .82835 .39753 Metetra
.925 .841 .743 r
.82835 .39753 .8342 .40451 .84691 .38336 .8411 .37586 Metetra
.977 .793 .589 r
.8411 .37586 .84691 .38336 .85739 .3418 .85159 .33331 Metetra
.93 .562 .289 r
.21894 .52858 .2267 .53541 .23502 .5678 .22715 .5616 Metetra
.722 .208 0 r
.22715 .5616 .23502 .5678 .24526 .58041 .23736 .57443 Metetra
.571 .757 .966 r
.23736 .57443 .24526 .58041 .2568 .57853 .24894 .57245 Metetra
.821 .79 .822 r
.24894 .57245 .2568 .57853 .26914 .56701 .26134 .56061 Metetra
.862 .774 .764 r
.26134 .56061 .26914 .56701 .28187 .54994 .27417 .54313 Metetra
.87 .764 .744 r
.27417 .54313 .28187 .54994 .29471 .53065 .28711 .52336 Metetra
.865 .758 .743 r
.28711 .52336 .29471 .53065 .30748 .51163 .29998 .50388 Metetra
.851 .754 .756 r
.29998 .50388 .30748 .51163 .32007 .49467 .31265 .48652 Metetra
.824 .749 .78 r
.31265 .48652 .32007 .49467 .33243 .48099 .32508 .47248 Metetra
.779 .74 .817 r
.32508 .47248 .33243 .48099 .34455 .47127 .33726 .46251 Metetra
.701 .718 .863 r
.33726 .46251 .34455 .47127 .35646 .46584 .34921 .4569 Metetra
.564 .667 .907 r
.34921 .4569 .35646 .46584 .36821 .46469 .36098 .45566 Metetra
.344 .559 .916 r
.36098 .45566 .36821 .46469 .37986 .46757 .37264 .45854 Metetra
.056 .387 .848 r
.37264 .45854 .37986 .46757 .39146 .47402 .38424 .46506 Metetra
0 .197 .716 r
.38424 .46506 .39146 .47402 .40308 .48344 .39585 .47462 Metetra
0 .053 .585 r
.39585 .47462 .40308 .48344 .41478 .49509 .40754 .48646 Metetra
0 0 .498 r
.40754 .48646 .41478 .49509 .42661 .50816 .41935 .49974 Metetra
0 0 .464 r
.41935 .49974 .42661 .50816 .43861 .52176 .43133 .51359 Metetra
0 0 .48 r
.43133 .51359 .43861 .52176 .4508 .535 .44351 .52708 Metetra
0 .033 .548 r
.44351 .52708 .4508 .535 .46321 .547 .45591 .53932 Metetra
0 .161 .664 r
.45591 .53932 .46321 .547 .47582 .55694 .46853 .54947 Metetra
0 .344 .81 r
.46853 .54947 .47582 .55694 .48863 .56411 .48135 .5568 Metetra
.199 .542 .928 r
.48135 .5568 .48863 .56411 .5016 .56792 .49435 .56072 Metetra
.462 .691 .966 r
.49435 .56072 .5016 .56792 .51472 .56795 .50749 .56078 Metetra
.645 .767 .937 r
.50749 .56078 .51472 .56795 .52792 .56398 .52073 .55678 Metetra
.755 .795 .886 r
.52073 .55678 .52792 .56398 .54116 .556 .53403 .54869 Metetra
.817 .801 .836 r
.53403 .54869 .54116 .556 .55441 .5442 .54734 .53672 Metetra
.853 .798 .796 r
.54734 .53672 .55441 .5442 .56762 .52897 .5606 .52125 Metetra
.874 .793 .767 r
.5606 .52125 .56762 .52897 .58075 .51089 .5738 .50288 Metetra
.886 .787 .746 r
.5738 .50288 .58075 .51089 .59379 .49065 .58691 .48234 Metetra
.891 .781 .734 r
.58691 .48234 .59379 .49065 .60673 .46909 .59992 .46045 Metetra
.891 .777 .728 r
.59992 .46045 .60673 .46909 .61958 .44709 .61284 .43812 Metetra
.887 .773 .73 r
.61284 .43812 .61958 .44709 .63236 .42555 .62568 .41629 Metetra
.877 .769 .739 r
.62568 .41629 .63236 .42555 .64511 .40539 .6385 .39586 Metetra
.861 .765 .755 r
.6385 .39586 .64511 .40539 .65789 .38745 .65133 .37771 Metetra
.834 .759 .78 r
.65133 .37771 .65789 .38745 .67076 .37249 .66425 .36261 Metetra
.791 .748 .813 r
.66425 .36261 .67076 .37249 .68377 .36116 .67731 .3512 Metetra
.721 .725 .854 r
.67731 .3512 .68377 .36116 .69702 .35393 .6906 .34399 Metetra
.608 .68 .893 r
.6906 .34399 .69702 .35393 .71056 .3511 .70419 .34127 Metetra
.439 .598 .911 r
.70419 .34127 .71056 .3511 .72447 .3527 .71813 .34306 Metetra
.223 .475 .886 r
.71813 .34306 .72447 .3527 .73876 .35843 .73247 .34906 Metetra
.013 .341 .821 r
.73247 .34906 .73876 .35843 .75346 .36759 .74722 .35857 Metetra
0 .245 .756 r
.74722 .35857 .75346 .36759 .76852 .37896 .76232 .37035 Metetra
0 .227 .741 r
.76232 .37035 .76852 .37896 .78382 .39069 .77768 .3825 Metetra
0 .323 .807 r
.77768 .3825 .78382 .39069 .79914 .40017 .79306 .39234 Metetra
.267 .563 .934 r
.79306 .39234 .79914 .40017 .81415 .40391 .80813 .39633 Metetra
.704 .797 .923 r
.80813 .39633 .81415 .40391 .82835 .39753 .82239 .38998 Metetra
.921 .83 .739 r
.82239 .38998 .82835 .39753 .8411 .37586 .8352 .36803 Metetra
.976 .789 .587 r
.8352 .36803 .8411 .37586 .85159 .33331 .84574 .32474 Metetra
.931 .563 .291 r
.21112 .5217 .21894 .52858 .22715 .5616 .21923 .55509 Metetra
.714 .201 0 r
.21923 .55509 .22715 .5616 .23736 .57443 .22943 .56792 Metetra
.589 .747 .953 r
.22943 .56792 .23736 .57443 .24894 .57245 .24105 .56568 Metetra
.819 .775 .811 r
.24105 .56568 .24894 .57245 .26134 .56061 .25354 .5534 Metetra
.857 .761 .755 r
.25354 .5534 .26134 .56061 .27417 .54313 .26647 .53537 Metetra
.864 .751 .736 r
.26647 .53537 .27417 .54313 .28711 .52336 .27952 .51504 Metetra
.858 .743 .735 r
.27952 .51504 .28711 .52336 .29998 .50388 .29249 .49501 Metetra
.843 .737 .746 r
.29249 .49501 .29998 .50388 .31265 .48652 .30525 .47713 Metetra
.817 .728 .768 r
.30525 .47713 .31265 .48652 .32508 .47248 .31776 .46265 Metetra
.772 .715 .799 r
.31776 .46265 .32508 .47248 .33726 .46251 .32999 .4523 Metetra
.698 .688 .837 r
.32999 .4523 .33726 .46251 .34921 .4569 .34199 .4464 Metetra
.578 .637 .873 r
.34199 .4464 .34921 .4569 .36098 .45566 .35378 .44494 Metetra
.396 .544 .885 r
.35378 .44494 .36098 .45566 .37264 .45854 .36545 .44767 Metetra
.161 .404 .848 r
.36545 .44767 .37264 .45854 .38424 .46506 .37705 .45411 Metetra
0 .249 .762 r
.37705 .45411 .38424 .46506 .39585 .47462 .38865 .46364 Metetra
0 .123 .669 r
.38865 .46364 .39585 .47462 .40754 .48646 .40032 .47551 Metetra
0 .047 .604 r
.40032 .47551 .40754 .48646 .41935 .49974 .41211 .48886 Metetra
0 .023 .581 r
.41211 .48886 .41935 .49974 .43133 .51359 .42407 .5028 Metetra
0 .048 .603 r
.42407 .5028 .43133 .51359 .44351 .52708 .43624 .51639 Metetra
0 .122 .666 r
.43624 .51639 .44351 .52708 .45591 .53932 .44862 .52873 Metetra
0 .24 .756 r
.44862 .52873 .45591 .53932 .46853 .54947 .46123 .53898 Metetra
.102 .387 .845 r
.46123 .53898 .46853 .54947 .48135 .5568 .47405 .54638 Metetra
.324 .526 .898 r
.47405 .54638 .48135 .5568 .49435 .56072 .48706 .55033 Metetra
.512 .628 .902 r
.48706 .55033 .49435 .56072 .50749 .56078 .50022 .5504 Metetra
.646 .688 .874 r
.50022 .5504 .50749 .56078 .52073 .55678 .5135 .54636 Metetra
.734 .718 .837 r
.5135 .54636 .52073 .55678 .53403 .54869 .52683 .53819 Metetra
.789 .733 .801 r
.52683 .53819 .53403 .54869 .54734 .53672 .54018 .5261 Metetra
.824 .739 .771 r
.54018 .5261 .54734 .53672 .5606 .52125 .55351 .51048 Metetra
.845 .741 .748 r
.55351 .51048 .5606 .52125 .5738 .50288 .56676 .49194 Metetra
.859 .74 .731 r
.56676 .49194 .5738 .50288 .58691 .48234 .57993 .47121 Metetra
.865 .739 .721 r
.57993 .47121 .58691 .48234 .59992 .46045 .593 .44914 Metetra
.867 .737 .717 r
.593 .44914 .59992 .46045 .61284 .43812 .60598 .42664 Metetra
.864 .735 .719 r
.60598 .42664 .61284 .43812 .62568 .41629 .61889 .40467 Metetra
.855 .732 .727 r
.61889 .40467 .62568 .41629 .6385 .39586 .63176 .38414 Metetra
.839 .728 .742 r
.63176 .38414 .6385 .39586 .65133 .37771 .64465 .36593 Metetra
.813 .722 .764 r
.64465 .36593 .65133 .37771 .66425 .36261 .65762 .35083 Metetra
.772 .71 .793 r
.65762 .35083 .66425 .36261 .67731 .3512 .67073 .3395 Metetra
.706 .687 .829 r
.67073 .3395 .67731 .3512 .6906 .34399 .68406 .33244 Metetra
.602 .644 .864 r
.68406 .33244 .6906 .34399 .70419 .34127 .69769 .32993 Metetra
.448 .569 .883 r
.69769 .32993 .70419 .34127 .71813 .34306 .71167 .33203 Metetra
.251 .459 .868 r
.71167 .33203 .71813 .34306 .73247 .34906 .72605 .33841 Metetra
.052 .337 .816 r
.72605 .33841 .73247 .34906 .74722 .35857 .74084 .34837 Metetra
0 .247 .761 r
.74084 .34837 .74722 .35857 .76232 .37035 .756 .36064 Metetra
0 .229 .747 r
.756 .36064 .76232 .37035 .77768 .3825 .7714 .3733 Metetra
0 .319 .807 r
.7714 .3733 .77768 .3825 .79306 .39234 .78685 .38364 Metetra
.278 .545 .922 r
.78685 .38364 .79306 .39234 .80813 .39633 .80199 .38801 Metetra
.696 .775 .912 r
.80199 .38801 .80813 .39633 .82239 .38998 .81634 .38187 Metetra
.916 .821 .738 r
.81634 .38187 .82239 .38998 .8352 .36803 .82922 .35983 Metetra
.975 .786 .587 r
.82922 .35983 .8352 .36803 .84574 .32474 .83984 .31609 Metetra
.931 .564 .292 r
.20324 .51477 .21112 .5217 .21923 .55509 .21127 .54826 Metetra
.695 .182 0 r
.21127 .54826 .21923 .55509 .22943 .56792 .22147 .56089 Metetra
.611 .74 .937 r
.22147 .56089 .22943 .56792 .24105 .56568 .23315 .55822 Metetra
.818 .762 .8 r
.23315 .55822 .24105 .56568 .25354 .5534 .24574 .54538 Metetra
.853 .748 .747 r
.24574 .54538 .25354 .5534 .26647 .53537 .25878 .52672 Metetra
.859 .738 .729 r
.25878 .52672 .26647 .53537 .27952 .51504 .27195 .50573 Metetra
.853 .73 .727 r
.27195 .50573 .27952 .51504 .29249 .49501 .28502 .48506 Metetra
.837 .722 .737 r
.28502 .48506 .29249 .49501 .30525 .47713 .29788 .46659 Metetra
.81 .711 .756 r
.29788 .46659 .30525 .47713 .31776 .46265 .31046 .45157 Metetra
.767 .694 .783 r
.31046 .45157 .31776 .46265 .32999 .4523 .32276 .44074 Metetra
.698 .665 .814 r
.32276 .44074 .32999 .4523 .34199 .4464 .3348 .43443 Metetra
.591 .614 .844 r
.3348 .43443 .34199 .4464 .35378 .44494 .34662 .43263 Metetra
.435 .531 .856 r
.34662 .43263 .35378 .44494 .36545 .44767 .3583 .43507 Metetra
.241 .414 .834 r
.3583 .43507 .36545 .44767 .37705 .45411 .3699 .44129 Metetra
.047 .286 .778 r
.3699 .44129 .37705 .45411 .38865 .46364 .38149 .45064 Metetra
0 .179 .713 r
.38149 .45064 .38865 .46364 .40032 .47551 .39314 .46238 Metetra
0 .114 .666 r
.39314 .46238 .40032 .47551 .41211 .48886 .40491 .47563 Metetra
0 .094 .652 r
.40491 .47563 .41211 .48886 .42407 .5028 .41685 .4895 Metetra
0 .12 .671 r
.41685 .4895 .42407 .5028 .43624 .51639 .42898 .50305 Metetra
0 .186 .718 r
.42898 .50305 .43624 .51639 .44862 .52873 .44134 .51537 Metetra
.049 .285 .777 r
.44134 .51537 .44862 .52873 .46123 .53898 .45394 .5256 Metetra
.221 .397 .826 r
.45394 .5256 .46123 .53898 .47405 .54638 .46675 .53298 Metetra
.391 .5 .849 r
.46675 .53298 .47405 .54638 .48706 .55033 .47976 .53691 Metetra
.533 .577 .845 r
.47976 .53691 .48706 .55033 .50022 .5504 .49293 .53694 Metetra
.639 .63 .825 r
.49293 .53694 .50022 .5504 .5135 .54636 .50622 .53286 Metetra
.713 .662 .798 r
.50622 .53286 .5135 .54636 .52683 .53819 .51959 .52463 Metetra
.763 .681 .771 r
.51959 .52463 .52683 .53819 .54018 .5261 .53297 .51248 Metetra
.797 .692 .749 r
.53297 .51248 .54018 .5261 .55351 .51048 .54634 .4968 Metetra
.82 .699 .731 r
.54634 .4968 .55351 .51048 .56676 .49194 .55965 .47819 Metetra
.834 .702 .718 r
.55965 .47819 .56676 .49194 .57993 .47121 .57287 .4574 Metetra
.842 .704 .71 r
.57287 .4574 .57993 .47121 .593 .44914 .58599 .43529 Metetra
.845 .705 .707 r
.58599 .43529 .593 .44914 .60598 .42664 .59903 .41278 Metetra
.843 .704 .71 r
.59903 .41278 .60598 .42664 .61889 .40467 .61199 .39081 Metetra
.835 .702 .717 r
.61199 .39081 .61889 .40467 .63176 .38414 .62492 .37034 Metetra
.82 .698 .731 r
.62492 .37034 .63176 .38414 .64465 .36593 .63786 .35223 Metetra
.794 .691 .751 r
.63786 .35223 .64465 .36593 .65762 .35083 .65087 .33728 Metetra
.754 .678 .777 r
.65087 .33728 .65762 .35083 .67073 .3395 .66403 .32616 Metetra
.691 .654 .809 r
.66403 .32616 .67073 .3395 .68406 .33244 .67741 .31937 Metetra
.593 .612 .841 r
.67741 .31937 .68406 .33244 .69769 .32993 .69107 .3172 Metetra
.449 .542 .859 r
.69107 .3172 .69769 .32993 .71167 .33203 .70509 .3197 Metetra
.265 .44 .848 r
.70509 .3197 .71167 .33203 .72605 .33841 .71951 .32656 Metetra
.078 .328 .806 r
.71951 .32656 .72605 .33841 .74084 .34837 .73434 .33705 Metetra
0 .243 .758 r
.73434 .33705 .74084 .34837 .756 .36064 .74955 .3499 Metetra
0 .225 .746 r
.74955 .3499 .756 .36064 .7714 .3733 .76501 .36316 Metetra
0 .308 .801 r
.76501 .36316 .7714 .3733 .78685 .38364 .78053 .37407 Metetra
.279 .523 .908 r
.78053 .37407 .78685 .38364 .80199 .38801 .79575 .37896 Metetra
.684 .753 .904 r
.79575 .37896 .80199 .38801 .81634 .38187 .81018 .37318 Metetra
.909 .812 .739 r
.81018 .37318 .81634 .38187 .82922 .35983 .82316 .35129 Metetra
.973 .784 .588 r
.82316 .35129 .82922 .35983 .83984 .31609 .83388 .30737 Metetra
.931 .563 .29 r
.19529 .50777 .20324 .51477 .21127 .54826 .20326 .54112 Metetra
.666 .153 0 r
.20326 .54112 .21127 .54826 .22147 .56089 .21349 .55336 Metetra
.633 .734 .92 r
.21349 .55336 .22147 .56089 .23315 .55822 .22524 .55013 Metetra
.818 .75 .789 r
.22524 .55013 .23315 .55822 .24574 .54538 .23794 .53662 Metetra
.85 .738 .739 r
.23794 .53662 .24574 .54538 .25878 .52672 .25109 .51724 Metetra
.855 .728 .722 r
.25109 .51724 .25878 .52672 .27195 .50573 .26438 .49553 Metetra
.849 .72 .72 r
.26438 .49553 .27195 .50573 .28502 .48506 .27757 .47416 Metetra
.833 .71 .729 r
.27757 .47416 .28502 .48506 .29788 .46659 .29053 .45502 Metetra
.806 .698 .745 r
.29053 .45502 .29788 .46659 .31046 .45157 .3032 .43939 Metetra
.764 .679 .769 r
.3032 .43939 .31046 .45157 .32276 .44074 .31556 .42801 Metetra
.699 .649 .796 r
.31556 .42801 .32276 .44074 .3348 .43443 .32765 .42119 Metetra
.602 .599 .821 r
.32765 .42119 .3348 .43443 .34662 .43263 .3395 .41893 Metetra
.466 .523 .832 r
.3395 .41893 .34662 .43263 .3583 .43507 .35119 .42096 Metetra
.301 .422 .818 r
.35119 .42096 .3583 .43507 .3699 .44129 .3628 .42682 Metetra
.136 .312 .778 r
.3628 .42682 .3699 .44129 .38149 .45064 .37438 .43585 Metetra
.004 .221 .731 r
.37438 .43585 .38149 .45064 .39314 .46238 .38601 .4473 Metetra
0 .164 .697 r
.38601 .4473 .39314 .46238 .40491 .47563 .39775 .46031 Metetra
0 .148 .686 r
.39775 .46031 .40491 .47563 .41685 .4895 .40966 .47397 Metetra
0 .171 .7 r
.40966 .47397 .41685 .4895 .42898 .50305 .42177 .48734 Metetra
.029 .228 .732 r
.42177 .48734 .42898 .50305 .44134 .51537 .4341 .4995 Metetra
.152 .308 .769 r
.4341 .4995 .44134 .51537 .45394 .5256 .44667 .50959 Metetra
.292 .397 .798 r
.44667 .50959 .45394 .5256 .46675 .53298 .45946 .51687 Metetra
.427 .478 .809 r
.45946 .51687 .46675 .53298 .47976 .53691 .47246 .52071 Metetra
.542 .542 .804 r
.47246 .52071 .47976 .53691 .49293 .53694 .48563 .52068 Metetra
.631 .589 .788 r
.48563 .52068 .49293 .53694 .50622 .53286 .49893 .51655 Metetra
.696 .621 .769 r
.49893 .51655 .50622 .53286 .51959 .52463 .51231 .50829 Metetra
.743 .643 .749 r
.51231 .50829 .51959 .52463 .53297 .51248 .52573 .49613 Metetra
.776 .657 .731 r
.52573 .49613 .53297 .51248 .54634 .4968 .53912 .48047 Metetra
.799 .666 .717 r
.53912 .48047 .54634 .4968 .55965 .47819 .55247 .4619 Metetra
.814 .673 .707 r
.55247 .4619 .55965 .47819 .57287 .4574 .56574 .44118 Metetra
.823 .676 .701 r
.56574 .44118 .57287 .4574 .58599 .43529 .57891 .41916 Metetra
.826 .678 .699 r
.57891 .41916 .58599 .43529 .59903 .41278 .592 .39678 Metetra
.825 .679 .702 r
.592 .39678 .59903 .41278 .61199 .39081 .60501 .37498 Metetra
.817 .678 .709 r
.60501 .37498 .61199 .39081 .62492 .37034 .61799 .3547 Metetra
.803 .674 .722 r
.61799 .3547 .62492 .37034 .63786 .35223 .63098 .33684 Metetra
.778 .666 .74 r
.63098 .33684 .63786 .35223 .65087 .33728 .64404 .32218 Metetra
.738 .653 .765 r
.64404 .32218 .65087 .33728 .66403 .32616 .65724 .31139 Metetra
.676 .628 .794 r
.65724 .31139 .66403 .32616 .67741 .31937 .67065 .30498 Metetra
.581 .586 .823 r
.67065 .30498 .67741 .31937 .69107 .3172 .68436 .30325 Metetra
.444 .518 .84 r
.68436 .30325 .69107 .3172 .70509 .3197 .69841 .30623 Metetra
.269 .422 .831 r
.69841 .30623 .70509 .3197 .71951 .32656 .71287 .31364 Metetra
.089 .315 .793 r
.71287 .31364 .71951 .32656 .73434 .33705 .72774 .32472 Metetra
0 .234 .75 r
.72774 .32472 .73434 .33705 .74955 .3499 .74299 .33821 Metetra
0 .215 .739 r
.74299 .33821 .74955 .3499 .76501 .36316 .75851 .35213 Metetra
0 .294 .791 r
.75851 .35213 .76501 .36316 .78053 .37407 .77409 .36371 Metetra
.271 .499 .893 r
.77409 .36371 .78053 .37407 .79575 .37896 .78939 .36922 Metetra
.668 .732 .897 r
.78939 .36922 .79575 .37896 .81018 .37318 .80392 .36395 Metetra
.902 .803 .741 r
.80392 .36395 .81018 .37318 .82316 .35129 .81702 .3424 Metetra
.972 .782 .59 r
.81702 .3424 .82316 .35129 .83388 .30737 .82786 .29856 Metetra
.93 .561 .287 r
.18727 .50072 .19529 .50777 .20326 .54112 .19522 .53368 Metetra
.624 .111 0 r
.19522 .53368 .20326 .54112 .21349 .55336 .20548 .54536 Metetra
.656 .729 .903 r
.20548 .54536 .21349 .55336 .22524 .55013 .21732 .54145 Metetra
.819 .741 .778 r
.21732 .54145 .22524 .55013 .23794 .53662 .23013 .5272 Metetra
.849 .729 .732 r
.23013 .5272 .23794 .53662 .25109 .51724 .24341 .50705 Metetra
.853 .72 .715 r
.24341 .50705 .25109 .51724 .26438 .49553 .25682 .48458 Metetra
.847 .711 .714 r
.25682 .48458 .26438 .49553 .27757 .47416 .27013 .46247 Metetra
.831 .702 .721 r
.27013 .46247 .27757 .47416 .29053 .45502 .2832 .44263 Metetra
.805 .689 .737 r
.2832 .44263 .29053 .45502 .3032 .43939 .29595 .42634 Metetra
.764 .669 .758 r
.29595 .42634 .3032 .43939 .31556 .42801 .30838 .41433 Metetra
.702 .638 .782 r
.30838 .41433 .31556 .42801 .32765 .42119 .32052 .40693 Metetra
.612 .59 .804 r
.32052 .40693 .32765 .42119 .3395 .41893 .33241 .40412 Metetra
.491 .519 .814 r
.33241 .40412 .3395 .41893 .35119 .42096 .34412 .40564 Metetra
.346 .429 .804 r
.34412 .40564 .35119 .42096 .3628 .42682 .35573 .41102 Metetra
.201 .333 .774 r
.35573 .41102 .3628 .42682 .37438 .43585 .3673 .41961 Metetra
.086 .251 .738 r
.3673 .41961 .37438 .43585 .38601 .4473 .37891 .43064 Metetra
.018 .201 .71 r
.37891 .43064 .38601 .4473 .39775 .46031 .39063 .44327 Metetra
.003 .186 .701 r
.39063 .44327 .39775 .46031 .40966 .47397 .40251 .45658 Metetra
.037 .206 .71 r
.40251 .45658 .40966 .47397 .42177 .48734 .41458 .46964 Metetra
.113 .255 .732 r
.41458 .46964 .42177 .48734 .4341 .4995 .42689 .48152 Metetra
.218 .321 .756 r
.42689 .48152 .4341 .4995 .44667 .50959 .43943 .49139 Metetra
.336 .394 .774 r
.43943 .49139 .44667 .50959 .45946 .51687 .4522 .49847 Metetra
.449 .462 .781 r
.4522 .49847 .45946 .51687 .47246 .52071 .46518 .50217 Metetra
.547 .518 .776 r
.46518 .50217 .47246 .52071 .48563 .52068 .47834 .50204 Metetra
.624 .561 .763 r
.47834 .50204 .48563 .52068 .49893 .51655 .49164 .49785 Metetra
.684 .593 .748 r
.49164 .49785 .49893 .51655 .51231 .50829 .50502 .4896 Metetra
.727 .615 .732 r
.50502 .4896 .51231 .50829 .52573 .49613 .51845 .47748 Metetra
.759 .631 .718 r
.51845 .47748 .52573 .49613 .53912 .48047 .53187 .46191 Metetra
.782 .642 .707 r
.53187 .46191 .53912 .48047 .55247 .4619 .54525 .44348 Metetra
.798 .65 .699 r
.54525 .44348 .55247 .4619 .56574 .44118 .55856 .42294 Metetra
.807 .655 .694 r
.55856 .42294 .56574 .44118 .57891 .41916 .57177 .40115 Metetra
.811 .658 .693 r
.57177 .40115 .57891 .41916 .592 .39678 .5849 .37902 Metetra
.81 .66 .696 r
.5849 .37902 .592 .39678 .60501 .37498 .59796 .35752 Metetra
.803 .659 .703 r
.59796 .35752 .60501 .37498 .61799 .3547 .61099 .33758 Metetra
.788 .655 .716 r
.61099 .33758 .61799 .3547 .63098 .33684 .62402 .32009 Metetra
.763 .647 .733 r
.62402 .32009 .63098 .33684 .64404 .32218 .63713 .30583 Metetra
.724 .633 .757 r
.63713 .30583 .64404 .32218 .65724 .31139 .65037 .29547 Metetra
.662 .608 .784 r
.65037 .29547 .65724 .31139 .67065 .30498 .66382 .28954 Metetra
.568 .565 .81 r
.66382 .28954 .67065 .30498 .68436 .30325 .67756 .28832 Metetra
.434 .497 .825 r
.67756 .28832 .68436 .30325 .69841 .30623 .69165 .29186 Metetra
.263 .403 .816 r
.69165 .29186 .69841 .30623 .71287 .31364 .70614 .29985 Metetra
.089 .3 .78 r
.70614 .29985 .71287 .31364 .72774 .32472 .72105 .31157 Metetra
0 .221 .74 r
.72105 .31157 .72774 .32472 .74299 .33821 .73634 .32573 Metetra
0 .202 .73 r
.73634 .32573 .74299 .33821 .75851 .35213 .75191 .34036 Metetra
0 .277 .779 r
.75191 .34036 .75851 .35213 .77409 .36371 .76756 .35265 Metetra
.257 .475 .878 r
.76756 .35265 .77409 .36371 .78939 .36922 .78294 .35885 Metetra
.65 .711 .892 r
.78294 .35885 .78939 .36922 .80392 .36395 .79757 .35422 Metetra
.894 .795 .744 r
.79757 .35422 .80392 .36395 .81702 .3424 .81079 .33317 Metetra
.97 .78 .593 r
.81079 .33317 .81702 .3424 .82786 .29856 .82179 .28967 Metetra
.929 .557 .281 r
.17919 .49361 .18727 .50072 .19522 .53368 .18713 .52597 Metetra
.567 .057 0 r
.18713 .52597 .19522 .53368 .20548 .54536 .19744 .53694 Metetra
.676 .726 .887 r
.19744 .53694 .20548 .54536 .21732 .54145 .20938 .53228 Metetra
.821 .734 .769 r
.20938 .53228 .21732 .54145 .23013 .5272 .2223 .51724 Metetra
.848 .723 .725 r
.2223 .51724 .23013 .5272 .24341 .50705 .23572 .49631 Metetra
.852 .714 .71 r
.23572 .49631 .24341 .50705 .25682 .48458 .24926 .47308 Metetra
.846 .706 .708 r
.24926 .47308 .25682 .48458 .27013 .46247 .26269 .45022 Metetra
.831 .696 .716 r
.26269 .45022 .27013 .46247 .2832 .44263 .27586 .42967 Metetra
.805 .683 .73 r
.27586 .42967 .2832 .44263 .29595 .42634 .28871 .4127 Metetra
.766 .664 .75 r
.28871 .4127 .29595 .42634 .30838 .41433 .30121 .40003 Metetra
.707 .633 .772 r
.30121 .40003 .30838 .41433 .32052 .40693 .3134 .39199 Metetra
.624 .587 .792 r
.3134 .39199 .32052 .40693 .33241 .40412 .32533 .38857 Metetra
.512 .521 .802 r
.32533 .38857 .33241 .40412 .34412 .40564 .33707 .3895 Metetra
.38 .437 .795 r
.33707 .3895 .34412 .40564 .35573 .41102 .34868 .3943 Metetra
.249 .349 .771 r
.34868 .3943 .35573 .41102 .3673 .41961 .36025 .40234 Metetra
.144 .275 .741 r
.36025 .40234 .3673 .41961 .37891 .43064 .37185 .41284 Metetra
.082 .228 .717 r
.37185 .41284 .37891 .43064 .39063 .44327 .38354 .42497 Metetra
.069 .214 .707 r
.38354 .42497 .39063 .44327 .40251 .45658 .39539 .43782 Metetra
.1 .231 .713 r
.39539 .43782 .40251 .45658 .41458 .46964 .40744 .45045 Metetra
.169 .273 .728 r
.40744 .45045 .41458 .46964 .42689 .48152 .41971 .46196 Metetra
.262 .33 .746 r
.41971 .46196 .42689 .48152 .43943 .49139 .43221 .4715 Metetra
.364 .393 .758 r
.43221 .4715 .43943 .49139 .4522 .49847 .44495 .47832 Metetra
.463 .453 .761 r
.44495 .47832 .4522 .49847 .46518 .50217 .45791 .48182 Metetra
.549 .503 .757 r
.45791 .48182 .46518 .50217 .47834 .50204 .47106 .48157 Metetra
.619 .543 .747 r
.47106 .48157 .47834 .50204 .49164 .49785 .48435 .47733 Metetra
.674 .574 .734 r
.48435 .47733 .49164 .49785 .50502 .4896 .49773 .4691 Metetra
.716 .596 .721 r
.49773 .4691 .50502 .4896 .51845 .47748 .51117 .45707 Metetra
.747 .613 .709 r
.51117 .45707 .51845 .47748 .53187 .46191 .52461 .44166 Metetra
.77 .625 .7 r
.52461 .44166 .53187 .46191 .54525 .44348 .53801 .42346 Metetra
.786 .634 .693 r
.53801 .42346 .54525 .44348 .55856 .42294 .55134 .4032 Metetra
.795 .64 .689 r
.55134 .4032 .55856 .42294 .57177 .40115 .5646 .38174 Metetra
.8 .644 .689 r
.5646 .38174 .57177 .40115 .5849 .37902 .57777 .35999 Metetra
.799 .646 .692 r
.57777 .35999 .5849 .37902 .59796 .35752 .59087 .33891 Metetra
.792 .646 .7 r
.59087 .33891 .59796 .35752 .61099 .33758 .60394 .31942 Metetra
.777 .642 .712 r
.60394 .31942 .61099 .33758 .62402 .32009 .61702 .30239 Metetra
.752 .634 .73 r
.61702 .30239 .62402 .32009 .63713 .30583 .63016 .28863 Metetra
.712 .619 .752 r
.63016 .28863 .63713 .30583 .65037 .29547 .64344 .27879 Metetra
.649 .593 .778 r
.64344 .27879 .65037 .29547 .66382 .28954 .65693 .27339 Metetra
.554 .549 .803 r
.65693 .27339 .66382 .28954 .67756 .28832 .6707 .27274 Metetra
.419 .48 .816 r
.6707 .27274 .67756 .28832 .69165 .29186 .68483 .27686 Metetra
.25 .385 .805 r
.68483 .27686 .69165 .29186 .70614 .29985 .69935 .28547 Metetra
.078 .283 .768 r
.69935 .28547 .70614 .29985 .72105 .31157 .71429 .29783 Metetra
0 .205 .728 r
.71429 .29783 .72105 .31157 .73634 .32573 .72961 .31266 Metetra
0 .186 .718 r
.72961 .31266 .73634 .32573 .75191 .34036 .74523 .32799 Metetra
0 .258 .765 r
.74523 .32799 .75191 .34036 .76756 .35265 .76093 .341 Metetra
.237 .451 .865 r
.76093 .341 .76756 .35265 .78294 .35885 .7764 .34794 Metetra
.629 .691 .889 r
.7764 .34794 .78294 .35885 .79757 .35422 .79113 .34402 Metetra
.885 .788 .749 r
.79113 .34402 .79757 .35422 .81079 .33317 .80449 .32364 Metetra
.967 .779 .597 r
.80449 .32364 .81079 .33317 .82179 .28967 .81567 .2807 Metetra
.927 .553 .273 r
.17105 .48644 .17919 .49361 .18713 .52597 .17899 .51801 Metetra
.496 0 0 r
.17899 .51801 .18713 .52597 .19744 .53694 .18937 .52818 Metetra
.695 .723 .872 r
.18937 .52818 .19744 .53694 .20938 .53228 .20141 .52271 Metetra
.823 .729 .761 r
.20141 .52271 .20938 .53228 .2223 .51724 .21446 .50688 Metetra
.848 .719 .72 r
.21446 .50688 .2223 .51724 .23572 .49631 .228 .4852 Metetra
.853 .711 .706 r
.228 .4852 .23572 .49631 .24926 .47308 .24168 .46123 Metetra
.846 .703 .704 r
.24168 .46123 .24926 .47308 .26269 .45022 .25522 .43768 Metetra
.832 .694 .712 r
.25522 .43768 .26269 .45022 .27586 .42967 .2685 .41644 Metetra
.808 .682 .725 r
.2685 .41644 .27586 .42967 .28871 .4127 .28144 .39879 Metetra
.77 .663 .745 r
.28144 .39879 .28871 .4127 .30121 .40003 .29403 .38547 Metetra
.715 .634 .766 r
.29403 .38547 .30121 .40003 .3134 .39199 .30628 .37677 Metetra
.635 .59 .786 r
.30628 .37677 .3134 .39199 .32533 .38857 .31825 .3727 Metetra
.53 .528 .797 r
.31825 .3727 .32533 .38857 .33707 .3895 .33001 .37299 Metetra
.406 .449 .792 r
.33001 .37299 .33707 .3895 .34868 .3943 .34164 .37714 Metetra
.283 .365 .771 r
.34164 .37714 .34868 .3943 .36025 .40234 .35321 .38455 Metetra
.184 .295 .744 r
.35321 .38455 .36025 .40234 .37185 .41284 .3648 .39444 Metetra
.125 .249 .722 r
.3648 .39444 .37185 .41284 .38354 .42497 .37647 .40598 Metetra
.112 .235 .712 r
.37647 .40598 .38354 .42497 .39539 .43782 .3883 .41827 Metetra
.141 .249 .715 r
.3883 .41827 .39539 .43782 .40744 .45045 .40031 .43038 Metetra
.204 .286 .727 r
.40031 .43038 .40744 .45045 .41971 .46196 .41255 .44143 Metetra
.289 .338 .74 r
.41255 .44143 .41971 .46196 .43221 .4715 .42502 .45057 Metetra
.382 .394 .749 r
.42502 .45057 .43221 .4715 .44495 .47832 .43773 .45707 Metetra
.472 .448 .75 r
.43773 .45707 .44495 .47832 .45791 .48182 .45066 .46033 Metetra
.551 .495 .746 r
.45066 .46033 .45791 .48182 .47106 .48157 .46379 .45993 Metetra
.616 .533 .737 r
.46379 .45993 .47106 .48157 .48435 .47733 .47706 .45564 Metetra
.668 .562 .726 r
.47706 .45564 .48435 .47733 .49773 .4691 .49044 .44745 Metetra
.709 .585 .715 r
.49044 .44745 .49773 .4691 .51117 .45707 .50388 .43555 Metetra
.739 .602 .704 r
.50388 .43555 .51117 .45707 .52461 .44166 .51733 .42036 Metetra
.761 .615 .696 r
.51733 .42036 .52461 .44166 .53801 .42346 .53075 .40245 Metetra
.777 .624 .69 r
.53075 .40245 .53801 .42346 .55134 .4032 .54412 .38256 Metetra
.787 .631 .687 r
.54412 .38256 .55134 .4032 .5646 .38174 .5574 .36153 Metetra
.792 .636 .688 r
.5574 .36153 .5646 .38174 .57777 .35999 .57061 .34025 Metetra
.791 .638 .692 r
.57061 .34025 .57777 .35999 .59087 .33891 .58375 .31968 Metetra
.784 .638 .699 r
.58375 .31968 .59087 .33891 .60394 .31942 .59686 .30072 Metetra
.769 .635 .712 r
.59686 .30072 .60394 .31942 .61702 .30239 .60998 .28425 Metetra
.744 .627 .73 r
.60998 .28425 .61702 .30239 .63016 .28863 .62317 .27104 Metetra
.702 .611 .752 r
.62317 .27104 .63016 .28863 .64344 .27879 .63648 .26178 Metetra
.637 .584 .778 r
.63648 .26178 .64344 .27879 .65693 .27339 .65001 .25695 Metetra
.539 .538 .802 r
.65001 .25695 .65693 .27339 .6707 .27274 .66381 .25688 Metetra
.4 .465 .812 r
.66381 .25688 .6707 .27274 .68483 .27686 .67796 .26158 Metetra
.228 .368 .797 r
.67796 .26158 .68483 .27686 .69935 .28547 .6925 .27079 Metetra
.056 .264 .758 r
.6925 .27079 .69935 .28547 .71429 .29783 .70747 .28376 Metetra
0 .187 .716 r
.70747 .28376 .71429 .29783 .72961 .31266 .72283 .29922 Metetra
0 .167 .705 r
.72283 .29922 .72961 .31266 .74523 .32799 .73848 .31522 Metetra
0 .237 .752 r
.73848 .31522 .74523 .32799 .76093 .341 .75424 .32893 Metetra
.213 .427 .853 r
.75424 .32893 .76093 .341 .7764 .34794 .76977 .33659 Metetra
.607 .673 .887 r
.76977 .33659 .7764 .34794 .79113 .34402 .78462 .33344 Metetra
.875 .782 .755 r
.78462 .33344 .79113 .34402 .80449 .32364 .79812 .31382 Metetra
.965 .778 .601 r
.79812 .31382 .80449 .32364 .81567 .2807 .80948 .27165 Metetra
.926 .547 .263 r
.16283 .47921 .17105 .48644 .17899 .51801 .17081 .50983 Metetra
0 .081 .584 r
.17081 .50983 .17899 .51801 .18937 .52818 .18126 .51913 Metetra
.711 .722 .859 r
.18126 .51913 .18937 .52818 .20141 .52271 .19341 .51286 Metetra
.826 .726 .754 r
.19341 .51286 .20141 .52271 .21446 .50688 .20658 .4963 Metetra
.85 .717 .716 r
.20658 .4963 .21446 .50688 .228 .4852 .22025 .47393 Metetra
.854 .71 .703 r
.22025 .47393 .228 .4852 .24168 .46123 .23405 .44931 Metetra
.849 .704 .702 r
.23405 .44931 .24168 .46123 .25522 .43768 .24772 .42512 Metetra
.835 .696 .709 r
.24772 .42512 .25522 .43768 .2685 .41644 .2611 .40327 Metetra
.812 .684 .723 r
.2611 .40327 .2685 .41644 .28144 .39879 .27413 .38501 Metetra
.777 .667 .742 r
.27413 .38501 .28144 .39879 .29403 .38547 .28679 .37105 Metetra
.724 .641 .765 r
.28679 .37105 .29403 .38547 .30628 .37677 .29911 .36172 Metetra
.648 .599 .786 r
.29911 .36172 .30628 .37677 .31825 .3727 .31113 .35699 Metetra
.547 .539 .798 r
.31113 .35699 .31825 .3727 .33001 .37299 .32292 .35661 Metetra
.427 .463 .795 r
.32292 .35661 .33001 .37299 .34164 .37714 .33457 .36009 Metetra
.306 .382 .777 r
.33457 .36009 .34164 .37714 .35321 .38455 .34615 .36681 Metetra
.209 .312 .751 r
.34615 .36681 .35321 .38455 .3648 .39444 .35773 .37603 Metetra
.151 .267 .73 r
.35773 .37603 .3648 .39444 .37647 .40598 .36939 .38691 Metetra
.137 .251 .719 r
.36939 .38691 .37647 .40598 .3883 .41827 .38119 .39856 Metetra
.165 .263 .72 r
.38119 .39856 .3883 .41827 .40031 .43038 .39318 .41009 Metetra
.225 .297 .729 r
.39318 .41009 .40031 .43038 .41255 .44143 .40539 .4206 Metetra
.305 .345 .739 r
.40539 .4206 .41255 .44143 .42502 .45057 .41783 .42929 Metetra
.393 .398 .746 r
.41783 .42929 .42502 .45057 .43773 .45707 .43051 .43542 Metetra
.478 .449 .747 r
.43051 .43542 .43773 .45707 .45066 .46033 .44342 .43841 Metetra
.553 .493 .742 r
.44342 .43841 .45066 .46033 .46379 .45993 .45652 .43784 Metetra
.615 .529 .733 r
.45652 .43784 .46379 .45993 .47706 .45564 .46978 .43349 Metetra
.666 .558 .723 r
.46978 .43349 .47706 .45564 .49044 .44745 .48315 .42536 Metetra
.705 .58 .713 r
.48315 .42536 .49044 .44745 .50388 .43555 .49659 .41363 Metetra
.735 .597 .703 r
.49659 .41363 .50388 .43555 .51733 .42036 .51005 .39871 Metetra
.757 .61 .696 r
.51005 .39871 .51733 .42036 .53075 .40245 .52349 .38116 Metetra
.773 .621 .691 r
.52349 .38116 .53075 .40245 .54412 .38256 .53688 .3617 Metetra
.783 .628 .688 r
.53688 .3617 .54412 .38256 .5574 .36153 .55019 .34116 Metetra
.788 .633 .689 r
.55019 .34116 .5574 .36153 .57061 .34025 .56344 .32043 Metetra
.787 .636 .693 r
.56344 .32043 .57061 .34025 .58375 .31968 .57662 .30043 Metetra
.78 .636 .702 r
.57662 .30043 .58375 .31968 .59686 .30072 .58977 .28207 Metetra
.765 .633 .715 r
.58977 .28207 .59686 .30072 .60998 .28425 .60293 .2662 Metetra
.738 .625 .733 r
.60293 .2662 .60998 .28425 .62317 .27104 .61615 .2536 Metetra
.695 .61 .757 r
.61615 .2536 .62317 .27104 .63648 .26178 .62951 .24492 Metetra
.627 .581 .783 r
.62951 .24492 .63648 .26178 .65001 .25695 .64306 .24068 Metetra
.523 .531 .806 r
.64306 .24068 .65001 .25695 .66381 .25688 .65689 .24116 Metetra
.377 .454 .813 r
.65689 .24116 .66381 .25688 .67796 .26158 .67106 .24642 Metetra
.198 .351 .793 r
.67106 .24642 .67796 .26158 .6925 .27079 .68563 .25616 Metetra
.023 .244 .747 r
.68563 .25616 .6925 .27079 .70747 .28376 .70061 .26967 Metetra
0 .166 .702 r
.70061 .26967 .70747 .28376 .72283 .29922 .71599 .28569 Metetra
0 .147 .691 r
.71599 .28569 .72283 .29922 .73848 .31522 .73168 .30226 Metetra
0 .217 .739 r
.73168 .30226 .73848 .31522 .75424 .32893 .74748 .3166 Metetra
.186 .406 .843 r
.74748 .3166 .75424 .32893 .76977 .33659 .76308 .32494 Metetra
.585 .657 .887 r
.76308 .32494 .76977 .33659 .78462 .33344 .77803 .32254 Metetra
.866 .777 .761 r
.77803 .32254 .78462 .33344 .79812 .31382 .79168 .30376 Metetra
.963 .778 .607 r
.79168 .30376 .79812 .31382 .80948 .27165 .80324 .26251 Metetra
.923 .54 .25 r
.15455 .47192 .16283 .47921 .17081 .50983 .16257 .50147 Metetra
0 .157 .66 r
.16257 .50147 .17081 .50983 .18126 .51913 .17311 .50987 Metetra
.724 .722 .848 r
.17311 .50987 .18126 .51913 .19341 .51286 .18536 .50285 Metetra
.829 .725 .75 r
.18536 .50285 .19341 .51286 .20658 .4963 .19864 .48565 Metetra
.852 .717 .714 r
.19864 .48565 .20658 .4963 .22025 .47393 .21244 .46272 Metetra
.857 .712 .701 r
.21244 .46272 .22025 .47393 .23405 .44931 .22635 .43758 Metetra
.852 .706 .7 r
.22635 .43758 .23405 .44931 .24772 .42512 .24013 .41289 Metetra
.84 .7 .708 r
.24013 .41289 .24772 .42512 .2611 .40327 .25362 .39053 Metetra
.819 .691 .723 r
.25362 .39053 .2611 .40327 .27413 .38501 .26675 .37173 Metetra
.786 .677 .743 r
.26675 .37173 .27413 .38501 .28679 .37105 .27948 .35722 Metetra
.736 .653 .767 r
.27948 .35722 .28679 .37105 .29911 .36172 .29186 .3473 Metetra
.662 .615 .791 r
.29186 .3473 .29911 .36172 .31113 .35699 .30393 .34195 Metetra
.563 .558 .806 r
.30393 .34195 .31113 .35699 .32292 .35661 .31577 .34091 Metetra
.442 .483 .806 r
.31577 .34091 .32292 .35661 .33457 .36009 .32744 .34371 Metetra
.32 .401 .789 r
.32744 .34371 .33457 .36009 .34615 .36681 .33903 .34973 Metetra
.22 .329 .763 r
.33903 .34973 .34615 .36681 .35773 .37603 .35061 .35824 Metetra
.16 .282 .741 r
.35061 .35824 .35773 .37603 .36939 .38691 .36227 .36841 Metetra
.146 .264 .729 r
.36227 .36841 .36939 .38691 .38119 .39856 .37406 .37939 Metetra
.173 .275 .729 r
.37406 .37939 .38119 .39856 .39318 .41009 .38602 .39028 Metetra
.232 .308 .736 r
.38602 .39028 .39318 .41009 .40539 .4206 .39821 .40021 Metetra
.311 .354 .745 r
.39821 .40021 .40539 .4206 .41783 .42929 .41063 .4084 Metetra
.397 .405 .751 r
.41063 .4084 .41783 .42929 .43051 .43542 .42328 .41412 Metetra
.481 .454 .75 r
.42328 .41412 .43051 .43542 .44342 .43841 .43616 .41681 Metetra
.555 .496 .745 r
.43616 .41681 .44342 .43841 .45652 .43784 .44925 .41607 Metetra
.616 .532 .736 r
.44925 .41607 .45652 .43784 .46978 .43349 .46249 .41167 Metetra
.666 .56 .726 r
.46249 .41167 .46978 .43349 .48315 .42536 .47586 .4036 Metetra
.705 .582 .715 r
.47586 .4036 .48315 .42536 .49659 .41363 .4893 .39207 Metetra
.734 .599 .706 r
.4893 .39207 .49659 .41363 .51005 .39871 .50276 .37744 Metetra
.757 .613 .699 r
.50276 .37744 .51005 .39871 .52349 .38116 .51622 .3603 Metetra
.773 .623 .694 r
.51622 .3603 .52349 .38116 .53688 .3617 .52963 .34132 Metetra
.783 .631 .692 r
.52963 .34132 .53688 .3617 .55019 .34116 .54298 .32133 Metetra
.788 .637 .693 r
.54298 .32133 .55019 .34116 .56344 .32043 .55626 .3012 Metetra
.788 .64 .698 r
.55626 .3012 .56344 .32043 .57662 .30043 .56948 .28182 Metetra
.78 .641 .708 r
.56948 .28182 .57662 .30043 .58977 .28207 .58268 .26408 Metetra
.765 .639 .722 r
.58268 .26408 .58977 .28207 .60293 .2662 .59588 .24883 Metetra
.737 .631 .742 r
.59588 .24883 .60293 .2662 .61615 .2536 .60914 .23684 Metetra
.69 .615 .767 r
.60914 .23684 .61615 .2536 .62951 .24492 .62253 .22874 Metetra
.617 .585 .795 r
.62253 .22874 .62951 .24492 .64306 .24068 .63612 .22504 Metetra
.505 .531 .817 r
.63612 .22504 .64306 .24068 .65689 .24116 .64997 .22604 Metetra
.347 .446 .821 r
.64997 .22604 .65689 .24116 .67106 .24642 .66416 .23177 Metetra
.158 .335 .792 r
.66416 .23177 .67106 .24642 .68563 .25616 .67875 .24196 Metetra
0 .222 .737 r
.67875 .24196 .68563 .25616 .70061 .26967 .69374 .2559 Metetra
0 .143 .688 r
.69374 .2559 .70061 .26967 .71599 .28569 .70914 .27235 Metetra
0 .126 .676 r
.70914 .27235 .71599 .28569 .73168 .30226 .72484 .28936 Metetra
0 .196 .726 r
.72484 .28936 .73168 .30226 .74748 .3166 .74067 .30419 Metetra
.157 .387 .835 r
.74067 .30419 .74748 .3166 .76308 .32494 .75633 .31311 Metetra
.563 .644 .889 r
.75633 .31311 .76308 .32494 .77803 .32254 .77137 .3114 Metetra
.857 .773 .769 r
.77137 .3114 .77803 .32254 .79168 .30376 .78517 .29349 Metetra
.96 .778 .613 r
.78517 .29349 .79168 .30376 .80324 .26251 .79694 .25328 Metetra
.92 .531 .236 r
.14619 .46457 .15455 .47192 .16257 .50147 .15428 .49297 Metetra
0 .231 .726 r
.15428 .49297 .16257 .50147 .17311 .50987 .1649 .5005 Metetra
.735 .724 .841 r
.1649 .5005 .17311 .50987 .18536 .50285 .17725 .49283 Metetra
.832 .725 .747 r
.17725 .49283 .18536 .50285 .19864 .48565 .19064 .47513 Metetra
.855 .72 .713 r
.19064 .47513 .19864 .48565 .21244 .46272 .20454 .4518 Metetra
.86 .716 .701 r
.20454 .4518 .21244 .46272 .22635 .43758 .21856 .42632 Metetra
.857 .712 .701 r
.21856 .42632 .22635 .43758 .24013 .41289 .23244 .40129 Metetra
.847 .708 .709 r
.23244 .40129 .24013 .41289 .25362 .39053 .24603 .37857 Metetra
.828 .702 .725 r
.24603 .37857 .25362 .39053 .26675 .37173 .25924 .35939 Metetra
.797 .691 .748 r
.25924 .35939 .26675 .37173 .27948 .35722 .27205 .34443 Metetra
.75 .672 .775 r
.27205 .34443 .27948 .35722 .29186 .3473 .2845 .33401 Metetra
.678 .638 .802 r
.2845 .33401 .29186 .3473 .30393 .34195 .29662 .3281 Metetra
.578 .584 .823 r
.29662 .3281 .30393 .34195 .31577 .34091 .30849 .32645 Metetra
.453 .509 .826 r
.30849 .32645 .31577 .34091 .32744 .34371 .3202 .32859 Metetra
.324 .424 .81 r
.3202 .32859 .32744 .34371 .33903 .34973 .33181 .33391 Metetra
.217 .347 .782 r
.33181 .33391 .33903 .34973 .35061 .35824 .3434 .34171 Metetra
.152 .296 .758 r
.3434 .34171 .35061 .35824 .36227 .36841 .35506 .35116 Metetra
.136 .276 .744 r
.35506 .35116 .36227 .36841 .37406 .37939 .36684 .36143 Metetra
.163 .285 .743 r
.36684 .36143 .37406 .37939 .38602 .39028 .3788 .37166 Metetra
.225 .318 .75 r
.3788 .37166 .38602 .39028 .39821 .40021 .39097 .38099 Metetra
.307 .365 .759 r
.39097 .38099 .39821 .40021 .41063 .4084 .40337 .38865 Metetra
.396 .416 .763 r
.40337 .38865 .41063 .4084 .42328 .41412 .41601 .39394 Metetra
.482 .465 .762 r
.41601 .39394 .42328 .41412 .43616 .41681 .42887 .39632 Metetra
.557 .507 .755 r
.42887 .39632 .43616 .41681 .44925 .41607 .44194 .39539 Metetra
.619 .542 .745 r
.44194 .39539 .44925 .41607 .46249 .41167 .45517 .39093 Metetra
.669 .57 .734 r
.45517 .39093 .46249 .41167 .47586 .4036 .46854 .38295 Metetra
.708 .592 .723 r
.46854 .38295 .47586 .4036 .4893 .39207 .48198 .37162 Metetra
.738 .609 .714 r
.48198 .37162 .4893 .39207 .50276 .37744 .49546 .35733 Metetra
.761 .622 .706 r
.49546 .35733 .50276 .37744 .51622 .3603 .50893 .34061 Metetra
.777 .633 .701 r
.50893 .34061 .51622 .3603 .52963 .34132 .52237 .32215 Metetra
.788 .641 .7 r
.52237 .32215 .52963 .34132 .54298 .32133 .53576 .30274 Metetra
.793 .648 .701 r
.53576 .30274 .54298 .32133 .55626 .3012 .54908 .28322 Metetra
.793 .652 .707 r
.54908 .28322 .55626 .3012 .56948 .28182 .56234 .26448 Metetra
.785 .654 .718 r
.56234 .26448 .56948 .28182 .58268 .26408 .57558 .24738 Metetra
.769 .653 .734 r
.57558 .24738 .58268 .26408 .59588 .24883 .58883 .23275 Metetra
.739 .646 .756 r
.58883 .23275 .59588 .24883 .60914 .23684 .60213 .22133 Metetra
.689 .63 .784 r
.60213 .22133 .60914 .23684 .62253 .22874 .61556 .21377 Metetra
.609 .597 .814 r
.61556 .21377 .62253 .22874 .63612 .22504 .62918 .21056 Metetra
.483 .538 .837 r
.62918 .21056 .63612 .22504 .64997 .22604 .64306 .21197 Metetra
.308 .442 .834 r
.64306 .21197 .64997 .22604 .66416 .23177 .65727 .21807 Metetra
.104 .318 .792 r
.65727 .21807 .66416 .23177 .67875 .24196 .67187 .22857 Metetra
0 .198 .726 r
.67187 .22857 .67875 .24196 .69374 .2559 .68687 .24278 Metetra
0 .119 .67 r
.68687 .24278 .69374 .2559 .70914 .27235 .70226 .25947 Metetra
0 .104 .659 r
.70226 .25947 .70914 .27235 .72484 .28936 .71798 .27675 Metetra
0 .178 .713 r
.71798 .27675 .72484 .28936 .74067 .30419 .73383 .29189 Metetra
.127 .371 .829 r
.73383 .29189 .74067 .30419 .75633 .31311 .74954 .30123 Metetra
.543 .635 .892 r
.74954 .30123 .75633 .31311 .77137 .3114 .76466 .30012 Metetra
.848 .771 .776 r
.76466 .30012 .77137 .3114 .78517 .29349 .77859 .28304 Metetra
.957 .778 .619 r
.77859 .28304 .78517 .29349 .79694 .25328 .79058 .24397 Metetra
.916 .521 .22 r
.13777 .45715 .14619 .46457 .15428 .49297 .14592 .48436 Metetra
0 .297 .78 r
.14592 .48436 .15428 .49297 .1649 .5005 .15662 .49108 Metetra
.743 .726 .836 r
.15662 .49108 .1649 .5005 .17725 .49283 .16906 .4829 Metetra
.835 .728 .746 r
.16906 .4829 .17725 .49283 .19064 .47513 .18254 .46492 Metetra
.858 .724 .713 r
.18254 .46492 .19064 .47513 .20454 .4518 .19653 .44141 Metetra
.865 .722 .702 r
.19653 .44141 .20454 .4518 .21856 .42632 .21064 .41581 Metetra
.864 .721 .703 r
.21064 .41581 .21856 .42632 .23244 .40129 .22461 .39066 Metetra
.855 .72 .713 r
.22461 .39066 .23244 .40129 .24603 .37857 .23828 .36778 Metetra
.839 .718 .73 r
.23828 .36778 .24603 .37857 .25924 .35939 .25157 .34837 Metetra
.811 .712 .756 r
.25157 .34837 .25924 .35939 .27205 .34443 .26445 .33312 Metetra
.766 .699 .787 r
.26445 .33312 .27205 .34443 .2845 .33401 .27696 .32232 Metetra
.696 .671 .822 r
.27696 .32232 .2845 .33401 .29662 .3281 .28914 .31595 Metetra
.592 .621 .849 r
.28914 .31595 .29662 .3281 .30849 .32645 .30106 .31376 Metetra
.457 .545 .858 r
.30106 .31376 .30849 .32645 .3202 .32859 .3128 .31529 Metetra
.313 .453 .841 r
.3128 .31529 .3202 .32859 .33181 .33391 .32444 .31996 Metetra
.192 .367 .809 r
.32444 .31996 .33181 .33391 .3434 .34171 .33606 .32706 Metetra
.119 .308 .78 r
.33606 .32706 .3434 .34171 .35506 .35116 .34773 .33581 Metetra
.101 .285 .764 r
.34773 .33581 .35506 .35116 .36684 .36143 .35951 .34538 Metetra
.132 .294 .763 r
.35951 .34538 .36684 .36143 .3788 .37166 .37147 .35493 Metetra
.2 .329 .772 r
.37147 .35493 .3788 .37166 .39097 .38099 .38363 .36364 Metetra
.291 .379 .781 r
.38363 .36364 .39097 .38099 .40337 .38865 .39602 .37076 Metetra
.388 .433 .786 r
.39602 .37076 .40337 .38865 .41601 .39394 .40865 .37561 Metetra
.48 .484 .784 r
.40865 .37561 .41601 .39394 .42887 .39632 .42151 .37767 Metetra
.56 .527 .775 r
.42151 .37767 .42887 .39632 .44194 .39539 .43457 .37654 Metetra
.625 .561 .763 r
.43457 .37654 .44194 .39539 .45517 .39093 .4478 .37204 Metetra
.676 .589 .75 r
.4478 .37204 .45517 .39093 .46854 .38295 .46117 .36414 Metetra
.717 .61 .737 r
.46117 .36414 .46854 .38295 .48198 .37162 .47462 .35304 Metetra
.747 .627 .727 r
.47462 .35304 .48198 .37162 .49546 .35733 .48812 .33909 Metetra
.77 .641 .718 r
.48812 .33909 .49546 .35733 .50893 .34061 .50162 .32281 Metetra
.787 .652 .713 r
.50162 .32281 .50893 .34061 .52237 .32215 .51509 .30488 Metetra
.798 .661 .712 r
.51509 .30488 .52237 .32215 .53576 .30274 .52852 .28606 Metetra
.803 .668 .714 r
.52852 .28606 .53576 .30274 .54908 .28322 .54188 .26716 Metetra
.803 .674 .721 r
.54188 .26716 .54908 .28322 .56234 .26448 .5552 .24905 Metetra
.796 .677 .733 r
.5552 .24905 .56234 .26448 .57558 .24738 .56849 .23257 Metetra
.779 .678 .752 r
.56849 .23257 .57558 .24738 .58883 .23275 .58179 .21852 Metetra
.747 .673 .778 r
.58179 .21852 .58883 .23275 .60213 .22133 .59514 .20763 Metetra
.692 .657 .811 r
.59514 .20763 .60213 .22133 .61556 .21377 .60861 .20054 Metetra
.601 .622 .845 r
.60861 .20054 .61556 .21377 .62918 .21056 .62226 .1977 Metetra
.456 .554 .866 r
.62226 .1977 .62918 .21056 .64306 .21197 .63617 .19942 Metetra
.256 .441 .852 r
.63617 .19942 .64306 .21197 .65727 .21807 .6504 .20573 Metetra
.035 .3 .791 r
.6504 .20573 .65727 .21807 .67187 .22857 .665 .21636 Metetra
0 .172 .709 r
.665 .21636 .67187 .22857 .68687 .24278 .68 .23064 Metetra
0 .094 .649 r
.68 .23064 .68687 .24278 .70226 .25947 .69539 .24736 Metetra
0 .084 .641 r
.69539 .24736 .70226 .25947 .71798 .27675 .7111 .26467 Metetra
0 .162 .702 r
.7111 .26467 .71798 .27675 .73383 .29189 .72696 .27989 Metetra
.1 .361 .827 r
.72696 .27989 .73383 .29189 .74954 .30123 .7427 .28944 Metetra
.526 .63 .897 r
.7427 .28944 .74954 .30123 .76466 .30012 .75789 .28877 Metetra
.84 .769 .784 r
.75789 .28877 .76466 .30012 .77859 .28304 .77196 .27245 Metetra
.955 .779 .626 r
.77196 .27245 .77859 .28304 .79058 .24397 .78416 .23457 Metetra
.912 .51 .201 r
.12927 .44968 .13777 .45715 .14592 .48436 .13751 .47566 Metetra
0 .35 .82 r
.13751 .47566 .14592 .48436 .15662 .49108 .14828 .48169 Metetra
.748 .728 .834 r
.14828 .48169 .15662 .49108 .16906 .4829 .16078 .4732 Metetra
.837 .732 .748 r
.16078 .4732 .16906 .4829 .18254 .46492 .17433 .45516 Metetra
.862 .73 .716 r
.17433 .45516 .18254 .46492 .19653 .44141 .18838 .43175 Metetra
.87 .731 .706 r
.18838 .43175 .19653 .44141 .21064 .41581 .20256 .4063 Metetra
.871 .733 .707 r
.20256 .4063 .21064 .41581 .22461 .39066 .2166 .38129 Metetra
.865 .737 .719 r
.2166 .38129 .22461 .39066 .23828 .36778 .23033 .35849 Metetra
.852 .74 .739 r
.23033 .35849 .23828 .36778 .25157 .34837 .24369 .33908 Metetra
.828 .741 .768 r
.24369 .33908 .25157 .34837 .26445 .33312 .25664 .32371 Metetra
.786 .736 .807 r
.25664 .32371 .26445 .33312 .27696 .32232 .2692 .31269 Metetra
.715 .718 .851 r
.2692 .31269 .27696 .32232 .28914 .31595 .28144 .30599 Metetra
.604 .674 .889 r
.28144 .30599 .28914 .31595 .30106 .31376 .29341 .30336 Metetra
.45 .595 .904 r
.29341 .30336 .30106 .31376 .3128 .31529 .30519 .30437 Metetra
.278 .489 .883 r
.30519 .30437 .3128 .31529 .32444 .31996 .31687 .30844 Metetra
.134 .387 .84 r
.31687 .30844 .32444 .31996 .33606 .32706 .32852 .31488 Metetra
.049 .317 .801 r
.32852 .31488 .33606 .32706 .34773 .33581 .34021 .32295 Metetra
.029 .289 .783 r
.34021 .32295 .34773 .33581 .35951 .34538 .35201 .33183 Metetra
.066 .3 .785 r
.35201 .33183 .35951 .34538 .37147 .35493 .36398 .34071 Metetra
.147 .341 .8 r
.36398 .34071 .37147 .35493 .38363 .36364 .37615 .34881 Metetra
.254 .398 .815 r
.37615 .34881 .38363 .36364 .39602 .37076 .38855 .35539 Metetra
.368 .458 .822 r
.38855 .35539 .39602 .37076 .40865 .37561 .40118 .3598 Metetra
.473 .513 .819 r
.40118 .3598 .40865 .37561 .42151 .37767 .41403 .36153 Metetra
.562 .559 .807 r
.41403 .36153 .42151 .37767 .43457 .37654 .4271 .36022 Metetra
.633 .594 .792 r
.4271 .36022 .43457 .37654 .4478 .37204 .44034 .35566 Metetra
.688 .621 .775 r
.44034 .35566 .4478 .37204 .46117 .36414 .45372 .34786 Metetra
.73 .641 .76 r
.45372 .34786 .46117 .36414 .47462 .35304 .4672 .33698 Metetra
.762 .658 .747 r
.4672 .33698 .47462 .35304 .48812 .33909 .48072 .32338 Metetra
.786 .671 .737 r
.48072 .32338 .48812 .33909 .50162 .32281 .49426 .30756 Metetra
.803 .682 .731 r
.49426 .30756 .50162 .32281 .51509 .30488 .50777 .29016 Metetra
.814 .692 .729 r
.50777 .29016 .51509 .30488 .52852 .28606 .52125 .27192 Metetra
.82 .7 .732 r
.52125 .27192 .52852 .28606 .54188 .26716 .53467 .25363 Metetra
.821 .708 .74 r
.53467 .25363 .54188 .26716 .5552 .24905 .54804 .23612 Metetra
.813 .714 .755 r
.54804 .23612 .5552 .24905 .56849 .23257 .56139 .22021 Metetra
.795 .717 .778 r
.56139 .22021 .56849 .23257 .58179 .21852 .57475 .20669 Metetra
.761 .715 .81 r
.57475 .20669 .58179 .21852 .59514 .20763 .58815 .19626 Metetra
.699 .702 .849 r
.58815 .19626 .59514 .20763 .60861 .20054 .60167 .18952 Metetra
.591 .664 .889 r
.60167 .18952 .60861 .20054 .62226 .1977 .61537 .18694 Metetra
.418 .581 .907 r
.61537 .18694 .62226 .1977 .63617 .19942 .6293 .18879 Metetra
.184 .443 .872 r
.6293 .18879 .63617 .19942 .6504 .20573 .64355 .19513 Metetra
0 .28 .783 r
.64355 .19513 .6504 .20573 .665 .21636 .65816 .20568 Metetra
0 .144 .684 r
.65816 .20568 .665 .21636 .68 .23064 .67315 .21979 Metetra
0 .069 .623 r
.67315 .21979 .68 .23064 .69539 .24736 .68853 .23627 Metetra
0 .065 .621 r
.68853 .23627 .69539 .24736 .7111 .26467 .70422 .25333 Metetra
0 .151 .692 r
.70422 .25333 .7111 .26467 .72696 .27989 .72008 .26835 Metetra
.076 .357 .828 r
.72008 .26835 .72696 .27989 .7427 .28944 .73583 .27787 Metetra
.514 .63 .903 r
.73583 .27787 .7427 .28944 .75789 .28877 .75107 .27743 Metetra
.834 .77 .791 r
.75107 .27743 .75789 .28877 .77196 .27245 .76526 .26176 Metetra
.952 .781 .633 r
.76526 .26176 .77196 .27245 .78416 .23457 .77768 .22508 Metetra
.906 .498 .181 r
.1207 .44214 .12927 .44968 .13751 .47566 .12902 .46691 Metetra
.002 .39 .847 r
.12902 .46691 .13751 .47566 .14828 .48169 .13986 .47237 Metetra
.75 .732 .836 r
.13986 .47237 .14828 .48169 .16078 .4732 .1524 .4638 Metetra
.839 .737 .752 r
.1524 .4638 .16078 .4732 .17433 .45516 .16598 .446 Metetra
.865 .738 .721 r
.16598 .446 .17433 .45516 .18838 .43175 .18007 .423 Metetra
.876 .742 .711 r
.18007 .423 .18838 .43175 .20256 .4063 .19429 .39801 Metetra
.879 .749 .714 r
.19429 .39801 .20256 .4063 .2166 .38129 .20837 .37344 Metetra
.877 .757 .727 r
.20837 .37344 .2166 .38129 .23033 .35849 .22215 .351 Metetra
.867 .768 .75 r
.22215 .351 .23033 .35849 .24369 .33908 .23555 .33183 Metetra
.847 .779 .785 r
.23555 .33183 .24369 .33908 .25664 .32371 .24856 .31657 Metetra
.807 .786 .833 r
.24856 .31657 .25664 .32371 .2692 .31269 .26118 .3055 Metetra
.734 .781 .891 r
.26118 .3055 .2692 .31269 .28144 .30599 .27347 .29862 Metetra
.607 .746 .943 r
.27347 .29862 .28144 .30599 .29341 .30336 .28549 .29569 Metetra
.415 .658 .96 r
.28549 .29569 .29341 .30336 .30519 .30437 .29732 .29627 Metetra
.196 .525 .92 r
.29732 .29627 .30519 .30437 .31687 .30844 .30904 .29982 Metetra
.018 .395 .851 r
.30904 .29982 .31687 .30844 .32852 .31488 .32073 .30568 Metetra
0 .309 .796 r
.32073 .30568 .32852 .31488 .34021 .32295 .33246 .3131 Metetra
0 .276 .777 r
.33246 .3131 .34021 .32295 .35201 .33183 .3443 .32133 Metetra
0 .293 .791 r
.3443 .32133 .35201 .33183 .36398 .34071 .35629 .32956 Metetra
.046 .346 .823 r
.35629 .32956 .36398 .34071 .37615 .34881 .36848 .33705 Metetra
.182 .42 .855 r
.36848 .33705 .37615 .34881 .38855 .35539 .38089 .3431 Metetra
.325 .495 .872 r
.38089 .3431 .38855 .35539 .40118 .3598 .39354 .34707 Metetra
.456 .559 .871 r
.39354 .34707 .40118 .3598 .41403 .36153 .40642 .34848 Metetra
.563 .608 .856 r
.40642 .34848 .41403 .36153 .4271 .36022 .4195 .34698 Metetra
.644 .644 .835 r
.4195 .34698 .4271 .36022 .44034 .35566 .43276 .34238 Metetra
.705 .67 .812 r
.43276 .34238 .44034 .35566 .45372 .34786 .44617 .33467 Metetra
.75 .689 .792 r
.44617 .33467 .45372 .34786 .4672 .33698 .45968 .32402 Metetra
.784 .703 .775 r
.45968 .32402 .4672 .33698 .48072 .32338 .47324 .31077 Metetra
.808 .716 .763 r
.47324 .31077 .48072 .32338 .49426 .30756 .48682 .2954 Metetra
.826 .727 .755 r
.48682 .2954 .49426 .30756 .50777 .29016 .50039 .27853 Metetra
.838 .737 .753 r
.50039 .27853 .50777 .29016 .52125 .27192 .51393 .26085 Metetra
.845 .747 .756 r
.51393 .26085 .52125 .27192 .53467 .25363 .52741 .24314 Metetra
.845 .758 .766 r
.52741 .24314 .53467 .25363 .54804 .23612 .54086 .2262 Metetra
.838 .768 .784 r
.54086 .2262 .54804 .23612 .56139 .22021 .55427 .21082 Metetra
.819 .776 .813 r
.55427 .21082 .56139 .22021 .57475 .20669 .5677 .19774 Metetra
.78 .78 .852 r
.5677 .19774 .57475 .20669 .58815 .19626 .58117 .18765 Metetra
.707 .77 .901 r
.58117 .18765 .58815 .19626 .60167 .18952 .59475 .18115 Metetra
.574 .726 .946 r
.59475 .18115 .60167 .18952 .61537 .18694 .60849 .17867 Metetra
.357 .619 .951 r
.60849 .17867 .61537 .18694 .6293 .18879 .62246 .18048 Metetra
.082 .443 .879 r
.62246 .18048 .6293 .18879 .64355 .19513 .63672 .18663 Metetra
0 .254 .754 r
.63672 .18663 .64355 .19513 .65816 .20568 .65134 .19685 Metetra
0 .116 .645 r
.65134 .19685 .65816 .20568 .67315 .21979 .66632 .21049 Metetra
0 .047 .588 r
.66632 .21049 .67315 .21979 .68853 .23627 .68168 .22644 Metetra
0 .052 .599 r
.68168 .22644 .68853 .23627 .70422 .25333 .69735 .24291 Metetra
0 .148 .685 r
.69735 .24291 .70422 .25333 .72008 .26835 .71318 .25742 Metetra
.061 .363 .833 r
.71318 .25742 .72008 .26835 .73583 .27787 .72893 .26659 Metetra
.509 .637 .911 r
.72893 .26659 .73583 .27787 .75107 .27743 .74421 .26614 Metetra
.829 .771 .798 r
.74421 .26614 .75107 .27743 .76526 .26176 .75851 .25098 Metetra
.949 .782 .641 r
.75851 .25098 .76526 .26176 .77768 .22508 .77113 .21549 Metetra
.9 .484 .158 r
.11206 .43453 .1207 .44214 .12902 .46691 .12047 .45811 Metetra
.041 .417 .863 r
.12047 .45811 .12902 .46691 .13986 .47237 .13135 .46316 Metetra
.748 .735 .84 r
.13135 .46316 .13986 .47237 .1524 .4638 .14391 .45478 Metetra
.839 .744 .759 r
.14391 .45478 .1524 .4638 .16598 .446 .15749 .43753 Metetra
.868 .749 .729 r
.15749 .43753 .16598 .446 .18007 .423 .17158 .41528 Metetra
.882 .756 .72 r
.17158 .41528 .18007 .423 .19429 .39801 .18579 .3911 Metetra
.888 .768 .724 r
.18579 .3911 .19429 .39801 .20837 .37344 .19988 .36731 Metetra
.889 .784 .739 r
.19988 .36731 .20837 .37344 .22215 .351 .21369 .34554 Metetra
.883 .804 .766 r
.21369 .34554 .22215 .351 .23555 .33183 .22712 .32688 Metetra
.866 .827 .808 r
.22712 .32688 .23555 .33183 .24856 .31657 .24017 .31196 Metetra
.826 .851 .866 r
.24017 .31196 .24856 .31657 .26118 .3055 .25283 .30107 Metetra
.742 .863 .937 r
.25283 .30107 .26118 .3055 .27347 .29862 .26518 .29419 Metetra
.575 .83 .993 r
.26518 .29419 .27347 .29862 .28549 .29569 .27725 .29109 Metetra
.311 .708 .978 r
.27725 .29109 .28549 .29569 .29732 .29627 .28914 .29137 Metetra
.027 .52 .876 r
.28914 .29137 .29732 .29627 .30904 .29982 .30091 .2945 Metetra
0 .353 .76 r
.30091 .2945 .30904 .29982 .32073 .30568 .31265 .29983 Metetra
0 .254 .69 r
.31265 .29983 .32073 .30568 .33246 .3131 .32443 .30667 Metetra
0 .223 .679 r
.32443 .30667 .33246 .3131 .3443 .32133 .33631 .31427 Metetra
0 .249 .717 r
.33631 .31427 .3443 .32133 .35629 .32956 .34834 .32188 Metetra
0 .324 .79 r
.34834 .32188 .35629 .32956 .36848 .33705 .36057 .32878 Metetra
.042 .429 .869 r
.36057 .32878 .36848 .33705 .38089 .3431 .37302 .3343 Metetra
.235 .537 .923 r
.37302 .3343 .38089 .3431 .39354 .34707 .3857 .33784 Metetra
.413 .624 .939 r
.3857 .33784 .39354 .34707 .40642 .34848 .39861 .33893 Metetra
.553 .683 .925 r
.39861 .33893 .40642 .34848 .4195 .34698 .41172 .33725 Metetra
.655 .72 .896 r
.41172 .33725 .4195 .34698 .43276 .34238 .42502 .3326 Metetra
.726 .743 .865 r
.42502 .3326 .43276 .34238 .44617 .33467 .43847 .32499 Metetra
.776 .758 .837 r
.43847 .32499 .44617 .33467 .45968 .32402 .45202 .31458 Metetra
.812 .77 .814 r
.45202 .31458 .45968 .32402 .47324 .31077 .46564 .30168 Metetra
.838 .78 .797 r
.46564 .30168 .47324 .31077 .48682 .2954 .47928 .28675 Metetra
.856 .79 .786 r
.47928 .28675 .48682 .2954 .50039 .27853 .49292 .27039 Metetra
.868 .801 .782 r
.49292 .27039 .50039 .27853 .51393 .26085 .50653 .25326 Metetra
.875 .814 .786 r
.50653 .25326 .51393 .26085 .52741 .24314 .52009 .23611 Metetra
.875 .828 .797 r
.52009 .23611 .52741 .24314 .54086 .2262 .53362 .21968 Metetra
.867 .843 .819 r
.53362 .21968 .54086 .2262 .55427 .21082 .54712 .20475 Metetra
.845 .859 .853 r
.54712 .20475 .55427 .21082 .5677 .19774 .56062 .19203 Metetra
.798 .87 .901 r
.56062 .19203 .5677 .19774 .58117 .18765 .57417 .18218 Metetra
.704 .862 .957 r
.57417 .18218 .58117 .18765 .59475 .18115 .58782 .17576 Metetra
.527 .803 .996 r
.58782 .17576 .59475 .18115 .60849 .17867 .60161 .1732 Metetra
.251 .65 .963 r
.60161 .1732 .60849 .17867 .62246 .18048 .61563 .17476 Metetra
0 .427 .838 r
.61563 .17476 .62246 .18048 .63672 .18663 .62992 .18047 Metetra
0 .222 .689 r
.62992 .18047 .63672 .18663 .65134 .19685 .64454 .19007 Metetra
0 .09 .586 r
.64454 .19007 .65134 .19685 .66632 .21049 .65951 .20295 Metetra
0 .032 .547 r
.65951 .20295 .66632 .21049 .68168 .22644 .67484 .21801 Metetra
0 .048 .576 r
.67484 .21801 .68168 .22644 .69735 .24291 .69047 .23355 Metetra
0 .155 .682 r
.69047 .23355 .69735 .24291 .71318 .25742 .70627 .24718 Metetra
.058 .381 .845 r
.70627 .24718 .71318 .25742 .72893 .26659 .72199 .25568 Metetra
.513 .65 .919 r
.72199 .25568 .72893 .26659 .74421 .26614 .7373 .25495 Metetra
.826 .774 .803 r
.7373 .25495 .74421 .26614 .75851 .25098 .75169 .24012 Metetra
.946 .784 .648 r
.75169 .24012 .75851 .25098 .77113 .21549 .76452 .20582 Metetra
.892 .468 .133 r
.10334 .42686 .11206 .43453 .12047 .45811 .11185 .44925 Metetra
.063 .432 .872 r
.11185 .44925 .12047 .45811 .13135 .46316 .12275 .45406 Metetra
.74 .737 .849 r
.12275 .45406 .13135 .46316 .14391 .45478 .13529 .44613 Metetra
.837 .752 .77 r
.13529 .44613 .14391 .45478 .15749 .43753 .14883 .42977 Metetra
.87 .761 .739 r
.14883 .42977 .15749 .43753 .17158 .41528 .16288 .40865 Metetra
.887 .774 .731 r
.16288 .40865 .17158 .41528 .18579 .3911 .17706 .38565 Metetra
.896 .792 .737 r
.17706 .38565 .18579 .3911 .19988 .36731 .19112 .36299 Metetra
.901 .816 .755 r
.19112 .36299 .19988 .36731 .21369 .34554 .20492 .34222 Metetra
.898 .847 .786 r
.20492 .34222 .21369 .34554 .22712 .32688 .21836 .32438 Metetra
.88 .886 .833 r
.21836 .32438 .22712 .32688 .24017 .31196 .23142 .31008 Metetra
.83 .926 .897 r
.23142 .31008 .24017 .31196 .25283 .30107 .24413 .29958 Metetra
.706 .942 .96 r
.24413 .29958 .25283 .30107 .26518 .29419 .25652 .29289 Metetra
.448 .861 .957 r
.25652 .29289 .26518 .29419 .27725 .29109 .26865 .28978 Metetra
.094 .643 .823 r
.26865 .28978 .27725 .29109 .28914 .29137 .28059 .28988 Metetra
.199 0 0 r
.28059 .28988 .28914 .29137 .30091 .2945 .29243 .29267 Metetra
.37 0 0 r
.29243 .29267 .30091 .2945 .31265 .29983 .30423 .29755 Metetra
.45 0 0 r
.30423 .29755 .31265 .29983 .32443 .30667 .31607 .30385 Metetra
.469 0 0 r
.31607 .30385 .32443 .30667 .33631 .31427 .32801 .31087 Metetra
.433 0 0 r
.32801 .31087 .33631 .31427 .34834 .32188 .3401 .31788 Metetra
.338 0 0 r
.3401 .31788 .34834 .32188 .36057 .32878 .35238 .3242 Metetra
0 .376 .752 r
.35238 .3242 .36057 .32878 .37302 .3343 .36488 .3292 Metetra
.057 .539 .891 r
.36488 .3292 .37302 .3343 .3857 .33784 .37761 .33231 Metetra
.303 .683 .976 r
.37761 .33231 .3857 .33784 .39861 .33893 .39057 .33309 Metetra
.506 .775 .992 r
.39057 .33309 .39861 .33893 .41172 .33725 .40374 .33122 Metetra
.648 .821 .966 r
.40374 .33122 .41172 .33725 .42502 .3326 .41709 .32653 Metetra
.74 .842 .927 r
.41709 .32653 .42502 .3326 .43847 .32499 .43059 .31903 Metetra
.8 .852 .889 r
.43059 .31903 .43847 .32499 .45202 .31458 .4442 .30885 Metetra
.84 .858 .858 r
.4442 .30885 .45202 .31458 .46564 .30168 .45789 .2963 Metetra
.867 .865 .834 r
.45789 .2963 .46564 .30168 .47928 .28675 .47161 .28183 Metetra
.885 .873 .819 r
.47161 .28183 .47928 .28675 .49292 .27039 .48533 .26597 Metetra
.897 .883 .812 r
.48533 .26597 .49292 .27039 .50653 .25326 .49902 .24937 Metetra
.902 .897 .813 r
.49902 .24937 .50653 .25326 .52009 .23611 .51268 .23273 Metetra
.899 .913 .823 r
.51268 .23273 .52009 .23611 .53362 .21968 .5263 .21678 Metetra
.885 .933 .845 r
.5263 .21678 .53362 .21968 .54712 .20475 .5399 .20223 Metetra
.852 .953 .879 r
.5399 .20223 .54712 .20475 .56062 .19203 .5535 .18977 Metetra
.783 .963 .923 r
.5535 .18977 .56062 .19203 .57417 .18218 .56714 .18004 Metetra
.646 .94 .963 r
.56714 .18004 .57417 .18218 .58782 .17576 .58087 .17355 Metetra
.407 .835 .958 r
.58087 .17355 .58782 .17576 .60161 .1732 .59473 .17073 Metetra
.091 .625 .863 r
.59473 .17073 .60161 .1732 .61563 .17476 .6088 .1718 Metetra
0 .379 .712 r
.6088 .1718 .61563 .17476 .62992 .18047 .62312 .17681 Metetra
.383 0 0 r
.62312 .17681 .62992 .18047 .64454 .19007 .63775 .1855 Metetra
.477 0 0 r
.63775 .1855 .64454 .19007 .65951 .20295 .65271 .19727 Metetra
.496 0 0 r
.65271 .19727 .65951 .20295 .67484 .21801 .66801 .21107 Metetra
0 .057 .558 r
.66801 .21107 .67484 .21801 .69047 .23355 .68359 .2253 Metetra
0 .179 .688 r
.68359 .2253 .69047 .23355 .70627 .24718 .69934 .23767 Metetra
.074 .415 .864 r
.69934 .23767 .70627 .24718 .72199 .25568 .71503 .24514 Metetra
.528 .669 .927 r
.71503 .24514 .72199 .25568 .7373 .25495 .73035 .24385 Metetra
.825 .778 .807 r
.73035 .24385 .7373 .25495 .75169 .24012 .74482 .22919 Metetra
.943 .785 .656 r
.74482 .22919 .75169 .24012 .76452 .20582 .75785 .19605 Metetra
.883 .449 .105 r
.09455 .41912 .10334 .42686 .11185 .44925 .10316 .4403 Metetra
.071 .436 .875 r
.10316 .4403 .11185 .44925 .12275 .45406 .11407 .44503 Metetra
.727 .738 .86 r
.11407 .44503 .12275 .45406 .13529 .44613 .12655 .43781 Metetra
.831 .759 .783 r
.12655 .43781 .13529 .44613 .14883 .42977 .14001 .42268 Metetra
.869 .774 .754 r
.14001 .42268 .14883 .42977 .16288 .40865 .15396 .40305 Metetra
.89 .793 .747 r
.15396 .40305 .16288 .40865 .17706 .38565 .16806 .38163 Metetra
.903 .819 .754 r
.16806 .38163 .17706 .38565 .19112 .36299 .18206 .36047 Metetra
.91 .853 .774 r
.18206 .36047 .19112 .36299 .20492 .34222 .19582 .34104 Metetra
.906 .898 .808 r
.19582 .34104 .20492 .34222 .21836 .32438 .20924 .32433 Metetra
.877 .948 .854 r
.20924 .32433 .21836 .32438 .23142 .31008 .22231 .31091 Metetra
.786 .985 .898 r
.22231 .31091 .23142 .31008 .24413 .29958 .23504 .30104 Metetra
.561 .936 .879 r
.23504 .30104 .24413 .29958 .25652 .29289 .24746 .29473 Metetra
.196 .722 .723 r
.24746 .29473 .25652 .29289 .26865 .28978 .25964 .29177 Metetra
.141 0 0 r
.25964 .29177 .26865 .28978 .28059 .28988 .27165 .2918 Metetra
.352 0 0 r
.27165 .2918 .28059 .28988 .29243 .29267 .28356 .29435 Metetra
.468 0 0 r
.28356 .29435 .29243 .29267 .30423 .29755 .29544 .29884 Metetra
.525 0 0 r
.29544 .29884 .30423 .29755 .31607 .30385 .30735 .30464 Metetra
.543 0 0 r
.30735 .30464 .31607 .30385 .32801 .31087 .31937 .31109 Metetra
.526 0 0 r
.31937 .31109 .32801 .31087 .3401 .31788 .33154 .31751 Metetra
.468 0 0 r
.33154 .31751 .3401 .31788 .35238 .3242 .34389 .32326 Metetra
.353 0 0 r
.34389 .32326 .35238 .3242 .36488 .3292 .35646 .32773 Metetra
.164 0 0 r
.35646 .32773 .36488 .3292 .37761 .33231 .36926 .3304 Metetra
.095 .638 .844 r
.36926 .3304 .37761 .33231 .39057 .33309 .38228 .33086 Metetra
.365 .807 .955 r
.38228 .33086 .39057 .33309 .40374 .33122 .39551 .32881 Metetra
.575 .901 .982 r
.39551 .32881 .40374 .33122 .41709 .32653 .40893 .32409 Metetra
.711 .939 .96 r
.40893 .32409 .41709 .32653 .43059 .31903 .42251 .31669 Metetra
.794 .95 .922 r
.42251 .31669 .43059 .31903 .4442 .30885 .4362 .30676 Metetra
.844 .952 .886 r
.4362 .30676 .4442 .30885 .45789 .2963 .44996 .29458 Metetra
.875 .953 .856 r
.44996 .29458 .45789 .2963 .47161 .28183 .46377 .28056 Metetra
.893 .957 .834 r
.46377 .28056 .47161 .28183 .48533 .26597 .47758 .26521 Metetra
.9 .964 .82 r
.47758 .26521 .48533 .26597 .49902 .24937 .49138 .24914 Metetra
.898 .974 .814 r
.49138 .24914 .49902 .24937 .51268 .23273 .50515 .23301 Metetra
.883 .986 .815 r
.50515 .23301 .51268 .23273 .5263 .21678 .51889 .21749 Metetra
.85 .997 .822 r
.51889 .21749 .5263 .21678 .5399 .20223 .5326 .20326 Metetra
.785 .999 .833 r
.5326 .20326 .5399 .20223 .5535 .18977 .54631 .19098 Metetra
.669 .975 .838 r
.54631 .19098 .5535 .18977 .56714 .18004 .56005 .18124 Metetra
.477 .895 .818 r
.56005 .18124 .56714 .18004 .58087 .17355 .57387 .17454 Metetra
.213 .735 .749 r
.57387 .17454 .58087 .17355 .59473 .17073 .58782 .17126 Metetra
.068 0 0 r
.58782 .17126 .59473 .17073 .6088 .1718 .60194 .17162 Metetra
.292 0 0 r
.60194 .17162 .6088 .1718 .62312 .17681 .61631 .17565 Metetra
.437 0 0 r
.61631 .17565 .62312 .17681 .63775 .1855 .63095 .18311 Metetra
.509 0 0 r
.63095 .18311 .63775 .1855 .65271 .19727 .64591 .19342 Metetra
.516 0 0 r
.64591 .19342 .65271 .19727 .66801 .21107 .66117 .20558 Metetra
.445 0 0 r
.66117 .20558 .66801 .21107 .68359 .2253 .6767 .2181 Metetra
0 .224 .709 r
.6767 .2181 .68359 .2253 .69934 .23767 .69238 .22883 Metetra
.115 .466 .891 r
.69238 .22883 .69934 .23767 .71503 .24514 .70803 .23493 Metetra
.554 .693 .932 r
.70803 .23493 .71503 .24514 .73035 .24385 .72334 .2328 Metetra
.826 .781 .809 r
.72334 .2328 .73035 .24385 .74482 .22919 .73788 .21814 Metetra
.939 .786 .664 r
.73788 .21814 .74482 .22919 .75785 .19605 .75112 .18618 Metetra
.87 .427 .07 r
.08568 .41132 .09455 .41912 .10316 .4403 .09441 .43122 Metetra
.07 .434 .874 r
.09441 .43122 .10316 .4403 .11407 .44503 .10531 .43596 Metetra
.706 .735 .873 r
.10531 .43596 .11407 .44503 .12655 .43781 .11771 .42969 Metetra
.821 .766 .801 r
.11771 .42969 .12655 .43781 .14001 .42268 .13104 .41611 Metetra
.865 .787 .773 r
.13104 .41611 .14001 .42268 .15396 .40305 .14485 .39833 Metetra
.89 .814 .767 r
.14485 .39833 .15396 .40305 .16806 .38163 .15882 .37885 Metetra
.906 .849 .776 r
.15882 .37885 .16806 .38163 .18206 .36047 .17271 .35955 Metetra
.912 .895 .798 r
.17271 .35955 .18206 .36047 .19582 .34104 .18638 .3418 Metetra
.899 .949 .829 r
.18638 .3418 .19582 .34104 .20924 .32433 .19976 .32652 Metetra
.833 .994 .853 r
.19976 .32652 .20924 .32433 .22231 .31091 .21281 .31425 Metetra
.649 .967 .821 r
.21281 .31425 .22231 .31091 .23504 .30104 .22554 .30524 Metetra
.312 .779 .659 r
.22554 .30524 .23504 .30104 .24746 .29473 .238 .29948 Metetra
.039 0 0 r
.238 .29948 .24746 .29473 .25964 .29177 .25024 .29681 Metetra
.279 0 0 r
.25024 .29681 .25964 .29177 .27165 .2918 .26231 .29687 Metetra
.419 0 0 r
.26231 .29687 .27165 .2918 .28356 .29435 .2743 .29924 Metetra
.498 0 0 r
.2743 .29924 .28356 .29435 .29544 .29884 .28626 .30338 Metetra
.54 .014 0 r
.28626 .30338 .29544 .29884 .30735 .30464 .29827 .30869 Metetra
.554 .024 0 r
.29827 .30869 .30735 .30464 .31937 .31109 .31038 .31457 Metetra
.544 .003 0 r
.31038 .31457 .31937 .31109 .33154 .31751 .32264 .32038 Metetra
.505 0 0 r
.32264 .32038 .33154 .31751 .34389 .32326 .33508 .32552 Metetra
.428 0 0 r
.33508 .32552 .34389 .32326 .35646 .32773 .34774 .32945 Metetra
.297 0 0 r
.34774 .32945 .35646 .32773 .36926 .3304 .36062 .33166 Metetra
.097 0 0 r
.36062 .33166 .36926 .3304 .38228 .33086 .37373 .33179 Metetra
.156 .697 .745 r
.37373 .33179 .38228 .33086 .39551 .32881 .38704 .32954 Metetra
.404 .858 .853 r
.38704 .32954 .39551 .32881 .40893 .32409 .40054 .32479 Metetra
.592 .948 .889 r
.40054 .32479 .40893 .32409 .42251 .31669 .4142 .31752 Metetra
.712 .985 .881 r
.4142 .31752 .42251 .31669 .4362 .30676 .42798 .30785 Metetra
.784 .997 .856 r
.42798 .30785 .4362 .30676 .44996 .29458 .44184 .29606 Metetra
.823 .999 .828 r
.44184 .29606 .44996 .29458 .46377 .28056 .45575 .28253 Metetra
.841 .999 .801 r
.45575 .28253 .46377 .28056 .47758 .26521 .46967 .26772 Metetra
.842 .998 .778 r
.46967 .26772 .47758 .26521 .49138 .24914 .48358 .2522 Metetra
.825 .995 .756 r
.48358 .2522 .49138 .24914 .50515 .23301 .49747 .23657 Metetra
.787 .987 .736 r
.49747 .23657 .50515 .23301 .51889 .21749 .51134 .22148 Metetra
.721 .967 .712 r
.51134 .22148 .51889 .21749 .5326 .20326 .52518 .20755 Metetra
.617 .926 .681 r
.52518 .20755 .5326 .20326 .54631 .19098 .53901 .19539 Metetra
.466 .851 .636 r
.53901 .19539 .54631 .19098 .56005 .18124 .55287 .18555 Metetra
.55287 .18555 .56005 .18124 .57387 .17454 .5668 .17849 Metetra
.5668 .17849 .57387 .17454 .58782 .17126 .58084 .17458 Metetra
.158 0 0 r
.58084 .17458 .58782 .17126 .60194 .17162 .59505 .17401 Metetra
.325 0 0 r
.59505 .17401 .60194 .17162 .61631 .17565 .60946 .17679 Metetra
.44 0 0 r
.60946 .17679 .61631 .17565 .63095 .18311 .62413 .1827 Metetra
.5 0 0 r
.62413 .1827 .63095 .18311 .64591 .19342 .63907 .19121 Metetra
.5 0 0 r
.63907 .19121 .64591 .19342 .66117 .20558 .6543 .20137 Metetra
.416 0 0 r
.6543 .20137 .66117 .20558 .6767 .2181 .66977 .21179 Metetra
0 .299 .75 r
.66977 .21179 .6767 .2181 .69238 .22883 .68539 .22051 Metetra
.187 .533 .924 r
.68539 .22051 .69238 .22883 .70803 .23493 .70098 .2249 Metetra
.588 .717 .932 r
.70098 .2249 .70803 .23493 .72334 .2328 .71627 .22168 Metetra
.827 .782 .809 r
.71627 .22168 .72334 .2328 .73788 .21814 .73088 .20692 Metetra
.934 .786 .673 r
.73088 .20692 .73788 .21814 .75112 .18618 .74431 .17622 Metetra
.853 .397 .026 r
.07673 .40345 .08568 .41132 .09441 .43122 .08561 .42191 Metetra
.071 .43 .872 r
.08561 .42191 .09441 .43122 .10531 .43596 .0965 .4267 Metetra
.677 .725 .886 r
.0965 .4267 .10531 .43596 .11771 .42969 .10878 .42154 Metetra
.803 .767 .821 r
.10878 .42154 .11771 .42969 .13104 .41611 .12194 .40976 Metetra
.853 .798 .796 r
.12194 .40976 .13104 .41611 .14485 .39833 .13557 .39415 Metetra
.883 .834 .793 r
.13557 .39415 .14485 .39833 .15882 .37885 .14936 .37694 Metetra
.901 .879 .805 r
.14936 .37694 .15882 .37885 .17271 .35955 .1631 .35984 Metetra
.902 .935 .825 r
.1631 .35984 .17271 .35955 .18638 .3418 .17665 .34409 Metetra
.862 .987 .842 r
.17665 .34409 .18638 .3418 .19976 .32652 .18995 .33051 Metetra
.726 .988 .812 r
.18995 .33051 .19976 .32652 .21281 .31425 .20295 .31962 Metetra
.438 .846 .667 r
.20295 .31962 .21281 .31425 .22554 .30524 .21568 .31165 Metetra
.21568 .31165 .22554 .30524 .238 .29948 .22817 .30659 Metetra
.179 0 0 r
.22817 .30659 .238 .29948 .25024 .29681 .24045 .30429 Metetra
.344 0 0 r
.24045 .30429 .25024 .29681 .26231 .29687 .2526 .30445 Metetra
.443 0 0 r
.2526 .30445 .26231 .29687 .2743 .29924 .26467 .30666 Metetra
.501 .008 .016 r
.26467 .30666 .2743 .29924 .28626 .30338 .27674 .31043 Metetra
.533 .038 .028 r
.27674 .31043 .28626 .30338 .29827 .30869 .28885 .31523 Metetra
.543 .043 .017 r
.28885 .31523 .29827 .30869 .31038 .31457 .30107 .32048 Metetra
.534 .023 0 r
.30107 .32048 .31038 .31457 .32264 .32038 .31344 .32563 Metetra
.502 0 0 r
.31344 .32563 .32264 .32038 .33508 .32552 .32599 .33011 Metetra
.441 0 0 r
.32599 .33011 .33508 .32552 .34774 .32945 .33875 .33343 Metetra
.338 0 0 r
.33875 .33343 .34774 .32945 .36062 .33166 .35173 .33514 Metetra
.183 0 0 r
.35173 .33514 .36062 .33166 .37373 .33179 .36493 .3349 Metetra
.36493 .3349 .37373 .33179 .38704 .32954 .37834 .33245 Metetra
.247 .747 .681 r
.37834 .33245 .38704 .32954 .40054 .32479 .39193 .32766 Metetra
.443 .87 .756 r
.39193 .32766 .40054 .32479 .4142 .31752 .40568 .32053 Metetra
.584 .937 .781 r
.40568 .32053 .4142 .31752 .42798 .30785 .41955 .31117 Metetra
.672 .968 .775 r
.41955 .31117 .42798 .30785 .44184 .29606 .43352 .29983 Metetra
.72 .977 .754 r
.43352 .29983 .44184 .29606 .45575 .28253 .44753 .28683 Metetra
.738 .975 .726 r
.44753 .28683 .45575 .28253 .46967 .26772 .46157 .27263 Metetra
.73 .964 .693 r
.46157 .27263 .46967 .26772 .48358 .2522 .47561 .25772 Metetra
.699 .945 .657 r
.47561 .25772 .48358 .2522 .49747 .23657 .48963 .24266 Metetra
.642 .914 .616 r
.48963 .24266 .49747 .23657 .51134 .22148 .50363 .22803 Metetra
.556 .866 .568 r
.50363 .22803 .51134 .22148 .52518 .20755 .51761 .2144 Metetra
.51761 .2144 .52518 .20755 .53901 .19539 .53158 .20234 Metetra
.53158 .20234 .53901 .19539 .55287 .18555 .54558 .19235 Metetra
.54558 .19235 .55287 .18555 .5668 .17849 .55963 .18484 Metetra
.031 0 0 r
.55963 .18484 .5668 .17849 .58084 .17458 .57378 .18015 Metetra
.183 0 0 r
.57378 .18015 .58084 .17458 .59505 .17401 .58807 .17845 Metetra
.309 0 0 r
.58807 .17845 .59505 .17401 .60946 .17679 .60254 .17976 Metetra
.402 0 0 r
.60254 .17976 .60946 .17679 .62413 .1827 .61724 .18385 Metetra
.452 0 0 r
.61724 .18385 .62413 .1827 .63907 .19121 .63218 .19022 Metetra
.443 0 0 r
.63218 .19022 .63907 .19121 .6543 .20137 .64738 .19804 Metetra
.339 0 0 r
.64738 .19804 .6543 .20137 .66977 .21179 .66279 .20602 Metetra
0 .407 .818 r
.66279 .20602 .66977 .21179 .68539 .22051 .67834 .2124 Metetra
.291 .609 .954 r
.67834 .2124 .68539 .22051 .70098 .2249 .69386 .21482 Metetra
.628 .736 .925 r
.69386 .21482 .70098 .2249 .71627 .22168 .70913 .21034 Metetra
.827 .779 .807 r
.70913 .21034 .71627 .22168 .73088 .20692 .7238 .19543 Metetra
.928 .785 .683 r
.7238 .19543 .73088 .20692 .74431 .17622 .73744 .16616 Metetra
.824 .353 0 r
.06771 .39551 .07673 .40345 .08561 .42191 .07677 .41224 Metetra
.088 .432 .873 r
.07677 .41224 .08561 .42191 .0965 .4267 .08766 .41699 Metetra
.641 .706 .894 r
.08766 .41699 .0965 .4267 .10878 .42154 .09982 .41302 Metetra
.774 .761 .841 r
.09982 .41302 .10878 .42154 .12194 .40976 .11277 .40321 Metetra
.832 .801 .822 r
.11277 .40321 .12194 .40976 .13557 .39415 .12617 .38999 Metetra
.866 .847 .823 r
.12617 .38999 .13557 .39415 .14936 .37694 .13974 .37531 Metetra
.883 .903 .838 r
.13974 .37531 .14936 .37694 .1631 .35984 .15328 .36067 Metetra
.872 .964 .856 r
.15328 .36067 .1631 .35984 .17665 .34409 .16668 .34716 Metetra
.792 .998 .846 r
.16668 .34716 .17665 .34409 .18995 .33051 .17987 .3355 Metetra
.579 .928 .743 r
.17987 .3355 .18995 .33051 .20295 .31962 .19281 .32617 Metetra
.19281 .32617 .20295 .31962 .21568 .31165 .20552 .31935 Metetra
.046 0 0 r
.20552 .31935 .21568 .31165 .22817 .30659 .21802 .31507 Metetra
.245 0 0 r
.21802 .31507 .22817 .30659 .24045 .30429 .23036 .31318 Metetra
.369 0 0 r
.23036 .31318 .24045 .30429 .2526 .30445 .24258 .31342 Metetra
.444 0 .015 r
.24258 .31342 .2526 .30445 .26467 .30666 .25476 .31542 Metetra
.49 .01 .042 r
.25476 .31542 .26467 .30666 .27674 .31043 .26694 .31874 Metetra
.514 .031 .046 r
.26694 .31874 .27674 .31043 .28885 .31523 .27917 .32292 Metetra
.521 .03 .031 r
.27917 .32292 .28885 .31523 .30107 .32048 .29152 .32744 Metetra
.51 .006 0 r
.29152 .32744 .30107 .32048 .31344 .32563 .30401 .3318 Metetra
.477 0 0 r
.30401 .3318 .31344 .32563 .32599 .33011 .31669 .33551 Metetra
.416 0 0 r
.31669 .33551 .32599 .33011 .33875 .33343 .32957 .33812 Metetra
.318 0 0 r
.32957 .33812 .33875 .33343 .35173 .33514 .34266 .33925 Metetra
.175 0 0 r
.34266 .33925 .35173 .33514 .36493 .3349 .35596 .33857 Metetra
.35596 .33857 .36493 .3349 .37834 .33245 .36947 .33588 Metetra
.36947 .33588 .37834 .33245 .39193 .32766 .38315 .33107 Metetra
.391 .834 .714 r
.38315 .33107 .39193 .32766 .40568 .32053 .397 .32411 Metetra
.524 .905 .743 r
.397 .32411 .40568 .32053 .41955 .31117 .41097 .31512 Metetra
.608 .938 .74 r
.41097 .31512 .41955 .31117 .43352 .29983 .42503 .30429 Metetra
.652 .949 .719 r
.42503 .30429 .43352 .29983 .44753 .28683 .43915 .29195 Metetra
.665 .944 .686 r
.43915 .29195 .44753 .28683 .46157 .27263 .4533 .27847 Metetra
.65 .927 .646 r
.4533 .27847 .46157 .27263 .47561 .25772 .46747 .26429 Metetra
.61 .897 .599 r
.46747 .26429 .47561 .25772 .48963 .24266 .48162 .24991 Metetra
.544 .852 .546 r
.48162 .24991 .48963 .24266 .50363 .22803 .49576 .23585 Metetra
.49576 .23585 .50363 .22803 .51761 .2144 .50988 .22261 Metetra
.50988 .22261 .51761 .2144 .53158 .20234 .524 .2107 Metetra
.524 .2107 .53158 .20234 .54558 .19235 .53814 .20057 Metetra
.53814 .20057 .54558 .19235 .55963 .18484 .55233 .19258 Metetra
.04 0 0 r
.55233 .19258 .55963 .18484 .57378 .18015 .56659 .18704 Metetra
.157 0 0 r
.56659 .18704 .57378 .18015 .58807 .17845 .58098 .18408 Metetra
.255 0 0 r
.58098 .18408 .58807 .17845 .60254 .17976 .59552 .18373 Metetra
.327 0 0 r
.59552 .18373 .60254 .17976 .61724 .18385 .61026 .18578 Metetra
.361 0 0 r
.61026 .18578 .61724 .18385 .63218 .19022 .62521 .18978 Metetra
.33 0 0 r
.62521 .18978 .63218 .19022 .64738 .19804 .64037 .19498 Metetra
0 .384 .715 r
.64037 .19498 .64738 .19804 .66279 .20602 .65573 .20025 Metetra
.084 .543 .905 r
.65573 .20025 .66279 .20602 .67834 .2124 .6712 .20405 Metetra
.412 .676 .97 r
.6712 .20405 .67834 .2124 .69386 .21482 .68666 .20432 Metetra
.665 .744 .909 r
.68666 .20432 .69386 .21482 .70913 .21034 .7019 .19851 Metetra
.823 .771 .804 r
.7019 .19851 .70913 .21034 .7238 .19543 .71665 .18355 Metetra
.918 .782 .696 r
.71665 .18355 .7238 .19543 .73744 .16616 .7305 .156 Metetra
.772 .279 0 r
.05861 .3875 .06771 .39551 .07677 .41224 .06794 .40204 Metetra
.136 .449 .881 r
.06794 .40204 .07677 .41224 .08766 .41699 .07886 .4065 Metetra
.603 .677 .893 r
.07886 .4065 .08766 .41699 .09982 .41302 .09088 .40362 Metetra
.735 .739 .855 r
.09088 .40362 .09982 .41302 .11277 .40321 .10362 .39581 Metetra
.796 .788 .845 r
.10362 .39581 .11277 .40321 .12617 .38999 .11676 .38508 Metetra
.832 .843 .855 r
.11676 .38508 .12617 .38999 .13974 .37531 .13007 .37308 Metetra
.848 .908 .876 r
.13007 .37308 .13974 .37531 .15328 .36067 .14338 .36104 Metetra
.825 .971 .892 r
.14338 .36104 .15328 .36067 .16668 .34716 .15659 .3499 Metetra
.713 .987 .861 r
.15659 .3499 .16668 .34716 .17987 .3355 .16964 .34028 Metetra
.465 .872 .716 r
.16964 .34028 .17987 .3355 .19281 .32617 .18251 .33256 Metetra
.18251 .33256 .19281 .32617 .20552 .31935 .19518 .32693 Metetra
.094 0 0 r
.19518 .32693 .20552 .31935 .21802 .31507 .2077 .3234 Metetra
.256 0 0 r
.2077 .3234 .21802 .31507 .23036 .31318 .2201 .32184 Metetra
.358 0 0 r
.2201 .32184 .23036 .31318 .24258 .31342 .23241 .32203 Metetra
.422 0 0 r
.23241 .32203 .24258 .31342 .25476 .31542 .2447 .32367 Metetra
.46 0 0 r
.2447 .32367 .25476 .31542 .26694 .31874 .25701 .32637 Metetra
.478 0 0 r
.25701 .32637 .26694 .31874 .27917 .32292 .26939 .32972 Metetra
.478 0 0 r
.26939 .32972 .27917 .32292 .29152 .32744 .28188 .3333 Metetra
.458 0 0 r
.28188 .3333 .29152 .32744 .30401 .3318 .29451 .33667 Metetra
.412 0 0 r
.29451 .33667 .30401 .3318 .31669 .33551 .30732 .33942 Metetra
.332 0 0 r
.30732 .33942 .31669 .33551 .32957 .33812 .32033 .34116 Metetra
.207 0 0 r
.32033 .34116 .32957 .33812 .34266 .33925 .33353 .34157 Metetra
.036 0 0 r
.33353 .34157 .34266 .33925 .35596 .33857 .34694 .34038 Metetra
.163 .698 .706 r
.34694 .34038 .35596 .33857 .36947 .33588 .36054 .3374 Metetra
.352 .827 .801 r
.36054 .3374 .36947 .33588 .38315 .33107 .37432 .33255 Metetra
.502 .909 .843 r
.37432 .33255 .38315 .33107 .397 .32411 .38824 .32581 Metetra
.604 .953 .848 r
.38824 .32581 .397 .32411 .41097 .31512 .40229 .31727 Metetra
.666 .973 .83 r
.40229 .31727 .41097 .31512 .42503 .30429 .41644 .3071 Metetra
.697 .979 .8 r
.41644 .3071 .42503 .30429 .43915 .29195 .43066 .29556 Metetra
.7 .973 .76 r
.43066 .29556 .43915 .29195 .4533 .27847 .44491 .28299 Metetra
.678 .956 .713 r
.44491 .28299 .4533 .27847 .46747 .26429 .45919 .26974 Metetra
.632 .925 .659 r
.45919 .26974 .46747 .26429 .48162 .24991 .47346 .25625 Metetra
.562 .878 .597 r
.47346 .25625 .48162 .24991 .49576 .23585 .48773 .24296 Metetra
.47 .815 .529 r
.48773 .24296 .49576 .23585 .50988 .22261 .502 .2303 Metetra
.502 .2303 .50988 .22261 .524 .2107 .51626 .2187 Metetra
.51626 .2187 .524 .2107 .53814 .20057 .53054 .20855 Metetra
.53054 .20855 .53814 .20057 .55233 .19258 .54486 .20016 Metetra
.54486 .20016 .55233 .19258 .56659 .18704 .55925 .19378 Metetra
.072 0 0 r
.55925 .19378 .56659 .18704 .58098 .18408 .57374 .18956 Metetra
.148 0 0 r
.57374 .18956 .58098 .18408 .59552 .18373 .58836 .18747 Metetra
.195 0 0 r
.58836 .18747 .59552 .18373 .61026 .18578 .60314 .18736 Metetra
.197 0 0 r
.60314 .18736 .61026 .18578 .62521 .18978 .6181 .18884 Metetra
.124 0 0 r
.6181 .18884 .62521 .18978 .64037 .19498 .63324 .19126 Metetra
.055 .577 .871 r
.63324 .19126 .64037 .19498 .65573 .20025 .64855 .19368 Metetra
.302 .668 .974 r
.64855 .19368 .65573 .20025 .6712 .20405 .66395 .19479 Metetra
.526 .713 .958 r
.66395 .19479 .6712 .20405 .68666 .20432 .67934 .19289 Metetra
.692 .736 .885 r
.67934 .19289 .68666 .20432 .7019 .19851 .69457 .18584 Metetra
.813 .756 .799 r
.69457 .18584 .7019 .19851 .71665 .18355 .70939 .17109 Metetra
.903 .776 .711 r
.70939 .17109 .71665 .18355 .7305 .156 .7235 .14574 Metetra
.656 .14 0 r
.04942 .37942 .05861 .3875 .06794 .40204 .05914 .39108 Metetra
.229 .485 .892 r
.05914 .39108 .06794 .40204 .07886 .4065 .07015 .39478 Metetra
.574 .641 .879 r
.07015 .39478 .07886 .4065 .09088 .40362 .08207 .3927 Metetra
.688 .699 .855 r
.08207 .3927 .09088 .40362 .10362 .39581 .0946 .3867 Metetra
.746 .749 .855 r
.0946 .3867 .10362 .39581 .11676 .38508 .10747 .37838 Metetra
.781 .808 .874 r
.10747 .37838 .11676 .38508 .13007 .37308 .1205 .369 Metetra
.797 .876 .905 r
.1205 .369 .13007 .37308 .14338 .36104 .13357 .35955 Metetra
.775 .943 .934 r
.13357 .35955 .14338 .36104 .15659 .3499 .14657 .35075 Metetra
.676 .97 .919 r
.14657 .35075 .15659 .3499 .16964 .34028 .15948 .34311 Metetra
.463 .886 .805 r
.15948 .34311 .16964 .34028 .18251 .33256 .17225 .33692 Metetra
.17225 .33692 .18251 .33256 .19518 .32693 .1849 .33234 Metetra
.031 0 0 r
.1849 .33234 .19518 .32693 .2077 .3234 .19744 .32937 Metetra
.183 0 0 r
.19744 .32937 .2077 .3234 .2201 .32184 .20991 .32792 Metetra
.28 0 0 r
.20991 .32792 .2201 .32184 .23241 .32203 .22233 .3278 Metetra
.338 0 0 r
.22233 .3278 .23241 .32203 .2447 .32367 .23475 .32877 Metetra
.367 0 0 r
.23475 .32877 .2447 .32367 .25701 .32637 .24721 .33052 Metetra
.37 0 0 r
.24721 .33052 .25701 .32637 .26939 .32972 .25974 .33272 Metetra
.345 0 0 r
.25974 .33272 .26939 .32972 .28188 .3333 .27239 .33504 Metetra
.282 0 0 r
.27239 .33504 .28188 .3333 .29451 .33667 .28518 .33711 Metetra
.171 0 0 r
.28518 .33711 .29451 .33667 .30732 .33942 .29814 .33861 Metetra
0 .568 .738 r
.29814 .33861 .30732 .33942 .32033 .34116 .31127 .33924 Metetra
.182 .701 .88 r
.31127 .33924 .32033 .34116 .33353 .34157 .32458 .33874 Metetra
.362 .797 .965 r
.32458 .33874 .33353 .34157 .34694 .34038 .33809 .33689 Metetra
.505 .853 .994 r
.33809 .33689 .34694 .34038 .36054 .3374 .35176 .33356 Metetra
.607 .883 .991 r
.35176 .33356 .36054 .3374 .37432 .33255 .36561 .32866 Metetra
.68 .903 .975 r
.36561 .32866 .37432 .33255 .38824 .32581 .37959 .3222 Metetra
.732 .921 .956 r
.37959 .3222 .38824 .32581 .40229 .31727 .3937 .31423 Metetra
.769 .939 .938 r
.3937 .31423 .40229 .31727 .41644 .3071 .4079 .3049 Metetra
.793 .959 .92 r
.4079 .3049 .41644 .3071 .43066 .29556 .42217 .29441 Metetra
.803 .978 .9 r
.42217 .29441 .43066 .29556 .44491 .28299 .43649 .28301 Metetra
.798 .993 .876 r
.43649 .28301 .44491 .28299 .45919 .26974 .45085 .27101 Metetra
.771 .997 .843 r
.45085 .27101 .45919 .26974 .47346 .25625 .46522 .25873 Metetra
.718 .984 .798 r
.46522 .25873 .47346 .25625 .48773 .24296 .4796 .24654 Metetra
.639 .95 .74 r
.4796 .24654 .48773 .24296 .502 .2303 .49398 .23477 Metetra
.537 .893 .674 r
.49398 .23477 .502 .2303 .51626 .2187 .50837 .22379 Metetra
.424 .822 .607 r
.50837 .22379 .51626 .2187 .53054 .20855 .52278 .21388 Metetra
.52278 .21388 .53054 .20855 .54486 .20016 .53723 .20532 Metetra
.53723 .20532 .54486 .20016 .55925 .19378 .55174 .19829 Metetra
.55174 .19829 .55925 .19378 .57374 .18956 .56633 .19292 Metetra
.56633 .19292 .57374 .18956 .58836 .18747 .58103 .18919 Metetra
.58103 .18919 .58836 .18747 .60314 .18736 .59586 .18697 Metetra
.107 .661 .778 r
.59586 .18697 .60314 .18736 .6181 .18884 .61083 .18595 Metetra
.214 .71 .917 r
.61083 .18595 .6181 .18884 .63324 .19126 .62595 .18562 Metetra
.358 .731 .988 r
.62595 .18562 .63324 .19126 .64855 .19368 .6412 .18522 Metetra
.494 .721 .973 r
.6412 .18522 .64855 .19368 .66395 .19479 .65654 .18374 Metetra
.607 .709 .916 r
.65654 .18374 .66395 .19479 .67934 .19289 .67189 .17984 Metetra
.703 .71 .854 r
.67189 .17984 .67934 .19289 .69457 .18584 .68711 .17185 Metetra
.793 .73 .794 r
.68711 .17185 .69457 .18584 .70939 .17109 .70204 .1578 Metetra
.878 .763 .731 r
.70204 .1578 .70939 .17109 .7235 .14574 .71642 .13538 Metetra
0 .144 .624 r
.04016 .37126 .04942 .37942 .05914 .39108 .05042 .37904 Metetra
.364 .535 .891 r
.05042 .37904 .05914 .39108 .07015 .39478 .06164 .38124 Metetra
.566 .604 .85 r
.06164 .38124 .07015 .39478 .08207 .3927 .07353 .37938 Metetra
.644 .642 .834 r
.07353 .37938 .08207 .3927 .0946 .3867 .08587 .37477 Metetra
.687 .682 .84 r
.08587 .37477 .0946 .3867 .10747 .37838 .0985 .3685 Metetra
.715 .73 .862 r
.0985 .3685 .10747 .37838 .1205 .369 .11127 .36146 Metetra
.73 .787 .898 r
.11127 .36146 .1205 .369 .13357 .35955 .12409 .35432 Metetra
.725 .849 .94 r
.12409 .35432 .13357 .35955 .14657 .35075 .1369 .34761 Metetra
.683 .901 .974 r
.1369 .34761 .14657 .35075 .15948 .34311 .14966 .34165 Metetra
.586 .915 .973 r
.14966 .34165 .15948 .34311 .17225 .33692 .16235 .33668 Metetra
.438 .87 .92 r
.16235 .33668 .17225 .33692 .1849 .33234 .17499 .33279 Metetra
.28 .783 .837 r
.17499 .33279 .1849 .33234 .19744 .32937 .18757 .32999 Metetra
.154 .696 .768 r
.18757 .32999 .19744 .32937 .20991 .32792 .20013 .32821 Metetra
.078 .639 .741 r
.20013 .32821 .20991 .32792 .22233 .3278 .21268 .32732 Metetra
.053 .619 .761 r
.21268 .32732 .22233 .3278 .23475 .32877 .22526 .32713 Metetra
.078 .63 .821 r
.22526 .32713 .23475 .32877 .24721 .33052 .2379 .32744 Metetra
.148 .659 .898 r
.2379 .32744 .24721 .33052 .25974 .33272 .25061 .328 Metetra
.246 .684 .959 r
.25061 .328 .25974 .33272 .27239 .33504 .26344 .32857 Metetra
.346 .692 .982 r
.26344 .32857 .27239 .33504 .28518 .33711 .27639 .32891 Metetra
.431 .683 .97 r
.27639 .32891 .28518 .33711 .29814 .33861 .28949 .32878 Metetra
.495 .669 .941 r
.28949 .32878 .29814 .33861 .31127 .33924 .30274 .32797 Metetra
.544 .657 .91 r
.30274 .32797 .31127 .33924 .32458 .33874 .31615 .3263 Metetra
.582 .65 .883 r
.31615 .3263 .32458 .33874 .33809 .33689 .32972 .32362 Metetra
.614 .649 .862 r
.32972 .32362 .33809 .33689 .35176 .33356 .34344 .31983 Metetra
.641 .654 .847 r
.34344 .31983 .35176 .33356 .36561 .32866 .35731 .31489 Metetra
.667 .665 .839 r
.35731 .31489 .36561 .32866 .37959 .3222 .3713 .30877 Metetra
.691 .681 .836 r
.3713 .30877 .37959 .3222 .3937 .31423 .38541 .30154 Metetra
.715 .703 .838 r
.38541 .30154 .3937 .31423 .4079 .3049 .39961 .29329 Metetra
.738 .731 .845 r
.39961 .29329 .4079 .3049 .42217 .29441 .41388 .28415 Metetra
.76 .765 .857 r
.41388 .28415 .42217 .29441 .43649 .28301 .42822 .2743 Metetra
.78 .804 .872 r
.42822 .2743 .43649 .28301 .45085 .27101 .44259 .26396 Metetra
.795 .847 .89 r
.44259 .26396 .45085 .27101 .46522 .25873 .457 .25337 Metetra
.802 .892 .909 r
.457 .25337 .46522 .25873 .4796 .24654 .47144 .24275 Metetra
.794 .933 .923 r
.47144 .24275 .4796 .24654 .49398 .23477 .4859 .23238 Metetra
.767 .963 .93 r
.4859 .23238 .49398 .23477 .50837 .22379 .50038 .22248 Metetra
.717 .974 .925 r
.50038 .22248 .50837 .22379 .52278 .21388 .51489 .21329 Metetra
.65 .964 .913 r
.51489 .21329 .52278 .21388 .53723 .20532 .52944 .20499 Metetra
.578 .941 .903 r
.52944 .20499 .53723 .20532 .55174 .19829 .54405 .19771 Metetra
.518 .914 .908 r
.54405 .19771 .55174 .19829 .56633 .19292 .55872 .19155 Metetra
.483 .891 .933 r
.55872 .19155 .56633 .19292 .58103 .18919 .57349 .18649 Metetra
.477 .869 .97 r
.57349 .18649 .58103 .18919 .59586 .18697 .58836 .18244 Metetra
.497 .836 .998 r
.58836 .18244 .59586 .18697 .61083 .18595 .60335 .17918 Metetra
.529 .788 .992 r
.60335 .17918 .61083 .18595 .62595 .18562 .61845 .17636 Metetra
.564 .734 .955 r
.61845 .17636 .62595 .18562 .6412 .18522 .63366 .17344 Metetra
.601 .69 .905 r
.63366 .17344 .6412 .18522 .65654 .18374 .64895 .16972 Metetra
.643 .667 .858 r
.64895 .16972 .65654 .18374 .67189 .17984 .66426 .16427 Metetra
.694 .666 .819 r
.66426 .16427 .67189 .17984 .68711 .17185 .67951 .15595 Metetra
.758 .69 .787 r
.67951 .15595 .68711 .17185 .70204 .1578 .69456 .14336 Metetra
.837 .739 .757 r
.69456 .14336 .70204 .1578 .71642 .13538 .70927 .12491 Metetra
.212 .557 .934 r
.03081 .36304 .04016 .37126 .05042 .37904 .04185 .36557 Metetra
.511 .58 .861 r
.04185 .36557 .05042 .37904 .06164 .38124 .05344 .36516 Metetra
.583 .573 .808 r
.05344 .36516 .06164 .38124 .07353 .37938 .06542 .36261 Metetra
.616 .582 .792 r
.06542 .36261 .07353 .37938 .08587 .37477 .07768 .3586 Metetra
.637 .6 .795 r
.07768 .3586 .08587 .37477 .0985 .3685 .09012 .35371 Metetra
.652 .625 .81 r
.09012 .35371 .0985 .3685 .11127 .36146 .10267 .34838 Metetra
.662 .656 .834 r
.10267 .34838 .11127 .36146 .12409 .35432 .11529 .34297 Metetra
.665 .689 .863 r
.11529 .34297 .12409 .35432 .1369 .34761 .12793 .33776 Metetra
.66 .721 .894 r
.12793 .33776 .1369 .34761 .14966 .34165 .14059 .33291 Metetra
.646 .744 .921 r
.14059 .33291 .14966 .34165 .16235 .33668 .15324 .32854 Metetra
.625 .755 .94 r
.15324 .32854 .16235 .33668 .17499 .33279 .1659 .32471 Metetra
.602 .75 .948 r
.1659 .32471 .17499 .33279 .18757 .32999 .17857 .32141 Metetra
.582 .731 .945 r
.17857 .32141 .18757 .32999 .20013 .32821 .19126 .31861 Metetra
.569 .7 .93 r
.19126 .31861 .20013 .32821 .21268 .32732 .20398 .31624 Metetra
.561 .662 .905 r
.20398 .31624 .21268 .32732 .22526 .32713 .21675 .31419 Metetra
.557 .622 .873 r
.21675 .31419 .22526 .32713 .2379 .32744 .22959 .31235 Metetra
.556 .585 .838 r
.22959 .31235 .2379 .32744 .25061 .328 .24251 .3106 Metetra
.557 .553 .805 r
.24251 .3106 .25061 .328 .26344 .32857 .25552 .30881 Metetra
.56 .527 .776 r
.25552 .30881 .26344 .32857 .27639 .32891 .26864 .30684 Metetra
.563 .508 .751 r
.26864 .30684 .27639 .32891 .28949 .32878 .28187 .30458 Metetra
.567 .494 .732 r
.28187 .30458 .28949 .32878 .30274 .32797 .29522 .30191 Metetra
.573 .485 .717 r
.29522 .30191 .30274 .32797 .31615 .3263 .3087 .29875 Metetra
.579 .48 .707 r
.3087 .29875 .31615 .3263 .32972 .32362 .32229 .29501 Metetra
.586 .479 .699 r
.32229 .29501 .32972 .32362 .34344 .31983 .336 .29065 Metetra
.593 .481 .696 r
.336 .29065 .34344 .31983 .35731 .31489 .34982 .28563 Metetra
.601 .487 .695 r
.34982 .28563 .35731 .31489 .3713 .30877 .36375 .27996 Metetra
.611 .495 .697 r
.36375 .27996 .3713 .30877 .38541 .30154 .37778 .27366 Metetra
.621 .506 .702 r
.37778 .27366 .38541 .30154 .39961 .29329 .39189 .26677 Metetra
.632 .521 .71 r
.39189 .26677 .39961 .29329 .41388 .28415 .40607 .25938 Metetra
.643 .539 .721 r
.40607 .25938 .41388 .28415 .42822 .2743 .42033 .25156 Metetra
.656 .561 .736 r
.42033 .25156 .42822 .2743 .44259 .26396 .43464 .24344 Metetra
.669 .586 .754 r
.43464 .24344 .44259 .26396 .457 .25337 .449 .23512 Metetra
.682 .616 .776 r
.449 .23512 .457 .25337 .47144 .24275 .46342 .22675 Metetra
.693 .65 .802 r
.46342 .22675 .47144 .24275 .4859 .23238 .47787 .21845 Metetra
.703 .685 .83 r
.47787 .21845 .4859 .23238 .50038 .22248 .49238 .21035 Metetra
.707 .719 .859 r
.49238 .21035 .50038 .22248 .51489 .21329 .50693 .20257 Metetra
.705 .749 .886 r
.50693 .20257 .51489 .21329 .52944 .20499 .52153 .19522 Metetra
.697 .769 .907 r
.52153 .19522 .52944 .20499 .54405 .19771 .5362 .18836 Metetra
.682 .775 .921 r
.5362 .18836 .54405 .19771 .55872 .19155 .55093 .18204 Metetra
.666 .767 .926 r
.55093 .18204 .55872 .19155 .57349 .18649 .56574 .17626 Metetra
.65 .745 .919 r
.56574 .17626 .57349 .18649 .58836 .18244 .58064 .17097 Metetra
.637 .712 .901 r
.58064 .17097 .58836 .18244 .60335 .17918 .59563 .16606 Metetra
.628 .675 .875 r
.59563 .16606 .60335 .17918 .61845 .17636 .61071 .16134 Metetra
.625 .64 .845 r
.61071 .16134 .61845 .17636 .63366 .17344 .62589 .15654 Metetra
.629 .615 .817 r
.62589 .15654 .63366 .17344 .64895 .16972 .64113 .15128 Metetra
.641 .602 .795 r
.64113 .15128 .64895 .16972 .66426 .16427 .65642 .14509 Metetra
.663 .606 .781 r
.65642 .14509 .66426 .16427 .67951 .15595 .67172 .13737 Metetra
.701 .633 .777 r
.67172 .13737 .67951 .15595 .69456 .14336 .68696 .12741 Metetra
.764 .694 .785 r
.68696 .12741 .69456 .14336 .70927 .12491 .70205 .11434 Metetra
.657 .75 .919 r
.02138 .35474 .03081 .36304 .04185 .36557 .03352 .35021 Metetra
.633 .607 .806 r
.03352 .35021 .04185 .36557 .05344 .36516 .04571 .34566 Metetra
.618 .553 .759 r
.04571 .34566 .05344 .36516 .06542 .36261 .05797 .34109 Metetra
.611 .532 .74 r
.05797 .34109 .06542 .36261 .07768 .3586 .07029 .3365 Metetra
.609 .526 .736 r
.07029 .3365 .07768 .3586 .09012 .35371 .08267 .33188 Metetra
.61 .53 .739 r
.08267 .33188 .09012 .35371 .10267 .34838 .09511 .32724 Metetra
.613 .537 .745 r
.09511 .32724 .10267 .34838 .11529 .34297 .10761 .32258 Metetra
.616 .546 .753 r
.10761 .32258 .11529 .34297 .12793 .33776 .12017 .3179 Metetra
.618 .552 .759 r
.12017 .3179 .12793 .33776 .14059 .33291 .1328 .31319 Metetra
.618 .554 .76 r
.1328 .31319 .14059 .33291 .15324 .32854 .14549 .30846 Metetra
.617 .551 .757 r
.14549 .30846 .15324 .32854 .1659 .32471 .15824 .30371 Metetra
.614 .541 .749 r
.15824 .30371 .1659 .32471 .17857 .32141 .17105 .29893 Metetra
.61 .527 .736 r
.17105 .29893 .17857 .32141 .19126 .31861 .18393 .29413 Metetra
.604 .51 .721 r
.18393 .29413 .19126 .31861 .20398 .31624 .19688 .2893 Metetra
.597 .491 .704 r
.19688 .2893 .20398 .31624 .21675 .31419 .20988 .28445 Metetra
.59 .473 .687 r
.20988 .28445 .21675 .31419 .22959 .31235 .22296 .27957 Metetra
.584 .456 .671 r
.22296 .27957 .22959 .31235 .24251 .3106 .2361 .27467 Metetra
.578 .441 .658 r
.2361 .27467 .24251 .3106 .25552 .30881 .24931 .26975 Metetra
.573 .428 .646 r
.24931 .26975 .25552 .30881 .26864 .30684 .26258 .2648 Metetra
.569 .417 .636 r
.26258 .2648 .26864 .30684 .28187 .30458 .27592 .25983 Metetra
.565 .409 .628 r
.27592 .25983 .28187 .30458 .29522 .30191 .28933 .25483 Metetra
.563 .402 .621 r
.28933 .25483 .29522 .30191 .3087 .29875 .30281 .2498 Metetra
.561 .397 .617 r
.30281 .2498 .3087 .29875 .32229 .29501 .31636 .24475 Metetra
.559 .394 .614 r
.31636 .24475 .32229 .29501 .336 .29065 .32997 .23967 Metetra
.559 .392 .612 r
.32997 .23967 .336 .29065 .34982 .28563 .34366 .23457 Metetra
.559 .392 .612 r
.34366 .23457 .34982 .28563 .36375 .27996 .35742 .22944 Metetra
.559 .394 .614 r
.35742 .22944 .36375 .27996 .37778 .27366 .37125 .22428 Metetra
.561 .397 .617 r
.37125 .22428 .37778 .27366 .39189 .26677 .38515 .2191 Metetra
.563 .402 .621 r
.38515 .2191 .39189 .26677 .40607 .25938 .39913 .21389 Metetra
.565 .409 .628 r
.39913 .21389 .40607 .25938 .42033 .25156 .41317 .20865 Metetra
.569 .417 .636 r
.41317 .20865 .42033 .25156 .43464 .24344 .42729 .20338 Metetra
.573 .428 .646 r
.42729 .20338 .43464 .24344 .449 .23512 .44149 .19809 Metetra
.578 .441 .658 r
.44149 .19809 .449 .23512 .46342 .22675 .45576 .19277 Metetra
.584 .456 .671 r
.45576 .19277 .46342 .22675 .47787 .21845 .4701 .18742 Metetra
.59 .473 .687 r
.4701 .18742 .47787 .21845 .49238 .21035 .48453 .18204 Metetra
.597 .491 .704 r
.48453 .18204 .49238 .21035 .50693 .20257 .49902 .17664 Metetra
.604 .51 .721 r
.49902 .17664 .50693 .20257 .52153 .19522 .5136 .1712 Metetra
.61 .527 .736 r
.5136 .1712 .52153 .19522 .5362 .18836 .52825 .16574 Metetra
.614 .541 .749 r
.52825 .16574 .5362 .18836 .55093 .18204 .54298 .16025 Metetra
.617 .551 .757 r
.54298 .16025 .55093 .18204 .56574 .17626 .55779 .15472 Metetra
.618 .554 .76 r
.55779 .15472 .56574 .17626 .58064 .17097 .57268 .14917 Metetra
.618 .552 .759 r
.57268 .14917 .58064 .17097 .59563 .16606 .58765 .14359 Metetra
.616 .546 .753 r
.58765 .14359 .59563 .16606 .61071 .16134 .60271 .13798 Metetra
.613 .537 .745 r
.60271 .13798 .61071 .16134 .62589 .15654 .61784 .13233 Metetra
.61 .53 .739 r
.61784 .13233 .62589 .15654 .64113 .15128 .63305 .12666 Metetra
.609 .526 .736 r
.63305 .12666 .64113 .15128 .65642 .14509 .64835 .12096 Metetra
.611 .532 .74 r
.64835 .12096 .65642 .14509 .67172 .13737 .66374 .11522 Metetra
.618 .553 .759 r
.66374 .11522 .67172 .13737 .68696 .12741 .6792 .10945 Metetra
.633 .607 .806 r
.6792 .10945 .68696 .12741 .70205 .11434 .69475 .10365 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{327, 265.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006H0001Bb000`400?l00000o`00003ooooooonI
ooooo`00oooooonIooooo`00oooooonIooooo`00oooooonIooooo`00oooooonIooooo`00oooooonI
ooooo`00oooooonIooooo`00oooooonIooooo`00oooooonIooooo`00oooooonIooooo`00oooooonI
ooooo`00oooooonIooooo`00oooooonIooooo`00oooooonIooooo`00oooooolPooooo`Co000000?o
410@ooooooooool0L_ooool00?oooooo8_ooool00ol0003oooooooooo`1dooooo`00oooooolRoooo
o`03o`000?oooooooooo07Cooooo003oooooob;ooooo00?o0000ooooooooool0M?ooool00?oooooo
8_ooool00ol0003oooooooooo`1dooooo`00oooooolRooooo`03o`000?oooooooooo07Cooooo003o
ooooob;ooooo00?o0000ooooooooool0M?ooool00?oooooo8?ooool00omEEEGoIVIVo`00000:oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0Ioooool00?oooooo;Oooool01OmgMgOoV9RHoooooonHV9So
MgMg06Oooooo003oooooobgooooo00Go410@oooooooooooooooooa0@401Wooooo`00ooooool]oooo
o`05o`000?ooooooooooooooool00000Ioooool00?oooooo;Oooool01Ol0003ooooooooooooooooo
000006Oooooo003oooooobgooooo00Go410@oooooooooooooooooa0@401Wooooo`00oooooolWoooo
o`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg06Oooooo003oooooobCooooo0ol000000ooo
oooo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0Ioooool00?oooooo8_ooool2o`00
00Cooooo0_l0001_ooooo`00oooooolOooooo`?o00001_ooool00ol0003oooooo`00001^ooooo`00
oooooolMooooo`;o00002Oooool00ol0003oooooo`00001^ooooo`00oooooolJooooo`?o00002ooo
ool01?l0003oooooooooool0001]ooooo`00oooooolGooooo`Co00003Oooool01Ol0003ooooooooo
oooooooo000006cooooo003ooooooaGooooo0_l00004ooooo`03o`000?oooooooooo00[ooooo00Go
0000ooooooooooooooooo`00001/ooooo`00g?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`08?ooool3o`0001?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Yooooo`00g?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B407_ooool2o`0001Kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Xooooo`00g?ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`?o00006Oooool00ol0003oooooooooo`03
o`0006[ooooo003Looooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonH
V9So<S8b01Wooooo0ol0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Iooo
ool00=cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0
5_ooool3o`0000?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo06Oooooo003Looooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zj
oooooonj^[[o410@01Cooooo0_l0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0I_ooool00=cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj
^_l000004Oooool3o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Uoooo
o`00g?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0?
ooooo`;o00009_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06Gooooo003moooo
o`Co00009oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Cooooo002@ooooo`;o
00000_ooool2o`0006Cooooo0ol00003ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1Sooooo`00T?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgM
gF;ooooo0_l0000^ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Hoooool0097o
oooo00CogMgMo`000?l@413oc<c<H?ooool3o`00033ooooo00?o0000ooooooooool01_ooool3o`00
06Cooooo002Aooooo`04onk^k_lQ8B7o410@onk^kUkooooo0_l0000cooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0HOooool0097ooooo00Co8B4QogMgMomgMgOo<S8bFoooool4o`00
03Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Qooooo`00T?ooool2o`0000;o
oooo0_l0001Hooooo`;o00001?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0H?ooool00>_ooooo0ol0000jooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0Goooool00>Wooooo0_l0000mooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0Goooool00>Kooooo0ol0000oooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0G_ooool00>Cooooo0_l000000ooooooo0000ooooo`0oooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0GOooool00:[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<02;ooooo0ol00003ooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Mooooo`00Z_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B408?oo
ool2o`0004Sooooo00?o0000ooooooooool02oooool3o`0005kooooo002Zooooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol0003ooooooooooooooooo000001gooooo0ol0001:ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0Foooool00:[ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B406_ooool3o`0004gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`07ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo1Ol0000oooooo`00Z_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEE
EOl0003o410@olc<c00Hooooo`;o00000_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0?oooool00:[ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`03oeEEEOn7QhOooooo01Oooooo0ol0001Booooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool01_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h0@?ooool00:[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01Go
oooo0_l0001Eooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool01Ol0003o
oooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?oooool00:[ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@413ooooo0ol0001Gooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool0?_ooool00<gooooo0_l0001Jooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0?Ooo
ool00<[ooooo0ol00002ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@03oooooo0038ooooo`;o0000Goooool00ol0003oooooooooo`0Aooooo`?o00001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00oooooo`00
aOooool3o`00063ooooo0_l0000Booooo`04o`000?ooooooooooo`0005Sooooo0033ooooo`;o0000
H?ooool3o`000003oj:Kc_l0003ooooo01Gooooo00?o0000ooooooooool0EOooool00<3ooooo1?l0
001Nooooo`?o00001?nRVlh2o`0001Kooooo00?o0000ooooooooool0E?ooool00;gooooo0ol00004
ooooo`03o`000?oooooooooo05Sooooo0ol000000onNSL;o0000oj:KcP04oj:KcP03o`000?nRVlko
000001Gooooo00?o0000ooooooooool0E?ooool00;_ooooo0_l0001Pooooo`;o00001OnNSL800ol0
003oXY_>oj:KcP02oj:KcP?o00005_ooool00ol0003oooooooooo`1Cooooo`00^?ooool3o`0005oo
oooo0ol000000onLR;go0000oij=`P04oij=`P03o`000?nRVlkoXY_>00;oXY_>00Co0000ol>ab?o3
/LSo00005_ooool00ol0003oooooooooo`1Booooo`00]_ooool2o`0005oooooo0ol00004oib8_@03
o`000?nNSL;oWXg200CoWXg200?o0000oj:Kc_nRVlh00_l00003ol>ab003o`000?oooooooooo01?o
oooo00?o0000ooooooooool0D_ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool2o`000003oa0@4?oooooooooo02;ooooo0ol000000ooooooo0000ooooo`1Kooooo`?o
000000?oVhJlo`000?nLR;d01OnLR;d00ol0003oWXg2oij=`P03oij=`P03o`000?nRVlko000000;o
`k7800Go0000ol>ab?o3/LSo`k78o`00000Eooooo`03o`000?oooooooooo057ooooo001jooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool08Oooool2o`00
05oooooo0_l00005oi^6_003o`000?nLR;goW8Rm00?oW8Rm00?o0000oij=`_nNSL800onNSL82o`00
00?o`k7800Go0000ol>ab?o3/LSo`k78o`00000Dooooo`03o`000?oooooo000005;ooooo001joooo
o`05oa0@4?ooooooooooooooool@41002oooool5o`0001oooooo0ol0001Nooooo`?o000000?oW8Nm
o`000?nKQ[`01?nKQ[`00ol0003oW8Rmoib8_@03oib8_@03o`000?nNSL;oWXg200;oWXg200?o0000
ok>Ra_l000000oo3/LP01_l0003o`k78ol>ab?l0003oe[g1o`0001Gooooo00?o0000ooooooooool0
D?ooool007[ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001ko
oooo0_l0001Nooooo`?o00001?nLQkd00ol0003oVhJloi^6_003oi^6_003o`000?nLR;goW8Rm00?o
W8Rm00?o0000oij=`_nNSL800_l00003ok>RaP06o`000?o3/LSo`k78o`000?o3/LSo00000_oF_L40
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04oooooo001jooooo`05o`000?oooooooooo
ooooool000002oooool01?oMgMgoEEEEooooool0000Kooooo`?o0000GOooool3o`000003oib9__l0
003oW8Nm00GoW8Nm00?o0000oi^6_?nKQ[`00onKQ[`00ol0003oW8Rmoib8_@03oib8_@;o00001Onc
X/H00ol0003o`k78ol>ab002o`0000Coe[g100?o0000ooooooooool04oooool00ol0003ooooooooo
o`1?ooooo`00N_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000006Ooo
ool2o`0000;ooooo00?o0000ooooooooool0FOooool2o`0000GoW8Vn00?o0000oib7_OnLQkd00onL
Qkd00ol0003oVhJloi^6_003oi^6_003o`000?nLR;goW8Rm00;oW8Rm0_l00007ok>RaP04o`000?o3
/LSo0000o`0000Coe[g100?o0000ooooooooool05?ooool00ol0003oooooooooo`1>ooooo`00N_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000005_ooool3o`0005gooooo
0ol000000onMRl3o0000oib9_P04oib9_P03o`000?nLQkgoW8Nm00?oW8Nm00?o0000oi^6_?nKQ[`0
0onKQ[`00ol0003oW8Rmo`000002o`000003ojVKaol0003o/j;600Ko/j;600?o0000ol>ab?l00000
1?oF_L400ol0003oh<>ko`00000Fooooo`03o`000?oooooooooo04gooooo001jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Booooo`?o0000GOooool3o`0000GoWH_0
00?o0000oib9__nLRKh00_nLRKh00ol0003oW8Nmoib7_@03oib7_@03o`000?nKQ[coVhJl00?oVhJl
0_l00005ojVKa`03o`000?ncX/Ko/j;600Co/j;60ol00003omJm`@05o`000?oP`k_oh<>kon33^ol0
00005Oooool00ol0003oooooooooo`1=ooooo`00Woooool2o`0005gooooo0ol000000onNSL;o0000
oif;`005oif;`003o`000?nLRKkoW8Vn00?oW8Vn00?o0000oib7_OnLQkd00_nLQkd01?l0003oVhJl
oi^6_?nKQ[`2o`000003ojBJbol0003oZI_700CoZI_700?o0000ok>Ra_ncX/H00oncX/H01?l0003o
`[39o`000?l00003omJm`@03o`000?oP`k_oh<>k00;oh<>k00?o0000ooooooooool04oooool00ol0
003oooooooooo`1<ooooo`00W?ooool3o`000003ooooool0003ooooo05[ooooo0_l00005oij=`P03
o`000?nMRl3oWH_000?oWH_000?o0000oib9__nLRKh00onLRKh00ol0003oW8Nmoib7_@03oib7_@?o
00001?nTV//00ol0003oZI_7ojVKa`03ojVKa`03o`000?ncX/Ko/j;600;o00000oo2/<T01?l0003o
e[g1omJm`Ol00005on33^`;o00004oooool3o`0004gooooo002Jooooo`;o0000GOooool3o`000003
oij=`_l0003oWXg200CoWXg200?o0000oif;`?nMRl001?nMRl000ol0003oW8Vnoib9_P02oib9_P03
o`000?nLQkgoW8Nm00;oW8Nm0_l00006ojBJb`03o`000?nYVlOoZI_700?oZI_700?o0000ok>Ra_l0
00001Oo2/<T01?l0003oe[g1omJm`Ol00004on33^`04o`000?oWa[KoilJfo`0001Cooooo00?o0000
ooooooooool0Boooool009Oooooo0ol0001Mooooo`;o00001OnNSL800ol0003oWXg2oij=`P02oij=
`P03o`000?nMRl3oWH_000CoWH_000?o0000oib9__nLRKh00onLRKh4o`000003oj6MdOl0003oY9[;
00KoY9[;00?o0000ojVKaonYVlL00_nYVlL2o`0000Ko`[3900?o0000omJm`Ol000001OoP`k/01Ol0
003oilJfonO6]_oWa[Ko000001Cooooo00?o0000ooooooooool0B_ooool009Gooooo0_l0001Moooo
o`?o000000?oWHg1o`000?nNSL801?nNSL800ol0003oWXg2oij=`P03oij=`P03o`000?nMRl3oWH_0
00?oWH_000Co0000oib9__nLRKkoW8Vn0ol00005oj6Md@03o`000?nTV/_oY9[;00CoY9[;00?o0000
ojVKaonYVlL00_l000000onaZ]7o0000ol:`b@05ol:`b@;o00001OoP`k/00ol0003oilJfonO6]P02
onO6]P03o`000?oooooooooo01?ooooo00?o0000ooooooooool0BOooool009;ooooo0ol0001Loooo
o`?o00001?nMSL400ol0003oWXg2oij=`P03oij=`P03o`000?nNSL;oWXg200?oWXg200?o0000oif;
`?nMRl000onMRl04o`0000;oWj?H00?o0000oj6MdOnQWM400onQWM400ol0003oY9[;ojBJb`04ojBJ
b`03o`000?nYVlOo000000Co/J[A00?o0000ol:`bOo2/<T00oo2/<T2o`0000Coh<>k00?o0000onO6
]_oWa[H00_oWa[H00ol0003ojlRbo`00000Dooooo`03o`000?oooooooooo04Wooooo002@ooooo`;o
00000_ooool00ol0003oooooooooo`1Gooooo`?o000000?oWHZoo`000?nMSL401OnMSL400ol0003o
WXg2oij=`P03oij=`P03o`000?nNSL;oWXg200;oWXg200?o0000oif;`?nMRl000ol000000onP[=oo
0000oinSf004oinSf003o`000?nQWM7oXIgA00?oXIgA00?o0000ojBJbonTV//00onTV//2o`0000Go
/J[A00?o0000ol:`bOo2/<T00_o2/<T2o`000003ol^jbol0003oh<>k00;oh<>k00?o0000onO6]_oW
a[H00_oWa[H00ol0003ojlRbo`00000Eooooo`03o`000?oooooooooo04Sooooo002=ooooo`?o0000
1Oooool00ol0003oooooooooo`1Dooooo`;o00001OnMR[l00ol0003oWHg1oif=`@03oif=`@03o`00
0?nNSL;oWXg200?oWXg200?o0000oij=`_nNSL800_nNSL83o`0000GoX:cO00?o0000oinSf?nOXmP0
0_nOXmP00ol0003oXIgAoj6Md@03oj6Md@03o`000?nTV/_oY9[;00?o000000?oY:[Ko`000?naZ]40
1OnaZ]401_l0003o`[39ol:`bOl0003obk[;o`0000;obk[;00?o0000on33^ol000001?oWa[H01Ol0
003ojlRbon_8/_o[b;;o000001Gooooo00?o0000ooooooooool0Aoooool008_ooooo0_l0001Loooo
o`?o000000?oW8Jlo`000?nMR[l01?nMR[l00ol0003oWHg1oif=`@03oif=`@03o`000?nNSL;oWXg2
00?oWXg200?o0000oij=`_l000000_l000000onS]^Ko0000oj2/g`05oj2/g`03o`000?nOXmSoWj?H
00?oWj?H00?o0000oj6MdOnQWM400_nQWM43o`0000GoY:[K00?o0000ok6ZdOnaZ]400onaZ]400ol0
003o`[39o`000002ol^jb`06o`000?o;^/_obk[;o`000?oP`k_o00001?oWa[H01Ol0003ojlRbon_8
/_o[b;;o000001Gooooo00?o0000ooooooooool0Aoooool008Sooooo0ol0001Looooo`;o00001OnL
Q[`00ol0003oWHZooif:_`02oif:_`03o`000?nMSL7oWHg100?oWHg100?o0000oij=`_nNSL800onN
SL82o`0000GoXkKV00?o0000oj2/gonP[=l00onP[=l00ol0003oWj?HoinSf003oinSf003o`000?nQ
WM7o000000;o000000?oVK3Wo`000?nTZ]/01OnTZ]/00ol0003o/J[Aok6Zd@03ok6Zd@;o00000oo;
^//01Ol0003obk[;ol^jboo;^/_o000000CoilJf00Oo0000on_8/_o[b;;ojlRbo`000?o]b:ko0000
01Cooooo0_l00018ooooo`00COooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00008oooool3o`000003ooooool0003ooooo05Wooooo0ol000000onJP[So0000oib6_004oib6
_003o`000?nMR[ooWHZo00?oWHZo00?o0000oif=`OnMSL400onMSL400ol0003oWXg2o`000002o`00
0003ojJnjol0003oXkKV00GoXkKV00?o0000oj2/gonP[=l00onP[=l00ol0003oWj?HoinSf004o`00
00GoVK3W00?o0000ojBZfonTZ]/00onTZ]/01?l0003o/J[Aok6ZdOnaZ]42o`000003ok>ef_l0003o
bk[;00?obk[;00Co0000ol^jbol0003o00001?oWa[H01ol0003ojlRbon_8/_o[b;;o0000ong8[_l0
00005_ooool00ol0003oooooooooo`15ooooo`00COooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08Oooool2o`0005cooooo0ol00005oiZ2
^003o`000?nLQ[coW8Jl00;oW8Jl00?o0000oif:_onMR[l00onMR[l00ol0003oWHg1oif=`@02oif=
`@?o00001OnV_^/00ol0003oXkKVoj>fiP03oj>fiP04o`000?nP[=ooX:cOoj2/g`Go00000on@^o@0
0ol0003oVK3WoiV`i`04oiV`i`03o`000?nTZ]_oY:[K00?oY:[K0ol00004ok>efP04o`000?o;^/_o
bk[;ol^jb`;o00000_o@`L`01?l0003oilJfonO6]_l00003on_8/P05o`000?o]b:kokLR^ong8[_l0
00005Oooool00ol0003oooooooooo`07ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Kooooo0_l000000ol@413oooooooooo`0Wooooo`00COooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h07oooool3o`0005_ooooo0ol000000onHOKCo0000oiZ2^005oiZ2
^003o`000?nLQ[coW8Jl00?oW8Jl00?o0000oif:_onMR[l00_nMR[l00ol0003oWHg1o`000002o`00
00;oZ/C]00?o0000ojJnjonV_^/01?nV_^/01?l0003oXkKVoj>fi_nS]^H5o`0000?oQlWm00?o0000
oi2km?n@^o@00on@^o@00ol0003oVK3WoiV`i`03oiV`i`04o`000?nTZ]_oY:[KojBZf`?o00001onc
]MX01?l0003obk[;ol^jbol00004om31c003o`000?oWa[Ko000000?ojlRb00Co0000ong8[_o]b:ko
kLR^0_l0000Eooooo`03o`000?oooooooooo00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1oooool00ol0003oooooooooo`0Xooooo`00COooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h07?ooool2o`0005cooooo0_l00005oiQm]003o`000?nJP[SoVX:h
00?oVX:h00?o0000oib6_?nLQ[`00onLQ[`00ol0003oWHZooif:_`02oif:_`;o00001_nZa>d01?l0
003oY[k[ojJnjonV_^/6o`0000CoOmKo00?o0000ohO9oOn7bOd00_n7bOd00ol0003oT;_doi2km002
oi2km004o`000?nI/>OoVK3WoiV`i`Ko00000_nK]NX00ol0003o/kGJok>efP05ok>efP04o`000?o;
^/_o0000o`0000God<7<00Go0000on_8/_o[b;;ojlRbo`000003ong8[P04o`000?o_bJcoklV/o`00
01Gooooo00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Y
ooooo`00COooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool06?ooool3
o`0005_ooooo0ol000000onGNJoo0000oiQm]004oiQm]003o`000?nJP[SoVX:h00CoVX:h00?o0000
oib6_?nLQ[`00_nLQ[`00ol0003oWHZoo`000002o`0000;o[/K[00?o0000oj[4kOnZa>d00onZa>d4
o`0000?oN]kh5Ol00003ogjhn@03o`000?nK]N[oVkGZ00?oVkGZ00?o0000ok>ef_nc]MX01?nc]MX2
o`000003om31c?l0003od<7<00?od<7<0_l00003on_8/P05o`000?o]b:kokLR^ong8[_l000000oo_
bJ`00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooo
o`00000;ooooo`04odA4A?oMgMgoooooo`0002[ooooo001=ooooo`05oa0@4?ooooooooooooooool@
41003oooool00ol0003oooooooooo`0Eooooo`;o00000oooool00ol0003oooooooooo`1Fooooo`;o
00001?nGNJl00ol0003oV7fdoiQm]003oiQm]003o`000?nJP[SoVX:h00CoVX:h00?o0000oib6_?nL
Q[`00_nLQ[`2o`0000Ko[/K[00?o0000oj[4kOl000000_l00003og_TkQ;o000000?o=[GZo`000?mK
^o`00_mK^o`00ol0003oO[Siogjhn@03ogjhn@03o`000?nK]N[oVkGZ00?oVkGZ00Co0000ok>ef_nc
]M[o/kGJ0_l000001?na_>;o0000om31c?l00003om31c006o`000?oBaLgod/G=o`000?o[b;;o0000
1?o]b:h01Ol0003oklV/ono9[?o_bJco000001Gooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00003_ooool3o`000003oa0@4?oooooo
oooo01Kooooo001=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@01Cooooo0ol0001Kooooo`?o000000?oUGB[o`000?nGNJl01?nGNJl00ol0003oV7fdoiQm
]003oiQm]003o`000?nJP[SoVX:h00?oVX:h00?o0000oib6_?l000000_l00002ok;4j003o`000?n^
a^_o[/K[00?o[/K[1?l000001_mki>ko0000o`000?l0003oalOJo`0000?o]<GV0_l000000onb/mWo
0000oiNYh`04oiNYh`04o`000?m[U>SoJiCXof^Dj0Oo00001Omn^?T00ol0003oVkGZoi^ejP02oi^e
jP04o`000?nc]M[o0000o`0000Co/KcR0_l00002om31c007o`000?oBaLgod/G=om;5cOl0003ojlRb
o`000003ong8[P07o`000?o_bJcoklV/ono9[?l0003ol<VYo`00000Dooooo`03o`000?oooooooooo
00Cooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co0000013ooooo00?o410@
okZj^_ooool05oooool004gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`04_ooool2o`0005_ooooo0ol00004oiEdZ`03o`000?nGNJooUgV_00?oUgV_00?o
0000oiQm]?nHOK@00onHOK@00ol0003oVX:hoiZ2^003oiZ2^0;o00001_nba>P00ol0003o[/K[o`00
0002o`000003ohCYj?l0003o000000?o00001?o7amX00ol0003o]<GVo`000004ok:cf@03o`000?nG
ZN?oUjWS00?oUjWS00Go0000of^Dj?m[U>SoJiCXo`000002obmag`oo00001_na_>82o`000003om31
c?l0003od/G=00Cod/G=00?o0000ong8[_o]b:h00_o]b:h01ol0003oklV/ono9[?o_bJco0000oo39
ZOl000005?ooool2o`0000Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co
0000013ooooo00?oV9RHoc8b<_ooool05oooool0077ooooo0ol0001Iooooo`Co00000_nCL:P00ol0
003oUGB[oiEdZ`03oiEdZ`03o`000?nGNJooUgV_00;oUgV_00?o0000oiQm]?nHOK@00onHOK@01?l0
003oVX:hoiZ2^?nJP[P2o`000003okBoh_l0003o//CX00Go//CX1_l00003omSKfP03o`000?o7am[o
alOJ00CoalOJ00?o0000ok:cfOnb/mT01?nb/mT01?l0003oUjWSoiNYhonGZN<7o`0000;o;g7O00?o
0000o`17b?l000000_l00003odf[n@03o`000?n6]_GoQ[Ke00;oQ[Ke00?o0000ok6lh_na_>801?na
_>83o`0000Kod/G=00?o0000ong8[_o]b:h00_o]b:h01Ol0003oklV/ono9[?o_bJco000000;ol<VY
00?o0000ooooooooool04?ooool01?l0003oooooooooool00004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03Oooool00omgMgOo0000ooooo`0?ooooo`03omgMgOl0003o^[Zj01Oooooo001_ooooo`;o
00000_ooool00ol0003oooooooooo`1Dooooo`?o000000?oTVfUo`000?nCL:P00onCL:P00ol0003o
UGB[oiEdZ`03oiEdZ`03o`000?nGNJooUgV_00?oUgV_00?o0000oiQm]?nHOK@00onHOK@3o`0000Co
];oR00Co0000ok;4j?nba>So//CX1?l00002om[ch@04o`000?oHfm[of=_JomSKfP;o00001Oo7amX2
o`0000Ko/[?I1?l00002oiVOf004o`000?mdSMgoM8gMogB=g@?o000000?o;g7Oo`000?l0AlP01?l0
0002odf[n@03o`000?n6]_GoQ[Ke00;oQ[Ke00?o0000ok6lh_na_>800ona_>82o`0000Kod/G=00?o
0000om?7c_l000000_o]b:h01Ol0003oklV/ono9[?o_bJco000000?ol<VY0_l0000Dooooo`03o`00
0?oooooooooo02Kooooo00?oEEEEogMgMom4A4@05oooool006cooooo0ol0001Iooooo`;o00001?nB
KJD00ol0003oTg2Xoi=`Z003oi=`Z003o`000?nEM:_oUGB[00;oUGB[00?o0000oiMi[onGNJl00onG
NJl00ol0003oV7fdoiQm]002oiQm]0;o00001_nd_n801Ol0003o//CXo`000?l0003oTo3W00?o0000
00?of_?Qo`000?oHfmX00_oHfmX01?l0003odLK@om76d?l00003olO7fP04o`000?o2]loo`[O?o`00
00?o/[?I0_l000000onaZ<oo0000oiVOf004oiVOf006o`000?mdSMgoM8gMogB=gOl0003o@G3J0ol0
00000ol0AlSo0000o`000004o`0000GoQ[Ke00?o0000ok6lh_l000000_l000000onZ_^So0000om;5
c@04om;5c@07o`000?oCalkodlO>om?7c_l0003okLR^o`000003ono9[004o`000?o`bJWol<VYo`00
00;olLRW00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Tooooo`05omgMgOl@413ooooo
ob4Q8OoMgMd05_ooool006[ooooo0_l0001Iooooo`?o000000?oTFZRo`000?nBKJD01?nBKJD00ol0
003oTg2Xoi=`Z002oi=`Z003o`000?nEM:_oUGB[00?oUGB[00?o0000oiMi[onGNJl00_nGNJl00ol0
003oV7fdoiQm]002o`000003okBhfol0003o];oR00Go];oR1Ol00003on;^f005o`000?oHfm[of=_J
omSKf_l000001?oAa]000ol0003oalOJo`000004ol:gc`03o`000?nb/mWo000000Co/JS?00?o0000
oiVOf?nIWmP00_nIWmP00ol0003oM8gMogB=g@02ogB=g@04o`000?m1L=[o@G3Jod5`fP;o000000Go
04O8o`000?l0003o0000oaF;i`07o`0000CoZ[kX0_l00003om;5c@03o`000?oCalkodlO>00;odlO>
00?o0000ong8[_l000000_o_bJ`01Ol0003ol<VYoo39ZOo`bJWo000000?olLRW00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Sooooo`05ofIVI_n7QhOooooooiRHV?mEEED05_ooool006Oo
oooo0ol0001Iooooo`;o00001?nAJZ800ol0003oTVfUoi9]Y@03oi9]Y@03o`000?nCL:SoTg2X00;o
Tg2X00?o0000oiEdZonEM:/00onEM:/00ol0003oUgV_oiMi[`03oiMi[`;o00001?nd^=/01?l0003o
];oRokBoh_nd_n82o`000004ojKfjOl0003o0000o`0000?oh^kH00Go0000omgGdOl0003of=_Jo`00
0005om76d0;o00001Oo2]ll2o`0000Go/JS?00?o0000oiVOf?nIWmP00_nIWmP00ol0003oM8gMogB=
g@02ogB=g@06o`000?m1L=[o@G3Jod5`f_l0003o24c:1ol00004ofV]n003o`000?nZ_^SoZ[kX00;o
Z[kX00Go0000ojZnj?l0003od/G=o`000005om?7cP;o00000oo_bJ`01Ol0003ol<VYoo39ZOo`bJWo
000000?olLRW00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Rooooo`03onk^k_l0003o
k^k^00;ooooo00?o0000omgMgOooool05?ooool006Cooooo0ol000000ooooooo0000ooooo`1Foooo
o`?o000000?oT6RPo`000?nAJZ800onAJZ800ol0003oTVfUoi9]Y@03oi9]Y@03o`000?nCL:SoTg2X
00;oTg2X00?o0000oiEdZonEM:/00onEM:/00ol0003oUgV_oiMi[`02oiMi[`;o00001_nd^=/00ol0
003o];oRo`000002ojKfj@03o`000?oIom;o000000?oh^kH00Go0000omgGdOoMem7ogMOAo`000005
om76d003o`000?o;]lOo000000Co`[O?00?o0000okn/aol000001OnaZ<l01?l0003oVIoHoiVOf?nI
WmP9o`0000;o@G3J00?o0000o`Q<b_l000001_l00004ofV]n004o`000?nZ_^SoZ[kXojZnj0Co0000
1OoCalh00ol0003odlS?o`000002ono9[005o`000?o`bJWol<VYoo39ZOl000000ooab:L00ol0003o
l/RUo`00000Dooooo`03o`000?oooooooooo027ooooo00Co410@o`000?l0003ooooo0_l000000ol@
413oooooooooo`0Cooooo`00H_ooool2o`0000Gooooo00?o0000ooooooooool0D_ooool2o`0000Co
T6RP00?o0000oi5ZX_nAJZ800_nAJZ800ol0003oTVfUoi9]Y@03oi9]Y@03o`000?nCL:SoTg2X00?o
Tg2X00?o0000oiEdZonEM:/00_nEM:/00ol0003oUgV_oiMi[`02o`000003ok>_e?l0003o];SK00Go
];SK1Ol000000ooIom;o0000on;^f002on;^f003o`000?oMem7ogMOA00;ogMOA0_l00003om76d005
o`000?o;]lOobkO7ol^gaol000000_o2]ll01Ol0003o_jc7okn/aono[<Oo000000Co/JS?1?l00002
oi^Hd003o`000?mkRMKoNhWF00;oNhWF00?o0000odiaeOl000000_l00002o`Q<bP05o`000?l09:oo
0000o`000?l0C;l02_l00002oj2lk003o`000?oCalkodlO>00;odlO>00Oo0000om?8cooCb<oodlS?
o`000?o_bJco000000?ol<VY00Oo0000oo78Yooab:OolLRWo`000?obb:Go000001Gooooo00?o0000
ooooooooool0??ooool005oooooo0ol0001Iooooo`?o000000?oT6JNo`000?n@J:000on@J:000ol0
003oTFZRoi5ZXP03oi5ZXP03o`000?nBKJGoTVfU00;oTVfU00?o0000oi=`Z?nCL:P00onCL:P00ol0
003oUGB[oiEdZ`03oiEdZ`;o00001?nc[m@01?l0003o];SKokBhfond^=/2o`0000;o]oW/1_l00000
0ooRk]So0000omgGd@03omgGd@06o`000?oFa<Soe/C8o`000?oAa]3o00001?o;]lL00ol0003o`[O?
o`000004okn/a`03o`000?naZ<oo/JS?00;o000000?o/:78o`000?nKV=001?nKV=000ol0003oNhWF
og^9eP02og^9eP04o`000?m>LMGoCW7Eo`0000?o24c:00Co0000o`0T[ol0003o00000_l0C;l01Ol0
003oBY_dodZKm?m:VoCo000000;oX;c/00Go0000oj2lk?nP_>coX;c/o`000002om?7cP03o`000?oC
b<oodlS?00;odlS?00?o0000ono9[?l000000oo`bJT01Ol0003olLRWoo78Yooab:Oo000000;ol/RU
00?o0000ooooooooool04Oooool2o`0003kooooo001Mooooo`;o0000F_ooool2o`0000CoT6JN00?o
0000oi1XX?n@J:000_n@J:000ol0003oTFZRoi5ZXP03oi5ZXP03o`000?nBKJGoTVfU00?oTVfU00?o
0000oi=`Z?nCL:P00_nCL:P00ol0003oUGB[oiEdZ`02oiEdZ`;o00001_nc[m@00ol0003o];SKo`00
0003okOik0?o000000Goh_c@o`000?oVjM;oi^WBo`000004omgGd@03o`000?oFa<Soe/C800;oe/C8
00?o0000ol^gaoo;]lL01?o;]lL00ol0003o_jc7okn/a`03okn/a`03o`000?naZ<oo000000Co/:78
00?o0000oi^Hd?nKV=000onKV=000ol0003oNhWFog^9eP02og^9eP03o`000?m>LMGoCW7E00;o0000
00Co24c:o`000?l0003o02B_0ol000002?l0C;oo0000o`000?l0003oBY_do`000?nP_>co00000onP
_>`00ol0003odlO>o`000006om?8c`05o`000?o`bJWol<VYoo39ZOl000000ooab:L01Ol0003ol/RU
oo;8YOobb:Go000001Gooooo00?o0000ooooooooool0>oooool003;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`?o0000FOooool3o`000003ohmUWOl0003oT6JN00?oT6JN00?o0000oi1XX?n@
J:000on@J:000ol0003oTFZRoi5ZXP02oi5ZXP03o`000?nBKJGoTVfU00?oTVfU00?o0000oi=`Z?nC
L:P00_nCL:P00ol0003oUGB[oiEdZ`02o`000003ok6VcOl0003o/joD00Go/joD1?l000001_ngnNco
0000olWl_?l0003oh_c@o`0000?oi^WB00Go0000omgGdOoMem7ogMOAo`000005omK4b003o`000?o;
]lOobkO700?obkO70_l00006okn/a`03o`000?n`XLSo/:7800Co/:7800?o0000oi^Hd?nKV=000_nK
V=000ol0003oNhWFog^9eP02og^9eP05o`000?m>LMGoCW7Eo`000?lJDLX02_l000001ol_R>co0000
o`000?l0003oX;c/o`000?nP_>`00ol00006om?8c`;o00000oo`bJT01Ol0003olLRWoo78Yooab:Oo
000000;ol/RU00?o0000oo;8Y?l000005Oooool00ol0003oooooooooo`0jooooo`00<_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg027ooooo0_l00003ooooo`03o`000?oooooooooo05Cooooo0_l00004
ohmUW@03o`000?n@IYkoT6JN00;oT6JN00?o0000oi1XX?n@J:000on@J:000ol0003oTFZRoi5ZXP02
oi5ZXP03o`000?nBKJGoTVfU00?oTVfU00?o0000oi=`Z?nCL:P00onCL:P2o`0000Co/JK=00?o0000
ok>_e?nc[m@00_nc[m@01?l0003oa?K^olCfk_o4m^h2o`000004olWl_?l0003oh_c@o`0000?oi^WB
00Go0000omoCc?l0003ogMOAo`000005omK4b003o`000?o@]/7o000000?obkO700Co0000olN]`?o7
[L3o00001?no[<L2o`0000Ko/:7800Co0000oi^Hd?nKV=3oViS@2Ol000001_m>LMGo0000oaYAb_lJ
DL[o0000o`0/]@Oo00000ol_R>`3o`0000;oU[O^00?o0000om?8cooCb<l00ooCb<l01?l0003odlO?
om?7col00002oo39Z@04o`000?oab:OolLRWo`0000?ol/RU00Co0000oo;8Y?obb:Co00005?ooool0
0ol0003oooooooooo`0jooooo`00<_ooool01Ol@413ooooooooooooooooo410@01kooooo0ol0001I
ooooo`?o000000?oSfBMo`000?n?IId00on?IId00ol0003oT6JNoi1VWP03oi1VWP03o`000?n@J:3o
T6RP00;oT6RP00?o0000oi5ZX_nAJZ800_nAJZ800ol0003oTVfUoi9]Y@03oi9]Y@03o`000?nCL:So
Tg2X00;oTg2X0_l00006ok6Vc@04o`000?nc[mCo/joDo`0000?oa?K^0_l000001?o9o;co0000on;l
d?l00003onKYdP05o`000?oOdlcogm?<omoCc?l000001OoFa<P01?l0003od;K1om2f`Ol00002ol^g
a`03o`000?o7[L3oajg000;oajg000Co0000okn/aono[<Oo00000_nmYL400ol0003o/:78ok2Qb003
ok2Qb0Co00000_nMUL/00ol0003oPHOAoh67d@02oh67d@03o`000?mHL];o000000;o00000_lJDLX7
o`000004o`0i]Ol0003o0000obn8k0;o00001?nF]nh01Ol0003odlS?om?8cooCb<oo000000CodlO?
0_l00003oo78Y`05o`000?obb:Gol/RUoo;8YOl000000_obb:@00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo03Wooooo000booooo`05o`000?ooooooooooooooool000007?ooool2o`0005[o
oooo0_l00004ohmTW@03o`000?n?IIgoSfFM00;oSfFM00?o0000oi1VW_n@IYh00on@IYh00ol0003o
T6RPoi1XX002oi1XX003o`000?nAJZ;oTFZR00;oTFZR00?o0000oi9]YOnBKJD00onBKJD00ol0003o
Tg2Xoi=`Z002o`000003ojjMa_l0003o/JK=00Go/JK=00?o0000ok>_e?l000000oo4m^h2o`000004
olWl_?l0003oh_c@o`0000?oi^WB00?o0000omoCc?oOdl`00_oOdl`2o`0000?oe/C800Oo0000om2f
`Oo@]/7od;K1o`000?o;]lOo000000Goajg000?o0000okn/aol000001?nmYL400ol0003o/:78ok2Q
b002o`000003ok2Ma?l0003oWIG;00CoWIG;00?o0000oh67dOn1Qm400_n1Qm401?l0003oF7;BoeQb
d_l00002oaYAbP03o`000?l0<[Wo000000Ko000000Co7GOTo`000?l0003o00001OnF]nh00ol0003o
dlS?o`000005om?7c`;o00000ooab:L01?l0003ol/RUoo;8YOl00003oo;8Y0;o00005Oooool00ol0
003oooooooooo`0hooooo`00<_ooool01Ol0003ooooooooooooooooo000001Wooooo0ol0001Ioooo
o`?o000000?oSfBLo`000?n?I9d00on?I9d00ol0003oSfFMohmUW@03ohmUW@03o`000?n@IYkoT6JN
00;oT6JN00?o0000oi1XX?n@J:000_n@J:000ol0003oTFZRoi5ZXP02oi5ZXP03o`000?nBKJGoTVfU
00CoTVfU0_l00004ojjMaP03o`000?naY/go/JK=00?o/JK=1?l000000oo4m^ko0000o`000006o`00
0003onKYd_l0003ogm?<00?ogm?<00Ko0000omS2a?oH`/Co0000omK4b?l00005om2f`@03o`000?o7
[L3oajg000Goajg000?o0000okfU`OnmYL400onmYL400ol0003o/:78o`000004ok2Ma003o`000?nM
UL_oWIG;00;oWIG;00?o0000oh67dOn1Qm400_n1Qm401?l0003oF7;BoeQbd_mHL]82o`000003oaYA
b_l0003o03:i00Oo00000_lMMn@01?l0003oU[O^oiJgk_nF]nh4o`0000GodlO?00?o0000om?7c_l0
00000_oab:L01Ol0003ol/RUoo;8YOobb:Go000000;ol/RT00Co0000oo?7X_ocaj;o00005?ooool0
0ol0003oooooooooo`0hooooo`00<_ooool01Ol@413ooooooooooooooooo410@01Oooooo0_l00003
ooooo`03o`000?oooooooooo05?ooooo0ol00004ohmTW003o`000?n?I9goSfBM00;oSfBM00?o0000
ohmUWOn?IId00on?IId00ol0003oT6JNoi1VWP02oi1VWP03o`000?n@J:3oT6RP00;oT6RP00?o0000
oi5ZX_nAJZ800onAJZ800ol0003oTVfUoi9]Y@02oi9]Y@;o00001_n^WLH00ol0003o/JK=ok6Vc@02
o`0000?obnk/1?l000001?oCo/7o0000onGid?l00002onKUd003o`000?oOdlcogm?<00;ogm?<00?o
0000omS2a?oH`/@00_oH`/@00ol0003od;K1om2f`@04om2f`@03o`000?o7[L3oajg000Coajg00_l0
0006okfU`@03o`000?n`WLCo/9g400?o/9g400?o0000oifEbonMUL/00_nMUL/00ol0003oPHOAoh67
d@02oh67d@06o`000?mHL];oF7;BoeQbd_l0003o:5G:0ol000000ol0<[Wo0000o`000002o`000004
o`0W[_l0003o7GOToaegi0Co00000on=/Nh00ol0003odlO?om?7c`02om?7c`07o`000?oCalkodlO>
om?7c_l0003olLRWo`000003oo;8Y@04o`000?obb:Col/RTo`0000?ollNR00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0gooooo`00<_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo
0ol0001Gooooo`Co00000_n?I9`00ol0003oSfBLohmTW002ohmTW003o`000?n?I9goSfBM00?oSfBM
00?o0000ohmUWOn?IId00_n?IId00ol0003oT6JNoi1VWP02oi1VWP03o`000?n@J:3oT6RP00;oT6RP
00?o0000oi5ZX_nAJZ800onAJZ800ol0003oTVfUoi9]Y@02o`000003oj^F`Ol0003o[Yg600Go[Yg6
00?o0000ok6VcOl000001?o;k^`2o`000006ok;aZ?l0003odok1o`000?oUnM3o00000ooViM02o`00
00?ogm?<00?o0000omS2a?oH`/@00_oH`/@00ol0003od;K1om2f`@03om2f`@03o`000?o;[K_o0000
00Coajg000Co0000olBW^oo4Yk_o00001?nmYL42o`0000Go/9g400?o0000oifEbonMUL/00onMUL/0
0ol0003oPHOAoh67d@02oh67d@05o`000?mHL];oF7;BoeQbd_l000000_lXELX00ol0003o03:io`0b
^@04o`000006o`0W[_l0003o0000o`000?lMMnCo00001On=/Nh01?l0003odlO?om?7col00004om?7
cP03o`000?oab:Oo000000;ol/RU00Go0000oo;8Y?obb:Col/RTo`000003oo?7XP03o`000?oooooo
oooo017ooooo0ol0000hooooo`00<_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol0001G
ooooo`?o000000?oSfBMo`000?n?I9`00on?I9`00ol0003oSfBLohmTW002ohmTW003o`000?n?I9go
SfBM00?oSfBM00?o0000ohmUWOn?IId00_n?IId00ol0003oT6JNoi1VWP02oi1VWP03o`000?n@J:3o
T6RP00;oT6RP00?o0000oi5ZX_nAJZ800onAJZ83o`0000CoZiK100?o0000ojjMa_n^WLH00on^WLH2
o`0000?obnk/0ol000001_nblJSo0000om?n`Ol0003oiOW@o`0000?oi^G@00Ko0000omo@bOoOd<Wo
0000omoCc?l00004omS2a003o`000?oB]Kgo000000?od;K100Go0000ol^]^oo;[K_objfko`000002
olN]`005o`000?o4Yk_oa:NkolBW^ol000000onmYL401?l0003o_:6mokbQ_Ol00005ok2Ma003o`00
0?nMUL_oWIG;00Wo00000_mHL]801Ol0003o:5G:obQEb_lXEL[o000000;o03:i1?l000000ol09jko
0000o`000003o`0000CoSK7^00?o0000om?7col000001_oCalh01Ol0003ol/RUoo;8YOobb:Go0000
00;ol/RT00Oo0000oo?7X_ocaj;ollNRo`000?odaj3o000001Cooooo00?o0000ooooooooool0=_oo
ool004Kooooo0_l0001Hooooo`;o00001?n?I9d00ol0003oSfBLohmTW002ohmTW003o`000?n?I9co
SfBL00?oSfBL00?o0000ohmTWOn?I9d00_n?I9d00ol0003oSfFMohmUW@02ohmUW@03o`000?n@IYko
T6JN00;oT6JN00?o0000oi1XX?n@J:000on@J:001?l0003oTFZRoi5ZX_nAJZ82o`0000KoZiK100?o
0000ojjMa_n^WLH00_n^WLH01Ol0003ocNCXolgTj?l0003obnk/00Go000000Codok1o`000?oUnM3o
00000ooViM000ol0003ogm39omo@b@02omo@b@03o`000?oH`/Cof<;400;of<;400Go0000om:e_OoB
]Kgod[Fmo`000002om2f`@07o`000?o;[K_objfkol^]^ol0003oajg0o`000004olBW^`04o`000?nm
YL7o_JG1o`0000?o_:6m00?o0000ok2Ma?n`WL@00_n`WL@4o`0000;oX9C800?o0000ohF7c_n5Qlh0
0_n5Qlh00ol0003oH7C@o`000002o`0000?o:5G:0_l000000ol0<[Wo0000o`0HYP05o`0000?o4V[M
1_l00006om?7cP03o`000?oCa/go000000;ol/RU00Co0000oo;8Y?obb:Co00000oocaj801?l0003o
m<NPooC7X?l0000Dooooo`03o`000?oooooooooo03Gooooo0013ooooo`?o00000_ooool00ol0003o
ooooooooo`1Booooo`?o000000?oSfFMo`000?n?I9d00on?I9d00ol0003oSfBLohmTW002ohmTW003
o`000?n?I9coSfBL00?oSfBL00?o0000ohmTWOn?I9d00_n?I9d00ol0003oSfFMohmUW@02ohmUW@03
o`000?n@IYkoT6JN00;oT6JN00?o0000oi1XX?n@J:000on@J:001_l0003oTFZRo`000?l0003oYhnl
o`0000KoZiK100?o0000ojjMa_n^WLH00_l00003olgTj0Ko000000Codok1o`000?oUnM3o00000ooV
iM000ol0003ogm39omo@b@03omo@b@05o`000?oH`/Cof<;4omS2a?l000001?oB]Kd00ol0003od;K1
o`000005ol^]^`03o`000?o4Yk_oa:Nk00Coa:Nk0_l00004okbQ_@03o`000?n`WLCo/9g400;o0000
00?o/Ic1o`000?nPU<P01?nPU<P00ol0003oQHO>ohF7cP02ohF7cP04o`000?mPM=3oH7C@of1dd0;o
00000_lXELX2o`000003o`0b^Ol0003o000000Ko000000?o4V[Mo`000?n7Znd00on7Znd00ol0003o
dlO>om?7cP03om?7cP04o`000?oCa/godlK=om?6c@;o00000oobb:@01Ol0003ollNRoo?7X_ocaj;o
000000;om<NP00?o0000ooooooooool04_ooool00ol0003oooooooooo`0eooooo`00@Oooool2o`00
05Sooooo0_l00004ohmUW@03o`000?n?I9goSfBM00;oSfBM00?o0000ohmTW?n?I9`00on?I9`00ol0
003oSfBLohmTW002ohmTW003o`000?n?I9goSfBM00;oSfBM00?o0000ohmUWOn?IId00_n?IId00ol0
003oT6JNoi1VWP03oi1VWP03o`000?n@J:3oT6RP00;oT6RP0_l00004ojN?_003o`000?n[U/7oZiK1
00CoZiK10_l00004olgTj003o`000?ngnlco000000Wo000000?oi^G@o`000?oOd<T01?oOd<T01Ol0
003of;o1o`000?oH`/Co000000Kod[Fm00?o0000ol^]^oo;[K/01?o;[K/00ol0003oa:NkolBW^`04
olBW^`03o`000?nlXKgo_:6m00Co_:6m0_l00004ok6L`@03o`000?nPU<SoX9C800;oX9C800?o0000
ohF7c_n5Qlh00_n5Qlh01_l0003oH7C@of1dd?mPM=3o0000oc9Ib`co000000Co3V7Ho`000?l0003o
00001?n7Znd01Ol0003odlO>om?7c_oCalko000000GodlK=00Co0000oo;8Y?obb:Co00000oocaj80
1?l0003om<NPooC7X?odaj02o`0001Cooooo00?o0000ooooooooool0=?ooool003kooooo0ol0001G
ooooo`?o000000?oT6JNo`000?n?IId00on?IId00ol0003oSfBMohmTW@02ohmTW@03o`000?n?I9co
SfBL00?oSfBL00?o0000ohmTW?n?I9`00_n?I9`00ol0003oSfBMohmTW@02ohmTW@03o`000?n?IIgo
SfFM00;oSfFM00?o0000oi1VW_n@IYh00on@IYh01?l0003oT6RPoi1XX?n@J:02o`0000GoYhnl00?o
0000oj^F`On[U/400on[U/43o`0000?ocNCX00?o0000okOkc?l000001?l000001?oGolOo0000onKf
dOl00002onGRc`03o`000?oOd<Wogm3900?ogm3900Go0000omRo`OoH_l7of;o1o`000007om:e_@03
o`000?o;[K_objfk00?objfk00?o0000olRW]ol000001?o4Yk/2o`0000Ko_:6m00?o0000ok6L`Ona
W<400onaW<400ol0003oX9C8oj2Db003oj2Db003o`000?n5QlkoQHO>00;oQHO>00Co0000of1dd?mP
M=3oH7C@1?l00002o`0h_003o`000?l07Z_o000000Go00000_l>HMP00ol0003oQj_]ohN[k@03ohN[
k@03o`000?oCalko000000GodlK=0_l00002oo;8Y005o`000?ocaj;ollNRoo?7X_l000000_odaj00
1?l0003om<NNooC7W_l0000Dooooo`03o`000?oooooooooo03?ooooo000mooooo`;o0000Eoooool2
o`0000CoT6JN00?o0000ohmUWOn?IId00_n?IId00ol0003oSfBMohmTW@03ohmTW@03o`000?n?I9co
SfBL00;oSfBL00?o0000ohmTW?n?I9`00_n?I9`00ol0003oSfBMohmTW@02ohmTW@03o`000?n?IIgo
SfFM00;oSfFM00?o0000oi1VW_n@IYh00on@IYh4o`000003ojB9^?l0003oYhnl00GoYhnl00Go0000
oj^F`On[U/7oZiK1o`000003ol_Hh`03o`000?o=i>So000000Go00000_oGolL00ol0003oi_KAo`00
0003onGRc`;o00000ooOd<T00ol0003of;o1omRo`@02omRo`@03o`000?oB]Kgod[Fm00Cod[Fm00?o
0000olf/^?l000000oo;[K/01?l0003ob:NgolRW]ol00003olBW^`04o`000?o3XkSo`j>ho`0000Go
_:6m00?o0000ok6L`OnaW<401?naW<400ol0003oX9C8oj2Db002oj2Db003o`000?n5QlkoQHO>00;o
QHO>00?o0000of1dd?l000000ol00002oc9Ib`;o000000Go03Rlo`000?l07Z_o0000o`0EY004o`00
00;o3V7H1ol00005om?6c@06o`000?oDaLcoe<G<o`000?obb:Co00000_ocaj801Ol0003om<NPooC7
X?odaj3o000000;om<NN00?o0000ooooooooool04_ooool00ol0003oooooooooo`0cooooo`00?Ooo
ool3o`0005?ooooo0ol000000on@J:3o0000oi1VWP03oi1VWP03o`000?n?IIgoSfFM00?oSfFM00?o
0000ohmTWOn?I9d00_n?I9d00ol0003oSfBLohmTW002ohmTW003o`000?n?I9coSfBL00;oSfBL00?o
0000ohmTWOn?I9d00_n?I9d00ol0003oSfFMohmUW@03ohmUW@04o`000?n@IYkoT6JNoi1VWP;o0000
1OnTRKP00ol0003oYhnlojN?_003ojN?_004o`000?n[U/7oZiK1o`0000GobmSS1_l00002omOoa`03
o`000?oVm]7o000000?oiN;?00Ko0000omk=b?oNcLSo0000omo@bOl00004omRo`@03o`000?oA/k_o
000000Cod[Fm00Co0000olf/^?o=[;So00000_o;[K/01Ol0003ob:NgolRW]oo8YkOo000000;oa:Nk
00Go0000ol>S^?o3XkSo`j>ho`000004okbQ_@03o`000?nlWk_o000000Go/Ic100Co0000oj2Db?nP
U<SoX9C83?l00002oc9Ib`03o`000?l5?[oo000000;o000000?o01j[o`000?l05J@01?l000000ol>
HMSo0000oh>Vj`04oh>Vj`03o`000?oCa/godlK=00;odlK=00Co0000omC5c?oDaLcoe<G<0_l00003
oo?7XP05o`000?odaj3om<NPooC7X?l000000_odaih2o`0001Cooooo00?o0000ooooooooool0<_oo
ool003gooooo00Co0000oooooooooooo0000Coooool3o`0000CoT6RP00?o0000oi1VW_n@IYh00_n@
IYh00ol0003oSfFMohmUW@03ohmUW@03o`000?n?I9goSfBM00;oSfBM00?o0000ohmTW?n?I9`00_n?
I9`00ol0003oSfBLohmTW002ohmTW003o`000?n?I9goSfBM00;oSfBM00?o0000ohmUWOn?IId00on?
IId01_l0003oT6JNo`000?l0003oXHFeo`0000GoY8Vh00?o0000ojN?_?nWSk`00onWSk`00ol0003o
ZiK1o`000005ol_Hh`03o`000?o5omOo000000?o00000_oGolL01?l0003oi_KAonKfdOl00002onGR
c`03o`000?oNcLSog/g800;og/g800?o0000omRo`OoH_l400_oH_l401Ol0003odK>kom6c^ooA/k_o
000000;od[Fm00Oo0000olf/^?o=[;SocJbho`000?o;[K_o000000Gob:Ng0_l00005ol>S^004o`00
0?nlXKgo_:6mo`0000;o_9nk00?o0000ok6L`OnaW<400onaW<44o`0000;oXiG70ol00002ohV9c@04
o`000?mVMlooIWO?ofIgc`?o000000?o<UW;o`000?l5?[l01?l00002o`0EY0Ko00001On3Y^/01?l0
003odlK=om?6cOl00005omC5c005o`000?ocaj;ollNRoo?7X_l000000_odaj001?l0003om<NNooC7
W_l00002ooG7W003o`000?oooooooooo013ooooo00?o0000ooooool000002Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`05Oooool003go
oooo00Go0000ooooooooooooooooo`00001;ooooo`?o00000_nAJZ800ol0003oT6RPoi1XX002oi1X
X003o`000?n@IYkoT6JN00?oT6JN00?o0000ohmUWOn?IId00_n?IId00ol0003oSfBMohmTW@02ohmT
W@03o`000?n?I9coSfBL00;oSfBL00?o0000ohmTW?n?I9`00_n?I9`00ol0003oSfBMohmTW@03ohmT
W@03o`000?n?IIgoSfFM00;oSfFM0_l00004oj65]@03o`000?nTRKSoY8Vh00;oY8Vh00?o0000ojN?
_?nWSk`00onWSk`2o`0000GobmSS00?o0000olGoeol000000ol00002omOoa`04o`000?oVm]7oi_KA
o`0000;oiN;?00?o0000omk=b?oNcLP00ooNcLP01Ol0003of;o1omRo`OoH_l7o000000CodK>k00?o
0000om:e_Ol000001Oo=[;P00ol0003ob:NgolRW]`04olRW]`03o`000?o3XkSo`j>h00Co`j>h00?o
0000okbQ_Ol000001?nlWk/02?l0003o/Ic1ok6L`OnaW<7o0000ok>L`?l0003oXiG70ol000000onS
ULOo0000ohV9c@03ohV9c@06o`000?mVMlooIWO?ofIgcol0003o>Uk<0_l00002o`Dn_`Co00000_l0
5J@3o`000003o`mLeOl0003o000000CoPjK[00?o0000om?6cOl000001_oDaL`01?l0003ollNRoo?7
X_l00003ooC7X004o`000?odaikom<NNo`0000?omLNL00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`07ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMg
MoooooooV9RHob4Q8@0Eooooo`00??ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
04Gooooo0ol000000onBKJGo0000oi5ZXP02oi5ZXP03o`000?n@J:3oT6RP00;oT6RP00?o0000oi1V
W_n@IYh00on@IYh00ol0003oSfFMohmUW@02ohmUW@03o`000?n?I9goSfBM00;oSfBM00?o0000ohmT
W?n?I9`00_n?I9`00ol0003oSfBLohmTW002ohmTW003o`000?n?I9goSfBM00?oSfBM00Co0000ohmU
WOn?IIgoSfFM0_l00005oj65]@03o`000?nTRKSoY8Vh00?oY8Vh00Go0000ojN?_?nWSkcoYhnlo`00
0002olO=g`06o`000?o;f>?obmSSol_Hhol0003oaOoG2ol000000ooUh/oo0000omk=b004omk=b003
o`000?oF_<3o000000;of;o100?o0000om6c^ooA/k/00ooA/k/00ol0003ocJbholf/^004olf/^003
o`000?o8YkOob:Ng00Cob:Ng00?o0000ol>S^?o3XkP01Oo3XkP00ol0003o_9nkokbO^`03okbO^`04
o`000?naW<7o/Ic1o`0000;o/ic00_l00004oj>Ea`03o`000?n9RLgoRHW=00;oRHW=00?o0000ofIg
comVMll00_mVMll01?l0003o>Uk<o`000?l00002o`Dn_`08o`000?l09;3o0000o`000?l05JCo0000
o`0V/Ol00003o`mLe@Ko00001_oDaL`01Ol0003oeLG:o`000?ocaj;o000000?om<NP00Co0000ooC7
W_odaiko00000ooeai`00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00Go410@
oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000005Oooool003cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`12ooooo`;o00001?nBKJD01Ol0003oTFZRoi5Z
X_nAJZ;o000000GoT6RP00?o0000oi1VW_n@IYh00_n@IYh00ol0003oSfFMohmUW@02ohmUW@03o`00
0?n?I9goSfBM00;oSfBM00?o0000ohmTW?n?I9`00_n?I9`00ol0003oSfBLohmTW003ohmTW003o`00
0?n?I9goSfBM00;oSfBM00Ko0000ohmUWOl0003o0000oij1/ol00005oj65]@03o`000?nTRKSoY8Vh
00?oY8Vh00Co0000ojN?_?nWSkco00001?o7cMl00ol0003obmSSo`000004o`000004okci^Ol0003o
eoo=o`0000;oi?CE00Co0000on;OdOoRgm7o00001OoNcLP01_l0003oe[c0omJl`?l0003of;o1o`00
00KodK>k00?o0000olf/^?o=[;P00oo=[;P00ol0003objJdo`000004olRW]`03o`000?o7Y;Go0000
00Ko`j>h00?o0000okbO^onlWk/00onlWk/00ol0003o/Ic1o`000003o`000003ok>L`?l0003oXiG7
00?oXiG700?o0000ohV9cOn9RLd00_n9RLd00ol0003oIWO?ofIgc`02ofIgc`04o`000?ljG/co>Uk<
o`0000?o1Cjo00Oo0000o`0T/?l0003o0000o`0EY?l0003o02Ja00;o000000?o3ecEo`000?n2XnT0
0on2XnT00ol0003oe<G<omC5c003omC5c006o`000?oEaL[oeLG:o`000?ocaj;o00000oodaj001?l0
003om<NNooC7W_l00002ooG7W003o`000?ofai_o000001Cooooo00?o0000ooooooooool01Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Eooooo`00??oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03kooooo0ol000000onCL:So0000oi9]
Y@03oi9]Y@03o`000?nAJZ;oTFZR00;oTFZR00?o0000oi1XX?n@J:000_n@J:000ol0003oT6JNoi1V
WP02oi1VWP03o`000?n?IIgoSfFM00;oSfFM00?o0000ohmTWOn?I9d00_n?I9d00ol0003oSfBLohmT
W002ohmTW003o`000?n?I9coSfBL00?oSfBL00?o0000ohmTWOn?I9d00_n?I9d2o`0000?oWX6c00?o
0000oj65]OnQQKD01?nQQKD00ol0003oY8VhojB9^002ojB9^003o`000?nWSkco000000GoalgO1_l0
00001?nlnKWo0000omOocOl00002onCde@04o`000?oRgm7oh]oAon;Od@;o00000ooNcLP00ol0003o
e[c0omJl`002omJl`003o`000?oA/k_odK>k00CodK>k00?o0000olf[]_l000000oo=[;P01?l0003o
bjJdol^V]?l00003olRW]`04o`000?o7Y;GoajBeo`0000Go`j>h00?o0000ol>R]ol000001?nlWk/3
o`0000Co/ic000?o0000oj>EaonSULL00_nSULL8o`0000;oIWO?00Co0000ocYNc?ljG/co>Uk<0_l0
00001?l5?[oo0000o`0T/?l09;09o`0000CoPZ?Y00Go0000omC5c?oDaLcoe<G<o`000004omG5bP05
o`000?odaj3om<NPooC7X?l000000_odaih01Ol0003omLNLooG7W?oeaico000000;om/NK00?o0000
ooooooooool04Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000002ooo
ool01Ol0003oEEEEo`000?l@413oc<c<01Gooooo000looooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0>oooool2o`0000CoTg2X00?o0000oi9]YOnBKJD00_nBKJD00ol0003oTFZRoi5Z
XP02oi5ZXP03o`000?n@J:3oT6RP00;oT6RP00?o0000oi1VW_n@IYh00_n@IYh00ol0003oSfFMohmU
W@02ohmUW@03o`000?n?I9goSfBM00;oSfBM00?o0000ohmTW?n?I9`00on?I9`00ol0003oSfBLohmT
W002ohmTW004o`000?n?I9goSfBMohmTW@;o00001OnNPK<00ol0003oXHFeoj65]@03oj65]@03o`00
0?nTRKSoY8Vh00;oY8Vh0_l00005olO=g`03o`000?o<o^3oc?kP00?o000000Co_?Vio`000?oGolgo
00000_oTm=D01Ol0003oh]oAon;OdOoRgm7o000000;ofl[900?o0000omk=b?l000001OoF_<000ol0
003odK>kom6c^`03om6c^`04o`000?o=ZkKocJ^fo`0000;ocJbh00?o0000ol^V]?o;Y[@00_o;Y[@0
1?l0003ob:NgolRW]ol00003olNT]@05o`000?o3XkSo`j>hol>S^?l000000_o3X[L00ol0003o_9nk
o`000002o`000003okjP^_l0003o/ic000Go/ic01?l000000onVUlOo0000ohf<c@03ohf<c@03o`00
0?m[N]3o000000?o00000_ljG/`02_l0003o3T?2o`000?l5?[oo0000o`0T/?l0003o01ZXo`000?l0
:K<3o`000003oa=Kdol0003oPZ?Y00CoPZ?Y00?o0000omC5c?l000001OoEaLX01Ol0003om<NPooC7
X?odaj3o000000;om<NN00Go0000ooG7W?oeaicomLNLo`000002ooK7V`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7
Qoooool05oooool003_ooooo0ol00008ooooo`03o`000?oooooooooo03Oooooo0ol000000onEM:_o
0000oi=`Z003oi=`Z003o`000?nBKJGoTVfU00?oTVfU00Go0000oi5ZX_nAJZ;oTFZRo`000004oi1X
X003o`000?n@IYkoT6JN00;oT6JN00?o0000ohmUWOn?IId00_n?IId00ol0003oSfBMohmTW@02ohmT
W@03o`000?n?I9coSfBL00?oSfBL00?o0000ohmTW?n?I9`00_n?I9`4o`000003oian/_l0003oWX6c
00CoWX6c00?o0000oj65]OnQQKD00onQQKD00ol0003oY8VhojB9^002o`0000;o`/?K00Go0000olO=
goo7cMooalgOo`000002olcnh0?o000000Co_?Vio`000?oGolgo00000_oTm=D01Ol0003oh]oAon;O
dOoRgm7o000000Cofl[900?o0000omJl`?oF_<000ooF_<000ol0003od;6jo`000003om6c^`05o`00
0?o=ZkKocJ^folf[]_l000000_o=[;P00ol0003objJdol^V]002ol^V]003o`000?o8YkOo000000Co
ajBe00Co0000ol>S^?o3XkSo00000_o3X[L3o`000003okbO^ol0003o_Z2j00;o_Z2j00?o0000ok>L
`?ncW<000oncW<000ol0003oYYO7ojJGa`03ojJGa`03o`000?n=S<goSHc=00;oSHc=00Co0000of]j
d?m[N]3oJg[@0_l00002ocYNc003o`000?l>@l;o000000;o000000?o02B`o`000?l06ZP01?l00002
oa=Kd`Oo00001OoEaLX00ol0003oelC8o`000002ooC7X004o`000?odaikom<NNo`0000;omLNL00Co
0000ooK7Voofai_om/NK0_l0000Dooooo`03o`000?oooooooooo00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01Oooooo000looooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0<oooool3o`0000CoUGB[00?o0000oi=`Z?nCL:P00onCL:P00ol0003oTVfU
oi9]Y@02oi9]Y@05o`000?nAJZ;oTFZRoi5ZX_l000001?n@J:000ol0003oT6JNoi1VWP02oi1VWP03
o`000?n?IIgoSfFM00;oSfFM00?o0000ohmTWOn?I9d00on?I9d00ol0003oSfBLohmTW002ohmTW004
o`000?n?I9coSfBLohmTW0;o00001?nLO[800ol0003oWX6coij1/`03oij1/`03o`000?nQQKGoXHFe
00CoXHFe0_l00005ol;3f`03o`000?o7cMoo000000;oc?kP0ol000000onlnKWo0000o`000004o`00
00?oh]oA00?o0000om_:bOoKb/T00ooKb/T00ol0003oe[c0omJl`002omJl`005o`000?o@/K[od;6j
om2a^_l000000_oA/k/00ol0003ocJ^folf[]P02olf[]P;o00001_o;Y[@00ol0003oajBeolNT]@03
olNT]@03o`000?o3XkSo000000?o00000_o3X[L2o`0000Co_Z2j00?o0000ok>L`?ncW<000_ncW<02
o`0000GoYYO700?o0000ohf<cOn=S<d00_n=S<d01_l0003oJg[@of]jd?m[N]3o0000ocmRcP?o0000
0_l>@l800ol0003o02Zco`000003o`000006o`0]]_l0003o0000o`000?lCFm?o00001On3XNL00ol0
003oeLG:omG5bP02omG5bP04o`000?oGa<SoelC8omO4b0;o00000_odaih01Ol0003omLNLooG7W?oe
aico000000;om/NK00Co0000ooO7VOogaiWo00004Oooool3o`0000Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@41Gooooo000kooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0;oooool3o`0000;oUgV_00?o0000oiEdZonEM:/00_nEM:/00ol0003o
Tg2Xoi=`Z003oi=`Z003o`000?nBKJGoTVfU00;oTVfU00Go0000oi5ZX_nAJZ;oTFZRo`000004oi1X
X003o`000?n@IYkoT6JN00;oT6JN00?o0000ohmUWOn?IId00on?IId00ol0003oSfBMohmTW@02ohmT
W@03o`000?n?I9coSfBL00;oSfBL1?l000000onIO;7o0000oian/P04oian/P03o`000?nNPK?oWX6c
00?oWX6c00?o0000oj65]OnQQKD00_nQQKD2o`0000Ko`/?K2ol00003omocf`;o000000?oh]oAo`00
0?oKb/T01?oKb/T00ol0003odk[1o`000003omJl`007o`000?o@/K[od;6jom2a^_l0003odK>ko`00
0005olf[]P03o`000?o;Y[CobjJd00GobjJd00?o0000olNT]Oo7Y;D00oo7Y;D3o`0000Go`j:g00?o
0000okjP^_nnX;X01?nnX;X01?l0003o/ic0ok>L`?l00002okJN`003o`000?nVUlOoYYO700?oYYO7
00?o0000ohf<cOn=S<d00_n=S<d01Ol0003oJg[@of]jd?m[N]3o000000;o?f;>00So0000o`i3`_l>
@l;o3T?2o`000?l0:[?o0000o`0P[@;o000000?o02ffo`000?lIG=<00ol00005oh>Qi`04o`000?oE
aL[oeLG:o`0000GoelC800Co0000ooC7W_odaiko00000ooeai`01?l0003om/NKooK7Vol00002ooO7
V@03o`000?oooooooooo01;ooooo00?o0000ooooooooool0;?ooool003_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0[ooooo`?o000000?oV7fdo`000?nGNJl00_nGNJl00ol0003o
UGB[oiEdZ`03oiEdZ`03o`000?nCL:SoTg2X00;oTg2X00?o0000oi9]YOnBKJD00_nBKJD00ol0003o
TFZRoi5ZXP02oi5ZXP05o`000?n@J:3oT6RPoi1XX?l000001?n@IYh00ol0003oSfFMohmUW@03ohmU
W@03o`000?n?I9goSfBM00;oSfBM00Co0000ohmTW?n?I9coSfBL0_l00004oiUl/@03o`000?nLO[;o
W7jb00?oW7jb00?o0000oij1/onNPK<00onNPK<01ol0003oXHFeoj65]OnQQKGo0000okbkf?l00000
1Oo2`m/01Ol0003ocO[Volgji_l0003o/oW200Co000000?od_oCo`000?oOlm/00_oOlm/01?l0003o
gMgEomgMeOl00005om_:b@07o`000?oC^/7odk[1om>j`Ol0003oe[c0o`000005om2a^P03o`000?o=
ZkKocJ^f00CocJ^f00?o0000ol^V]?o;Y[@01?o;Y[@2o`0000;oajBe0ol000000oo7Y;Go0000ol>R
]`05ol>R]`03o`000?nnX;[o_Z2j00Co_Z2j00?o0000ok>L`?l000000onfW/000ol0003oYYO7ojJG
a`03ojJGa`03o`000?n=S<goSHc=00;oSHc=00?o0000of]jd?m[N]000_m[N]000ol0003o?f;>ocmR
cP02o`000007o`i3`_l0003o0000o`0Z/ol0003o022]o`000002o`0]]P;o000000?o6EcCo`000?l0
00001?n3XNL00ol0003oeLG:o`000006omO4b004o`000?odaikom<NNo`0000;omLNL00Go0000ooK7
Voofai_om/NKo`000002ooO7V@;o00005?ooool00ol0003oooooooooo`0[ooooo`00>oooool2o`00
00gooooo00?o0000ooooooooool0:?ooool2o`0000CoV7fd00?o0000oiMi[onGNJl00_nGNJl00ol0
003oUGB[oiEdZ`02oiEdZ`03o`000?nCL:SoTg2X00;oTg2X00?o0000oi9]YOnBKJD00_nBKJD00ol0
003oTFZRoi5ZXP02oi5ZXP05o`000?n@J:3oT6RPoi1XX?l000001On@IYh00ol0003oSfFMohmUW@02
ohmUW@03o`000?n?I9goSfBM00;oSfBM1?l000000onGNk;o0000oiUl/@04oiUl/@03o`000?nLO[;o
W7jb00;oW7jb00?o0000oij1/onNPK<00onNPK<01?l0003oXHFeoj65]Ol00003okbkf005o`000?o2
`m_o`/?Kol;3fol000000_o=n^H02?l0003o/oW2o`000?l0003o^?[1o`000?oBom?o00000ooOlm/0
1?l0003ogMgEomgMeOoMgMD2o`0000?ofl[900?o0000om>j`OoC^/400ooC^/400ol0003od;6jom2a
^P04om2a^P03o`000?o=ZkKocJ^f00?ocJ^f00?o0000ol^U/ol000001?o;Y[@00ol0003obJ>bolVS
/P02o`0000?oajBe00?o0000olNR/ol000001?o3X[L00ol0003oa::fo`000006okjP^P03o`000?nf
W/3o]Yk000?o]Yk000?o0000ojJGaonVUlL00_nVUlL;o`0000;o?f;>00Co0000oa=8a?l0003o3T?2
1?l000001?l08:go0000o`000?l0;KH2o`0000;o6EcC1_l00006omO4b005o`000?oIaLKo0000ooC7
W_l000000_oeai`01ol0003om/NKooK7Voofai_o0000ooO7VOl000000_ogaiP00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo02_ooooo000kooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool09?ooool3o`000003oiZ2^?l0003oV7fd00?oV7fd00?o0000oiMi[onGNJl00_nGNJl0
0ol0003oUGB[oiEdZ`02oiEdZ`03o`000?nCL:SoTg2X00;oTg2X00?o0000oi9]YOnBKJD00_nBKJD0
0ol0003oTFZRoi5ZXP02oi5ZXP05o`000?n@J:3oT6RPoi1XX?l000001On@IYh00ol0003oSfFMohmU
W@02ohmUW@03o`000?n?I9goSfBM00?o00001?nGNk800ol0003oVGbaoiUl/@03oiUl/@03o`000?nL
O[;oW7jb00?oW7jb00?o0000oij1/onNPK<00onNPK<2o`0000Go_;_H00?o0000ol;3fol000000_o=
n^H4o`000004okSj`Ol0003od_oCo`0000?ogo?K00Go0000omgMeOoMgMGogMgEo`000002omK7c003
o`000?oKb/Wo000000Kodk[100?o0000om2a^_o@/KX00oo@/KX00ol0003oc:Vfo`000004olf[]P03
o`000?o;YK?o000000?objJd1Ol00003olNT]@04o`000?o7X[?oaj:co`0000?o`j:g00Co0000olBR
]_o4X[Ko00001OnnX;X2o`0000Go]Yk000?o0000ojJGaol000000_l000000onYVlSo0000oi6@c`03
oi6@c`04o`000?m_Om?oKgoCofmod`?o000000?o?f;>o`000?lCB<@01ol000000ol0<[Wo0000o`0]
]P02o`000003oaULdol0003oQZ7U00?oQZ7U00?o0000omO4b?oGa<P00ooGa<P00ol0003ofLG6omW5
aP02o`0000?omLNL00Co0000ooK7Voofai_o00000_ogaiT01?l0003omlNHooO7V?l0000Dooooo`03
o`000?oooooooooo02[ooooo000kooooo`03o`000?oooooooooo00kooooo0_l0000Rooooo`;o0000
1?nJP[P00ol0003oV7fdoiQm]003oiQm]005o`000?nGNJooUgV_oiMi[ol000001?nEM:/00ol0003o
Tg2Xoi=`Z002oi=`Z003o`000?nBKJGoTVfU00;oTVfU00?o0000oi5ZX_nAJZ800_nAJZ800ol0003o
T6RPoi1XX002oi1XX003o`000?n@IYkoT6JN00;oT6JN00Co0000ohmUWOn?IIgoSfFM1?l00002oiIj
/P03o`000?nGNk;oUg^b00?oUg^b00?o0000oiUl/OnIO;400_nIO;400ol0003oW7jboian/P03oian
/P03o`000?nNPK?oWX6c00;oWX6c0_l00006okbkf0So000000?o^?[1o`000?l000000ol000000ooO
lm_o0000omgMe@02omgMe@03o`000?oFalcoe/O<00;oe/O<00?o0000om>j`OoC^/401?oC^/400ol0
003ocJjko`000003om2a^P04o`000?o<ZKKoc:Vfo`0000?ocJ^f00Co0000ol^U/oo;YK?objFc1?l0
0003olVS/P04o`000?o7Y;GoajBeo`0000Coaj:c00Co0000ol>R]oo3X[Oo00000oo4X[H01Ol0003o
_Z2jokjP^_nnX;[o000000;o`::j00?o0000okJN`?nfW/000_nfW/02o`0000GoZI_800?o0000oi6@
conAT<l00_nAT<l01_l0003oKgoCofmodom_Om?o0000od=Wd0?o00000_lCB<@00ol0003o02ngo`00
0003o`000004o`0b^Ol0003o0000ob1Ne0?o00001?n6XND01Ol0003oelC8omO4b?oGa<So000000Co
fLG600Co0000ooG7W?oeaico00000oofai/01?l0003omlNIooO7VOl00002ooO7V0;o00005?ooool0
0ol0003oooooooooo`0Yooooo`00>oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
01gooooo0_l000000onLQ[co0000oiZ2^004oiZ2^003o`000?nHOKCoV7fd00;oV7fd00?o0000oiMi
[onGNJl00_nGNJl01Ol0003oUGB[oiEdZonEM:_o000000CoTg2X00?o0000oi9]YOnBKJD00onBKJD0
1Ol0003oTFZRoi5ZX_nAJZ;o000000CoT6RP00?o0000oi1VW_n@IYh00_n@IYh4o`000003oiAj]?l0
003oUWZb00?oUWZb00?o0000oiMk/_nGNk800onGNk800ol0003oVGbaoiUl/@03oiUl/@03o`000?nL
O[;oW7jb00;oW7jb00?o0000oij1/onNPK<00_l000000ong/mKo0000okbkf004okbkf006o`000?o;
mN_oboG[ol_ejol0003o/_[<1Ol00003omSchP;o00000ooMgMD00ol0003oe/O<omK7c003omK7c003
o`000?oC^/7odk[100?odk[100Co0000olf^^oo=[[_o00000_o@/KX00ol0003oc:VfolbY]P02olbY
]P03o`000?o=ZkKo000000;objFc0ol000000oo;Y[Co0000olVS/P04olVS/P;o00001Oo7X[<00ol0
003o`j:go`000004olBR]P04o`000?nnX;[o_Z2jo`0000?o`::j00Oo0000okJN`?nfW/3o]Yk0o`00
0?niX/7o000000GoZI_800?o0000oi6@conAT<l00_nAT<l00ol0003oKgoCofmod`02ofmod`04o`00
0?m3Im3o@fO@o`0000?o4dS400Co0000o`0_]ol0003o02F`0_l000001_l0<[Wo0000o`000?l0003o
85kDo`0000GoQZ7U00?o0000omO4b?l000001OoIaLH01?l0003omLNLooG7W?l00003ooK7V`06o`00
0?ogaiWomlNIo`000?ogaiSo00000_ohaiL00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
02Wooooo000jooooo`?o00004_ooool00ol0003oooooooooo`0Iooooo`?o00001?nLQ[`00ol0003o
VX:hoiZ2^002oiZ2^003o`000?nHOKCoV7fd00;oV7fd00?o0000oiMi[onGNJl00_nGNJl01Ol0003o
UGB[oiEdZonEM:_o000000GoTg2X00?o0000oi9]YOnBKJD00_nBKJD00ol0003oTFZRoi5ZXP02oi5Z
XP05o`000?n@J:3oT6RPoi1XX?l000000_n@IYh3o`0000CoU7Zd00?o0000oiIj/_nFN[800onFN[80
0ol0003oUg^boiMk/P02oiMk/P03o`000?nIO;7oVGba00?oVGba00?o0000oian/_nLO[800onLO[82
o`0000Co]k?F00Go0000okbkf?nl^mSo_;_Ho`000003ol_ej`03o`000?nbn/co000000;o000000?o
b?oKo`000?oHln800_oHln801_l0003oem_KomOKfol0003ogMgEo`0000Goe/O<00?o0000oljg`ol0
00000ooC^/401Ol0003ocJjkolf^^oo=[[_o000000;od;6j00?o0000olbY]_o<ZKH00_o<ZKH00ol0
003ocJ^fo`000002o`0000?objFc00?o0000olVS/_o9Xk801?o9Xk800ol0003oaj:colNR/`05olNR
/`03o`000?o4X[Koa::f00?oa::f00?o0000okjP^_l000001?o0X[X01?l0003o]Yk0okJN`?l00003
okVR`@03o`000?nYVlSoZI_800;oZI_800?o0000oi6@conAT<l00_nAT<l00ol0003oKgoCofmod`02
ofmod`04o`000?m3Im3o@fO@od=Wd0;o000000Oo4dS4o`000?l0;kOo02ngo`000?l09K3o000000;o
03:i00Co0000ob1Ne?l0003o85kD1ol00005omW5aP05o`000?oKaLCo0000ooG7W?l000000_ofai/0
1?l0003omlNIooO7VOl00002ooO7V004o`000?ohaiOon<NGo`0001;ooooo0ol0000Zooooo`00>_oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo1?l00002oif:_`03o`000?nL
Q[coW8Jl00;oW8Jl00?o0000oiZ2^?nJP[P00_nJP[P00ol0003oV7fdoiQm]002oiQm]003o`000?nG
NJooUgV_00;oUgV_00Go0000oiEdZonEM:_oUGB[o`000005oi=`Z003o`000?nBKJGoTVfU00;oTVfU
00?o0000oi5ZX_nAJZ800_nAJZ800ol0003oT6RPo`000004o`0000;oTWbg00?o0000oiAj]?nDN[@0
0onDN[@00ol0003oUWZboiIj/P02oiIj/P03o`000?nGNk;oUg^b00?oUg^b00?o0000oiUl/OnIO;40
0_nIO;400ol0003oW7jboian/P02oian/P;o00001_ng/mH00ol0003o_;_Ho`000003ol_ej`07o`00
0?nbn/co0000ojcga_l0003ob?oKo`000003omSchP03o`000?oGfm_oem_K00;oem_K00?o0000omK7
c?oFal`00ooFal`01Ol0003oc[O3oljg`oo>]l?o000000;odk[100?o0000olf^^oo=[[/00_o=[[/2
o`0000Coc:Vf0ol00006ol^U/`03o`000?o9Xk;obJ>b00CobJ>b00?o0000olNR/oo7X[<01Oo7X[<0
0ol0003oa::folBR]P04olBR]P03o`000?o0X[[o`::j00Co`::j0_l00004okVR`@03o`000?nYVlSo
ZI_800?oZI_800?o0000oi6@conAT<l01ol00003od=Wd006o`000?lFC<Oo0000oa=8a?l0003o02ng
0_l000001?l09K3o0000o`000?l0<[T4o`0000GoRj;T00?o0000omW5a_oIaLH00_oIaLH01Ol0003o
flG4om_5a?oKaLCo000000?om/NK00Co0000ooO7VOogaiWo00000_ogaiP00ol0003on<NGooS7U`02
o`0001?ooooo00?o0000ooooooooool0:?ooool003[ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0Aooooo`;o000000?oWHg1o`000?nMR[l00onMR[l00ol0003oW8Jloib6_002oib6
_003o`000?nJP[SoVX:h00?oVX:h00Go0000oiQm]?nHOKCoV7fdo`000004oiMi[`03o`000?nEM:_o
UGB[00;oUGB[00?o0000oi=`Z?nCL:P00_nCL:P00ol0003oTVfUoi9]Y@09o`0000;oTGjk00?o0000
oi9l]onBO;L00onBO;L00ol0003oU7ZdoiAj]002oiAj]003o`000?nFN[;oUWZb00;oUWZb00?o0000
oiMk/_nGNk800onGNk800ol0003oVGbaoiUl/@03oiUl/@Co000000?o/:kFo`000?ng/mH01Ong/mH4
o`000005ol_ejol0003o0000o`000?n/mlH01Ol000000ooHln;o0000omOKf`03omOKf`03o`000?o?
aM3o000000?oe/O<00?o0000oljg`oo>]l<00_o>]l<00ol0003odk[1o`000005olf^^`03o`000?o<
ZKKoc:Vf00?o00000_o<ZKH00ol0003objFcol^U/`03ol^U/`03o`000?o9Xk7o000000CobJ>b00?o
0000olVR/Ol000001Oo7X[<2o`0000Koa::f00?o0000ol2R^_o0X[X01?o0X[X00ol0003o^J;1okVR
`@03okVR`@03o`000?nYVlSoZI_800;oZI_81?l00002oiBFdP04o`000?maQ=OoLHCGog64e`?o0000
0_m3Im000ol0003o5Tc7o`000002o`000005o`0_]ol0003o0000o`000?l0=kd00_l000001?lXHmGo
0000o`000?l00005oh^Ri004o`000?oIaLKofLG6o`0000CoflG400Go0000ooK7Voofai_om/NKo`00
0002ooO7V@04o`000?ogaiSomlNHo`0000;on<NG00?o0000ooS8Uol000004oooool00ol0003ooooo
ooooo`0Wooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`Go00001_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00kooooo0_l00004oif=`@03o`000?nMR[ooWHZo00;oWHZo00?o0000oib6_?nLQ[`00_nLQ[`0
0ol0003oVX:hoiZ2^002oiZ2^003o`000?nHOKCoV7fd00;oV7fd00?o0000oiMi[onGNJl00_nGNJl0
1Ol0003oUGB[oiEdZonEM:_o000000;oTg2X1Ol00002ohn6aP03o`000?n@P/3oT8;000;oT8;000?o
0000oi5n^onAO[/00_nAO[/00ol0003oTWbgoi9l]`02oi9l]`03o`000?nDN[CoU7Zd00;oU7Zd00?o
0000oiIj/_nFN[800onFN[800ol0003oUg^boiMk/P02oiMk/P03o`000?nIO;7oVGba00;oVGba0_l0
0005ok2^eP04o`000?ng/mKo]k?FokNceP;o00000oo4l?07o`0000?obo?/0ol00003omOKf`07o`00
0?o?aM3oclG@olo5d?l0003oe/O<o`000006oljg``03o`000?o=[[_ocJjk00CocJjk0ol00004olbY
]P;o00001?o;YK<01?l0003obJ>aolVS/Ol00004olVS/P03o`000?o9X[7o000000Coaj:c00Co0000
olRS/_o8Xk;o00001?o4X[H00ol0003oaZBfo`000004ol2R^P;o00001_niX/44o`000003ojfPbol0
003oU9KB00CoU9KB00Ko0000og64eomaQ=OoLHCGo`000?m4K=@3o`0000;o5Tc700Go0000o`0d^_l0
003o0000o`0Z]002o`000004o`0g_Ol0003o0000obQSe@?o00001?n;X^@00ol0003ofLG6o`000004
om_5a003o`000?oMa/;o000000;om/NK00?o0000ooO7VOl000000_ogaiP01?l0003on<NGooS7Uol0
0003ooS8U`03o`000?oooooooooo017ooooo00?o0000ooooooooool09_ooool000Oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OnH
V9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0:
ooooo`?o000000?oWXg2o`000?nMSL400onMSL400ol0003oWHZooif:_`02oif:_`03o`000?nLQ[co
W8Jl00;oW8Jl00?o0000oiZ2^?nJP[P00_nJP[P00ol0003oV7fdoiQm]002oiQm]003o`000?nGNJoo
UgV_00Wo00000_n>SLh00ol0003oShK6ohn6aP03ohn6aP05o`000?n@P/3oT8;0oi22`?l000001?nA
O[/00ol0003oTWbgoi9l]`02oi9l]`03o`000?nDN[CoU7Zd00?oU7Zd00?o0000oiIj/_nFN[800_nF
N[800ol0003oUg^boiMk/P03oiMk/PCo000000?oZZ[Fo`000?n`[]H01On`[]H00ol0003o]k?Fo`00
0003olC`l0Ko000000?o]_cQo`000?o;ln`00_o;ln`01ol0003oc=[SolcJhoo<f^?o0000omOKfol0
00001Oo?aM000ol0003oc[O3oljg``04oljg``;o00001?o=[[/2o`000003olVV]_l0003oc:Vf00?o
c:Vf00Co0000olVT/oo9Y;?o00000oo;YK<01Ol0003obJ>aolVS/Oo9Xk7o000000;obJ>b00Go0000
olVR/Oo9X[7obJ:ao`000002olNR/`05o`000?o8Xk;ob:>bolRS/_l000000oo4X[H01?l0003oaZBf
olJT]_l00003ol2R^P04o`000?o3YK_o`jFko`0000Go^J;100?o0000ojfPbon]X</00on]X</00ol0
003oU9KBoiBFdP02oiBFdP03o`000?maQ=OoLHCG00;oLHCG00Co0000odA/e?m4K=Co00000olFC<L3
o`0000;o02Zd00?o0000o`0g_Ol0=kd00_l000000olXHmGo0000o`000003oh^Ri0?o00001OoKaL@0
0ol0003ogLK2omg6`P02o`0000;omlNI00Co0000ooO7V?ogaiSo00000_ohaiL01Ol0003on<RGooS8
Uoohb9Oo000001?ooooo00?o0000ooooooooool09_ooool000Go00000_ooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00Cooooo00?oV9RHob4Q8Oo^k^h01oooool2
o`0001Sooooo00?o0000ooooooooool01_ooool3o`0000CoWXg200?o0000oif=`OnMSL400_nMSL40
0ol0003oWHZooif:_`02oif:_`03o`000?nLQ[coW8Jl00;oW8Jl00?o0000oiZ2^?nJP[P00onJP[P0
0ol0003oV7fdo`000004o`0000;oSYoO00Go0000ohjEe_n>UMKoSYGFo`000005ohj=cP03o`000?n?
Q/KoShK600;oShK600?o0000oi22`?n@P/000_n@P/001Ol0003oTGjkoi5n^onAO[_o000000GoTWbg
00?o0000oiAj]?nDN[@00_nDN[@00ol0003oUWZboiIj/P02oiIj/P03o`000?nGNk;oUg^b00;oUg^b
0_l00005ojZZeP03o`000?n`[]Ko/:kF00?o/:kF1?l000000oo4l?3o0000o`000003o`0000;o]_cQ
00Go0000ol_ck?o;lncobo?/o`000004olcJh`;o00001Oo?aM02o`0000Goc[O300?o0000olV[_?o9
Zk`01Ol00002olVV]P05o`000?o<ZKKoc:VfolbY]_l000000oo9Y;<01?l0003objFcol^U/ol00004
olVS/@03o`000?o9Xk;o000000CobJ:a00Co0000olNR/oo7X[?o00000oo8Xk801?l0003oa::folBR
]_l00003olJT]P04o`000?o0X[[o`::jo`0000?o`jFk00?o0000okVR`OniX/400_niX/42o`0000Go
[J3;00?o0000oiBFd_nDU]800_nDU]800ol0003oLHCGog64e`02og64e`04o`000?m4K=CoA6cDodA/
e0;o000000?o5Tc7o`000?l0>;d00ol000001Ol0:[Co0000o`000?l0=kgo000000;o:6?E1?l00002
oi2Th`03o`000?oKaLCoflG400;oflG400?o0000omg6`_oMa/800_oMa/801?l0003omlNIooO7VOl0
0002ooO7V004o`000?ohaiOon<NGo`0000?on<RG0_l0000Cooooo`03o`000?oooooooooo02Gooooo
0007ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001Oooool0
0onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00_ooool3
o`0000;oWXg200?o0000oij=`_nNSL800onNSL800ol0003oWHg1oif=`@02oif=`@05o`000?nMR[oo
WHZooif:_ol000001OnLQ[`00ol0003oVX:hoiZ2^004o`0000;oSjWW00?o0000ohjOgon>Wml00on>
Wml01Ol0003oSYGFohjEe_n>UMKo000000CoSXg>00?o0000ohn6a_n?Q/H00_n?Q/H00ol0003oT8;0
oi22`002oi22`003o`000?nAO[_oTGjk00;oTGjk00?o0000oi9l]onBO;L00_nBO;L00ol0003oU7Zd
oiAj]002oiAj]003o`000?nFN[;oUWZb00?oUWZb1?l000000onTYmSo0000ojZZeP05ojZZeP03o`00
0?n`[]Ko/:kF00;o00000onkjo@;o`000003ol_ck?l0003oc=[S00?oc=[S00?o0000olK2e_l00000
1?o?aM001?l0003ob;?6olRca_l00003oljg``03o`000?o9Zkco000000;o00000_o=[[/00ol0003o
bJJfolVV]P02olVV]P04o`000?o<ZKKoc:Vfo`0000?obJBc00Co0000ol^U/oo;YK?o00001?o9Xk40
0ol0003obJ>bo`000004olVR/@03o`000?o7X[?o000000Gob:>b0_l00005olJT]P;o00001Oo3YK/0
1?l0003o^J;1okVR`Ol00002okbW``03o`000?n]X<_o[J3;00;o[J3;00Co0000oiBFd_nDU];oU9KB
1ol00003odA/e008o`000?lFD<_o0000oaI<aol0003o03Rmo`000?l0;kL2o`000003o`0l`?l0003o
03Nm00Co00001On@Y><01?l0003oflG4om_5a?l00005omg6`P04o`000?ogaiWomlNIo`0000;omlNH
00Co0000ooS7UoohaiOo00000_ohb9L01?l0003onLRFooW8U_l0000Cooooo`03o`000?oooooooooo
02Cooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
1_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo01[ooooo1?l000000onMRl3o0000
oij=`P03oij=`P03o`000?nNSL;oWXg200;oWXg200?o0000oif=`OnMSL400_nMSL400ol0003oWHZo
oif:_`02oif:_`03o`000?nLQ[coW8Jl00Go00000_nA/nh00ol0003oSjWWohnYi`02ohnYi`03o`00
0?n>WmooSYoO00;oSYoO00Go0000ohjEe_n>UMKoSYGFo`000005ohj=cP03o`000?n?Q/KoShK600;o
ShK600Go0000oi22`?n@P/3oT8;0o`000004oi5n^`03o`000?nBO;OoTWbg00;oTWbg00?o0000oiAj
]?nDN[@00onDN[@00ol0003oUWZboiIj/P03o`0000GoY:OH00?o0000ojZZe_nZZ]H00onZZ]H00ol0
003o/:kFo`000003ok_[m0;o000000GoV_?Io`000?l0003o0000oiObh`02o`0000?o]_3e0ol00003
olcJh`05o`000?o6`]Koa/;FolK2e_l000000_o?aM000ol0003ob;?6olRcaP02olRcaP03o`000?o>
]l?o000000;o00000_o9Zk`00ol0003ocJjko`000005olVV]P03o`000?o<ZKKo000000GobJBc0_l0
0006olVS/@03o`000?o9X[7obJ:a00CobJ:a00?o0000olRS/_o8Xk801?o8Xk800ol0003oaZBfolJT
]P04olJT]P03o`000?o3YK_o`jFk00Co`jFk00?o0000okVR`Ol000001?nlYl<01?l0003o[J3;ojfP
bon]X</4o`0000;oUicG00Co0000og::fombR]_oLX[K0ol00002odA/e003o`000?lFD<_o000000;o
000000?o03Rmo`000?l0;kL00_l000001?l0?<3o0000o`000?l_ImL3o`0000GoT:CS00?o0000om_5
a?l000001?oMa/801?l0003oglS1o`000?l00002ooO7V005o`000?ohaiOon<NGooS7Uol000000_oh
b9L01?l0003onLRFooW8U_l0000Booooo`;o00009_ooool000Oooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool06Oooool2o`0000CoWH_000?o0000oij=`_nNSL800_nNSL800ol0003oWXg2oij=`P02
oij=`P03o`000?nMSL7oWHg100;oWHg100?o0000oif:_onMR[l01Ol00003oiBkl@03o`000?nA/nko
TK?^00;oTK?^00?o0000ohnYion?ZNL00_n?ZNL00ol0003oSYoOohjOg`02ohjOg`05o`000?n>UMKo
SYGFohjEe_l000001?n>SLh00ol0003oShK6ohn6aP02ohn6aP05o`000?n@P/3oT8;0oi22`?l00000
1?nAO[/00ol0003oTWbgoi9l]`03oi9l]`03o`000?nDN[CoU7Zd00Go00000_nMY]`00ol0003oY:OH
ojBWf004ojBWf003o`000?nZZ]KoZZ[F00;oZZ[F1?l000001?nkjoCo0000oi[cfOnJlmT2o`0000;o
Uo;S00Co0000okK`mOnfl?Go]_3e0_l00003okgGk@03o`000?o<f^?o000000Coa/;F00?o0000olo5
d?l000001?o8/lH3o`0000KobJ^l00?o0000olVV]_o9Y[H01Oo9Y[H00ol0003obJBcolVT/`04olVT
/`03o`000?o9Xk7obJ>a00GobJ>a00?o0000olVR/Oo9X[401?o9X[400ol0003ob:>bolRS/P04olRS
/P03o`000?o6Y;KoaZBf00CoaZBf00?o0000ol>U^oo3YK/01Oo3YK/00ol0003o_:O3okbW``03okbW
``06o`000?n]X<_o0000o`000?n`Yloo00001OnGW=L01_l0003oLX[Kog::fombR]_o0000od=`f@;o
000000GoA6cDo`000?lFD<_o5U3;o`000002o`0h_@05o`000?l0;kOo0000o`000?l0?<000_l00002
obmWe`04o`000?n@Y>?oT:CSoi2Th`Co00001?oMa/801Ol0003oglS1omo8`OoOb<7o000000;omlNH
00Co0000ooS7UoohaiOo00000oohb9L00ol0003onLRFooW8UP02o`0001?ooooo00?o0000oooooooo
ool08oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`0Gooooo`;o0000
00?oW8Vno`000?nMRl001?nMRl000ol0003oWXg2oij=`P02oij=`P03o`000?nNSL;oWXg200;oWXg2
00?o0000oif=`OnMSL401?l00004oiZolP03o`000?nD^o7oU;_a00;oU;_a00?o0000oi6ck_nA/nh0
0_nA/nh01Ol0003oSjWWohnYion?ZNOo000000CoSYoO00Go0000ohjEe_n>UMKoSYGFo`000004ohj=
cP03o`000?n?Q/KoShK600;oShK600?o0000oi22`?n@P/000_n@P/000ol0003oTGjkoi5n^`02oi5n
^`03o`000?nBO;OoTWbg00Go00000_nDY^800ol0003oWJKLoifVg003oifVg003o`000?nTYmSoY:OH
00?oY:OH00?o0000ojZZe_l000000_l00003ojkWn@_o000000?o]_3eo`000?nmend01?nmend2o`00
00Goa/;F0_l00002olRcaP?o000000?ob;?6o`000?l000001_o9Zk`00ol0003obJJfolVV]P05olVV
]P03o`000?o9Y;?obJBc00CobJBc00?o0000olVS/Oo9Xk401?o9Xk42o`0000GobJ:a0_l00005olRS
/P03o`000?o:YK?o000000CoaZBf00?o0000olVW]ol000001Oo3YK/2o`0000Go_:O30_l00004ok2W
c`03o`000?nGW=OoUicG00?oUicG00Go0000og::fombR]_oLX[Ko`000002od=`f@;o00000olFD</0
1_l0003o03Rmo`0h_Ol0003o02ngo`0000;o03c000Co0000obmWeol_ImOo;fOG0ol00003oiFXh`05
o`000?oMa/;ogLK2omg6`_l000001?oOb<401?l0003omlNHooO7V?l00002ooS7U`07o`000?ohb9Oo
n<RGooS8Uol0003onLRFo`000002ooW9UP03o`000?oooooooooo017ooooo00?o0000ooooooooool0
8_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool2o`0001Gooooo0ol00004oib9_P03o`000?nM
Rl3oWH_000;oWH_000?o0000oij=`_nNSL800_nNSL801?l0003oWXg2oij=`_nNSL84o`0000?oWl7`
00?o0000oiZol_nJ_o800onJ_o800ol0003oU;_aoiBkl@0Zo`0000;oRjSX00?o0000oiBVh_nDY^80
0onDY^800ol0003oWJKLoifVg003oifVg003o`000?nTYmSoY:OH00;oY:OH0ol00003ojkWn@So0000
0onCi_/4o`0000?o_MO]0_l000000oni_]go0000olK2eP02olK2eP;o000000Co_k3:o`000?l0003o
00000oo8/lH01?l0003o`jRool>X_ol00004olV[_003o`000?o5Y;Oo000000GobJJf0_l00005olVT
/`03o`000?o8XK7o000000CobJ>a00Co0000olVR/?o9X[3o00000oo9X[401?l0003obZ>aolZS/Ol0
0003olRS/P04o`000?o:YK?obZFco`0000?oaZBf00Co0000olVW]oo9YkOo00001?o3YK/01?l0003o
ajZmolNZ_Ol00003okbW``03o`000?o1[LKo000000Go/:O?00?o0000oiNLeonGW=L00_nGW=L00ol0
003oLX[Kog::f`02og::f`04o`000?m3L=Wo@g3Iod=`f@;o000000Co5U3;o`000?l0003o03Rm0_l0
00001?l0;kOo0000o`0l`?l0?<02o`000003obmWeol0003oUJSS00GoUJSS00Co0000omg6`_oMa/;o
00000ooOb<401Ol0003oh/Voo`000?ogaiSo000000;on<NG00Co0000ooS8Uoohb9Oo00000_oib9H0
1?l0003onLVFooW9U_l0000Cooooo`03o`000?oooooooooo02;ooooo000iooooo`03o`000?oooooo
oooo013ooooo1?l00002oib7_@03o`000?nLRKkoW8Vn00;oW8Vn00?o0000oif;`?nMRl000_nMRl00
0ol0003oWXg2oij=`P02oij=`P04o`000?nNSL;o0000o`0000?oYKk[00?o0000oio1l?nO`O000_nO
`O001?l0003oV[oboiZol_nJ_o89o`0000?oinG>00Go0000onGHbOoUf<WoiMS9o`000002on;=a003
o`000?oHalSof<O800Ko00000_ln[oD00ol0003oF;7koeRan`02oeRan`04o`000?m^[_SoKZkho`00
00CoOZ_`00?o0000oh^Xj?n;Z>P00on;Z>P00ol0003oU:KRoiBVhP03oiBVhP03o`000?nMY]coWJKL
00;oWJKL00?o0000ojBWf?l000000_l00003oi_Ro@03o`000?n^ioWo000000Co00000_mMc_@5o`00
00CoYM;g00?o0000okgGkOl000001?ni_]d00ol0003oa/;Fo`000003o`000003okn`b_l0003ob;?6
00;ob;?600Go0000ol>X_oo3Z;oo`jRoo`000003olV[_004o`000?o5Y;OoaJBgo`0000CobJJf00Co
0000olJR/oo6X[?o00000oo9Y;<01?l0003ob:6aolRQ/Ol00004olVS/@04o`000?o9X[3obJ:`o`00
00;obJ:a00Go0000olZS/Oo:Xk7obZ>ao`000002olRS/P03o`000?o:YK?obZFc00;obZFc00Co0000
olJT]_o6Y;Ko00000oo9YkL01?l0003o`jFkol>U^ol00003olNZ_@04o`000?nlYl?o_:O3o`0000?o
`Jg600?o0000ok2Wcon`Yll00_n`Yll01?l0003oUicGoiNLeonGW=L9o`000003od=`fOl0003o4e?>
00Co000000?o03Rmo`000?l000000_l000000ol0?<3o0000ocI]fP03o`0000GoUJSS00?o0000omg6
`_l000000ooOb<400ol0003oh/Voon;9_`02o`0000?on<NG00Co0000ooS8Uoohb9Oo00000_oib9H0
0ol0003onLVFooW9UP02o`0001?ooooo00?o0000ooooooooool08Oooool003Sooooo00?o0000oooo
ooooool03oooool2o`000003oi^6_?l0003oW8Nm00?oW8Nm00?o0000oib9__nLRKh00onLRKh01Ol0
003oWH_0oif;`?nMRl3o000000CoWXg20_l00006ojFnj`03o`000?nO`O3oWl7`00So000000Gog?cG
o`000?oVl]Coi_;Do`000003onOUcP05o`000?oUf<WoiMS9onGHbOl000000ooRcL@2o`0000?of<O8
00?o0000om>ma?oC_L@01Ol00004oeRan`04o`000?m^[_SoKZkho`0000CoOZ_`00?o0000oh^Xj?n;
Z>P00on;Z>P00ol0003oU:KRoiBVhP02oiBVhP04o`000?nMY]coWJKLoifVg0Go00000onKh_d:o`00
00CoPLKm00Co0000ojGBmonUd_OoYM;g0ol00005okVng@?o00001Ono/<X00ol0003ob;?6o`000005
ol>X_`04o`000?o9ZkcobJ^lo`0000?oaJBg00Co0000olVV]_o9Y[Ko00000oo6X[<01?l0003obJBc
olVT/ol00004olRQ/@04o`000?o9Xk7obJ>ao`0000?obJ:`00Co0000olVR/Oo9X[7o00000oo:Xk40
1?l0003ob:>bolRS/_l00004olZU/`03o`000?o6Y;Ko000000CobJNg00?o0000ol>U^ol000001?o7
Z[d00ol0003o_:O3o`000004ol6]aP03o`000?n`Yloo/:O?00;o/:O?1?l00002oiZTg@03o`000?mb
TN;oLY7R00;oLY7R00?o0000od1eg_l000000_l00002oa=CcP05o`000?l0>koo0000o`000?l0<kX0
0ol000001?l0?<3o0000ocI]f_lfKMX2o`0000?oUJSS0ol00004omo8`@05o`000?oRbKooh/Voon;9
_ol000000oohaiL01?l0003on<RGooS8Uol00002ooW8UP03o`000?oibIKo000000;onLVF00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Pooooo`00>?ooool00ol0003oooooooooo`0=oooo
o`;o00001?nKQ[`00ol0003oW8Nmoib7_@02oib7_@03o`000?nLRKkoW8Vn00;oW8Vn00?o0000oif;
`?nMRl000_nMRl04o`0000;oZ;ST00?o0000ojFnjonU_^/00onU_^/8o`000004ol[of?l0003og?cG
o`0000?oi_;D00Co0000onOUc_oWiLko00000ooUf<T01Ol0003oh/g4on;=a?oRcLCo000000;ogLBo
00?o0000omS7b?l000001OoC_L@00ol0003oa;;9o`000009o`0000CoOZ_`00?o0000oh^Xj?n;Z>P0
0_n;Z>P01?l0003oU:KRoiBVh_nDY^85o`0000?oPM[n2ol00003odf^n@04o`000?n1a_goPLKmoh76
o@Go00000onW^>D00ol0003o^KkMokVng@04o`0000Ko_k3:0_l00006ol>X_`03o`000?o9Zkco0000
00CoaJBg00Co0000olVV]_o9Y[Ko00000oo6X[<01?l0003obJBcolVT/ol00004olRQ/@04o`000?o9
Xk7obJ>ao`0000CobJ:`0_l00005olZS/@;o00001_o:YK<00ol0003obJNgolVW]`04olVW]`03o`00
0?o7Z[goajZm00CoajZm00?o0000ol6]a_o1[LH00oo1[LH00ol0003o/:O?o`000002o`000003okB_
e?l0003oVZCM00CoVZCM00?o0000og:Ah_mbTN800_mbTN801?l0003o@7GNod1eg_l00003oa=CcP03
o`000?l0>koo000000;o03>j00Co0000o`12`ol0003o00000olfKMX4o`0000;oVjcS00Go0000omo8
`OoOb<7oglS1o`000004on;9_`;o000000Gon<NGo`000?ohb9Oon<RGo`000002ooW8UP04o`000?oi
bIKonLVFo`0000;onLVF00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Pooooo`00>?oo
ool2o`0000_ooooo0ol000000onLR;go0000oi^6_003oi^6_003o`000?nLQkgoW8Nm00;oW8Nm00?o
0000oib9__nLRKh00_nLRKh00ol0003oWH_0oif;`004o`0000GoZ;ST00?o0000ojFnjol000000_l0
00000onFj_Wo0000o`000003o`0000;ob_oH00?o0000omcleol000000ooVl]@01?l0003oinG>onOU
c_l00003onGHb@05o`000?oRcLCoh/g4on;=a?l000001?oMa;l00ol0003odkg4om>ma003om>ma003
o`000?o?]/7o000000?oa;;900Co0000okn/a_no[<Ko00000_n]Xld>o`0000?oG<cg2?l00002o`]H
dP04o`000?l^Jm[o0000o`0000;o?8W/1ol00002ohf^k003o`000?nW^>GoYkSU00?oYkSU1?l00003
okB[c`03o`000?no/<[o_k3:00;o_k3:00?o0000okZT`_l000001oo3Z;l00ol0003oaJBgolFT]`03
olFT]`03o`000?o9Y[Ko000000GoaZ:c0_l00005olRQ/@03o`000?o9Xk7o000000GobJ:`00?o0000
olZS/Oo:Xk401?o:Xk400ol0003obZFcolZU/`05olZU/`03o`000?o9YkOobJNg00CobJNg00?o0000
olNZ_Oo7Z[d01?o7Z[d00ol0003o`Jg6ol6]aP03ol6]aP;o00001Ond[m@00ol0003oVZCMoiZTg@02
oiZTg@03o`000?mbTN;oLY7R00;oLY7R00Co0000od1eg_m0MMko@7GN0_l000001?lCDlko0000o`00
0?l0>kl2o`000004o`0c^_l0003o0000o`0000Co=VgJ00?o0000oi^/honK[><00onK[><01?l0003o
glS1omo8`Ol00003on;9_`03o`000?oTbkkoi<^n00;o00000_ohb9L01?l0003onLRFooW8U_l00002
ooW9UP03o`000?oibIKonLVF00;o00004_ooool2o`00027ooooo000hooooo`03o`000?oooooooooo
00Oooooo0ol00004oib8_@03o`000?nKQ[coVhJl00;oVhJl00?o0000oib7_OnLQkd00_nLQkd00ol0
003oW8Vnoib9_P02oib9_P?o00001?nZ/=`00ol0003oZ;STojRhi002ojRhi0So000000Co]_cLo`00
0?o:omSob_oH3?l000000ooUf<Wo0000on;=a002on;=a003o`000?oMa;oogLBo00?ogLBo0_l00003
om>ma007o`000?o?]/7ockK1olnf`Ol0003oa;;9o`000004okn/aP04o`000?n]Xlgo[J?=ojfSc@oo
000000Ko=eS8o`000?l0003o0000oaU8`ol00002oa1<b0;o000000Co2eSBo`000?l^Jm[o;V_J0_l0
00000ollRNco0000ofVOl002ofVOl003o`000?n=[^coSJk/00;oSJk/00?o0000ojNhiOl000000_l0
00000onW^>Go0000o`000005okB[c`04o`000?no/<[o_k3:o`0000?o^ZC200?o0000ol>X_oo3Z;l0
0oo3Z;l2o`0000KoaJBg00?o0000olJR/oo6X[<01?o6X[<00ol0003ob:6aolRQ/@05olRQ/@03o`00
0?o9X[3obJ:`00CobJ:`00?o0000olZS/Oo:Xk401?o:Xk400ol0003obZFcolZU/`04olZU/`;o0000
1Oo9YkL00ol0003ocJbho`000004olNZ_@03o`000?o;/<3o000000?o`Jg600?o0000olFebol00000
1Ond[m@01?l0003oVZCMoiZTgOnJY=d9o`000003od1eg_l0003o3EK@00Go000000Co03Nmo`000?l0
003o04K71?l00002ocI]fP03o`000?nK[>?oVjcS00;oVjcS00?o0000omo8`Ol000001?oRbKl01Ol0
003oi<^nonC;__oTbkko000000;on<RG00Co0000ooW8U_oib9Ko00000_oibIH00ol0003onLVFo`00
0002oo[;UP03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`00oooool003Sooooo
00?o0000ooooooooool01?ooool3o`0000;oWXg200?o0000oib8_OnLR;d00onLR;d00ol0003oVhJl
oi^6_002oi^6_003o`000?nLQkgoW8Nm00;oW8Nm1?l000000onYYmGo0000ojZ`g005ojZ`g004o`00
0?nX^>Co0000o`0000;o[^Ki0_l00002ojghj`03o`000?nfo=co000000Co000000?oi^oCo`000?oY
iL`00_oYiL`01?l0003oj=[6onSJa_l00002onK@`@;o00000ooRcL@00ol0003ogLBoomg4_`02omg4
_`06o`000?oJ_Kgof[fmo`000?oC_LCo00001Oo?]/400ol0003o_jc6okn/aP03okn/aP06o`000?n]
Xlgo0000o`000?nYWL[o00001?n@S/h00ol0003oLG_>og5kcP03o`000006oe9/col0003o=eS8ocMH
b?l0003o9T_20_l000001OlIB<?o0000o`000?l0003o9EO<00;o00000_l^JmX00ol0003oDgkOo`00
0002o`0000?oJIo`00?o0000ohf^k?n=[^`00ol000001_nW^>Go0000o`000?l0003oY:CEo`0000Go
]:_?00?o0000okn`b_l000001?njY<800ol0003o`jRool>X_`02ol>X_`03o`000?noX;[o000000Ko
aJBg00?o0000olJR/oo6X[<01?o6X[<00ol0003ob:6aolRQ/@05olRQ/@03o`000?o9X[3obJ:`00?o
bJ:`00?o0000olZR/?l000001?o:Xk400ol0003oc:Fao`000004olZU/`04o`000?o=Z;?ocJRco`00
00?obJNg00Co0000olf/^?o=[;So00000oo7Z[d01?l0003obk30ol^``?l00002ol6]aP05o`000?o5
]L_oaKG;olFebol000001?nd[m@4o`0000;oVjkT00?o0000og2IjOm`VNT00_m`VNT00ol0003o>GWR
o`000002o`0000;o3EK@00Go0000o`0n`_l0003o0000o`0g_@02o`000004o`16aol0003o?7?Mocac
g@Co00000_nK[><3o`0000Coh/Vo00?o0000onC;__oTbkh00_oTbkh01_l0003on<RGooS8Uol0003o
nLRFo`0000;onLVF00Co0000ooW9U_oibIKo00000_ojbiH00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7o
V9RHoooooonHV9So8B4Q00?ooooo000hooooo`04o`000?ooooooooooooooo`?o000000?oXY_>o`00
0?nNSL800onNSL800ol0003oW8Rmoib8_@02oib8_@03o`000?nKQ[coVhJl00;oVhJl00Co0000oib7
_OnLQkgoW8Nm0_l00005ojVWe@03o`000?nZ/=coZ[3L00?oZ[3L1?l000000on^i_Wo0000ojghj`02
ojghj`Co000000GogoKKo`000?oVkm?oi^oCo`000003onWUc004o`000?oXf/Koj=[6o`0000?oi]31
00Go0000on?8_Ol0003oh/g4o`000004omg4_`03o`000?oJ_Kgof[fm00;of[fm00?o0000olnf`Oo?
]/400oo?]/42o`0000Ko_jc600?o0000ojVMb_nYWLX00_nYWLX00ol0003oT8k>oi2>cP02oi2>cP05
o`000?maNlkoLG_>o`000?mAI/T00_l00003ocMHb006o`000?lVBl;o0000oaU8`ol0003o8D_30_l0
00000olUElco0000obi[fP02obi[fP04o`000?mCO]ooDgkOoe=ng`[o00001OnTY=D00ol0003o]:_?
okB[c`02okB[c`;o00001_njY<801?l0003o`jRool>X_ol00003oknP^P03o`000?o5Y;OoaJBg00;o
aJBg00?o0000ol:O]?l000001?o6X[<00ol0003oaInao`000005olRQ/@;o00001?o9X[001?l0003o
bZ:`olZR/?l00004olZS/@03o`000?o<YK7o000000CobZFc00Co0000olfX/oo=Z;?o00000_o9YkL0
1Ol0003ocJbholf/^?o=[;So000000;oajZm00Oo0000ol^``?o;/<3obk30o`000?o1[LKo000000Co
aKG;00?o0000okB_e?l000000_l00002okRifP03o`000?nK[^CoVjkT00;oVjkT00?o0000og2IjOm`
VNT00_m`VNT01?l0003o>GWRocUih_l00003o`eFd0?o00000_l0=kd2o`000003o`16aol0003o?7?M
00?o?7?M0ol00003oj6`h`04o`000?oRbKooh/Voo`0000Coi<^n00Co0000onK=_Ol0003o00000_oi
b9H01?l0003onLVFooW9U_l00002ooW9UP03o`000?ojbiKon/^F00;o00004oooool00ol0003ooooo
ooooo`05ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo0000
00?ooooo000gooooo`03o`000?oooooooooo00;o00001OnRVlh01Ol0003oWXg2oij=`_nNSL;o0000
00CoW8Rm00?o0000oi^6_?nKQ[`00_nKQ[`01_l0003oW8Nmo`000?l0003oYYo?o`0000KoZJOE00?o
0000ojZ`g?l000000_l00003okWIl0So00000_oOm]/01?l0003oi^oConK_dol00003onWUc004o`00
0?oXf/Koj=[6o`0000?oi]3100Go0000on?8_OoSb;gohlRmo`000004omg4_`03o`000?oJ_Kgof[fm
00?of[fm00?o0000olnf`Oo?]/400_o?]/401?l0003oc;2oolb`_ol00004okn/aP;o00001OnYWLX0
1Ol0003oT8k>oi2>c_n@S/ko000000?oLG_>00?o0000oe5VbOmAI/T00_l000002?lgF<So0000obI;
`_lVBl;o0000oaU8`ol0003o8D_30_l000000olUElco0000o`000002obi[fP03o`000?mCO]ooDgkO
00?o000000?oM8oNo`000?n@Vm/00on@Vm/00ol0003oY:CEojBTe@03ojBTe@03o`000?ndZloo]:_?
00;o000000?o/9k6o`000?njY<801OnjY<800ol0003o`jRoo`000004oknP^P05o`000?o5Y;OoaJBg
olFT]ol000000_o2Wk@00ol0003oaZ:colJR/`02olJR/`03o`000?o5Wk7o000000Cob:6a00Co0000
olRP/?o8X;3o00000oo9X[001?l0003obZ:`olZR/?l00003olZS/@05o`000?o<YK7oc:FaolbU/Ol0
00000_o:YK<01Ol0003ocJRcolfX/oo=Z;?o000000;obJNg00?o0000olf/^?o=[;P00_o=[;P2o`00
00Gobk3000?o0000olFeboo5]L/01?o5]L/00ol0003o^;WJokRifP04okRifP03o`000?nK[^CoVjkT
00Oo00000oliNN82o`000003o`eFd?l0003o03o200?o000000Go03Nmo`000?l0A/Oo04K7o`000003
ocacg@;o00001OnQ/><00ol0003oh/Voo`000003onC;_P05o`000?oVcKgoi/fmonK=_Ol000000_oi
b9H01?l0003onLVFooW9U_l00002ooW9UP03o`000?ojbiKo000000;on/bG00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;o
V9RHoooooonHV9So<S8b00?ooooo000gooooo`?o000000?oZ;o[o`000?nRVlh01?nRVlh00ol0003o
WXg2oij=`P02oij=`P05o`000?nLR;goW8Rmoib8_Ol000001?nKQ[`2o`0000CoYYo?00?o0000ojVW
eOnYYmD00onYYmD3o`0000?o^MW`0_l00003olKak`04o`000?oCn>CodoSTo`0000;ogoKK00Co0000
onK_dooVkm?o00000ooYiL`01Ol0003oj=[6onSJa_oXf/Ko000000;oi]3100?o0000on?8_OoSb;d0
0_oSb;d2o`0000?ogLBo00?o0000omZm_OoJ_Kd00_oJ_Kd00ol0003oe[Njo`000002olnf`@03o`00
0?o</;ooc;2o00;oc;2o00Co0000okn/a_no[<Ko00000_nlYl@00ol0003oZIg:ojVMbP02ojVMbP05
o`000?n@S/koT8k>oi2>c_l000000omaNlh01Ol0003oDFK9oe5VbOl0003o>5C300;o00000_lVBl83
o`0000;o8D_300Co0000obEGc?l0003o@FG@1Ol000000omCO]oo0000ogB?gP02ogB?gP03o`000?n@
Vm_oT9_K00;oT9_K00?o0000ojBTeOnTY=D00_nTY=D00ol0003o]:_?o`000004ok2NaP03o`000?nj
Y<;o^ZC200?o^ZC20_l00005oknP^P04o`000?o5Y;OoaJBgo`0000Co`Ynd00Co0000olJR/oo6X[?o
00000oo5Wk401?l0003ob:6aolRQ/Ol00003olRP/004o`000?o9X[3obJ:`o`0000CobZ:`00Co0000
olZS/Oo:Xk7o00000oo<YK401?l0003obZFcolZU/ol00004olfX/`;o00001Oo=[;P00ol0003obk30
ol^``004ol^``003o`000?o5]L_oaKG;00?oaKG;0_l00006okRifP?o00000onK^>`00ol0003oJZ3`
ofZPl003o`000003ocUih_l0003o0eOB00?o000000Go03o2o`000?l0>Kko0000o`0g_@02o`000003
o`16aol0003o000000;o?7?M0_l00004oj6`h`;o00001?oTbkh01Ol0003oi/fmonK=_OoVcKgo0000
00;onLRF00?o0000ooW9U_l000000_oibIH01?l0003on/^Foo[;U_l00002oo[<U`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go
c<c<o`000?l0003o0000olc<c003ooooo`00=oooool00ol0003oZ;o[ojRoj`02ojRoj`03o`000?nR
VlkoXY_>00?oXY_>00Go0000oij=`_nNSL;oWXg2o`000004oib8_@Co000000?oXiW;o`000?nVWll0
1?nVWll00ol0003oZJOEojVWe@02o`0000?o^/WU00?o0000okWIl?l000001?o6lNl01?l0003odoST
om?hi?l00002omoff`04o`000?oVkm?oi^oCo`0000CojNG<00Co0000onSJa_oXf/Ko00000ooVd<40
1Ol0003ohlRmon?8_OoSb;go000000;oh<6j00?o0000omg4_ol000001?oJ_Kd01_l0003oe[NjomJg
^_l0003ockK1o`0000Goc;2o00?o0000okn/a_l000001?nlYl@01?l0003oZIg:ojVMb_nYWLX7o`00
0003og5kc_l0003oDFK900;oDFK900Oo0000ocQD`ol0003o0000obI;`_l0003o8TJn00;o00000_lQ
Bl<5o`000003od5Ud?l0003o000000;o00001?mdSmh00ol0003oT9_Koi2Kf`02oi2Kf`04o`000?nT
Y=GoY:CEojBTe@;o00001On`W/H00ol0003o^ZC2okZT`P02okZT`P03o`000?ngW;co000000Ko_j2j
0_l00005ol:O]003o`000?o6X[?o000000CoaIna00Co0000olRQ/Oo8XK7o00000oo8X;001?l0003o
bJ:`olVR/?l00004olZR/003o`000?o:Xk7o000000Coc:Fa00?o0000olZU/ol000001Oo=Z;<00ol0
003ocJbholf/^004olf/^003o`000?o;/<3obk3000?obk3000?o0000om2h`ol000000oo5]L/01?l0
003ob[o@olZod?l00003okRifP;o000000?o^lCQo`000?nK^>`01?nK^>`01?l0003oJZ3`ofZPl?mZ
X?04o`0000;o0eOB0_l000000ol0?l;o0000o`0i_P02o`000004o`1;b_l0003o0000od5ih0Co0000
00KoXK3So`000?l0003o0000ojJfi?l00003onC;_P06o`000?oVcKgoi/fmonK=_Ol0003oj<nm0_l0
0002ooW9UP04o`000?oibIKonLVFo`0000;on/^F00?o0000oo[<Uoojc9L00_l0000Cooooo`03o`00
0?oooooooooo00?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj
^_l@41000oooool002cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`;o00000onX_n/00ol0
003oXY_>oj:KcP03oj:KcP05o`000?nNSL;oWXg2oij=`_l000000_nLR;d3o`0000GoXiW;00?o0000
ojJOconVWll00_nVWll00ol0003oZJOEo`000006ok[9i@?o00000_o6lNl00ol0003odoSTom?hi009
o`0000;ojNG<00Go0000onSJa_oXf/Koj=[6o`000002onK@`@05o`000?oSb;gohlRmon?8_Ol00000
1?oP`KX00ol0003of[fmomZm_@02omZm_@03o`000?oF]k[oe[Nj00;oe[Nj00?o0000olb`_oo</;l0
1Oo</;l00ol0003o_:O4okbWa003okbWa006o`000?nYWL[o0000o`000?nUVLWo00000on<RL`00ol0
003oKGK;o`000002o`0000;oDFK900Co0000ocQD`olhE<?o00000_lVBl800ol0003o8TJno`000002
ob5;``Co00000_m1IM000ol0003oGWGBoeiedP06o`0000CoT9_K00Ko0000ojBTeOl0003o0000oj:H
b_l00006ok2NaP04o`000?njY<;o^ZC2o`0000;o]ibl00?o0000oknP^_noX;X01?noX;X00ol0003o
`Yndol:O]004ol:O]003o`000?o6X[?o000000CoaIna00?o0000olRQ/Ol000001Oo8X;02o`0000Go
bZ:`00?o0000olZS/Ol000001Oo<YK400ol0003ocJRcolfX/`04olfX/`03o`000?o=[;SocJbh00?o
cJbh00?o0000om6b^ol000000oo;/<001ol0003od;S3om2h`oo@^<?o0000olFebol000001?o:_m00
0ol0003o^;WJo`000004ok_4h@04o`000?nK^>coVkS/oi^hk0Oo00000_l]O>H2o`0000;o0eOB0ol0
00001?l0>Kko0000o`000?l0BlX2o`0000?o@GWP0_l00005ojJfi004o`000?oTbkkoi<^no`0000;o
i/fm00Go0000onS?_OoXckgoj<nmo`000002ooW9UP04o`000?oibIKonLVFo`0000;on/^F00?o0000
oo[<Uol000000_ojcIP00ol0003oooooooooo`0>ooooo`?o00001Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000003ooooo`00;?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooool000000onX_n/00ol0003oXY_>oj:KcP02oj:KcP03o`00
0?nNSL;oWXg200Co00000_nMU<X00ol0003oXiW;oj>Ib`03oj>Ib`03o`000?nVWlooYYo?00;oYYo?
0ol00005ok[9i@04o`000?o<h>Ooc>3WolcPi`Ko00000_oRimH01?l0003oi^7>onKQc_l00002onOI
aPCo000000?oj=[6o`000?oVd<400_oVd<401Ol0003ohlRmon?8_OoSb;go000000Coh<6j0_l00003
omZm_@03o`000?oF]k[oe[Nj00;oe[Nj00?o0000olb`_oo</;l01?o</;l2o`0000Go_:O40_l00004
ojFIb@05o`000?n<RLcoS8W<ohb9c?l000000_m]M//2o`0000;oDFK900Oo0000ocQD`ol0003o0000
obI;`_l0003o8TJn00?o000000Co8D_3o`000?lcE<Go00000om1IM001?l0003oGWGBoeied_l00003
ogV3d@Oo00001?nRV<X00ol0003o/9k6ok2NaP03ok2NaP03o`000?njY<;o000000Co]ibl00?o0000
oknP^_noX;X00_noX;X2o`0000Oo`Ynd00?o0000olFO/Oo5Wk401?o5Wk400ol0003ob:2`olRP/004
olRP/003o`000?o:X[3obZ:`00GobZ:`00?o0000olbU/Oo<YK401?o<YK400ol0003ocJRcolfX/`03
olfX/`03o`000?oA[KGo000000?ocJbh00Go0000om6b^ooA/[_odK:ko`000002ol^``003o`000?o@
^<?od;S300;od;S300?o0000olZod?o:_m000oo:_m02o`0000Go^lCQ1?l00002oiS3m@04o`000?mQ
Y_KoHJKfof6VmP?o000000?o;GcVo`000?l000000_l000000ol0?/7o0000o`000002o`0000;o04_:
00Oo0000od5ih?m1NN3o@GWPo`000?nV]^Co000000CoY[KT00?o0000onC;__l000000ooVcKd01Ol0
003oj<nmonS?_OoXckgo000000;onLVF00?o0000ooW9U_l000000_ojbiH01?l0003on/bGoo[<Uol0
0002oo[=V003o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`00;?ooool01Ol@413ooooo
oooooooooooo410@00Kooooo00?o0000ooooooooool01?l00003oj:KcPCo00000_nET/h00ol0003o
WIC:oifDbP02oifDbP03o`000?nSVL_oXiW;00?oXiW;00Co0000ojJOconVWloo00000ong^]`01Ol0
003o^/WUok[9iOnjbNGo000000?oc>3W00?o0000omWXh?oIj>000_oIj>001?l0003oh^OFon;We_l0
0002onKQcP03o`000?oWfLKoimW600;oimW600?o0000onOA`OoWdL400ol000000ooVd<7o0000on?8
_@02on?8_@03o`000?oP`K[oh<6j00;oh<6j00Ko0000omfl^?oM_;So0000omZm_Ol00004omJg^P03
o`000?oC/kWo000000Coc;2o00Co0000olV]__o9[Kko00000_nlYl@2o`000003okVT`ol0003oYIW9
00?oYIW900Go0000ohb9c?n<RLcoS8W<o`000002ofefb`03o`000?m>HLKo000000;o00000_lhE<<4
o`000005ob96__l0003o0000ob5;`ol000000_lcE<D2o`000003od5Ud?l0003oGWGB00;oGWGB00Go
0000ogV3dOmiPm7oNH?Ao`000004ohn?cP03o`000?nRV<[oXYS:00;oXYS:00?o0000ok2Na_n`W/H0
0on`W/H2o`0000Go]ibl00Go0000oknP^_noX;[o_j2jo`000002okbK]P03o`000?o2WkCo`Ynd00Co
`Ynd00?o0000olFO/Oo5Wk401?o5Wk400ol0003ob:2`olRP/004olRP/003o`000?o:X[3obZ:`00Go
bZ:`00?o0000olbU/Oo<YK400oo<YK400ol0003ocjRbo`000003olfX/`05o`000?oA[KGodJfeom6]
]Ol000000_o=[;P01ol0003odK:kom6b^ooA/[_o0000ol^``?l000001Oo@^<<00ol0003ob[o@olZo
d002olZod003o`000?o?b]Ko000000?o^lCQ0_l000000onmdNWo0000oiS3m@04oiS3m@03o`000?mQ
Y_KoHJKf00;oHJKf1?l000001_l0E]3o0000o`000?l0?/7o0000o`0j_`?o000000So04_:o`000?l0
003o0000od5ih?l0003oY[KTo`0000?oY[KT0_l00003onK=_@06o`000?oXckgoj<nmonS?_Ol0003o
j]:l0_l00002ooW9UP04o`000?ojbiKon/^Fo`0000;on/bG00?o0000oo[=V?ojcIP00_l0000Coooo
o`03o`000?oooooooooo01Wooooo000/ooooo`05o`000?ooooooooooooooool000001Oooool3o`00
00?ooooo1Ol00002oh:Dg003o`000?nET/koUI;>00;oUI;>00Go0000oifDb_nMU<[oWIC:o`000005
oj>Ib`03o`000?nVWloo000000Go]k[L00?o0000ok[9iOl000000oo<h>L00ol0003ofNSPomWXh002
omWXh004o`000?oRimKoh^OFo`0000;oi^7>00?o0000onOIa_oWfLH00_oWfLH01Ol0003oim71onOA
`OoWdL7o000000;oiLZl0_l00003on?8_@05o`000?oP`K[oh<6jon31^_l000001?oM_;P00ol0003o
e[NjomJg^P03omJg^P04o`000?oC/kWodk>io`0000;oc;2o00Oo0000olV]__o9[KkobJfno`000?nl
YlCo000000Co^JC300?o0000ojFIbOnUVLT00_nUVLT01Ol0003oS8W<ohb9c?n<RLco000000;oKGK;
00Co0000odiQa_m>HLKoCV760ol000000olXB;go0000o`000002ob96_P?o00000_lcE<D01?l0003o
BV77o`000?l00003oeiedP03o`000?miPm7oNH?A00;oNH?A00?o0000ohn?c_n?Slh00_n?Slh00ol0
003oXYS:oj:HbP02oj:HbP03o`000?n`W/Ko/9k600;o000000?o[IJoo`000?ngW;`01?ngW;`01?l0
003o_j2joknP^_l00003okbK]P03o`000?o2WkCo`Ynd00?o`Ynd0_l00005olFO/@03o`000?o5W[3o
000000Cob:2`00?o0000olVQ[ol000001Oo:X[000ol0003oc:B`o`000003olbU/@04o`000?o?Z;;o
cjRbo`0000;ocJRc00?o0000om6]]OoA[KD00_oA[KD00ol0003ocJbho`000005om6b^`03o`000?o@
^<?od;S300?od;S300?o0000omG2aol000000_o:_m001ol0003ocl[Folo:e_o?b]Ko0000ok_4hOl0
00001?nmdNT01?l0003oV<?eoiS3mOnH`oD9o`000004oaeli_l0003o0000o`1Fd0?o000000?o03Zo
o`000?l0C/d00_l00002odEoi0Oo000000?oZk_Uo`000?oVcKd00_oVcKd01?l0003oj<nmonS?_Ol0
0003on[B_004o`000?oibIKonLVFo`0000;on/^F00?o0000oo[<Uol000000_ojcIP01?l0003on/jJ
oo[>V_l0000Booooo`03o`000?oooooooooo01Wooooo000/ooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`04ooooo`;o00001On2U=`01Ol0003oUI;>oiFBc_nET/ko0000
00CoWIC:00?o0000oj>IbonSVL/00_nSVL/2o`0000Ko]k[L1?l000000oo<h>Oo0000omWXh003omWX
h004o`000?oRimKoh^OFo`0000;oi^7>00?o0000onOIa_oWfLH00_oWfLH01Ol0003oim71onOA`OoW
dL7o000000?oiLZl00Go0000on?4^Ol0003ohlRmo`000004on31^P03o`000?oM_;SogKbh00;ogKbh
00?o0000omJg^_oF]kX00_oF]kX01ol0003odk>iom>c^OoC/kWo0000olb`_ol000001Oo9[Kh00ol0
003o^JC3okVT``03okVT``03o`000?nUVLWoYIW900;oYIW900Go0000ohb9c?n<RLcoS8W<o`000002
ofefb`Go000000Co=Do0o`000?l0003o:4Rm0_l000000olRA[ko0000obU8_P02o`0000;o<eC500?o
0000odYQaom:HLL00_l00002oeiedP05o`000?miPm7oNH?AogV3dOl000001?n?Slh00ol0003oXYS:
oj:HbP02oj:HbP03o`000?n`W/Ko000000Co[IJo00?o0000okNL_?ngW;`00ongW;`2o`0000Go_9^f
00Go0000ol:O]?o2WkCo`Yndo`000002ol6L/P05o`000?o5Wk7oaInaolFO/Ol000000_o5W[000ol0
003ob:2`olRP/002olRP/003o`000?o9XJoo000000CobZ:`00Co0000olbT/?o<Y;3o00000_o<YK40
1Ol0003ocjRbolnX/_o?Z;;o000000;ocJRc00?o0000om6]]OoA[KD00ooA[KD00ol0003odK:kom6b
^`04om6b^`03o`000?o@^<?od;S300;od;S300Ko0000omG2aooE`/Oo0000olZod?l00004olo:eP;o
00001OnmdNT4o`0000?oTLcl00?o0000oe:YnOmBZOT00_mBZOT6o`000006o`0k_Ol0003o0000o`0j
_ol0003o04k=0_l00004odEoi0;o00001?n[^nD00ol0003oi/fmo`000003onS?_@05o`000?oZd[co
j]:lon[B_?l000000_oibIH00ol0003on/^Fo`000002oo[<U`04o`000?ojcISon/fHo`0000;on/jJ
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Hooooo`00;?ooool01Ol@413ooooooooo
oooooooo410@00Gooooo00?o0000ooooooooool01Oooool2o`0000CoPYCL00?o0000oiFBc_nET/h0
0_nET/h01_l0003oWIC:oifDb_nMU<[o0000oj>Ib`?o00000_n_[]L01?l0003o]k[LokNjg?ng^]`2
o`0000CoalkO0ol00002omWXh005o`000?oRimKoh^OFon;We_l000000_oVhLh01Ol0003oimW6onOI
a_oWfLKo000000?oim7100Go0000onG:_?oUb[coiLZlo`000003on?4^@03o`000?oP`K[oh<6j00;o
h<6j00?o0000omfl^?oM_;P00_oM_;P00ol0003of[Rfo`000002omJg^P03o`000?oC/kWodk>i00?o
dk>i00?o0000olV]__o9[Kh01?o9[Kh00ol0003o^JC3okVT``03okVT``03o`000?nUVLWoYIW900;o
YIW92Ol00003odiQaP06o`000?leCl3o0000obQ8_Ol0003o9D>j0ol000001OlYB;ko0000o`000?lc
E<Go000000;oBV7700?o0000of=^bOl000000_l00004ogV3d@05o`000?n?SlkoSho>ohn?c_l00000
0onRV<X3o`0000Go[IJo00?o0000okNL_?ngW;`00ongW;`00ol0003o_9^fokbK]P04okbK]P04o`00
0?o2WkCo`Yndo`0000?o`Ibb00Co0000olFO/Oo5Wk7o00000oo5W[001Ol0003ob:2`olRP/?o8X;3o
000000?obJ6_00Co0000olZR/?o:X[3o00000oo<Y;001?l0003oc:FaolbU/Ol00004olnX/P;o0000
1_oA[KD00ol0003odK:kom6b^`03om6b^`03o`000?oF^[go000000;od;S300?o0000omG2aooE`/L0
0_oE`/L00ol0003ocl[Folo:eP02olo:eP05o`000?oBe]cod]KLo`000?nmdNT00ol00002ok_Ll004
o`000?nAc?coTLcloi7<o0Wo000000Go2gWRo`000?l0003o0000o`0k_@02o`000004o`0j_ol0003o
0000o`0000CoAGoT00?o0000oj^kiOl000000on[^nD2o`0000?oj<nm00Ko0000on[B_?oZd[coj]:l
o`000?o[e;d2o`0000;on/^F00Co0000oo[<Uoojc9Oo00000_ojcIP00ol0003on/jJoo[>VP02o`00
01?ooooo00?o0000ooooooooool05oooool002cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`03o`000?oooooooooo00Oooooo00?o0000oh:Dg?n2U=`00_n2U=`01Ol0003oUI;>oiFBc_nET/ko
000000;oWIC:0ol00006ojn^e`03o`000?ng^]co000000GoalkO00Co0000omCGf_oDem[oe=OJ1?l0
00001OoRimKo0000onKQc_oVhLko000000CoimW600Go0000onOA`OoWdL7oim71o`000003onG:_004
o`000?oSa;WohlBion?4^@;o00000ooP`KX00ol0003ogKbhomfl^002omfl^006o`000?oJ^;Kof[Rf
o`000?oF]k[o00001OoC/kT00ol0003obJfnolV]_P03olV]_P03o`000?o6Z[go000000Go^JC31?l0
00000onRUlWo0000o`000003o`000003ofMbb_l0003o000000?oCV7600Ko0000ocE?`?leCl3o0000
obQ8_Ol00002obE3^P04o`000?lYB;ko0000ocUA_`?o00000_m:HLL01?l0003oHfk9of=^bOmSK/T5
o`0000;oSho>1Ol00002oin?``03o`000?n]U[oo[IJo00Co[IJo00Co0000okNL_?ngW;co]ibl0_l0
0006okbK]P03o`000?o2WkCo000000Co`Ibb00Co0000olFO/Oo5Wk7o00001?o5W[001?l0003ob:2`
olRP/?l00003olVQ[`04o`000?o:X[3obZ:`o`0000Coc:B`0_l00005olnX/P03o`000?oA[KGodJfe
00CodJfe00?o0000omFc]ol000000ooA/[/01_l0003oe[ZmomJj_Ol0003od;S3o`0000CoeL;70_l0
0003olo:eP03o`000?oBe]cod]KL00;od]KL00?o0000ok_Ll?nkg?000onkg?04o`0000;oQ];o4?l0
00000ol0DLko0000o`000003o`000003odEoi?l0003oZk_U00?o000000?o[l3Wo`000?oXckd00_oX
ckd01Ol0003oj]:lon[B_?oZd[co000000;ojmBm00Co0000oo[;U_ojbiKo00000_ojc9L00ol0003o
n/fHo`000002oo[>VP04o`000?ojcicon/nLo`0001;ooooo0_l0000Hooooo`00;?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool02?ooool5o`0000;oUI;>1?l00002ojBT
e@03o`000?n_[]Oo[jkG00Co[jkG0_l00005olO>g`03o`000?oDem[oe=OJ00;oe=OJ00Co0000omgH
d_oMf=;ogMSB1_l00002onOIaP05o`000?oWdL7oim71onOA`Ol000000ooUb[`01Ol0003ohlBion?4
^OoSa;Wo000000;ohKnf00?o0000on31^_l000001?oM_;P00ol0003of[RfomZh]P02omZh]P03o`00
0?oC/kWodk>i00?odk>i00?o0000om6`^Ol000000oo9[Kh01?l0003oaZZmolJZ_Ol00004okVT``;o
00000onRUlT3o`0000?oQhO<00?o0000ofMbb_mWL/X00_l000001?m>HLKo0000ocE?`?leCl03o`00
00?o9D>j00?o0000obU8__l000000_liDKl01?l0003oBV77odYQaol00003of=^b@04o`000?mjNlSo
NW_8ogYkb0?o00000_n?Q/H00ol0003oWho3oin?``03oin?``03o`000?n]U[oo[IJo00?o[IJo00Co
0000okNL_?ngW;co00000_neUkT00ol0003o_9^fokbK]P04okbK]P03o`000?o1W;;o`Ibb00Co`Ibb
0_l00005olFN/003o`000?o8X;3o000000CobJ6_00?o0000olZR/?l000001Oo<Y;000ol0003ocjRb
olnX/P04olnX/P03o`000?oA[KGodJfe00?odJfe00Co0000omFc]ooE/kOo00000_oA/[/00ol0003o
e[ZmomJj_@02omJj_@03o`000?oE`/OoeL;700;oeL;700Ko0000om[=c?oJcLco0000olo:e_l00004
om;Fg004o`000?oDhn;o0000ok_Ll0?o00000_ngi_H4o`0000?oMm;n00?o0000obbSkol/Xnl00ol0
00000ol0L]So0000o`000005o`000003o`1Ac_l0003o000000;oAhGX1?l00004ojo0i`03o`000?oX
ckgo000000?oj]:l00Go0000on_D_Oo[e;gojmBmo`000002oo[;UP03o`000?ojc9Oo000000;on/fH
00Co0000oo[>V_ojcY[o00000_ojci`00ol0003oooooooooo`0?ooooo`03o`000?oooooo000001So
oooo000fooooo`;o00002Oooool01?l0003oGHSToef8i?mMR>@3o`0000;oT9[I00?o0000ojBTeOnT
Y=D00_nTY=D01?l0003o[jkGojn^eon_[]L2o`0000;o_[oJ00Go0000olO>goo7c]ooalkOo`000004
omCGfP03o`000?oMf=;ogMSB00;ogMSB00Co0000on;EbooReL_o00000_oSd<@3o`0000?oim7100Co
0000onG:_?oUb[co00001?oSa;T01Ol0003ohKnfon6o]_oQ_kKo000000CogKbh00?o0000omZh]_oJ
^;H00ooJ^;H00ol0003odk>iom>c^@02om>c^@07o`000?oA/;WodK2iom6`^Ol0003obJfno`000004
olJZ_@05o`000?niY<?o^JC3o`000?ngX/@01?l00002oj:Gb@05o`000?n7QlcoQhO<ohN7c?l00000
0_mWL/X00ol0003oB5g5o`000002o`000003ocE?`?l0003o9TBj00;o00000_lU@kX3o`0000?o>E6o
0_l000000om:HLOo0000of=^b@02of=^b@05o`000?mjNlSoNW_8ogYkb?l000001?n?Q/H00ol0003o
Who3oin?``02oin?``03o`000?n]U[oo[IJo00?o[IJo00?o0000okNL_?l000000oneUkT00ol0003o
_9^fokbK]P03okbK]P;o00001_o1W;800ol0003oaIj`olFN/004olFN/003o`000?o8X;3o000000Go
bJ6_00?o0000olbT/?o<Y;001?o<Y;000ol0003ocjRbolnX/P03olnX/P03o`000?oC[K?o000000Co
dJfe00Ko0000omFc]ooE/kOo0000om6b^ol00005omJj_@05o`000?oE`/OoeL;7omG2aol000001?oJ
cL`2o`0000?od]KL00Co0000omCSh_oDhn;oe>?R0ol000000ongi_Ko0000o`000002ojk/n17o0000
00?o03Nio`000?l0DLh00_l0DLh01ol0003oAhGXodN5j?m7QNSo0000ojo0iol000000on_`>L2o`00
00Coj]:l00Go0000on_D_Oo[e;go0000oncG_P02o`0000;on/bG00Co0000oo[=V?ojcISo00000_oj
cYX00ol0003on/nLoo[?W002o`0001?ooooo00?o0000ooooooooool05Oooool003Gooooo00?o0000
ooooooooool02_ooool01Ol0003oGHSToef8i?mMR>Co000000CoT9[I00?o0000ojBTeOnTY=D00_nT
Y=D00ol0003o[jkGo`000005okjofP03o`000?o7c]oo000000Coe=OJ00?o0000omgHd_oMf=800_oM
f=801?l0003oh]G;on;Ebol00004on?@a005o`000?oSbkoo0000onOA`Ol000000ooUb[`01Ol0003o
hlBion?4^OoSa;Wo000000CohKnf00?o0000omfl^?oM_;P00_oM_;P00ol0003of[RfomZh]P02omZh
]P03o`000?oH]KGo000000;odk>i00?o0000om6`^OoA/;T00ooA/;T00ol0003oaZZmolJZ_@03olJZ
_@03o`000?niY<?o000000Co00001?nRUlT01Ol0003oQhO<ohN7c?n7Qlco000000?oIg;:00Co0000
odQMaOm8GLGo00000_leCl000ol0003o9TBjo`000002obE3^P04o`000?l/A[[o0000o`0000;o>E6o
00Co0000odiM`_l0003o00000omSK/T01Ol0003oNW_8ogYkb?mjNlSo000000CoShK600?o0000oin?
`onOSl<00onOSl<00ol0003o[IJoojfF_`02ojfF_`;o00001OneUkT01ol0003o_9^fokbK]_nlVkKo
0000ok^I]?l000001_o1W;800ol0003oaIj`olFN/005olFN/003o`000?o9XJoobJ6_00CobJ6_00?o
0000olbT/?o<Y;000oo<Y;000ol0003ocjRao`000004olnX/P03o`000?oC[K?o000000?odJfe00?o
0000omFc]ooE/kL00_oE/kL00ol0003oe[ZmomJj_@03omJj_@05o`000?oL`l7o0000omG2aol00000
1OoJcL`01Ol0003ogmW@o`000?oBe]co000000?oe>?R00?o0000om?^i_oCk^H00ol000000on^k?So
0000o`000002oj?]n13o000000?o03Nio`000?l000000_l0DLh2o`0000;oAhGX00?o0000ojo0iol0
00000_l00002ok;6j@04o`000?oZd[coj]:lo`0000?ojmBm00Co0000oncG__o/ekko00000_ojc9L0
1_l0003on/fHoo[=V?l0003on/jJo`0000;on/nL00Co0000ooWAWooidIoo00004_ooool00ol0003o
ooooooooo`0Eooooo`00=Oooool00ol0003oooooooooo`0;ooooo`05o`000?mMR>CoGHSToef8i?l0
00001?n@V]T01?l0003oY:CEojBTeOnTY=D3o`0000Go_[oJ1?l00002omCGfP03o`000?oMf=;ogMSB
00;ogMSB00Co0000on;EbooReL_o00001?oSd<@01?l0003ohl^oon?;_ooSbkl2o`0000;oiLZl00Go
0000on?4^OoSa;WohlBio`000004on6o]P03o`000?oN^kCo000000;ogKbh00?o0000omZh]_oJ^;H0
0_oJ^;H01_l0003of;FeomRe]Ol0003odk>io`0000KodK2i00?o0000olJZ_Oo6Z[d00oo6Z[d3o`00
00Co]j;400?o0000oj:GbOnRUlT00_nRUlT01Ol0003oQhO<ohN7c?n7Qlco000000;oIg;:00?o0000
odQMaOm8GLD00_l000001OleCl3o0000obI4^_lVA;[o000000;o9D>j00?o0000oba6^_l000000_li
DKl01?l0003oCUg2odiM`_l00004of=^b@05o`000?mjNlSoNW_8ogYkb?l000001?n?Q/H00ol0003o
Who3oin?``02oin?``03o`000?n]U[oo[IJo00;o000000?oZi6ko`000?neUkT01?neUkT01?l0003o
_9^fokbK]_l00003ok^I]003o`000?o1W;;o`Ibb00;o`Ibb00?o0000ol6L/_l000001_o5W[000ol0
003obJ6_olVQ[`03olVQ[`03o`000?o;Xk3o000000Coc:B`00?o0000olnX/Ol000000oo?Z;801Ol0
003odjfcom>]/ooC[K?o000000;odJfe00?o0000omFc]ooE/kL00_oE/kL00ol0003oe[ZmomJj_@02
omJj_@05o`000?oL`l7og<?1omc3`Ol000001OoJcL`01Ol0003ogmW@omoId?oOfM3o000000?oe>?R
00Co0000om?^i_oCk^Ko00000_o>mNT3o`000003oj?]n?l0003o000000;oV>_h5?l000001_m7Rnco
0000o`000?l0003o[l3Wo`0000Go//KY00?o0000on[B_?l000000_o[e;d01?l0003ok=NnoncG__o/
ekh3o`0000;on/fH00Co0000oo[>V_ojcY[o00000_ojci`01?l0003onM6OooWAWol0000Cooooo`03
o`000?oooooooooo01Cooooo000Eooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
3?ooool01Ol0003oGHSToef8i?mMR>Co000000?oT9[I00Co0000ojBTeOl0003o00000on`/]X01Ol0
003o_[oJokjof_nn_m[o000000CoblWH0ol00003omgHdP04o`000?oReL_oh]G;o`0000Cohm3400?o
0000on?;_ooSbkl00_oSbkl01Ol0003ohlJko`000?oUb[co000000?ohlBi00?o0000on6o]_oQ_kH0
0_oQ_kH01_l0003og[^domjk]?l0003ogKbho`0000Cof[Rf00Go0000omRe]OoH]KGof;Feo`000006
om6`^@04o`000?o?[kWo0000olJZ_@?o000000?oaJVno`000?ngX/@01?ngX/@00ol0003oXYO9oj:G
b@08o`0000;oIg;:00?o0000odQMaOm8GLD00ol00002obI4^P;o000000Go9D>jo`000?l/A[[o;4Jj
o`000002ocUA_`03o`000?m>GL;oCUg200;o00000_mSK/T01Ol0003oNW_8ogYkb?mjNlSo000000Co
ShK600?o0000oin?`onOSl<00_nOSl<00ol0003o[IJoo`000003oj^A^`03o`000?neUkWo]INi00?o
]INi00?o0000okbK]_l000001?nkVK@01Ol0003o`Ibbol6L/_o1W;;o000000;o`Ibb00?o0000olFN
/?o5W[000oo5W[02o`0000CobJ6_00Co0000ol^S/?o;Xk3o00000oo<Y;001Ol0003ocjRaolnX/Oo?
Z;7o000000;ocjRb00Oo0000om>]/ooC[K?odjfco`000?oA[KGo000000CoeK>g00?o0000omZk^_l0
00000ooF^[d01?l0003og<?1omc3`OoL`l42o`0000?of/g<00Wo0000omoId?oOfM3ogmW@o`000?oR
iMGo0000omCSh_l000000_oCk^H01?l0003oc_GYolkejOl00002olKijP?o000000?oV>_ho`000?l0
00000_nBioX@o`000003o`1Bc_l0003o000000?oAh_/00?o0000ok;6jOl000001?nba^T2o`0000?o
jmBm00Co0000oncG__o/ekko00000_o]fKl01?l0003on/fHoo[=V?l00002oo[>VP08o`000?ojcico
n/nLo`000?oidIoo0000ooWBX_l0000Cooooo`03o`000?oooooooooo01?ooooo000Eooooo`03oa0@
4?oMgMgooooo01gooooo0_l0000>ooooo`Co00000_n@V]T3o`0000Ko/;;J00?o0000okjof_l00000
1Oo;bMP01_l0003oe<gBomC=d_l0003ogMSBo`0000?oh]G;00?o0000on?@a?oSd<@00_oSd<@01Ol0
003ohl^oon?;_ooSbkoo000000?ohlJk0_l00002on?4^@03o`000?oQ_kKohKnf00;ohKnf00?o0000
omjk]?oN^k@00_oN^k@00ol0003of[RfomZh]P02omZh]P03o`000?oH]KGof;Fe00;of;Fe00?o0000
om6`^OoA/;T00ooA/;T00ol0003ocjnio`000002o`000003olJZ_Ol0003oaJVn00;oaJVn00?o0000
okNRa?ngX/@00_ngX/@3o`0000;oWiK:00Ko0000oh>5cOn3QLgoPhG=o`000?mQKl/3o`0000;oB5g5
00Oo0000obm;__l0003o0000obI4^_l0003o8d2h00;o00000_l/A[X2o`000006ocUA_ol0003oCUg2
odiM`_l0003oIF[30ol00003ogYkb003o`000?n?Q/KoShK600;oShK600Co0000oin?`onOSl?oWho3
0ol00005oj^A^`03o`000?neUkWo]INi00;o]INi0_l00005ok^I]004o`000?o1W;;o`Ibbo`0000?o
`Ibb00?o0000olFN/?o5W[000_o5W[001?l0003oaYn`olJO/?l00003olVQ[`05o`000?o;Xk3obj>`
ol^S/?l000000_o<Y;001ol0003ocjRaolnX/Oo?Z;7o0000olnX/_l000001OoC[K<00ol0003oeK>g
omFc]`02omFc]`07o`000?oJ^k[of[^jomZk^_l0003oe[Zmo`000003omc3`@06o`000?oQc/GohLk5
o`000?oJcLco00000ooOfM001?l0003oh^GEon;UeOoRiMD2o`000006om?^i_l0003oc_GYolkejOl0
003oa_WZ0_l00002okkik0?o000000CoT^Ojo`000?l0003oTN;m4Ol000001Ol0D/ko0000o`000?m7
Rnco000000;o//KY00Ko0000ok;6jOl0003o0000okC<k?l00002on_D_@05o`000?o/ekkok=NnoncG
__l000000_o]fKl01_l0003on/fHoo[=V?l0003on/jJo`0000;on/nL00Co0000ooWAWooidIoo0000
0_oidZ800ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo000:ooooo`03oc8b<_l0
003o000000?o000000Go<S8booooooooooooc<c<oa0@4002o`000003ohN7Qooooooooooo01_ooooo
00?o0000ooooooooool03Oooool00ol0003o>WcTocYli003o`0000;oTZCQ00?o0000ok2bf_n`/]X0
1?n`/]X2o`0000GoblWH00?o0000omC=d_oDcM800_oDcM83o`000003on;Ebol0003ohm3400?ohm34
00Go0000on?;_ooSbkoohl^oo`000004on?6^`05o`000?oQ`KSo0000on?4^Ol000000ooQ_kH00ol0
003og[^domjk]003omjk]0;o00000ooJ^;H01ol0003of;FeomRe]OoH]KGo0000omNc]Ol000000ooA
/;T3o`000004oln_^Ol0003oaZZmo`0000CoaJVn00?o0000okNRa?ngX/@00_l000000ondX/Go0000
oinFbP03oinFbP05o`000?n3QLgoPhG=oh>5cOl000000omQKl/2o`000004odQMaOl0003o;d^no`00
00;o9TBj00Oo0000ob=0^?l0003o0000oba6^_l0003o>djl00;o00000om>GL801?l0003oIF[3ofEZ
`omUJ/<3o`000004ogYkb?l0003oShK6ohn6aPGo00000_nNR[h00ol0003oZi6koj^A^`03oj^A^`07
o`000?neUkWo]INiokFG^Ol0003o]9Bgo`000006ok^I]0;o00001Oo1W;801?l0003oaIj`olFN/?l0
0003olJO/004o`000?o9XJoobJ6_o`0000Cobj>`00?o0000olbT/?l000001?o?Z;400ol0003ocjRb
o`000005om>]/`03o`000?oE/kOoeK>g00;oeK>g00?o0000omZk^_oJ^kX00_oJ^kX00ol0003og<?1
omc3`@02omc3`@05o`000?oQc/GohLk5on7>aOl000000ooOfM001Ol0003oh^GEon;UeOoRiMGo0000
00;oh^oH0_l000001?o>mNWo0000olKij_l00002okkik0;o00000_nimnl5o`0000?oU=Wn00?o0000
of:moOmR_Od00_mR_Od00ol0003o9IC]obFDk@08o`000005odB@kol0003o0000o`000?nba^T00_l0
0004okC<k003o`000?o[e;go000000;ok=Nn00Go0000ongI_oo]fKoo0000ongL`@02o`0000;on/jJ
00Co0000oo[?W?ojcico00000_oidIl01?l0003onM:RooWBX_l0000Booooo`;o00005?ooool000[o
oooo00?oV9RHodA4A?ooool00_ooool02_m4A4CoV9RHoooooooooooo8B4QohN7Qolb<S;oZJVYodA4
A?n7QhLLooooo`03o`000?oooooooooo00kooooo00Co0000ocYli?ljO>Co00001?nBY>401?l0003o
/;;Jok2bf_n`/]X2o`0000;o_;gJ00Go0000ol_9f?o;bMSoblWHo`000004omC=dP04o`000?oJc<_o
f/c;om[<b`;o00001?oSd<@01Ol0003ohl^oon?;_ooSbkoo000000?ohlJk00Go0000on71^?oQ`KSo
hL6ho`000004on6o]P03o`000?oN^kCog[^d00;og[^d00Ko0000omfh/ooM^;?o0000omZh]_l00004
omRe]@03o`000?oG/kGoek>e00Co00001?o?[kT00ol0003oaJVnolFY_P03olFY_P03o`000?ngX/Co
000000Co]:;500?o0000oinFb_nOU/X00_nOU/X01?l0003oPhG=oh>5cOl00003of5_b`05o`000?lo
FLGo0000o`000?l_Bkh00_l000001OlVA;[o0000ob=0^?lS@;So000000;o;4Jj00Co0000oc]>_?l0
003o00000_m>GL801Ol0003oIF[3ofEZ`omUJ/?o000000;oNgO31?l00002ohj1`@03o`000?nNR[ko
WXZn00;oWXZn00?o0000oj^A^on[TK/00on[TK/01?l0003o]INiokFG^Ol00003okBD]`03o`000?nk
VKCo^iVd00?o^iVd00?o0000ol6L/_o1W;801?o1W;801?l0003oaIj`olFN/?l00003olJO/004o`00
0?o9XJoobJ6_o`0000Cobj>`00?o0000olbT/?l000001Oo?Z;400ol0003odjfcom>]/`03om>]/`03
o`000?oG];Go000000;oeK>g00?o0000omZk^_oJ^kX00ooJ^kX01Ol0003og<?1omc3`OoL`l7o0000
00CohLk50_l000000ooOfM3o0000on;Ue@02on;Ue@05o`000?oRkmSoh^oHo`000?oOmmX01Ol00000
0onnnNco0000okWgk`05o`0000;o]^Wf00?o0000oiCIo_nDfOh04_l00003odB@k`?o00001?ndc>`2
o`0000;ok=Nn00Go0000ongI_oo]fKookMVoo`000002ongL`@04o`000?ojcY[on/jJo`0000;on/nL
00?o0000ooWAWol000000_oidZ800ol0003on=>Uo`00000Cooooo`03o`000?oooooooooo017ooooo
000;ooooo`05oa0@4?oMgMgoooooomgMgOl@41000oooool01_l0003oooooofIVI_n7QhOogMgMoa0@
41_ooooo00?o0000ooooooooool04?ooool01?l0003o>WcTocYli?l00004oi:Th@03o`000?n`/][o
000000Go_;gJ00?o0000ol_9f?l000001?oDcM800ol0003of/c;om[<b`02om[<b`06o`000?oMbLGo
0000o`000?oSd<Co00000ooSbkl01Ol0003ohlJkon?6^ooSa[_o000000CohL6h0_l00002on6o]P03
o`000?oN^kCog[^d00?og[^d00Go0000omfh/ooM^;?ogKRco`000004omRe]@03o`000?oG/kGo0000
00;o000000?odK2io`000?o?[kT01?o?[kT00ol0003oaJVnolFY_P04olFY_P03o`000?ndX/Go]:;5
00?o]:;500?o0000oinFb_nOU/X00_nOU/X01Ol0003oPhG=oh>5cOn3QLgo000000?oHFo;00?o0000
ocmIaOl000000_l_Bkh3o`0000;o8d2h0_l000001?l/A[[o0000oc]>_?lkC[`2o`0000;oCUg200Co
0000ofEZ`omUJ/?o00000omkMl<00ol0003oSX71ohj1`@03ohj1`@03o`000?nNR[koWXZn00;oWXZn
00?o0000oj^A^on[TK/00on[TK/2o`0000Co]9Bg00?o0000ok^I]?nkVK@00onkVK@00ol0003o`Ibb
ol6L/P04ol6L/P03o`000?o5W[3o000000GoaYn`0_l00006ol^S/003o`000?o?Z;7ocjRa00CocjRa
00?o0000om>]/ooC[K<00_oC[K<01?l0003oekBeomNd]Ol00002omFc]`03o`000?oJ^k[of[^j00;o
f[^j00Go0000on34_Ol0003og<?1o`000004on7>a@04o`000?oVf/Soi][8o`0000?oh^GE00Ko0000
on;_f?oRkmSo0000omogf_l00002om[lf`03o`000?oCoMco000000Co000000?o]o;co`000?nfjOH0
0onfjOH3o`0000?oUlgj00?o0000ofjfnom^]_/00_m^]_/00ol0003o>IGaocVEl@0;o`000003odB@
kol0003o000000?o00000_nddNl00ol0003ok=Nno`000002ongI_`04o`000?o]g<7okMc1ongL`@?o
00000_ojci`01?l0003onM6OooWAWol00002ooWBXP04o`000?ohdjGon=>Uo`0001;ooooo00?o0000
ooooooooool04Oooool000_ooooo00GoQhN7ogMgMoooooooIVIVohN7Q`03ooooo`06oa0@4?oMgMgo
MgMgogMgMooooooo00006oooool00ol0003oooooooooo`0Aooooo`Co00000_nBY>43o`0000Ko_;gJ
0ol00003omC=dP03o`000?oJc<_of/c;00;of/c;00?o0000omg9aOoMbLD00_oMbLD2o`0000?ohl^o
00Go0000on?6^ooSa[_ohlJko`000003on71^006o`000?oP_KKoh;ffo`000?oQ_kKo00001?oN^k@0
0ol0003ogKRcomfh/`02omfh/`04o`000?oH]KGof;FeomRe]@?o00000ooG/kD00ol0003ocjnioln_
^@03oln_^@03o`000?o>[[Wo000000CoaJVn0_l00005okBRa@04o`000?nOU/[oWiK:oinFbPKo0000
0omQKl/00ol0003o?eW5ocmIa@03o`000003oalo^?l0003o000000;o8d2h0ol00002oc]>_003o`00
0?m?F[ko000000;o00000omUJ/<01Ol0003oNgO3og]g`omkMl?o000000CoSX7100?o0000oij:__nN
R[h00_nNR[h00ol0003oZi6koj^A^`02oj^A^`;o00001OndU;L00ol0003o^iVdok^I]002ok^I]003
o`000?nlV;?o000000Ko`Ibb00?o0000olJO/?o6Wk001?o6Wk000ol0003obj>`ol^S/005ol^S/003
o`000?o?Z;7ocjRa00?ocjRa00?o0000om>]/_l000000_oC[K<01ol0003oekBeomNd]OoG];Go0000
omFc]ol000001?oJ^kX01_l0003oh<Bmon34_Ol0003og<?1o`0000?ohLk500Co0000onKJb?oVf/So
i][80_l000001ooRiMGo0000on;_f?oRkmSo0000omogf_l000000_oJo=/00ol0003odogLo`000002
olomh003o`000?o=n^Ko000000;o000000Co]^Wfo`000?l0003o00000_neg?@00ol0003oUlgjoiO=
nP0Bo`0000;o?Y?a1?l00004okCAk`;o00000oo]fKl01?l0003okMc1ongL`Ol00002oncOa004o`00
0?ojcicon/nLo`0000;onM6O00Co0000ooWBX_oidZ;o00000_ohdjD2o`0001;ooooo00?o0000oooo
ooooool04?ooool000_ooooo00Gok^k^oa0@4?o^k^ko410@onk^kP03ooooo`06ojVYZOm4A4CoV9RH
odA4A?nHV9So410@6oooool3o`0001;ooooo00?o0000ob9bhOl000000_l00002oiZ]i003o`000?nl
_M[o_;gJ00?o_;gJ00Oo0000olK2eoo6`]Ooa/;Go`000?oDcM;o000000Cof/c;00?o0000omg9aOoM
bLD00ooMbLD01Ol0003og/K1o`000?oSbkoo000000?ohlJk00?o0000on71^?oQ`KP00_oQ`KP01Ol0
003oh;ffon2m]_oP_KKo000000Cog[^d00?o0000omfh/ooM^;<00_oM^;<00ol0003ofkJco`000002
o`000003omRe]Ol0003oek>e00?oek>e00?o0000oln_^Oo?[kT00oo?[kT01?l0003ocZjiolj^^Ol0
0002olFY_P04o`000?o4ZKooa:Voo`0000Co]:;51?l00002oibGc@03o`000?mmQ=3oOHC@00?o0000
00KoHFo;o`000?loFLGo?eW5o`000?lTA[d2o`000006oalo^?l0003o0000ob=0^?l0003o:T>h0_l0
0002oc]>_004o`000?m?F[koCeZno`0000?oIF[300Go0000og]g`omkMl?oNgO3o`000004ohj1`@03
o`000?nNR[koWXZn00;oWXZn00?o0000oj^A^on[TK/00_l000000onZSkWo0000okBD]`05okBD]`04
o`000?nkVKCo^iVdo`0000;o_9Rc00?o0000ol6L/_o1W;801?o1W;800ol0003oaYn`olJO/004olJO
/003o`000?o;Xk3obj>`00Cobj>`0_l00004olnX/@04o`000?oC[K;odjfbo`0000;odjfc00?o0000
omNd]OoG];D00_oG];D00ol0003of[^jomZk^P03omZk^P05o`000?oPa;goh<Bmon34_Ol000000ooQ
c/D01Ol0003oi][8onKJb?oVf/So000000;oj^G;0_l000001?oRkmSo0000omogf_l00002om[lf`03
o`000?oCoMco000000;ocogP00?o0000olgji_l000000_o<l^/3o`0000?o]Mcd1?l00003oiZnl@03
o`000?mi[??oNJcc00;oNJcc00?o0000odjDl?m>U?000ol000000ol2Kmgo0000o`000004o`000003
ocjClOl0003o000000;o]=7_0_l000001Once_;o0000ongI_oo]fKoo000000?okMc100Co0000oncO
a?o/glCo00000_ojci`00ol0003onM6Oo`000002ooWBXP04o`000?ohdjGon=>Uo`0000;ommFY00?o
0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`003?ooool00omgMgOo8B4QoeEEE@05
ooooo`05oiRHV?l0003o0000oa0@4?o<c<`06oooool00ol0003oooooooooo`0Cooooo`03o`000?lR
L^7o000000CoVZgT00Go0000okbmf_nl_M[o_;gJo`000005olK2e`03o`000?oJc<_of/c;00;of/c;
00?o0000omg9aOoMbLD00ooMbLD01?l0003og/K1omk6`OoNa/42o`0000?ohlJk00Go0000on71^?oQ
`KSohL6ho`000004on2m]P03o`000?oN^kCog[^d00;og[^d00Co0000omfh/ooM^;?ogKRc0ol00000
1?oK][?o0000omRe]Ol00004omNc]@03o`000?oE/[Go000000?ocjni00Oo0000olj^^Oo>[[WocZji
o`000?o5ZKko000000Coa:Vo00Ko0000okBRaOndX/Go0000ok>Sb?l00005oibGc@05o`000?mmQ=3o
OHC@o`000?mHKLd00ol00002ocmIa@0:o`000?lTA[go0000oalo^?l0003o73bfo`000?lS@;So0000
obY3^0;o000000?o>djlo`000?m?F[h00_m?F[h2o`000003ofEZ`ol0003oNgO300?oNgO300?o0000
ohj1`On>PL400_n>PL400ol0003oWXZnoij:_P02oij:_P;o00001?nZSkT00ol0003o]9BgokBD]`03
okBD]`04o`000?nkVKCo^iVdo`0000;o_9Rc00?o0000ol6L/_o1W;800oo1W;82o`0000GoaYn`00?o
0000olVR/Ol000001?o;Xk001?l0003ocZNaoljW/Ol00003olnX/@06o`000?oC[K;odjfbo`000?oC
[K?o00001OoG];D00ol0003of[^jomZk^P02omZk^P03o`000?oPa;goh<Bm00;oh<Bm0_l000000ooQ
c/Go0000onKJb002onKJb006o`000?oZiL_oj^G;on[Ubol0003ojo3=2Ol000001?o?oN3o0000olgj
i_l00002olcbj`03o`000?o9iN_obNG[00Co00000onbb^`00ol0003oV[kaoiZnl@09o`000003odjD
l?l0003o7gOT00Go00000_lfU?45o`0000Co/mKb00?o0000ongI_ol000000_o]g<401Ol0003ok=o4
oncOa?l0003ojn7700;o00000_oidIl01?l0003onM:RooWBX_l00002ooSCY@04o`000?ogeJWommFY
o`0001;ooooo00?o0000ooooooooool03oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Ooo
ool01?lQ8B7o71`Lo`000?oMgMd2ooooo`06onk^k_lb<S;o0000oc8b<_n^[Zko<S8b0_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`Go00001_oo
ool00ol0003oooooooooo`0Dooooo`?o00001?nJ[N@00ol0003o_;gJo`000005olK2e`03o`000?o=
a=;o000000?of/c;00?o0000omg9aOoMbLD00_oMbLD00ol0003og/K1omk6`@02omk6`@05o`000?oN
`[go0000on?6^ol000000ooQ`KP00ol0003oh;ffon2m]P02on2m]P03o`000?oN^kCo000000;og[^d
00?o0000omfh/ol000000ol00003om^f/`03o`000?oH]KGo000000?oek>e00Oo0000omFb]OoE/[Go
eK:eo`000?o?[kWo000000GocZji00?o0000olBY_oo4ZKl00oo4ZKl00ol0003o]:;5o`000003ok>S
b003o`000?nLUlgoW9O=00;oW9O=00Go0000ogf4d?mmQ=3oOHC@o`000002oeQ]c@;o000000So?eW5
o`000?lTA[go94Jmo`000?lO?kSo0000oa`l]P;o000000Ko:T>ho`000?liC;[o0000oc]>_?l00002
odmJ_P03o`000?mUIl3o000000;o00000omkMl<00ol0003oSX71ohj1`@02ohj1`@04o`000?nNR[ko
WXZnoij:_P;o00001OnZSkT00ol0003o]9BgokBD]`03okBD]`03o`000?nkVKCo000000Co_9Rc00Go
0000ol6L/_o1W;;o`Ibbo`000002ol:M/P05o`000?o6Wk3oaYn`olJO/?l000000_o9X[400ol0003o
bj>`ol^S/002ol^S/004o`000?o>Yk7ocZNao`0000;ocjRa00?o0000om>]/_oC[K800_oC[K800ol0
003oekBeomNd]@03omNd]@03o`000?oM_;So000000?of[^j00Go0000on34_OoPa;goh<Bmo`000002
onK?`005o`000?oVf/Soi][8onKJb?l000000ooZiL/02ol0003ojo3=on_`cOl0003oj?O=o`000?oS
o<go0000omknc_l0003of_kB00Go000000Ooc?;[o`000?o9iN_obNG[o`000?o3dnKo000000Go//[/
0ol00002oi^_iP03o`000?n1X^WoPJ;Y00;oPJ;Y00?o0000of6AjOl000000_l00003oamgi0?o0000
1?lfU?42o`0000Co/mKb0_l00002ongL`@05o`000?o/glCok=o4oncOa?l000000_o[hLL01?l0003o
nM6OooWAWol00002ooWBXP08o`000?ohdjGon=>Uo`000?ogeJWo0000ooGF[Ol0000Booooo`03o`00
0?oooooooooo00kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B402_nYZJWo
ooooooooooooooooMgMgoiRHV?ooooooV9RHogMgMol00002ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006
ooooo`03o`000?oooooooooo01Cooooo00Co0000oaI^gol0003o00000_nJ[N@3o`0000Goa/;G00Oo
0000olg4d_o=a=;ocLCBo`000?oJc<_o000000CogLW500?o0000omk6`OoNa/400_oNa/401Ol0003o
g/:momk2_OoN`[go000000CohL6h00?o0000on2m]_oP_KH00_oP_KH00ol0003og[^domjk]004o`00
00;ogKRc00?o0000om^f/ooK][<00ooK][<00ol0003oek>eomNc]@02omNc]@07o`000?oE/[GoeK:e
omFb]Ol0003ocjnio`000005olj^^@03o`000?o4ZKooa:Vo00Coa:Vo00?o0000ok>Sb?ncXlP00onc
XlP01Ol0003oW9O=oibGcOnLUlgo000000?oOHC@00Go0000oeQ]cOmHKLgo0000oc=EaP02o`0000;o
94Jm00?o0000oalo^?l000000_lL?;H01Ol0003o:T>hobY3^?l0003o>Dbj00;o00000_m?F[h01?l0
003oIFO0ofEW`?mUIl05o`0000CoSX7100Ko0000oij:__l0003o0000oif8_?l00005ojZ?^@03o`00
0?ndU;Oo]9Bg00?o]9Bg0_l00005okbH/`04o`000?o1W;;o`Ibbo`0000?o`Yfb00Co0000olJO/?o6
Wk3o00001?o9X[401?l0003obj>`ol^S/?l00003oljW/@04o`000?o?Z;7ocjRao`0000Codjfb00?o
0000omNd]OoG];D00ooG];D01_l0003ogKbhomfl^?l0003of[^jo`0000?oh<Bm00Co0000onK?`?oV
cl3oi/o00_l000000ooVf/So0000on[Ub`02on[Ub`0>o`000?o[l<gojo3=o`000?oXmlgo0000on?l
cOl0003og_k>o`000?oJo];o0000omWmfOl00002omWgh0?o000000?obNG[o`000?o3dnH00_o3dnH0
0ol0003o//[/o`000002o`000003ojjihOl0003oVjoV00?oVjoV00?o0000oh6RjOn1X^T00_n1X^T0
1?l0003oHI7Yof6AjOmQTNT2o`000003oamgi?l0003o05[B00Go000000?o=YCao`000?l000000ol0
0002ok3Jm@03o`000?o]g<7o000000;ok=o400Co0000on_Qaoo[hLOojn770ol00002ooWBXP04o`00
0?ohdjGon=>Uo`0000;ommFY00Co0000ooGF[OoeeZgo00004?ooool2o`0000[ooooo1?l00001oa0@
407ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00Cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0Fooooo`03o`000?lF
K]oo5VkO00;o00000onT]>@01Ol0003oa/;GolK2eoo6`]Oo000000GocLCB0_l00004omg9a@05o`00
0?oNa/7og/K1omk6`Ol000001?oN`[d2o`0000;ohL6h00?o0000on2m]_oP_KH00_oP_KH00ol0003o
g[^do`000003o`0000CogKRc00?o0000om^f/ooK][<00ooK][<01Ol0003oek>eomNc]OoG/kGo0000
00GoeK:e00?o0000olj^^Oo>[[T00oo>[[T00ol0003ocZjjo`000004olBY_`;o00001OncXlP00ol0
003oW9O=oibGc@02oibGc@04o`000?mmQ=3oOHC@o`0000?oF6g=00Go0000oc=Ea_l0003o0000obA6
_@02o`000007oalo^?l0003o73bfoa`l]_l0003o:T>ho`000002ocU<^P05o`000?m?F[koCeZnodmJ
__l000000_mUIl001?l0003oNgBoog]d_omkM;l7o`0000CoWHRl00?o0000ojZ?^OnZSkT00onZSkT0
1ol0003o]9BgokBD]ondU;Oo0000okBD]_l000001OnlV;<00ol0003o`Ibbo`000004ol:M/P04o`00
0?o6Wk3oaYn`o`0000CobJ:a00Co0000ol^S/?o;Xk3o00001?o>Yk42o`0000Codjfb00?o0000omRd
]?l000000ooG];D00ol0003ogKbhomfl^002omfl^005o`000?oPa;goh<Bmon34_Ol000000ooVcl00
0ol0003ojm_3on_K``02o`0000?oj^G;00go0000on_`cOl0003oj?O=o`000?oSo<go0000omknc_l0
003of_kBo`000?oIoMWo000000;ofOOP00?o0000omK[hooFjn<00_l00004ol?CiP;o00001On^^N40
0ol0003oVjoVoi^_iP09o`000003of6AjOl0003o>gcT00?o00000_l0F]800ol0003o:Y?_obZCk`03
o`0000Go/=[e0_l00002oncOa005o`000?o[hLOojn77on_Qaol000000_oYhl/01?l0003onM:RooWB
X_l00002ooSCY@04o`000?ogeJWommFYo`0000;omMJ]00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo007ooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?oV9RHob4Q8Oo^k^h01Oooool3
o`0001Oooooo00Co0000oaI^golFK]oo00001?nT]>@00ol0003oa/;Go`000006olg4dP06o`000?oB
a<go0000o`000?oMbLGo00001?oNa/401Ol0003og/:momk2_OoN`[go000000;og[nj00?o0000on71
^?l000000ooP_KH3o`0000?og[^d0_l00002omfh/`03o`000?oK][?ofkJc00?ofkJc00?o0000omZd
/ol000000_oG/kD00ol0003oeK:eomFb]@03omFb]@03o`000?o>[[WocZji00;ocZji00Go0000olj^
^_o>[[[ocZjjo`000002olBY_`04o`000?o3Zl;o`j_2o`0000Co/j?82ol000001OmHKLgo0000oc=E
a_lcELKo000000;o94Jm0ol00002oa`l]P03o`000?lZ@kSo000000?o>Dbj0_l000000om?F[ko0000
ofEW`002ofEW`005o`000?mkM;ooNgBoog]d_ol000001?n>O[h00ol0003oWHRloif8_002oif8_003
o`000?nZSkWoZXni00?oZXni00Co0000okBD]ondU;Oo00000_ndU;H00ol0003o_9RcokbH/`04okbH
/`03o`000?o2WK;o`Yfb00Co`Yfb0_l00005olVR/@03o`000?o;Xk3o000000GocZNa00?o0000om>]
/_oC[K800ooC[K801_l0003of;BdomRd]?l0003oekBeo`0000GogKbh00Go0000on34_OoPa;goh<Bm
o`000003onK?`00Do`000?o[fl?ojm_3o`000?o_i/Co0000on[Ubol0003ojo3=o`000?oXmlgo0000
on?lcOl0003og_k>o`000?oJo];o0000omWmfOl00002omWgh004o`000?oFjn?oe^_So`0000;od=[Q
00Ko0000ol?Ci_l0003o0000okg1gOl00005ojjih@?o00000_nKXmX00ol0003oR9WMohRIg@02ohRI
g@03o`000?m_SMoo000000;o00000olkO>@2o`000003o`1Jd_l0003o000000;o000000?o:Y?_o`00
0?n`f_D00ol00002ojcLn003o`000?o/glCo000000;ojn7700Co0000onWSbooYhl_ojN?;0_l00000
1?oidZ;o0000ooSCYOl00002ooOEZ@06o`000?oeeZgomMJ]o`000?ocek;o00004_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo007ooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00?oMgMgofIVI_ooool01?ooool0
0ol0003oooooooooo`0Hooooo`Co00000_nT]>@4o`0000GocLCB00?o0000om;4cOoBa<d00_oBa<d0
0ol0003og/K1omk6`@02omk6`@05o`000?oN`[gog/:momk2_Ol000001?oN_kX00ol0003oh;ffon2m
]P03o`0000Cog[^d00Ko0000omfh/ooM^;?o0000omfh/ol00004om^f/`06o`000?oJ];?of[Bco`00
0?oG/kGo00001OoE/[D00ol0003oe;6fo`000002olj^^@03o`000?o>[[[ocZjj00;ocZjj00?o0000
olBY_ol000001?o3Zl801_l0003o/j?8ok>Sb?l0003o/ZK;o`0000?oVYWB00Ko0000ogN5e?mgQMCo
MhGDo`000?m=K=43o`000007oc=Ea_l0003o0000obA6_Ol0003o53Zgo`000002oa`l]P;o000000Ko
:T>ho`000?liC;[o>Dbjo`000?m>F;d2o`0000?oIFO000?o0000og]d_omkM;l00_mkM;l01Ol0003o
SWjnohin__n>O[ko000000CoWHRl00?o0000ojZ?^OnZSkT00onZSkT00ol0003o]9Bgo`000004okBD
]P03o`000?nlV;?o_9Rc00?o_9Rc00?o0000ol:M/_o2WK801?o2WK800ol0003obJ:aolVR/@05olVR
/@03o`000?o>Yk7ocZNa00CocZNa00?o0000om>]/_oC[K800_oC[K801ol0003of;BdomRd]?oH];Co
0000omNd]Ol000001?oM_;P01Ol0003ohlFjo`000?oPa;go000000?oi/o000Co0000on_K`oo[fl?o
00000oo_i/@>o`000005omWgh?l0003oe^_SomK[hol000000oo@f^42o`0000Co_L7M00?o0000ojji
hOl000000_l000000on[ZmOo0000oi^SfP03oi^SfP03o`000?n8VMgoR9WM00;oR9WM00Co0000ofn=
gom_SMooKhgO0_l000000olkO>Co0000oaEVfP08o`0000Go[=ch0_l00003on_Qa`04o`000?oYhl_o
jN?;o`0000;oinG?00Co0000ooSCYOohdjGo00000_ogeJT01?l0003omMJ]ooGF[Ol00002oo?G/P03
o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4007
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06Oooool00ol0003o4VkOo`000002
o`0000Co[KWR00Go0000olg4d_o=a=;ocLCBo`000004om;4c@03o`000?oD`/So000000?og/K100Go
0000omk2_OoN`[gog/:mo`000004omjo^P?o000000?oh;ffo`000?oN^k@01?oN^k@01Ol0003ogKRc
omfh/ooM^;?o000000GofkJc00Go0000omZd/ooJ];?of[Bco`000005omFb]@04o`000?oD/KKoe;6f
o`0000;ocZji00?o0000olj^^_o>[[X00oo>[[X00ol0003o`j_2ol>[`P03ol>[`P03o`000?ncXlSo
000000?o/ZK;00Go0000oiZId_nJVM;oVYWBo`000003ogN5e004o`000?m=K=7oCFcAo`0000;o<eG6
0ol00002oa@j]`03o`000?lL?;Ko73bf00?o00000_liC;X00ol0003oCURmodiH_@02o`0000;oIFO0
00?o0000og]d_omkM;l00_mkM;l00ol0003oSWjnohin_P02ohin_P03o`000?nMR;coWHRl00;oWHRl
00?o0000ojZ?^OnZSkT00_nZSkT2o`0000Go]9Bf00?o0000okbH/onlV;<00_nlV;<00ol0003o_IZd
o`000005ol:M/P03o`000?o9X[7obJ:a00GobJ:a00?o0000oljW/Oo>Yk400oo>Yk400ol0003odZfc
o`000003om>]/P03o`000?oH];Cof;Bd00;of;Bd00?o0000omfl^?oM_;P00_oM_;P01Ol0003ohlFj
on?5^_oSaK[o000000Coi/o000Co0000on_K`oo[fl?o00000oo_i/@03_l0003oko35o`000?o]mlCo
0000onSk`_l0003oh_g2o`000?oOo/Ko0000omknc_l0003ogo[G0_l000001?oFjn?o0000om3JhOo@
f^42o`000003olO7f_l0003o_L7M00?o_L7M0_l00005oj^[e`05o`000?nKXm[oVj?Joi^Sf_l00000
1?n8VMd01_l0003oKhgOofn=gom_SMoo0000oe9ng`?o00000_lEI]X01?l0003o04C1o`000?l?RN@3
o`000004ojcLn?l0003o0000o`0000;oY=gk00?o0000on_Qaol000000_oYhl/01?l0003oinG?onOU
cooWiLl2o`000004ooSCYOl0003ommFYo`0000;omMJ]00Go0000oo?G/_ocek;olmNbo`00000Boooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00Oooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg2oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Ol0003o^[ZjoooooonHV9So410@
00Gooooo00?o0000ooooooooool06_ooool00ol0003o4VkOo`000006ojfihP03o`000?o=a=;o0000
00Cod/C=00Oo0000omC2b?oD`/Soe<;8o`000?oNa/7o000000?og/:m00?o0000omjo^_oN_kX00ol0
0002omfl^003o`000?oP_KKo000000Cog[^d00?o0000omfh/ooM^;<00_oM^;<00ol0003ofkJcom^f
/`02om^f/`03o`000?oJ];?of[Bc00;of[Bc00?o0000omFb]OoE/[D00_oE/[D01ol0003oe;6fomBa
]_oD/KKo0000olj^^Ol000001_o>[[X00ol0003o`j_2ol>[`P03ol>[`P;o00001OnbY//01Ol0003o
VYWBoiZId_nJVM;o000000?oMhGD00?o0000ode/dOm=K=400ol000001?lF@;co0000o`000?lD>[L2
o`000004oa`l]_l0003o93ngo`0000?o>Dbj00?o0000odiH_Om>F;d00_l00002ofEW`005o`000?mk
M;ooNgBoog]d_ol000001?n>O[h00ol0003oWHRloif8_002oif8_003o`000?nZSkWoZXni00;o0000
00?oZXjio`000?ndU;H01?ndU;H01Ol0003o_9RcokbH/onlV;?o000000;o_IZd00?o0000ol:M/_o2
WK800_o2WK800ol0003oaInco`000005olVR/@;o00001?o>Yk401?l0003odZfcom:]/ol00003om>]
/P03o`000?oH];Cof;Bd00;of;Bd00?o0000omfl^?oM_;P00_oM_;P01?l0003ohlFjon?5^_oSaKX2
o`0000;oi/o000Co0000on_K`oo[fl?o00000oo_i/@03ol0003oko35o`000?o]mlCo0000onSk`_l0
003oh_g2o`000?oOo/Ko0000omknc_l0003ogo[Go`000002omk`g@;o000000?od=[Qo`000?o7amX0
0oo7amX01_l0003o_L7Mo`000?l0003o][7Do`0000GoZj_G00?o0000oi^Sf_nKXmX03?l00003oe9n
g`;o000000?o5FKJo`000?l000001_l00003ojCMn`?o00000ooYhl/01?l0003oinG?onOUcol00002
on?Ve004o`000?ogeJWommFYo`0000;omMJ]00Ko0000oo?G/_ocek;o0000oo7H]ol0000@ooooo`?o
00002?ooool00ol0003oooooooooo`01ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003o
ooooooooo`0Kooooo`?o00001On]^N83o`0000?od/C=00?o0000omC2b?oD`/P00ooD`/P2o`0000?o
g/:m0ol000000ooN_k[o0000omfl^003omfl^003o`000?oN^kCog[^d00;og[^d00?o0000omfh/ooM
^;<00_oM^;<00ol0003og;Nco`000003om^f/`07o`000?oJ];?of[BcomZd/ol0003ofKBco`000003
omFb]@03o`000?oD/KKoe;6f00;oe;6f00?o0000olj^^_o>[[X01?o>[[X00ol0003oc[2lo`000003
ol>[`P03o`000?o3[LCo000000Go/ZK;00Go0000oiZId_nJVM;oVYWBo`000003ogN5e005o`000?m=
K=7oCFcAo`000?lRClL00_l000001?lF@;co0000o`000?lD>[L3o`0000;o93ng00Co0000ocU<^_li
C;[o00000_m>F;d00ol0003oI6Fno`000002o`0000CoNgBo00Go0000ohin__n>O[koSWjno`000004
oif8_003o`000?nZSkWo000000?oZXji00?o0000okBD]_ndU;H00ondU;H01?l0003o_9RcokbH/ol0
0003okfJ]003o`000?o2WK;o`Yfb00;o`Yfb00?o0000olFO/ol000001?o9X[401?l0003oc:JbolbV
/_l00003oljW/@07o`000?oB[K?odZfcom:]/ol0003odjfbo`000004omRd]003o`000?oM_;Oo0000
00;ogKbh00Go0000on?5^_oSaK[ohlFjo`000002onS@_@05o`000?oVcl3o0000on_K`ol000000oo_
i/@03ol0003oko35o`000?o]mlCo0000onSk`_l0003oh_g2o`000?oOo/Ko0000omknc_l0003ogo[G
o`000002omk`g@04o`000?oHh=gof>3Mo`0000GoalOJ0_l00004okJae004o`000?n[ZmOoZj_Goj^[
e`Co00000_nLVM000ol0003oSI;CohfBd`02ohfBd`04o`000?mjRMOoNXWGogZ9e`?o000000?oDWkO
o`000?lcKm`03?l00003oi_Mo@03o`000?oYhl_o000000;oinG?00Co0000on?Ve?oSi]CohnKD0_l0
00001OogeJWo0000ooGF[OoeeZgo000000;olmNb00Co0000oo7H]ooaf;Oo00003?ooool4o`000003
ooooool0003ooooo00Oooooo00?o0000ooooooooool00Oooool003;ooooo0ol0000Mooooo`?o0000
00Co[KWRo`000?l0003o00000ond_=l00ol0003od/C=o`000005omC2b003o`000?oF`<Goe/3500?o
00001?oN_kX00ol0003ogKbhomfl^002omfl^003o`000?oN^kCog[^d00;og[^d00?o0000omfh/ooM
^;<00_oM^;<01_l0003og;Ncombg/ol0003ofkJco`0000Cof[Bc00Ko0000omVd/ooI];?o0000omFb
]Ol00005omBa]P03o`000?o>[[[ocZjj00?ocZjj00Co0000olj`_?o>/;co00000_o3Zl801Ol0003o
`jg4ol>]a?o3[LCo000000Co/ZK;2ol000001om=K=7o0000ob9?aol0003o5T2lo`000?l4<kD00_l0
00001?lA=[Co0000o`000?lT?kL2o`000003ocU<^_l0003oCURm00;oCURm00Co0000ofAU__mTIKko
00001?mkM;l00ol0003oSWjnohin_P02ohin_P03o`000?nMR;coWHRl00?o00001OnZS[T00ol0003o
]9BfokBD]P03okBD]P;o00001OnmV[@01?l0003o`Yfbol:M/_l00003olFO/`04o`000?o9X[7obJ:a
o`0000?oc:Jb00Co0000oljW/Oo>Yk7o00001?oB[K<00ol0003odjfbo`000004omRd]003o`000?oM
_;Oo000000;ogKbh00Go0000on?5^_oSaK[ohlFjo`000003onS@_@;o000000Oojm_3o`000?o_i/Co
knK4o`000?o_l<Go000000;okOO400[o0000onSk`_l0003o0000omona_l0003og_k>o`000?oOn]Oo
00000_oNl=d00ol0003of>3MomSPg@02o`0000?oalOJ0_l000000ono]]7o0000okJae003okJae0Co
00000_nWWlh00ol0003oW9W@oibId002oibId003o`000?n=T]?oSI;C00;oSI;C00Ko0000ogZ9eomj
RMOoNXWGo`000?mTOmT3o`0000?o<foL2?l00003oi_Mo@Co000000?oinG?o`000?oSi]@00_oSi]@0
1?l0003ognOIomoWfOl00002ooGF[@04o`000?ocek;olmNbo`0000?olMRg00?o0000ooooooooool0
1oooool3o`0000Gooooo00?o0000ooooooooool01?ooool00omEEEGoIVIVo`000003ooooo`00<_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?lAKmoo000000Ko];cO0_l00005omC2b0Co000000?o
e/35o`000?oN_kX00ooN_kX00ol0003ogKbhomfl^002omfl^003o`000?oL^[Oo000000;og[^d00?o
0000omfh/ooM^;<00_oM^;<00ol0003og;Ncombg/`02ombg/`03o`000?oJ];?of[Bc00;of[Bc00?o
0000omVd/ooI];<00_oI];<00ol0003oe;6fomBa]P03omBa]P03o`000?oD/[Oo000000?ocZjj00Oo
0000olj`_?o>/;coc[2lo`000?o3Zl;o000000Co`jg400?o0000ok:Vbol000000_l000000onbZ]3o
0000oiNMf002oiNMf006o`000?m_Qm_oKhOKofn7fol0003o?FWE0_l00002ob9?a`04o`000?lF@;co
0000o`@c]@;o000000Co4CJdo`000?lT?kOo93ng0ol00003odiH_@04o`000?mTIKkoI6FnofAU_PGo
00000_n>O[h5o`0000;oWHNk00?o0000ojZ>^OnZS[T00onZS[T00ol0003o]9BfokBD]P02okBD]P;o
00001_nmV[@00ol0003o`Yfbo`000004olFO/`04o`000?o9X[7obJ:ao`0000?oc:Jb00Co0000oljW
/Oo>Yk7o00001OoB[K<00ol0003of;BdomRd]002omRd]006o`000?oM_;OogKbgo`000?oM_;So0000
0ooSaKX00ol0003oj=2monS@_@02onS@_@08o`000?o^g;oo0000o`000?o_i/Co0000ono`aOl00002
ongga003o`000?oXnl;o000000So000000Gog_3Mo`000?oHh=gof>3Mo`000002olo=e`03o`000?o7
am[o000000Co_kKA00Ko0000okJae?nf/MCo0000ok6Tbol00005ojNOcP03o`000?nLVM3oW9W@00;o
W9W@00Go0000ohfBdon=T]?oSI;Co`000004ogZ9e`04o`000?mTOmWoI7oIofAof@;o000000?o<foL
o`000?lGH]L01?l000000ol0MM?o0000o`000002o`0000;oTM[o0ol00003on?Ve008o`000?oOimWo
gnOIo`000?oJi]go0000ooGF[Ol00002oo?G/P06o`000?oaf;OolMRgo`000?o^f;_o00001?ooool4
o`0000Sooooo00?o0000ooooooooool02_ooool003;ooooo00?o0000ooooooooool07oooool3o`00
00?o];cO0_l00002okZlg003o`000?oD`/Soe<;800?o00001?oF`<D2o`0000?og[nj00?o0000omfl
^?oM_;P00_oM_;P01_l0003og;Zgombj]ol0003og[^do`0000?ogKRc00?o0000ombg/ooL]k<00ooL
]k<01Ol0003of[BcomZd/ooJ];?o000000GofKBc00?o0000omBa]_oD/KH00ooD/KH01_l0003oe;:g
omBb]ol0003ocZjjo`0000Goc[2l00?o0000ol>]a?o3[L@01?o3[L@00ol0003o/Z[@ok:Zd003ok:Z
d005o`000?nGWMSoUigHoiNMf?l000000om_Qm/00ol0003o?FWEo`000002ob9?a`?o00000_l4<kD0
1ol0003o4CJdo`000?l0003o93ngo`000?ldBKX00_l00002odiH_@05o`000?mTIKkoI6FnofAU__l0
00000omjL[l3o`0000;oSGjm00?o0000oif7^onMQk/00onMQk/00ol0003oZXjiojZ>^@02ojZ>^@07
o`000?ndU;Ko]9BfokBD]_l0003o]IFgo`000006okfJ]003o`000?o2WK;o000000CoaInc00?o0000
olVR/Ol000001Oo<Y[82o`0000KodZfc00Go0000omRd]?oH];Cof;Bdo`000004omfl]`03o`000?oS
aK[ohlFj00;ohlFj00Go0000onS@_OoXd;goj=2mo`000002onkL_`03o`000?oail3o000000Oo0000
00Soh_bho`000?l0003ogok4o`000?oQo<oo0000on;df0?o000000?of>3Mo`000?o?cML00oo?cML0
0ol0003o_kKAoknfd@03oknfd@03o`000?nf/MCo000000?o/JC;00?o0000ojNOc_nWWlh00_nWWlh0
0ol0003oW9W@oibId002oibId005o`000?n=T]?oSI;CohfBdol000001?mjRML01_l0003oI7oIofAo
fOmTOmWo0000odaefP?o000000?o5f;Go`000?l0C<T00ol00002o`1ed`?o00000on7e_l00ol0003o
hnKDo`000002omoWf@03o`000?oJi]gof^KM00;o00000_ocek801Ol0003olMRgoo7H]ooaf;Oo0000
00;ok]Rk1?l0000<ooooo`03o`000?oooooooooo00[ooooo000booooo`03o`000?oooooooooo023o
oooo0ol000000ond_=oo0000okZlg003okZlg0Co00001OoF`<D01_l0003oe[k2omJn`_l0003og[nj
o`0000CogKbh00?o0000ombj]ooL^[L00_oL^[L00ol0003ogKRcomfh/`02omfh/`03o`000?oL]k?o
g;Nc00;og;Nc00?o0000om^f/ol000000_oJ];<00ol0003ofKBcomVd/`02omVd/`03o`000?oH/kCo
000000?oe;6f00?o0000omBb]ooD/[L00_oD/[L00ol0003oc[2lolj`_004olj`_003o`000?o3[LCo
`jg400?o`jg40_l00005ok:Zd005o`000?nGWMSoUigHoiNMf?l000001?m_Qm/01Ol0003o?FWEo`00
0?l0003o8To700?o00000_l4<kD01ol0003o4CJdo`000?l0003o93ngo`000?ldBKX00_l00002odiH
_@04o`000?mTIKkoI6Fno`0000CoNW:o00?o0000ohen_On=O[d00_n=O[d00ol0003oWHNkoif7^`02
oif7^`03o`000?nZS[WoZXji00;oZXji00Co0000okBD]_ndU;Ko00000oneUKL00ol0003o_IZdokfJ
]004okfJ]003o`000?o5Wk?oaInc00CoaInc00?o0000olbV/_o<Y[801?o<Y[800ol0003odZfcom:]
/`04om:]/`03o`000?oG];Go000000;of;Bd00?o0000omfl]ooM_;L00_oM_;L2o`0000;ohlFj00Go
0000onS@_OoXd;goj=2mo`000002onkL_`06o`000?oail3olNO0o`000?oalKoo00000_o^n;d00ol0
003oj?^jo`000002o`000006omona?l0003ohOc?o`000?oRm=So00000ooMiMX00ol0003oclgGolo=
e`02olo=e`;o00001Ono]]42o`0000Co/JC;00?o0000ojNOc_nWWlh00_nWWlhAo`0000;oI7oI00Co
0000odaef_m<MM[oC7GJ0ol000000ol0C<Wo0000o`000003o`0000?oQmKo1?l00002omoWf@04o`00
0?oJi]gof^KMo`0000;oeNCR00?o0000oo?G/_l000000_oaf;L01?l0003ok]RkonkH^oo^f;/2o`00
00oooooo00?o0000ooooooooool02Oooool003;ooooo00?o0000ooooooooool08Oooool00ol0003o
4VoOo`000003okZlg0;o000000?o^[cLo`000?l000001OoF`<D00ol0003oe[k2omJn`P02omJn`P03
o`000?oM_;SogKbh00;ogKbh00?o0000ombj]ooL^[L00ooL^[L2o`0000;ogKRc00?o0000ombg/ooL
]k<00ooL]k<01Ol0003ofkJco`000?oJ];?o000000GofKBc00Ko0000omRc]?oH/kCo0000omBa]_l0
0005omBb]`03o`000?o>/;coc[2l00?oc[2l00?o0000oljb__l000000oo3[L@01?l0003oa;78olBa
b?l00004ok:Zd003o`000?nGWMSoUigH00Oo000000?o?FWEo`000?l<BLL00_l000002?l1>;_o0000
o`@c]Ol4<kGo0000oa4f]?l0003o6C^f0_l000000oldBK[o0000odUF_@03o`0000?oI6Fn00Go0000
ogYb_omjL[ooNW:oo`000004ohen_@03o`000?nMQk_oWHNk00;oWHNk00?o0000ojZ>^OnZS[T00onZ
S[T2o`0000Co]IFg00?o0000okfJ]?nmV[@00onmV[@2o`0000KoaInc00?o0000olbV/_o<Y[801?o<
Y[800ol0003odZfcom:]/`03om:]/`06o`000?oG];GoekBeo`000?oH];Co00001?oM_;L01_l0003o
i<JjonC6^_l0003ohlFjo`0000;oj=2m00Co0000onkL_oo^g;oo00000_oail000ol0003olO6oo`00
0002onkh_@03o`000?oXnk[o000000;o000000Kogok4o`000?oQo<oo0000on;df?l00003omgUfP;o
00000oo?cML01?l0003oa[_@olJkd?l00002oknfd@;o000000?o^:W9o`000?naY</00onaY</00ol0
003oYio>o`000002o`000003ojFGa_l0003oW9;900?oW9;900Go0000oi6=c?nASLcoTHg<o`000004
oh>7c`03o`000?mbP=;o000000;o00000om<MMX00ol0003o=FcJo`000009o`0000?oOM3o00?o0000
omoWfOl000000_oJi]d01?l0003oeNCRomGTh_oEi>82o`0000;olMRg00Go0000onkH^oo^f;_ok]Rk
o`000002oncH_`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool003;ooooo0_l0
000Sooooo`03o`000?lBKmoo000000;o000000Go^[cLo`000?l0003o_KcIo`000004omK0a@03o`00
0?oF_/;oe[k200?oe[k200?o0000omfl^?oM_;P00_oM_;P00ol0003og;Zgombj]`02ombj]`06o`00
0?oK^KKofkVfo`000?oM^;?o00001?oL]k<01_l0003ofkJcom^f/ol0003of[Bco`0000CofKBc00Oo
0000omRc]?oH/kCof;>do`000?oD/KKo000000Coe;:g00?o0000omBc^?l000000oo>/;`01ol0003o
c[:noljb__o>/[ko0000ol>]a?l000001?o4/LP01?l0003o/Z[@ok:Zd?nbZ]03o`0000;oTj?O00Co
0000ofF;h_mURn;oIH_R1?l000001_l<BLOo0000o`4h^ol1>;_o0000o`@c]@;o000000Co4CJdo`00
0?lI>kKo00000_ldBKX01?l0003oBEJmodUF_Ol00003ofAU_P03o`000?mjL[ooNW:o00;oNW:o00Go
0000ohen_On=O[goSGjmo`000005oif7^`04o`000?nZS[WoZXjiojZ>^@;o00001_neUKL01ol0003o
_IZdokfJ]?nmV[Co0000oknL]Ol000001Oo5Wk<00ol0003ob:Bdo`000004olbV/P03o`000?o@[;Co
000000?odZfc00Oo0000omNd]OoG];GoekBeo`000?oH];Co000000CogKbg00Go0000onC6^_oTa[[o
i<Jjo`000003onS@_@04o`000?o^g;ook]boo`0000;olNO000Ko0000oo7a_ol0003ok_Rmo`000?oX
nkX3o`000006omona?l0003ohOc?o`000?oRm=So00000ooMiMX01_l0003oeM;GomGBeol0003oclgG
o`0000?oa[_@00?o0000oknfdOl000001?nhZLT01?l0003o/JC;ok6TbonaY</2o`0000GoYIO600?o
0000oibBbOnLT/T00_nLT/T01Ol0003oTHg<oi6=c?nASLco000000CoPhO?00Co0000og:0d_mbP=;o
LX3B0_l00002odaefP03o`000?leK=[o=FcJ00ko000000?of^KMo`000?oEi>800_oEi>801_l0003o
cn;UoloRiOl0003olMRgo`0000;ok]Rk00Go0000oncH_oo/f;ook=Roo`00000>ooooo`03o`000?oo
oooooooo00Wooooo000aooooo`03o`000?oooooooooo02;ooooo1Ol000000onj_=co0000okflf@03
okflf@05o`000?oF`<Goe/35omK0aOl000001?oF_/800ol0003oe[c0o`000002omfl^003o`000?oL
^[Oog;Zg00;og;Zg00?o0000om^i]_oK^KH00_oK^KH00ol0003og;Ncombg/`02ombg/`03o`000?oK
][?ofkJc00;ofkJc00?o0000omVd/ooI];<00_oI];<00ol0003of;>domRc]003omRc]003o`000?oD
/[Ooe;:g00;oe;:g00Go0000omBc^?oD/kSoe;>ho`000002olj`_003o`000?o>/[koc[:n00;oc[:n
00?o0000olBab?o4/LP00oo4/LP01?l0003o/Z[@o`000?l00002ok:`eP05o`000?nCXmooTj?Ooi>S
gol000000omURn802?l0003o:FOIo`000?l0003o34W7o`000?l1>;_o00000_l4<kD3o`0000;o6C^f
00?o0000ocA9^_l000000om9E[d2o`000003ofAU__l0003oNW:o00?oNW:o00?o0000ohen_On=O[d0
0_n=O[d00ol0003oWHNkoif7^`02oif7^`06o`000?nZS[WoZXjio`000?n[SkWo00001_neUKL01?l0
003o_IZdokfJ]?l00003oknL]@05o`000?o5Wk?oaIncolFO/ol000000_o8Y;@00ol0003oc:JbolbV
/P02olbV/P04o`000?o@[;Cod:bdo`0000;odZfc00?o0000omNd]OoG];D00_oG];D00ol0003ogKbg
omfl]`02omfl]`03o`000?oTa[[oi<Jj00;oi<Jj0_l000001OoXd;go0000onkL_oo^g;oo000000;o
lNO000Ko0000oo7a_ol0003ok_Rmo`000?oXnkX;o`000003omgUf_l0003oeM;G00;oeM;G0_l00004
olJkd0;o00001OnhZLT01_l0003o/JC;o`000?l0003o[I_4o`0000GoYIO600?o0000oibBbOnLT/T0
0_nLT/T01Ol0003oTHg<oi6=c?nASLco000000CoPhO?00Ko0000og:0d_mbP=;oLX3Bo`000?mPN]D3
o`0000?o=FcJ2?l00003ogK:o`?o00000ooEi>801?l0003ocn;UoloRiOo?h^D2o`0000;ok]Rk00Oo
0000oncH_oo/f;ook=Roo`000?oXel?o000000gooooo00?o0000ooooooooool02Oooool0037ooooo
00?o0000ooooooooool07oooool3o`0000?ooooo00?o0000oa1^gol000001_nm_=T00ol0003oe/35
o`000004omJn`P07o`000?oF_<3oe[c0omJl`?l0003ogKbho`000004ombj]`03o`000?oK^KKofkVf
00;ofkVf00?o0000ombg/ooL]k<00_oL]k<00ol0003ofkJcom^f/`02om^f/`03o`000?oI];?ofKBc
00;ofKBc00?o0000omRc]?oH/k@00ooH/k@01Ol0003oe;:gomBb]ooD/[Oo000000Coe;>h00?o0000
olj`_?l000001Oo>/[h00ol0003oa;78olBab003olBab0;o00001Onb/=H01Ol0003oTj?Ooi>SgonC
Xmoo000000?oIH_R00?o0000obUWfOlYImT00ol000001_l1>;_o0000o`@c]Ol0003o02nco`0000;o
6C^f0_l000001_ldBK[o0000odUF_Om9E[go0000of5T_`?o00000omjL[l00ol0003oSGjmohen_@02
ohen_@03o`000?nMQk_oWHNk00;oWHNk00?o0000ojZ>^Ol000000on[SkT00ol0003o]IFgokFE]`03
okFE]`03o`000?nmV[Co000000Co_ibe00Co0000olFO/oo5Wk?o00001?o8Y;@01?l0003oc:JbolbV
/_l00003om2/]003o`000?oB[K?o000000GoekBe00?o0000omfl]ooM_;L00_oM_;L01Ol0003oi<Jj
onC6^_oTa[[o000000;oj]:m00Wo0000onkL_oo^g;ook]boo`000?oail3o0000oo7a_ol000000_o^
n;d3o`000003omSk/_l0003of_fk00;o00000_oSnM@01?l0003oh>_Ion3[fOl00003omGBe`03o`00
0?o;`=3o000000?oa[_@00?o0000okj]bOl000001OnhZLT2o`0000Co[I_400?o0000ojFGa_nUUlH0
0_nUUlH00ol0003oW9;9oibBb@02oibBb@05o`000?nASLcoTHg<oi6=c?l000001?n3Qll00ol0003o
LX3Bog:0dP02og:0dP04o`000?mPN]GoH7[Eof1je@;o000000?o=FcJo`000?lUJMX02Ol00003og75
o`03o`000?oEi>;o000000?ocn;U00?o0000ol[Niol000000_o^f;/01?l0003ok=RooncH_ol00002
onSG``03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool0037ooooo00?o0000oooo
ooooool07?ooool3o`0000Oooooo00?o0000oa1^gol000001Onm_=T2o`0000Coe[k200?o0000omJl
`?oF_<000ooF_<000ol0003og;Zgombj]`02ombj]`03o`000?oK^KKofkVf00;ofkVf00?o0000omZh
]_l000000_oL]k<00ol0003ofkJcom^f/`02om^f/`03o`000?oJ]K?o000000;ofKBc00?o0000omRc
]?oH/k@00ooH/k@00ol0003of;Beo`000002omBb]`03o`000?oD/kSoe;>h00?oe;>h00?o0000oljb
__o>/[h00oo>/[h00ol0003ockK1o`000002olBab0;o000000?oaKO<o`000?nb/=H01?nb/=H9o`00
00;o:FOI1ol00002o`0_/`04o`000?lI>kKo0000ob]5^P;o00000_m9E[d01?l0003oHFBoof5T_omQ
I;l2o`0000;oNW:o00?o0000ohen_On=O[d00_n=O[d01?l0003oWHNkoif7^onMQk/3o`0000CoZhni
00?o0000okFE]oneUKL01?neUKL00ol0003o_ibeoknL]@03oknL]@04o`000?o5Wk?oaInco`0000Co
b:Bd00?o0000olbV/_l000001Oo@[;@00ol0003oekBeomNd]@03omNd]@03o`000?oM_KSo000000;o
gKbg00Go0000onC6^_oTa[[oi<Jjo`000003on[B_@;o000000Sok]boo`000?oail3olNO0o`000?oa
lKoo0000onkh_@;o000000Cog?Z_o`000?l0003of_fk0_l00002on?ie008o`000?oPjmWoh>_Io`00
0?oHf=Oo0000omGBeol00003ol_0d003o`000?o6^m3o000000?o_Zg900Oo0000okRYbOnhZLWo^:W9
o`000?ncW/?o000000Go[I_400?o0000ojFGa_nUUlH00_nUUlH00ol0003oW9;9oibBb@0@o`0000?o
H7[E00?o0000odidf?l000000_l000000olUJM[o0000o`000004o`000003o`Aggol0003o000000Co
00000oo?h^D01?l0003ob]kWol[Nioo:g^L2o`0000;ok=Ro00Go0000onSG`ooXel?oj=O3o`00000=
ooooo`03o`000?oooooooooo00Wooooo000aooooo`?o00006Oooool3o`0000_ooooo0ol00003okfl
f@04o`000?no_=Oo_kcGo`0000?oe[k200?o0000omJl`?oF_<000ooF_<02o`0000?og;Zg00?o0000
om^i]_oK^KH00_oK^KH01_l0003of[RfomZh]_l0003og;Nco`0000?ofkJc00Oo0000omZe/ooJ]K?o
f[Fco`000?oI];?o000000Cof;>d00Ko0000omRd]OoH];Go0000omBb]ol00006omBc^003o`000?o>
/[koc[:n00;oc[:n00Ko0000olnf`Oo?]/7o0000olBab?l00004olFgc003o`000?nb/=Ko000000;o
000000?o/kOLo`000?n@Z^P00on@Z^P00ol0003oF8oZo`000002o`000003obUWfOl0003o000000;o
000000Go02Vbo`000?l0003o02nco`000002oaTk]P03o`000?l[AK[o000000?oBEJm00Go0000of5T
_omQI;oo0000ogQb_`04o`0000;oSGjm1Ol00002oif8_003o`000?n[SkWoZhni00;oZhni00?o0000
okFE]oneUKL00oneUKL2o`0000Ko_ibe0_l00005olRT]003o`000?o<Y[;o000000God:bd00?o0000
omNd]OoG];D00_oG];D01ol0003ogKfhomfm^?oM_KSo0000omfl]ol000000ooTa[X01?l0003oj]:m
on[B_Ol00002onoN_PSo000000Goi?^bo`000?l0003o0000om[m^`02o`0000;ohoWD00Co0000on3[
fOoPjmWo00000_oHf=L2o`0000Cobl3@0_l00005okj]b@03o`000?nhZLWo000000?o/ik300?o0000
ojfKa?n]Vl@00_n]Vl@00ol0003oYIO6ojFGaP05o`0000;oWHg300Go0000oiB9a_nDRLKoU8W6o`00
0004ohV5b@04o`000?mmPLgoOH7=ogf1c@?o00000_mPN]D01?l0003oCWCHodidf?l00002obEYfPCo
000000Co5WgVo`000?l0003o00001?m`_oh00ol0003ocn;Uo`000003ol[Ni`;o00000oo/f;l01_l0
003oj=O3onSG`ol0003oi]K7o`0000cooooo00?o0000ooooooooool02Oooool0037ooooo00?o0000
ooooooooool05_ooool3o`0000oooooo0ol000000onm_=Wo0000oknle`03oknle`03o`000?oF_/;o
000000Goe[c000Ko0000omJk_ooF^koo0000ombj]ol00004om^i]P03o`000?oJ^;Kof[Rf00;of[Rf
00?o0000om^f/ooK][<00_oK][<00ol0003of[FcomZe/`02omZe/`03o`000?oH/kCof;>d00?of;>d
00Go0000omRd]OoH];Gof;Beo`000006omBc^003o`000?oE]K[o000000;oc[:n00?o0000olnf`Oo?
]/400_o?]/400ol0003oaKO<olFgc004olFgc003o`000?nc]mco/kOL00?o/kOL00?o0000oi2Zj?n@
Z^P00_n@Z^P00ol0003oF8oZoeR?jP03o`000006o`0o`ol0003o02ffo`000?l0:K;o00000_l0;k<0
0ol0003o6C^fo`000002ob]5^P04o`000?m9E[goBEJmo`0000?oHFBo00Co0000ogQb_omhL[ooN7:o
0ol00002ohen_P03o`000?nMR;coWHRl00;oWHRl00?o0000oj^?^On[SkT00on[SkT01ol0003o]IFg
okFE]oneUKOo0000okNH^?l000001_noW;D00ol0003ob:BdolRT]005olRT]003o`000?o@[;Cod:bd
00?od:bd00?o0000omFc]ol000000_oG];D00ol0003ogKfhomfm^003omfm^005o`000?oTa[[oi<Jj
onC6^_l000000ooZd[d01?l0003okmjnonoN__l00002oo;Z_`04o`000?oblkco0000onci^0?o0000
00?of?^bo`000?l000000_l000001OoSnMCo0000on3[fOoPjmWo000000;of=SG00?o0000olk4dOl0
00000oo;`=000ol0003o`[38o`000005okj]b@;o00001?ncW/<00ol0003o[I_4ojfKa002ojfKa0?o
00000_nTTL400ol0003oWHg3oif=``03oif=``05o`000?nDRLKoU8W6oiB9a_l000001?n9QLT01_l0
003oOH7=ogf1cOmmPLgo0000ofmmd@?o00000om>M=P2o`000003obEYf_l0003o9G7P00Co000000?o
5WgVo`000?l000001?l00003ol[Ni`06o`000?o6f^Soa][Xo`000?o/f;oo00000_oXel<01Ol0003o
i]K7onKFaooVe/Oo000000cooooo00?o0000ooooooooool02?ooool0037ooooo00?o0000oooooooo
ool04oooool3o`0001?ooooo00?o0000o`YZg?l000001Ono_=L2o`0000Goe[c000?o0000omJk_ooF
^kl00_oF^kl00ol0003ofkVfom^i]P02om^i]P03o`000?oJ^;Kof[Rf00?of[Rf00Go0000om^f/ooK
][?ofkJco`000005omZe/`03o`000?oH/kCof;>d00;of;>d00?o0000omRd]OoH];D00_oH];D00ol0
003oe;>homBc^003omBc^006o`000?oE]K[oeKFjo`000?o>/[ko00001Oo?]/400ol0003oaKO<olFg
c003olFgc003o`000?o7_M7o000000Co/kOL00Co0000oi2Zj?n@Z^SoT:[X1_l000000ol>HmWo0000
o`0o``05o`000004o`0_/ol0003o0000o`0000;o:dFj0_l000000om9E[go0000of5T_`02of5T_`05
o`000?mhL[ooN7:oogQb_ol000001?n=O[h00ol0003oWHRloif8_003oif8_003o`000?n[SkWoZhni
00;oZhni00Co0000okFE]oneUKOo00000ongV;P00ol0003o_ibeoknL]@03oknL]@03o`000?o8Y;Co
b:Bd00Gob:Bd00?o0000om2/]?o@[;@00_o@[;@01?l0003oeK>gomFc]ol00002omNd]@03o`000?oM
_KSogKfh00?ogKfh00Go0000onC6^_oTa[[oi<Jjo`000002on[B_@04o`000?o_g[kokmjno`0000;o
l^Zo00Co0000oo;c_?l0003ok?Vh0_l000001ooLnZoo0000o`000?l0003oeok1o`000?oOoM400_l0
00001OoPjmWo0000omSHeooHf=Oo000000?oc/CA00?o0000ol_0d?l000000oo2/<P00ol0003o_Zg9
okj]b@02o`000003okNQ`_l0003o/ik300?o/ik300?o0000ojfKa?l000000_l000000onZU;oo0000
ojBA`@03ojBA`@03o`000?nMSL?oWHg300;oWHg300?o0000oiB9a_nDRLH00_nDRLH01Ol0003oRHG9
ohV5bOn9QLWo000000CoOH7=00Co0000ofmmdOm_OM7oKggA0_l000000om>M=So0000od5cg003o`00
00;o9G7P00?o0000obZ4j_l000000_l00004og:ko003o`000?o:g^Oo000000?oa][X0_l00003onSG
``04o`000?oVe/Ooi]K7onKFa`;o00002oooool00ol0003oooooooooo`08ooooo`0000?o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo01;ooooo0_l0000Gooooo`?o00000ono_=L01?l0003o_k_F
oknke_l00003omJl`003o`000?oF^kooe[^o00?oe[^o00?o0000om^i]_oK^KH00_oK^KH00ol0003o
f[RfomZh]P02omZh]P03o`000?oJ]kKo000000;ofkJc00?o0000omZe/ooJ]K<00_oJ]K<00ol0003o
f[Jdo`000003omRc]007o`000?oH];Gof;BeomRd]Ol0003of;Jfo`000003omBc^003o`000?oE]K[o
eKFj00;oeKFj00?o0000olnf`Oo?]/400oo?]/400ol0003odK[4o`000003olFgc005o`000?o7_M7o
akgAolNmdOl000000_nc]m`5o`0000;oS;?a00?o0000odJCl?m6To002ol000000ol9=;Go0000o`00
0002ob]5^P?o00000omQI;l00ol0003oN7:oogQb_`02ogQb_`03o`000?n=O[koSGjn00;oSGjn00?o
0000oif8_?nMR;`00_nMR;`00ol0003oZhnioj^?^@02oj^?^@03o`000?neUKOo000000Co]iRh00?o
0000oknL]OnoW;D00_noW;D00ol0003o`Z6go`000005olRT]003o`000?o<Z[Oo000000?od:bd00Ko
0000omFc]ooE/kOo0000omNd]Ol00005omfm^005o`000?oTak_o0000onC6^_l000000ooZd[d02ol0
003okmjnonoN__l0003ol^Zoo`000?oblkco0000onci^?l0003oi?^b00?o000000GocoZao`000?l0
003ogogAo`000002on3afP;o000000?of=SGo`000?o>a=400oo>a=42o`0000Co`[3800?o0000okj]
bOl000001?ngXL801?l0003o/ik3ok>N`oncW/<2o`0000GoZYBo00Go0000ojBA`OnTTL7oY971o`00
0004oif=``03o`000?nDRLKoU8W600;oU8W600Go0000ohV5bOn9QLWoRHG9o`000004ogf1c@06o`00
0?m_OM7oKggAofmmdOl0003oHW_E0ol00002od5cg0?o000000Go9G7Po`000?l0003o0000obZ4jP06
o`0000?oa][X00Ko0000ol;Fj?o2e^So0000onSG`ol00003onKFa`04o`000?oSe/[ohmK:o`0000[o
oooo00?o0000ooooooooool02?ooool00003oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool3
o`0001[ooooo0ol000000ono_=Oo0000oknkeP03oknkeP03o`000?oF_<3o000000Goe[^o00?o0000
omFj__l000000_oK^KH00ol0003of[RfomZh]P03omZh]P05o`000?oJ]kKo0000om^f/ol000001?oJ
]K<01ol0003of[JdomZf]?oJ][Co0000omRc]?l000001?oH];D01_l0003of;JfomRf]_l0003oe;>h
o`0000GoeKFj00?o0000olnf`Oo?]/400_o?]/401ol0003odK[4om6ja?oA^/Co0000olFgc?l00000
1Oo7_M42o`0000Co]<7T00Go0000ohbclOn</o7oS;?ao`000002odJCl003o`000?l0Fm7o000000So
000000Ko2CBeo`000?l0003o:dFjo`000?m3E;h2o`0000?oHFBo00Go0000ogQb_omhL[ooN7:oo`00
0004ohen_P03o`000?nMR;coWHRl00;oWHRl00?o0000oj^?^On[SkT00_n[SkT2o`0000Go]iRh00Go
0000oknL]OnoW;Go_ibeo`000002ol:Q]`03o`000?o8Y;Cob:Bd00;ob:Bd00Co0000olbZ]oo<Z[Oo
00000_o@[;@00ol0003oeK>gomFc]`02omFc]`03o`000?oM_KSogKfh00?ogKfh00Co0000onC7^ooT
ak_oi<Nk0_l00002on[B_@08o`000?o_g[kokmjno`000?obj[oo0000oo;c_?l00002onci^0?o0000
00Koc?NWo`000?l0003o0000omomdOl00002on3afP04o`000?oJgMWof]gIo`0000Coc/CA00?o0000
olBcbOl000001?o2/<P2o`0000Go]j7200Ko0000ok>N`oncW/?o0000ojnG__l00005ojZD_`05o`00
0?nTTL7oY971ojBA`Ol000001OnMSL<00ol0003oU8W6oiB9aP0;o`0000CoKggA00Co0000of9keOmR
NmGoHW_E0_l000000om1Lmco0000ocmkhP02o`0000;o?h_]0ol00004ogJhn`03o`000?o6f^So0000
00?o`]KX0_l00003onKFa`05o`000?oSe/[ohmK:on?Fb_l000002_ooool00ol0003oooooooooo`08
ooooo`000_ooool00ol@413oooooooooo`09ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`Go0000
1Oooool00ol0003oooooooooo`0<ooooo`?o00007_ooool00ol0003o06?Ho`000005oknkeP;o0000
1OoF^kl01ol0003oeKZnomFj__oE^[ko0000om^i]_l000001?oJ^;H01Ol0003of[NfomZg]_oJ]kKo
000000Gof[Fc00?o0000omZf]?oJ][@00_oJ][@00ol0003of;BeomRd]@02omRd]@03o`000?oH][Ko
f;Jf00;of;Jf00?o0000omFe^_oE]KX00ooE]KX00ol0003oe[Rlo`000003olnf`@03o`000?oA^/Co
dK[400;odK[400?o0000olNmdOo7_M400oo7_M400ol0003obLCFo`000004okC1i0Wo00000_l0Fm40
3_l0003o01n[o`000?l07J[o0000o`0U[ol0003o2CBeo`000?lL@K_o0000ob]5^_l0003o@eBn0_l0
0002of5T_`03o`000?mhL[ooN7:o00;oN7:o00Go0000ohen__n=O[koSGjno`000004oif8_003o`00
0?n[SkWoZhni00;o000000?o[9:ko`000?ngV;P01?ngV;P01?l0003o_ibeoknL]Ol00004ol:Q]`04
o`000?o8Y;Cob:Bdo`0000?oc:Zg00Co0000om2/]?o@[;Co00001?oE/kL00ol0003ogKfhomfm^002
omfm^003o`000?oTak_oi<Nk00;oi<Nk00Oo0000on[D__l0003oj]:mo`000?o_g[ko000000;ol^Zo
00Co0000oo;c_?l0003ok?Vh0_l000000ooAmjKo0000o`000002o`000005omomdOl0003oh?7Jon3a
f_l000000_oJgMT2o`0000?oc/CA00Go0000olBcbOo4/lWoa;?9o`000002ol:`b003o`000?nkY<;o
000000Go]j7200?o0000ok>N`ol000000on_Ukh00ol0003oZYBoojZD_`02ojZD_`03o`000?nTTL7o
Y97100;oY97100?o0000oif=`onMSL<01Ol00002oiN8`P05o`000?n?QLGoShG5ohn5aOl000000on6
PlP3o`0000;oKggA00Ko0000of9keOmRNmGoHW_Eo`000?mHNm/3o`0000;o?g_R00?o0000ocn;kOlo
Rnd00_loRnd6o`0000;o`]KX0_l00002ol3Bj003o`000?oVe/Oo000000?ohmK:00?o0000on3Ec?l0
00002Oooool00ol0003oooooooooo`08ooooo`000_ooool00ol0003oooooooooo`09ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`04odA4A?oMgMgoooooo`0000Kooooo0_l0000:ooooo`?o00008_oo
ool3o`0000?o_k_F00?o0000oknjeOl000001?oF^kl00ol0003oeKZnomFj_P03omFj_P03o`000?oJ
^;Kof[Rf00;of[Rf00?o0000omZg]_oJ]kH00_oJ]kH00ol0003of[FcomZe/`02omZe/`03o`000?oJ
][Cof[Jd00?of[Jd00?o0000omRd]OoH];D00_oH];D00ol0003of;JfomRf]P02omRf]P03o`000?oE
]K[oeKFj00;oeKFj00Oo0000omJh_?oF^;coe[Rlo`000?o?]/7o000000GodK[40_l00003olNmd@06
o`000?o9a=KobLCFolW4e_l0003o]<7T0_l00003okG;jP04o`000?n6__WoQ[kiohJnn@So000000Oo
01fZo`000?l0003o0000o`Td]Ol0003o746k00;o000000?o@eBno`000?mMI<800ol00004ogQb_`05
o`000?n=O[koSGjnohen__l000001OnMR;`2o`0000Co[9:k00?o0000okNH^?ngV;P00ongV;P2o`00
00Go`Z6g00Co0000olRT]?o8Y;Co00001?o<Z[L2o`0000CoeK>g00?o0000om^m^ol000000ooM_KP0
1Ol0003oi<NkonC7^ooTak_o000000?oj]Bn0_l000001Oo_g[ko0000oo;Z_ol0003ol_>l00?o0000
00?ofoV/o`000?l000001_l000001OoPlM[o0000om[MfOoJgMWo000000;od<SC00?o0000olk4dOl0
00001?o4/lT00ol0003o`[38o`000003ok^T`P03o`000?ngXL;o]j7200;o]j720_l00004ojnG_P03
o`000?nZU;ooZYBo00?oZYBo00?o0000ojBA`Ol000001?l00002oij;_`03o`000?nGR<;oUhS200?o
UhS200Go0000ohn5aOn?QLGoShG5o`000003ohJ3b003o`000?mlPLgo000000;o00001?mRNmD00ol0
003oF7_KoeQkf`03o`000003ocmkh_l0003o000000?o00001?mm]_P00ol0003o`]KXo`000004ol3B
j0;o00000ooSe/X01Ol0003oh=G<on3Ec?oPeLco000000Sooooo00?o0000ooooooooool02?ooool0
00;ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?oMgMgoEEEE
ooooool00006ooooo`03o`000?oooooooooo00Kooooo0ol0000Vooooo`?o000000?o_k_Fo`000?no
^]D00_no^]D01Ol0003oe[^oomJk_ooF^koo000000GoeKZn00?o0000omZh]_oJ^;H00_oJ^;H01ol0
003of[NfomZg]_oJ]kKo0000omVg]ol000000ooJ]K<00ol0003of[JdomZf]002omZf]003o`000?oJ
][Go000000;of;Be00?o0000omRf]_oH][H00_oH][H00ol0003ofKRho`000003omFe^P03o`000?oF
^;coe[Rl00;oe[Rl00?o0000om6ja?oA^/@00ooA^/@01_l0003od[o7om:oaol0003oakgAo`0000Co
bLCF0_l00005okG;jPco000000?o01fZo`000?l09Jl00ol00002oaa1^`04o`000?m3E;ko@eBno`00
00?oGFC21Ol00004ohen_P03o`000?nMR;coWHRl00?o00001On/T[/00ol0003o]iRhokNH^003okNH
^003o`000?o2XKOo`Z6g00Co`Z6g00?o0000olRT]?l000001Oo<Z[L00ol0003oeK>gomFc]`03omFc
]`06o`000?oK_K_ofkfko`000?oM_KSo00000ooTak/00ol0003oj]Bnon[D_P02on[D_P03o`000?o`
hL3o000000Go000000?oioZdo`000?l000001Ol00003omgfg0;o000000?of]gIo`000?o@b=<00oo@
b=<00ol0003oa;?9olBcb@04olBcb@03o`000?nkY<;o^jC200;o^jC200?o0000okNQ`_ngXL800_l0
00000oncVKko0000ojnG_P03ojnG_P03o`000?nZU;ooZYBo00;oZYBo0ol00002ojB>_@03o`000?nN
RkooWX^o00?oWX^o00?o0000oiN8`_nGR<800_nGR<801Ol0003oShG5ohn5aOn?QLGo000000CoQX?8
00Co0000ogb1cOmlPLgoO87=1Ol00003oeQkf`03o`000?mFPn;o000000;o00000_mDTNd7o`0000?o
`=;X0_l000000onocnOo0000on?FbP02on?FbP06o`000?oPeLcoh=G<o`000?oNe<oo00001oooool0
0ol0003oooooooooo`08ooooo`000_ooool00ol@413oooooooooo`09ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@4004ooooo`03ogMgMoo<c<co000000Kooooo00?o0000ooooooooool00oooool3o`0002[ooooo
00?o0000o`1IdOl000001Ono^]D00ol0003oe[^oo`000005omFj_P03o`000?oD^Koo000000;of[Rf
00?o0000omZg]_oJ]kH00_oJ]kH01_l0003ofKNgomVg]ol0003of[Fco`0000Cof[Jd00Oo0000omZf
]OoJ][Gof[Jeo`000?oH];Go000000?of;Jf00Oo0000omVh^?oI^;SofKRho`000?oE]K[o000000Go
e[Rl0_l00003om6ja003o`000?oB_lOod[o700;od[o700?o0000olW4e_o9a=H00_o9a=H01Ol0003o
c<cJolc<f_l0003o]L_Z00?o00000_nfeO000ol0003oP<Onoh37oP08o`000004o`0MZ_l0003o0000
o`0[/`;o00000_lL@K/00ol0003o@eBno`000003oeeT`P04o`000?mfLl;oMW?2ogIc`PSo00000_nN
Rkl00ol0003o[9:kojbB^`04ojbB^`04o`000?ngV;So]iRhokNH^0;o00001oo2XKL00ol0003oc:Zg
olbZ]`04olbZ]`03o`000?oE/kOoeK>g00;oeK>g00?o0000om^m^ooK_K/00_oK_K/01Ol0003oi<Nk
onC7^ooTak_o000000Coj]Bn00Wo0000oo3Q`?o`hL3o0000oo;^_ol0003okoNko`000?oWn[@01ol0
0003omgfg004o`000?oIh]gofN;Mo`0000Cod<SC0_l00005olBcb@;o00001?nkY<800ol0003o]j72
o`000004ok>I_P03o`000?n_Ukko[iNn00;o[iNn1?l000000onYT;co0000ojB>_@03ojB>_@03o`00
0?nNRkooWX^o00;oWX^o00?o0000oiN8`_nGR<800_nGR<800ol0003oShG5ohn5a@02ohn5a@05o`00
0?n6PlSoQX?8ohJ3b?l000000omlPLd01?l0003oLX3Bog:0d_mbP=83o`0000;oF7_K00Co0000oeJ3
h_mFPn;oEX?R1Ol00004ohFem003o`000?o0d^So000000Co_loW00?o0000on?Fb_l000000_oPeL`0
1Ol0003og]C?omkDcooNe<oo000000Oooooo00?o0000ooooooooool01oooool00003oooooonHV9So
MgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?ok^k^odA4A?l000001Oooool01?l0003o
ooooooooooooool3o`0002kooooo0_l00005oknje@;o00001OoE^[h01ol0003oe;VoomBi_ooD^Koo
0000omZh]_l000000ooJ]kH00ol0003ofKNgomVg]`02omVg]`03o`000?oJ][Cof[Jd00?of[Jd00?o
0000omZf]OoJ][D00_oJ][D00ol0003of;JfomRf]P02omRf]P03o`000?oI^;SofKRh00;ofKRh00?o
0000omJh_?oF^;`00ooF^;`01_l0003oekbnomNl__l0003odK[4o`0000Cod[o70_l00003olW4eP03
o`000?o<c=[oc<cJ00;oc<cJ0_l00004okKEl0Co00000_mjcol9o`000004o`0[/ol0003o746koaa1
^`;o000000?o@eBno`000?mMI<800_mMI<801Ol0003oMW?2ogIc`_mfLl;o000000?oS83100?o0000
oij;_onNRkl00onNRkl00ol0003o[9:kojbB^`03ojbB^`04o`000?ngV;So]iRho`0000;o^Yfk00?o
0000ol:Q]oo2XKL00oo2XKL2o`0000Goc:Zg00?o0000om6b^ol000000ooE/kL00ol0003ofkfkom^m
^`02om^m^`05o`000?oTak_oi<NkonC7^ol000000ooZe;h02Ol0003ol>70oo3Q`?l0003ol^joo`00
0?o_mk_o0000onOj]003o`000004okS^Vol0003o0000o`0000?ogOKL00?o0000omWRgOoIh]d00_l0
0003om38d`04o`000?o6]/_oa[K;o`0000?oa;?900Co0000okfW`onmYl?o00000onkY<82o`0000Go
/iVn00Co0000ojnG__n_Ukko[iNn0_l00004ojV@_003o`000?nTS[goY8jm00;oY8jm00?o0000oij;
_onNRkl00_nNRkl00ol0003oUhS2oiN8`P03oiN8`P05o`000?n?QLGoShG5ohn5aOl000000on6PlP0
0ol0003oO87=ogb1c@02ogb1c@06o`000?mbP=;oLX3Bog:0d_l0003oJX?I1?l00002oeJ3hP04o`00
0?mVUn_oIYO[ofJGj`Oo00001OnocnL2o`0000;oh=G<00Co0000omkDcooNe<oog]C?0_l00007oooo
o`03o`000?oooooooooo00Oooooo00000ol0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`03ogMgMol0003ooooo00Cooooo1?l0000booooo`;o00000ono^]D01?l0003o_[WFokji
e_l00003omFj_P03o`000?oD^Kooe;Vo00?oe;Vo00?o0000omZg]_oJ]kH00_oJ]kH00ol0003ofKNg
omVg]`02omVg]`03o`000?oJ][Cof[Jd00;of[Jd00?o0000omZf]OoJ][D00ooJ][D01Ol0003of;Jf
omRf]_oH][Ko000000GofKRh00?o0000omJh_?oF^;`00_oF^;`00ol0003oekbnomNl_P02omNl_P03
o`000?oB_lOod[o700;od[o700Ko0000omG5booEaL_o0000olW4e_l00004olc<fP05o`000?o>e=ko
c]CNo`000?nfeO000_l00003okOMm0?o00000omgeOh4o`000008o`0HY_l0003o02^co`0[/ol0003o
746ko`000?lgD/42o`0000?oGFC200Go0000ogIc`_mfLl;oMW?2o`000004ohb0`@03o`000?nNRkoo
WX^o00;oWX^o00?o0000ojbB^on/T[/00on/T[/00ol0003o]iRho`000003okZM^`03o`000?o2XKOo
`Z6g00;o`Z6g00Co0000olJX^oo6Z;_o00000oo<Z[L01ol0003odK:kom6b^ooA/[_o0000omFc]ol0
00001?oK_K/01Ol0003oh/Vno`000?oTak_o000000?oj]Bn00Co0000oo3Q`?o`hL3o00000_obk[l0
1ol0003okoNko`000?l0003ofoV/o`000?nhkY/01Ol000001OoMm]co0000omWRgOoIh]go000000;o
d<cF00?o0000om38dol000001?o6]//00ol0003oa;?9o`000003okfW``06o`000?nkY<;o^jC2o`00
0?neW;ko00001OncVKh01_l0003o[iNnojnG__l0003o[I:ko`0000GoZI2l00?o0000ojB>_OnTS[d0
0_nTS[d00ol0003oWX^ooij;_`02oij;_`03o`000?nGR<;oUhS200[o000000?oQX?8o`000?mlPLd0
0_mlPLd00ol0003oLX3Bog:0dP02og:0dP04o`000?mZPmWoJX?IofZ3f@Go00000omVUn/00ol0003o
SKGaohfel@03ohfel@03o`000?nocnOo000000;o000000Co_lgUo`000?oPeLco00000ooNe<l01?l0
003og=CAomcDdOl00006ooooo`03o`000?oooooooooo00Oooooo000_ooooo`;o0000=Oooool2o`00
0003oknjeOl0003o_[WF00?o_[WF00?o0000omFj__l000001_oD^Kl2o`0000;of[Nf00?o0000omVg
]ooI]kL00_oI]kL00ol0003ofKRho`000003omZf]003o`000?oJ][Gof[Je00;of[Je00?o0000omZh
]ol000000_oH][H00ol0003ofKRhomVh^002omVh^003o`000?oJ^[[o000000;oe[Rl00?o0000omNl
__oG_;h00ooG_;h01Ol0003od[o7om:oaooB_lOo000000CoeLG;0_l00003olc<fP04o`000?o>e=ko
c]CNolkDgPCo000000?o]mgdo`000?l000000_nhi?D4o`0000;oN][l0ol000001?l06:Ko0000o`0[
/ol00002oaa1^`03o`000?lgD/7o000000CoGFC200Go0000ogIc`_mfLl;oMW?2o`000003ohb0`@03
o`000?nNRkooWX^o00?oWX^o00?o0000ojbB^on/T[/00_n/T[/2o`0000Go^Yfk00Co0000ol:Q]oo2
XKOo00000oo6Z;/01?l0003oc:ZgolbZ]ol00004om6b^`03o`000?oE/kOo000000?ofkfk00Co0000
on;9__oRbKkoh/Vn0_l00003on[D_P03o`000?o`hL3o000000;ol^jo00Co0000onog^ol0003oioZd
1_l00002omKkg`?o000000?ofN;Mo`000?o@c=H00_o@c=H2o`0000Goa[K;0_l00004okfW``03o`00
0?nkY<;o000000?o]Ibn00?o0000ok>I__ncVKh00oncVKh2o`0000?o[I:k00?o0000ojV@_?nYT;`0
0_nYT;`00ol0003oY8jmojB>_@02ojB>_@03o`000?nNRkooWX^o00Go00000_nJR;l00ol0003oU8K2
oiB6`P02oiB6`P03o`000?n=QLKoSHG600_o00000omZPmT2o`0000;oJH_P1_l00003ohfel@?o0000
1?nocND2o`0000?og]C?00Go0000omcDdOoLe=7og=CAo`000006ooooo`03o`000?oooooooooo00Oo
oooo000aooooo`03o`000?oooooooooo03?ooooo0_l00005okjieP;o00001_oD^Kl01_l0003oe;Vo
omBi_ol0003of[Nfo`0000?ofKNg00Oo0000omVh^?oI^;SofKRho`000?oJ][Co000000Cof[Je00Ko
0000omZh]ooJ^;Oo0000omRf]_l00004omVh^006o`000?oJ^[[of[Zjo`000?oF^;co00001OoG_;h0
1Ol0003ofL71o`000?oB_lOo000000CoeLG;00Ko0000omS<c_oHc<ko0000olc<f_l00003olkDgP04
o`000?oAfn7odM_Qom7Kh@?o000000?o^>Ceo`000?l000000onjjO@8o`0000;o02^c00?o0000oaa1
^ol000000_lgD/42o`0000;oGFC200Go0000ogIc`_mfLl;oMW?2o`000004ohb0`@03o`000?nNRkoo
WX^o00;oWX^o00?o0000ojbB^on/T[/00_l000000on_Ukoo0000okZM^`04okZM^`03o`000?o2XKOo
000000CoaZRk00Co0000olbZ]oo<Z[Oo00001OoA/[/00ol0003ofkfkom^m^`02om^m^`09o`000?oR
bKkoh/Vnon;9__l0003ojMO2o`000?oZe;ko000000;ol>7000?o0000oo;^_oobk[l00_l000000ooW
n[Co0000o`000004o`0000;oe__O00?o0000omKWh_oFin800_l00003om3<eP03o`000?o6^Lko0000
00?oa[K;0_l000000onnZ<Co0000okfW``04okfW``03o`000?neW;ko]Ibn00;o]Ibn00?o0000ok>I
__ncVKh00_ncVKh2o`0000Co[I:k00?o0000ojV@_?nYT;`00_nYT;`00ol0003oY8jmojB>_@02ojB>
_@?o00000_nPR[d00ol0003oVXRooiZ8_`02oiZ8_`03o`000?nDQ/;oU8K200?oU8K200Co0000ohf5
a_n=QLKo00001?n5Q</01?l0003oOXG@ogj5d?mnQM03o`0000;oJX?I0_l00002ofV;h004o`000?mf
W>WoMYcYogJLj@Co00000_nE]^h01Ol0003o_lgUoko=iOnocNGo000000;o`<gT00?o0000omkDcol0
00001?oLe=400ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo000booooo`03o`00
0?oooooooooo03?ooooo0_l00003okjieP03o`000?nl^MOo000000Goe;Vo00?o0000omBi_ooD^Kl0
0_oD^Kl00ol0003ofKNgomVg]`02omVg]`03o`000?oI^;SofKRh00;ofKRh00?o0000omZf]OoJ][D0
0ooJ][D01Ol0003of[RgomZh]ooJ^;Oo000000GofKRh00Go0000omZj^_oJ^[[of[Zjo`000005omNl
_P04o`000?oI`L7ofL71omW1`@;o00000ooEaL/00ol0003of<c>omS<cP02omS<cP?o000000?oc]CN
o`000?oAfn400_oAfn401?l0003odn7Rom?Qh_oChN83o`000005ok[Ym?l0003o0000okgZlol00000
0oo2jO44o`000004o`0[/ol0003o0000o`0000;o=e;100?o0000oeITa_l000000_l00003ogIc`P03
o`000?n<P<7oS83100;oS83100?o0000oij;_onNRkl00_nNRkl00ol0003o[9:ko`000003ojnG_`03
o`000?njWK_o^Yfk00Co^Yfk00?o0000olJX^oo6Z;/01?o6Z;/2o`0000KodK:k00Go0000om^m^ooK
_K_ofkfko`000003on;9_P04o`000?oYel;ojMO2onWG`P;o000000Kol>70o`000?obk[ool^joo`00
0?o_mk/2o`000003olcfXol0003o000000;o00000_oFnml01?l0003oe^ORomKWh_l00002olk?f`03
o`000?o@c=Ko000000?oa[W>00?o0000olJfbol000001?nnZ<@01?l0003o_JO3okfW`onmYl<2o`00
00Go]Ibn00Ko0000ok>I__ncVKko0000ok2D^_l00005ojfB^`03o`000?nYT;coZI2l00;oZI2l1?l0
00000onTS;_o0000oj2:_@03oj2:_@03o`000?nJR;ooVXRo00;oVXRo00?o0000oiB6`_nDQ/800_nD
Q/801Ol0003oSHG6ohf5a_n=QLKo000000CoQHC;00Ko0000ogj5d?mnQM3oOXG@o`000?miRML3o`00
0005ofV;h?l0003oJH_PofV;h?l000000omfW>T00ol0003oUKK^oiFfkP03oiFfkP03o`000?nocNGo
000000?o`<gT0_l00004omcDd@03o`000?oJeMCo000000Gooooo00?o0000ooooooooool01oooool0
03?ooooo00?o0000ooooooooool0<oooool2o`000003okjie_l0003o_;WG00;o_;WG00Go0000omBi
_ooD^Kooe;Voo`000005omBi_`05o`000?oI]kOofKNgomVg]ol000001OoI^;P00ol0003of[JeomZf
]@02omZf]@03o`000?oJ^;Oof[Rg00;of[Rg00?o0000omVh^?oI^;P00_oI^;P00ol0003of[ZjomZj
^P02omZj^P;o00000ooG_;h00ol0003ofL71omW1`@02omW1`@05o`000?oKaL?o0000omG5bol00000
1?oHc<h01Ol0003of];@om[Bd?oJd]3o000000?odM_Q00Go0000om?Qh_oChN;odn7Ro`000002omCT
hP?o000000?o_N[co`000?o2jO400_o2jO400ol0003oa^C]o`000004o`000003o`Lj^ol0003o0000
00;o=e;100Co0000oeITa_mFI<KoEVC60_l000000omfLl;o0000ohb0`@03ohb0`@04o`000?nNRkoo
WX^ooij;_`?o00001On_Ukl00ol0003o^YfkokZM^`02okZM^`;o00001_o6Z;/00ol0003odK:kom6b
^`04om6b^`03o`000?oH_Koo000000;ofkfk00Go0000on;9__oRbKkoh/Vno`000003onWG`P03o`00
0?o_iLCo000000;o000000Col^joo`000?l0003ogO^`1_l000001OoFnmoo0000omKWh_oFin;o0000
00?oc/oK0_l00005olJicP03o`000?nnZ<Co_ZS400?o_ZS400Co0000okfW`onmYl?o00000_ngWKh0
0ol0003o]IbnokFL_P02okFL_P03o`000?ncVKko000000;o/9Bj00?o0000ojfB^on]T[/00on]T[/0
1?l0003oZI2lojV@_?nYT;`2o`0000CoY8bk00?o0000oj2:_OnPR[d00_nPR[d00ol0003oVXRooiZ8
_`02oiZ8_`03o`000?nDQ/;oU8K200;oU8K200Go0000ohf5a_n=QLKoSHG6o`000004ohF4b`03o`00
0?mnQM3oOXG@00;oOXG@00Co0000ogV9eomiRMOoNHWG2_l00003oiFfkP?o00000oo0cN@00ol0003o
`LkTo`000003omcDd@05o`000?oJeMCof]GDom[Ee?l000001?ooool00ol0003oooooooooo`07oooo
o`00=?ooool2o`0003Cooooo0_l00005okbie`03o`000?oD^Koo000000Goe;Vo00?o0000om>i`Ol0
00000_oI]kL00ol0003ofKRhomVh^002omVh^003o`000?oI^KWo000000?of[Je00Oo0000omZh]ooJ
^;Oof[Rgo`000?oJ^[So000000?ofKRh00Go0000omZj^_oJ^[[of[Zjo`000002om^n_003o`000?oG
_;ko000000CofL7100Co0000om_5`ooKaL?oflG30_l00003omS<cP09o`000?oJd]3of];@om[Bd?l0
003og=OBo`000?oAfn7o000000?odn7R00Co0000omCTh_oDi>;o00000ooFiN43o`000004ol;YlOl0
003oa^C]olKTk@Ko000000Go1cZko`000?l0003o=e;1o`000003oeITaP03o`000?mbM/Oo000000;o
00000_n<P<45o`0000;oWho300?o0000ojnG_on_Ukl00on_Ukl01Ol0003o^YfkokZM^onjWK_o0000
00;o_ZBo00?o0000olJX^oo6Z;/00oo6Z;/00ol0003odK:kom6b^`03om6b^`06o`000?oH_Koof;fo
o`000?oK_K_o00000ooRbKh01Ol0003ojMO2onWG`_oYel;o000000;oknG400Go0000oo3b`oo`l/?o
0000on[j_006o`000006olOmhol0003o0000o`000?oFin;o00000oo>cm/00ol0003oa;[Ao`000004
olJicP;o00001OnnZ<@00ol0003o_JO3o`000003okNM_P03o`000?neW;ko]Ibn00;o]Ibn0_l00004
ok2D^P03o`000?n]T[_o[I:k00;o[I:k00Ko0000ojV@_?l0003o0000ojR>^_l00005ojB<^`05o`00
0?nPR[goX8Zmoj2:_Ol000001?nJR;l00ol0003oU8K2oiB6`P03oiB6`P04o`000?n=QLKoSHG6o`00
00CoQHC;00?o0000ogj5d?mnQM000_mnQM001ol0003oNHWGogV9eomiRMOo0000ogVBgol000000_mi
T]l01?l0003oQ:;WohBRion4X^L4o`0000?oWKS[00?o0000ol3=i?l000000oo1c^@00ol0003og=CA
o`000003om[Ee003o`000?oGemSo000000?ooooo00?o0000ooooooooool01oooool003Kooooo00?o
0000ooooooooool0<_ooool2o`0000Co_;WG0_l00005omBi_`06o`000?oC^L7odkW1o`000?oI]kOo
00001?oI^;P01ol0003ofKViomVi^OoI^KWo0000omZf]Ol000000ooJ^;L01ol0003of[ZhomZj^?oJ
^[So0000omVh^?l000001?oJ^[X01Ol0003ofkjlom^n_?oK_[co000000CofL7100?o0000om_5`ooK
aL<00_oKaL<01Ol0003og/_6o`000?oHc<ko000000?of];@00Co0000omcGd_oLem;og=OB0ol00000
1OoChN;o0000omCTh_oDi>;o000000?oe^GQ00?o0000omOSgooGhml00ol000001_o6i>go0000olSL
j?o8g>So0000o`05U0Co000000Co9Tk4o`000?l0003o00000_mFI<H01?l0003oLWK7og9faombM/L3
o`0000;oS8C600?o0000oin?`onOSl<00_nOSl<00ol0003o[iNoojnG_`03ojnG_`04o`000?njWK_o
^Yfko`0000?o_ZBo00?o0000olJX^oo6Z;/00_o6Z;/00ol0003oc;6oo`000003om6b^`03o`000?oH
_Koof;fo00;of;fo00?o0000on;9__oRbKh00_oRbKh01?l0003ojMO2onWG`_l00002onoUa004o`00
0?o`l/?ol?;3oo3b``Go000000Co[?O4o`000?o7oN?o00000_o?k>T2o`0000?oc/oK00Go0000olBj
dOo4^]7oa;[Ao`000002olJicP04o`000?nmZ/Ko_J[6o`0000Co_ZS40_l00004okNM_P03o`000?ne
W;ko]Ibn00;o000000?o/YJjo`000?n`U;X00on`U;X00ol0003o[I:kojfB^`02ojfB^`;o00000onX
S[X00ol0003oY8bkojB<^`03ojB<^`03o`000?nPR[goX8Zm00;oX8Zm00?o0000oiZ8_onJR;l00_nJ
R;l00ol0003oU8K2oiB6`P0@o`0000CoNHWG00?o0000ogVBgol000000_miT]l00ol0003oQ:;WohBR
i`02ohBRi`04o`000?nM^>_oWKS[oifhj`?o00001?o1c^@2o`0000?of]GD00?o0000omOGf?oGemP0
0_l00003ooooo`03o`000?oooooooooo00Kooooo000gooooo`03o`000?oooooooooo03;ooooo0_l0
00000onl^MOo0000o`000002okVhf@05o`000?oD^Kooe;VoomBi_ol000001?oC^L400ol0003ofKRh
omVh^003omVh^003o`000?oI^KWofKVi00;ofKVi00?o0000omZh]ooJ^;L00_oJ^;L00ol0003of[Zh
omZj^002omZj^003o`000?oJ^[[of[Zj00;of[Zj00?o0000om^n_?oK_[`00_oK_[`2o`0000?ofL71
00Go0000om_5`ooKaL?oflG3o`000003omk;aP05o`000?oJd]3of];@om[Bd?l000000ooLem801?l0
003og]_ComkKdooNfm<2o`000003omCTh_l0003oe^GQ00;oe^GQ00Co0000omOSgooGhmoo00000_oG
gmd4o`000003olSLj?l0003o000000;o000000?o02ngo`000?l000000_lVC/@01Ol0003oEVC6oeIT
a_mFI<Ko000000;oLWK700?o0000ohb4a_n<Q<H00on<Q<H00ol0003oWho3oin?``02oin?``03o`00
0?n_Ukoo[iNo00?o[iNo0_l00005okjT_`04o`000?o6Z;_oaZRko`0000?oc;6o00Co0000om6b^ooA
/[_o00001?oH_Kl2o`0000;oh/Vn00Co0000onWG`_oYel;o00000oo_iL@00ol0003ol?;3oo3b``02
o`000007omgk/?l0003o0000ojcga?l0003oaogSo`000002olo/j@06o`000?o9d^7obM;Qo`000?o>
cm_o00001?o4^]400ol0003oa[W>o`000003okfZaP03o`000?nnZ<Co_ZS400;o000000?o^9noo`00
0?ngWKh01?ngWKh2o`0000Co/YJj00Go0000ok2D^_n`U;[o/9Bjo`000002ojfB^`;o000000?o[92i
o`000?nXS[X00onXS[X00ol0003oY8bkojB<^`02ojB<^`04o`000?nPR[goX8Zmoj2:_@Wo00000_nI
RL801Ol0003oThW5oi>9aOnCRLGo000000CoSXW:00Co0000ohV<d?n9S=3oRHc@2ol00003ohBRi`Go
00000_nT_>X00ol0003o`LkTo`000002o`0000;o`m3T00?o0000om[Ee?l000000_oGemP00ol0003o
dm[Mo`000003ooooo`03o`000?oooooooooo00Kooooo000hooooo`03o`000?oooooooooo03;ooooo
0_l00005okVhf@03o`000?oD^Koo000000GodkW100?o0000omVh^?oI^;P00_oI^;P00ol0003ofKVi
omVi^@03omVi^@05o`000?oJ^;Oof[RgomZh]ol000001OoJ^[P2o`0000;of[Zj00?o0000om^n_?oK
_[`00_oK_[`01_l0003ogL:nomg2__l0003ofL71o`0000?oflG300?o0000omk;a_oNblH00_oNblH2
o`000003om[Bd?l0003og=OB00;og=OB00?o0000omkKdooNfm<00_oNfm<00ol0003ogmkCo`000002
o`000005omKUhOl0003oen?OomOSgol000000_oGgmd00ol0003oe]WJomKIfP02omKIfP03o`000?o7
d^;oam;R00?o000000?o02ngo`000?l000000_lVC/@2o`000003oeITa_l0003oLWK700;oLWK700?o
0000ohb4a_n<Q<H00_n<Q<H00ol0003oWho3oin?``02oin?``03o`000?n_Ukoo[iNo00;o[iNo0_l0
0006okjT_`03o`000?o6Z;_o000000Coc;6o00?o0000om6b^ol000001?oH_Kl01_l0003ogl_4omo;
a?l0003oh/Vno`0000;ojMO200Co0000onoUa?o_iLCo00000_o`l/<2o`000003omgk/?l0003o0000
00Go000000?ocncYo`000?o9d^400_o9d^42o`0000Goa;[A0_l00004okfZaP03o`000?nnZ<Co0000
00Co^9no00Co0000okNM__ngWKko]ifn0_l00005ok:F^P03o`000?n`U;[o/9Bj00;o/9Bj0_l00003
ojb@^@03o`000?nXS[[oZ8jj00;oZ8jj00?o0000ojB<^onTS;/00onTS;/3o`000003oj:<_Ol0003o
WX^o00?oWX^o00?o0000oiV9`_nIRL800onIRL801Ol0003oThW5oi>9aOnCRLGo000000CoSXW:00Go
0000ohV<d?n9S=3oRHc@o`000004ohF@e`04o`000?n7V]ko0000ohNJgPCo00000_n@Z>H00ol0003o
Y;cZojBljP02ojBljP;o00001Oo3d>@2o`0000;oemOH00Go0000om?JgOoCf]godm[Mo`000002oooo
o`03o`000?oooooooooo00Kooooo000iooooo`;o0000<_ooool2o`0000Go^KSI0_l00005om>i`@03
o`000?oB^/;o000000?ofKRh00?o0000omVi^OoI^KT00_oI^KT00ol0003ofKZko`000002omZh]`03
o`000?oJ^[Sof[Zh00;of[Zh00Ko0000om^l^_oK_;[o0000omZj^_l00003om^n_003o`000?oM`[ko
gL:n00;ogL:n00Go0000om_5`ooKaL?oflG3o`000004omk;aP03o`000?oPclOoh<o700?o000000?o
g=OBo`000?oNfm<00ooNfm<00ol0003ogmkCo`000003on3Nd`Go000000?oemoMo`000?oFfMX00ooF
fMX01?l0003oe=7Fo`000?o7d^84o`000006o`0_]ol0003o9Tk4obI>a?l0003oBVG<0_l00003og9f
a`03o`000?n<Q<KoS8C600?oS8C600Go0000oin?`onOSl?oWho3o`000002ojnG_`;o000000?o/Yk4
o`000?nnY;l01_nnY;l00ol0003oc;6oolba_`04olba_`03o`000?oH_Koof;fo00;of;fo00?o0000
omo;a?oObl@00_oObl@2o`000005onWG`_l0003oknG4onoUa?l000000_o`l/<8o`0000;o`^ka0_l0
0003olWBh@04o`000?o1^mGo`K_Eo`0000?oa;[A00?o0000okb[b?l000001?nmZ/H2o`0000Go^9no
00Ko0000okNM__ngWKko0000ok>G^ol00005ok:F^P04o`000?n`U;[o/9Bjok2D^P;o00001On/T;T0
1Ol0003oZ8jjojR>^_nXS[[o000000CoY8bk0_l00004oj:<_@03o`000?nNRkooWX^o00;oWX^o00?o
0000oiV9`_nIRL800_nIRL800ol0003oThW5oi>9a@02oi>9a@05o`000?n>RL[oSXW:ohj9b_l00000
1?n9S=000ol0003oQI3GohF@e`02ohF@e`05o`000?n7V]ko0000ohNJg_l000001On@Z>H01_l0003o
Y;cZo`000?l0003oZl;Zo`0000?o`m3T0_l000001?o5eNKo0000omOGf?l00004om?Jg@;o000000?o
ooooo`000?ooool01oooool003_ooooo00?o0000ooooooooool0<?ooool2o`0000;o^KSI0_l00000
0onf^=_o0000om>i`@03om>i`@07o`000?oB^/;od[[2om:j`_l0003ofKRho`000004omVi^@06o`00
0?oI^[_ofKZko`000?oJ^;Oo00001?oJ^[P00ol0003ofkbjom^l^P02om^l^P05o`000?oK_[cofkjl
om^n_?l000001OoM`[h2o`000003om_5`ol0003og/_600?og/_600Go0000on3?aooPclOoh<o7o`00
0002on;Cb@;o00000ooNfm<00ol0003ogmkCo`000003on3Nd`04o`000?oPgM;oh=gBo`0000;oh=[A
0_l00003omKIfP03o`000?oDdMKoe=7F00?o000000?oaLOKo`000?l000000_l0;kL01Ol0003o9Tk4
obI>a?l0003oBVG<00;o00000ombM/L00ol0003oS8C6ohb4aP02ohb4aP03o`000?nOSl?oWho300;o
Who30_l00004ok:Na003o`000?nnY;oo_ZBo00?o_ZBo0_l00005olba_`03o`000?oB_LGo000000?o
f;fo00?o0000omo;a?oObl@00_oObl@00ol0003oim[8o`000002o`000003onoUa?l0003ol?;300?o
000000?obOR[o`000?l000000_l000000oo2k_7o0000o`000002ol7Cj003o`000?o9d^7o000000Co
`K_E00?o0000olBjdOl000000onlZlP01_l0003o_J[6okfZa_l0003o]j31o`0000Go^9no00?o0000
okNM__l000000oncUk/00ol0003o/YJjok:F^P03ok:F^P?o000000?o[Y:io`000?n/T;T01?n/T;T0
0ol0003oZ8jjojR>^P02ojR>^PCo000000?oYXfko`000?nRS;d00onRS;d00ol0003oWX^ooij;_`02
oij;_`03o`000?nIRL;oVHW200;oVHW200?o0000oi>9aOnCRLD00_nCRLD01Ol0003oSXW:ohj9b_n>
RL[o000000CoRHc@00?o0000ohF@eon5T=L00_n5T=L01_l0003oQi[NohNJg_l0003oQi[No`0000?o
T:SV0ol00004oj_2jP03o`000?o3d>Co000000?oaMGV0_l00003om?Jg@;o000000CocMoVo`000?oo
oooo00002?ooool003cooooo00?o0000ooooooooool0<?ooool00ol0003o^KSIo`000004okJhf`05
o`000?oC^L7odkW1om>i`Ol000001?oB^/800ol0003ofKViomVi^@03omVi^@05o`000?oI^[_ofKZk
omVj^ol000001?oJ^[P00ol0003ofkbjom^l^P03om^l^P05o`000?oK_[cofkjlom^n_?l000001?oM
`[h00ol0003oglK0omo6`002o`0000?og/_600Go0000on3?aooPclOoh<o7o`000003on;Cb@07o`00
0?oTel[o0000omkKdol0003ogmkCo`000003on3Nd`04o`000?oPgM;oh=gBo`0000?oh=[A00Go0000
omkFcol0003oe]WJo`000002omCAeP06o`000?o@b=;od<SBom38d_l0003oaLOK0_l000001Ol0;kOo
0000o`000?lVC/Co000000;oBVG<1Ol00004ohb4aP03o`000?nOSl?oWho300?o00001OnbW/@00ol0
003o_ZBookjT_`02okjT_`04o`000?o3[/Go`jk5o`0000?oc;6o00Oo0000om:maOoB_LGod[g5o`00
0?oH_Koo000000Cogl_400Co0000onOJb?oWf/So00000_o/jl/3o`000004omkm_Ol0003obOR[o`00
00?o[^ch0_l00004ol7Cj0;o00001Oo1^mD2o`0000Co_:_800?o0000okfZa_l000000ongX<400ol0
003o^9nookRO_`02okRO_`;o00001?ncUk/00ol0003o/YJjok:F^P02ok:F^P;o00001?n^T[T00ol0
003o[92iojb@^@02ojb@^@04o`000?nXS[[oZ8jjojR>^P;o00001?nVSK/00ol0003oXXbmoj:<_@03
oj:<_@05o`000?nNRkooWX^ooij;_ol000001OnIRL800ol0003oThW5oi>9a@0Ho`0000;oV[7W00?o
0000oj_2j_n[`^X00_n[`^X2o`0000?oaMGV00Ko0000olCMjoo4gN_o0000om?JgOl00003olgOiP?o
00002?ooool003gooooo00?o0000ooooooooool0<?ooool00ol0003o][SKokJhf`04okJhf`03o`00
0?oC^L7o000000God[[200?o0000omVi^OoI^KT00_oI^KT00ol0003ofKZkomVj^`02omVj^`;o0000
0ooJ^[P00ol0003ofkbjom^l^P02om^l^P05o`000?oM`;co0000om^n_?l000001?oM`[h02Ol0003o
glK0omo6`?oOa/3o0000on7:`_l0003og/_6o`000003on3?a`05o`000?oRdlWoh]?9on;CbOl00000
0ooTelX5o`000005on3Ndol0003oh=gBon3Md_l000000ooPf]401?l0003og]K?omkFcooNe/l2o`00
0003omCAe_l0003od<SB00?od<SB0_l000001?o2_=Co0000o`000?l0;kL3o`0000;oBVG<00Co0000
ofejcom]N/ooKG[?2?l00002oj6Fb@03o`000?nbW/Co/Yk400Co/Yk400Co0000okjT_onnY;oo0000
0oo3[/D01?l0003oc;6oolba_ol00005om:ma@03o`000?oOblCogl_400;ogl_400Co0000onOJb?oW
f/So00000oo/jl/01ol0003oj_S8o`000?l0003obOR[o`000?n^k?P00ol00002okKCk`06o`000?o1
dnSo0000o`000?nk^m[o00000oo1^mD2o`000003okV[c?l0003o_:_800?o_:_80_l00005okNP`@06
o`000?nhWkoo^9noo`000?ncVKco00001OncUk/01_l0003o/YJjok:F^_l0003o/9>io`0000Co[Y:i
00?o0000ojb@^On/T;T00on/T;T3o`000003ojV?^_l0003oYXfk00CoYXfk00?o0000oj:<_OnRS;d0
0_nRS;d00ol0003oWX^ooij;_`02oij;_`03o`000?nIRL;oVHW200Go00000_nISlL01Ol0003oUY7<
oiJAc?nFTLco000000CoTYCB00?o0000oi2JfOn@V]T00_n@V]T01_l0003oTZ?Poi:Sh?l0003oTZ?P
o`0000GoV[7W1?l00002ok7:k@03o`000?o5eNKo000000?oa=g[0_l00003olgOiP04o`000?nmi?;o
0000o`0000Sooooo000nooooo`;o0000<Oooool00ol0003o][SKokJhf`03okJhf`;o00001OoB^/80
0ol0003od[_4o`000003omVi^@05o`000?oI^[_ofKZkomVj^ol000000_oI_;d00ol0003of[Zho`00
0004om^l^P05o`000?oM`;cogL2lomg0_?l000001?oM`[h01Ol0003oglK0omo6`?oOa/3o000000?o
hL[20_l00003on3?a`04o`000?oRdlWoh]?9o`0000?oi=O:00Co0000onGIb_oUfL[o00000_oUf/X2
o`000003on3Md_l0003oh=[A00;oh=[A00Go0000omkFcooNe/oog]K?o`000002om_?c@03o`000?o@
b=;od<SB00;od<SB00?o0000olbncOl000000_o2_=@3o`000003o`a8a_l0003o000000;oBVG<00Go
0000ofejcom]N/ooKG[?o`000004ohZ:c@03o`000?nQU/WoXIK900;oXIK900?o0000ok:Na?nbW/@0
0onbW/@00ol0003o_ZBoo`000004ol>^a@03o`000?o</Koo000000Kod[g500Go0000omo;a?oOblCo
gl_4o`000003onOJb005o`000?o/jl_ok>_;o`000?oZn<P00_l000001?o9n:_o0000o`000?l00005
okKCk`;o00001?nk^mX00ol0003o`K_Eo`000004okV[c006o`000?nlZlSo_:_8o`000?nfX<;o0000
1OngX<400ol0003o^9noo`000003ok>I_003o`000?ncUk_o/iNk00;o/iNk00?o0000ok:F^_l00000
0_n`TkT00ol0003o[Y:iojjB^@03ojjB^@04o`000?n/T;Wo[92iojb@^@;o00001?nYSkX00ol0003o
YXfkojJ=^`02ojJ=^`03o`000?nRS;goXXbm00;oXXbm00?o0000oij;_onNRkl01Ol00002oif?a003
o`000?nISlOoVHo700?oVHo700Go0000oiJAc?nFTLcoUY7<o`000004oi:DdP03o`000?n@V]WoT9[I
00;oT9[I00Ko0000oi:Sh?nBXn3o0000oi:Sh?l00002oiZai`?o00001Onab^d2o`000004olCMjol0
003o0000o`0000;o_^Sb00?o0000olgOi_l000000onmi?82o`0000Oooooo0010ooooo`03o`000?oo
oooooooo02oooooo00?o0000okJhfol000000_l00002ok6ig`05o`000?oB^/;od[[2om:j`_l00000
0ooB^l@00ol0003ofKVio`000004omVj^`05o`000?oI_;gofKbmomVl_Ol000001?oK_;X00ol0003o
gL2lomg0_002omg0_0;o00000ooM`[h01Ol0003oglK0omo6`?oOa/3o000000?ohL[200Go0000on?>
`ol0003oh<o7o`000002on;Cb@05o`000?oTel[oi=O:onCGb_l000000_oUfLX01_l0003oiM[:onGJ
b_oUf/[o0000onGIb@?o000000?oh=[Ao`000?oNe/l00_oNe/l01Ol0003oflo=om_?cOoKclgo0000
00?od<SB00Ko0000olbncOo<_/goc;k=o`000?o2_=@3o`0000;o34S60_l000000om:ILco0000ofej
c`03ofejc`03o`000?n:R/goRX[=00;oRX[=00Go0000oj6FbOnQU/WoXIK9o`000005ok:Na0;o0000
1Oo3[/D2o`0000Kod[g500Go0000om[<bol0003ogl_4o`000003onOJb007o`000?o/jl_ok>_;o`00
0?oZn<So0000omkm_@03o`0000;oYLke00?o0000okKCkol000000_l000000onc^]oo0000ok^kfP03
ok^kfP;o00001OniZl`00ol0003o_:_8o`000003okJP`P03o`000?ngX<7o]j3100;o]j310_l00004
ok>I_003o`000?ncUk_o/iNk00;o/iNk0_l00004ok2C^@03o`000?n^T[Wo[Y:i00;o[Y:i00Ko0000
ojb@^Ol0003o0000ojb@^_l00004ojV?^P03o`000?nVSK_oYXfk00;oYXfk00?o0000oj:<_OnRS;d0
0_nRS;d3o`0000;oXXo100?o0000oif?a?nMSl@00onMSl@00ol0003oVHo7oiV?a`02oiV?a`05o`00
0?nFTLcoUY7<oiJAc?l000001?nBU=801?l0003oT9[Ioi2JfOn@V]T9o`0000?oXkc[00?o0000ok7:
kOl000000_l000000ondf?;o0000o`000005okkXlP;o00000onmi?83o`0000Oooooo0011ooooo`03
o`000?oooooooooo02oooooo00?o0000ok6igona^Ml01?na^Ml00ol0003od[[2o`000005om:ka003
o`000?oI^[_ofKZk00;ofKZk00?o0000omVl_OoI_;d00_oI_;d2o`0000?ofkbj00Go0000omg0_?oM
`;cogL2lo`000002omk3_P03o`000?oM`[ko000000?oglK000Go0000on7:`_oQb/;ohL[2o`000003
on?>``;o000000?oh]?9o`000?oTelX00_oTelX01?l0003oiMW:onGIb_l00003onGJbP04o`000?oU
fLWoiMW9o`0000;oi=O900Go0000omkFcooNe/oog]K?o`000003om_?c@05o`000?oHb<_o0000om38
d_l000001?o<_/d2o`0000;o_K7>1?l000001?lhIM?o0000o`000?l00003ofejc`03o`000?n:R/go
RX[=00;oRX[=00?o0000oj6FbOnQU/T00_nQU/T00ol0003o/Yk4ok:Na002o`000003okJYc?l0003o
`jk500?o`jk500?o0000olVkcOl000001OoB_LD01?l0003of/c;om[<booJc</2o`0000;oim[800Oo
0000onc[boo/jl_o0000on[hb?l0003og_fm00?o00000_nUc_D3o`0000Go/k[O00Ko0000ok^kf_l0
003o0000okBZcol00005okV[c0;o00001?nfX<800ol0003o]j31okNP`@02o`000003ok>I_Ol0003o
/iVl00?o/iVl00?o0000ok>G^oncUk/00_l000000onaU;Wo0000ok2C^@03ok2C^@03o`000?n^T[Wo
[Y:i00;o[Y:i0_l00003ojb@^P03o`000?nYSk[oZHnj00?oZHnj00?o0000ojJ=^onVSK/00_nVSK/4
o`000003ojF@_ol0003oXXo100?oXXo100?o0000oif?a?nMSl@00_nMSl@00ol0003oVHo7oiV?a`02
oiV?a`05o`000?nFTLcoUY7<oiJAc?l000000onBU=85o`0000;oVZKO00Ko0000oib`i_nL/>Ko0000
oib`i_l00003oj>lj`Co000000?o]=Sbo`000?l000000_n^jOT00ol0003o_^Sbo`000007o`0000;o
oooo00?o0000ooooooooool01Oooool004;ooooo00?o0000ooooooooool0;oooool00ol0003o/KWO
ok6ig`03ok6ig`;o00001OoB^l@00ol0003odKg7o`000002omVj^`03o`000?oI_;gofKbm00;ofKbm
00Ko0000omZo_ooJ_koo0000om^l^_l00004omg0_004o`000?oN`kkog/>nomk3_P;o00000_oOa/00
0ol0003ohL[2on7:`P02on7:`P06o`000?oSc/?ohlk3on?>`ol0003oi=;40ol000000ooTel[o0000
onGIbP02onGIbP04o`000?oUf/[oiM[:o`0000;oiMW900Co0000onCGbOoTelWoi=O90_l000000ooN
e/oo0000om_?c@02om_?c@04o`000?oHb<_of<S;omS8b`;o00000oo<_/d00ol0003oakK9o`000003
okfacP04o`000?l0?L7o0000o`0000;o>6GC00?o0000ofejcom]N/l00_m]N/l01Ol0003oRX[=ohZ:
cOn:R/go000000CoXIK900?o0000ok:Na?l000001?nfZL`01?l0003o`jk5ol>^aOl00003olVkc@05
o`000?oB_LGod[g5om:maOl000001?oJc</01Ol0003ohMkBo`000?oWf/So000000;ok>_;2Ol00003
ojRfh`03o`000?nc^]oo/k[O00;o/k[O0_l00004okBZc`03o`000?niZlco^J_<00;o000000?o/j34
o`000?nfX<800onfX<800ol0003o]j31o`000004ok>I_@03o`000?ncVKco/iVl00;o/iVl0_l00003
ok6D^@03o`000?n`TkWo/9>i00;o/9>i00?o0000ojjB^On^T[T00_l000000on^T[Wo0000ojb@^P03
ojb@^P03o`000?nYSk[oZHnj00;oZHnj00Co0000ojJ=^onVSK_oYXfk0_l00005ojF@_`05o`000?nR
Sl7oXXo1oj:?`Ol000001?nMSl@01?l0003oVHo7oiV?aonISlL9o`0000;oVZ3H00?o0000oiZVgonJ
Y]l00onJY]l00ol0003oW;3Voib`iP05o`0000?oZLkc0_l00004ojkYn@Go00001oooool00ol0003o
ooooooooo`05ooooo`00@oooool2o`00033ooooo00?o0000ok6igol000000_l000000on]^N?o0000
om:ka003om:ka007o`000?oA_LOodKg7om6maol0003ofKZko`000004omVl_@05o`000?oJ_koof[no
omZo_ol000001?oM`;`00ol0003og/>nomk3_P02omk3_P05o`000?oPal3o0000omo6`?l000000ooQ
b/801Ol0003ohlk3on?>`ooSc/?o000000;oi=;400?o0000onKEaOoVeLD00ol000001OoUfL[o0000
onGJb_oUf/[o000000;oiMW900Go0000onCGbOoTelWoi=O9o`000002on?Cb0?o000000?oflo=o`00
0?oHb</00_oHb</01_l0003odl78om?1b?l0003oc;k=o`0000?oakK900Ko0000okfac_l0003o^JS8
o`000?l0?L42o`0000;o>6GC1Ol00004ohZ:c@03o`000?nQU/WoXIK900?o00001OnfZL`00ol0003o
`jk5o`000005olVkc@03o`000?oB_LGo000000Cof/c;00Co0000on7Nd_oQg];ohMkB0_l000000oo/
jl_o0000o`000004o`0000;oVk3V00?o0000ojRfhonX]^<00onX]^<01_l0003o/k[Oo`000?l0003o
[ZSBo`0000Co]:[?00?o0000okV[c?l000001?ncX<@01?l0003o]Z32okJP`_nfX<82o`0000Go/iVm
00Co0000ok>I_?ncVKco/iVl0_l00005ok6D^@03o`000?n`TkWo/9>i00;o/9>i0_l00003ojjB^@03
o`000?n/T;[o[92j00;o[92j00?o0000ojV?^_nYSkX00_nYSkX01_l0003oYXfko`000?l0003oZ96n
o`0000GoYI2o00?o0000oj:?`OnRSl400_nRSl401?l0003oWHo4oif?a?nMSl@4o`0000;oX9[>00Go
0000oifLd_nMW=;oWIcBo`000005oiZPf004o`000?nJY]ooVZKOoiZVg`Co000000GoXlC`o`000?nS
a?3o0000ojW>l`03o`000003oj?Uo?l0003o[^Wi00Go00002_ooool00ol0003oooooooooo`05oooo
o`00AOooool00ol0003oooooooooo`0^ooooo`03o`000?n]^N?o[KWS00?o[KWS00Co0000om:ka?oB
^lCo00001OoA_LL00ol0003ofKbmomVl_@02omVl_@03o`000?oJ_koof[no00;of[no0_l00002omg0
_003o`000?oN`kkog/>n00;og/>n00Co0000on37`?oPal3oh<O00_l00002on7:`P05o`000?oSc/?o
hlk3on?>`ol000000_oTd/@01Ol0003oi]G5onKEaOoVeLGo000000;oimO50_l000000ooUf/[o0000
onGIb@02onGIb@04o`000?oTelWoi=O9o`0000?ohm?800Co0000on3?aooPclOo00000ooHb</00ol0
003odl78om?1b002om?1b003o`000?o7]/WoakK900?oakK900Oo0000okVXb?niZ<So^JS8o`000?l0
?L7o000000;o>6GC00Co0000ofAofOmTOmWoI7oI2?l00002oj>Qd`03o`000?nfZLco]ZW<00?o]ZW<
0_l00006olVkc@;o00001?oJc</01Ol0003ohMkBon7Nd_oQg];o000000;oiO7E00Ko0000omkncol0
003o0000ohjYj?l00004oi^`iP04o`000?nX]^?oZ;KSojRfh`?o00001?n^Z=801?l0003o]:[?okBZ
condZ/l2o`0000Go/j3400Ko0000okJP`_nfX<;o0000ok:I__l00005ok>I_@06o`000?ncVKco/iVl
o`000?naUK[o00001OnaU;T01?l0003o/9>iok2C^On`TkT2o`0000Go[Y:i00Go0000ojb@^_n/T;[o
[92jo`000004ojV?^P;o00001?nXTKh00ol0003oYI2oojF@_`02ojF@_`03o`000?nRSl7oXXo100;o
XXo100Ko0000oif?a?l0003o0000oj>Ib_l00005oj2JcP05o`000?nMW=;oWIcBoifLd_l000001?nJ
X=P4o`0000;oX[_[00Go0000oj?4l?nSa?3o0000oj?4l003o`0000;oXnGl1Ol0000=ooooo`03o`00
0?oooooooooo00Gooooo0016ooooo`03o`000?oooooooooo02kooooo00?o0000ojfihon]^N<00_n]
^N<00ol0003od[_4o`000005om6ma`03o`000?oA_lWo000000;ofKbm00?o0000omZo_ooJ_kl00_oJ
_kl01_l0003ofl;1om_2`Ol0003ogL2lo`0000Cog/>n00Wo0000on37`?oPal3oh<O0o`000?oRbl7o
0000on7:`_l000000_oSc/<01Ol0003oi=;4onCBa?oTd/Co000000;oi]G500Ko0000onOGaOoWelGo
imO5o`000?oWelD3o`000003onGIbOl0003oi=O900;oi=O900Co0000on?Cb?oSdlSo00000ooPclL2
o`000003omS8bol0003odl7800Codl7800?o0000olNfbOo7]/T00_o7]/T2o`0000Co^JS81?l00000
0olhIM?o0000ofAof@02ofAof@05o`000?n8TmSoR9?HohRCf?l000001OnSXM<01ol0003o]ZW<okJY
c?nfZLco0000ok^ge_l000001Oo9^ld00ol0003odLgFo`000003om[<b`05o`000?oQg];ohMkBon7N
d_l000000_oUlMD01?l0003og_k?o`000?l00003ohjYj003o`000?nK/>KoVk3V00Go00000_nVYM@0
0ol0003o[ZSBojjXdP02ojjXdP06o`000?ndZ/oo0000o`000?n_WlKo00001OncX<@00ol0003o]Z32
o`000003ok:I_P03o`000?ncVKgo/iVm00?o/iVm0_l00003ok6E^P03o`000?naU;Wo/IBi00;o/IBi
00Ko0000ok2C^On`TkWo0000ojnC^_l00005ojjB^@03o`000?n/T;[o[92j00;o[92j1?l000000on[
T[go0000ojRA_P03ojRA_P03o`000?nUT;ooYI2o00?oYI2o00?o0000oj:?`OnRSl400ol00004oj>I
bP03o`000?nPV/koX9[>00;oX9[>00Ko0000oifLd_nMW=;oWIcBo`000?nJX=P3o`000003oj:ei_l0
003oX[_[00CoX[_[00Co0000oj?4l?l0003o00000_nMhOd5o`00013ooooo00?o0000ooooooooool0
1Oooool004Oooooo00?o0000ooooooooool0;_ooool00ol0003o[KWSojfih`03o`0000GodKg700Oo
0000om6obOoA_lWodKo9o`000?oI_;go000000?of[no00?o0000om_2`OoK`/400_oK`/400ol0003o
g/>nomk3_P02omk3_P05o`000?oPal3oh<O0on37`?l000000ooRbl42o`000003on?>`ol0003oi=;4
00;oi=;400Go0000onKEaOoVeLGoi]G5o`000002onOGa@04o`000?oWelGoimO5o`0000;oimO50ol0
00001OoTelWo0000on?Cb?oSdlSo000000?oh<o700Co0000omg9a_oMbLKo00001OoC`LP00ol0003o
c[W6o`000002olNfb@04o`000?o2[LKo`Zg6o`0000?o^JS80ol000001?lJHmSo0000o`000?l00003
ofAof@05o`000?n8TmSoR9?HohRCf?l000001OnSXM<00ol0003o]ZW<o`000003ok^geP05o`000?o9
^lgobK_=olVkcOl000000ooAcMH00ol0003of/c;o`000003on7NdP05o`000?oUlMGoiO7Eo`000?oN
o/l02Ol00002oifPeP03o`000?nVYMCoYZGD00?oYZGD00Co0000ojjXd_n^Z=;o[ZSB0_l00004ojnO
aP03o`000?ncX<Co/j3400;o/j340_l00004ok:I_P03o`000?ncVKgo/iVm00;o/iVm0_l00004ok6E
^P03o`000?naU;Wo/IBi00?o/IBi0_l00003ojnC^P03o`000?n^T[Wo[Y:i00;o[Y:i00Co0000ojb@
^_n/T;[o[92j0_l00005oj^B_@05o`000?nXTKkoZ96nojRA__l000001?nUT;l4o`0000;oYYW700?o
0000oj>Ib_nSVLX00_nSVLX00ol0003oX9[>oj2JcP02oj2JcP03o`000?nMW=;oWIcB00?o00001OnR
]NH01?l0003oX[_[oj:kjonR^n/3o`000004oigQoOl0003o0000o`0001Kooooo00?o0000oooooooo
ool01?ooool004Sooooo00?o0000ooooooooool0;_ooool2o`0000?oYk[W00Go0000om6maooA_LOo
dKg7o`000005om6ob@05o`000?oJ_koof[noomZo_ol000001OoK`/42o`0000;og/>n00Go0000on37
`?oPal3oh<O0o`000004on;;`@04o`000?oSc/?o0000o`0000;oi=;400Go0000onKEaOoVeLGoi]G5
o`000002onOGa@04o`000?oWelGoimO5o`0000?oimO500?o0000onKEaOoVeLD00_l000000ooSdlSo
0000on3?a`02on3?a`04o`000?oMbLKogLW6omg9aP;o00000ooC`LP01_l0003oc[W6oljia_l0003o
akK9o`0000Co`Zg600?o0000okVXb?l000000_ndXL@2o`0000?o6V?H0_l000000omTOmWo0000ohRC
f003ohRCf003o`000?nSXM?oXj7C00;oXj7C0_l00005ok^geP03o`000?o9^lgo000000GodLgF0ol0
00001_oQg];o0000onGaeOoUlMGo0000omknc`;o00000_n;U=L01Ol0003oU9_GoiBKeonDVmOo0000
00CoWJ3F00?o0000ojJUe?nVYM@00_nVYM@01_l0003o[ZSBo`000?l0003oZYg8o`0000Go[io600Ko
0000ok>Pa?ncX<Co0000ojnI`?l00005ok:I_P06o`000?ncVKgo/iVmo`000?n`U[_o00001OnaUKX0
1?l0003o/IBiok6D^OnaU;T2o`0000Co[i>j00?o0000ojjB^On^T[T00on^T[T3o`000003ojfD_?l0
003oZi:m00CoZi:m00?o0000ojRA__nXTKh00_nXTKh4o`000003ojVIa_l0003oYYW700CoYYW700Go
0000oj>Ib_nSVL[oXiW:o`000003oj2JcPCo00000onT/>401?l0003oX[GVoj:ei_nR]NH5o`000004
oigNoOl0003o0000o`0000;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04oooo
o`00BOooool2o`0002oooooo00?o0000ojNjionW^^L00_nW^^L00ol0003odKg7o`000005om6ob@;o
00000ooJ_kl00ol0003ofl;1om_2`@02om_2`@06o`000?oLa/?og<K3o`000?oN`kko00000_oPal00
0ol0003oh/_1on;;`@02on;;`@08o`000?oSc/?ohlk3o`000?oUd/Co0000onCBa?l00002onKEa@04
o`000?oWelGoimO5o`0000?oimO500Co0000onOGaOoWelGo00000ooVeLD01?l0003oiM?4o`000?l0
0003on3?a`04o`000?oMbLKogLW6o`0000;ofL?500?o0000om?1b?l000001?o>^LH00ol0003o`Zg6
ol:]aP03ol:]aP;o00001?ndXL@2o`0000;o6V?H00Co0000oe:6iOl0003o00001?n8TmP00ol0003o
Xj7Co`000002o`000003ojF`gol0003o^kOF00Co^kOF0_l00005om7=eP03o`000?oGh]ooen;O00?o
000000?oiO7Eo`000?l000000_l00004oh^De`05o`000?nDVmOoU9_GoiBKeol000000onMX=H01?l0
003oYZGDojJUe?nVYM@3o`0000CoZYg800?o0000ojnOa_n_WlH00_n_WlH00ol0003o/j34o`000003
ojnI`003o`000?nbVKko/YVn00;o/YVn00?o0000ok>I_Ol000000_n`U[/00ol0003o/IFjok6E^P03
ok6E^P06o`000?naU;Wo/IBio`000?n`U;[o00001On_TkX01?l0003o[Y:iojjB^On^T[T2o`0000Co
[IBl00?o0000oj^B_On[T[d00_n[T[d01?l0003oZ96nojRA__nXTKh2o`0000GoZIW600?o0000ojJI
aonVVLL00_nVVLL00ol0003oXiW:oj>IbP05o`0000;oYjkL00?o0000ojB`hOnT/>400_nT/>44o`00
00?oWm_l0ol00005ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool004_o
oooo00?o0000ooooooooool0;Oooool00ol0003oYk[WojNji`03o`0000GodKo900Ko0000om73c?oA
`lco0000omZo_ol00004om_2`@03o`000?oLa/?og<K300;og<K300Go0000on37`?oPal3oh<O0o`00
0003on;;`@04o`000?oSc/?ohlk3o`0000?oiM;40ol000001OoVeLGo0000onOGaOoWelGo000000;o
imO500Go0000onOGaOoWelGoimO5o`000002onKEa@08o`000?oUdlCoiM?4o`000?oSclCo0000on3?
aol00002omg9aP03o`000?oI`lGofL?500;ofL?500?o0000oljia_o>^LH00_o>^LH2o`0000?o`Zg6
0_l000000onmY/?o0000okBQa003okBQa006o`000?n/VlKo0000o`000?lJHmSo00000_mBQ^D6o`00
00GoYK3O00?o0000ok^ge_nk]mH00_l00002ol7;hP05o`000?oAcMKodLgFom7=e_l000000_oGh]l0
1?l0003oe_ORomKgh_oFmn85o`0000CoRiCG00Go0000oiBKeonDVmOoU9_Go`000002oifPePGo0000
0_nTV/X00ol0003oZYg8ojZMb002ojZMb003o`000?n_WlKo[io600;o[io60_l00004ojnI`003o`00
0?nbVKko/YVn00;o/YVn0_l00004ok2F^`03o`000?naUK[o/IFj00;o/IFj00?o0000ok6D^Ol00000
0_n`U;X00ol0003o[i>jojnC^P03ojnC^P06o`000?n^T[Wo[Y:io`000?n_U[go00001?n]U;`00ol0
003oZi:moj^B_@03oj^B_@?o000000?o[9[5o`000?nYVLH01?nYVLH00ol0003oYYW7ojJIa`02ojJI
a`?o00000_nZ[MT00ol0003oYjkLojN^g003ojN^g004o`000?nT/>7o0000o`0000;oXm[k00?o0000
oioKo?l000000_l00009ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01?ooool0
04cooooo00?o0000ooooooooool0;Oooool2o`0000?oX[_[00Go0000om6obOoA_lWodKo9o`000004
om73c003o`000?oK`/7ofl;100;ofl;100?o0000omc6`ooLa/<00ooLa/<2o`000003on37`?l0003o
h/_100;oh/_100Go0000on?>`ooSc/?ohlk3o`000003onGBa003o`000?oVe<Coi]C400;o000000Go
imO5o`000?oWelGoimO5o`000003onOGa@04o`000?oVeLGoi]G5o`0000;oiM?400Go0000on??a?oS
clCohlo4o`000003omg9aP04o`000?oI`lGofL?5omW3a@;o00000oo>^LH01_l0003obK;3olVb`ol0
003o`Zg6o`0000Co_JK300Co0000okBQa?ndXLCo]:741_l00002oe:6i@03o`000?n3X>KoPj3V00;o
Pj3V00?o0000ojF`gonU/=l00onU/=l00ol0003o^kOFo`000005ol7;hP03o`000?oAcMKo000000;o
en;O00Co0000omKgh_oFmn;oe_OR4Ol00002oijFc003o`000?nTV/[oY9[:00?oY9[:00Ko0000ojZM
b?nZWLSoZYg8o`000?n_WlH3o`000003ojbH`_l0003o[iW000?o[iW000?o0000ok:I__nbVKh00_l0
00000on_U[co0000ok2F^`03ok2F^`03o`000?naUK[o/IFj00;o/IFj0_l00004ok2D^P03o`000?n_
Tk[o[i>j00;o[i>j00?o0000ojjB^Ol000000_n_U[d00ol0003o[IBlojfD_003ojfD_004o`000?n[
T[goZi:moj^B_@;o00001?n/V/D00ol0003oZIW6ojVIaP02ojVIaP03o`000?nVVLOo000000;o0000
00?o[JgGo`000?nZ[MT00onZ[MT01?l0003oYjkLojN^g?nW[]`3o`0000?oXm[k0ol0000=ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool004gooooo00?o0000ooooooooool0
;Oooool00ol0003oX[_[oj:kj`02oj:kj`03o`000?oA_lWo000000CodL?<00?o0000om76col00000
0ooK`/400ol0003og<K3omc6``02omc6``03o`000?oMbLGogLW500;o00000ooRbl401?l0003ohlk3
on?>`ol00003onGBa006o`000?oVe<Coi]C4onKDa?l0003oimK50ol000001OoWelGo0000onOGaOoW
elGo000000;oi]G500Go0000onGCa?oUdlCoiM?4o`000003on??a0;o000000?ogLW6o`000?oI`lD0
0_oI`lD01_l0003oe;g3omBm`ol0003oc[W6o`0000CobK;300?o0000okfV`onmY/<00onmY/<01_l0
003o]:74okBQa?l0003o/9[1o`0000;oZ9G11?l000000omBQ^Go0000oh>PiP03oh>PiP03o`000?nU
/=ooYK3O00;oYK3O0_l00006ol7;hP?o000000?oen;Oo`000?oFmn800_oFmn84o`0000?oRhW<00?o
0000oi2=c?n@SL`00_n@SL`01Ol0003oUi;<oiNBc?nGT/co000000CoWYK<00?o0000ojBJb_nTV/X0
0_nTV/X01?l0003oZYg8ojZMb?nZWLP2o`0000Go[9S200?o0000ojnI`?n_VL000_n_VL02o`0000?o
[iJl00?o0000ok2F^on`U[/00_n`U[/00ol0003o/IFjok6E^P02o`000003ok2E^ol0003o/9Bj00?o
/9Bj00?o0000ojnC^_n_TkX00_n_TkX2o`0000Co[iJm00?o0000ojfD_?n]U;`00_n]U;`01_l0003o
Zi:mo`000?l0003o[ic4o`0000Go[9[500Co0000ojVIa_nYVLKoZIW60_l00005ojf]e`04o`000?nZ
[MWoZZgIojZ]f@Co00000_nVf_X4o`00013ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`04ooooo`00C_ooool2o`0002kooooo00?o0000oj:kjonR^n/01?l00003om73c007o`000?oA
a/oodLK?om76col0003ofl;1o`000004omc6``09o`000?oMbLGogLW5omg9aOl0003oglg7o`000?oR
bl7o000000;ohlk300Go0000onGBa?oUd/CoiM;4o`000003onKDa004o`000?oWe/GoimK5o`0000;o
imO50ol000001OoWelGo0000onKEaOoVeLGo000000;oiM?400Go0000on??a?oSclCohlo4o`000002
on3;``05o`000?oI`lGofL?5omW3aOl000001?oD_L<00ol0003obK;3olVb``02olVb``;o00001Onm
Y/<00ol0003o]:74o`000003ok2J`@04o`000?nXUL7oZ9G1ojRE`@Go00001?n3X>H01?l0003oYK3O
o`000?l00002ojG4k`04o`000?o1bn;o`L_Rol7;hP;o00000_o3hnl4o`000003omKgh_l0003o0000
00?oQhG;00Go0000oh^9c?n;RLcoRhW<o`000004oi2=c005o`000?nGT/coUi;<oiNBc?l000001?nN
U/`01_l0003oY9[:ojBJb_nTV/[o0000ojZMb0;o000000?oZ9K3o`000?n/V<801?n/V<801?l0003o
[iW0ojnI`?n_VL02o`0000Go[iJl00?o0000ok2F^on`U[/00_n`U[/2o`0000?o/9Fk00?o0000ok2D
^_n`U;X00_n`U;X00ol0003o[i>jojnC^P02o`000003ok2G_Ol0003o[iJm00?o[iJm00?o0000ojfD
_?n]U;`00_n]U;`2o`0000Co[ic400?o0000ojbJaOn/V/D00_n/V/D01_l0003oZIW6o`000?l0003o
/:kFo`0000Go[JgG00Co0000ojZ]fOl0003o00000_nYg?T01?l0003oY][jo`000?l0000Eooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool0053ooooo00?o0000ooooooooool0
;?ooool2o`0000CoW;g_00?o0000om73c?l000001OoAa/l2o`0000?og<K300Go0000omg9aOoMbLGo
gLW5o`000003omo=a`?o000000?ohlk3o`000?oUd/@00_oUd/@01?l0003oi]C4onKDa?l00002onOF
a@05o`000?oWelGoimO5onOGaOl000000_oWel@2o`000005onKEaOl0003oiM?4onGCa?l000000ooS
cl@01?l0003oh<_3on3;`ooPbl<2o`000003omW3aOl0003oe;g300Coe;g300Go0000olVb`oo9//?o
bK;3o`000002olB/`P03o`000?nmY/?o_JK300;o_JK30_l00004ok2J`@04o`000?nXUL7oZ9G1ojRE
`@?o00000_lbR^d6o`0000GoYLC_00?o0000ol7;h_l000000_o3hnl2o`0000?o^?O`1?l00003ohN5
b`03o`000?n;RLcoRhW<00;oRhW<00Go0000oi2=c?n@SLcoT8g<o`000003oiNBc003o`000?nNU/co
WYK<00;oWYK<00?o0000ojBJb_nTV/X00ol00004ojRF``03o`000?n/V<;o[9S200;o[9S200Ko0000
ojnI`?l0003o0000ojfE__l00005ojnF_004o`000?n`U[_o/9Jkok2F^`;o00001On`UK/00ol0003o
/9Bjok2D^P02ok2D^P;o00001?n`Ukd01Ol0003o[iJmojnF_On_U[go000000;o[IBl0_l000000ona
W/Co0000ojnLa003ojnLa003o`000?n/V/Go[9[500;o[9[50_l00004ok2^eP03o`000?n][MOo[JgG
00;o[JgG0_l00003ojWLn@?o00006?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Cooooo001Aooooo`03o`000?oooooooooo02gooooo00?o0000oibmkonL_Nl00ol00005om76c`06
o`000?oBb];od/[Bo`000?oLa/?o00000ooMbLD00ol0003oglg7omo=a`02omo=a`03o`000?oQdLSo
hM7800?o000000GoiM;4o`000?oVe<Coi]C4o`000002onOFa@05o`000?oWelGoimO5onOGaOl00000
0ooWel@00ol0003oimG4o`000002o`000005onGCa?l0003ohlo4on??a?l000000ooPbl<01?l0003o
g<K3omc6`ol00005omBm``05o`000?o?]l;o0000olVb`ol000001?o4[<801_l0003o_JK3okfV`ol0
003o^:30o`0000Co/9[100Co0000ojRE`OnXUL7oZ9G11ol00004ogJ`m`04o`000?nUa>ooYLC_ojG4
k`Co000000?o`n?_o`000?nhmo000_nhmo05o`000005ohF3bOl0003oQhG;ohN5bol000001?n;RL`0
1Ol0003oT8g<oi2=c?n@SLco000000?oUi;<00Co0000oijFc?nNU/coWYK<1?l00002oj>Ca003o`00
0?nXU/?oZ9K300;oZ9K300?o0000ojbH`_n/V<800_n/V<82o`0000Co[IFn00?o0000ojnF_?n_U[`0
0_n_U[`01_l0003o/9Jkok2F^ol0003o/9Jlo`0000Go/9Fk00Co0000ok2D^_n`U;[o/9Bj0_l00005
ok2G_@03o`000?n_U[go[iJm00;o[iJm0_l00004ok6Na006o`000?n_W<Co[ic4ojnLa?l0003o[9[5
0ol000000onc/MKo0000ok2^eP03ok2^eP03o`000?n][MOo000000;o000000?o[>3io`000?l00000
0_l0000Looooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool005;ooooo00?o
0000ooooooooool0;Oooool2o`0000?oU[oc00Go0000om76cooAa/oodLK?o`000004om;:dP;o0000
0ooMbLD01Ol0003oglg7omo=aooOcLOo000000?ohM7800?o0000on;DbOoRe<T00_l000000ooVe<Co
0000onOFa@02onOFa@04o`000?oWelGoimO5o`0000?oimO400Co0000onOEa?oWeLCo00000_oVdl@2
o`000003on??a?l0003oh<_300;oh<_300Co0000omc6`ooLa/?og<K30_l00003omBm``05o`000?o?
]l;ockO2olng`_l000001Oo4[<800ol0003o_JK3o`000003okRP`003o`000?n`V/7o/9[100;o/9[1
0ol000000onVT;oo0000oin;_`02oin;_`[o00000onKfod4o`000003okSgl?l0003o000000;o0000
0_n9PL<Eo`0000;oWI3500?o0000oj>Ca?nSTl@00_nSTl@00ol0003oZ9K3ojRF``02ojRF``06o`00
0?n/V<;o[9S2o`000?nZU;oo00001?n]UKh00ol0003o[iJlojnF_003ojnF_0;o00000on`U[`00ol0
003o/9Fkok2E^`02ok2E^`06o`000?n`U;[o/9Bjo`000?naV;ko00001On`Ukd01?l0003o[iJmojnF
_On_U[d2o`0000Go/Ik400Co0000ojnLa?n_W<Co[ic40_l00005ok>aeP04o`000?n`[]Ko/:kFok2^
eP?o000000?o[>3io`000?l000008?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00?ooooo001Cooooo`;o0000;oooool01ol0003oU[ocoiJolonF_o?o0000om76col000001?oBb]80
1_l0003odlkDom?>e?l0003ogLW5o`0000?oglg700Go0000on7Ab?oQdLSohM78o`000003on;Db@03
o`000?oSe/Wo000000;o000000?oimK5o`000?oWelD00_oWelD01?l0003oimO4onOGa?l00002onOE
a006o`000?oVdlCoi]?4onKCa?l0003oi=340_l00003on3;``04o`000?oLa/?og<K3o`0000;ofL72
00?o0000omBm`ol000001?o?]l800ol0003oa:c2olB/`P03olB/`P;o00001?nhX<001?l0003o/9[1
ok2J`On`V/42o`0000CoYY2o00Co0000oin;_onORkooWh^o1?l00004oeJkn`04o`000?nKfogo0000
o`0000;oN^;b1?l00003ohUo`P04o`000?n9PL?oRH73o`0000?oRh;400?o0000ohj5aOn>QLD00_n>
QLD01Ol0003oThW5oi>9aOnCRLGo000000?oV8c600?o0000oif@aOnMT<D00onMT<D01Ol0003oXi?4
oj>Ca?nSTlCo000000CoZ9K300?o0000ojbH`_l000000onZU;l00ol0003o[IFnojfE_P02ojfE_P04
o`000?n_U[co[iJlojnF_0;o00001?n`U[`00ol0003o/9Fkok2E^`03ok2E^`;o00000onaV;h00ol0
003o/9Nmok2G_@03ok2G_@?o000000?o/j35o`000?naW/@01?naW/@01_l0003o[ic4o`000?l0003o
][CGo`0000Go/k7F00Co0000ok2^e_l0003o00000_n]iOT2o`0002?ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`03ooooo`00EOooool00ol0003oooooooooo`0]ooooo`Ko00000ooB
b]801?l0003odlkDom?>e?oCc]@3o`0000?oglg700Co0000on7Ab?oQdLSo00000ooRe<T01?l0003o
hmK9on?FbOl00002onCHb@?o000000GoimO5o`000?oWelCoimO4o`000002onOEa005o`000?oVdlCo
i]?4onKCa?l000000_oTd<@01Ol0003oh/g3o`000?oPbl?o000000;og<K300?o0000omW1`_oI`L80
0_oI`L800ol0003ockO2olng`P02olng`P03o`000?o:/L7o000000?oa:c200?o0000oknV`?l00000
1?nhX<001_l0003o/9[1o`000?l0003o[IJoo`0000CoYY2o00Go0000oin;_onORkooWh^oo`000003
oiV7_`[o00000on;P<401Ol0003oRGo2ohUo`_n9Ol;o000000?oRH7300Go0000oh^2a?n;P/CoRh;4
o`000004ohj5a@05o`000?nCRLGoThW5oi>9aOl000000onHS<H00ol0003oWI35oif@a@02oif@a@05
o`000?nSTlCoXi?4oj>Ca?l000000onXU/<3o`0000CoZYBo00?o0000ojfE__n]UKh00_n]UKh01_l0
003o[iJlo`000?l0003o[YJmo`0000Co/9Jl00?o0000ok2E^on`UK/00_n`UK/2o`0000Co/IRn00?o
0000ok2G_On`Ukd00_n`Ukd2o`0000Co/j3500?o0000ok6Na?naW/@00_naW/@2o`0000Co][CG00?o
0000ok>ae_nc/MH00_nc/MH2o`000004ojgUnOl0003o0000o`0002Kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`03ooooo`00E_ooool00ol0003oooooooooo`0/ooooo`03o`000?nB
`OOoT/7g00?oT/7g00?o0000om;:d_l000000ooCc]@01ol0003oe=7GomCAeooDdMOo0000omo=aol0
00000_oQdLP01Ol0003oh]C9on;DbOoRe<Wo000000;ohmK900Go0000onCHbOoTf<Woi=S9o`000002
onGHb@;o000000?oimO4o`000?oWeL@00_oWeL@01?l0003oi]?4onKCa?l00002onC@a005o`000?oR
cL?oh/g3on;=`ol000000ooLa/<00ol0003ofL72omW1`P02omW1`P05o`000?o?]l;ockO2olng`_l0
00000oo:/L400ol0003oa:c2o`000003oknV`004o`000?nhX<3o^:30okRP`0;o00001?n]U[l01Ol0
003oYY2oojJ@_onVT;oo000000CoWh^o00Go0000oiV7_onIQkooVHNoo`000003oi>4`003o`000?n?
PL7oSh7100;oSh7100Co0000oh^0`On;P<7o00000on9Ol801Ol0003oRH73ohV1`on9PL?o000000?o
Rh;400?o0000ohj5aOn>QLD00_n>QLD01Ol0003oThW5oi>9aOnCRLGo000000CoV8c600Go0000oif@
aOnMT<GoWI35o`000002oj>Ca0Go00000_nVT/400ol0003oZYBoojZD_`02ojZD_`03o`000?n]UKko
[IFn00;o[IFn0_l00004ojjF_@03o`000?n`U[co/9Jl00;o/9Jl1?l000000onaVKoo0000ok6H_P03
ok6H_P03o`000?n`Ukgo/9Nm00;o000000?o]:;6o`000?ncX<D00oncX<D00ol0003o/Ik4ok6Na002
o`000003okVhf?l0003o][CG00?o][CG00?o0000ok>ae_l000001Ol0000Yooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool00oooool005Oooooo00?o0000ooooooooool0;?ooool01?l0
003oT/7goi;1monB`OL3o`0000?odlkD00?o0000omCAeooDdML00_oDdML3o`000003on7Ab?l0003o
h]C900;oh]C900Co0000on?FbOoSe/Wo00000ooTf<T01_l0003oiMS9onGHbOoUf<Wo0000onGHb@?o
000000GoimG4o`000?oVdlCoi]?4o`000002onC@a003o`000?oRcL?oh/g300;oh/g30_l000000ooL
a/?o0000omW1`P03omW1`P05o`000?oD_<;o0000olng`_l000001Oo:/L400ol0003o_jK0oknV`002
oknV`006o`000?nhX<3o^:30o`000?ncVkoo00001?n]U[l00ol0003oYY2oojJ@_`02ojJ@_`03o`00
0?nORkoo0000017o000000?oRh31o`000?n9Ol800_n9Ol801?l0003oRH73ohV1`ol00004oh^2a005
o`000?n>QLGoSXG5ohj5aOl000000onCRLD00ol0003oV8c6oiR<aP02oiR<aP03o`000?nMT<GoWI35
00Co00000_nRT<800ol0003oYY;1ojJB`@03ojJB`@03o`000?nZU;ooZYBo00;oZYBo1?l000000on/
UKoo0000ojjF_@03ojjF_@04o`000?n`U[co/9Jlok2F_0;o00001OnaVKl00ol0003o/IRnok6H_P02
ok6H_P;o00001?ndX/H01ol0003o/j35ok>PaOncX<Go0000ok6Na?l000001?ni^=P01?l0003o][CG
okJdeonf]=L5o`0002gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`00
F?ooool2o`0002gooooo0ol00003oho4n@03o`000?oCc]Co000000Coe=7G00Co0000omGEf?oEeMSo
eMGH0ol000000ooRe<Wo0000on?Fb@02on?Fb@04o`000?oTf<Woi=S9o`0000?oiMS900Co0000onGH
bOoUf<Wo00000_oUelP2o`000003onKCa?l0003oi=3400;oi=3400Go0000on;=`ooRcL?oh/g3o`00
0002omo9``;o00000ooI`L801Ol0003oe;c2omBl`_oD_<;o000000Kob[7100?o0000oknV`?noY/00
0_noY/000ol0003o^:30o`000003ok>K_`05o`000?n]U[oo[IJoojfF_ol000000onVT;l3o`0000;o
WHVm00?o0000oiR5_OnHQKd00_nHQKd01Ol0003oTh:noi>2__nCP[ko000000?oT82n00?o0000oheo
_on=Okl03_l00004ohj5a@05o`000?nCRLGoThW5oi>9aOl000000_nHS<H4o`0000;oWHg200?o0000
oj:@`_nRT<800_nRT<800ol0003oYY;1ojJB`@02ojJB`@04o`000?nZU;ooZYBoojZD_`;o00001On/
UKl01Ol0003o[YJmojjF_On^U[go000000;o/9Jl00?o0000ok6J`Ol000001OnaVKl01?l0003o/IRn
ok6H__naV;h2o`0000Go]:;600Co0000ok>PaOncX<Go/j350_l00005okVhf003o`000?nf]=Oo0000
00?o0000<Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo001Jooooo`03
o`000?oooooooooo02cooooo00?o0000oho4nOn?a?T01?l00003omCAe`05o`000?oEeMSoeMGHomGE
f?l000000ooGf=T3o`000003on?FbOl0003oi=S900;oi=S900Co0000onGHbOoUf<Wo00000_oUf<T0
1_l0003oiMO8onGGb?oUelSo0000onCFb0?o000000?oi=34o`000?oRcL<00_oRcL<02Ol0003oglW3
omo9`ooObL?o0000om_5`ol0003ofL72o`000004omBl`P03o`000?o:/L7ob[7100?ob[7100?o0000
olF/`Ol000000onoY/02o`0000Co/i^o00?o0000ojfF_on]U[l00_n]U[l3o`000003oj>=_Ol0003o
WHVm00?oWHVm00Go0000oiR5_OnHQKgoV8Fmo`000003oi>2_P05o`000?n@P;koT82noi20__l00000
0on=Okl01Ol0003oS7noohao_on<Okoo000000?oS83100Co0000ohj2`On>P/7oSX;13?l00002oiV:
``03o`000?nMSL;oWHg200;oWHg200Go0000oj:@`_nRT<;oXY32o`000004ojJB`@06o`000?nZU;oo
0000o`000?nZU<3o00001On/UKl00ol0003o[YJmojjF_@02ojjF_@;o00000onaV/400ol0003o/IVo
ok6I_`02ok6I_`06o`000?naV;ko0000o`000?neY<So00001OndX/H01_l0003o/j35o`000?l0003o
^kgKo`0000Go^KSH1?l0000dooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_oo
ool005_ooooo00?o0000ooooooooool0;?ooool3o`0000?oS/Sk00?o0000omCAeol000000ooEeMP0
1Ol0003oemSIomOHfOoGf=Wo000000?of=_I0ol000001OoTf<Wo0000onGHbOoUf<Wo000000;oiMS9
00Go0000onGGb?oUelSoiMO8o`000002onCFb003o`000?oSdlSohm?800;o00000ooRcL<01?l0003o
glW3omo9`ol00003om_5``03o`000?oD_<;oe;c200;oe;c200?o0000olng`_l000000oo:/L401?l0
003oaJc1olF/`Ol00002oknV`003o`000?njXKoo000000Co/i^o00Co0000ojfF_on]U[oo[IJo0_l0
0004oj>=_@05o`000?nMRKgoWHVmoif9_Ol000001?nHQKd01Ol0003oTh:noi>2__nCP[ko000000?o
T82n00Go0000oheo_on=OkooSGnoo`000003ohao_`05o`000?n<P<7oS831ohb0`Ol000000on>P/40
1Ol0003oTHC2oi64`_nAQ<;o000000?oU8O200?o0000oiV:`onIR/<00onIR/<01Ol0003oWHg2oif=
`_nMSL;o000000?oXY3200?o0000ojJB`OnVT/400_nVT/42o`0000CoZYC000?o0000ojbE_on/UKl0
0_n/UKl01?l0003o[YJmojjF_On^U[d2o`0000Co/I[100?o0000ok6I_onaVKl00_naVKl2o`0000Co
]JC800?o0000okBRa_ndX/H00_ndX/H2o`0000Co^kgK00?o0000okVhf?l000001?l0000fooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool005cooooo00?o0000ooooooooool0
;_ooool7o`000003omGEf?l0003oemSI00;oemSI00?o0000omSKfOoHfmT00_oHfmT00ol0003of]cI
om[Lf@02o`000003onGHbOl0003oiMS900;oiMS900Co0000onGGb?oUelSo00000_oTe/P02Ol0003o
hm?8on?Cb?oSdlSo0000on7@aol0003oh/g3o`000002omo9``03o`000?oKaL?oflG300;oflG300Go
0000omBl`_oD_<;oe;c2o`000003olng`P03o`000?o:/L7o000000?oaJc100?o0000oknV`?l00000
0onjXKl00ol0003o/i^ook>K_`02ok>K_`?o000000?oZI:no`000?nSSKd00onSSKd00ol0003oWHVm
oif9_@02oif9_@05o`000?nHQKgoV8FmoiR5_Ol000000onCP[h01Ol0003oT82noi20__n@P;ko0000
00?oSGno00Go0000ohao_on<OkooS7noo`000003ohb0`@03o`000?n>P/7oSX;100;oSX;100Go0000
oi64`_nAQ<;oTHC2o`000003oiB7`P03o`000?nIR/?oVH[300;oVH[300Go0000oif=`_nMSL;oWHg2
o`000004oj:@`PCo000000?oYY?1o`000?nZU<000onZU<000ol0003o[9FoojbE_`03ojbE_`?o0000
00?o/9_2o`000?naV/401?naV/401_l0003o/IVook6I_ol0003o]JO:o`0000Go]JC800Ko0000okBR
a_l0003o0000okg2g_l00004ok^mf`Co0000>_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00;ooooo001Mooooo`;o0000<?ooool00ol0003oSlcloho<o005o`000003omOHfOl0003o
f=_I00?of=_I00Co0000om[LfOoJg=Wo00000_oKgMP3o`000003onGHbOl0003oiMO800;oiMO800?o
0000onCFb?l000000ooSdlP01Ol0003ohM37on7@aooQd<Oo000000?oglW300Wo0000om_5`ooKaL?o
flG3o`000?oG`L?o0000omBl`_l000001?o?]l82o`0000GoaJc100?o0000okZQ_onjXKl00_njXKl0
1?l0003o/i^ook>K_oncVkl2o`0000CoZI:n00?o0000oj>=_OnSSKd00_nSSKd01Ol0003oWHVmoif9
_OnMRKgo000000?oV8Fm00Go0000oi>2__nCP[koTh:no`000003oi20_P05o`000?n=OkooSGnooheo
_ol000000on<Okl00ol0003oS831ohb0`@02ohb0`@05o`000?n>P/7oSX;1ohj2`Ol000000onAQ<80
1Ol0003oU8O2oiB7`_nDQl;o000000CoVH[300?o0000oif=`_nMSL800_nMSL800ol0003oXY32o`00
0002o`0000GoYY?100Go0000ojZD`?nZU<3oZYC0o`000004ojbE_`;o00001?n`Vl800ol0003o/I[1
ok6J`@02ok6J`@03o`000?naVKoo000000?o]JO:00?o0000okFTb?neY<P00_neY<P2o`0000Co_L;N
00?o0000ok^mfol000000ol0000mooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
0_ooool005oooooo00?o0000ooooooooool0;_ooool3o`0000;oTm3m1?l00003omSKf@04o`000?oJ
g=Wof]cIo`0000?ofmgH00?o0000omcLeooLg=L00ol000001OoUelSo0000onCFb?oTe/So000000;o
hm?800?o0000on7@aooQd<L00_oQd<L2o`000003omo9`ol0003oflG300;oflG300Go0000omO1`ooG
`L?oel73o`000004olng`P03o`000?o;//;o000000CoaJc10_l00004okZQ_`06o`000?ncVkoo0000
o`000?n_V;oo00001?nYT[h00ol0003oXhfmoj>=_@02oj>=_@05o`000?nMRKgoWHVmoif9_Ol00000
1?nHQKd01Ol0003oTh:noi>2__nCP[ko000000?oT82n00Go0000oheo_on=OkooSGnoo`000003ohao
_`05o`000?n<P<7oS831ohb0`Ol000000on>P/401Ol0003oTHC2oi64`_nAQ<;o000000?oU8O200?o
0000oiV:`onIR/<00onIR/<00ol0003oWHg2o`000003o`0000;oXY7200?o0000ojJC`OnVTl400onV
Tl400ol0003oZYC0ojZD`002ojZD`0Co000000?o[Y_4o`000?n`Vl800on`Vl800ol0003o/I[1ok6J
`@02ok6J`@;o00001?neYlX00ol0003o]JC8okFTb002o`000003okk8h_l0003o_L;N00?o_L;N1?l0
000oooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool0063ooooo00?o0000
ooooooooool0<?ooool2o`0000CoVMCl00?o0000omSKfOl000000_oJg=T01Ol0003ofmgHom_Mf?oK
gMSo000000?og=cG00?o0000omcKeOoLfmD00_l000000ooTe/So0000on?Cb002on?Cb005o`000?oQ
d<OohM37on7@aol000000_oNcLL01Ol0003oflG3om_5`ooKaL?o000000Coel7300Go0000olng`_o?
]l;ockO2o`000003ol^b`P04o`000?o5[<7oaJc1o`0000;o`:S100Co0000okZQ_onjXKoo^Z6o0_l0
0004ojnH_`03o`000?nYT[koZI:n00;oZI:n00Go0000oj>=_OnSSKgoXhfmo`000002oif9_A_o0000
1?n>P/401Ol0003oTHC2oi64`_nAQ<;o000000?oU8O200?o0000oiV:`onIR/<01?l00002oij>``03
o`000?nRTL;oXY7200;oXY7200?o0000ojJC`OnVTl400_nVTl401?l0003oZYC0ojZD`?nZU<02o`00
00Go[Y_400Ko0000ok2K`_n`Vl;o/9_2o`000?naV/43o`000003okFXc?l0003o]JO:00?o]JO:00?o
0000okFTb?l000001?nnb>800ol0003o_L;No`000002o`0004?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`02ooooo`00HOooool00ol0003oooooooooo`0`ooooo`04o`000?nIe?co
VMCloiWDo0Co000000?of]cIo`000?oKgMP00_oKgMP01Ol0003og=cGomcLeooLg=Oo000000;og=_E
00?o0000omgJe?oMf]@00ol000000ooSdlSo0000on7@a`02on7@a`04o`000?oNcLOog/g7omk=a`;o
000000?oflG3o`000?oG`L<00ooG`L<01Ol0003odkc4o`000?o?]l;o000000Cobk;200?o0000olF/
`Ol000000oo0Z<401_l0003o^Z6ookZQ_ol0003o]Yk0o`0000Co[iRo00?o0000ojVB__nYT[h00_nY
T[h00ol0003oXhfmoj>=_@04o`0000;oW8Rn00Go0000oiN5__nGQKkoUhFno`000003oi>3_P05o`00
0?nAPKkoTH6noi61__l000000on?P;l01Ol0003oSX30ohj0`?n>P<3o000000?oSX714?l00002oiZ;
``03o`000?nNS/?oWXk300;oWXk300Go0000oj:A`_nRTL;oXY72o`000005ojJC`@?o000000?oZi[5
o`000?n^Vl@01?n^Vl@01?l0003o/9_2ok2K`_n`Vl82o`0000Go]JS<00Co0000okFWb_neYl[o]JO:
0_l00005okk8hP;o0000Aoooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo
001Rooooo`;o0000<Oooool3o`0000;oXMSk1Ol000000ooKgMSo0000omcLe`02omcLe`04o`000?oL
fmGog=_Eo`0000?ogM[D00Co0000omcHdooLf=?o00000ooQd<L01Ol0003og/g7omk=aooNcLOo0000
00;oflW70_l00003omO1``05o`000?oC_<Codkc4om>la?l000001_o;//800ol0003o`:S1ol2X`@02
ol2X`@03o`000?njXKoo000000?o]Yk000Go0000ojnH_on_V;oo[iRoo`000003ojVB_PCo00000_nQ
S;h00ol0003oW8Rnoib8_P02oib8_P05o`000?nGQKkoUhFnoiN5__l000000onCPkh01Ol0003oTH6n
oi61__nAPKko000000?oSh2o00Go0000ohj0`?n>P<3oSX30o`000003ohj1`@05o`000?n@Pl;oT8?2
oi23`_l000000onBQL801Ol0003oUXS3oiJ8`onFR<?o000000GoVX_300Go0000oij>`onNS/?oWXk3
o`000004oj:A`P04o`000?nVTl7oYY?1ojJC`@;o00001?n[V/D00ol0003o[Y_4ojjKa002ojjKa006
o`000?n`Vl;o/9_2o`000?ndZ/oo00001OneZ<`01?l0003o]JO:o`000?l00002okk>i`03o`000?nn
b>;o000000;o0000B_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo001T
ooooo`03o`000?oooooooooo037ooooo0ol00002ojWKn@Go000000Gog=cGo`000?oLfmGog=_Eo`00
0003omgJe004o`000?oLf=?og=SComcHd`;o000000?ohM37o`000?oNcLL00_oNcLL02Ol0003oflW7
om_9aooKbLOo0000omS6b?l0003oel73o`000004om>la003o`000?o;//;obk;200?obk;20_l00004
ol2X`@;o00001?nfW/001?l0003o[iRoojnH_on_V;l4o`0000;oYY6o00?o0000oj6<__nQS;h00_nQ
S;h01Ol0003oW8Rnoib8__nLR;ko000000?oUhFn00Go0000oi>3__nCPkkoTh>no`000003oi61_P05
o`000?n?P;ooSh2oohn0_ol000000on>P<000ol0003oSX71ohj1`@02ohj1`@05o`000?n@Pl;oT8?2
oi23`_l000000onBQL801Ol0003oUXS3oiJ8`onFR<?o000000CoVX_300Go0000oij>`onNS/?oWXk3
o`000004oj:A`P06o`000?nVTl7o0000o`000?nXVLOo00001?n[V/D00ol0003o[Y_4ojjKa003ojjK
a0;o00000ondZ/l00ol0003o]JS<okFXc002okFXc0;o00001?nnc^L2o`0004gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`01ooooo`00IOooool00ol0003oooooooooo`0booooo`?o
00001?n`gOH3o`000003omcKeOl0003ogM[D00;ogM[D00Go0000omcHdooLf=?og=SCo`000002om_E
dP?o000000?og/g7o`000?oKbLL00_oKbLL01Ol0003of<K8omS6b?oHa/So000000Codkc400?o0000
oljhaOl000000oo;//801?l0003oaJk3olF^`ol00002ol2X`@03o`000?nkY<;o000000Co]Yk000Ko
0000ojnH_ol0003o0000ojbF`?l00005ojJA_`05o`000?nQS;koXHbnoj6<__l000000onLR;h01Ol0
003oUhFnoiN5__nGQKko000000?oTh>n00Go0000oi61__nAPKkoTH6no`000003ohn0_`03o`000?n>
P<3oSX3000;oSX3000Go0000ohj1`On>PL7oSX71o`000003oi23`P05o`000?nBQL;oTXG2oi:5`_l0
00000onFR<<00ol0003oVX_3oiZ;``02oiZ;``03o`000?nNS/?oWXk300;oWXk300?o0000oj:A`_nR
TL800ol00004ojRIa`03o`000?n[V/GoZi[500;oZi[500Co0000ojjKa?n^VlCo[Y_40_l00004okBZ
c`03o`000?neZ<co000000;o00000_nle>/01?l0003o_/kWo`000?l0001@ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00Oooool006Kooooo00?o0000ooooooooool0<oooool2o`00
0003ok3Mm_l0003o000000;o]mgc1?l000000ooMf]Co0000omcHd`02omcHd`04o`000?oKeM;ofmGB
o`0000?ofM;A00Go0000om_9aooKbLOoflW7o`000004omS6b005o`000?oC_<Codkc4om>la?l00000
0oo>^<D00ol0003obk;2o`000003olF^``03o`000?o0Z<7o000000?o^jC200Co0000okJN`?nfW/3o
]Yk00_l00004ojbF`003o`000?nVTKooYY6o00;oYY6o00Go0000oj6<__nQS;koXHbno`000004oib8
_P05o`000?nGQKkoUhFnoiN5__l000000onCPkh01Ol0003oTH6noi61__nAPKko000000?oSh2o00Go
0000ohj0`?n>P<3oSX30o`000003ohj1`@05o`000?n@Pl;oT8?2oi23`_l000000onBQL800ol0003o
UXS3oiJ8``02oiJ8``03o`000?nJRl?oVX_300;oVX_300?o0000oij>`ol000001?l00002ojBGb003
o`000?nXVLOoZ9W700;oZ9W700?o0000oj^JaOn[V/D00_n[V/D01_l0003o[Y_4o`000?l0003o/Z_A
o`0000Co]:[?0_l00005okcDj`;o0000Doooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo007ooooo001Wooooo`;o0000=Oooool2o`000003okOMlol0003o000000?o_Mc`1?l000001OoL
f=?o0000om_Ed_oKeM;o000000?ofM;A00Go0000omO?dOl0003oflW7o`000004omS6b005o`000?oD
`/So0000om>la?l000001Oo>^<D00ol0003oaJk3olF^``03olF^``03o`000?nkY<;o^jC200;o^jC2
00Ko0000okJN`?nfW/3o0000ok:L`_l00004ojbF`003o`000?nVTKooYY6o00;oYY6o00?o0000oj6<
__nQS;h00_nQS;h00ol0003oW8Rno`00000Fo`0000CoSX7100Go0000oi23`_n@Pl;oT8?2o`000003
oi:5`P05o`000?nFR<?oUXS3oiJ8`ol000000_nJRl<4o`0000;oWiC800?o0000ojBGb?nTUlP00onT
UlP01Ol0003oZ9W7ojRIaonXVLOo000000?oZi[50ol00004ok:[d@04o`000?ndZ/oo0000o`0000;o
^MW`00?o0000okcDjol000000_l0001Fooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00Oooool006Wooooo00?o0000ooooooooool0<oooool4o`000003okgLl?l0003o000000?o`M_/
0ol000000ooKeM;o0000omWBd@02omWBd@04o`000?oGcm7oeloAomO?d@;o00000ooHa/P01Ol0003o
e<;8omC2b?oD`/So000000Goc[S50_l00004olF^``;o00001?nkY<800ol0003o]Yk0o`000003ok:L
`P03o`000?n/U/3o[9K000;o[9K000?o0000ojJA_onVTKl00_nVTKl00ol0003oXHbno`000003o`00
00;oVh[100Go0000oiN7`OnGQl7oUhO1o`000003oi>6`P05o`000?nAQ<;oTHC2oi64`_l000000on@
Q<<01?l0003oShG4ohn5a?n?QL@Do`0000;oVi7800?o0000oinDb?nOU<P00_nOU<P00ol0003oY9O8
ojBGb002ojBGb004o`000?nXVLOoZ9W7ojRIa`Co00000_n_Zm@00ol0003o/Z_Aok:[d@02ok:[d@;o
00001?nifO02o`0005Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`01ooooo`00
J_ooool00ol0003oooooooooo`0eooooo`?o000000Co`M_/o`000?l0003o00000_o3f>T4o`000003
omWBdOl0003oeloA00;oeloA00Ko0000omC;dOoDbm7o0000omS6b?l00003omC2b003o`000?o@_l[o
000000?oc[S500Co0000olVea_o9]LKo00000_o5[/<01?l0003o`J_4ol6[a?l00003ok^T`P;o0000
1?nbW<800ol0003o[9K0ojbF`002ojbF`003o`000?nVTKooYY6o00Co00000_nOS/800ol0003oVh[1
oi^:`@02oi^:`@05o`000?nGQl7oUhO1oiN7`Ol000000onCQ/801Ol0003oTHC2oi64`_nAQ<;o0000
00?oT8C300Go0000ohn5a?n?QLCoShG4o`000003oi26a@05o`000?nAR<KoTHS6oi68a_l000000onD
RlL00ol0003oUhk8oiN>b002oiN>b003o`000?nKTLSoVi7800;oVi7800?o0000oinDb?nOU<P00_nO
U<P01_l0003oY9O8ojBGb?nTUlSo0000ojRIa`;o000000?oZj[Fo`000?n_Zm@01?n_Zm@01?l0003o
/Z_Ao`000?l00002okCLm004o`000?nifO3o0000o`0005cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`01ooooo`00Joooool00ol0003oooooooooo`0eooooo`04o`000?lbW?;o0000
o`0000?o`mSY00Co0000olCFioo4e^Ooa=KW0_l00003omO?d@03o`000?oDbm7oe<_A00;oe<_A00Go
0000omC2b?oD`/Soe<;8o`000003om2obP03o`000?o>^<Go000000?obKG600?o0000olF^`ol00000
0oo1Zl@01_l0003o^jC2ok^T`_l0003o]j?4o`0000Go/Yc200Co0000ojbF`?n/U/3o[9K00ol00002
ojBB``03o`000?nOS/;oWhk200;oWhk200Go0000oi^:`OnKR/7oVh[1o`000003oiN7`@05o`000?nC
Q/;oThK2oi>6`_l000000onAQ<801Ol0003oT8C3oi24`on@Q<?o000000CoShG400Go0000oi26aOn@
Q/GoT8K5o`000003oi68aP05o`000?nDRlOoU8_7oiB;aol000001?nGS/P01Ol0003oVi78oi^Ab?nK
TLSo000000CoWiC800?o0000ojBGb?nTUlP00ol00004oj^ZeP03o`000?n_ZmCo[j_D00;o[j_D0_l0
0004okCLm0;o0000Goooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo007ooooo001/
ooooo`;o0000=_ooool4o`000003ol?HjOl0003oa=KW00;oa=KW00Ko0000olCCiOo4dnGo0000omO?
dOl00004omC;d@05o`000?oAb=;o0000omC2b?l000001Oo@_lX00ol0003obKG6olVeaP02olVeaP;o
00001?o1Zl@00ol0003o^jC2o`000003okNSa003o`000?nbW<;o/Yc200;o/Yc200Ko0000ojbF`?l0
003o0000ojVGa?l00004ojBB``05o`000?nOS/;oWhk2oin>`_l000000onKR/401Ol0003oUhO1oiN7
`OnGQl7o000000?oThK200?o0000oi64`_nAQ<800_nAQ<801Ol0003oT8C3oi24`on@Q<?o000000?o
ShG400Go0000oi26aOn@Q/GoT8K5o`000003oi68aP03o`000?nDRlOoU8_700;oU8_700Go0000oiN>
b?nGS/SoUhk8o`000003oi^Ab004o`000?nOU<SoWiC8oinDb0Co00000_nVZ=L00ol0003oZj[Foj^Z
eP02oj^ZeP03o`000?n_ZmCo000000;o00000_n]g_P01?l0003o]=cdo`000?l0001Qooooo`03o`00
0?oooooooooo00Cooooo0Ol00001ooooo`7ooooo001^ooooo`03o`000?oooooooooo03Gooooo1Ol0
00000oo4e^Oo0000olCCi@02olCCi@?o00000ooDbm401Ol0003odLSBom78d_oAb=;o000000God;o:
0_l00003olVeaP03o`000?o5//So000000Co`J_40_l00005okNSa004o`000?nbW<;o/Yc2ok:L`P;o
00001?nYUl@01Ol0003oY9;3ojBB`onTT/?o000000?oWhk200?o0000oi^:`OnKR/400_nKR/401Ol0
003oUhO1oiN7`OnGQl7o000000?oThK200Go0000oi64`_nAQ<;oTHC2o`000003oi24``05o`000?n?
QLCoShG4ohn5a?l000000on@Q/D01Ol0003oTHS6oi68a_nAR<Ko000000CoU8_700Go0000oiN>b?nG
S/SoUhk8o`000002oi^Ab0Go00000_nRYMP00ol0003oYZSGojJXe`02ojJXe`03o`000?n[Z]KoZj[F
00Co00000on]g_P3o`0006Cooooo00?o0000ooooooooool00oooool1o`00007ooooo0Oooool006oo
oooo00?o0000ooooooooool0=Oooool5o`0000?oa=?U00Oo0000ol?@i?o3d>Co`m3To`000?oDbm7o
000000?odLSB00?o0000olg5dol000000oo@_lX01_l0003obkc<ol^lc?l0003obKG6o`0000?oaK;8
00Ko0000ol6[a?o1ZlCo0000okbZaol00005okNSa006o`000?nbW<;o0000o`000?n^WLKo00001?nY
Ul@01Ol0003oY9;3ojBB`onTT/?o000000CoWhk200?o0000oi^:`Ol00000:Ol00002oifRf003o`00
0?nRYMSoXZGH00?oXZGH00Co0000ojJXeonVZ=OoYZSG0ol00003ojCMn`Co0000J?ooool00ol0003o
ooooooooo`02ooooo`7o00000Oooool1ooooo`00L?ooool00ol0003oooooooooo`0fooooo`Co0000
00?oa=?Uo`000?o3d>@00oo3d>@2o`0000?odLSB00Oo0000olg5doo=aM?ocLGCo`000?o@_l[o0000
00Cobkc<00?o0000olFbb?o5//P00_o5//P00ol0003o`J_4o`000003okbZa`03o`000?ngXlCo]j?4
00;o]j?40_l00004ojjMaP05o`000?nYUlCoZIO4ojVGa?l000001?nTT/<00ol0003oWhk2o`000003
o`0000;oVY7900Go0000oiJ?b_nFSl[oUXo:o`000003oi>>b`03o`000?nAS/coTHk<00;oTHk<00Go
0000oi2>c_n@S/koT8k>o`000003ohn@d005o`000?n@T];oT9;Boi2Bd_l000000onAU]@00ol0003o
U9[FoiBJeP02oiBJeP05o`000?nHW]SoV9kHoiRNf?l000001?nMX]P00ol0003oXZGHoj:Uf002oj:U
f004o`000?nVZ=Oo0000o`0000;oW=_m00Co0000ojCMnol0003o0000KOooool01Ol0003ooooooooo
oooooooo000000;ooooo001aooooo`;o0000=oooool6o`000003ol?@i?l0003o000000;o`LgT00?o
0000om78d_l000001?o=aM<2o`0000Cobkc<0_l00004olFbb0;o00001OnlZ/L01_l0003o]j?4o`00
0?l0003o/jC9o`0000Co[Yg600?o0000ojVGa?nYUl@00_nYUl@00ol0003oY9;3o`000003o`0000;o
WYC:00?o0000oiZAbOnJTLT00_nJTLT01Ol0003oUXo:oiJ?b_nFSl[o000000?oThk;00?o0000oi6>
c?nAS/`00_nAS/`01Ol0003oT8k>oi2>c_n@S/ko000000?oSi3@00Go0000oi2Bd_n@T];oT9;Bo`00
0003oi6Fe003o`000?nDV]KoU9[F00;oU9[F00Go0000oiRNf?nHW]SoV9kHo`000003oifRf004o`00
0?nRYMSoXZGHoj:Uf0Co00000_nLfod3o`0006oooooo00Go0000ooooooooooooooooo`000002oooo
o`00Loooool00ol0003oooooooooo`0fooooo`Go00001?o1cN@2o`0000?ocLGC0_l000000oo8`mKo
0000ol^lc002ol^lc005o`000?o6^/ooa[[?o`000?o5//P00_l00002oknbc003o`000?nlZ/Oo_:[7
00;o_:[70_l00004ok>Tb@05o`000?n^WLKo[Yg6ojjMa_l000000_nYUl@4o`0000;oXYS;00?o0000
oijDb_nNU<X00_nNU<X01Ol0003oVY79oiZAbOnJTLWo000000?oUXo:00?o0000oi>>bonCS//00_nC
S//01Ol0003oTHk<oi6>c?nAS/co000000?oT8k>00Go0000ohn@d?n?T=3oSi3@o`000003oi2BdP03
o`000?nAU]CoTIKD00;oTIKD00Go0000oiBJe_nDV]KoU9[Fo`000002oiRNf0Wo00000_nCeoh4o`00
07?ooooo00Co0000oooooooooooo00000_ooool007Cooooo00?o0000ooooooooool0=_ooool01_l0
003oMKSkogFhnome^?_o0000ol7=i0;o00000_nmb^@00ol0003ocLGCo`000004olS3eP03o`000?o;
_<co000000?oa[[?0_l00005oknbc006o`000?nlZ/Oo0000o`000?ngZlgo00001?ncY<T00ol0003o
[Yg6ojjMaP04o`0000;oYig<00?o0000oj:HbonRV</00_nRV</01Ol0003oWYC:oijDb_nNU<[o0000
00?oVY7900Go0000oiJ?b_nFSl[oUXo:o`000004oi>>b`05o`000?nAS/coTHk<oi6>c?l000000on@
S/h01Ol0003oSi3@ohn@d?n?T=3o000000?oT9;B00Co0000oi6Fe?nAU]CoTIKD2?l00003ohS:o@04
o`000?n=dOkoSM7nohgAoPCo0000N?ooool00ol0003oooooo`000002ooooo`00MOooool00ol0003o
ooooooooo`0fooooo`Go00001?nmb^@3o`0000Cob<?F0_l00003olJjc`03o`000?o1^]?o000000Go
_k;<0_l00004okN[c@04o`000?ncY<Wo/jC9ok>Tb@?o00000_n[Xlh00ol0003oYig<ojNMc002ojNM
c005o`000?nRV<_oXYS;oj:Hbol000000onNU<X00ol0003oVY79oiZAb@0No`0000?oQ;_h00?o0000
ohG3non5`o/02Ol0001looooo`04o`000?ooooooooooo`00007ooooo001fooooo`;o0000=oooool2
o`0000;oNKSj00Co0000okg:i?l0003o00000onhb>H01?l0003ob<?Fo`000?l00002ol?2f@03o`00
0?o6^/oo000000?o`K[C00Oo0000oknbc?no//co_k;<o`000?nj/m;o000000Co]j_=00Ko0000ok>T
bOl0003o0000ok2Yd_l00004oj^ScP05o`000?nWWLcoYig<ojNMc?l000000_nRV</8o`0000?oV:CN
00Go0000oiBTh?nDY>3oU:CPo`000003oi2Uh`03o`000?n=YnOoSJOW00;oSJOW00Go0000ohVZjon9
Z^_oRJ[[o`000003ohN_l003o`000?n5]OCoQKGd00Wo0000Q_ooool00ol0003oooooo`000001oooo
o`00N?ooool00ol0003oooooooooo`0eooooo`Ko00001?nhb>H2o`0000Co`l;I0_l00005ol6jd`03
o`000?no//co000000?o^[?B00Co0000okN[cOngZlgo]j_=0_l00004ok2YdP05o`000?n[XlkoZj?>
oj^Sc_l000000_nWWL`4o`0000;oX:WL00Go0000oibVgOnLY]goW:KMo`000005oiRTgP05o`000?nD
Y>3oU:CPoiBTh?l000000on@YN<00ol0003oSJOWohfWi`0<o`00093ooooo0_l00001ooooo`00NOoo
ool00ol0003oooooooooo`0eooooo`;o00000omi]oT01?l0003o^<SVo`000?l00002ok;6j@04o`00
0?o3`]Wo0000o`0000;o_<7N00?o0000ol6jdoo1^]<00_o1^]<2o`0000Co^[?B00Ko0000okN[cOl0
003o0000ok>ae_l00004ok2YdP03o`000?n[XlkoZj?>00Co00000_nT[Md00ol0003oX:WLoj2Yg002
oj2Yg005o`000?nLY]goW:KMoibVgOl000000onHY=h>o`0009Wooooo0ol00001ooooo`00N_ooool0
0ol0003oooooooooo`0eooooo`Ko00001?nba^T2o`0000Go_<7N00Ko0000ol6jdol0003o0000ok^k
f_l00004okZcdP;o00001?nc/MH01?l0003o/:WBok2Yd_n`ZM83o`0000;oZ;;O00?o0000ojB]gOnT
[Md00_nT[Md01Ol0003oX:WLoj2Yg?nPZMco000000;oW:KM1Ol00002og7@oPCo0000WOooool4o`00
00Cooooo001kooooo`03o`000?oooooooooo03Gooooo0_l00003ogJfn@04o`000?nba^Wo0000o`00
00;oZlG]00?o0000okc1g_nl`Mh00_nl`Mh2o`0000Co^k_J00Ko0000okZcd_l0003o0000okFig?l0
0004ok>aeP06o`000?n`ZM;o0000o`000?n/^>?o00001?nX/]l00ol0003oY:gMojB]g@09o`0000;o
P=7o1?l0002Mooooo`Co00002?ooool007cooooo0_l0000fooooo`Oo00001?n[aNd01_l0003o_<7N
o`000?l0003o]L?To`0000Co^k_J0_l00004okFig003o`000?nc/MKo/k7F00?o00001?n/^><00ol0
003oZ;;OojRbg`05o`0000;oTMCn2?l0002Mooooo`Co00003?ooool007kooooo00?o0000oooooooo
ool0=?ooool00ol0003o06WIo`000004o`0000;oZlG]0ol00004okG3i004o`000?nk^m[o0000o`00
00;o]<7T00?o0000okFig?ne^M`01?l00003ojjoi`03o`000?n/^>?o[;SS00Go00000_nFe_d4o`00
0:;ooooo0ol0000@ooooo`00Ooooool00ol0003oooooooooo`0dooooo`Co000000CoJk;jo`000?l0
003o00000onQaO800ol0003o]L?TokG3i003o`0000Co]<7T0ol00003ojk7k@03o`000?n^_nOo[[oW
00Go00000_nHfOd4o`000:;ooooo1?l0000Cooooo`00P?ooool00ol0003oooooooooo`0eooooo`Ko
00000_nQaO84o`0000?o[<O^00Co0000okC1i?l0003o00000_nYcO<00ol0003o[/O]ojk7k@05o`00
00;oV=cn1?l0002Rooooo`Co00005oooool0087ooooo0_l0000fooooo`Oo00000onFaoP00ol0003o
[<O^ojc7kP05o`0000;oZLgc1?l00002oiCNoPCo0000X_ooool4o`0001_ooooo0023ooooo`03o`00
0?oooooooooo03Cooooo00?o0000ocF>kol000002_l00002oik@n@Co00000_n=g_h4o`000:;ooooo
1?l0000Oooooo`00Q?ooool00ol0003oooooooooo`0dooooo`ko00000_n2fOh4o`000:;ooooo1?l0
000Sooooo`00QOooool00ol0003oooooooooo`0dooooo`05o`000?mKX_GoFj;eoe^RmOl000000_mX
__h9o`000:7ooooo1?l0000Wooooo`00Q_ooool2o`0003Gooooo1ol00002ogO=o`?o0000XOooool3
o`0002_ooooo0028ooooo`03o`000?oooooooooo03Cooooo00?o0000ohBdm?n4]?@01?l0002Poooo
o`Co0000;_ooool008Wooooo00?o0000ooooooooool0=?ooool2o`000:3ooooo1?l0000booooo`00
R_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo09_ooooo1?l0000fooooo`00Rooo
ool2o`0003?ooooo00?o0000ooooooooool0Uoooool4o`0003[ooooo002=ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool0Toooool4o`0003kooooo002>ooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool0Soooool4o`0004;ooooo002?ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0S?ooool3o`0004Kooooo002@ooooo`;o0000;Oooool00ol0003ooooo
ooooo`29ooooo`Co0000BOooool009;ooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`25ooooo`Co0000COooool009?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`21
ooooo`Co0000DOooool009Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1moooo
o`Co0000EOooool009Gooooo0_l0000Xooooo`03o`000?oooooooooo07Wooooo1?l0001Iooooo`00
Uoooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07Gooooo1?l0001Mooooo`00V?oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo07;ooooo0ol0001Qooooo`00VOooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06kooooo1?l0001Tooooo`00V_ooool2o`00
02?ooooo00?o0000ooooooooool0J_ooool4o`0006Sooooo002Looooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool0I_ooool4o`0006cooooo002Mooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool0H_ooool4o`00073ooooo002Nooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool0G_ooool4o`0007Cooooo002Oooooo`;o00007_ooool00ol0003oooooooooo`1J
ooooo`Co0000N?ooool00:7ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Goooo
o`?o0000O?ooool00:;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Cooooo`Co
0000Ooooool00:?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1?ooooo`Co0000
Poooool00:Cooooo0_l0000Iooooo`03o`000?oooooooooo04_ooooo1?l00027ooooo`00Y_ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo1?l0002;ooooo`00Yoooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo04?ooooo1?l0002?ooooo`00Z?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo03oooooo1?l0002Cooooo`00ZOooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo03cooooo0ol0002Gooooo`00Z_ooool2o`0001?ooooo00?o
0000ooooooooool0>?ooool4o`0009[ooooo002/ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0=?ooool4o`0009kooooo002]ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0<?ooool4o`000:;ooooo002^ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0;?ooool4o`000:Kooooo002_ooooo`;o00003Oooool00ol0003oooooooooo`0Yooooo`Co0000
Z_ooool00;7ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Uooooo`Co0000[_oo
ool00;;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`?o0000/_ooool0
0;?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`Co0000]Oooool00;Co
oooo0_l00008ooooo`03o`000?oooooooooo01[ooooo1?l0002iooooo`00]_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01Kooooo1?l0002mooooo`00]oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01;ooooo1?l00031ooooo`00^?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00kooooo1?l00035ooooo`00^Oooool2o`0000?ooooo00?o0000oooo
ooooool02_ooool4o`000<Wooooo002kooooo`04o`000?ooooooooooo`0000Wooooo0ol0003=oooo
o`00_?ooool00ol0003oooooo`000005ooooo`Co0000d?ooool00;gooooo0_l000000ooooooo0000
o`000002o`000=Cooooo002nooooo`;o0000f?ooool00?ooooooVOooool00?ooooooVOooool00?oo
ooooVOooool00?ooooooVOooool00?ooooooVOooool00?ooooooVOooool00?ooooooVOooool00?oo
ooooVOooool00?ooooooVOooool00?ooooooVOooool00?ooooooVOooool00?ooooooVOooool00001
\
\>"],
  ImageRangeCache->{{{0, 407.75}, {330.438, 0}} -> {0, 0, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "The error could be reduced even further  by increasing ",
  Cell[BoxData[
      \(TraditionalForm\`P\_x\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`P\_y\)]],
  ". However, the more terms one keeps, the more time it takes to create and \
solve the equations."
}], "Text"],

Cell[TextData[{
  "\t The computation time can be reduced significantly if a general analytic \
form for one or more of the inner products can be found.  For example, the \
inner product ",
  Cell[BoxData[
      \(TraditionalForm\`L[i, j, k, l]\)]],
  " in the above example can  be determined analytically for general ",
  Cell[BoxData[
      \(TraditionalForm\`i, j, k\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Lmat[i_, j_, k_, l_] = \ \ Integrate[
        v[i, j, x, y]\ L[v[k, l, x, y]], {x, 0, 1}, {y, 0, 1}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.15"],

Cell[BoxData[
    \(\((2\ \((\(2\ k\)\/\(1 + i + k\) + \(3\ j\ k\)\/\(1 + i + k\) + \(j\^2\ \
k\)\/\(1 + i + k\) + \(2\ k\^2\)\/\(1 + i + k\) + \(3\ j\ k\^2\)\/\(1 + i + k\
\) + \(j\^2\ k\^2\)\/\(1 + i + k\) - 
              4\/\(2 + i + k\) - \(6\ j\)\/\(2 + i + k\) - \(2\ j\^2\)\/\(2 + \
i + k\) - \(8\ k\)\/\(2 + i + k\) - \(12\ j\ k\)\/\(2 + i + k\) - \(4\ j\^2\ \
k\)\/\(2 + i + k\) - \(4\ k\^2\)\/\(2 + i + k\) - \(6\ j\ k\^2\)\/\(2 + i + k\
\) - \(2\ j\^2\ k\^2\)\/\(2 + i + k\) - 
              16\/\(3 + i + k\) - \(23\ j\)\/\(3 + i + k\) - \(8\ j\^2\)\/\(3 \
+ i + k\) - 
              j\^3\/\(3 + i + k\) + \(6\ k\)\/\(3 + i + k\) + \(9\ j\ \
k\)\/\(3 + i + k\) + \(3\ j\^2\ k\)\/\(3 + i + k\) + \(2\ k\^2\)\/\(3 + i + k\
\) + \(3\ j\ k\^2\)\/\(3 + i + k\) + \(j\^2\ k\^2\)\/\(3 + i + k\) + 
              40\/\(4 + i + k\) + \(58\ j\)\/\(4 + i + k\) + \(20\ \
j\^2\)\/\(4 + i + k\) + \(2\ j\^3\)\/\(4 + i + k\) - 
              20\/\(5 + i + k\) - \(29\ j\)\/\(5 + i + k\) - \(10\ \
j\^2\)\/\(5 + i + k\) - 
              j\^3\/\(5 + i + k\) + \(3\ k\ l\)\/\(1 + i + k\) + \(2\ j\ k\ l\
\)\/\(1 + i + k\) + \(3\ k\^2\ l\)\/\(1 + i + k\) + \(2\ j\ k\^2\ l\)\/\(1 + \
i + k\) - \(6\ l\)\/\(2 + i + k\) - \(4\ j\ l\)\/\(2 + i + k\) - \(12\ k\ l\)\
\/\(2 + i + k\) - \(8\ j\ k\ l\)\/\(2 + i + k\) - \(6\ k\^2\ l\)\/\(2 + i + k\
\) - \(4\ j\ k\^2\ l\)\/\(2 + i + k\) - \(23\ l\)\/\(3 + i + k\) - \(36\ j\ l\
\)\/\(3 + i + k\) - \(12\ j\^2\ l\)\/\(3 + i + k\) - \(j\^3\ l\)\/\(3 + i + k\
\) + \(9\ k\ l\)\/\(3 + i + k\) + \(6\ j\ k\ l\)\/\(3 + i + k\) + \(3\ k\^2\ \
l\)\/\(3 + i + k\) + \(2\ j\ k\^2\ l\)\/\(3 + i + k\) + \(58\ l\)\/\(4 + i + \
k\) + \(80\ j\ l\)\/\(4 + i + k\) + \(24\ j\^2\ l\)\/\(4 + i + k\) + \(2\ \
j\^3\ l\)\/\(4 + i + k\) - \(29\ l\)\/\(5 + i + k\) - \(40\ j\ l\)\/\(5 + i + \
k\) - \(12\ j\^2\ l\)\/\(5 + i + k\) - \(j\^3\ l\)\/\(5 + i + k\) + \(k\ l\^2\
\)\/\(1 + i + k\) + \(k\^2\ l\^2\)\/\(1 + i + k\) - \(2\ l\^2\)\/\(2 + i + \
k\) - \(4\ k\ l\^2\)\/\(2 + i + k\) - \(2\ k\^2\ l\^2\)\/\(2 + i + k\) - \(8\ \
l\^2\)\/\(3 + i + k\) - \(12\ j\ l\^2\)\/\(3 + i + k\) - \(2\ j\^2\ \
l\^2\)\/\(3 + i + k\) + \(3\ k\ l\^2\)\/\(3 + i + k\) + \(k\^2\ l\^2\)\/\(3 + \
i + k\) + \(20\ l\^2\)\/\(4 + i + k\) + \(24\ j\ l\^2\)\/\(4 + i + k\) + \(4\ \
j\^2\ l\^2\)\/\(4 + i + k\) - \(10\ l\^2\)\/\(5 + i + k\) - \(12\ j\ l\^2\)\/\
\(5 + i + k\) - \(2\ j\^2\ l\^2\)\/\(5 + i + k\) - 
              l\^3\/\(3 + i + k\) - \(j\ l\^3\)\/\(3 + i + k\) + \(2\ \
l\^3\)\/\(4 + i + k\) + \(2\ j\ l\^3\)\/\(4 + i + k\) - 
              l\^3\/\(5 + i + k\) - \(j\ l\^3\)\/\(5 + i + k\))\))\)/\((\((1 \
+ j + l)\)\ \((2 + j + l)\)\ \((3 + j + l)\)\ \((4 + j + l)\)\ \((5 + j + 
              l)\))\)\)], "Output"]
}, Closed]],

Cell[TextData[{
  "(the result is suppressed to save space). Even though this expression for \
",
  Cell[BoxData[
      \(TraditionalForm\`L\_\(i\ j\ k\ l\)\)]],
  " is quite complicated, it takes less time to evaluate than the previous \
expression that contained a delayed evaluation of the inner product. \
Previously, when the equations ",
  Cell[BoxData[
      FormBox[
        RowBox[{"eq", "[", 
          RowBox[{
            StyleBox["i",
              FontSlant->"Plain"], ",", 
            StyleBox["j",
              FontSlant->"Plain"]}], "]"}], TraditionalForm]],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "were constructed, the integrals in the inner product had to be performed \
separately for every value of ",
  StyleBox["i, j, k",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["l",
    FontSlant->"Italic"],
  ".  Now, the equations take much less time to create. (Try it.)"
}], "Text"],

Cell[TextData[{
  "\t  However, it is not always possible to work out the inner products \
analytically for general values of the indices. For instance, the integrals \
needed in ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\&_\_\(k\ l\)\)]],
  " are too complex to be done for general ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  ". "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 2", "Section",
  CellTags->"c:7"],

Cell[TextData[{
  "In the next example, we will solve Poisson's equation in a domain that \
does not allow for an analytic solution. The domain is defined by the \
equations ",
  Cell[BoxData[
      \(TraditionalForm\`y \[LessEqual] \ x/6\  + \ 1, \ 
      y \[GreaterEqual] \ x\^2\)]],
  ". This domain is plotted in Cell ",
  ButtonBox["6.17",
    ButtonData:>"Cell 6.17",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[BoxData[
    \(<< Calculus`\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.16"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ContourPlot[\ 
        Boole[y \[LessEqual] \ x/6\  + \ 1 && \ 
            y \[GreaterEqual] \ x\^2], {x, \(-1\), 1.3}, {y, 0, 1.3}, 
        PlotPoints \[Rule] 100];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.17"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.437291 0.41806 0.0192308 0.739645 [
[.01923 -0.0125 -6 -9 ]
[.01923 -0.0125 6 0 ]
[.22826 -0.0125 -12 -9 ]
[.22826 -0.0125 12 0 ]
[.43729 -0.0125 -3 -9 ]
[.43729 -0.0125 3 0 ]
[.64632 -0.0125 -9 -9 ]
[.64632 -0.0125 9 0 ]
[.85535 -0.0125 -3 -9 ]
[.85535 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .16716 -18 -4.5 ]
[-0.0125 .16716 0 4.5 ]
[-0.0125 .31509 -18 -4.5 ]
[-0.0125 .31509 0 4.5 ]
[-0.0125 .46302 -18 -4.5 ]
[-0.0125 .46302 0 4.5 ]
[-0.0125 .61095 -18 -4.5 ]
[-0.0125 .61095 0 4.5 ]
[-0.0125 .75888 -6 -4.5 ]
[-0.0125 .75888 0 4.5 ]
[-0.0125 .9068 -18 -4.5 ]
[-0.0125 .9068 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-1)] .01923 -0.0125 0 1 Mshowa
.22826 0 m
.22826 .00625 L
s
[(-0.5)] .22826 -0.0125 0 1 Mshowa
.43729 0 m
.43729 .00625 L
s
[(0)] .43729 -0.0125 0 1 Mshowa
.64632 0 m
.64632 .00625 L
s
[(0.5)] .64632 -0.0125 0 1 Mshowa
.85535 0 m
.85535 .00625 L
s
[(1)] .85535 -0.0125 0 1 Mshowa
.125 Mabswid
.06104 0 m
.06104 .00375 L
s
.10284 0 m
.10284 .00375 L
s
.14465 0 m
.14465 .00375 L
s
.18645 0 m
.18645 .00375 L
s
.27007 0 m
.27007 .00375 L
s
.31187 0 m
.31187 .00375 L
s
.35368 0 m
.35368 .00375 L
s
.39548 0 m
.39548 .00375 L
s
.4791 0 m
.4791 .00375 L
s
.5209 0 m
.5209 .00375 L
s
.56271 0 m
.56271 .00375 L
s
.60452 0 m
.60452 .00375 L
s
.68813 0 m
.68813 .00375 L
s
.72993 0 m
.72993 .00375 L
s
.77174 0 m
.77174 .00375 L
s
.81355 0 m
.81355 .00375 L
s
.89716 0 m
.89716 .00375 L
s
.93896 0 m
.93896 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .16716 m
.00625 .16716 L
s
[(0.2)] -0.0125 .16716 1 0 Mshowa
0 .31509 m
.00625 .31509 L
s
[(0.4)] -0.0125 .31509 1 0 Mshowa
0 .46302 m
.00625 .46302 L
s
[(0.6)] -0.0125 .46302 1 0 Mshowa
0 .61095 m
.00625 .61095 L
s
[(0.8)] -0.0125 .61095 1 0 Mshowa
0 .75888 m
.00625 .75888 L
s
[(1)] -0.0125 .75888 1 0 Mshowa
0 .9068 m
.00625 .9068 L
s
[(1.2)] -0.0125 .9068 1 0 Mshowa
.125 Mabswid
0 .05621 m
.00375 .05621 L
s
0 .0932 m
.00375 .0932 L
s
0 .13018 m
.00375 .13018 L
s
0 .20414 m
.00375 .20414 L
s
0 .24112 m
.00375 .24112 L
s
0 .27811 m
.00375 .27811 L
s
0 .35207 m
.00375 .35207 L
s
0 .38905 m
.00375 .38905 L
s
0 .42604 m
.00375 .42604 L
s
0 .5 m
.00375 .5 L
s
0 .53698 m
.00375 .53698 L
s
0 .57396 m
.00375 .57396 L
s
0 .64793 m
.00375 .64793 L
s
0 .68491 m
.00375 .68491 L
s
0 .72189 m
.00375 .72189 L
s
0 .79586 m
.00375 .79586 L
s
0 .83284 m
.00375 .83284 L
s
0 .86982 m
.00375 .86982 L
s
0 .94379 m
.00375 .94379 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.22826 .99375 m
.22826 1 L
s
.43729 .99375 m
.43729 1 L
s
.64632 .99375 m
.64632 1 L
s
.85535 .99375 m
.85535 1 L
s
.125 Mabswid
.06104 .99625 m
.06104 1 L
s
.10284 .99625 m
.10284 1 L
s
.14465 .99625 m
.14465 1 L
s
.18645 .99625 m
.18645 1 L
s
.27007 .99625 m
.27007 1 L
s
.31187 .99625 m
.31187 1 L
s
.35368 .99625 m
.35368 1 L
s
.39548 .99625 m
.39548 1 L
s
.4791 .99625 m
.4791 1 L
s
.5209 .99625 m
.5209 1 L
s
.56271 .99625 m
.56271 1 L
s
.60452 .99625 m
.60452 1 L
s
.68813 .99625 m
.68813 1 L
s
.72993 .99625 m
.72993 1 L
s
.77174 .99625 m
.77174 1 L
s
.81355 .99625 m
.81355 1 L
s
.89716 .99625 m
.89716 1 L
s
.93896 .99625 m
.93896 1 L
s
.98077 .99625 m
.98077 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .16716 m
1 .16716 L
s
.99375 .31509 m
1 .31509 L
s
.99375 .46302 m
1 .46302 L
s
.99375 .61095 m
1 .61095 L
s
.99375 .75888 m
1 .75888 L
s
.99375 .9068 m
1 .9068 L
s
.125 Mabswid
.99625 .05621 m
1 .05621 L
s
.99625 .0932 m
1 .0932 L
s
.99625 .13018 m
1 .13018 L
s
.99625 .20414 m
1 .20414 L
s
.99625 .24112 m
1 .24112 L
s
.99625 .27811 m
1 .27811 L
s
.99625 .35207 m
1 .35207 L
s
.99625 .38905 m
1 .38905 L
s
.99625 .42604 m
1 .42604 L
s
.99625 .5 m
1 .5 L
s
.99625 .53698 m
1 .53698 L
s
.99625 .57396 m
1 .57396 L
s
.99625 .64793 m
1 .64793 L
s
.99625 .68491 m
1 .68491 L
s
.99625 .72189 m
1 .72189 L
s
.99625 .79586 m
1 .79586 L
s
.99625 .83284 m
1 .83284 L
s
.99625 .86982 m
1 .86982 L
s
.99625 .94379 m
1 .94379 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.39802 .01961 m
.40773 .01961 L
.41744 .01961 L
.42716 .01961 L
.43687 .01961 L
.44658 .01961 L
.45629 .01961 L
.46601 .01961 L
.47572 .01961 L
.48465 .02894 L
.48543 .02973 L
.49514 .02973 L
.50486 .02973 L
.51378 .03866 L
.51457 .03944 L
.5235 .04837 L
.52428 .04915 L
.53321 .05808 L
.53399 .05887 L
.54371 .05887 L
.55263 .06779 L
.55342 .06858 L
.56235 .07751 L
.56313 .07829 L
.57206 .08722 L
.57206 .09693 L
.57284 .09772 L
.58177 .10664 L
.58256 .10743 L
.59148 .11636 L
.59227 .11714 L
.6012 .12607 L
.60198 .12685 L
.61091 .13578 L
.61091 .14549 L
.61169 .14628 L
.62062 .15521 L
.62141 .15599 L
.63033 .16492 L
.63033 .17463 L
.63112 .17542 L
.64005 .18434 L
.64005 .19406 L
.64083 .19484 L
.64976 .20377 L
.65054 .20455 L
.65947 .21348 L
.65947 .22319 L
.66026 .22398 L
.66918 .23291 L
.66918 .24262 L
.66997 .2434 L
.6789 .25233 L
.6789 .26204 L
.67968 .26283 L
.68861 .27176 L
.68861 .28147 L
.68939 .28225 L
.69832 .29118 L
.69832 .30089 L
.69911 .30168 L
.70803 .31061 L
.70803 .32032 L
.70803 .33003 L
.70882 .33082 L
.71775 .33974 L
.71775 .34946 L
.71853 .35024 L
.72746 .35917 L
.72746 .36888 L
.72824 .36967 L
.73717 .37859 L
.73717 .38831 L
.73717 .39802 L
.73796 .3988 L
.74688 .40773 L
.74688 .41744 L
.74767 .41823 L
.7566 .42716 L
.7566 .43687 L
.7566 .44658 L
.75738 .44737 L
.76631 .45629 L
.76631 .46601 L
.76631 .47572 L
.76709 .4765 L
.77602 .48543 L
.77602 .49514 L
.77602 .50486 L
.77681 .50564 L
.78573 .51457 L
.78573 .52428 L
.78573 .53399 L
.78652 .53478 L
.79545 .54371 L
.79545 .55342 L
.79545 .56313 L
.79623 .56392 L
.80516 .57284 L
.80516 .58256 L
.80516 .59227 L
.80594 .59305 L
.81487 .60198 L
.81487 .61169 L
.81487 .62141 L
.81566 .62219 L
.82458 .63112 L
.82458 .64083 L
.82458 .65054 L
.82537 .65133 L
.8343 .66026 L
.8343 .66997 L
.8343 .67968 L
.83508 .68047 L
.84401 .68939 L
.84401 .69911 L
.84401 .70882 L
.84401 .71853 L
.84479 .71932 L
.85372 .72824 L
.85372 .73796 L
.85372 .74767 L
.85451 .74845 L
.86343 .75738 L
.86343 .76709 L
.86343 .77681 L
.86343 .78652 L
.86422 .7873 L
.87315 .79623 L
.87315 .80594 L
.87315 .81566 L
.87315 .82537 L
.87393 .82615 L
.88286 .83508 L
.88286 .84479 L
.88286 .85451 L
.88364 .85529 L
.89257 .86422 L
.89257 .87393 L
.89257 .88364 L
.88364 .89257 L
.87393 .89257 L
.86422 .89257 L
.85529 .88364 L
.85451 .88286 L
.84479 .88286 L
.83508 .88286 L
.82615 .87393 L
.82537 .87315 L
.81566 .87315 L
.80594 .87315 L
.79623 .87315 L
.7873 .86422 L
.78652 .86343 L
.77681 .86343 L
.76709 .86343 L
.75817 .85451 L
.75738 .85372 L
.74767 .85372 L
.73796 .85372 L
.72903 .84479 L
.72824 .84401 L
.71853 .84401 L
.70882 .84401 L
.69911 .84401 L
.69018 .83508 L
.68939 .8343 L
.67968 .8343 L
.66997 .8343 L
.66104 .82537 L
.66026 .82458 L
.65054 .82458 L
.64083 .82458 L
.63112 .82458 L
.62219 .81566 L
.62141 .81487 L
.61169 .81487 L
.60198 .81487 L
.59305 .80594 L
.59227 .80516 L
.58256 .80516 L
.57284 .80516 L
.56392 .79623 L
.56313 .79545 L
.55342 .79545 L
.54371 .79545 L
.53399 .79545 L
.52507 .78652 L
.52428 .78573 L
.51457 .78573 L
.50486 .78573 L
.49593 .77681 L
.49514 .77602 L
.48543 .77602 L
.47572 .77602 L
.46601 .77602 L
.45708 .76709 L
.45629 .76631 L
.44658 .76631 L
.43687 .76631 L
.42794 .75738 L
.42716 .7566 L
.41744 .7566 L
.40773 .7566 L
.3988 .74767 L
.39802 .74688 L
.38831 .74688 L
.37859 .74688 L
.36888 .74688 L
.35995 .73796 L
.35917 .73717 L
.34946 .73717 L
.33974 .73717 L
.33082 .72824 L
.33003 .72746 L
.32032 .72746 L
.31061 .72746 L
.30089 .72746 L
.29197 .71853 L
.29118 .71775 L
.28147 .71775 L
.27176 .71775 L
.26283 .70882 L
.26204 .70803 L
.25233 .70803 L
.24262 .70803 L
.23369 .69911 L
.23291 .69832 L
.22319 .69832 L
.21348 .69832 L
.20377 .69832 L
.19484 .68939 L
.19406 .68861 L
.18434 .68861 L
.17463 .68861 L
.1657 .67968 L
.16492 .6789 L
.15521 .6789 L
.14549 .6789 L
.13578 .6789 L
.12685 .66997 L
.12607 .66918 L
.11636 .66918 L
.10664 .66918 L
.09772 .66026 L
.09693 .65947 L
.08722 .65947 L
.07751 .65947 L
.06858 .65054 L
.06779 .64976 L
.05808 .64976 L
.04915 .64083 L
.04915 .63112 L
.05808 .62219 L
.05887 .62141 L
.05887 .61169 L
.05887 .60198 L
.06779 .59305 L
.06858 .59227 L
.06858 .58256 L
.06858 .57284 L
.07751 .56392 L
.07829 .56313 L
.07829 .55342 L
.07829 .54371 L
.08722 .53478 L
.088 .53399 L
.088 .52428 L
.088 .51457 L
.09693 .50564 L
.09772 .50486 L
.09772 .49514 L
.09772 .48543 L
.10664 .4765 L
.10743 .47572 L
.10743 .46601 L
.10743 .45629 L
.11636 .44737 L
.11714 .44658 L
.11714 .43687 L
.12607 .42794 L
.12685 .42716 L
.12685 .41744 L
.12685 .40773 L
.13578 .3988 L
.13657 .39802 L
.13657 .38831 L
.14549 .37938 L
.14628 .37859 L
.14628 .36888 L
.14628 .35917 L
.15521 .35024 L
.15599 .34946 L
.15599 .33974 L
.16492 .33082 L
.1657 .33003 L
.1657 .32032 L
.17463 .31139 L
.17542 .31061 L
.17542 .30089 L
.17542 .29118 L
.18434 .28225 L
.18513 .28147 L
.18513 .27176 L
.19406 .26283 L
.19484 .26204 L
.19484 .25233 L
.20377 .2434 L
.20455 .24262 L
.20455 .23291 L
.21348 .22398 L
.21427 .22319 L
.21427 .21348 L
.22319 .20455 L
.22398 .20377 L
.23291 .19484 L
.23369 .19406 L
.23369 .18434 L
.24262 .17542 L
.2434 .17463 L
.2434 .16492 L
.25233 .15599 L
.25312 .15521 L
.26204 .14628 L
.26283 .14549 L
.26283 .13578 L
.27176 .12685 L
.27254 .12607 L
.28147 .11714 L
.28225 .11636 L
.29118 .10743 L
.29197 .10664 L
.30089 .09772 L
.30168 .09693 L
.30168 .08722 L
.31061 .07829 L
.31139 .07751 L
.32032 .06858 L
.33003 .06858 L
.33082 .06779 L
.33974 .05887 L
.34053 .05808 L
.34946 .04915 L
.35024 .04837 L
.35917 .03944 L
.36888 .03944 L
.36967 .03866 L
.37859 .02973 L
.38831 .02973 L
.38909 .02894 L
F
0 g
.39802 .01961 m
.40773 .01961 L
.41744 .01961 L
.42716 .01961 L
.43687 .01961 L
.44658 .01961 L
.45629 .01961 L
.46601 .01961 L
.47572 .01961 L
.48465 .02894 L
.48543 .02973 L
.49514 .02973 L
.50486 .02973 L
.51378 .03866 L
.51457 .03944 L
.5235 .04837 L
.52428 .04915 L
.53321 .05808 L
.53399 .05887 L
.54371 .05887 L
.55263 .06779 L
.55342 .06858 L
.56235 .07751 L
.56313 .07829 L
.57206 .08722 L
.57206 .09693 L
.57284 .09772 L
.58177 .10664 L
.58256 .10743 L
.59148 .11636 L
.59227 .11714 L
.6012 .12607 L
.60198 .12685 L
.61091 .13578 L
.61091 .14549 L
.61169 .14628 L
.62062 .15521 L
.62141 .15599 L
.63033 .16492 L
.63033 .17463 L
.63112 .17542 L
.64005 .18434 L
.64005 .19406 L
.64083 .19484 L
.64976 .20377 L
.65054 .20455 L
.65947 .21348 L
.65947 .22319 L
.66026 .22398 L
.66918 .23291 L
Mistroke
.66918 .24262 L
.66997 .2434 L
.6789 .25233 L
.6789 .26204 L
.67968 .26283 L
.68861 .27176 L
.68861 .28147 L
.68939 .28225 L
.69832 .29118 L
.69832 .30089 L
.69911 .30168 L
.70803 .31061 L
.70803 .32032 L
.70803 .33003 L
.70882 .33082 L
.71775 .33974 L
.71775 .34946 L
.71853 .35024 L
.72746 .35917 L
.72746 .36888 L
.72824 .36967 L
.73717 .37859 L
.73717 .38831 L
.73717 .39802 L
.73796 .3988 L
.74688 .40773 L
.74688 .41744 L
.74767 .41823 L
.7566 .42716 L
.7566 .43687 L
.7566 .44658 L
.75738 .44737 L
.76631 .45629 L
.76631 .46601 L
.76631 .47572 L
.76709 .4765 L
.77602 .48543 L
.77602 .49514 L
.77602 .50486 L
.77681 .50564 L
.78573 .51457 L
.78573 .52428 L
.78573 .53399 L
.78652 .53478 L
.79545 .54371 L
.79545 .55342 L
.79545 .56313 L
.79623 .56392 L
.80516 .57284 L
.80516 .58256 L
Mistroke
.80516 .59227 L
.80594 .59305 L
.81487 .60198 L
.81487 .61169 L
.81487 .62141 L
.81566 .62219 L
.82458 .63112 L
.82458 .64083 L
.82458 .65054 L
.82537 .65133 L
.8343 .66026 L
.8343 .66997 L
.8343 .67968 L
.83508 .68047 L
.84401 .68939 L
.84401 .69911 L
.84401 .70882 L
.84401 .71853 L
.84479 .71932 L
.85372 .72824 L
.85372 .73796 L
.85372 .74767 L
.85451 .74845 L
.86343 .75738 L
.86343 .76709 L
.86343 .77681 L
.86343 .78652 L
.86422 .7873 L
.87315 .79623 L
.87315 .80594 L
.87315 .81566 L
.87315 .82537 L
.87393 .82615 L
.88286 .83508 L
.88286 .84479 L
.88286 .85451 L
.88364 .85529 L
.89257 .86422 L
.89257 .87393 L
.89257 .88364 L
.88364 .89257 L
.87393 .89257 L
.86422 .89257 L
.85529 .88364 L
.85451 .88286 L
.84479 .88286 L
.83508 .88286 L
.82615 .87393 L
.82537 .87315 L
.81566 .87315 L
Mistroke
.80594 .87315 L
.79623 .87315 L
.7873 .86422 L
.78652 .86343 L
.77681 .86343 L
.76709 .86343 L
.75817 .85451 L
.75738 .85372 L
.74767 .85372 L
.73796 .85372 L
.72903 .84479 L
.72824 .84401 L
.71853 .84401 L
.70882 .84401 L
.69911 .84401 L
.69018 .83508 L
.68939 .8343 L
.67968 .8343 L
.66997 .8343 L
.66104 .82537 L
.66026 .82458 L
.65054 .82458 L
.64083 .82458 L
.63112 .82458 L
.62219 .81566 L
.62141 .81487 L
.61169 .81487 L
.60198 .81487 L
.59305 .80594 L
.59227 .80516 L
.58256 .80516 L
.57284 .80516 L
.56392 .79623 L
.56313 .79545 L
.55342 .79545 L
.54371 .79545 L
.53399 .79545 L
.52507 .78652 L
.52428 .78573 L
.51457 .78573 L
.50486 .78573 L
.49593 .77681 L
.49514 .77602 L
.48543 .77602 L
.47572 .77602 L
.46601 .77602 L
.45708 .76709 L
.45629 .76631 L
.44658 .76631 L
.43687 .76631 L
Mistroke
.42794 .75738 L
.42716 .7566 L
.41744 .7566 L
.40773 .7566 L
.3988 .74767 L
.39802 .74688 L
.38831 .74688 L
.37859 .74688 L
.36888 .74688 L
.35995 .73796 L
.35917 .73717 L
.34946 .73717 L
.33974 .73717 L
.33082 .72824 L
.33003 .72746 L
.32032 .72746 L
.31061 .72746 L
.30089 .72746 L
.29197 .71853 L
.29118 .71775 L
.28147 .71775 L
.27176 .71775 L
.26283 .70882 L
.26204 .70803 L
.25233 .70803 L
.24262 .70803 L
.23369 .69911 L
.23291 .69832 L
.22319 .69832 L
.21348 .69832 L
.20377 .69832 L
.19484 .68939 L
.19406 .68861 L
.18434 .68861 L
.17463 .68861 L
.1657 .67968 L
.16492 .6789 L
.15521 .6789 L
.14549 .6789 L
.13578 .6789 L
.12685 .66997 L
.12607 .66918 L
.11636 .66918 L
.10664 .66918 L
.09772 .66026 L
.09693 .65947 L
.08722 .65947 L
.07751 .65947 L
.06858 .65054 L
.06779 .64976 L
Mistroke
.05808 .64976 L
.04915 .64083 L
.04915 .63112 L
.05808 .62219 L
.05887 .62141 L
.05887 .61169 L
.05887 .60198 L
.06779 .59305 L
.06858 .59227 L
.06858 .58256 L
.06858 .57284 L
.07751 .56392 L
.07829 .56313 L
.07829 .55342 L
.07829 .54371 L
.08722 .53478 L
.088 .53399 L
.088 .52428 L
.088 .51457 L
.09693 .50564 L
.09772 .50486 L
.09772 .49514 L
.09772 .48543 L
.10664 .4765 L
.10743 .47572 L
.10743 .46601 L
.10743 .45629 L
.11636 .44737 L
.11714 .44658 L
.11714 .43687 L
.12607 .42794 L
.12685 .42716 L
.12685 .41744 L
.12685 .40773 L
.13578 .3988 L
.13657 .39802 L
.13657 .38831 L
.14549 .37938 L
.14628 .37859 L
.14628 .36888 L
.14628 .35917 L
.15521 .35024 L
.15599 .34946 L
.15599 .33974 L
.16492 .33082 L
.1657 .33003 L
.1657 .32032 L
.17463 .31139 L
.17542 .31061 L
.17542 .30089 L
Mistroke
.17542 .29118 L
.18434 .28225 L
.18513 .28147 L
.18513 .27176 L
.19406 .26283 L
.19484 .26204 L
.19484 .25233 L
.20377 .2434 L
.20455 .24262 L
.20455 .23291 L
.21348 .22398 L
.21427 .22319 L
.21427 .21348 L
.22319 .20455 L
.22398 .20377 L
.23291 .19484 L
.23369 .19406 L
.23369 .18434 L
.24262 .17542 L
.2434 .17463 L
.2434 .16492 L
.25233 .15599 L
.25312 .15521 L
.26204 .14628 L
.26283 .14549 L
.26283 .13578 L
.27176 .12685 L
.27254 .12607 L
.28147 .11714 L
.28225 .11636 L
.29118 .10743 L
.29197 .10664 L
.30089 .09772 L
.30168 .09693 L
.30168 .08722 L
.31061 .07829 L
.31139 .07751 L
.32032 .06858 L
.33003 .06858 L
.33082 .06779 L
.33974 .05887 L
.34053 .05808 L
.34946 .04915 L
.35024 .04837 L
.35917 .03944 L
.36888 .03944 L
.36967 .03866 L
.37859 .02973 L
.38831 .02973 L
.38909 .02894 L
Mistroke
.39802 .01961 L
Mfstroke
.2 g
.39802 .02016 m
.40773 .02016 L
.41744 .02016 L
.42716 .02016 L
.43687 .02016 L
.44658 .02016 L
.45629 .02016 L
.46601 .02016 L
.47572 .02016 L
.48367 .02894 L
.48543 .03071 L
.49514 .03071 L
.50486 .03071 L
.5128 .03866 L
.51457 .04042 L
.52252 .04837 L
.52428 .05013 L
.53223 .05808 L
.53399 .05985 L
.54371 .05985 L
.55165 .06779 L
.55342 .06956 L
.56137 .07751 L
.56313 .07927 L
.57108 .08722 L
.57108 .09693 L
.57284 .0987 L
.58079 .10664 L
.58256 .10841 L
.5905 .11636 L
.59227 .11812 L
.60022 .12607 L
.60198 .12783 L
.60993 .13578 L
.60993 .14549 L
.61169 .14726 L
.61964 .15521 L
.62141 .15697 L
.62935 .16492 L
.62935 .17463 L
.63112 .1764 L
.63907 .18434 L
.63907 .19406 L
.64083 .19582 L
.64878 .20377 L
.65054 .20553 L
.65849 .21348 L
.65849 .22319 L
.66026 .22496 L
.6682 .23291 L
.6682 .24262 L
.66997 .24438 L
.67792 .25233 L
.67792 .26204 L
.67968 .26381 L
.68763 .27176 L
.68763 .28147 L
.68939 .28323 L
.69734 .29118 L
.69734 .30089 L
.69911 .30266 L
.70705 .31061 L
.70705 .32032 L
.70705 .33003 L
.70882 .3318 L
.71677 .33974 L
.71677 .34946 L
.71853 .35122 L
.72648 .35917 L
.72648 .36888 L
.72824 .37065 L
.73619 .37859 L
.73619 .38831 L
.73619 .39802 L
.73796 .39978 L
.7459 .40773 L
.7459 .41744 L
.74767 .41921 L
.75562 .42716 L
.75562 .43687 L
.75562 .44658 L
.75738 .44835 L
.76533 .45629 L
.76533 .46601 L
.76533 .47572 L
.76709 .47748 L
.77504 .48543 L
.77504 .49514 L
.77504 .50486 L
.77681 .50662 L
.78475 .51457 L
.78475 .52428 L
.78475 .53399 L
.78652 .53576 L
.79447 .54371 L
.79447 .55342 L
.79447 .56313 L
.79623 .5649 L
.80418 .57284 L
.80418 .58256 L
.80418 .59227 L
.80594 .59403 L
.81389 .60198 L
.81389 .61169 L
.81389 .62141 L
.81566 .62317 L
.8236 .63112 L
.8236 .64083 L
.8236 .65054 L
.82537 .65231 L
.83332 .66026 L
.83332 .66997 L
.83332 .67968 L
.83508 .68145 L
.84303 .68939 L
.84303 .69911 L
.84303 .70882 L
.84303 .71853 L
.84479 .7203 L
.85274 .72824 L
.85274 .73796 L
.85274 .74767 L
.85451 .74943 L
.86245 .75738 L
.86245 .76709 L
.86245 .77681 L
.86245 .78652 L
.86422 .78828 L
.87217 .79623 L
.87217 .80594 L
.87217 .81566 L
.87217 .82537 L
.87393 .82713 L
.88188 .83508 L
.88188 .84479 L
.88188 .85451 L
.88364 .85627 L
.89159 .86422 L
.89159 .87393 L
.89159 .88364 L
.88364 .89159 L
.87393 .89159 L
.86422 .89159 L
.85627 .88364 L
.85451 .88188 L
.84479 .88188 L
.83508 .88188 L
.82713 .87393 L
.82537 .87217 L
.81566 .87217 L
.80594 .87217 L
.79623 .87217 L
.78828 .86422 L
.78652 .86245 L
.77681 .86245 L
.76709 .86245 L
.75915 .85451 L
.75738 .85274 L
.74767 .85274 L
.73796 .85274 L
.73001 .84479 L
.72824 .84303 L
.71853 .84303 L
.70882 .84303 L
.69911 .84303 L
.69116 .83508 L
.68939 .83332 L
.67968 .83332 L
.66997 .83332 L
.66202 .82537 L
.66026 .8236 L
.65054 .8236 L
.64083 .8236 L
.63112 .8236 L
.62317 .81566 L
.62141 .81389 L
.61169 .81389 L
.60198 .81389 L
.59403 .80594 L
.59227 .80418 L
.58256 .80418 L
.57284 .80418 L
.5649 .79623 L
.56313 .79447 L
.55342 .79447 L
.54371 .79447 L
.53399 .79447 L
.52605 .78652 L
.52428 .78475 L
.51457 .78475 L
.50486 .78475 L
.49691 .77681 L
.49514 .77504 L
.48543 .77504 L
.47572 .77504 L
.46601 .77504 L
.45806 .76709 L
.45629 .76533 L
.44658 .76533 L
.43687 .76533 L
.42892 .75738 L
.42716 .75562 L
.41744 .75562 L
.40773 .75562 L
.39978 .74767 L
.39802 .7459 L
.38831 .7459 L
.37859 .7459 L
.36888 .7459 L
.36093 .73796 L
.35917 .73619 L
.34946 .73619 L
.33974 .73619 L
.3318 .72824 L
.33003 .72648 L
.32032 .72648 L
.31061 .72648 L
.30089 .72648 L
.29295 .71853 L
.29118 .71677 L
.28147 .71677 L
.27176 .71677 L
.26381 .70882 L
.26204 .70705 L
.25233 .70705 L
.24262 .70705 L
.23467 .69911 L
.23291 .69734 L
.22319 .69734 L
.21348 .69734 L
.20377 .69734 L
.19582 .68939 L
.19406 .68763 L
.18434 .68763 L
.17463 .68763 L
.16668 .67968 L
.16492 .67792 L
.15521 .67792 L
.14549 .67792 L
.13578 .67792 L
.12783 .66997 L
.12607 .6682 L
.11636 .6682 L
.10664 .6682 L
.0987 .66026 L
.09693 .65849 L
.08722 .65849 L
.07751 .65849 L
.06956 .65054 L
.06779 .64878 L
.05808 .64878 L
.05013 .64083 L
.05013 .63112 L
.05808 .62317 L
.05985 .62141 L
.05985 .61169 L
.05985 .60198 L
.06779 .59403 L
.06956 .59227 L
.06956 .58256 L
.06956 .57284 L
.07751 .5649 L
.07927 .56313 L
.07927 .55342 L
.07927 .54371 L
.08722 .53576 L
.08898 .53399 L
.08898 .52428 L
.08898 .51457 L
.09693 .50662 L
.0987 .50486 L
.0987 .49514 L
.0987 .48543 L
.10664 .47748 L
.10841 .47572 L
.10841 .46601 L
.10841 .45629 L
.11636 .44835 L
.11812 .44658 L
.11812 .43687 L
.12607 .42892 L
.12783 .42716 L
.12783 .41744 L
.12783 .40773 L
.13578 .39978 L
.13755 .39802 L
.13755 .38831 L
.14549 .38036 L
.14726 .37859 L
.14726 .36888 L
.14726 .35917 L
.15521 .35122 L
.15697 .34946 L
.15697 .33974 L
.16492 .3318 L
.16668 .33003 L
.16668 .32032 L
.17463 .31237 L
.1764 .31061 L
.1764 .30089 L
.1764 .29118 L
.18434 .28323 L
.18611 .28147 L
.18611 .27176 L
.19406 .26381 L
.19582 .26204 L
.19582 .25233 L
.20377 .24438 L
.20553 .24262 L
.20553 .23291 L
.21348 .22496 L
.21525 .22319 L
.21525 .21348 L
.22319 .20553 L
.22496 .20377 L
.23291 .19582 L
.23467 .19406 L
.23467 .18434 L
.24262 .1764 L
.24438 .17463 L
.24438 .16492 L
.25233 .15697 L
.2541 .15521 L
.26204 .14726 L
.26381 .14549 L
.26381 .13578 L
.27176 .12783 L
.27352 .12607 L
.28147 .11812 L
.28323 .11636 L
.29118 .10841 L
.29295 .10664 L
.30089 .0987 L
.30266 .09693 L
.30266 .08722 L
.31061 .07927 L
.31237 .07751 L
.32032 .06956 L
.33003 .06956 L
.3318 .06779 L
.33974 .05985 L
.34151 .05808 L
.34946 .05013 L
.35122 .04837 L
.35917 .04042 L
.36888 .04042 L
.37065 .03866 L
.37859 .03071 L
.38831 .03071 L
.39007 .02894 L
F
0 g
.39802 .02016 m
.40773 .02016 L
.41744 .02016 L
.42716 .02016 L
.43687 .02016 L
.44658 .02016 L
.45629 .02016 L
.46601 .02016 L
.47572 .02016 L
.48367 .02894 L
.48543 .03071 L
.49514 .03071 L
.50486 .03071 L
.5128 .03866 L
.51457 .04042 L
.52252 .04837 L
.52428 .05013 L
.53223 .05808 L
.53399 .05985 L
.54371 .05985 L
.55165 .06779 L
.55342 .06956 L
.56137 .07751 L
.56313 .07927 L
.57108 .08722 L
.57108 .09693 L
.57284 .0987 L
.58079 .10664 L
.58256 .10841 L
.5905 .11636 L
.59227 .11812 L
.60022 .12607 L
.60198 .12783 L
.60993 .13578 L
.60993 .14549 L
.61169 .14726 L
.61964 .15521 L
.62141 .15697 L
.62935 .16492 L
.62935 .17463 L
.63112 .1764 L
.63907 .18434 L
.63907 .19406 L
.64083 .19582 L
.64878 .20377 L
.65054 .20553 L
.65849 .21348 L
.65849 .22319 L
.66026 .22496 L
.6682 .23291 L
Mistroke
.6682 .24262 L
.66997 .24438 L
.67792 .25233 L
.67792 .26204 L
.67968 .26381 L
.68763 .27176 L
.68763 .28147 L
.68939 .28323 L
.69734 .29118 L
.69734 .30089 L
.69911 .30266 L
.70705 .31061 L
.70705 .32032 L
.70705 .33003 L
.70882 .3318 L
.71677 .33974 L
.71677 .34946 L
.71853 .35122 L
.72648 .35917 L
.72648 .36888 L
.72824 .37065 L
.73619 .37859 L
.73619 .38831 L
.73619 .39802 L
.73796 .39978 L
.7459 .40773 L
.7459 .41744 L
.74767 .41921 L
.75562 .42716 L
.75562 .43687 L
.75562 .44658 L
.75738 .44835 L
.76533 .45629 L
.76533 .46601 L
.76533 .47572 L
.76709 .47748 L
.77504 .48543 L
.77504 .49514 L
.77504 .50486 L
.77681 .50662 L
.78475 .51457 L
.78475 .52428 L
.78475 .53399 L
.78652 .53576 L
.79447 .54371 L
.79447 .55342 L
.79447 .56313 L
.79623 .5649 L
.80418 .57284 L
.80418 .58256 L
Mistroke
.80418 .59227 L
.80594 .59403 L
.81389 .60198 L
.81389 .61169 L
.81389 .62141 L
.81566 .62317 L
.8236 .63112 L
.8236 .64083 L
.8236 .65054 L
.82537 .65231 L
.83332 .66026 L
.83332 .66997 L
.83332 .67968 L
.83508 .68145 L
.84303 .68939 L
.84303 .69911 L
.84303 .70882 L
.84303 .71853 L
.84479 .7203 L
.85274 .72824 L
.85274 .73796 L
.85274 .74767 L
.85451 .74943 L
.86245 .75738 L
.86245 .76709 L
.86245 .77681 L
.86245 .78652 L
.86422 .78828 L
.87217 .79623 L
.87217 .80594 L
.87217 .81566 L
.87217 .82537 L
.87393 .82713 L
.88188 .83508 L
.88188 .84479 L
.88188 .85451 L
.88364 .85627 L
.89159 .86422 L
.89159 .87393 L
.89159 .88364 L
.88364 .89159 L
.87393 .89159 L
.86422 .89159 L
.85627 .88364 L
.85451 .88188 L
.84479 .88188 L
.83508 .88188 L
.82713 .87393 L
.82537 .87217 L
.81566 .87217 L
Mistroke
.80594 .87217 L
.79623 .87217 L
.78828 .86422 L
.78652 .86245 L
.77681 .86245 L
.76709 .86245 L
.75915 .85451 L
.75738 .85274 L
.74767 .85274 L
.73796 .85274 L
.73001 .84479 L
.72824 .84303 L
.71853 .84303 L
.70882 .84303 L
.69911 .84303 L
.69116 .83508 L
.68939 .83332 L
.67968 .83332 L
.66997 .83332 L
.66202 .82537 L
.66026 .8236 L
.65054 .8236 L
.64083 .8236 L
.63112 .8236 L
.62317 .81566 L
.62141 .81389 L
.61169 .81389 L
.60198 .81389 L
.59403 .80594 L
.59227 .80418 L
.58256 .80418 L
.57284 .80418 L
.5649 .79623 L
.56313 .79447 L
.55342 .79447 L
.54371 .79447 L
.53399 .79447 L
.52605 .78652 L
.52428 .78475 L
.51457 .78475 L
.50486 .78475 L
.49691 .77681 L
.49514 .77504 L
.48543 .77504 L
.47572 .77504 L
.46601 .77504 L
.45806 .76709 L
.45629 .76533 L
.44658 .76533 L
.43687 .76533 L
Mistroke
.42892 .75738 L
.42716 .75562 L
.41744 .75562 L
.40773 .75562 L
.39978 .74767 L
.39802 .7459 L
.38831 .7459 L
.37859 .7459 L
.36888 .7459 L
.36093 .73796 L
.35917 .73619 L
.34946 .73619 L
.33974 .73619 L
.3318 .72824 L
.33003 .72648 L
.32032 .72648 L
.31061 .72648 L
.30089 .72648 L
.29295 .71853 L
.29118 .71677 L
.28147 .71677 L
.27176 .71677 L
.26381 .70882 L
.26204 .70705 L
.25233 .70705 L
.24262 .70705 L
.23467 .69911 L
.23291 .69734 L
.22319 .69734 L
.21348 .69734 L
.20377 .69734 L
.19582 .68939 L
.19406 .68763 L
.18434 .68763 L
.17463 .68763 L
.16668 .67968 L
.16492 .67792 L
.15521 .67792 L
.14549 .67792 L
.13578 .67792 L
.12783 .66997 L
.12607 .6682 L
.11636 .6682 L
.10664 .6682 L
.0987 .66026 L
.09693 .65849 L
.08722 .65849 L
.07751 .65849 L
.06956 .65054 L
.06779 .64878 L
Mistroke
.05808 .64878 L
.05013 .64083 L
.05013 .63112 L
.05808 .62317 L
.05985 .62141 L
.05985 .61169 L
.05985 .60198 L
.06779 .59403 L
.06956 .59227 L
.06956 .58256 L
.06956 .57284 L
.07751 .5649 L
.07927 .56313 L
.07927 .55342 L
.07927 .54371 L
.08722 .53576 L
.08898 .53399 L
.08898 .52428 L
.08898 .51457 L
.09693 .50662 L
.0987 .50486 L
.0987 .49514 L
.0987 .48543 L
.10664 .47748 L
.10841 .47572 L
.10841 .46601 L
.10841 .45629 L
.11636 .44835 L
.11812 .44658 L
.11812 .43687 L
.12607 .42892 L
.12783 .42716 L
.12783 .41744 L
.12783 .40773 L
.13578 .39978 L
.13755 .39802 L
.13755 .38831 L
.14549 .38036 L
.14726 .37859 L
.14726 .36888 L
.14726 .35917 L
.15521 .35122 L
.15697 .34946 L
.15697 .33974 L
.16492 .3318 L
.16668 .33003 L
.16668 .32032 L
.17463 .31237 L
.1764 .31061 L
.1764 .30089 L
Mistroke
.1764 .29118 L
.18434 .28323 L
.18611 .28147 L
.18611 .27176 L
.19406 .26381 L
.19582 .26204 L
.19582 .25233 L
.20377 .24438 L
.20553 .24262 L
.20553 .23291 L
.21348 .22496 L
.21525 .22319 L
.21525 .21348 L
.22319 .20553 L
.22496 .20377 L
.23291 .19582 L
.23467 .19406 L
.23467 .18434 L
.24262 .1764 L
.24438 .17463 L
.24438 .16492 L
.25233 .15697 L
.2541 .15521 L
.26204 .14726 L
.26381 .14549 L
.26381 .13578 L
.27176 .12783 L
.27352 .12607 L
.28147 .11812 L
.28323 .11636 L
.29118 .10841 L
.29295 .10664 L
.30089 .0987 L
.30266 .09693 L
.30266 .08722 L
.31061 .07927 L
.31237 .07751 L
.32032 .06956 L
.33003 .06956 L
.3318 .06779 L
.33974 .05985 L
.34151 .05808 L
.34946 .05013 L
.35122 .04837 L
.35917 .04042 L
.36888 .04042 L
.37065 .03866 L
.37859 .03071 L
.38831 .03071 L
.39007 .02894 L
Mistroke
.39802 .02016 L
Mfstroke
.3 g
.39802 .02074 m
.40773 .02074 L
.41744 .02074 L
.42716 .02074 L
.43687 .02074 L
.44658 .02074 L
.45629 .02074 L
.46601 .02074 L
.47572 .02074 L
.48275 .02894 L
.48543 .03163 L
.49514 .03163 L
.50486 .03163 L
.51189 .03866 L
.51457 .04134 L
.5216 .04837 L
.52428 .05105 L
.53131 .05808 L
.53399 .06076 L
.54371 .06076 L
.55074 .06779 L
.55342 .07048 L
.56045 .07751 L
.56313 .08019 L
.57016 .08722 L
.57016 .09693 L
.57284 .09961 L
.57987 .10664 L
.58256 .10933 L
.58959 .11636 L
.59227 .11904 L
.5993 .12607 L
.60198 .12875 L
.60901 .13578 L
.60901 .14549 L
.61169 .14818 L
.61872 .15521 L
.62141 .15789 L
.62844 .16492 L
.62844 .17463 L
.63112 .17731 L
.63815 .18434 L
.63815 .19406 L
.64083 .19674 L
.64786 .20377 L
.65054 .20645 L
.65757 .21348 L
.65757 .22319 L
.66026 .22588 L
.66729 .23291 L
.66729 .24262 L
.66997 .2453 L
.677 .25233 L
.677 .26204 L
.67968 .26473 L
.68671 .27176 L
.68671 .28147 L
.68939 .28415 L
.69642 .29118 L
.69642 .30089 L
.69911 .30358 L
.70614 .31061 L
.70614 .32032 L
.70614 .33003 L
.70882 .33271 L
.71585 .33974 L
.71585 .34946 L
.71853 .35214 L
.72556 .35917 L
.72556 .36888 L
.72824 .37156 L
.73527 .37859 L
.73527 .38831 L
.73527 .39802 L
.73796 .4007 L
.74499 .40773 L
.74499 .41744 L
.74767 .42013 L
.7547 .42716 L
.7547 .43687 L
.7547 .44658 L
.75738 .44926 L
.76441 .45629 L
.76441 .46601 L
.76441 .47572 L
.76709 .4784 L
.77412 .48543 L
.77412 .49514 L
.77412 .50486 L
.77681 .50754 L
.78384 .51457 L
.78384 .52428 L
.78384 .53399 L
.78652 .53668 L
.79355 .54371 L
.79355 .55342 L
.79355 .56313 L
.79623 .56581 L
.80326 .57284 L
.80326 .58256 L
.80326 .59227 L
.80594 .59495 L
.81297 .60198 L
.81297 .61169 L
.81297 .62141 L
.81566 .62409 L
.82269 .63112 L
.82269 .64083 L
.82269 .65054 L
.82537 .65323 L
.8324 .66026 L
.8324 .66997 L
.8324 .67968 L
.83508 .68236 L
.84211 .68939 L
.84211 .69911 L
.84211 .70882 L
.84211 .71853 L
.84479 .72121 L
.85182 .72824 L
.85182 .73796 L
.85182 .74767 L
.85451 .75035 L
.86154 .75738 L
.86154 .76709 L
.86154 .77681 L
.86154 .78652 L
.86422 .7892 L
.87125 .79623 L
.87125 .80594 L
.87125 .81566 L
.87125 .82537 L
.87393 .82805 L
.88096 .83508 L
.88096 .84479 L
.88096 .85451 L
.88364 .85719 L
.89067 .86422 L
.89067 .87393 L
.89067 .88364 L
.88364 .89067 L
.87393 .89067 L
.86422 .89067 L
.85719 .88364 L
.85451 .88096 L
.84479 .88096 L
.83508 .88096 L
.82805 .87393 L
.82537 .87125 L
.81566 .87125 L
.80594 .87125 L
.79623 .87125 L
.7892 .86422 L
.78652 .86154 L
.77681 .86154 L
.76709 .86154 L
.76006 .85451 L
.75738 .85182 L
.74767 .85182 L
.73796 .85182 L
.73093 .84479 L
.72824 .84211 L
.71853 .84211 L
.70882 .84211 L
.69911 .84211 L
.69208 .83508 L
.68939 .8324 L
.67968 .8324 L
.66997 .8324 L
.66294 .82537 L
.66026 .82269 L
.65054 .82269 L
.64083 .82269 L
.63112 .82269 L
.62409 .81566 L
.62141 .81297 L
.61169 .81297 L
.60198 .81297 L
.59495 .80594 L
.59227 .80326 L
.58256 .80326 L
.57284 .80326 L
.56581 .79623 L
.56313 .79355 L
.55342 .79355 L
.54371 .79355 L
.53399 .79355 L
.52696 .78652 L
.52428 .78384 L
.51457 .78384 L
.50486 .78384 L
.49783 .77681 L
.49514 .77412 L
.48543 .77412 L
.47572 .77412 L
.46601 .77412 L
.45898 .76709 L
.45629 .76441 L
.44658 .76441 L
.43687 .76441 L
.42984 .75738 L
.42716 .7547 L
.41744 .7547 L
.40773 .7547 L
.4007 .74767 L
.39802 .74499 L
.38831 .74499 L
.37859 .74499 L
.36888 .74499 L
.36185 .73796 L
.35917 .73527 L
.34946 .73527 L
.33974 .73527 L
.33271 .72824 L
.33003 .72556 L
.32032 .72556 L
.31061 .72556 L
.30089 .72556 L
.29386 .71853 L
.29118 .71585 L
.28147 .71585 L
.27176 .71585 L
.26473 .70882 L
.26204 .70614 L
.25233 .70614 L
.24262 .70614 L
.23559 .69911 L
.23291 .69642 L
.22319 .69642 L
.21348 .69642 L
.20377 .69642 L
.19674 .68939 L
.19406 .68671 L
.18434 .68671 L
.17463 .68671 L
.1676 .67968 L
.16492 .677 L
.15521 .677 L
.14549 .677 L
.13578 .677 L
.12875 .66997 L
.12607 .66729 L
.11636 .66729 L
.10664 .66729 L
.09961 .66026 L
.09693 .65757 L
.08722 .65757 L
.07751 .65757 L
.07048 .65054 L
.06779 .64786 L
.05808 .64786 L
.05105 .64083 L
.05105 .63112 L
.05808 .62409 L
.06076 .62141 L
.06076 .61169 L
.06076 .60198 L
.06779 .59495 L
.07048 .59227 L
.07048 .58256 L
.07048 .57284 L
.07751 .56581 L
.08019 .56313 L
.08019 .55342 L
.08019 .54371 L
.08722 .53668 L
.0899 .53399 L
.0899 .52428 L
.0899 .51457 L
.09693 .50754 L
.09961 .50486 L
.09961 .49514 L
.09961 .48543 L
.10664 .4784 L
.10933 .47572 L
.10933 .46601 L
.10933 .45629 L
.11636 .44926 L
.11904 .44658 L
.11904 .43687 L
.12607 .42984 L
.12875 .42716 L
.12875 .41744 L
.12875 .40773 L
.13578 .4007 L
.13846 .39802 L
.13846 .38831 L
.14549 .38128 L
.14818 .37859 L
.14818 .36888 L
.14818 .35917 L
.15521 .35214 L
.15789 .34946 L
.15789 .33974 L
.16492 .33271 L
.1676 .33003 L
.1676 .32032 L
.17463 .31329 L
.17731 .31061 L
.17731 .30089 L
.17731 .29118 L
.18434 .28415 L
.18703 .28147 L
.18703 .27176 L
.19406 .26473 L
.19674 .26204 L
.19674 .25233 L
.20377 .2453 L
.20645 .24262 L
.20645 .23291 L
.21348 .22588 L
.21616 .22319 L
.21616 .21348 L
.22319 .20645 L
.22588 .20377 L
.23291 .19674 L
.23559 .19406 L
.23559 .18434 L
.24262 .17731 L
.2453 .17463 L
.2453 .16492 L
.25233 .15789 L
.25501 .15521 L
.26204 .14818 L
.26473 .14549 L
.26473 .13578 L
.27176 .12875 L
.27444 .12607 L
.28147 .11904 L
.28415 .11636 L
.29118 .10933 L
.29386 .10664 L
.30089 .09961 L
.30358 .09693 L
.30358 .08722 L
.31061 .08019 L
.31329 .07751 L
.32032 .07048 L
.33003 .07048 L
.33271 .06779 L
.33974 .06076 L
.34243 .05808 L
.34946 .05105 L
.35214 .04837 L
.35917 .04134 L
.36888 .04134 L
.37156 .03866 L
.37859 .03163 L
.38831 .03163 L
.39099 .02894 L
F
0 g
.39802 .02074 m
.40773 .02074 L
.41744 .02074 L
.42716 .02074 L
.43687 .02074 L
.44658 .02074 L
.45629 .02074 L
.46601 .02074 L
.47572 .02074 L
.48275 .02894 L
.48543 .03163 L
.49514 .03163 L
.50486 .03163 L
.51189 .03866 L
.51457 .04134 L
.5216 .04837 L
.52428 .05105 L
.53131 .05808 L
.53399 .06076 L
.54371 .06076 L
.55074 .06779 L
.55342 .07048 L
.56045 .07751 L
.56313 .08019 L
.57016 .08722 L
.57016 .09693 L
.57284 .09961 L
.57987 .10664 L
.58256 .10933 L
.58959 .11636 L
.59227 .11904 L
.5993 .12607 L
.60198 .12875 L
.60901 .13578 L
.60901 .14549 L
.61169 .14818 L
.61872 .15521 L
.62141 .15789 L
.62844 .16492 L
.62844 .17463 L
.63112 .17731 L
.63815 .18434 L
.63815 .19406 L
.64083 .19674 L
.64786 .20377 L
.65054 .20645 L
.65757 .21348 L
.65757 .22319 L
.66026 .22588 L
.66729 .23291 L
Mistroke
.66729 .24262 L
.66997 .2453 L
.677 .25233 L
.677 .26204 L
.67968 .26473 L
.68671 .27176 L
.68671 .28147 L
.68939 .28415 L
.69642 .29118 L
.69642 .30089 L
.69911 .30358 L
.70614 .31061 L
.70614 .32032 L
.70614 .33003 L
.70882 .33271 L
.71585 .33974 L
.71585 .34946 L
.71853 .35214 L
.72556 .35917 L
.72556 .36888 L
.72824 .37156 L
.73527 .37859 L
.73527 .38831 L
.73527 .39802 L
.73796 .4007 L
.74499 .40773 L
.74499 .41744 L
.74767 .42013 L
.7547 .42716 L
.7547 .43687 L
.7547 .44658 L
.75738 .44926 L
.76441 .45629 L
.76441 .46601 L
.76441 .47572 L
.76709 .4784 L
.77412 .48543 L
.77412 .49514 L
.77412 .50486 L
.77681 .50754 L
.78384 .51457 L
.78384 .52428 L
.78384 .53399 L
.78652 .53668 L
.79355 .54371 L
.79355 .55342 L
.79355 .56313 L
.79623 .56581 L
.80326 .57284 L
.80326 .58256 L
Mistroke
.80326 .59227 L
.80594 .59495 L
.81297 .60198 L
.81297 .61169 L
.81297 .62141 L
.81566 .62409 L
.82269 .63112 L
.82269 .64083 L
.82269 .65054 L
.82537 .65323 L
.8324 .66026 L
.8324 .66997 L
.8324 .67968 L
.83508 .68236 L
.84211 .68939 L
.84211 .69911 L
.84211 .70882 L
.84211 .71853 L
.84479 .72121 L
.85182 .72824 L
.85182 .73796 L
.85182 .74767 L
.85451 .75035 L
.86154 .75738 L
.86154 .76709 L
.86154 .77681 L
.86154 .78652 L
.86422 .7892 L
.87125 .79623 L
.87125 .80594 L
.87125 .81566 L
.87125 .82537 L
.87393 .82805 L
.88096 .83508 L
.88096 .84479 L
.88096 .85451 L
.88364 .85719 L
.89067 .86422 L
.89067 .87393 L
.89067 .88364 L
.88364 .89067 L
.87393 .89067 L
.86422 .89067 L
.85719 .88364 L
.85451 .88096 L
.84479 .88096 L
.83508 .88096 L
.82805 .87393 L
.82537 .87125 L
.81566 .87125 L
Mistroke
.80594 .87125 L
.79623 .87125 L
.7892 .86422 L
.78652 .86154 L
.77681 .86154 L
.76709 .86154 L
.76006 .85451 L
.75738 .85182 L
.74767 .85182 L
.73796 .85182 L
.73093 .84479 L
.72824 .84211 L
.71853 .84211 L
.70882 .84211 L
.69911 .84211 L
.69208 .83508 L
.68939 .8324 L
.67968 .8324 L
.66997 .8324 L
.66294 .82537 L
.66026 .82269 L
.65054 .82269 L
.64083 .82269 L
.63112 .82269 L
.62409 .81566 L
.62141 .81297 L
.61169 .81297 L
.60198 .81297 L
.59495 .80594 L
.59227 .80326 L
.58256 .80326 L
.57284 .80326 L
.56581 .79623 L
.56313 .79355 L
.55342 .79355 L
.54371 .79355 L
.53399 .79355 L
.52696 .78652 L
.52428 .78384 L
.51457 .78384 L
.50486 .78384 L
.49783 .77681 L
.49514 .77412 L
.48543 .77412 L
.47572 .77412 L
.46601 .77412 L
.45898 .76709 L
.45629 .76441 L
.44658 .76441 L
.43687 .76441 L
Mistroke
.42984 .75738 L
.42716 .7547 L
.41744 .7547 L
.40773 .7547 L
.4007 .74767 L
.39802 .74499 L
.38831 .74499 L
.37859 .74499 L
.36888 .74499 L
.36185 .73796 L
.35917 .73527 L
.34946 .73527 L
.33974 .73527 L
.33271 .72824 L
.33003 .72556 L
.32032 .72556 L
.31061 .72556 L
.30089 .72556 L
.29386 .71853 L
.29118 .71585 L
.28147 .71585 L
.27176 .71585 L
.26473 .70882 L
.26204 .70614 L
.25233 .70614 L
.24262 .70614 L
.23559 .69911 L
.23291 .69642 L
.22319 .69642 L
.21348 .69642 L
.20377 .69642 L
.19674 .68939 L
.19406 .68671 L
.18434 .68671 L
.17463 .68671 L
.1676 .67968 L
.16492 .677 L
.15521 .677 L
.14549 .677 L
.13578 .677 L
.12875 .66997 L
.12607 .66729 L
.11636 .66729 L
.10664 .66729 L
.09961 .66026 L
.09693 .65757 L
.08722 .65757 L
.07751 .65757 L
.07048 .65054 L
.06779 .64786 L
Mistroke
.05808 .64786 L
.05105 .64083 L
.05105 .63112 L
.05808 .62409 L
.06076 .62141 L
.06076 .61169 L
.06076 .60198 L
.06779 .59495 L
.07048 .59227 L
.07048 .58256 L
.07048 .57284 L
.07751 .56581 L
.08019 .56313 L
.08019 .55342 L
.08019 .54371 L
.08722 .53668 L
.0899 .53399 L
.0899 .52428 L
.0899 .51457 L
.09693 .50754 L
.09961 .50486 L
.09961 .49514 L
.09961 .48543 L
.10664 .4784 L
.10933 .47572 L
.10933 .46601 L
.10933 .45629 L
.11636 .44926 L
.11904 .44658 L
.11904 .43687 L
.12607 .42984 L
.12875 .42716 L
.12875 .41744 L
.12875 .40773 L
.13578 .4007 L
.13846 .39802 L
.13846 .38831 L
.14549 .38128 L
.14818 .37859 L
.14818 .36888 L
.14818 .35917 L
.15521 .35214 L
.15789 .34946 L
.15789 .33974 L
.16492 .33271 L
.1676 .33003 L
.1676 .32032 L
.17463 .31329 L
.17731 .31061 L
.17731 .30089 L
Mistroke
.17731 .29118 L
.18434 .28415 L
.18703 .28147 L
.18703 .27176 L
.19406 .26473 L
.19674 .26204 L
.19674 .25233 L
.20377 .2453 L
.20645 .24262 L
.20645 .23291 L
.21348 .22588 L
.21616 .22319 L
.21616 .21348 L
.22319 .20645 L
.22588 .20377 L
.23291 .19674 L
.23559 .19406 L
.23559 .18434 L
.24262 .17731 L
.2453 .17463 L
.2453 .16492 L
.25233 .15789 L
.25501 .15521 L
.26204 .14818 L
.26473 .14549 L
.26473 .13578 L
.27176 .12875 L
.27444 .12607 L
.28147 .11904 L
.28415 .11636 L
.29118 .10933 L
.29386 .10664 L
.30089 .09961 L
.30358 .09693 L
.30358 .08722 L
.31061 .08019 L
.31329 .07751 L
.32032 .07048 L
.33003 .07048 L
.33271 .06779 L
.33974 .06076 L
.34243 .05808 L
.34946 .05105 L
.35214 .04837 L
.35917 .04134 L
.36888 .04134 L
.37156 .03866 L
.37859 .03163 L
.38831 .03163 L
.39099 .02894 L
Mistroke
.39802 .02074 L
Mfstroke
.4 g
.39802 .02137 m
.40773 .02137 L
.41744 .02137 L
.42716 .02137 L
.43687 .02137 L
.44658 .02137 L
.45629 .02137 L
.46601 .02137 L
.47572 .02137 L
.48187 .02894 L
.48543 .03251 L
.49514 .03251 L
.50486 .03251 L
.511 .03866 L
.51457 .04222 L
.52072 .04837 L
.52428 .05193 L
.53043 .05808 L
.53399 .06165 L
.54371 .06165 L
.54985 .06779 L
.55342 .07136 L
.55957 .07751 L
.56313 .08107 L
.56928 .08722 L
.56928 .09693 L
.57284 .1005 L
.57899 .10664 L
.58256 .11021 L
.5887 .11636 L
.59227 .11992 L
.59842 .12607 L
.60198 .12963 L
.60813 .13578 L
.60813 .14549 L
.61169 .14906 L
.61784 .15521 L
.62141 .15877 L
.62755 .16492 L
.62755 .17463 L
.63112 .1782 L
.63727 .18434 L
.63727 .19406 L
.64083 .19762 L
.64698 .20377 L
.65054 .20733 L
.65669 .21348 L
.65669 .22319 L
.66026 .22676 L
.6664 .23291 L
.6664 .24262 L
.66997 .24618 L
.67612 .25233 L
.67612 .26204 L
.67968 .26561 L
.68583 .27176 L
.68583 .28147 L
.68939 .28503 L
.69554 .29118 L
.69554 .30089 L
.69911 .30446 L
.70525 .31061 L
.70525 .32032 L
.70525 .33003 L
.70882 .3336 L
.71497 .33974 L
.71497 .34946 L
.71853 .35302 L
.72468 .35917 L
.72468 .36888 L
.72824 .37245 L
.73439 .37859 L
.73439 .38831 L
.73439 .39802 L
.73796 .40158 L
.7441 .40773 L
.7441 .41744 L
.74767 .42101 L
.75382 .42716 L
.75382 .43687 L
.75382 .44658 L
.75738 .45015 L
.76353 .45629 L
.76353 .46601 L
.76353 .47572 L
.76709 .47928 L
.77324 .48543 L
.77324 .49514 L
.77324 .50486 L
.77681 .50842 L
.78295 .51457 L
.78295 .52428 L
.78295 .53399 L
.78652 .53756 L
.79267 .54371 L
.79267 .55342 L
.79267 .56313 L
.79623 .5667 L
.80238 .57284 L
.80238 .58256 L
.80238 .59227 L
.80594 .59583 L
.81209 .60198 L
.81209 .61169 L
.81209 .62141 L
.81566 .62497 L
.8218 .63112 L
.8218 .64083 L
.8218 .65054 L
.82537 .65411 L
.83152 .66026 L
.83152 .66997 L
.83152 .67968 L
.83508 .68325 L
.84123 .68939 L
.84123 .69911 L
.84123 .70882 L
.84123 .71853 L
.84479 .7221 L
.85094 .72824 L
.85094 .73796 L
.85094 .74767 L
.85451 .75123 L
.86065 .75738 L
.86065 .76709 L
.86065 .77681 L
.86065 .78652 L
.86422 .79008 L
.87037 .79623 L
.87037 .80594 L
.87037 .81566 L
.87037 .82537 L
.87393 .82893 L
.88008 .83508 L
.88008 .84479 L
.88008 .85451 L
.88364 .85807 L
.88979 .86422 L
.88979 .87393 L
.88979 .88364 L
.88364 .88979 L
.87393 .88979 L
.86422 .88979 L
.85807 .88364 L
.85451 .88008 L
.84479 .88008 L
.83508 .88008 L
.82893 .87393 L
.82537 .87037 L
.81566 .87037 L
.80594 .87037 L
.79623 .87037 L
.79008 .86422 L
.78652 .86065 L
.77681 .86065 L
.76709 .86065 L
.76095 .85451 L
.75738 .85094 L
.74767 .85094 L
.73796 .85094 L
.73181 .84479 L
.72824 .84123 L
.71853 .84123 L
.70882 .84123 L
.69911 .84123 L
.69296 .83508 L
.68939 .83152 L
.67968 .83152 L
.66997 .83152 L
.66382 .82537 L
.66026 .8218 L
.65054 .8218 L
.64083 .8218 L
.63112 .8218 L
.62497 .81566 L
.62141 .81209 L
.61169 .81209 L
.60198 .81209 L
.59583 .80594 L
.59227 .80238 L
.58256 .80238 L
.57284 .80238 L
.5667 .79623 L
.56313 .79267 L
.55342 .79267 L
.54371 .79267 L
.53399 .79267 L
.52785 .78652 L
.52428 .78295 L
.51457 .78295 L
.50486 .78295 L
.49871 .77681 L
.49514 .77324 L
.48543 .77324 L
.47572 .77324 L
.46601 .77324 L
.45986 .76709 L
.45629 .76353 L
.44658 .76353 L
.43687 .76353 L
.43072 .75738 L
.42716 .75382 L
.41744 .75382 L
.40773 .75382 L
.40158 .74767 L
.39802 .7441 L
.38831 .7441 L
.37859 .7441 L
.36888 .7441 L
.36273 .73796 L
.35917 .73439 L
.34946 .73439 L
.33974 .73439 L
.3336 .72824 L
.33003 .72468 L
.32032 .72468 L
.31061 .72468 L
.30089 .72468 L
.29475 .71853 L
.29118 .71497 L
.28147 .71497 L
.27176 .71497 L
.26561 .70882 L
.26204 .70525 L
.25233 .70525 L
.24262 .70525 L
.23647 .69911 L
.23291 .69554 L
.22319 .69554 L
.21348 .69554 L
.20377 .69554 L
.19762 .68939 L
.19406 .68583 L
.18434 .68583 L
.17463 .68583 L
.16848 .67968 L
.16492 .67612 L
.15521 .67612 L
.14549 .67612 L
.13578 .67612 L
.12963 .66997 L
.12607 .6664 L
.11636 .6664 L
.10664 .6664 L
.1005 .66026 L
.09693 .65669 L
.08722 .65669 L
.07751 .65669 L
.07136 .65054 L
.06779 .64698 L
.05808 .64698 L
.05193 .64083 L
.05193 .63112 L
.05808 .62497 L
.06165 .62141 L
.06165 .61169 L
.06165 .60198 L
.06779 .59583 L
.07136 .59227 L
.07136 .58256 L
.07136 .57284 L
.07751 .5667 L
.08107 .56313 L
.08107 .55342 L
.08107 .54371 L
.08722 .53756 L
.09078 .53399 L
.09078 .52428 L
.09078 .51457 L
.09693 .50842 L
.1005 .50486 L
.1005 .49514 L
.1005 .48543 L
.10664 .47928 L
.11021 .47572 L
.11021 .46601 L
.11021 .45629 L
.11636 .45015 L
.11992 .44658 L
.11992 .43687 L
.12607 .43072 L
.12963 .42716 L
.12963 .41744 L
.12963 .40773 L
.13578 .40158 L
.13935 .39802 L
.13935 .38831 L
.14549 .38216 L
.14906 .37859 L
.14906 .36888 L
.14906 .35917 L
.15521 .35302 L
.15877 .34946 L
.15877 .33974 L
.16492 .3336 L
.16848 .33003 L
.16848 .32032 L
.17463 .31417 L
.1782 .31061 L
.1782 .30089 L
.1782 .29118 L
.18434 .28503 L
.18791 .28147 L
.18791 .27176 L
.19406 .26561 L
.19762 .26204 L
.19762 .25233 L
.20377 .24618 L
.20733 .24262 L
.20733 .23291 L
.21348 .22676 L
.21705 .22319 L
.21705 .21348 L
.22319 .20733 L
.22676 .20377 L
.23291 .19762 L
.23647 .19406 L
.23647 .18434 L
.24262 .1782 L
.24618 .17463 L
.24618 .16492 L
.25233 .15877 L
.2559 .15521 L
.26204 .14906 L
.26561 .14549 L
.26561 .13578 L
.27176 .12963 L
.27532 .12607 L
.28147 .11992 L
.28503 .11636 L
.29118 .11021 L
.29475 .10664 L
.30089 .1005 L
.30446 .09693 L
.30446 .08722 L
.31061 .08107 L
.31417 .07751 L
.32032 .07136 L
.33003 .07136 L
.3336 .06779 L
.33974 .06165 L
.34331 .05808 L
.34946 .05193 L
.35302 .04837 L
.35917 .04222 L
.36888 .04222 L
.37245 .03866 L
.37859 .03251 L
.38831 .03251 L
.39187 .02894 L
F
0 g
.39802 .02137 m
.40773 .02137 L
.41744 .02137 L
.42716 .02137 L
.43687 .02137 L
.44658 .02137 L
.45629 .02137 L
.46601 .02137 L
.47572 .02137 L
.48187 .02894 L
.48543 .03251 L
.49514 .03251 L
.50486 .03251 L
.511 .03866 L
.51457 .04222 L
.52072 .04837 L
.52428 .05193 L
.53043 .05808 L
.53399 .06165 L
.54371 .06165 L
.54985 .06779 L
.55342 .07136 L
.55957 .07751 L
.56313 .08107 L
.56928 .08722 L
.56928 .09693 L
.57284 .1005 L
.57899 .10664 L
.58256 .11021 L
.5887 .11636 L
.59227 .11992 L
.59842 .12607 L
.60198 .12963 L
.60813 .13578 L
.60813 .14549 L
.61169 .14906 L
.61784 .15521 L
.62141 .15877 L
.62755 .16492 L
.62755 .17463 L
.63112 .1782 L
.63727 .18434 L
.63727 .19406 L
.64083 .19762 L
.64698 .20377 L
.65054 .20733 L
.65669 .21348 L
.65669 .22319 L
.66026 .22676 L
.6664 .23291 L
Mistroke
.6664 .24262 L
.66997 .24618 L
.67612 .25233 L
.67612 .26204 L
.67968 .26561 L
.68583 .27176 L
.68583 .28147 L
.68939 .28503 L
.69554 .29118 L
.69554 .30089 L
.69911 .30446 L
.70525 .31061 L
.70525 .32032 L
.70525 .33003 L
.70882 .3336 L
.71497 .33974 L
.71497 .34946 L
.71853 .35302 L
.72468 .35917 L
.72468 .36888 L
.72824 .37245 L
.73439 .37859 L
.73439 .38831 L
.73439 .39802 L
.73796 .40158 L
.7441 .40773 L
.7441 .41744 L
.74767 .42101 L
.75382 .42716 L
.75382 .43687 L
.75382 .44658 L
.75738 .45015 L
.76353 .45629 L
.76353 .46601 L
.76353 .47572 L
.76709 .47928 L
.77324 .48543 L
.77324 .49514 L
.77324 .50486 L
.77681 .50842 L
.78295 .51457 L
.78295 .52428 L
.78295 .53399 L
.78652 .53756 L
.79267 .54371 L
.79267 .55342 L
.79267 .56313 L
.79623 .5667 L
.80238 .57284 L
.80238 .58256 L
Mistroke
.80238 .59227 L
.80594 .59583 L
.81209 .60198 L
.81209 .61169 L
.81209 .62141 L
.81566 .62497 L
.8218 .63112 L
.8218 .64083 L
.8218 .65054 L
.82537 .65411 L
.83152 .66026 L
.83152 .66997 L
.83152 .67968 L
.83508 .68325 L
.84123 .68939 L
.84123 .69911 L
.84123 .70882 L
.84123 .71853 L
.84479 .7221 L
.85094 .72824 L
.85094 .73796 L
.85094 .74767 L
.85451 .75123 L
.86065 .75738 L
.86065 .76709 L
.86065 .77681 L
.86065 .78652 L
.86422 .79008 L
.87037 .79623 L
.87037 .80594 L
.87037 .81566 L
.87037 .82537 L
.87393 .82893 L
.88008 .83508 L
.88008 .84479 L
.88008 .85451 L
.88364 .85807 L
.88979 .86422 L
.88979 .87393 L
.88979 .88364 L
.88364 .88979 L
.87393 .88979 L
.86422 .88979 L
.85807 .88364 L
.85451 .88008 L
.84479 .88008 L
.83508 .88008 L
.82893 .87393 L
.82537 .87037 L
.81566 .87037 L
Mistroke
.80594 .87037 L
.79623 .87037 L
.79008 .86422 L
.78652 .86065 L
.77681 .86065 L
.76709 .86065 L
.76095 .85451 L
.75738 .85094 L
.74767 .85094 L
.73796 .85094 L
.73181 .84479 L
.72824 .84123 L
.71853 .84123 L
.70882 .84123 L
.69911 .84123 L
.69296 .83508 L
.68939 .83152 L
.67968 .83152 L
.66997 .83152 L
.66382 .82537 L
.66026 .8218 L
.65054 .8218 L
.64083 .8218 L
.63112 .8218 L
.62497 .81566 L
.62141 .81209 L
.61169 .81209 L
.60198 .81209 L
.59583 .80594 L
.59227 .80238 L
.58256 .80238 L
.57284 .80238 L
.5667 .79623 L
.56313 .79267 L
.55342 .79267 L
.54371 .79267 L
.53399 .79267 L
.52785 .78652 L
.52428 .78295 L
.51457 .78295 L
.50486 .78295 L
.49871 .77681 L
.49514 .77324 L
.48543 .77324 L
.47572 .77324 L
.46601 .77324 L
.45986 .76709 L
.45629 .76353 L
.44658 .76353 L
.43687 .76353 L
Mistroke
.43072 .75738 L
.42716 .75382 L
.41744 .75382 L
.40773 .75382 L
.40158 .74767 L
.39802 .7441 L
.38831 .7441 L
.37859 .7441 L
.36888 .7441 L
.36273 .73796 L
.35917 .73439 L
.34946 .73439 L
.33974 .73439 L
.3336 .72824 L
.33003 .72468 L
.32032 .72468 L
.31061 .72468 L
.30089 .72468 L
.29475 .71853 L
.29118 .71497 L
.28147 .71497 L
.27176 .71497 L
.26561 .70882 L
.26204 .70525 L
.25233 .70525 L
.24262 .70525 L
.23647 .69911 L
.23291 .69554 L
.22319 .69554 L
.21348 .69554 L
.20377 .69554 L
.19762 .68939 L
.19406 .68583 L
.18434 .68583 L
.17463 .68583 L
.16848 .67968 L
.16492 .67612 L
.15521 .67612 L
.14549 .67612 L
.13578 .67612 L
.12963 .66997 L
.12607 .6664 L
.11636 .6664 L
.10664 .6664 L
.1005 .66026 L
.09693 .65669 L
.08722 .65669 L
.07751 .65669 L
.07136 .65054 L
.06779 .64698 L
Mistroke
.05808 .64698 L
.05193 .64083 L
.05193 .63112 L
.05808 .62497 L
.06165 .62141 L
.06165 .61169 L
.06165 .60198 L
.06779 .59583 L
.07136 .59227 L
.07136 .58256 L
.07136 .57284 L
.07751 .5667 L
.08107 .56313 L
.08107 .55342 L
.08107 .54371 L
.08722 .53756 L
.09078 .53399 L
.09078 .52428 L
.09078 .51457 L
.09693 .50842 L
.1005 .50486 L
.1005 .49514 L
.1005 .48543 L
.10664 .47928 L
.11021 .47572 L
.11021 .46601 L
.11021 .45629 L
.11636 .45015 L
.11992 .44658 L
.11992 .43687 L
.12607 .43072 L
.12963 .42716 L
.12963 .41744 L
.12963 .40773 L
.13578 .40158 L
.13935 .39802 L
.13935 .38831 L
.14549 .38216 L
.14906 .37859 L
.14906 .36888 L
.14906 .35917 L
.15521 .35302 L
.15877 .34946 L
.15877 .33974 L
.16492 .3336 L
.16848 .33003 L
.16848 .32032 L
.17463 .31417 L
.1782 .31061 L
.1782 .30089 L
Mistroke
.1782 .29118 L
.18434 .28503 L
.18791 .28147 L
.18791 .27176 L
.19406 .26561 L
.19762 .26204 L
.19762 .25233 L
.20377 .24618 L
.20733 .24262 L
.20733 .23291 L
.21348 .22676 L
.21705 .22319 L
.21705 .21348 L
.22319 .20733 L
.22676 .20377 L
.23291 .19762 L
.23647 .19406 L
.23647 .18434 L
.24262 .1782 L
.24618 .17463 L
.24618 .16492 L
.25233 .15877 L
.2559 .15521 L
.26204 .14906 L
.26561 .14549 L
.26561 .13578 L
.27176 .12963 L
.27532 .12607 L
.28147 .11992 L
.28503 .11636 L
.29118 .11021 L
.29475 .10664 L
.30089 .1005 L
.30446 .09693 L
.30446 .08722 L
.31061 .08107 L
.31417 .07751 L
.32032 .07136 L
.33003 .07136 L
.3336 .06779 L
.33974 .06165 L
.34331 .05808 L
.34946 .05193 L
.35302 .04837 L
.35917 .04222 L
.36888 .04222 L
.37245 .03866 L
.37859 .03251 L
.38831 .03251 L
.39187 .02894 L
Mistroke
.39802 .02137 L
Mfstroke
.5 g
.39802 .02205 m
.40773 .02205 L
.41744 .02205 L
.42716 .02205 L
.43687 .02205 L
.44658 .02205 L
.45629 .02205 L
.46601 .02205 L
.47572 .02205 L
.481 .02894 L
.48543 .03337 L
.49514 .03337 L
.50486 .03337 L
.51014 .03866 L
.51457 .04308 L
.51985 .04837 L
.52428 .0528 L
.52957 .05808 L
.53399 .06251 L
.54371 .06251 L
.54899 .06779 L
.55342 .07222 L
.5587 .07751 L
.56313 .08193 L
.56842 .08722 L
.56842 .09693 L
.57284 .10136 L
.57813 .10664 L
.58256 .11107 L
.58784 .11636 L
.59227 .12078 L
.59755 .12607 L
.60198 .1305 L
.60727 .13578 L
.60727 .14549 L
.61169 .14992 L
.61698 .15521 L
.62141 .15963 L
.62669 .16492 L
.62669 .17463 L
.63112 .17906 L
.6364 .18434 L
.6364 .19406 L
.64083 .19848 L
.64612 .20377 L
.65054 .2082 L
.65583 .21348 L
.65583 .22319 L
.66026 .22762 L
.66554 .23291 L
.66554 .24262 L
.66997 .24705 L
.67525 .25233 L
.67525 .26204 L
.67968 .26647 L
.68497 .27176 L
.68497 .28147 L
.68939 .2859 L
.69468 .29118 L
.69468 .30089 L
.69911 .30532 L
.70439 .31061 L
.70439 .32032 L
.70439 .33003 L
.70882 .33446 L
.7141 .33974 L
.7141 .34946 L
.71853 .35388 L
.72382 .35917 L
.72382 .36888 L
.72824 .37331 L
.73353 .37859 L
.73353 .38831 L
.73353 .39802 L
.73796 .40245 L
.74324 .40773 L
.74324 .41744 L
.74767 .42187 L
.75295 .42716 L
.75295 .43687 L
.75295 .44658 L
.75738 .45101 L
.76267 .45629 L
.76267 .46601 L
.76267 .47572 L
.76709 .48015 L
.77238 .48543 L
.77238 .49514 L
.77238 .50486 L
.77681 .50928 L
.78209 .51457 L
.78209 .52428 L
.78209 .53399 L
.78652 .53842 L
.7918 .54371 L
.7918 .55342 L
.7918 .56313 L
.79623 .56756 L
.80152 .57284 L
.80152 .58256 L
.80152 .59227 L
.80594 .5967 L
.81123 .60198 L
.81123 .61169 L
.81123 .62141 L
.81566 .62583 L
.82094 .63112 L
.82094 .64083 L
.82094 .65054 L
.82537 .65497 L
.83065 .66026 L
.83065 .66997 L
.83065 .67968 L
.83508 .68411 L
.84037 .68939 L
.84037 .69911 L
.84037 .70882 L
.84037 .71853 L
.84479 .72296 L
.85008 .72824 L
.85008 .73796 L
.85008 .74767 L
.85451 .7521 L
.85979 .75738 L
.85979 .76709 L
.85979 .77681 L
.85979 .78652 L
.86422 .79095 L
.8695 .79623 L
.8695 .80594 L
.8695 .81566 L
.8695 .82537 L
.87393 .8298 L
.87922 .83508 L
.87922 .84479 L
.87922 .85451 L
.88364 .85893 L
.88893 .86422 L
.88893 .87393 L
.88893 .88364 L
.88364 .88893 L
.87393 .88893 L
.86422 .88893 L
.85893 .88364 L
.85451 .87922 L
.84479 .87922 L
.83508 .87922 L
.8298 .87393 L
.82537 .8695 L
.81566 .8695 L
.80594 .8695 L
.79623 .8695 L
.79095 .86422 L
.78652 .85979 L
.77681 .85979 L
.76709 .85979 L
.76181 .85451 L
.75738 .85008 L
.74767 .85008 L
.73796 .85008 L
.73267 .84479 L
.72824 .84037 L
.71853 .84037 L
.70882 .84037 L
.69911 .84037 L
.69382 .83508 L
.68939 .83065 L
.67968 .83065 L
.66997 .83065 L
.66468 .82537 L
.66026 .82094 L
.65054 .82094 L
.64083 .82094 L
.63112 .82094 L
.62583 .81566 L
.62141 .81123 L
.61169 .81123 L
.60198 .81123 L
.5967 .80594 L
.59227 .80152 L
.58256 .80152 L
.57284 .80152 L
.56756 .79623 L
.56313 .7918 L
.55342 .7918 L
.54371 .7918 L
.53399 .7918 L
.52871 .78652 L
.52428 .78209 L
.51457 .78209 L
.50486 .78209 L
.49957 .77681 L
.49514 .77238 L
.48543 .77238 L
.47572 .77238 L
.46601 .77238 L
.46072 .76709 L
.45629 .76267 L
.44658 .76267 L
.43687 .76267 L
.43158 .75738 L
.42716 .75295 L
.41744 .75295 L
.40773 .75295 L
.40245 .74767 L
.39802 .74324 L
.38831 .74324 L
.37859 .74324 L
.36888 .74324 L
.3636 .73796 L
.35917 .73353 L
.34946 .73353 L
.33974 .73353 L
.33446 .72824 L
.33003 .72382 L
.32032 .72382 L
.31061 .72382 L
.30089 .72382 L
.29561 .71853 L
.29118 .7141 L
.28147 .7141 L
.27176 .7141 L
.26647 .70882 L
.26204 .70439 L
.25233 .70439 L
.24262 .70439 L
.23733 .69911 L
.23291 .69468 L
.22319 .69468 L
.21348 .69468 L
.20377 .69468 L
.19848 .68939 L
.19406 .68497 L
.18434 .68497 L
.17463 .68497 L
.16935 .67968 L
.16492 .67525 L
.15521 .67525 L
.14549 .67525 L
.13578 .67525 L
.1305 .66997 L
.12607 .66554 L
.11636 .66554 L
.10664 .66554 L
.10136 .66026 L
.09693 .65583 L
.08722 .65583 L
.07751 .65583 L
.07222 .65054 L
.06779 .64612 L
.05808 .64612 L
.0528 .64083 L
.0528 .63112 L
.05808 .62583 L
.06251 .62141 L
.06251 .61169 L
.06251 .60198 L
.06779 .5967 L
.07222 .59227 L
.07222 .58256 L
.07222 .57284 L
.07751 .56756 L
.08193 .56313 L
.08193 .55342 L
.08193 .54371 L
.08722 .53842 L
.09165 .53399 L
.09165 .52428 L
.09165 .51457 L
.09693 .50928 L
.10136 .50486 L
.10136 .49514 L
.10136 .48543 L
.10664 .48015 L
.11107 .47572 L
.11107 .46601 L
.11107 .45629 L
.11636 .45101 L
.12078 .44658 L
.12078 .43687 L
.12607 .43158 L
.1305 .42716 L
.1305 .41744 L
.1305 .40773 L
.13578 .40245 L
.14021 .39802 L
.14021 .38831 L
.14549 .38302 L
.14992 .37859 L
.14992 .36888 L
.14992 .35917 L
.15521 .35388 L
.15963 .34946 L
.15963 .33974 L
.16492 .33446 L
.16935 .33003 L
.16935 .32032 L
.17463 .31503 L
.17906 .31061 L
.17906 .30089 L
.17906 .29118 L
.18434 .2859 L
.18877 .28147 L
.18877 .27176 L
.19406 .26647 L
.19848 .26204 L
.19848 .25233 L
.20377 .24705 L
.2082 .24262 L
.2082 .23291 L
.21348 .22762 L
.21791 .22319 L
.21791 .21348 L
.22319 .2082 L
.22762 .20377 L
.23291 .19848 L
.23733 .19406 L
.23733 .18434 L
.24262 .17906 L
.24705 .17463 L
.24705 .16492 L
.25233 .15963 L
.25676 .15521 L
.26204 .14992 L
.26647 .14549 L
.26647 .13578 L
.27176 .1305 L
.27618 .12607 L
.28147 .12078 L
.2859 .11636 L
.29118 .11107 L
.29561 .10664 L
.30089 .10136 L
.30532 .09693 L
.30532 .08722 L
.31061 .08193 L
.31503 .07751 L
.32032 .07222 L
.33003 .07222 L
.33446 .06779 L
.33974 .06251 L
.34417 .05808 L
.34946 .0528 L
.35388 .04837 L
.35917 .04308 L
.36888 .04308 L
.37331 .03866 L
.37859 .03337 L
.38831 .03337 L
.39273 .02894 L
F
0 g
.39802 .02205 m
.40773 .02205 L
.41744 .02205 L
.42716 .02205 L
.43687 .02205 L
.44658 .02205 L
.45629 .02205 L
.46601 .02205 L
.47572 .02205 L
.481 .02894 L
.48543 .03337 L
.49514 .03337 L
.50486 .03337 L
.51014 .03866 L
.51457 .04308 L
.51985 .04837 L
.52428 .0528 L
.52957 .05808 L
.53399 .06251 L
.54371 .06251 L
.54899 .06779 L
.55342 .07222 L
.5587 .07751 L
.56313 .08193 L
.56842 .08722 L
.56842 .09693 L
.57284 .10136 L
.57813 .10664 L
.58256 .11107 L
.58784 .11636 L
.59227 .12078 L
.59755 .12607 L
.60198 .1305 L
.60727 .13578 L
.60727 .14549 L
.61169 .14992 L
.61698 .15521 L
.62141 .15963 L
.62669 .16492 L
.62669 .17463 L
.63112 .17906 L
.6364 .18434 L
.6364 .19406 L
.64083 .19848 L
.64612 .20377 L
.65054 .2082 L
.65583 .21348 L
.65583 .22319 L
.66026 .22762 L
.66554 .23291 L
Mistroke
.66554 .24262 L
.66997 .24705 L
.67525 .25233 L
.67525 .26204 L
.67968 .26647 L
.68497 .27176 L
.68497 .28147 L
.68939 .2859 L
.69468 .29118 L
.69468 .30089 L
.69911 .30532 L
.70439 .31061 L
.70439 .32032 L
.70439 .33003 L
.70882 .33446 L
.7141 .33974 L
.7141 .34946 L
.71853 .35388 L
.72382 .35917 L
.72382 .36888 L
.72824 .37331 L
.73353 .37859 L
.73353 .38831 L
.73353 .39802 L
.73796 .40245 L
.74324 .40773 L
.74324 .41744 L
.74767 .42187 L
.75295 .42716 L
.75295 .43687 L
.75295 .44658 L
.75738 .45101 L
.76267 .45629 L
.76267 .46601 L
.76267 .47572 L
.76709 .48015 L
.77238 .48543 L
.77238 .49514 L
.77238 .50486 L
.77681 .50928 L
.78209 .51457 L
.78209 .52428 L
.78209 .53399 L
.78652 .53842 L
.7918 .54371 L
.7918 .55342 L
.7918 .56313 L
.79623 .56756 L
.80152 .57284 L
.80152 .58256 L
Mistroke
.80152 .59227 L
.80594 .5967 L
.81123 .60198 L
.81123 .61169 L
.81123 .62141 L
.81566 .62583 L
.82094 .63112 L
.82094 .64083 L
.82094 .65054 L
.82537 .65497 L
.83065 .66026 L
.83065 .66997 L
.83065 .67968 L
.83508 .68411 L
.84037 .68939 L
.84037 .69911 L
.84037 .70882 L
.84037 .71853 L
.84479 .72296 L
.85008 .72824 L
.85008 .73796 L
.85008 .74767 L
.85451 .7521 L
.85979 .75738 L
.85979 .76709 L
.85979 .77681 L
.85979 .78652 L
.86422 .79095 L
.8695 .79623 L
.8695 .80594 L
.8695 .81566 L
.8695 .82537 L
.87393 .8298 L
.87922 .83508 L
.87922 .84479 L
.87922 .85451 L
.88364 .85893 L
.88893 .86422 L
.88893 .87393 L
.88893 .88364 L
.88364 .88893 L
.87393 .88893 L
.86422 .88893 L
.85893 .88364 L
.85451 .87922 L
.84479 .87922 L
.83508 .87922 L
.8298 .87393 L
.82537 .8695 L
.81566 .8695 L
Mistroke
.80594 .8695 L
.79623 .8695 L
.79095 .86422 L
.78652 .85979 L
.77681 .85979 L
.76709 .85979 L
.76181 .85451 L
.75738 .85008 L
.74767 .85008 L
.73796 .85008 L
.73267 .84479 L
.72824 .84037 L
.71853 .84037 L
.70882 .84037 L
.69911 .84037 L
.69382 .83508 L
.68939 .83065 L
.67968 .83065 L
.66997 .83065 L
.66468 .82537 L
.66026 .82094 L
.65054 .82094 L
.64083 .82094 L
.63112 .82094 L
.62583 .81566 L
.62141 .81123 L
.61169 .81123 L
.60198 .81123 L
.5967 .80594 L
.59227 .80152 L
.58256 .80152 L
.57284 .80152 L
.56756 .79623 L
.56313 .7918 L
.55342 .7918 L
.54371 .7918 L
.53399 .7918 L
.52871 .78652 L
.52428 .78209 L
.51457 .78209 L
.50486 .78209 L
.49957 .77681 L
.49514 .77238 L
.48543 .77238 L
.47572 .77238 L
.46601 .77238 L
.46072 .76709 L
.45629 .76267 L
.44658 .76267 L
.43687 .76267 L
Mistroke
.43158 .75738 L
.42716 .75295 L
.41744 .75295 L
.40773 .75295 L
.40245 .74767 L
.39802 .74324 L
.38831 .74324 L
.37859 .74324 L
.36888 .74324 L
.3636 .73796 L
.35917 .73353 L
.34946 .73353 L
.33974 .73353 L
.33446 .72824 L
.33003 .72382 L
.32032 .72382 L
.31061 .72382 L
.30089 .72382 L
.29561 .71853 L
.29118 .7141 L
.28147 .7141 L
.27176 .7141 L
.26647 .70882 L
.26204 .70439 L
.25233 .70439 L
.24262 .70439 L
.23733 .69911 L
.23291 .69468 L
.22319 .69468 L
.21348 .69468 L
.20377 .69468 L
.19848 .68939 L
.19406 .68497 L
.18434 .68497 L
.17463 .68497 L
.16935 .67968 L
.16492 .67525 L
.15521 .67525 L
.14549 .67525 L
.13578 .67525 L
.1305 .66997 L
.12607 .66554 L
.11636 .66554 L
.10664 .66554 L
.10136 .66026 L
.09693 .65583 L
.08722 .65583 L
.07751 .65583 L
.07222 .65054 L
.06779 .64612 L
Mistroke
.05808 .64612 L
.0528 .64083 L
.0528 .63112 L
.05808 .62583 L
.06251 .62141 L
.06251 .61169 L
.06251 .60198 L
.06779 .5967 L
.07222 .59227 L
.07222 .58256 L
.07222 .57284 L
.07751 .56756 L
.08193 .56313 L
.08193 .55342 L
.08193 .54371 L
.08722 .53842 L
.09165 .53399 L
.09165 .52428 L
.09165 .51457 L
.09693 .50928 L
.10136 .50486 L
.10136 .49514 L
.10136 .48543 L
.10664 .48015 L
.11107 .47572 L
.11107 .46601 L
.11107 .45629 L
.11636 .45101 L
.12078 .44658 L
.12078 .43687 L
.12607 .43158 L
.1305 .42716 L
.1305 .41744 L
.1305 .40773 L
.13578 .40245 L
.14021 .39802 L
.14021 .38831 L
.14549 .38302 L
.14992 .37859 L
.14992 .36888 L
.14992 .35917 L
.15521 .35388 L
.15963 .34946 L
.15963 .33974 L
.16492 .33446 L
.16935 .33003 L
.16935 .32032 L
.17463 .31503 L
.17906 .31061 L
.17906 .30089 L
Mistroke
.17906 .29118 L
.18434 .2859 L
.18877 .28147 L
.18877 .27176 L
.19406 .26647 L
.19848 .26204 L
.19848 .25233 L
.20377 .24705 L
.2082 .24262 L
.2082 .23291 L
.21348 .22762 L
.21791 .22319 L
.21791 .21348 L
.22319 .2082 L
.22762 .20377 L
.23291 .19848 L
.23733 .19406 L
.23733 .18434 L
.24262 .17906 L
.24705 .17463 L
.24705 .16492 L
.25233 .15963 L
.25676 .15521 L
.26204 .14992 L
.26647 .14549 L
.26647 .13578 L
.27176 .1305 L
.27618 .12607 L
.28147 .12078 L
.2859 .11636 L
.29118 .11107 L
.29561 .10664 L
.30089 .10136 L
.30532 .09693 L
.30532 .08722 L
.31061 .08193 L
.31503 .07751 L
.32032 .07222 L
.33003 .07222 L
.33446 .06779 L
.33974 .06251 L
.34417 .05808 L
.34946 .0528 L
.35388 .04837 L
.35917 .04308 L
.36888 .04308 L
.37331 .03866 L
.37859 .03337 L
.38831 .03337 L
.39273 .02894 L
Mistroke
.39802 .02205 L
Mfstroke
.6 g
.39802 .02281 m
.40773 .02281 L
.41744 .02281 L
.42716 .02281 L
.43687 .02281 L
.44658 .02281 L
.45629 .02281 L
.46601 .02281 L
.47572 .02281 L
.48015 .02894 L
.48543 .03423 L
.49514 .03423 L
.50486 .03423 L
.50928 .03866 L
.51457 .04394 L
.519 .04837 L
.52428 .05365 L
.52871 .05808 L
.53399 .06337 L
.54371 .06337 L
.54813 .06779 L
.55342 .07308 L
.55785 .07751 L
.56313 .08279 L
.56756 .08722 L
.56756 .09693 L
.57284 .10222 L
.57727 .10664 L
.58256 .11193 L
.58698 .11636 L
.59227 .12164 L
.5967 .12607 L
.60198 .13135 L
.60641 .13578 L
.60641 .14549 L
.61169 .15078 L
.61612 .15521 L
.62141 .16049 L
.62583 .16492 L
.62583 .17463 L
.63112 .17992 L
.63555 .18434 L
.63555 .19406 L
.64083 .19934 L
.64526 .20377 L
.65054 .20905 L
.65497 .21348 L
.65497 .22319 L
.66026 .22848 L
.66468 .23291 L
.66468 .24262 L
.66997 .2479 L
.6744 .25233 L
.6744 .26204 L
.67968 .26733 L
.68411 .27176 L
.68411 .28147 L
.68939 .28675 L
.69382 .29118 L
.69382 .30089 L
.69911 .30618 L
.70353 .31061 L
.70353 .32032 L
.70353 .33003 L
.70882 .33532 L
.71325 .33974 L
.71325 .34946 L
.71853 .35474 L
.72296 .35917 L
.72296 .36888 L
.72824 .37417 L
.73267 .37859 L
.73267 .38831 L
.73267 .39802 L
.73796 .4033 L
.74238 .40773 L
.74238 .41744 L
.74767 .42273 L
.7521 .42716 L
.7521 .43687 L
.7521 .44658 L
.75738 .45187 L
.76181 .45629 L
.76181 .46601 L
.76181 .47572 L
.76709 .481 L
.77152 .48543 L
.77152 .49514 L
.77152 .50486 L
.77681 .51014 L
.78123 .51457 L
.78123 .52428 L
.78123 .53399 L
.78652 .53928 L
.79095 .54371 L
.79095 .55342 L
.79095 .56313 L
.79623 .56842 L
.80066 .57284 L
.80066 .58256 L
.80066 .59227 L
.80594 .59755 L
.81037 .60198 L
.81037 .61169 L
.81037 .62141 L
.81566 .62669 L
.82008 .63112 L
.82008 .64083 L
.82008 .65054 L
.82537 .65583 L
.8298 .66026 L
.8298 .66997 L
.8298 .67968 L
.83508 .68497 L
.83951 .68939 L
.83951 .69911 L
.83951 .70882 L
.83951 .71853 L
.84479 .72382 L
.84922 .72824 L
.84922 .73796 L
.84922 .74767 L
.85451 .75295 L
.85893 .75738 L
.85893 .76709 L
.85893 .77681 L
.85893 .78652 L
.86422 .7918 L
.86865 .79623 L
.86865 .80594 L
.86865 .81566 L
.86865 .82537 L
.87393 .83065 L
.87836 .83508 L
.87836 .84479 L
.87836 .85451 L
.88364 .85979 L
.88807 .86422 L
.88807 .87393 L
.88807 .88364 L
.88364 .88807 L
.87393 .88807 L
.86422 .88807 L
.85979 .88364 L
.85451 .87836 L
.84479 .87836 L
.83508 .87836 L
.83065 .87393 L
.82537 .86865 L
.81566 .86865 L
.80594 .86865 L
.79623 .86865 L
.7918 .86422 L
.78652 .85893 L
.77681 .85893 L
.76709 .85893 L
.76267 .85451 L
.75738 .84922 L
.74767 .84922 L
.73796 .84922 L
.73353 .84479 L
.72824 .83951 L
.71853 .83951 L
.70882 .83951 L
.69911 .83951 L
.69468 .83508 L
.68939 .8298 L
.67968 .8298 L
.66997 .8298 L
.66554 .82537 L
.66026 .82008 L
.65054 .82008 L
.64083 .82008 L
.63112 .82008 L
.62669 .81566 L
.62141 .81037 L
.61169 .81037 L
.60198 .81037 L
.59755 .80594 L
.59227 .80066 L
.58256 .80066 L
.57284 .80066 L
.56842 .79623 L
.56313 .79095 L
.55342 .79095 L
.54371 .79095 L
.53399 .79095 L
.52957 .78652 L
.52428 .78123 L
.51457 .78123 L
.50486 .78123 L
.50043 .77681 L
.49514 .77152 L
.48543 .77152 L
.47572 .77152 L
.46601 .77152 L
.46158 .76709 L
.45629 .76181 L
.44658 .76181 L
.43687 .76181 L
.43244 .75738 L
.42716 .7521 L
.41744 .7521 L
.40773 .7521 L
.4033 .74767 L
.39802 .74238 L
.38831 .74238 L
.37859 .74238 L
.36888 .74238 L
.36445 .73796 L
.35917 .73267 L
.34946 .73267 L
.33974 .73267 L
.33532 .72824 L
.33003 .72296 L
.32032 .72296 L
.31061 .72296 L
.30089 .72296 L
.29647 .71853 L
.29118 .71325 L
.28147 .71325 L
.27176 .71325 L
.26733 .70882 L
.26204 .70353 L
.25233 .70353 L
.24262 .70353 L
.23819 .69911 L
.23291 .69382 L
.22319 .69382 L
.21348 .69382 L
.20377 .69382 L
.19934 .68939 L
.19406 .68411 L
.18434 .68411 L
.17463 .68411 L
.1702 .67968 L
.16492 .6744 L
.15521 .6744 L
.14549 .6744 L
.13578 .6744 L
.13135 .66997 L
.12607 .66468 L
.11636 .66468 L
.10664 .66468 L
.10222 .66026 L
.09693 .65497 L
.08722 .65497 L
.07751 .65497 L
.07308 .65054 L
.06779 .64526 L
.05808 .64526 L
.05365 .64083 L
.05365 .63112 L
.05808 .62669 L
.06337 .62141 L
.06337 .61169 L
.06337 .60198 L
.06779 .59755 L
.07308 .59227 L
.07308 .58256 L
.07308 .57284 L
.07751 .56842 L
.08279 .56313 L
.08279 .55342 L
.08279 .54371 L
.08722 .53928 L
.0925 .53399 L
.0925 .52428 L
.0925 .51457 L
.09693 .51014 L
.10222 .50486 L
.10222 .49514 L
.10222 .48543 L
.10664 .481 L
.11193 .47572 L
.11193 .46601 L
.11193 .45629 L
.11636 .45187 L
.12164 .44658 L
.12164 .43687 L
.12607 .43244 L
.13135 .42716 L
.13135 .41744 L
.13135 .40773 L
.13578 .4033 L
.14107 .39802 L
.14107 .38831 L
.14549 .38388 L
.15078 .37859 L
.15078 .36888 L
.15078 .35917 L
.15521 .35474 L
.16049 .34946 L
.16049 .33974 L
.16492 .33532 L
.1702 .33003 L
.1702 .32032 L
.17463 .31589 L
.17992 .31061 L
.17992 .30089 L
.17992 .29118 L
.18434 .28675 L
.18963 .28147 L
.18963 .27176 L
.19406 .26733 L
.19934 .26204 L
.19934 .25233 L
.20377 .2479 L
.20905 .24262 L
.20905 .23291 L
.21348 .22848 L
.21877 .22319 L
.21877 .21348 L
.22319 .20905 L
.22848 .20377 L
.23291 .19934 L
.23819 .19406 L
.23819 .18434 L
.24262 .17992 L
.2479 .17463 L
.2479 .16492 L
.25233 .16049 L
.25762 .15521 L
.26204 .15078 L
.26733 .14549 L
.26733 .13578 L
.27176 .13135 L
.27704 .12607 L
.28147 .12164 L
.28675 .11636 L
.29118 .11193 L
.29647 .10664 L
.30089 .10222 L
.30618 .09693 L
.30618 .08722 L
.31061 .08279 L
.31589 .07751 L
.32032 .07308 L
.33003 .07308 L
.33532 .06779 L
.33974 .06337 L
.34503 .05808 L
.34946 .05365 L
.35474 .04837 L
.35917 .04394 L
.36888 .04394 L
.37417 .03866 L
.37859 .03423 L
.38831 .03423 L
.39359 .02894 L
F
0 g
.39802 .02281 m
.40773 .02281 L
.41744 .02281 L
.42716 .02281 L
.43687 .02281 L
.44658 .02281 L
.45629 .02281 L
.46601 .02281 L
.47572 .02281 L
.48015 .02894 L
.48543 .03423 L
.49514 .03423 L
.50486 .03423 L
.50928 .03866 L
.51457 .04394 L
.519 .04837 L
.52428 .05365 L
.52871 .05808 L
.53399 .06337 L
.54371 .06337 L
.54813 .06779 L
.55342 .07308 L
.55785 .07751 L
.56313 .08279 L
.56756 .08722 L
.56756 .09693 L
.57284 .10222 L
.57727 .10664 L
.58256 .11193 L
.58698 .11636 L
.59227 .12164 L
.5967 .12607 L
.60198 .13135 L
.60641 .13578 L
.60641 .14549 L
.61169 .15078 L
.61612 .15521 L
.62141 .16049 L
.62583 .16492 L
.62583 .17463 L
.63112 .17992 L
.63555 .18434 L
.63555 .19406 L
.64083 .19934 L
.64526 .20377 L
.65054 .20905 L
.65497 .21348 L
.65497 .22319 L
.66026 .22848 L
.66468 .23291 L
Mistroke
.66468 .24262 L
.66997 .2479 L
.6744 .25233 L
.6744 .26204 L
.67968 .26733 L
.68411 .27176 L
.68411 .28147 L
.68939 .28675 L
.69382 .29118 L
.69382 .30089 L
.69911 .30618 L
.70353 .31061 L
.70353 .32032 L
.70353 .33003 L
.70882 .33532 L
.71325 .33974 L
.71325 .34946 L
.71853 .35474 L
.72296 .35917 L
.72296 .36888 L
.72824 .37417 L
.73267 .37859 L
.73267 .38831 L
.73267 .39802 L
.73796 .4033 L
.74238 .40773 L
.74238 .41744 L
.74767 .42273 L
.7521 .42716 L
.7521 .43687 L
.7521 .44658 L
.75738 .45187 L
.76181 .45629 L
.76181 .46601 L
.76181 .47572 L
.76709 .481 L
.77152 .48543 L
.77152 .49514 L
.77152 .50486 L
.77681 .51014 L
.78123 .51457 L
.78123 .52428 L
.78123 .53399 L
.78652 .53928 L
.79095 .54371 L
.79095 .55342 L
.79095 .56313 L
.79623 .56842 L
.80066 .57284 L
.80066 .58256 L
Mistroke
.80066 .59227 L
.80594 .59755 L
.81037 .60198 L
.81037 .61169 L
.81037 .62141 L
.81566 .62669 L
.82008 .63112 L
.82008 .64083 L
.82008 .65054 L
.82537 .65583 L
.8298 .66026 L
.8298 .66997 L
.8298 .67968 L
.83508 .68497 L
.83951 .68939 L
.83951 .69911 L
.83951 .70882 L
.83951 .71853 L
.84479 .72382 L
.84922 .72824 L
.84922 .73796 L
.84922 .74767 L
.85451 .75295 L
.85893 .75738 L
.85893 .76709 L
.85893 .77681 L
.85893 .78652 L
.86422 .7918 L
.86865 .79623 L
.86865 .80594 L
.86865 .81566 L
.86865 .82537 L
.87393 .83065 L
.87836 .83508 L
.87836 .84479 L
.87836 .85451 L
.88364 .85979 L
.88807 .86422 L
.88807 .87393 L
.88807 .88364 L
.88364 .88807 L
.87393 .88807 L
.86422 .88807 L
.85979 .88364 L
.85451 .87836 L
.84479 .87836 L
.83508 .87836 L
.83065 .87393 L
.82537 .86865 L
.81566 .86865 L
Mistroke
.80594 .86865 L
.79623 .86865 L
.7918 .86422 L
.78652 .85893 L
.77681 .85893 L
.76709 .85893 L
.76267 .85451 L
.75738 .84922 L
.74767 .84922 L
.73796 .84922 L
.73353 .84479 L
.72824 .83951 L
.71853 .83951 L
.70882 .83951 L
.69911 .83951 L
.69468 .83508 L
.68939 .8298 L
.67968 .8298 L
.66997 .8298 L
.66554 .82537 L
.66026 .82008 L
.65054 .82008 L
.64083 .82008 L
.63112 .82008 L
.62669 .81566 L
.62141 .81037 L
.61169 .81037 L
.60198 .81037 L
.59755 .80594 L
.59227 .80066 L
.58256 .80066 L
.57284 .80066 L
.56842 .79623 L
.56313 .79095 L
.55342 .79095 L
.54371 .79095 L
.53399 .79095 L
.52957 .78652 L
.52428 .78123 L
.51457 .78123 L
.50486 .78123 L
.50043 .77681 L
.49514 .77152 L
.48543 .77152 L
.47572 .77152 L
.46601 .77152 L
.46158 .76709 L
.45629 .76181 L
.44658 .76181 L
.43687 .76181 L
Mistroke
.43244 .75738 L
.42716 .7521 L
.41744 .7521 L
.40773 .7521 L
.4033 .74767 L
.39802 .74238 L
.38831 .74238 L
.37859 .74238 L
.36888 .74238 L
.36445 .73796 L
.35917 .73267 L
.34946 .73267 L
.33974 .73267 L
.33532 .72824 L
.33003 .72296 L
.32032 .72296 L
.31061 .72296 L
.30089 .72296 L
.29647 .71853 L
.29118 .71325 L
.28147 .71325 L
.27176 .71325 L
.26733 .70882 L
.26204 .70353 L
.25233 .70353 L
.24262 .70353 L
.23819 .69911 L
.23291 .69382 L
.22319 .69382 L
.21348 .69382 L
.20377 .69382 L
.19934 .68939 L
.19406 .68411 L
.18434 .68411 L
.17463 .68411 L
.1702 .67968 L
.16492 .6744 L
.15521 .6744 L
.14549 .6744 L
.13578 .6744 L
.13135 .66997 L
.12607 .66468 L
.11636 .66468 L
.10664 .66468 L
.10222 .66026 L
.09693 .65497 L
.08722 .65497 L
.07751 .65497 L
.07308 .65054 L
.06779 .64526 L
Mistroke
.05808 .64526 L
.05365 .64083 L
.05365 .63112 L
.05808 .62669 L
.06337 .62141 L
.06337 .61169 L
.06337 .60198 L
.06779 .59755 L
.07308 .59227 L
.07308 .58256 L
.07308 .57284 L
.07751 .56842 L
.08279 .56313 L
.08279 .55342 L
.08279 .54371 L
.08722 .53928 L
.0925 .53399 L
.0925 .52428 L
.0925 .51457 L
.09693 .51014 L
.10222 .50486 L
.10222 .49514 L
.10222 .48543 L
.10664 .481 L
.11193 .47572 L
.11193 .46601 L
.11193 .45629 L
.11636 .45187 L
.12164 .44658 L
.12164 .43687 L
.12607 .43244 L
.13135 .42716 L
.13135 .41744 L
.13135 .40773 L
.13578 .4033 L
.14107 .39802 L
.14107 .38831 L
.14549 .38388 L
.15078 .37859 L
.15078 .36888 L
.15078 .35917 L
.15521 .35474 L
.16049 .34946 L
.16049 .33974 L
.16492 .33532 L
.1702 .33003 L
.1702 .32032 L
.17463 .31589 L
.17992 .31061 L
.17992 .30089 L
Mistroke
.17992 .29118 L
.18434 .28675 L
.18963 .28147 L
.18963 .27176 L
.19406 .26733 L
.19934 .26204 L
.19934 .25233 L
.20377 .2479 L
.20905 .24262 L
.20905 .23291 L
.21348 .22848 L
.21877 .22319 L
.21877 .21348 L
.22319 .20905 L
.22848 .20377 L
.23291 .19934 L
.23819 .19406 L
.23819 .18434 L
.24262 .17992 L
.2479 .17463 L
.2479 .16492 L
.25233 .16049 L
.25762 .15521 L
.26204 .15078 L
.26733 .14549 L
.26733 .13578 L
.27176 .13135 L
.27704 .12607 L
.28147 .12164 L
.28675 .11636 L
.29118 .11193 L
.29647 .10664 L
.30089 .10222 L
.30618 .09693 L
.30618 .08722 L
.31061 .08279 L
.31589 .07751 L
.32032 .07308 L
.33003 .07308 L
.33532 .06779 L
.33974 .06337 L
.34503 .05808 L
.34946 .05365 L
.35474 .04837 L
.35917 .04394 L
.36888 .04394 L
.37417 .03866 L
.37859 .03423 L
.38831 .03423 L
.39359 .02894 L
Mistroke
.39802 .02281 L
Mfstroke
.7 g
.39802 .02365 m
.40773 .02365 L
.41744 .02365 L
.42716 .02365 L
.43687 .02365 L
.44658 .02365 L
.45629 .02365 L
.46601 .02365 L
.47572 .02365 L
.47928 .02894 L
.48543 .03509 L
.49514 .03509 L
.50486 .03509 L
.50842 .03866 L
.51457 .0448 L
.51813 .04837 L
.52428 .05452 L
.52785 .05808 L
.53399 .06423 L
.54371 .06423 L
.54727 .06779 L
.55342 .07394 L
.55698 .07751 L
.56313 .08365 L
.5667 .08722 L
.5667 .09693 L
.57284 .10308 L
.57641 .10664 L
.58256 .11279 L
.58612 .11636 L
.59227 .1225 L
.59583 .12607 L
.60198 .13222 L
.60555 .13578 L
.60555 .14549 L
.61169 .15164 L
.61526 .15521 L
.62141 .16135 L
.62497 .16492 L
.62497 .17463 L
.63112 .18078 L
.63468 .18434 L
.63468 .19406 L
.64083 .2002 L
.6444 .20377 L
.65054 .20992 L
.65411 .21348 L
.65411 .22319 L
.66026 .22934 L
.66382 .23291 L
.66382 .24262 L
.66997 .24877 L
.67353 .25233 L
.67353 .26204 L
.67968 .26819 L
.68325 .27176 L
.68325 .28147 L
.68939 .28762 L
.69296 .29118 L
.69296 .30089 L
.69911 .30704 L
.70267 .31061 L
.70267 .32032 L
.70267 .33003 L
.70882 .33618 L
.71238 .33974 L
.71238 .34946 L
.71853 .3556 L
.7221 .35917 L
.7221 .36888 L
.72824 .37503 L
.73181 .37859 L
.73181 .38831 L
.73181 .39802 L
.73796 .40417 L
.74152 .40773 L
.74152 .41744 L
.74767 .42359 L
.75123 .42716 L
.75123 .43687 L
.75123 .44658 L
.75738 .45273 L
.76095 .45629 L
.76095 .46601 L
.76095 .47572 L
.76709 .48187 L
.77066 .48543 L
.77066 .49514 L
.77066 .50486 L
.77681 .511 L
.78037 .51457 L
.78037 .52428 L
.78037 .53399 L
.78652 .54014 L
.79008 .54371 L
.79008 .55342 L
.79008 .56313 L
.79623 .56928 L
.7998 .57284 L
.7998 .58256 L
.7998 .59227 L
.80594 .59842 L
.80951 .60198 L
.80951 .61169 L
.80951 .62141 L
.81566 .62755 L
.81922 .63112 L
.81922 .64083 L
.81922 .65054 L
.82537 .65669 L
.82893 .66026 L
.82893 .66997 L
.82893 .67968 L
.83508 .68583 L
.83865 .68939 L
.83865 .69911 L
.83865 .70882 L
.83865 .71853 L
.84479 .72468 L
.84836 .72824 L
.84836 .73796 L
.84836 .74767 L
.85451 .75382 L
.85807 .75738 L
.85807 .76709 L
.85807 .77681 L
.85807 .78652 L
.86422 .79267 L
.86778 .79623 L
.86778 .80594 L
.86778 .81566 L
.86778 .82537 L
.87393 .83152 L
.8775 .83508 L
.8775 .84479 L
.8775 .85451 L
.88364 .86065 L
.88721 .86422 L
.88721 .87393 L
.88721 .88364 L
.88364 .88721 L
.87393 .88721 L
.86422 .88721 L
.86065 .88364 L
.85451 .8775 L
.84479 .8775 L
.83508 .8775 L
.83152 .87393 L
.82537 .86778 L
.81566 .86778 L
.80594 .86778 L
.79623 .86778 L
.79267 .86422 L
.78652 .85807 L
.77681 .85807 L
.76709 .85807 L
.76353 .85451 L
.75738 .84836 L
.74767 .84836 L
.73796 .84836 L
.73439 .84479 L
.72824 .83865 L
.71853 .83865 L
.70882 .83865 L
.69911 .83865 L
.69554 .83508 L
.68939 .82893 L
.67968 .82893 L
.66997 .82893 L
.6664 .82537 L
.66026 .81922 L
.65054 .81922 L
.64083 .81922 L
.63112 .81922 L
.62755 .81566 L
.62141 .80951 L
.61169 .80951 L
.60198 .80951 L
.59842 .80594 L
.59227 .7998 L
.58256 .7998 L
.57284 .7998 L
.56928 .79623 L
.56313 .79008 L
.55342 .79008 L
.54371 .79008 L
.53399 .79008 L
.53043 .78652 L
.52428 .78037 L
.51457 .78037 L
.50486 .78037 L
.50129 .77681 L
.49514 .77066 L
.48543 .77066 L
.47572 .77066 L
.46601 .77066 L
.46244 .76709 L
.45629 .76095 L
.44658 .76095 L
.43687 .76095 L
.4333 .75738 L
.42716 .75123 L
.41744 .75123 L
.40773 .75123 L
.40417 .74767 L
.39802 .74152 L
.38831 .74152 L
.37859 .74152 L
.36888 .74152 L
.36532 .73796 L
.35917 .73181 L
.34946 .73181 L
.33974 .73181 L
.33618 .72824 L
.33003 .7221 L
.32032 .7221 L
.31061 .7221 L
.30089 .7221 L
.29733 .71853 L
.29118 .71238 L
.28147 .71238 L
.27176 .71238 L
.26819 .70882 L
.26204 .70267 L
.25233 .70267 L
.24262 .70267 L
.23905 .69911 L
.23291 .69296 L
.22319 .69296 L
.21348 .69296 L
.20377 .69296 L
.2002 .68939 L
.19406 .68325 L
.18434 .68325 L
.17463 .68325 L
.17107 .67968 L
.16492 .67353 L
.15521 .67353 L
.14549 .67353 L
.13578 .67353 L
.13222 .66997 L
.12607 .66382 L
.11636 .66382 L
.10664 .66382 L
.10308 .66026 L
.09693 .65411 L
.08722 .65411 L
.07751 .65411 L
.07394 .65054 L
.06779 .6444 L
.05808 .6444 L
.05452 .64083 L
.05452 .63112 L
.05808 .62755 L
.06423 .62141 L
.06423 .61169 L
.06423 .60198 L
.06779 .59842 L
.07394 .59227 L
.07394 .58256 L
.07394 .57284 L
.07751 .56928 L
.08365 .56313 L
.08365 .55342 L
.08365 .54371 L
.08722 .54014 L
.09337 .53399 L
.09337 .52428 L
.09337 .51457 L
.09693 .511 L
.10308 .50486 L
.10308 .49514 L
.10308 .48543 L
.10664 .48187 L
.11279 .47572 L
.11279 .46601 L
.11279 .45629 L
.11636 .45273 L
.1225 .44658 L
.1225 .43687 L
.12607 .4333 L
.13222 .42716 L
.13222 .41744 L
.13222 .40773 L
.13578 .40417 L
.14193 .39802 L
.14193 .38831 L
.14549 .38474 L
.15164 .37859 L
.15164 .36888 L
.15164 .35917 L
.15521 .3556 L
.16135 .34946 L
.16135 .33974 L
.16492 .33618 L
.17107 .33003 L
.17107 .32032 L
.17463 .31675 L
.18078 .31061 L
.18078 .30089 L
.18078 .29118 L
.18434 .28762 L
.19049 .28147 L
.19049 .27176 L
.19406 .26819 L
.2002 .26204 L
.2002 .25233 L
.20377 .24877 L
.20992 .24262 L
.20992 .23291 L
.21348 .22934 L
.21963 .22319 L
.21963 .21348 L
.22319 .20992 L
.22934 .20377 L
.23291 .2002 L
.23905 .19406 L
.23905 .18434 L
.24262 .18078 L
.24877 .17463 L
.24877 .16492 L
.25233 .16135 L
.25848 .15521 L
.26204 .15164 L
.26819 .14549 L
.26819 .13578 L
.27176 .13222 L
.2779 .12607 L
.28147 .1225 L
.28762 .11636 L
.29118 .11279 L
.29733 .10664 L
.30089 .10308 L
.30704 .09693 L
.30704 .08722 L
.31061 .08365 L
.31675 .07751 L
.32032 .07394 L
.33003 .07394 L
.33618 .06779 L
.33974 .06423 L
.34589 .05808 L
.34946 .05452 L
.3556 .04837 L
.35917 .0448 L
.36888 .0448 L
.37503 .03866 L
.37859 .03509 L
.38831 .03509 L
.39445 .02894 L
F
0 g
.39802 .02365 m
.40773 .02365 L
.41744 .02365 L
.42716 .02365 L
.43687 .02365 L
.44658 .02365 L
.45629 .02365 L
.46601 .02365 L
.47572 .02365 L
.47928 .02894 L
.48543 .03509 L
.49514 .03509 L
.50486 .03509 L
.50842 .03866 L
.51457 .0448 L
.51813 .04837 L
.52428 .05452 L
.52785 .05808 L
.53399 .06423 L
.54371 .06423 L
.54727 .06779 L
.55342 .07394 L
.55698 .07751 L
.56313 .08365 L
.5667 .08722 L
.5667 .09693 L
.57284 .10308 L
.57641 .10664 L
.58256 .11279 L
.58612 .11636 L
.59227 .1225 L
.59583 .12607 L
.60198 .13222 L
.60555 .13578 L
.60555 .14549 L
.61169 .15164 L
.61526 .15521 L
.62141 .16135 L
.62497 .16492 L
.62497 .17463 L
.63112 .18078 L
.63468 .18434 L
.63468 .19406 L
.64083 .2002 L
.6444 .20377 L
.65054 .20992 L
.65411 .21348 L
.65411 .22319 L
.66026 .22934 L
.66382 .23291 L
Mistroke
.66382 .24262 L
.66997 .24877 L
.67353 .25233 L
.67353 .26204 L
.67968 .26819 L
.68325 .27176 L
.68325 .28147 L
.68939 .28762 L
.69296 .29118 L
.69296 .30089 L
.69911 .30704 L
.70267 .31061 L
.70267 .32032 L
.70267 .33003 L
.70882 .33618 L
.71238 .33974 L
.71238 .34946 L
.71853 .3556 L
.7221 .35917 L
.7221 .36888 L
.72824 .37503 L
.73181 .37859 L
.73181 .38831 L
.73181 .39802 L
.73796 .40417 L
.74152 .40773 L
.74152 .41744 L
.74767 .42359 L
.75123 .42716 L
.75123 .43687 L
.75123 .44658 L
.75738 .45273 L
.76095 .45629 L
.76095 .46601 L
.76095 .47572 L
.76709 .48187 L
.77066 .48543 L
.77066 .49514 L
.77066 .50486 L
.77681 .511 L
.78037 .51457 L
.78037 .52428 L
.78037 .53399 L
.78652 .54014 L
.79008 .54371 L
.79008 .55342 L
.79008 .56313 L
.79623 .56928 L
.7998 .57284 L
.7998 .58256 L
Mistroke
.7998 .59227 L
.80594 .59842 L
.80951 .60198 L
.80951 .61169 L
.80951 .62141 L
.81566 .62755 L
.81922 .63112 L
.81922 .64083 L
.81922 .65054 L
.82537 .65669 L
.82893 .66026 L
.82893 .66997 L
.82893 .67968 L
.83508 .68583 L
.83865 .68939 L
.83865 .69911 L
.83865 .70882 L
.83865 .71853 L
.84479 .72468 L
.84836 .72824 L
.84836 .73796 L
.84836 .74767 L
.85451 .75382 L
.85807 .75738 L
.85807 .76709 L
.85807 .77681 L
.85807 .78652 L
.86422 .79267 L
.86778 .79623 L
.86778 .80594 L
.86778 .81566 L
.86778 .82537 L
.87393 .83152 L
.8775 .83508 L
.8775 .84479 L
.8775 .85451 L
.88364 .86065 L
.88721 .86422 L
.88721 .87393 L
.88721 .88364 L
.88364 .88721 L
.87393 .88721 L
.86422 .88721 L
.86065 .88364 L
.85451 .8775 L
.84479 .8775 L
.83508 .8775 L
.83152 .87393 L
.82537 .86778 L
.81566 .86778 L
Mistroke
.80594 .86778 L
.79623 .86778 L
.79267 .86422 L
.78652 .85807 L
.77681 .85807 L
.76709 .85807 L
.76353 .85451 L
.75738 .84836 L
.74767 .84836 L
.73796 .84836 L
.73439 .84479 L
.72824 .83865 L
.71853 .83865 L
.70882 .83865 L
.69911 .83865 L
.69554 .83508 L
.68939 .82893 L
.67968 .82893 L
.66997 .82893 L
.6664 .82537 L
.66026 .81922 L
.65054 .81922 L
.64083 .81922 L
.63112 .81922 L
.62755 .81566 L
.62141 .80951 L
.61169 .80951 L
.60198 .80951 L
.59842 .80594 L
.59227 .7998 L
.58256 .7998 L
.57284 .7998 L
.56928 .79623 L
.56313 .79008 L
.55342 .79008 L
.54371 .79008 L
.53399 .79008 L
.53043 .78652 L
.52428 .78037 L
.51457 .78037 L
.50486 .78037 L
.50129 .77681 L
.49514 .77066 L
.48543 .77066 L
.47572 .77066 L
.46601 .77066 L
.46244 .76709 L
.45629 .76095 L
.44658 .76095 L
.43687 .76095 L
Mistroke
.4333 .75738 L
.42716 .75123 L
.41744 .75123 L
.40773 .75123 L
.40417 .74767 L
.39802 .74152 L
.38831 .74152 L
.37859 .74152 L
.36888 .74152 L
.36532 .73796 L
.35917 .73181 L
.34946 .73181 L
.33974 .73181 L
.33618 .72824 L
.33003 .7221 L
.32032 .7221 L
.31061 .7221 L
.30089 .7221 L
.29733 .71853 L
.29118 .71238 L
.28147 .71238 L
.27176 .71238 L
.26819 .70882 L
.26204 .70267 L
.25233 .70267 L
.24262 .70267 L
.23905 .69911 L
.23291 .69296 L
.22319 .69296 L
.21348 .69296 L
.20377 .69296 L
.2002 .68939 L
.19406 .68325 L
.18434 .68325 L
.17463 .68325 L
.17107 .67968 L
.16492 .67353 L
.15521 .67353 L
.14549 .67353 L
.13578 .67353 L
.13222 .66997 L
.12607 .66382 L
.11636 .66382 L
.10664 .66382 L
.10308 .66026 L
.09693 .65411 L
.08722 .65411 L
.07751 .65411 L
.07394 .65054 L
.06779 .6444 L
Mistroke
.05808 .6444 L
.05452 .64083 L
.05452 .63112 L
.05808 .62755 L
.06423 .62141 L
.06423 .61169 L
.06423 .60198 L
.06779 .59842 L
.07394 .59227 L
.07394 .58256 L
.07394 .57284 L
.07751 .56928 L
.08365 .56313 L
.08365 .55342 L
.08365 .54371 L
.08722 .54014 L
.09337 .53399 L
.09337 .52428 L
.09337 .51457 L
.09693 .511 L
.10308 .50486 L
.10308 .49514 L
.10308 .48543 L
.10664 .48187 L
.11279 .47572 L
.11279 .46601 L
.11279 .45629 L
.11636 .45273 L
.1225 .44658 L
.1225 .43687 L
.12607 .4333 L
.13222 .42716 L
.13222 .41744 L
.13222 .40773 L
.13578 .40417 L
.14193 .39802 L
.14193 .38831 L
.14549 .38474 L
.15164 .37859 L
.15164 .36888 L
.15164 .35917 L
.15521 .3556 L
.16135 .34946 L
.16135 .33974 L
.16492 .33618 L
.17107 .33003 L
.17107 .32032 L
.17463 .31675 L
.18078 .31061 L
.18078 .30089 L
Mistroke
.18078 .29118 L
.18434 .28762 L
.19049 .28147 L
.19049 .27176 L
.19406 .26819 L
.2002 .26204 L
.2002 .25233 L
.20377 .24877 L
.20992 .24262 L
.20992 .23291 L
.21348 .22934 L
.21963 .22319 L
.21963 .21348 L
.22319 .20992 L
.22934 .20377 L
.23291 .2002 L
.23905 .19406 L
.23905 .18434 L
.24262 .18078 L
.24877 .17463 L
.24877 .16492 L
.25233 .16135 L
.25848 .15521 L
.26204 .15164 L
.26819 .14549 L
.26819 .13578 L
.27176 .13222 L
.2779 .12607 L
.28147 .1225 L
.28762 .11636 L
.29118 .11279 L
.29733 .10664 L
.30089 .10308 L
.30704 .09693 L
.30704 .08722 L
.31061 .08365 L
.31675 .07751 L
.32032 .07394 L
.33003 .07394 L
.33618 .06779 L
.33974 .06423 L
.34589 .05808 L
.34946 .05452 L
.3556 .04837 L
.35917 .0448 L
.36888 .0448 L
.37503 .03866 L
.37859 .03509 L
.38831 .03509 L
.39445 .02894 L
Mistroke
.39802 .02365 L
Mfstroke
.8 g
.39802 .02463 m
.40773 .02463 L
.41744 .02463 L
.42716 .02463 L
.43687 .02463 L
.44658 .02463 L
.45629 .02463 L
.46601 .02463 L
.47572 .02463 L
.4784 .02894 L
.48543 .03597 L
.49514 .03597 L
.50486 .03597 L
.50754 .03866 L
.51457 .04568 L
.51725 .04837 L
.52428 .0554 L
.52696 .05808 L
.53399 .06511 L
.54371 .06511 L
.54639 .06779 L
.55342 .07482 L
.5561 .07751 L
.56313 .08454 L
.56581 .08722 L
.56581 .09693 L
.57284 .10396 L
.57553 .10664 L
.58256 .11367 L
.58524 .11636 L
.59227 .12339 L
.59495 .12607 L
.60198 .1331 L
.60466 .13578 L
.60466 .14549 L
.61169 .15252 L
.61438 .15521 L
.62141 .16224 L
.62409 .16492 L
.62409 .17463 L
.63112 .18166 L
.6338 .18434 L
.6338 .19406 L
.64083 .20109 L
.64351 .20377 L
.65054 .2108 L
.65323 .21348 L
.65323 .22319 L
.66026 .23022 L
.66294 .23291 L
.66294 .24262 L
.66997 .24965 L
.67265 .25233 L
.67265 .26204 L
.67968 .26907 L
.68236 .27176 L
.68236 .28147 L
.68939 .2885 L
.69208 .29118 L
.69208 .30089 L
.69911 .30792 L
.70179 .31061 L
.70179 .32032 L
.70179 .33003 L
.70882 .33706 L
.7115 .33974 L
.7115 .34946 L
.71853 .35649 L
.72121 .35917 L
.72121 .36888 L
.72824 .37591 L
.73093 .37859 L
.73093 .38831 L
.73093 .39802 L
.73796 .40505 L
.74064 .40773 L
.74064 .41744 L
.74767 .42447 L
.75035 .42716 L
.75035 .43687 L
.75035 .44658 L
.75738 .45361 L
.76006 .45629 L
.76006 .46601 L
.76006 .47572 L
.76709 .48275 L
.76978 .48543 L
.76978 .49514 L
.76978 .50486 L
.77681 .51189 L
.77949 .51457 L
.77949 .52428 L
.77949 .53399 L
.78652 .54102 L
.7892 .54371 L
.7892 .55342 L
.7892 .56313 L
.79623 .57016 L
.79891 .57284 L
.79891 .58256 L
.79891 .59227 L
.80594 .5993 L
.80863 .60198 L
.80863 .61169 L
.80863 .62141 L
.81566 .62844 L
.81834 .63112 L
.81834 .64083 L
.81834 .65054 L
.82537 .65757 L
.82805 .66026 L
.82805 .66997 L
.82805 .67968 L
.83508 .68671 L
.83776 .68939 L
.83776 .69911 L
.83776 .70882 L
.83776 .71853 L
.84479 .72556 L
.84748 .72824 L
.84748 .73796 L
.84748 .74767 L
.85451 .7547 L
.85719 .75738 L
.85719 .76709 L
.85719 .77681 L
.85719 .78652 L
.86422 .79355 L
.8669 .79623 L
.8669 .80594 L
.8669 .81566 L
.8669 .82537 L
.87393 .8324 L
.87661 .83508 L
.87661 .84479 L
.87661 .85451 L
.88364 .86154 L
.88633 .86422 L
.88633 .87393 L
.88633 .88364 L
.88364 .88633 L
.87393 .88633 L
.86422 .88633 L
.86154 .88364 L
.85451 .87661 L
.84479 .87661 L
.83508 .87661 L
.8324 .87393 L
.82537 .8669 L
.81566 .8669 L
.80594 .8669 L
.79623 .8669 L
.79355 .86422 L
.78652 .85719 L
.77681 .85719 L
.76709 .85719 L
.76441 .85451 L
.75738 .84748 L
.74767 .84748 L
.73796 .84748 L
.73527 .84479 L
.72824 .83776 L
.71853 .83776 L
.70882 .83776 L
.69911 .83776 L
.69642 .83508 L
.68939 .82805 L
.67968 .82805 L
.66997 .82805 L
.66729 .82537 L
.66026 .81834 L
.65054 .81834 L
.64083 .81834 L
.63112 .81834 L
.62844 .81566 L
.62141 .80863 L
.61169 .80863 L
.60198 .80863 L
.5993 .80594 L
.59227 .79891 L
.58256 .79891 L
.57284 .79891 L
.57016 .79623 L
.56313 .7892 L
.55342 .7892 L
.54371 .7892 L
.53399 .7892 L
.53131 .78652 L
.52428 .77949 L
.51457 .77949 L
.50486 .77949 L
.50217 .77681 L
.49514 .76978 L
.48543 .76978 L
.47572 .76978 L
.46601 .76978 L
.46332 .76709 L
.45629 .76006 L
.44658 .76006 L
.43687 .76006 L
.43419 .75738 L
.42716 .75035 L
.41744 .75035 L
.40773 .75035 L
.40505 .74767 L
.39802 .74064 L
.38831 .74064 L
.37859 .74064 L
.36888 .74064 L
.3662 .73796 L
.35917 .73093 L
.34946 .73093 L
.33974 .73093 L
.33706 .72824 L
.33003 .72121 L
.32032 .72121 L
.31061 .72121 L
.30089 .72121 L
.29821 .71853 L
.29118 .7115 L
.28147 .7115 L
.27176 .7115 L
.26907 .70882 L
.26204 .70179 L
.25233 .70179 L
.24262 .70179 L
.23994 .69911 L
.23291 .69208 L
.22319 .69208 L
.21348 .69208 L
.20377 .69208 L
.20109 .68939 L
.19406 .68236 L
.18434 .68236 L
.17463 .68236 L
.17195 .67968 L
.16492 .67265 L
.15521 .67265 L
.14549 .67265 L
.13578 .67265 L
.1331 .66997 L
.12607 .66294 L
.11636 .66294 L
.10664 .66294 L
.10396 .66026 L
.09693 .65323 L
.08722 .65323 L
.07751 .65323 L
.07482 .65054 L
.06779 .64351 L
.05808 .64351 L
.0554 .64083 L
.0554 .63112 L
.05808 .62844 L
.06511 .62141 L
.06511 .61169 L
.06511 .60198 L
.06779 .5993 L
.07482 .59227 L
.07482 .58256 L
.07482 .57284 L
.07751 .57016 L
.08454 .56313 L
.08454 .55342 L
.08454 .54371 L
.08722 .54102 L
.09425 .53399 L
.09425 .52428 L
.09425 .51457 L
.09693 .51189 L
.10396 .50486 L
.10396 .49514 L
.10396 .48543 L
.10664 .48275 L
.11367 .47572 L
.11367 .46601 L
.11367 .45629 L
.11636 .45361 L
.12339 .44658 L
.12339 .43687 L
.12607 .43419 L
.1331 .42716 L
.1331 .41744 L
.1331 .40773 L
.13578 .40505 L
.14281 .39802 L
.14281 .38831 L
.14549 .38562 L
.15252 .37859 L
.15252 .36888 L
.15252 .35917 L
.15521 .35649 L
.16224 .34946 L
.16224 .33974 L
.16492 .33706 L
.17195 .33003 L
.17195 .32032 L
.17463 .31764 L
.18166 .31061 L
.18166 .30089 L
.18166 .29118 L
.18434 .2885 L
.19137 .28147 L
.19137 .27176 L
.19406 .26907 L
.20109 .26204 L
.20109 .25233 L
.20377 .24965 L
.2108 .24262 L
.2108 .23291 L
.21348 .23022 L
.22051 .22319 L
.22051 .21348 L
.22319 .2108 L
.23022 .20377 L
.23291 .20109 L
.23994 .19406 L
.23994 .18434 L
.24262 .18166 L
.24965 .17463 L
.24965 .16492 L
.25233 .16224 L
.25936 .15521 L
.26204 .15252 L
.26907 .14549 L
.26907 .13578 L
.27176 .1331 L
.27879 .12607 L
.28147 .12339 L
.2885 .11636 L
.29118 .11367 L
.29821 .10664 L
.30089 .10396 L
.30792 .09693 L
.30792 .08722 L
.31061 .08454 L
.31764 .07751 L
.32032 .07482 L
.33003 .07482 L
.33706 .06779 L
.33974 .06511 L
.34677 .05808 L
.34946 .0554 L
.35649 .04837 L
.35917 .04568 L
.36888 .04568 L
.37591 .03866 L
.37859 .03597 L
.38831 .03597 L
.39534 .02894 L
F
0 g
.39802 .02463 m
.40773 .02463 L
.41744 .02463 L
.42716 .02463 L
.43687 .02463 L
.44658 .02463 L
.45629 .02463 L
.46601 .02463 L
.47572 .02463 L
.4784 .02894 L
.48543 .03597 L
.49514 .03597 L
.50486 .03597 L
.50754 .03866 L
.51457 .04568 L
.51725 .04837 L
.52428 .0554 L
.52696 .05808 L
.53399 .06511 L
.54371 .06511 L
.54639 .06779 L
.55342 .07482 L
.5561 .07751 L
.56313 .08454 L
.56581 .08722 L
.56581 .09693 L
.57284 .10396 L
.57553 .10664 L
.58256 .11367 L
.58524 .11636 L
.59227 .12339 L
.59495 .12607 L
.60198 .1331 L
.60466 .13578 L
.60466 .14549 L
.61169 .15252 L
.61438 .15521 L
.62141 .16224 L
.62409 .16492 L
.62409 .17463 L
.63112 .18166 L
.6338 .18434 L
.6338 .19406 L
.64083 .20109 L
.64351 .20377 L
.65054 .2108 L
.65323 .21348 L
.65323 .22319 L
.66026 .23022 L
.66294 .23291 L
Mistroke
.66294 .24262 L
.66997 .24965 L
.67265 .25233 L
.67265 .26204 L
.67968 .26907 L
.68236 .27176 L
.68236 .28147 L
.68939 .2885 L
.69208 .29118 L
.69208 .30089 L
.69911 .30792 L
.70179 .31061 L
.70179 .32032 L
.70179 .33003 L
.70882 .33706 L
.7115 .33974 L
.7115 .34946 L
.71853 .35649 L
.72121 .35917 L
.72121 .36888 L
.72824 .37591 L
.73093 .37859 L
.73093 .38831 L
.73093 .39802 L
.73796 .40505 L
.74064 .40773 L
.74064 .41744 L
.74767 .42447 L
.75035 .42716 L
.75035 .43687 L
.75035 .44658 L
.75738 .45361 L
.76006 .45629 L
.76006 .46601 L
.76006 .47572 L
.76709 .48275 L
.76978 .48543 L
.76978 .49514 L
.76978 .50486 L
.77681 .51189 L
.77949 .51457 L
.77949 .52428 L
.77949 .53399 L
.78652 .54102 L
.7892 .54371 L
.7892 .55342 L
.7892 .56313 L
.79623 .57016 L
.79891 .57284 L
.79891 .58256 L
Mistroke
.79891 .59227 L
.80594 .5993 L
.80863 .60198 L
.80863 .61169 L
.80863 .62141 L
.81566 .62844 L
.81834 .63112 L
.81834 .64083 L
.81834 .65054 L
.82537 .65757 L
.82805 .66026 L
.82805 .66997 L
.82805 .67968 L
.83508 .68671 L
.83776 .68939 L
.83776 .69911 L
.83776 .70882 L
.83776 .71853 L
.84479 .72556 L
.84748 .72824 L
.84748 .73796 L
.84748 .74767 L
.85451 .7547 L
.85719 .75738 L
.85719 .76709 L
.85719 .77681 L
.85719 .78652 L
.86422 .79355 L
.8669 .79623 L
.8669 .80594 L
.8669 .81566 L
.8669 .82537 L
.87393 .8324 L
.87661 .83508 L
.87661 .84479 L
.87661 .85451 L
.88364 .86154 L
.88633 .86422 L
.88633 .87393 L
.88633 .88364 L
.88364 .88633 L
.87393 .88633 L
.86422 .88633 L
.86154 .88364 L
.85451 .87661 L
.84479 .87661 L
.83508 .87661 L
.8324 .87393 L
.82537 .8669 L
.81566 .8669 L
Mistroke
.80594 .8669 L
.79623 .8669 L
.79355 .86422 L
.78652 .85719 L
.77681 .85719 L
.76709 .85719 L
.76441 .85451 L
.75738 .84748 L
.74767 .84748 L
.73796 .84748 L
.73527 .84479 L
.72824 .83776 L
.71853 .83776 L
.70882 .83776 L
.69911 .83776 L
.69642 .83508 L
.68939 .82805 L
.67968 .82805 L
.66997 .82805 L
.66729 .82537 L
.66026 .81834 L
.65054 .81834 L
.64083 .81834 L
.63112 .81834 L
.62844 .81566 L
.62141 .80863 L
.61169 .80863 L
.60198 .80863 L
.5993 .80594 L
.59227 .79891 L
.58256 .79891 L
.57284 .79891 L
.57016 .79623 L
.56313 .7892 L
.55342 .7892 L
.54371 .7892 L
.53399 .7892 L
.53131 .78652 L
.52428 .77949 L
.51457 .77949 L
.50486 .77949 L
.50217 .77681 L
.49514 .76978 L
.48543 .76978 L
.47572 .76978 L
.46601 .76978 L
.46332 .76709 L
.45629 .76006 L
.44658 .76006 L
.43687 .76006 L
Mistroke
.43419 .75738 L
.42716 .75035 L
.41744 .75035 L
.40773 .75035 L
.40505 .74767 L
.39802 .74064 L
.38831 .74064 L
.37859 .74064 L
.36888 .74064 L
.3662 .73796 L
.35917 .73093 L
.34946 .73093 L
.33974 .73093 L
.33706 .72824 L
.33003 .72121 L
.32032 .72121 L
.31061 .72121 L
.30089 .72121 L
.29821 .71853 L
.29118 .7115 L
.28147 .7115 L
.27176 .7115 L
.26907 .70882 L
.26204 .70179 L
.25233 .70179 L
.24262 .70179 L
.23994 .69911 L
.23291 .69208 L
.22319 .69208 L
.21348 .69208 L
.20377 .69208 L
.20109 .68939 L
.19406 .68236 L
.18434 .68236 L
.17463 .68236 L
.17195 .67968 L
.16492 .67265 L
.15521 .67265 L
.14549 .67265 L
.13578 .67265 L
.1331 .66997 L
.12607 .66294 L
.11636 .66294 L
.10664 .66294 L
.10396 .66026 L
.09693 .65323 L
.08722 .65323 L
.07751 .65323 L
.07482 .65054 L
.06779 .64351 L
Mistroke
.05808 .64351 L
.0554 .64083 L
.0554 .63112 L
.05808 .62844 L
.06511 .62141 L
.06511 .61169 L
.06511 .60198 L
.06779 .5993 L
.07482 .59227 L
.07482 .58256 L
.07482 .57284 L
.07751 .57016 L
.08454 .56313 L
.08454 .55342 L
.08454 .54371 L
.08722 .54102 L
.09425 .53399 L
.09425 .52428 L
.09425 .51457 L
.09693 .51189 L
.10396 .50486 L
.10396 .49514 L
.10396 .48543 L
.10664 .48275 L
.11367 .47572 L
.11367 .46601 L
.11367 .45629 L
.11636 .45361 L
.12339 .44658 L
.12339 .43687 L
.12607 .43419 L
.1331 .42716 L
.1331 .41744 L
.1331 .40773 L
.13578 .40505 L
.14281 .39802 L
.14281 .38831 L
.14549 .38562 L
.15252 .37859 L
.15252 .36888 L
.15252 .35917 L
.15521 .35649 L
.16224 .34946 L
.16224 .33974 L
.16492 .33706 L
.17195 .33003 L
.17195 .32032 L
.17463 .31764 L
.18166 .31061 L
.18166 .30089 L
Mistroke
.18166 .29118 L
.18434 .2885 L
.19137 .28147 L
.19137 .27176 L
.19406 .26907 L
.20109 .26204 L
.20109 .25233 L
.20377 .24965 L
.2108 .24262 L
.2108 .23291 L
.21348 .23022 L
.22051 .22319 L
.22051 .21348 L
.22319 .2108 L
.23022 .20377 L
.23291 .20109 L
.23994 .19406 L
.23994 .18434 L
.24262 .18166 L
.24965 .17463 L
.24965 .16492 L
.25233 .16224 L
.25936 .15521 L
.26204 .15252 L
.26907 .14549 L
.26907 .13578 L
.27176 .1331 L
.27879 .12607 L
.28147 .12339 L
.2885 .11636 L
.29118 .11367 L
.29821 .10664 L
.30089 .10396 L
.30792 .09693 L
.30792 .08722 L
.31061 .08454 L
.31764 .07751 L
.32032 .07482 L
.33003 .07482 L
.33706 .06779 L
.33974 .06511 L
.34677 .05808 L
.34946 .0554 L
.35649 .04837 L
.35917 .04568 L
.36888 .04568 L
.37591 .03866 L
.37859 .03597 L
.38831 .03597 L
.39534 .02894 L
Mistroke
.39802 .02463 L
Mfstroke
.9 g
.39802 .0258 m
.40773 .0258 L
.41744 .0258 L
.42716 .0258 L
.43687 .0258 L
.44658 .0258 L
.45629 .0258 L
.46601 .0258 L
.47572 .0258 L
.47748 .02894 L
.48543 .03689 L
.49514 .03689 L
.50486 .03689 L
.50662 .03866 L
.51457 .0466 L
.51633 .04837 L
.52428 .05632 L
.52605 .05808 L
.53399 .06603 L
.54371 .06603 L
.54547 .06779 L
.55342 .07574 L
.55518 .07751 L
.56313 .08545 L
.5649 .08722 L
.5649 .09693 L
.57284 .10488 L
.57461 .10664 L
.58256 .11459 L
.58432 .11636 L
.59227 .1243 L
.59403 .12607 L
.60198 .13402 L
.60375 .13578 L
.60375 .14549 L
.61169 .15344 L
.61346 .15521 L
.62141 .16315 L
.62317 .16492 L
.62317 .17463 L
.63112 .18258 L
.63288 .18434 L
.63288 .19406 L
.64083 .202 L
.6426 .20377 L
.65054 .21172 L
.65231 .21348 L
.65231 .22319 L
.66026 .23114 L
.66202 .23291 L
.66202 .24262 L
.66997 .25057 L
.67173 .25233 L
.67173 .26204 L
.67968 .26999 L
.68145 .27176 L
.68145 .28147 L
.68939 .28942 L
.69116 .29118 L
.69116 .30089 L
.69911 .30884 L
.70087 .31061 L
.70087 .32032 L
.70087 .33003 L
.70882 .33798 L
.71058 .33974 L
.71058 .34946 L
.71853 .3574 L
.7203 .35917 L
.7203 .36888 L
.72824 .37683 L
.73001 .37859 L
.73001 .38831 L
.73001 .39802 L
.73796 .40597 L
.73972 .40773 L
.73972 .41744 L
.74767 .42539 L
.74943 .42716 L
.74943 .43687 L
.74943 .44658 L
.75738 .45453 L
.75915 .45629 L
.75915 .46601 L
.75915 .47572 L
.76709 .48367 L
.76886 .48543 L
.76886 .49514 L
.76886 .50486 L
.77681 .5128 L
.77857 .51457 L
.77857 .52428 L
.77857 .53399 L
.78652 .54194 L
.78828 .54371 L
.78828 .55342 L
.78828 .56313 L
.79623 .57108 L
.798 .57284 L
.798 .58256 L
.798 .59227 L
.80594 .60022 L
.80771 .60198 L
.80771 .61169 L
.80771 .62141 L
.81566 .62935 L
.81742 .63112 L
.81742 .64083 L
.81742 .65054 L
.82537 .65849 L
.82713 .66026 L
.82713 .66997 L
.82713 .67968 L
.83508 .68763 L
.83685 .68939 L
.83685 .69911 L
.83685 .70882 L
.83685 .71853 L
.84479 .72648 L
.84656 .72824 L
.84656 .73796 L
.84656 .74767 L
.85451 .75562 L
.85627 .75738 L
.85627 .76709 L
.85627 .77681 L
.85627 .78652 L
.86422 .79447 L
.86598 .79623 L
.86598 .80594 L
.86598 .81566 L
.86598 .82537 L
.87393 .83332 L
.8757 .83508 L
.8757 .84479 L
.8757 .85451 L
.88364 .86245 L
.88541 .86422 L
.88541 .87393 L
.88541 .88364 L
.88364 .88541 L
.87393 .88541 L
.86422 .88541 L
.86245 .88364 L
.85451 .8757 L
.84479 .8757 L
.83508 .8757 L
.83332 .87393 L
.82537 .86598 L
.81566 .86598 L
.80594 .86598 L
.79623 .86598 L
.79447 .86422 L
.78652 .85627 L
.77681 .85627 L
.76709 .85627 L
.76533 .85451 L
.75738 .84656 L
.74767 .84656 L
.73796 .84656 L
.73619 .84479 L
.72824 .83685 L
.71853 .83685 L
.70882 .83685 L
.69911 .83685 L
.69734 .83508 L
.68939 .82713 L
.67968 .82713 L
.66997 .82713 L
.6682 .82537 L
.66026 .81742 L
.65054 .81742 L
.64083 .81742 L
.63112 .81742 L
.62935 .81566 L
.62141 .80771 L
.61169 .80771 L
.60198 .80771 L
.60022 .80594 L
.59227 .798 L
.58256 .798 L
.57284 .798 L
.57108 .79623 L
.56313 .78828 L
.55342 .78828 L
.54371 .78828 L
.53399 .78828 L
.53223 .78652 L
.52428 .77857 L
.51457 .77857 L
.50486 .77857 L
.50309 .77681 L
.49514 .76886 L
.48543 .76886 L
.47572 .76886 L
.46601 .76886 L
.46424 .76709 L
.45629 .75915 L
.44658 .75915 L
.43687 .75915 L
.4351 .75738 L
.42716 .74943 L
.41744 .74943 L
.40773 .74943 L
.40597 .74767 L
.39802 .73972 L
.38831 .73972 L
.37859 .73972 L
.36888 .73972 L
.36712 .73796 L
.35917 .73001 L
.34946 .73001 L
.33974 .73001 L
.33798 .72824 L
.33003 .7203 L
.32032 .7203 L
.31061 .7203 L
.30089 .7203 L
.29913 .71853 L
.29118 .71058 L
.28147 .71058 L
.27176 .71058 L
.26999 .70882 L
.26204 .70087 L
.25233 .70087 L
.24262 .70087 L
.24085 .69911 L
.23291 .69116 L
.22319 .69116 L
.21348 .69116 L
.20377 .69116 L
.202 .68939 L
.19406 .68145 L
.18434 .68145 L
.17463 .68145 L
.17287 .67968 L
.16492 .67173 L
.15521 .67173 L
.14549 .67173 L
.13578 .67173 L
.13402 .66997 L
.12607 .66202 L
.11636 .66202 L
.10664 .66202 L
.10488 .66026 L
.09693 .65231 L
.08722 .65231 L
.07751 .65231 L
.07574 .65054 L
.06779 .6426 L
.05808 .6426 L
.05632 .64083 L
.05632 .63112 L
.05808 .62935 L
.06603 .62141 L
.06603 .61169 L
.06603 .60198 L
.06779 .60022 L
.07574 .59227 L
.07574 .58256 L
.07574 .57284 L
.07751 .57108 L
.08545 .56313 L
.08545 .55342 L
.08545 .54371 L
.08722 .54194 L
.09517 .53399 L
.09517 .52428 L
.09517 .51457 L
.09693 .5128 L
.10488 .50486 L
.10488 .49514 L
.10488 .48543 L
.10664 .48367 L
.11459 .47572 L
.11459 .46601 L
.11459 .45629 L
.11636 .45453 L
.1243 .44658 L
.1243 .43687 L
.12607 .4351 L
.13402 .42716 L
.13402 .41744 L
.13402 .40773 L
.13578 .40597 L
.14373 .39802 L
.14373 .38831 L
.14549 .38654 L
.15344 .37859 L
.15344 .36888 L
.15344 .35917 L
.15521 .3574 L
.16315 .34946 L
.16315 .33974 L
.16492 .33798 L
.17287 .33003 L
.17287 .32032 L
.17463 .31855 L
.18258 .31061 L
.18258 .30089 L
.18258 .29118 L
.18434 .28942 L
.19229 .28147 L
.19229 .27176 L
.19406 .26999 L
.202 .26204 L
.202 .25233 L
.20377 .25057 L
.21172 .24262 L
.21172 .23291 L
.21348 .23114 L
.22143 .22319 L
.22143 .21348 L
.22319 .21172 L
.23114 .20377 L
.23291 .202 L
.24085 .19406 L
.24085 .18434 L
.24262 .18258 L
.25057 .17463 L
.25057 .16492 L
.25233 .16315 L
.26028 .15521 L
.26204 .15344 L
.26999 .14549 L
.26999 .13578 L
.27176 .13402 L
.2797 .12607 L
.28147 .1243 L
.28942 .11636 L
.29118 .11459 L
.29913 .10664 L
.30089 .10488 L
.30884 .09693 L
.30884 .08722 L
.31061 .08545 L
.31855 .07751 L
.32032 .07574 L
.33003 .07574 L
.33798 .06779 L
.33974 .06603 L
.34769 .05808 L
.34946 .05632 L
.3574 .04837 L
.35917 .0466 L
.36888 .0466 L
.37683 .03866 L
.37859 .03689 L
.38831 .03689 L
.39625 .02894 L
F
0 g
.39802 .0258 m
.40773 .0258 L
.41744 .0258 L
.42716 .0258 L
.43687 .0258 L
.44658 .0258 L
.45629 .0258 L
.46601 .0258 L
.47572 .0258 L
.47748 .02894 L
.48543 .03689 L
.49514 .03689 L
.50486 .03689 L
.50662 .03866 L
.51457 .0466 L
.51633 .04837 L
.52428 .05632 L
.52605 .05808 L
.53399 .06603 L
.54371 .06603 L
.54547 .06779 L
.55342 .07574 L
.55518 .07751 L
.56313 .08545 L
.5649 .08722 L
.5649 .09693 L
.57284 .10488 L
.57461 .10664 L
.58256 .11459 L
.58432 .11636 L
.59227 .1243 L
.59403 .12607 L
.60198 .13402 L
.60375 .13578 L
.60375 .14549 L
.61169 .15344 L
.61346 .15521 L
.62141 .16315 L
.62317 .16492 L
.62317 .17463 L
.63112 .18258 L
.63288 .18434 L
.63288 .19406 L
.64083 .202 L
.6426 .20377 L
.65054 .21172 L
.65231 .21348 L
.65231 .22319 L
.66026 .23114 L
.66202 .23291 L
Mistroke
.66202 .24262 L
.66997 .25057 L
.67173 .25233 L
.67173 .26204 L
.67968 .26999 L
.68145 .27176 L
.68145 .28147 L
.68939 .28942 L
.69116 .29118 L
.69116 .30089 L
.69911 .30884 L
.70087 .31061 L
.70087 .32032 L
.70087 .33003 L
.70882 .33798 L
.71058 .33974 L
.71058 .34946 L
.71853 .3574 L
.7203 .35917 L
.7203 .36888 L
.72824 .37683 L
.73001 .37859 L
.73001 .38831 L
.73001 .39802 L
.73796 .40597 L
.73972 .40773 L
.73972 .41744 L
.74767 .42539 L
.74943 .42716 L
.74943 .43687 L
.74943 .44658 L
.75738 .45453 L
.75915 .45629 L
.75915 .46601 L
.75915 .47572 L
.76709 .48367 L
.76886 .48543 L
.76886 .49514 L
.76886 .50486 L
.77681 .5128 L
.77857 .51457 L
.77857 .52428 L
.77857 .53399 L
.78652 .54194 L
.78828 .54371 L
.78828 .55342 L
.78828 .56313 L
.79623 .57108 L
.798 .57284 L
.798 .58256 L
Mistroke
.798 .59227 L
.80594 .60022 L
.80771 .60198 L
.80771 .61169 L
.80771 .62141 L
.81566 .62935 L
.81742 .63112 L
.81742 .64083 L
.81742 .65054 L
.82537 .65849 L
.82713 .66026 L
.82713 .66997 L
.82713 .67968 L
.83508 .68763 L
.83685 .68939 L
.83685 .69911 L
.83685 .70882 L
.83685 .71853 L
.84479 .72648 L
.84656 .72824 L
.84656 .73796 L
.84656 .74767 L
.85451 .75562 L
.85627 .75738 L
.85627 .76709 L
.85627 .77681 L
.85627 .78652 L
.86422 .79447 L
.86598 .79623 L
.86598 .80594 L
.86598 .81566 L
.86598 .82537 L
.87393 .83332 L
.8757 .83508 L
.8757 .84479 L
.8757 .85451 L
.88364 .86245 L
.88541 .86422 L
.88541 .87393 L
.88541 .88364 L
.88364 .88541 L
.87393 .88541 L
.86422 .88541 L
.86245 .88364 L
.85451 .8757 L
.84479 .8757 L
.83508 .8757 L
.83332 .87393 L
.82537 .86598 L
.81566 .86598 L
Mistroke
.80594 .86598 L
.79623 .86598 L
.79447 .86422 L
.78652 .85627 L
.77681 .85627 L
.76709 .85627 L
.76533 .85451 L
.75738 .84656 L
.74767 .84656 L
.73796 .84656 L
.73619 .84479 L
.72824 .83685 L
.71853 .83685 L
.70882 .83685 L
.69911 .83685 L
.69734 .83508 L
.68939 .82713 L
.67968 .82713 L
.66997 .82713 L
.6682 .82537 L
.66026 .81742 L
.65054 .81742 L
.64083 .81742 L
.63112 .81742 L
.62935 .81566 L
.62141 .80771 L
.61169 .80771 L
.60198 .80771 L
.60022 .80594 L
.59227 .798 L
.58256 .798 L
.57284 .798 L
.57108 .79623 L
.56313 .78828 L
.55342 .78828 L
.54371 .78828 L
.53399 .78828 L
.53223 .78652 L
.52428 .77857 L
.51457 .77857 L
.50486 .77857 L
.50309 .77681 L
.49514 .76886 L
.48543 .76886 L
.47572 .76886 L
.46601 .76886 L
.46424 .76709 L
.45629 .75915 L
.44658 .75915 L
.43687 .75915 L
Mistroke
.4351 .75738 L
.42716 .74943 L
.41744 .74943 L
.40773 .74943 L
.40597 .74767 L
.39802 .73972 L
.38831 .73972 L
.37859 .73972 L
.36888 .73972 L
.36712 .73796 L
.35917 .73001 L
.34946 .73001 L
.33974 .73001 L
.33798 .72824 L
.33003 .7203 L
.32032 .7203 L
.31061 .7203 L
.30089 .7203 L
.29913 .71853 L
.29118 .71058 L
.28147 .71058 L
.27176 .71058 L
.26999 .70882 L
.26204 .70087 L
.25233 .70087 L
.24262 .70087 L
.24085 .69911 L
.23291 .69116 L
.22319 .69116 L
.21348 .69116 L
.20377 .69116 L
.202 .68939 L
.19406 .68145 L
.18434 .68145 L
.17463 .68145 L
.17287 .67968 L
.16492 .67173 L
.15521 .67173 L
.14549 .67173 L
.13578 .67173 L
.13402 .66997 L
.12607 .66202 L
.11636 .66202 L
.10664 .66202 L
.10488 .66026 L
.09693 .65231 L
.08722 .65231 L
.07751 .65231 L
.07574 .65054 L
.06779 .6426 L
Mistroke
.05808 .6426 L
.05632 .64083 L
.05632 .63112 L
.05808 .62935 L
.06603 .62141 L
.06603 .61169 L
.06603 .60198 L
.06779 .60022 L
.07574 .59227 L
.07574 .58256 L
.07574 .57284 L
.07751 .57108 L
.08545 .56313 L
.08545 .55342 L
.08545 .54371 L
.08722 .54194 L
.09517 .53399 L
.09517 .52428 L
.09517 .51457 L
.09693 .5128 L
.10488 .50486 L
.10488 .49514 L
.10488 .48543 L
.10664 .48367 L
.11459 .47572 L
.11459 .46601 L
.11459 .45629 L
.11636 .45453 L
.1243 .44658 L
.1243 .43687 L
.12607 .4351 L
.13402 .42716 L
.13402 .41744 L
.13402 .40773 L
.13578 .40597 L
.14373 .39802 L
.14373 .38831 L
.14549 .38654 L
.15344 .37859 L
.15344 .36888 L
.15344 .35917 L
.15521 .3574 L
.16315 .34946 L
.16315 .33974 L
.16492 .33798 L
.17287 .33003 L
.17287 .32032 L
.17463 .31855 L
.18258 .31061 L
.18258 .30089 L
Mistroke
.18258 .29118 L
.18434 .28942 L
.19229 .28147 L
.19229 .27176 L
.19406 .26999 L
.202 .26204 L
.202 .25233 L
.20377 .25057 L
.21172 .24262 L
.21172 .23291 L
.21348 .23114 L
.22143 .22319 L
.22143 .21348 L
.22319 .21172 L
.23114 .20377 L
.23291 .202 L
.24085 .19406 L
.24085 .18434 L
.24262 .18258 L
.25057 .17463 L
.25057 .16492 L
.25233 .16315 L
.26028 .15521 L
.26204 .15344 L
.26999 .14549 L
.26999 .13578 L
.27176 .13402 L
.2797 .12607 L
.28147 .1243 L
.28942 .11636 L
.29118 .11459 L
.29913 .10664 L
.30089 .10488 L
.30884 .09693 L
.30884 .08722 L
.31061 .08545 L
.31855 .07751 L
.32032 .07574 L
.33003 .07574 L
.33798 .06779 L
.33974 .06603 L
.34769 .05808 L
.34946 .05632 L
.3574 .04837 L
.35917 .0466 L
.36888 .0466 L
.37683 .03866 L
.37859 .03689 L
.38831 .03689 L
.39625 .02894 L
Mistroke
.39802 .0258 L
Mfstroke
1 g
.39802 .02732 m
.40773 .02732 L
.41744 .02732 L
.42716 .02732 L
.43687 .02732 L
.44658 .02732 L
.45629 .02732 L
.46601 .02732 L
.47572 .02732 L
.4765 .02894 L
.48543 .03787 L
.49514 .03787 L
.50486 .03787 L
.50564 .03866 L
.51457 .04758 L
.51535 .04837 L
.52428 .0573 L
.52507 .05808 L
.53399 .06701 L
.54371 .06701 L
.54449 .06779 L
.55342 .07672 L
.5542 .07751 L
.56313 .08643 L
.56392 .08722 L
.56392 .09693 L
.57284 .10586 L
.57363 .10664 L
.58256 .11557 L
.58334 .11636 L
.59227 .12528 L
.59305 .12607 L
.60198 .135 L
.60277 .13578 L
.60277 .14549 L
.61169 .15442 L
.61248 .15521 L
.62141 .16413 L
.62219 .16492 L
.62219 .17463 L
.63112 .18356 L
.6319 .18434 L
.6319 .19406 L
.64083 .20298 L
.64162 .20377 L
.65054 .2127 L
.65133 .21348 L
.65133 .22319 L
.66026 .23212 L
.66104 .23291 L
.66104 .24262 L
.66997 .25155 L
.67075 .25233 L
.67075 .26204 L
.67968 .27097 L
.68047 .27176 L
.68047 .28147 L
.68939 .2904 L
.69018 .29118 L
.69018 .30089 L
.69911 .30982 L
.69989 .31061 L
.69989 .32032 L
.69989 .33003 L
.70882 .33896 L
.7096 .33974 L
.7096 .34946 L
.71853 .35838 L
.71932 .35917 L
.71932 .36888 L
.72824 .37781 L
.72903 .37859 L
.72903 .38831 L
.72903 .39802 L
.73796 .40695 L
.73874 .40773 L
.73874 .41744 L
.74767 .42637 L
.74845 .42716 L
.74845 .43687 L
.74845 .44658 L
.75738 .45551 L
.75817 .45629 L
.75817 .46601 L
.75817 .47572 L
.76709 .48465 L
.76788 .48543 L
.76788 .49514 L
.76788 .50486 L
.77681 .51378 L
.77759 .51457 L
.77759 .52428 L
.77759 .53399 L
.78652 .54292 L
.7873 .54371 L
.7873 .55342 L
.7873 .56313 L
.79623 .57206 L
.79702 .57284 L
.79702 .58256 L
.79702 .59227 L
.80594 .6012 L
.80673 .60198 L
.80673 .61169 L
.80673 .62141 L
.81566 .63033 L
.81644 .63112 L
.81644 .64083 L
.81644 .65054 L
.82537 .65947 L
.82615 .66026 L
.82615 .66997 L
.82615 .67968 L
.83508 .68861 L
.83587 .68939 L
.83587 .69911 L
.83587 .70882 L
.83587 .71853 L
.84479 .72746 L
.84558 .72824 L
.84558 .73796 L
.84558 .74767 L
.85451 .7566 L
.85529 .75738 L
.85529 .76709 L
.85529 .77681 L
.85529 .78652 L
.86422 .79545 L
.865 .79623 L
.865 .80594 L
.865 .81566 L
.865 .82537 L
.87393 .8343 L
.87472 .83508 L
.87472 .84479 L
.87472 .85451 L
.88364 .86343 L
.88443 .86422 L
.88443 .87393 L
.88443 .88364 L
.88364 .88443 L
.87393 .88443 L
.86422 .88443 L
.86343 .88364 L
.85451 .87472 L
.84479 .87472 L
.83508 .87472 L
.8343 .87393 L
.82537 .865 L
.81566 .865 L
.80594 .865 L
.79623 .865 L
.79545 .86422 L
.78652 .85529 L
.77681 .85529 L
.76709 .85529 L
.76631 .85451 L
.75738 .84558 L
.74767 .84558 L
.73796 .84558 L
.73717 .84479 L
.72824 .83587 L
.71853 .83587 L
.70882 .83587 L
.69911 .83587 L
.69832 .83508 L
.68939 .82615 L
.67968 .82615 L
.66997 .82615 L
.66918 .82537 L
.66026 .81644 L
.65054 .81644 L
.64083 .81644 L
.63112 .81644 L
.63033 .81566 L
.62141 .80673 L
.61169 .80673 L
.60198 .80673 L
.6012 .80594 L
.59227 .79702 L
.58256 .79702 L
.57284 .79702 L
.57206 .79623 L
.56313 .7873 L
.55342 .7873 L
.54371 .7873 L
.53399 .7873 L
.53321 .78652 L
.52428 .77759 L
.51457 .77759 L
.50486 .77759 L
.50407 .77681 L
.49514 .76788 L
.48543 .76788 L
.47572 .76788 L
.46601 .76788 L
.46522 .76709 L
.45629 .75817 L
.44658 .75817 L
.43687 .75817 L
.43608 .75738 L
.42716 .74845 L
.41744 .74845 L
.40773 .74845 L
.40695 .74767 L
.39802 .73874 L
.38831 .73874 L
.37859 .73874 L
.36888 .73874 L
.3681 .73796 L
.35917 .72903 L
.34946 .72903 L
.33974 .72903 L
.33896 .72824 L
.33003 .71932 L
.32032 .71932 L
.31061 .71932 L
.30089 .71932 L
.30011 .71853 L
.29118 .7096 L
.28147 .7096 L
.27176 .7096 L
.27097 .70882 L
.26204 .69989 L
.25233 .69989 L
.24262 .69989 L
.24183 .69911 L
.23291 .69018 L
.22319 .69018 L
.21348 .69018 L
.20377 .69018 L
.20298 .68939 L
.19406 .68047 L
.18434 .68047 L
.17463 .68047 L
.17385 .67968 L
.16492 .67075 L
.15521 .67075 L
.14549 .67075 L
.13578 .67075 L
.135 .66997 L
.12607 .66104 L
.11636 .66104 L
.10664 .66104 L
.10586 .66026 L
.09693 .65133 L
.08722 .65133 L
.07751 .65133 L
.07672 .65054 L
.06779 .64162 L
.05808 .64162 L
.0573 .64083 L
.0573 .63112 L
.05808 .63033 L
.06701 .62141 L
.06701 .61169 L
.06701 .60198 L
.06779 .6012 L
.07672 .59227 L
.07672 .58256 L
.07672 .57284 L
.07751 .57206 L
.08643 .56313 L
.08643 .55342 L
.08643 .54371 L
.08722 .54292 L
.09615 .53399 L
.09615 .52428 L
.09615 .51457 L
.09693 .51378 L
.10586 .50486 L
.10586 .49514 L
.10586 .48543 L
.10664 .48465 L
.11557 .47572 L
.11557 .46601 L
.11557 .45629 L
.11636 .45551 L
.12528 .44658 L
.12528 .43687 L
.12607 .43608 L
.135 .42716 L
.135 .41744 L
.135 .40773 L
.13578 .40695 L
.14471 .39802 L
.14471 .38831 L
.14549 .38752 L
.15442 .37859 L
.15442 .36888 L
.15442 .35917 L
.15521 .35838 L
.16413 .34946 L
.16413 .33974 L
.16492 .33896 L
.17385 .33003 L
.17385 .32032 L
.17463 .31953 L
.18356 .31061 L
.18356 .30089 L
.18356 .29118 L
.18434 .2904 L
.19327 .28147 L
.19327 .27176 L
.19406 .27097 L
.20298 .26204 L
.20298 .25233 L
.20377 .25155 L
.2127 .24262 L
.2127 .23291 L
.21348 .23212 L
.22241 .22319 L
.22241 .21348 L
.22319 .2127 L
.23212 .20377 L
.23291 .20298 L
.24183 .19406 L
.24183 .18434 L
.24262 .18356 L
.25155 .17463 L
.25155 .16492 L
.25233 .16413 L
.26126 .15521 L
.26204 .15442 L
.27097 .14549 L
.27097 .13578 L
.27176 .135 L
.28068 .12607 L
.28147 .12528 L
.2904 .11636 L
.29118 .11557 L
.30011 .10664 L
.30089 .10586 L
.30982 .09693 L
.30982 .08722 L
.31061 .08643 L
.31953 .07751 L
.32032 .07672 L
.33003 .07672 L
.33896 .06779 L
.33974 .06701 L
.34867 .05808 L
.34946 .0573 L
.35838 .04837 L
.35917 .04758 L
.36888 .04758 L
.37781 .03866 L
.37859 .03787 L
.38831 .03787 L
.39723 .02894 L
F
0 g
.39802 .02732 m
.40773 .02732 L
.41744 .02732 L
.42716 .02732 L
.43687 .02732 L
.44658 .02732 L
.45629 .02732 L
.46601 .02732 L
.47572 .02732 L
.4765 .02894 L
.48543 .03787 L
.49514 .03787 L
.50486 .03787 L
.50564 .03866 L
.51457 .04758 L
.51535 .04837 L
.52428 .0573 L
.52507 .05808 L
.53399 .06701 L
.54371 .06701 L
.54449 .06779 L
.55342 .07672 L
.5542 .07751 L
.56313 .08643 L
.56392 .08722 L
.56392 .09693 L
.57284 .10586 L
.57363 .10664 L
.58256 .11557 L
.58334 .11636 L
.59227 .12528 L
.59305 .12607 L
.60198 .135 L
.60277 .13578 L
.60277 .14549 L
.61169 .15442 L
.61248 .15521 L
.62141 .16413 L
.62219 .16492 L
.62219 .17463 L
.63112 .18356 L
.6319 .18434 L
.6319 .19406 L
.64083 .20298 L
.64162 .20377 L
.65054 .2127 L
.65133 .21348 L
.65133 .22319 L
.66026 .23212 L
.66104 .23291 L
Mistroke
.66104 .24262 L
.66997 .25155 L
.67075 .25233 L
.67075 .26204 L
.67968 .27097 L
.68047 .27176 L
.68047 .28147 L
.68939 .2904 L
.69018 .29118 L
.69018 .30089 L
.69911 .30982 L
.69989 .31061 L
.69989 .32032 L
.69989 .33003 L
.70882 .33896 L
.7096 .33974 L
.7096 .34946 L
.71853 .35838 L
.71932 .35917 L
.71932 .36888 L
.72824 .37781 L
.72903 .37859 L
.72903 .38831 L
.72903 .39802 L
.73796 .40695 L
.73874 .40773 L
.73874 .41744 L
.74767 .42637 L
.74845 .42716 L
.74845 .43687 L
.74845 .44658 L
.75738 .45551 L
.75817 .45629 L
.75817 .46601 L
.75817 .47572 L
.76709 .48465 L
.76788 .48543 L
.76788 .49514 L
.76788 .50486 L
.77681 .51378 L
.77759 .51457 L
.77759 .52428 L
.77759 .53399 L
.78652 .54292 L
.7873 .54371 L
.7873 .55342 L
.7873 .56313 L
.79623 .57206 L
.79702 .57284 L
.79702 .58256 L
Mistroke
.79702 .59227 L
.80594 .6012 L
.80673 .60198 L
.80673 .61169 L
.80673 .62141 L
.81566 .63033 L
.81644 .63112 L
.81644 .64083 L
.81644 .65054 L
.82537 .65947 L
.82615 .66026 L
.82615 .66997 L
.82615 .67968 L
.83508 .68861 L
.83587 .68939 L
.83587 .69911 L
.83587 .70882 L
.83587 .71853 L
.84479 .72746 L
.84558 .72824 L
.84558 .73796 L
.84558 .74767 L
.85451 .7566 L
.85529 .75738 L
.85529 .76709 L
.85529 .77681 L
.85529 .78652 L
.86422 .79545 L
.865 .79623 L
.865 .80594 L
.865 .81566 L
.865 .82537 L
.87393 .8343 L
.87472 .83508 L
.87472 .84479 L
.87472 .85451 L
.88364 .86343 L
.88443 .86422 L
.88443 .87393 L
.88443 .88364 L
.88364 .88443 L
.87393 .88443 L
.86422 .88443 L
.86343 .88364 L
.85451 .87472 L
.84479 .87472 L
.83508 .87472 L
.8343 .87393 L
.82537 .865 L
.81566 .865 L
Mistroke
.80594 .865 L
.79623 .865 L
.79545 .86422 L
.78652 .85529 L
.77681 .85529 L
.76709 .85529 L
.76631 .85451 L
.75738 .84558 L
.74767 .84558 L
.73796 .84558 L
.73717 .84479 L
.72824 .83587 L
.71853 .83587 L
.70882 .83587 L
.69911 .83587 L
.69832 .83508 L
.68939 .82615 L
.67968 .82615 L
.66997 .82615 L
.66918 .82537 L
.66026 .81644 L
.65054 .81644 L
.64083 .81644 L
.63112 .81644 L
.63033 .81566 L
.62141 .80673 L
.61169 .80673 L
.60198 .80673 L
.6012 .80594 L
.59227 .79702 L
.58256 .79702 L
.57284 .79702 L
.57206 .79623 L
.56313 .7873 L
.55342 .7873 L
.54371 .7873 L
.53399 .7873 L
.53321 .78652 L
.52428 .77759 L
.51457 .77759 L
.50486 .77759 L
.50407 .77681 L
.49514 .76788 L
.48543 .76788 L
.47572 .76788 L
.46601 .76788 L
.46522 .76709 L
.45629 .75817 L
.44658 .75817 L
.43687 .75817 L
Mistroke
.43608 .75738 L
.42716 .74845 L
.41744 .74845 L
.40773 .74845 L
.40695 .74767 L
.39802 .73874 L
.38831 .73874 L
.37859 .73874 L
.36888 .73874 L
.3681 .73796 L
.35917 .72903 L
.34946 .72903 L
.33974 .72903 L
.33896 .72824 L
.33003 .71932 L
.32032 .71932 L
.31061 .71932 L
.30089 .71932 L
.30011 .71853 L
.29118 .7096 L
.28147 .7096 L
.27176 .7096 L
.27097 .70882 L
.26204 .69989 L
.25233 .69989 L
.24262 .69989 L
.24183 .69911 L
.23291 .69018 L
.22319 .69018 L
.21348 .69018 L
.20377 .69018 L
.20298 .68939 L
.19406 .68047 L
.18434 .68047 L
.17463 .68047 L
.17385 .67968 L
.16492 .67075 L
.15521 .67075 L
.14549 .67075 L
.13578 .67075 L
.135 .66997 L
.12607 .66104 L
.11636 .66104 L
.10664 .66104 L
.10586 .66026 L
.09693 .65133 L
.08722 .65133 L
.07751 .65133 L
.07672 .65054 L
.06779 .64162 L
Mistroke
.05808 .64162 L
.0573 .64083 L
.0573 .63112 L
.05808 .63033 L
.06701 .62141 L
.06701 .61169 L
.06701 .60198 L
.06779 .6012 L
.07672 .59227 L
.07672 .58256 L
.07672 .57284 L
.07751 .57206 L
.08643 .56313 L
.08643 .55342 L
.08643 .54371 L
.08722 .54292 L
.09615 .53399 L
.09615 .52428 L
.09615 .51457 L
.09693 .51378 L
.10586 .50486 L
.10586 .49514 L
.10586 .48543 L
.10664 .48465 L
.11557 .47572 L
.11557 .46601 L
.11557 .45629 L
.11636 .45551 L
.12528 .44658 L
.12528 .43687 L
.12607 .43608 L
.135 .42716 L
.135 .41744 L
.135 .40773 L
.13578 .40695 L
.14471 .39802 L
.14471 .38831 L
.14549 .38752 L
.15442 .37859 L
.15442 .36888 L
.15442 .35917 L
.15521 .35838 L
.16413 .34946 L
.16413 .33974 L
.16492 .33896 L
.17385 .33003 L
.17385 .32032 L
.17463 .31953 L
.18356 .31061 L
.18356 .30089 L
Mistroke
.18356 .29118 L
.18434 .2904 L
.19327 .28147 L
.19327 .27176 L
.19406 .27097 L
.20298 .26204 L
.20298 .25233 L
.20377 .25155 L
.2127 .24262 L
.2127 .23291 L
.21348 .23212 L
.22241 .22319 L
.22241 .21348 L
.22319 .2127 L
.23212 .20377 L
.23291 .20298 L
.24183 .19406 L
.24183 .18434 L
.24262 .18356 L
.25155 .17463 L
.25155 .16492 L
.25233 .16413 L
.26126 .15521 L
.26204 .15442 L
.27097 .14549 L
.27097 .13578 L
.27176 .135 L
.28068 .12607 L
.28147 .12528 L
.2904 .11636 L
.29118 .11557 L
.30011 .10664 L
.30089 .10586 L
.30982 .09693 L
.30982 .08722 L
.31061 .08643 L
.31953 .07751 L
.32032 .07672 L
.33003 .07672 L
.33896 .06779 L
.33974 .06701 L
.34867 .05808 L
.34946 .0573 L
.35838 .04837 L
.35917 .04758 L
.36888 .04758 L
.37781 .03866 L
.37859 .03787 L
.38831 .03787 L
.39723 .02894 L
Mistroke
.39802 .02732 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`008oooool4o`000003oa0@4?oooooooooo03Gooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0hooooo`Co000000?o410@ooooooooool0
;Oooool002Gooooo00?o0000ooooooooool0=oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo03;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0iooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0>Oooool00ol0
003oooooooooo`0_ooooo`006_ooool6o`0000Gooooo00?o0000ooooooooool0;oooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo037ooooo00Go410@oooo
oooooooooooooa0@400iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo02oooooo000Uooooo`03o`000?oooooooooo03Oooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo03;ooooo00Go0000oooooooooooooooo
o`00000iooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0iooooo`03
o`000?oooooooooo02oooooo000Uooooo`03o`000?oooooooooo03Oooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0<oooool01Ol0003ooooooooooooooooo
000003Wooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
>_ooool00ol0003oooooooooo`0_ooooo`009Oooool00ol0003oooooooooo`0gooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00ol0003oooooooooo`0eooooo`05oa0@4?ooooooooooooooool@
4100>Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0_ooooo`009Oooool00ol0003oooooooooo`0gooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`0eooooo`05ogMgMonHV9SooooooiRHV?mgMgL0>Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`0_ooooo`008oooool00omEEEGoIVIVo`00000iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0003Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0iooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool4o`0003Wooooo00?oEEEEofIVI_l00000<Oooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001[oooooool0
001>o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0@_ooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0;Oooool1o`00
007ooooo000?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooo
od[ooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooo
ooooool0oooooom:ooooo`7o00000Oooool000oooooo00Go410@oooooooooooooooooa0@4006oooo
o`03o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo000?ooooo`05o`000?oooooooooooooo
ool000001_ooool3o`00087ooooo6ol0002[ooooo`?o00000Oooool000oooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo00Coooooool00010o`0000Kooooo0Ol00001oooo
o`003oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool01?ooooooo`00
043o00001_ooool1o`00007ooooo000?ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0
003oooooooooo`04oooooooo0000@?l00006ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP06ooooo`03o`000?oooooooooo00CoooooOOl0000KooooojOo00001_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooooO?l0000MooooojKo00001_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CoooooNol0000OooooojGo00001_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooMol0000[oooooigo00001_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooM_l0000]oooooico00001_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CoooooMOl0000_oooooi_o00001_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooLOl0000coooooi_o00001_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooL?l0000eoooooi[o00001_ooool1o`00007ooooo000Jooooo`;o00001Ooo
oom_o`0003OoooooVOl00005ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooom^
o`0003WoooooV?l00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooom]o`00
03coooooU_l00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooom/o`0003ko
ooooUOl00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooom[o`00043ooooo
U?l00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooomZo`0004GoooooT?l0
0006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooomYo`0004OoooooSol00006
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooomXo`0004WoooooS_l00006oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooomSo`0004ooooooSOl00006ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooomRo`00057oooooS?l00006ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooomQo`0005?oooooRol00006ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooomQo`0005?oooooRol00006ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooomQo`0005?oooooRol00006ooooo`7o00000Oooool001[o
oooo0_l00005ooooof7o0000Dooooon;o`0000Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooof7o0000Dooooon;o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooof3o0000EOoooon:o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooooeoo0000Eooooon9o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
oeko0000FOoooon8o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooego
0000G?oooon6o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooeco0000
G_oooon5o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooe_o0000H?oo
oon4o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooe[o0000H_oooon3
o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooeWo0000I?oooon2o`00
00Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooeSo0000I_oooon1o`0000Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooeKo0000JOoooon0o`0000Kooooo
0Ol00001ooooo`006_ooool2o`0000GoooooEOl0001[ooooogoo00001Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooE?l0001]ooooogko00001_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CoooooE?l0001]ooooogko00001_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooE?l0001]ooooogko00001_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooE?l0001]ooooogko00001_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooE?l0001]ooooogko00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CoooooDol0001_oooooggo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooD_l0001aooooogco00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooDOl0001cooooog_o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
D?l0001fooooogWo00001_ooool1o`00007ooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool01?oooom?o`0007SoooooN?l00006ooooo`7o0000
0Oooool00004oiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool00ol0003oooooooooo`04ooooodko0000N_oooomgo`0000Kooooo0Ol00001ooooo`00
0oooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol00004ooooodko0000
N_oooomgo`0000Cooooo0ol00001ooooo`000oooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ
8B7ok^k^00Kooooo00?o0000ooooooooool01?oooom>o`0007[oooooMol00006ooooo`7o00000Ooo
ool000?ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo
oooo00CoooooC_l0001jooooogOo00001_ooool1o`00007ooooo0003ooooo`03oa0@4?oooooooooo
00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooodko0000N_oooomgo`00
00Kooooo0Ol00001ooooo`0000CoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So
410@00Kooooo00?o0000ooooooooool01?oooom=o`0007coooooM_l00006ooooo`7o00000Oooool0
0004oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oo
oooooooo00CoooooC?l0001nooooogGo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CoooooBol00020ooooogCo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooB_l00021ooooogCo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooB_l00021ooooogCo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
B_l00021ooooogCo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooB_l0
0022ooooog?o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooBOl00024
ooooog;o00001_ooool1o`00007ooooo000Jooooo`;o00001Ooooom8o`0008KoooooLOl00005oooo
o`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooom6o`0008WoooooL?l00006ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooom5o`0008_oooooKol00006ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooom4o`0008goooooK_l00006ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooom4o`0008koooooKOl00006ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooom4o`0008koooooKOl00006ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooom4o`0008koooooKOl00006ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooom4o`0008koooooKOl00006ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooom3o`0008ooooooKOl00006ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooom2o`00097oooooK?l00006ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooom1o`0009?oooooJol00006ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooom1o`0009CoooooJ_l00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooom1o`0009CoooooJ_l00006ooooo`7o00000Oooool001[ooooo0_l00005oooood7o0000U?oo
oomZo`0000Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooood3o0000U_oooomY
o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooocoo0000V?oooomXo`00
00Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooocko0000V_oooomWo`0000Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooocko0000V_oooomWo`0000Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooocko0000V_oooomWo`0000Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooocko0000V_oooomWo`0000Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooocko0000V_oooomWo`0000Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooocgo0000W?oooomVo`0000Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooocco0000W_oooomUo`0000Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooooc_o0000X?oooomTo`0000Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooc[o0000XOoooomTo`0000Kooooo0Ol00001ooooo`006_ooool2o`00
00Gooooo>_l0002QooooofCo00001Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooo>_l0002QooooofCo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
>Ol0002Sooooof?o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo>?l0
002Uooooof;o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo=ol0002W
ooooof7o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo=ol0002Woooo
of7o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo=ol0002Wooooof7o
00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo=ol0002Wooooof7o0000
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo=ol0002Wooooof7o00001_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo=ol0002Xooooof3o00001_ooool1
o`00007ooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooo
oooo00Cooooo00?o0000ooooooooool01?oooolgo`000:WoooooGol00006ooooo`7o00000Oooool0
0004oiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?oooolgo`000:[oooooG_l00006ooooo`7o00000Oooool000?ooooo00?o410@oooo
ooooool02Oooool5o`0000Kooooo0ol00004ooooocKo0000[?oooomMo`0000Cooooo0ol00001oooo
o`000oooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000oooo
ooooool01?ooooleo`000:goooooGOl00006ooooo`7o00000Oooool000?ooooo00?o0000oooooooo
ool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo00Cooooo=?l0002^oooo
oego00001_ooool1o`00007ooooo0003ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l0
00001oooool00ol0003oooooooooo`04ooooocCo0000[_oooomMo`0000Kooooo0Ol00001ooooo`00
00CoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo00Co
oooo=?l0002^oooooego00001_ooool1o`00007ooooo00001?lb<S;o0000oc8b<_o^k^h=ooooo`03
ogMgMol0003ooooo00Kooooo00?o0000ooooooooool01?ooooldo`000:koooooGOl00006ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooolco`000;3oooooG?l00006ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooolbo`000;;oooooFol00006ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooolao`000;CoooooF_l00006ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooolao`000;CoooooF_l00006ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooolao`000;CoooooF_l00006ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooolao`000;CoooooF_l00006ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooolao`000;CoooooF_l00006ooooo`7o00000Oooool001[ooooo0_l00005
oooooc3o0000]_oooomIo`0000Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooo
oboo0000^?oooomHo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooobko
0000^_oooomGo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooobgo0000
^ooooomGo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooobgo0000^ooo
oomGo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooobgo0000^ooooomG
o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooobgo0000_?oooomFo`00
00Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooobgo0000_OoooomEo`0000Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooobgo0000__oooomDo`0000Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooobco0000_ooooomDo`0000Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooob_o0000`?oooomDo`0000Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooob[o0000`OoooomDo`0000Kooooo0Ol00001oooo
o`006_ooool2o`0000Gooooo:_l00031oooooeCo00001Oooool2o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Cooooo:_l00031oooooeCo00001_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo:_l00031oooooeCo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo:_l00031oooooeCo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Cooooo:Ol00033oooooe?o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooo:?l00035oooooe;o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
9ol00037oooooe7o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo9ol0
0038oooooe3o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo9ol00038
oooooe3o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo9ol00038oooo
oe3o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo9ol00039ooooodoo
00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo9ol0003:ooooodko0000
1_ooool1o`00007ooooo000Jooooo`;o00001OoooolWo`000<_oooooCOl00005ooooo`;o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooolWo`000<_oooooCOl00006ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooolUo`000<goooooCOl00006ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooolTo`000<koooooCOl00006ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooolTo`000<koooooCOl00006ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooolTo`000<koooooCOl00006ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooolTo`000<koooooCOl00006ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooolTo`000<koooooCOl00006ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooolSo`000=3oooooC?l00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooolRo`000=;oooooBol00006ooooo`7o00000Oooool00004oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`04ooooob7o
0000e?oooom:o`0000Kooooo0Ol00001ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Co
oooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo00Cooooo8Ol0003Doooo
od[o00001_ooool1o`00007ooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooo
ooooooooo`000006ooooo`?o00001?oooolQo`000=CoooooB_l00004ooooo`?o00000Oooool000?o
oooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool01?oooolQo`000=CoooooB_l00006ooooo`7o00000Oooool000?ooooo00?o0000oooooooo
ool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool01?oooolQo`00
0=CoooooB_l00006ooooo`7o00000Oooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGo
QhN7ooooo`08ooooo`03o`000?oooooooooo00Cooooo8Ol0003Doooood[o00001_ooool1o`00007o
oooo00001?nHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooooooo
ool01?oooolQo`000=CoooooB_l00006ooooo`7o00000Oooool00004oc8b<_l0003o<S8bonk^kPco
oooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`04ooooob7o0000e?oooom:o`00
00Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooob3o0000e_oooom9o`0000Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooaoo0000f?oooom8o`0000Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooako0000f_oooom7o`0000Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooooago0000fooooom7o`0000Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooooago0000fooooom7o`0000Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04oooooago0000fooooom7o`0000Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooooago0000fooooom7o`0000Kooooo0Ol00001ooooo`006_oo
ool2o`0000Gooooo7Ol0003KooooodOo00001Oooool2o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo7Ol0003KooooodOo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Cooooo7?l0003MooooodKo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooo6ol0003OooooodGo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
6_l0003QooooodCo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo6_l0
003QooooodCo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo6_l0003Q
ooooodCo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo6_l0003Qoooo
odCo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo6_l0003QooooodCo
00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo6_l0003QooooodCo0000
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo6_l0003QooooodCo00001_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo6_l0003QooooodCo00001_ooool1
o`00007ooooo000Jooooo`;o00001OoooolIo`000>?ooooo@ol00005ooooo`;o00000Oooool001[o
oooo00?o0000ooooooooool01?oooolHo`000>Gooooo@_l00006ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooolGo`000>Oooooo@Ol00006ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooolGo`000>Sooooo@?l00006ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooolGo`000>Sooooo@?l00006ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooolGo`000>Sooooo@?l00006ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooolGo`000>Sooooo@?l00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooolGo`000>Sooooo@?l00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oolGo`000>Sooooo@?l00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooolG
o`000>Sooooo@?l00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooolFo`00
0>[ooooo?ol00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooolEo`000>co
oooo?_l00006ooooo`7o00000Oooool001[ooooo0_l00005oooooaCo0000k_oooolmo`0000Gooooo
0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooooaCo0000k_oooolmo`0000Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooooaCo0000k_oooolmo`0000Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooooaCo0000k_oooolmo`0000Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04oooooaCo0000k_oooolmo`0000Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooooaCo0000k_oooolmo`0000Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooooaCo0000k_oooolmo`0000Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooa?o0000l?oooollo`0000Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooooa;o0000l_oooolko`0000Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooooa7o0000m?ooooljo`0000Kooooo0Ol00001ooooo`0000Co<S8bo`000?lb<S;o
k^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
00Cooooo4?l0003eoooooc[o00001_ooool1o`00007ooooo00001?nHV9SooooooiRHV?mgMgL5oooo
o`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool01?ooool@
o`000?Gooooo>_l00006ooooo`7o00000Oooool000?ooooo00?o410@ooooooooool02Oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01?ooool@o`000?Gooooo>_l00006
ooooo`7o00000Oooool000?ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So
<S8b00Kooooo0ol00004oooooa3o0000mOooooljo`0000Cooooo0ol00001ooooo`000oooool00ol0
003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`04
oooooa3o0000mOooooljo`0000Kooooo0Ol00001ooooo`000oooool00ol@413oooooooooo`09oooo
o`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`04oooooa3o0000mOoooolj
o`0000Kooooo0Ol00001ooooo`0000CoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj
^[[o000000Kooooo00?o0000ooooooooool01?ooool@o`000?Gooooo>_l00006ooooo`7o00000Ooo
ool00004oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`00
0?oooooooooo00Cooooo3ol0003gooooocWo00001_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo3_l0003iooooocSo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo3Ol0003kooooocOo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Cooooo3Ol0003kooooocOo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooo3Ol0003kooooocOo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
3Ol0003kooooocOo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo4Ol0
003gooooocOo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo4_l0003f
ooooocOo00001_ooool1o`00007ooooo000Jooooo`;o00001OoooolCo`000?Gooooo=ol00005oooo
o`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooolJo`000>kooooo=ol00006ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooolKo`000>kooooo=_l00006ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooolLo`000>kooooo=Ol00006ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooolTo`000>Oooooo=?l00006ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooolUo`000>Oooooo<ol00006ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooolVo`000>Kooooo<ol00006ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooolao`000=_ooooo<ol00006ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooolbo`000=[ooooo<ol00006ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooolco`000=Wooooo<ol00006ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooldo`000=Sooooo<ol00006ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooolko`000=;ooooo<_l00006ooooo`7o00000Oooool001[ooooo0_l00005ooooocco0000
d_oooolao`0000Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooocgo0000d_oo
ool`o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooodSo0000aoooool`
o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooodSo0000aoooool`o`00
00Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooodWo0000a_ooool`o`0000Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooe7o0000__ooool`o`0000Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooe;o0000_Oooool`o`0000Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooooe?o0000_?ooool`o`0000Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooooe_o0000]?ooool`o`0000Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04oooooeco0000/oooool`o`0000Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooooego0000/_ooool`o`0000Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooooeko0000/Oooool`o`0000Kooooo0Ol00001ooooo`006_ooool2
o`0000GoooooJ?l0002Xoooooboo00001Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooJOl0002Xooooobko00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooJ_l0002Xooooobgo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
LOl0002Qooooobgo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooL_l0
002Pooooobgo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooLol0002O
ooooobgo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooO_l0002Doooo
obgo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooOol0002Cooooobgo
00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooP?l0002Booooobgo0000
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooR?l0002:ooooobgo00001_oo
ool1o`00007ooooo000@ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`04
ooooohWo0000R_ooool/o`0000Kooooo0Ol00001ooooo`004_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00CoooooR_l0002:ooooob_o00001_ooool1o`00007ooooo000Booooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oooonBo`0008?ooooo:_l00006ooooo`7o
00000Oooool001;ooooo00?o0000ooooooooool01Oooool3o`0000CoooooTol00022ooooob[o0000
1?ooool3o`00007ooooo000Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
oonDo`00087ooooo:_l00006ooooo`7o00000Oooool001;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04oooooiGo0000P?oooolZo`0000Kooooo0Ol00001ooooo`004_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00CoooooWol0001fooooob[o00001_ooool1o`00
007ooooo000@ooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool01?oooonPo`0007Go
oooo:_l00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonQo`0007Cooooo
:_l00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonXo`0006gooooo:_l0
0006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonYo`0006cooooo:_l00006
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonZo`0006_ooooo:_l00006oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooneo`00063ooooo:_l00006ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonfo`00063ooooo:Ol00006ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooongo`00063ooooo:?l00006ooooo`7o00000Ooo
ool001[ooooo0_l00005oooookoo0000FOoooolWo`0000Gooooo0_l00001ooooo`006_ooool00ol0
003oooooooooo`04oooool3o0000F?oooolWo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooool7o0000EooooolWo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooool;o0000E_oooolWo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooolWo0000CooooolWo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooool[o0000C_oooolWo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ol_o0000COoooolWo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooomGo
0000@ooooolWo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooomKo0000
@_oooolWo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooomOo0000@Ooo
oolWo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooomoo0000>OoooolW
o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooon3o0000>OoooolVo`00
00Kooooo0Ol00001ooooo`006_ooool2o`0000GooooohOl0000iooooobGo00001Oooool2o`00007o
oooo000Jooooo`03o`000?oooooooooo00Coooook?l0000_ooooobCo00001_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooookOl0000_ooooob?o00001_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00Coooook_l0000^ooooob?o00001_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00Cooooom_l0000Vooooob?o00001_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00Cooooomol0000Uooooob?o00001_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Cooooon?l0000Tooooob?o00001_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooonOl0000Sooooob?o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Coooooool0000Nooooob;o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Coooooool00001o`0001kooooo8Ol00006ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooo`0000;o00007_oooolPo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooooooo00003Ol0000Cooooob3o00001_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Coooooool0000>o`0001;ooooo8?l00006ooooo`7o00000Oooool001[ooooo0_l00005
oooooooo00003ol0000Aooooob3o00001Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo
00Coooooool0000Go`0000Wooooo8?l00006ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooo`0001So00002?oooolPo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooooooo00006Ol00007ooooob3o00001_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Coooooool00010o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooooooo0000@?l00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooo`00
043o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooooool00010o`0000Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo0000@?l00006ooooo`7o0000
0Oooool000Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oo
oooooooo00Coooooool00010o`0000Kooooo0Ol00001ooooo`000_ooool00ol0003oooooooooo`04
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool01?oo
ooooo`00043o00001_ooool1o`00007ooooo0002ooooo`03o`000?oooooooooo00_ooooo00?oV9RH
ob4Q8Oo^k^h01oooool00ol0003oooooooooo`04oooooooo0000@?l00006ooooo`7o00000Oooool0
00;ooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP06ooooo`?o00001?ooooooo`00
043o00001?ooool3o`00007ooooo0002ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_oo
ool01Oooool00ol0003oooooooooo`04oooooooo0000@?l00006ooooo`7o00000Oooool000;ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
ool00010o`0000Kooooo0Ol00001ooooo`000_ooool00ol0003oooooooooo`0:ooooo`05o`000?nj
^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`04oooooooo0000@?l00006ooooo`7o0000
0Oooool00003oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo00Coooooool00010o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04oooooooo0000@?l00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
o`00043o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooooool00010o`00
00Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo0000@?l00006ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooo`00043o00001_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00Coooooool00010o`0000Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooooo0000@?l00006ooooo`7o00000Oooool001[ooooo0_l00005oooo
oooo0000@?l00005ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooo`00043o
00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooooool00010o`0000Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo0000@?l00006ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooo`00043o00001_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00Coooooool00010o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooooooo0000@?l00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooo`00043o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooooool0
0010o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo0000@?l00006
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooo`00043o00001_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00Coooooool00010o`0000Kooooo0Ol00001ooooo`00
6_ooool2o`0000Goooooool00010o`0000Gooooo0_l00001ooooo`006_ooool00ol0003ooooooooo
o`3ooooood[ooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`3ooooood[ooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`13ooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool0;Oooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00?ooooo0Ol00001ooooo`006_ooooooo`0004ko00000Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1, 0, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "Here we have used a technique involving the function ",
  StyleBox["Boole",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", available only in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " version 4.1 or later, that allows one to plot or integrate over complex \
regions defined by inequalities. We will also use this technique in defining \
the inner product over this region. This technique is merely a convenience; \
it is also possible to write out the ranges of integration in the inner \
product explicitly. "
}], "Text",
  CellTags->"i:64"],

Cell[TextData[{
  "\tWithin this domain, we will solve ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\( \[Phi](x, y)\)\  = \ 1\)]],
  ", with boundary conditions that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Phi]\)\( | \_S\)\) = 0\)]],
  ". "
}], "Text"],

Cell["\<\
\tThe following module puts the whole Galerkin method together in \
one place:\
\>", "Text",
  CellTags->"i:8"],

Cell[BoxData[
    RowBox[{
      StyleBox[\( (*\ 
          define\ the\ curves\ that\ determine\ the\ \(\(boundary\)\(:\)\)\ *) \
\),
        FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
      RowBox[{\(z[1, x_, y_]\  = \ y - \((x/6 + 1)\);\), 
        "\n", \(z[2, x_, y_]\  = \ y - x\^2;\), " ", "\n", 
        StyleBox[\( (*\ define\ the\ charge\ density\ \ *) \),
          FontColor->RGBColor[1, 0, 0]], 
        "\[IndentingNewLine]", \(\[Rho][x_, y_]\  = \ 1;\), "\n", 
        StyleBox[\( (*\ 
            define\ the\ function\ u\ used\ to\ match\ inhomogeneous\ \
boundary\ conditions, \ if\ any\ *) \),
          FontColor->RGBColor[1, 0, 0]], "\n", \(u[x_, y_]\  = \ 0;\), "\n", 
        RowBox[{
          StyleBox["(*",
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[" ",
            FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
            StyleBox["define",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["the",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["inner",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["product",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["using",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["Boole",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["notation",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              FontColor->RGBColor[1, 0, 0]], 
            RowBox[{
              StyleBox["(",
                FontColor->RGBColor[1, 0, 0]], 
              RowBox[{
                StyleBox["Mathematica",
                  FontSlant->"Italic",
                  FontColor->RGBColor[1, 0, 0]], 
                StyleBox[" ",
                  FontColor->RGBColor[1, 0, 0]], 
                StyleBox["4.1",
                  FontColor->RGBColor[1, 0, 0]], 
                StyleBox[" ",
                  FontColor->RGBColor[1, 0, 0]], 
                StyleBox["only",
                  FontColor->RGBColor[1, 0, 0]]}], 
              StyleBox[")",
                FontColor->RGBColor[1, 0, 0]]}]}], " ", 
          StyleBox["*)",
            FontColor->RGBColor[1, 0, 0]]}], 
        "\n", \(norm[f_, g_]\  := \ 
            Integrate[
                f\ g\ Boole[
                    z[1, x, y]\  \[LessEqual] \ \ 0\  && \ 
                      z[2, x, y] \[GreaterEqual] \ \ 0], {x, \(-Infinity\), 
                  Infinity}, {y, \(-Infinity\), Infinity}]\  // 
              N;\)}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.18"],

Cell[BoxData[
    RowBox[{\(galerkin[Px_, Py_, M_]\), " ", ":=", " ", 
      RowBox[{"Module", "[", 
        RowBox[{\({v, Lmat, \[Rho]vec, eq, eqns, vars}\), ",", 
          "\[IndentingNewLine]", 
          StyleBox[\( (*\ define\ the\ basis\ \(\(functions\)\(:\)\)\ *) \),
            FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
          
          RowBox[{\(v[i_, j_, x_, y_]\  = \ \(x\^i\) 
                y\^j\ \ \ \ Product[z[n, x, y], {n, 1, M}]\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ define\ the\ \(\(operator\)\(:\)\)\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(L[f_]\  := \ 
              D[f, {x, 2}]\  + \ D[f, {y, 2}]\), ";", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                determine\ the\ projection\ of\ the\ operator\ onto\ the\ \
basis\ \(\(functions\)\(:\)\)\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(Lmat[i_, j_, k_, l_]\  := \ 
              norm[v[i, j, x, y], \ L[v[k, l, x, y]]]\), ";", 
            "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                determine\ the\ projection\ of\ \[Rho]\&_\ onto\ the\ basis\ \
\(\(functions\)\(:\)\)\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[Rho]vec[i_, j_]\  := \ 
              norm[v[i, j, x, y], \ \[Rho][x, y] - L[u[x, y]]]\), ";", 
            "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                define\ the\ equations\ for\ the\ Fourier\ coefficients\ c[m, 
                    n]\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(eq[i_, j_]\  := \(eq[i, j]\  = \ 
                Sum[Lmat[i, j, k, l] c[k, l], {k, 0, Px}, {l, 0, 
                      Py}]\  \[Equal] \ \[Rho]vec[i, j]\)\), ";", 
            "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                Print\ out\ the\ equations\ \((not\ necessary, \ 
                    but\ a\ useful\ check)\)\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(Do[
              Print["\<eq\>", {i, j}, "\< = \>", eq[i, j]], {i, 0, Px}, {j, 
                0, Py}]\), ";", "\[IndentingNewLine]", 
            StyleBox[\( (*\ 
                create\ lists\ of\ equations\ and\ variables\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(eqns\  = \ 
              Flatten[Table[eq[i, j], {i, 0, Px}, {j, 0, Py}]]\), ";", 
            "\[IndentingNewLine]", \(vars\  = \ 
              Flatten[Table[c[k, l], {k, 0, Px}, {l, 0, Py}]]\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ solve\ the\ equations\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(coefficients\  = \ \(Solve[eqns, 
                  vars]\)[\([1]\)]\), ";", "\[IndentingNewLine]", 
            StyleBox[\( (*\ define\ the\ solution\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[Phi][x_, y_]\  = \ 
              u[x, y]\  + \ 
                  Sum[c[k, l]\ v[k, l, x, y], {k, 0, Px}, {l, 0, Py}] /. 
                coefficients\), ";"}]}], "]"}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.19"],

Cell[TextData[{
  "We will run the module taking ",
  Cell[BoxData[
      \(TraditionalForm\`P\_x = \(P\_y = 4\)\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(galerkin[4, 4, 2]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.20"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{0, 
          0}\[InvisibleSpace]" = \
"\[InvisibleSpace]\(\(-0.46064127662665527`\)\ c[0, 0] - 
            0.24861604593388045`\ c[0, 1] - 0.15698115485798506`\ c[0, 2] - 
            0.10948769802719581`\ c[0, 3] - 0.0818455017109958`\ c[0, 4] - 
            0.05003129625843903`\ c[1, 0] - 0.036376358896790424`\ c[1, 1] - 
            0.028569811921014602`\ c[1, 2] - 0.023644789389061865`\ c[1, 3] - 
            0.020328309499613624`\ c[1, 4] - 0.05383493048441987`\ c[2, 0] - 
            0.03514946373175552`\ c[2, 1] - 0.02542509951811765`\ c[2, 2] - 
            0.019753676994491532`\ c[2, 3] - 0.016180741359767898`\ c[2, 4] - 
            0.015880821839381908`\ c[3, 0] - 0.012563587654024454`\ c[3, 1] - 
            0.01048306087485224`\ c[3, 2] - 0.009093921920947861`\ c[3, 3] - 
            0.008127733109395886`\ c[3, 4] - 0.015976413964149252`\ c[4, 0] - 
            0.011760381891013425`\ c[4, 1] - 0.009301716115560361`\ c[4, 2] - 
            0.007756599928090679`\ c[4, 3] - 
            0.006735398953034707`\ c[4, 4] == \(-0.15611691801991245`\)\)\),
      SequenceForm[ "eq", {0, 0}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.46064127662665527, 
              c[ 0, 0]], 
            Times[ -0.24861604593388045, 
              c[ 0, 1]], 
            Times[ -0.15698115485798506, 
              c[ 0, 2]], 
            Times[ -0.10948769802719581, 
              c[ 0, 3]], 
            Times[ -0.081845501710995805, 
              c[ 0, 4]], 
            Times[ -0.05003129625843903, 
              c[ 1, 0]], 
            Times[ -0.036376358896790424, 
              c[ 1, 1]], 
            Times[ -0.028569811921014602, 
              c[ 1, 2]], 
            Times[ -0.023644789389061865, 
              c[ 1, 3]], 
            Times[ -0.020328309499613624, 
              c[ 1, 4]], 
            Times[ -0.053834930484419868, 
              c[ 2, 0]], 
            Times[ -0.035149463731755523, 
              c[ 2, 1]], 
            Times[ -0.025425099518117649, 
              c[ 2, 2]], 
            Times[ -0.019753676994491532, 
              c[ 2, 3]], 
            Times[ -0.016180741359767898, 
              c[ 2, 4]], 
            Times[ -0.015880821839381908, 
              c[ 3, 0]], 
            Times[ -0.012563587654024454, 
              c[ 3, 1]], 
            Times[ -0.01048306087485224, 
              c[ 3, 2]], 
            Times[ -0.009093921920947861, 
              c[ 3, 3]], 
            Times[ -0.0081277331093958863, 
              c[ 3, 4]], 
            Times[ -0.015976413964149252, 
              c[ 4, 0]], 
            Times[ -0.011760381891013425, 
              c[ 4, 1]], 
            Times[ -0.0093017161155603614, 
              c[ 4, 2]], 
            Times[ -0.0077565999280906793, 
              c[ 4, 3]], 
            Times[ -0.0067353989530347068, 
              c[ 4, 4]]], -0.15611691801991245]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{0, 
          1}\[InvisibleSpace]" = \
"\[InvisibleSpace]\(\(-0.24861604593388045`\)\ c[0, 0] - 
            0.1825638194777059`\ c[0, 1] - 0.1375848980582567`\ c[0, 2] - 
            0.10773337262158579`\ c[0, 3] - 0.0873648267401352`\ c[0, 4] - 
            0.036376358896790424`\ c[1, 0] - 0.03070170063932467`\ c[1, 1] - 
            0.02664674380223779`\ c[1, 2] - 0.02369658738379547`\ c[1, 3] - 
            0.021506894371527904`\ c[1, 4] - 0.03514946373175552`\ c[2, 0] - 
            0.027584320143072716`\ c[2, 1] - 0.0224807939019594`\ c[2, 2] - 
            0.01898587366661564`\ c[2, 3] - 0.016534433397738375`\ c[2, 4] - 
            0.012563587654024454`\ c[3, 0] - 0.010993256465558921`\ c[3, 1] - 
            0.009862441990431254`\ c[3, 2] - 0.009036608015159785`\ c[3, 3] - 
            0.00842887740212212`\ c[3, 4] - 0.011760381891013425`\ c[4, 0] - 
            0.009784579799622044`\ c[4, 1] - 0.008430303142237104`\ c[4, 2] - 
            0.00748618002259904`\ c[4, 3] - 
            0.006819507989826906`\ c[4, 4] == \(-0.0884180693106603`\)\)\),
      SequenceForm[ "eq", {0, 1}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.24861604593388045, 
              c[ 0, 0]], 
            Times[ -0.18256381947770589, 
              c[ 0, 1]], 
            Times[ -0.13758489805825669, 
              c[ 0, 2]], 
            Times[ -0.10773337262158579, 
              c[ 0, 3]], 
            Times[ -0.087364826740135196, 
              c[ 0, 4]], 
            Times[ -0.036376358896790424, 
              c[ 1, 0]], 
            Times[ -0.030701700639324671, 
              c[ 1, 1]], 
            Times[ -0.026646743802237791, 
              c[ 1, 2]], 
            Times[ -0.023696587383795469, 
              c[ 1, 3]], 
            Times[ -0.021506894371527904, 
              c[ 1, 4]], 
            Times[ -0.035149463731755523, 
              c[ 2, 0]], 
            Times[ -0.027584320143072716, 
              c[ 2, 1]], 
            Times[ -0.022480793901959398, 
              c[ 2, 2]], 
            Times[ -0.018985873666615641, 
              c[ 2, 3]], 
            Times[ -0.016534433397738375, 
              c[ 2, 4]], 
            Times[ -0.012563587654024454, 
              c[ 3, 0]], 
            Times[ -0.010993256465558921, 
              c[ 3, 1]], 
            Times[ -0.0098624419904312539, 
              c[ 3, 2]], 
            Times[ -0.0090366080151597847, 
              c[ 3, 3]], 
            Times[ -0.0084288774021221199, 
              c[ 3, 4]], 
            Times[ -0.011760381891013425, 
              c[ 4, 0]], 
            Times[ -0.0097845797996220438, 
              c[ 4, 1]], 
            Times[ -0.0084303031422371041, 
              c[ 4, 2]], 
            Times[ -0.0074861800225990401, 
              c[ 4, 3]], 
            Times[ -0.006819507989826906, 
              c[ 4, 4]]], -0.088418069310660305]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{0, 
          2}\[InvisibleSpace]" = \
"\[InvisibleSpace]\(\(-0.15698115485798506`\)\ c[0, 0] - 
            0.1375848980582567`\ c[0, 1] - 0.11636266292511578`\ c[0, 2] - 
            0.09884035203737365`\ c[0, 3] - 0.08515529520972057`\ c[0, 4] - 
            0.028569811921014602`\ c[1, 0] - 0.02664674380223779`\ c[1, 1] - 
            0.02481934667852275`\ c[1, 2] - 0.023263641237353888`\ c[1, 3] - 
            0.02199154114638158`\ c[1, 4] - 0.02542509951811765`\ c[2, 0] - 
            0.0224807939019594`\ c[2, 1] - 0.019920917768898223`\ c[2, 2] - 
            0.01789900835929596`\ c[2, 3] - 0.016347521425702227`\ c[2, 4] - 
            0.01048306087485224`\ c[3, 0] - 0.009862441990431254`\ c[3, 1] - 
            0.009339566317081084`\ c[3, 2] - 0.008923926125826348`\ c[3, 3] - 
            0.00860704236186341`\ c[3, 4] - 0.009301716115560361`\ c[4, 0] - 
            0.008430303142237104`\ c[4, 1] - 0.007736440379120484`\ c[4, 2] - 
            0.007210116265697266`\ c[4, 3] - 
            0.006822869599386631`\ c[4, 4] == \(-0.05766776727643512`\)\)\),
      SequenceForm[ "eq", {0, 2}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.15698115485798506, 
              c[ 0, 0]], 
            Times[ -0.13758489805825669, 
              c[ 0, 1]], 
            Times[ -0.11636266292511578, 
              c[ 0, 2]], 
            Times[ -0.098840352037373652, 
              c[ 0, 3]], 
            Times[ -0.085155295209720566, 
              c[ 0, 4]], 
            Times[ -0.028569811921014602, 
              c[ 1, 0]], 
            Times[ -0.026646743802237791, 
              c[ 1, 1]], 
            Times[ -0.024819346678522751, 
              c[ 1, 2]], 
            Times[ -0.023263641237353888, 
              c[ 1, 3]], 
            Times[ -0.02199154114638158, 
              c[ 1, 4]], 
            Times[ -0.025425099518117649, 
              c[ 2, 0]], 
            Times[ -0.022480793901959398, 
              c[ 2, 1]], 
            Times[ -0.019920917768898223, 
              c[ 2, 2]], 
            Times[ -0.017899008359295959, 
              c[ 2, 3]], 
            Times[ -0.016347521425702227, 
              c[ 2, 4]], 
            Times[ -0.01048306087485224, 
              c[ 3, 0]], 
            Times[ -0.0098624419904312539, 
              c[ 3, 1]], 
            Times[ -0.0093395663170810841, 
              c[ 3, 2]], 
            Times[ -0.008923926125826348, 
              c[ 3, 3]], 
            Times[ -0.0086070423618634095, 
              c[ 3, 4]], 
            Times[ -0.0093017161155603614, 
              c[ 4, 0]], 
            Times[ -0.0084303031422371041, 
              c[ 4, 1]], 
            Times[ -0.0077364403791204839, 
              c[ 4, 2]], 
            Times[ -0.0072101162656972662, 
              c[ 4, 3]], 
            Times[ -0.0068228695993866311, 
              c[ 4, 4]]], -0.05766776727643512]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{0, 
          3}\[InvisibleSpace]" = \
"\[InvisibleSpace]\(\(-0.10948769802719581`\)\ c[0, 0] - 
            0.10773337262158579`\ c[0, 1] - 0.09884035203737365`\ c[0, 2] - 
            0.08920441329321976`\ c[0, 3] - 0.08055548566910839`\ c[0, 4] - 
            0.023644789389061865`\ c[1, 0] - 0.02369658738379547`\ c[1, 1] - 
            0.023263641237353888`\ c[1, 2] - 0.022703059942531006`\ c[1, 3] - 
            0.022159557879049115`\ c[1, 4] - 0.019753676994491532`\ c[2, 0] - 
            0.01898587366661564`\ c[2, 1] - 0.01789900835929596`\ c[2, 2] - 
            0.016870230249380235`\ c[2, 3] - 0.01600477856717868`\ c[2, 4] - 
            0.009093921920947861`\ c[3, 0] - 0.009036608015159785`\ c[3, 1] - 
            0.008923926125826348`\ c[3, 2] - 0.008815172038822284`\ c[3, 3] - 
            0.008735578653956227`\ c[3, 4] - 0.007756599928090679`\ c[4, 0] - 
            0.00748618002259904`\ c[4, 1] - 0.007210116265697266`\ c[4, 2] - 
            0.006981427922155477`\ c[4, 3] - 
            0.006813932904362683`\ c[4, 4] == \(-0.04113339957503905`\)\)\),
      SequenceForm[ "eq", {0, 3}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.10948769802719581, 
              c[ 0, 0]], 
            Times[ -0.10773337262158579, 
              c[ 0, 1]], 
            Times[ -0.098840352037373652, 
              c[ 0, 2]], 
            Times[ -0.089204413293219764, 
              c[ 0, 3]], 
            Times[ -0.08055548566910839, 
              c[ 0, 4]], 
            Times[ -0.023644789389061865, 
              c[ 1, 0]], 
            Times[ -0.023696587383795469, 
              c[ 1, 1]], 
            Times[ -0.023263641237353888, 
              c[ 1, 2]], 
            Times[ -0.022703059942531006, 
              c[ 1, 3]], 
            Times[ -0.022159557879049115, 
              c[ 1, 4]], 
            Times[ -0.019753676994491532, 
              c[ 2, 0]], 
            Times[ -0.018985873666615641, 
              c[ 2, 1]], 
            Times[ -0.017899008359295959, 
              c[ 2, 2]], 
            Times[ -0.016870230249380235, 
              c[ 2, 3]], 
            Times[ -0.01600477856717868, 
              c[ 2, 4]], 
            Times[ -0.009093921920947861, 
              c[ 3, 0]], 
            Times[ -0.0090366080151597847, 
              c[ 3, 1]], 
            Times[ -0.008923926125826348, 
              c[ 3, 2]], 
            Times[ -0.0088151720388222835, 
              c[ 3, 3]], 
            Times[ -0.0087355786539562268, 
              c[ 3, 4]], 
            Times[ -0.0077565999280906793, 
              c[ 4, 0]], 
            Times[ -0.0074861800225990401, 
              c[ 4, 1]], 
            Times[ -0.0072101162656972662, 
              c[ 4, 2]], 
            Times[ -0.0069814279221554771, 
              c[ 4, 3]], 
            Times[ -0.0068139329043626828, 
              c[ 4, 4]]], -0.041133399575039052]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{0, 
          4}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.0818455017109958`\)\
\ c[0, 0] - 0.0873648267401352`\ c[0, 1] - 0.08515529520972057`\ c[0, 2] - 
            0.08055548566910839`\ c[0, 3] - 0.07554282471801659`\ c[0, 4] - 
            0.020328309499613624`\ c[1, 0] - 0.021506894371527904`\ c[1, 1] - 
            0.02199154114638158`\ c[1, 2] - 0.022159557879049115`\ c[1, 3] - 
            0.022197565878011704`\ c[1, 4] - 0.016180741359767898`\ c[2, 0] - 
            0.016534433397738375`\ c[2, 1] - 0.016347521425702227`\ c[2, 2] - 
            0.01600477856717868`\ c[2, 3] - 0.015662114696107947`\ c[2, 4] - 
            0.008127733109395886`\ c[3, 0] - 0.00842887740212212`\ c[3, 1] - 
            0.00860704236186341`\ c[3, 2] - 0.008735578653956227`\ c[3, 3] - 
            0.008853244905980365`\ c[3, 4] - 0.006735398953034707`\ c[4, 0] - 
            0.006819507989826906`\ c[4, 1] - 0.006822869599386631`\ c[4, 2] - 
            0.006813932904362683`\ c[4, 3] - 
            0.0068226126066063195`\ c[4, 4] == \(-0.03123761981881394`\)\)\),
      SequenceForm[ "eq", {0, 4}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.081845501710995805, 
              c[ 0, 0]], 
            Times[ -0.087364826740135196, 
              c[ 0, 1]], 
            Times[ -0.085155295209720566, 
              c[ 0, 2]], 
            Times[ -0.08055548566910839, 
              c[ 0, 3]], 
            Times[ -0.075542824718016585, 
              c[ 0, 4]], 
            Times[ -0.020328309499613624, 
              c[ 1, 0]], 
            Times[ -0.021506894371527904, 
              c[ 1, 1]], 
            Times[ -0.02199154114638158, 
              c[ 1, 2]], 
            Times[ -0.022159557879049115, 
              c[ 1, 3]], 
            Times[ -0.022197565878011704, 
              c[ 1, 4]], 
            Times[ -0.016180741359767898, 
              c[ 2, 0]], 
            Times[ -0.016534433397738375, 
              c[ 2, 1]], 
            Times[ -0.016347521425702227, 
              c[ 2, 2]], 
            Times[ -0.01600477856717868, 
              c[ 2, 3]], 
            Times[ -0.015662114696107947, 
              c[ 2, 4]], 
            Times[ -0.0081277331093958863, 
              c[ 3, 0]], 
            Times[ -0.0084288774021221199, 
              c[ 3, 1]], 
            Times[ -0.0086070423618634095, 
              c[ 3, 2]], 
            Times[ -0.0087355786539562268, 
              c[ 3, 3]], 
            Times[ -0.0088532449059803651, 
              c[ 3, 4]], 
            Times[ -0.0067353989530347068, 
              c[ 4, 0]], 
            Times[ -0.006819507989826906, 
              c[ 4, 1]], 
            Times[ -0.0068228695993866311, 
              c[ 4, 2]], 
            Times[ -0.0068139329043626828, 
              c[ 4, 3]], 
            Times[ -0.0068226126066063195, 
              c[ 4, 4]]], -0.031237619818813941]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{1, 
          0}\[InvisibleSpace]" = \
"\[InvisibleSpace]\(\(-0.05003129625843903`\)\ c[0, 0] - 
            0.036376358896790424`\ c[0, 1] - 0.028569811921014602`\ c[0, 2] - 
            0.023644789389061865`\ c[0, 3] - 0.020328309499613624`\ c[0, 4] - 
            0.07941759510414069`\ c[1, 0] - 0.04919806374728597`\ c[1, 1] - 
            0.03405438982164765`\ c[1, 2] - 0.02549143964311077`\ c[1, 3] - 
            0.020229859443267093`\ c[1, 4] - 0.02014459927600204`\ c[2, 0] - 
            0.01556554206720038`\ c[2, 1] - 0.012728579464306802`\ c[2, 2] - 
            0.010850668786773841`\ c[2, 3] - 0.009550770701694732`\ c[2, 4] - 
            0.022454075839014462`\ c[3, 0] - 0.015851057252215223`\ c[3, 1] - 
            0.012106848422408103`\ c[3, 2] - 0.009803462370427049`\ c[3, 3] - 
            0.008303525424068736`\ c[3, 4] - 0.00913459576150887`\ c[4, 0] - 
            0.007486207632183761`\ c[4, 1] - 0.006401313315192519`\ c[4, 2] - 
            0.0056558321916690855`\ c[4, 3] - 
            0.00512962422980158`\ c[4, 4] == \(-0.01300974316832604`\)\)\),
      SequenceForm[ "eq", {1, 0}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.05003129625843903, 
              c[ 0, 0]], 
            Times[ -0.036376358896790424, 
              c[ 0, 1]], 
            Times[ -0.028569811921014602, 
              c[ 0, 2]], 
            Times[ -0.023644789389061865, 
              c[ 0, 3]], 
            Times[ -0.020328309499613624, 
              c[ 0, 4]], 
            Times[ -0.07941759510414069, 
              c[ 1, 0]], 
            Times[ -0.049198063747285969, 
              c[ 1, 1]], 
            Times[ -0.03405438982164765, 
              c[ 1, 2]], 
            Times[ -0.025491439643110771, 
              c[ 1, 3]], 
            Times[ -0.020229859443267093, 
              c[ 1, 4]], 
            Times[ -0.02014459927600204, 
              c[ 2, 0]], 
            Times[ -0.015565542067200381, 
              c[ 2, 1]], 
            Times[ -0.012728579464306802, 
              c[ 2, 2]], 
            Times[ -0.010850668786773841, 
              c[ 2, 3]], 
            Times[ -0.0095507707016947319, 
              c[ 2, 4]], 
            Times[ -0.022454075839014462, 
              c[ 3, 0]], 
            Times[ -0.015851057252215223, 
              c[ 3, 1]], 
            Times[ -0.012106848422408103, 
              c[ 3, 2]], 
            Times[ -0.009803462370427049, 
              c[ 3, 3]], 
            Times[ -0.0083035254240687358, 
              c[ 3, 4]], 
            Times[ -0.0091345957615088704, 
              c[ 4, 0]], 
            Times[ -0.007486207632183761, 
              c[ 4, 1]], 
            Times[ -0.0064013133151925193, 
              c[ 4, 2]], 
            Times[ -0.0056558321916690855, 
              c[ 4, 3]], 
            Times[ -0.0051296242298015798, 
              c[ 4, 4]]], -0.01300974316832604]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{1, 
          1}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.036376358896790424`\
\)\ c[0, 0] - 0.03070170063932467`\ c[0, 1] - 0.02664674380223779`\ c[0, 2] - 
            0.02369658738379547`\ c[0, 3] - 0.021506894371527904`\ c[0, 4] - 
            0.04919806374728597`\ c[1, 0] - 0.03621361044660272`\ c[1, 1] - 
            0.028218556550578637`\ c[1, 2] - 0.023034991750114836`\ c[1, 3] - 
            0.019528306142544857`\ c[1, 4] - 0.01556554206720038`\ c[2, 0] - 
            0.013238775055013485`\ c[2, 1] - 0.011619188856257236`\ c[2, 2] - 
            0.01045964560745863`\ c[2, 3] - 0.009614290615458888`\ c[2, 4] - 
            0.015851057252215223`\ c[3, 0] - 0.012589712106469787`\ c[3, 1] - 
            0.010477165584573477`\ c[3, 2] - 0.009054306493633068`\ c[3, 3] - 
            0.008069049154051568`\ c[3, 4] - 0.007486207632183761`\ c[4, 0] - 
            0.0065791605132922825`\ c[4, 1] - 
            0.0059377391031358384`\ c[4, 2] - 
            0.0054771057786187054`\ c[4, 3] - 
            0.0051453642139178595`\ c[4, 4] == \(-0.010279303244109464`\)\)\),
      
      SequenceForm[ "eq", {1, 1}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.036376358896790424, 
              c[ 0, 0]], 
            Times[ -0.030701700639324671, 
              c[ 0, 1]], 
            Times[ -0.026646743802237791, 
              c[ 0, 2]], 
            Times[ -0.023696587383795469, 
              c[ 0, 3]], 
            Times[ -0.021506894371527904, 
              c[ 0, 4]], 
            Times[ -0.049198063747285969, 
              c[ 1, 0]], 
            Times[ -0.03621361044660272, 
              c[ 1, 1]], 
            Times[ -0.028218556550578637, 
              c[ 1, 2]], 
            Times[ -0.023034991750114836, 
              c[ 1, 3]], 
            Times[ -0.019528306142544857, 
              c[ 1, 4]], 
            Times[ -0.015565542067200381, 
              c[ 2, 0]], 
            Times[ -0.013238775055013485, 
              c[ 2, 1]], 
            Times[ -0.011619188856257236, 
              c[ 2, 2]], 
            Times[ -0.01045964560745863, 
              c[ 2, 3]], 
            Times[ -0.009614290615458888, 
              c[ 2, 4]], 
            Times[ -0.015851057252215223, 
              c[ 3, 0]], 
            Times[ -0.012589712106469787, 
              c[ 3, 1]], 
            Times[ -0.010477165584573477, 
              c[ 3, 2]], 
            Times[ -0.0090543064936330683, 
              c[ 3, 3]], 
            Times[ -0.0080690491540515684, 
              c[ 3, 4]], 
            Times[ -0.007486207632183761, 
              c[ 4, 0]], 
            Times[ -0.0065791605132922825, 
              c[ 4, 1]], 
            Times[ -0.0059377391031358384, 
              c[ 4, 2]], 
            Times[ -0.0054771057786187054, 
              c[ 4, 3]], 
            Times[ -0.0051453642139178595, 
              c[ 4, 4]]], -0.010279303244109464]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{1, 
          2}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.028569811921014602`\
\)\ c[0, 0] - 0.02664674380223779`\ c[0, 1] - 0.02481934667852275`\ c[0, 2] - 
            0.023263641237353888`\ c[0, 3] - 0.02199154114638158`\ c[0, 4] - 
            0.03405438982164765`\ c[1, 0] - 0.028218556550578637`\ c[1, 1] - 
            0.023970035852397417`\ c[1, 2] - 0.02089288110410244`\ c[1, 3] - 
            0.018646283397467652`\ c[1, 4] - 0.012728579464306802`\ c[2, 0] - 
            0.011619188856257236`\ c[2, 1] - 0.01076260390937993`\ c[2, 2] - 
            0.010109339339163116`\ c[2, 3] - 0.009617585440610052`\ c[2, 4] - 
            0.012106848422408103`\ c[3, 0] - 0.010477165584573477`\ c[3, 1] - 
            0.009304566850154513`\ c[3, 2] - 0.008459657429921929`\ c[3, 3] - 
            0.007851377836638139`\ c[3, 4] - 0.006401313315192519`\ c[4, 0] - 
            0.0059377391031358384`\ c[4, 1] - 
            0.005592932961557747`\ c[4, 2] - 0.005341366861189084`\ c[4, 3] - 
            0.005164329576180986`\ c[4, 4] == \(-0.00857688490232269`\)\)\),
      SequenceForm[ "eq", {1, 2}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.028569811921014602, 
              c[ 0, 0]], 
            Times[ -0.026646743802237791, 
              c[ 0, 1]], 
            Times[ -0.024819346678522751, 
              c[ 0, 2]], 
            Times[ -0.023263641237353888, 
              c[ 0, 3]], 
            Times[ -0.02199154114638158, 
              c[ 0, 4]], 
            Times[ -0.03405438982164765, 
              c[ 1, 0]], 
            Times[ -0.028218556550578637, 
              c[ 1, 1]], 
            Times[ -0.023970035852397417, 
              c[ 1, 2]], 
            Times[ -0.020892881104102441, 
              c[ 1, 3]], 
            Times[ -0.018646283397467652, 
              c[ 1, 4]], 
            Times[ -0.012728579464306802, 
              c[ 2, 0]], 
            Times[ -0.011619188856257236, 
              c[ 2, 1]], 
            Times[ -0.01076260390937993, 
              c[ 2, 2]], 
            Times[ -0.010109339339163116, 
              c[ 2, 3]], 
            Times[ -0.0096175854406100516, 
              c[ 2, 4]], 
            Times[ -0.012106848422408103, 
              c[ 3, 0]], 
            Times[ -0.010477165584573477, 
              c[ 3, 1]], 
            Times[ -0.009304566850154513, 
              c[ 3, 2]], 
            Times[ -0.0084596574299219286, 
              c[ 3, 3]], 
            Times[ -0.0078513778366381386, 
              c[ 3, 4]], 
            Times[ -0.0064013133151925193, 
              c[ 4, 0]], 
            Times[ -0.0059377391031358384, 
              c[ 4, 1]], 
            Times[ -0.0055929329615577467, 
              c[ 4, 2]], 
            Times[ -0.0053413668611890838, 
              c[ 4, 3]], 
            Times[ -0.0051643295761809862, 
              c[ 4, 4]]], -0.0085768849023226904]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{1, 
          3}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.023644789389061865`\
\)\ c[0, 0] - 0.02369658738379547`\ c[0, 1] - 
            0.023263641237353888`\ c[0, 2] - 0.022703059942531006`\ c[0, 3] - 
            0.022159557879049115`\ c[0, 4] - 0.02549143964311077`\ c[1, 0] - 
            0.023034991750114836`\ c[1, 1] - 0.02089288110410244`\ c[1, 2] - 
            0.019168992221145664`\ c[1, 3] - 0.017825944158161824`\ c[1, 4] - 
            0.010850668786773841`\ c[2, 0] - 0.01045964560745863`\ c[2, 1] - 
            0.010109339339163116`\ c[2, 2] - 0.009825715117568924`\ c[2, 3] - 
            0.009614012173747594`\ c[2, 4] - 0.009803462370427049`\ c[3, 0] - 
            0.009054306493633068`\ c[3, 1] - 0.008459657429921929`\ c[3, 2] - 
            0.008009936159406981`\ c[3, 3] - 0.00768386840556921`\ c[3, 4] - 
            0.0056558321916690855`\ c[4, 0] - 
            0.0054771057786187054`\ c[4, 1] - 
            0.005341366861189084`\ c[4, 2] - 0.005249281482429118`\ c[4, 3] - 
            0.005198701693497111`\ c[4, 4] == \(-0.007429339364667458`\)\)\),
      SequenceForm[ "eq", {1, 3}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.023644789389061865, 
              c[ 0, 0]], 
            Times[ -0.023696587383795469, 
              c[ 0, 1]], 
            Times[ -0.023263641237353888, 
              c[ 0, 2]], 
            Times[ -0.022703059942531006, 
              c[ 0, 3]], 
            Times[ -0.022159557879049115, 
              c[ 0, 4]], 
            Times[ -0.025491439643110771, 
              c[ 1, 0]], 
            Times[ -0.023034991750114836, 
              c[ 1, 1]], 
            Times[ -0.020892881104102441, 
              c[ 1, 2]], 
            Times[ -0.019168992221145664, 
              c[ 1, 3]], 
            Times[ -0.017825944158161824, 
              c[ 1, 4]], 
            Times[ -0.010850668786773841, 
              c[ 2, 0]], 
            Times[ -0.01045964560745863, 
              c[ 2, 1]], 
            Times[ -0.010109339339163116, 
              c[ 2, 2]], 
            Times[ -0.0098257151175689238, 
              c[ 2, 3]], 
            Times[ -0.0096140121737475943, 
              c[ 2, 4]], 
            Times[ -0.009803462370427049, 
              c[ 3, 0]], 
            Times[ -0.0090543064936330683, 
              c[ 3, 1]], 
            Times[ -0.0084596574299219286, 
              c[ 3, 2]], 
            Times[ -0.0080099361594069812, 
              c[ 3, 3]], 
            Times[ -0.0076838684055692101, 
              c[ 3, 4]], 
            Times[ -0.0056558321916690855, 
              c[ 4, 0]], 
            Times[ -0.0054771057786187054, 
              c[ 4, 1]], 
            Times[ -0.0053413668611890838, 
              c[ 4, 2]], 
            Times[ -0.0052492814824291181, 
              c[ 4, 3]], 
            Times[ -0.0051987016934971113, 
              c[ 4, 4]]], -0.0074293393646674578]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{1, 
          4}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.020328309499613624`\
\)\ c[0, 0] - 0.021506894371527904`\ c[0, 1] - 
            0.02199154114638158`\ c[0, 2] - 0.022159557879049115`\ c[0, 3] - 
            0.022197565878011704`\ c[0, 4] - 0.020229859443267093`\ c[1, 0] - 
            0.019528306142544857`\ c[1, 1] - 0.018646283397467652`\ c[1, 2] - 
            0.017825944158161824`\ c[1, 3] - 0.01714364597204234`\ c[1, 4] - 
            0.009550770701694732`\ c[2, 0] - 0.009614290615458888`\ c[2, 1] - 
            0.009617585440610052`\ c[2, 2] - 0.009614012173747594`\ c[2, 3] - 
            0.009629745796650418`\ c[2, 4] - 0.008303525424068736`\ c[3, 0] - 
            0.008069049154051568`\ c[3, 1] - 0.007851377836638139`\ c[3, 2] - 
            0.00768386840556921`\ c[3, 3] - 0.0075756649296774455`\ c[3, 4] - 
            0.00512962422980158`\ c[4, 0] - 0.0051453642139178595`\ c[4, 1] - 
            0.005164329576180986`\ c[4, 2] - 0.005198701693497111`\ c[4, 3] - 
            0.005254644949840944`\ c[4, 4] == \(-0.006616124724728609`\)\)\),
      SequenceForm[ "eq", {1, 4}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.020328309499613624, 
              c[ 0, 0]], 
            Times[ -0.021506894371527904, 
              c[ 0, 1]], 
            Times[ -0.02199154114638158, 
              c[ 0, 2]], 
            Times[ -0.022159557879049115, 
              c[ 0, 3]], 
            Times[ -0.022197565878011704, 
              c[ 0, 4]], 
            Times[ -0.020229859443267093, 
              c[ 1, 0]], 
            Times[ -0.019528306142544857, 
              c[ 1, 1]], 
            Times[ -0.018646283397467652, 
              c[ 1, 2]], 
            Times[ -0.017825944158161824, 
              c[ 1, 3]], 
            Times[ -0.017143645972042341, 
              c[ 1, 4]], 
            Times[ -0.0095507707016947319, 
              c[ 2, 0]], 
            Times[ -0.009614290615458888, 
              c[ 2, 1]], 
            Times[ -0.0096175854406100516, 
              c[ 2, 2]], 
            Times[ -0.0096140121737475943, 
              c[ 2, 3]], 
            Times[ -0.0096297457966504178, 
              c[ 2, 4]], 
            Times[ -0.0083035254240687358, 
              c[ 3, 0]], 
            Times[ -0.0080690491540515684, 
              c[ 3, 1]], 
            Times[ -0.0078513778366381386, 
              c[ 3, 2]], 
            Times[ -0.0076838684055692101, 
              c[ 3, 3]], 
            Times[ -0.0075756649296774455, 
              c[ 3, 4]], 
            Times[ -0.0051296242298015798, 
              c[ 4, 0]], 
            Times[ -0.0051453642139178595, 
              c[ 4, 1]], 
            Times[ -0.0051643295761809862, 
              c[ 4, 2]], 
            Times[ -0.0051987016934971113, 
              c[ 4, 3]], 
            Times[ -0.0052546449498409439, 
              c[ 4, 4]]], -0.0066161247247286089]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{2, 
          0}\[InvisibleSpace]" = \
"\[InvisibleSpace]\(\(-0.05383493048441987`\)\ c[0, 0] - 
            0.03514946373175552`\ c[0, 1] - 0.02542509951811765`\ c[0, 2] - 
            0.019753676994491532`\ c[0, 3] - 0.016180741359767898`\ c[0, 4] - 
            0.02014459927600204`\ c[1, 0] - 0.01556554206720038`\ c[1, 1] - 
            0.012728579464306802`\ c[1, 2] - 0.010850668786773841`\ c[1, 3] - 
            0.009550770701694732`\ c[1, 4] - 0.02461329646396953`\ c[2, 0] - 
            0.017214615705949156`\ c[2, 1] - 0.013041892524690684`\ c[2, 2] - 
            0.010485749851205841`\ c[2, 3] - 0.008826234247746746`\ c[2, 4] - 
            0.010154986942922238`\ c[3, 0] - 0.008254727701667155`\ c[3, 1] - 
            0.007007229919035119`\ c[3, 2] - 0.006150880915373312`\ c[3, 3] - 
            0.005545883583719328`\ c[3, 4] - 0.010707820741319048`\ c[4, 0] - 
            0.008165387528130017`\ c[4, 1] - 0.006611074427079434`\ c[4, 2] - 
            0.0056049222622869006`\ c[4, 3] - 
            0.00492782211471897`\ c[4, 4] == \(-0.018550930073353795`\)\)\),
      SequenceForm[ "eq", {2, 0}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.053834930484419868, 
              c[ 0, 0]], 
            Times[ -0.035149463731755523, 
              c[ 0, 1]], 
            Times[ -0.025425099518117649, 
              c[ 0, 2]], 
            Times[ -0.019753676994491532, 
              c[ 0, 3]], 
            Times[ -0.016180741359767898, 
              c[ 0, 4]], 
            Times[ -0.02014459927600204, 
              c[ 1, 0]], 
            Times[ -0.015565542067200381, 
              c[ 1, 1]], 
            Times[ -0.012728579464306802, 
              c[ 1, 2]], 
            Times[ -0.010850668786773841, 
              c[ 1, 3]], 
            Times[ -0.0095507707016947319, 
              c[ 1, 4]], 
            Times[ -0.024613296463969529, 
              c[ 2, 0]], 
            Times[ -0.017214615705949156, 
              c[ 2, 1]], 
            Times[ -0.013041892524690684, 
              c[ 2, 2]], 
            Times[ -0.010485749851205841, 
              c[ 2, 3]], 
            Times[ -0.0088262342477467455, 
              c[ 2, 4]], 
            Times[ -0.010154986942922238, 
              c[ 3, 0]], 
            Times[ -0.0082547277016671548, 
              c[ 3, 1]], 
            Times[ -0.0070072299190351191, 
              c[ 3, 2]], 
            Times[ -0.0061508809153733119, 
              c[ 3, 3]], 
            Times[ -0.0055458835837193278, 
              c[ 3, 4]], 
            Times[ -0.010707820741319048, 
              c[ 4, 0]], 
            Times[ -0.0081653875281300168, 
              c[ 4, 1]], 
            Times[ -0.0066110744270794341, 
              c[ 4, 2]], 
            Times[ -0.0056049222622869006, 
              c[ 4, 3]], 
            Times[ -0.0049278221147189697, 
              c[ 4, 4]]], -0.018550930073353795]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{2, 
          1}\[InvisibleSpace]" = \
"\[InvisibleSpace]\(\(-0.03514946373175552`\)\ c[0, 0] - 
            0.027584320143072716`\ c[0, 1] - 0.0224807939019594`\ c[0, 2] - 
            0.01898587366661564`\ c[0, 3] - 0.016534433397738375`\ c[0, 4] - 
            0.01556554206720038`\ c[1, 0] - 0.013238775055013485`\ c[1, 1] - 
            0.011619188856257236`\ c[1, 2] - 0.01045964560745863`\ c[1, 3] - 
            0.009614290615458888`\ c[1, 4] - 0.017214615705949156`\ c[2, 0] - 
            0.013524756208752368`\ c[2, 1] - 0.011159453065352268`\ c[2, 2] - 
            0.009577015317311078`\ c[2, 3] - 0.008485562875459788`\ c[2, 4] - 
            0.008254727701667155`\ c[3, 0] - 
            0.0071850771171348814`\ c[3, 1] - 
            0.006432787826840065`\ c[3, 2] - 0.005893365132536453`\ c[3, 3] - 
            0.005503804906830416`\ c[3, 4] - 0.008165387528130017`\ c[4, 0] - 
            0.006772272757480883`\ c[4, 1] - 0.005847177753002358`\ c[4, 2] - 
            0.0052146797712062645`\ c[4, 3] - 
            0.004775382682019783`\ c[4, 4] == \(-0.01241291572499795`\)\)\),
      SequenceForm[ "eq", {2, 1}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.035149463731755523, 
              c[ 0, 0]], 
            Times[ -0.027584320143072716, 
              c[ 0, 1]], 
            Times[ -0.022480793901959398, 
              c[ 0, 2]], 
            Times[ -0.018985873666615641, 
              c[ 0, 3]], 
            Times[ -0.016534433397738375, 
              c[ 0, 4]], 
            Times[ -0.015565542067200381, 
              c[ 1, 0]], 
            Times[ -0.013238775055013485, 
              c[ 1, 1]], 
            Times[ -0.011619188856257236, 
              c[ 1, 2]], 
            Times[ -0.01045964560745863, 
              c[ 1, 3]], 
            Times[ -0.009614290615458888, 
              c[ 1, 4]], 
            Times[ -0.017214615705949156, 
              c[ 2, 0]], 
            Times[ -0.013524756208752368, 
              c[ 2, 1]], 
            Times[ -0.011159453065352268, 
              c[ 2, 2]], 
            Times[ -0.0095770153173110779, 
              c[ 2, 3]], 
            Times[ -0.0084855628754597883, 
              c[ 2, 4]], 
            Times[ -0.0082547277016671548, 
              c[ 3, 0]], 
            Times[ -0.0071850771171348814, 
              c[ 3, 1]], 
            Times[ -0.0064327878268400649, 
              c[ 3, 2]], 
            Times[ -0.0058933651325364534, 
              c[ 3, 3]], 
            Times[ -0.0055038049068304156, 
              c[ 3, 4]], 
            Times[ -0.0081653875281300168, 
              c[ 4, 0]], 
            Times[ -0.0067722727574808829, 
              c[ 4, 1]], 
            Times[ -0.0058471777530023578, 
              c[ 4, 2]], 
            Times[ -0.0052146797712062645, 
              c[ 4, 3]], 
            Times[ -0.0047753826820197834, 
              c[ 4, 4]]], -0.012412915724997951]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{2, 
          2}\[InvisibleSpace]" = \
"\[InvisibleSpace]\(\(-0.02542509951811765`\)\ c[0, 0] - 
            0.0224807939019594`\ c[0, 1] - 0.019920917768898223`\ c[0, 2] - 
            0.01789900835929596`\ c[0, 3] - 0.016347521425702227`\ c[0, 4] - 
            0.012728579464306802`\ c[1, 0] - 0.011619188856257236`\ c[1, 1] - 
            0.01076260390937993`\ c[1, 2] - 0.010109339339163116`\ c[1, 3] - 
            0.009617585440610052`\ c[1, 4] - 0.013041892524690684`\ c[2, 0] - 
            0.011159453065352268`\ c[2, 1] - 0.009827275673832521`\ c[2, 2] - 
            0.008876171151330148`\ c[2, 3] - 0.008194213915721973`\ c[2, 4] - 
            0.007007229919035119`\ c[3, 0] - 0.006432787826840065`\ c[3, 1] - 
            0.006009192315475497`\ c[3, 2] - 0.005699807554101641`\ c[3, 3] - 
            0.005479260501230088`\ c[3, 4] - 0.006611074427079434`\ c[4, 0] - 
            0.005847177753002358`\ c[4, 1] - 0.005310298990035364`\ c[4, 2] - 
            0.0049324237817421415`\ c[4, 3] - 
            0.0046697952900079265`\ c[4, 4] == \(-0.009120951041058754`\)\)\),
      
      SequenceForm[ "eq", {2, 2}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.025425099518117649, 
              c[ 0, 0]], 
            Times[ -0.022480793901959398, 
              c[ 0, 1]], 
            Times[ -0.019920917768898223, 
              c[ 0, 2]], 
            Times[ -0.017899008359295959, 
              c[ 0, 3]], 
            Times[ -0.016347521425702227, 
              c[ 0, 4]], 
            Times[ -0.012728579464306802, 
              c[ 1, 0]], 
            Times[ -0.011619188856257236, 
              c[ 1, 1]], 
            Times[ -0.01076260390937993, 
              c[ 1, 2]], 
            Times[ -0.010109339339163116, 
              c[ 1, 3]], 
            Times[ -0.0096175854406100516, 
              c[ 1, 4]], 
            Times[ -0.013041892524690684, 
              c[ 2, 0]], 
            Times[ -0.011159453065352268, 
              c[ 2, 1]], 
            Times[ -0.0098272756738325209, 
              c[ 2, 2]], 
            Times[ -0.0088761711513301485, 
              c[ 2, 3]], 
            Times[ -0.0081942139157219727, 
              c[ 2, 4]], 
            Times[ -0.0070072299190351191, 
              c[ 3, 0]], 
            Times[ -0.0064327878268400649, 
              c[ 3, 1]], 
            Times[ -0.0060091923154754973, 
              c[ 3, 2]], 
            Times[ -0.0056998075541016407, 
              c[ 3, 3]], 
            Times[ -0.0054792605012300884, 
              c[ 3, 4]], 
            Times[ -0.0066110744270794341, 
              c[ 4, 0]], 
            Times[ -0.0058471777530023578, 
              c[ 4, 1]], 
            Times[ -0.0053102989900353642, 
              c[ 4, 2]], 
            Times[ -0.0049324237817421415, 
              c[ 4, 3]], 
            Times[ -0.0046697952900079265, 
              c[ 4, 4]]], -0.009120951041058754]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{2, 
          3}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.019753676994491532`\
\)\ c[0, 0] - 0.01898587366661564`\ c[0, 1] - 0.01789900835929596`\ c[0, 2] - 
            0.016870230249380235`\ c[0, 3] - 0.01600477856717868`\ c[0, 4] - 
            0.010850668786773841`\ c[1, 0] - 0.01045964560745863`\ c[1, 1] - 
            0.010109339339163116`\ c[1, 2] - 0.009825715117568924`\ c[1, 3] - 
            0.009614012173747594`\ c[1, 4] - 0.010485749851205841`\ c[2, 0] - 
            0.009577015317311078`\ c[2, 1] - 0.008876171151330148`\ c[2, 2] - 
            0.008352772238490817`\ c[2, 3] - 0.007973846905971384`\ c[2, 4] - 
            0.006150880915373312`\ c[3, 0] - 0.005893365132536453`\ c[3, 1] - 
            0.005699807554101641`\ c[3, 2] - 0.005564212407478219`\ c[3, 3] - 
            0.005480240284468271`\ c[3, 4] - 
            0.0056049222622869006`\ c[4, 0] - 
            0.0052146797712062645`\ c[4, 1] - 
            0.0049324237817421415`\ c[4, 2] - 
            0.004736386012973122`\ c[4, 3] - 
            0.004609784506921807`\ c[4, 4] == \(-0.00715968137984925`\)\)\),
      SequenceForm[ "eq", {2, 3}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.019753676994491532, 
              c[ 0, 0]], 
            Times[ -0.018985873666615641, 
              c[ 0, 1]], 
            Times[ -0.017899008359295959, 
              c[ 0, 2]], 
            Times[ -0.016870230249380235, 
              c[ 0, 3]], 
            Times[ -0.01600477856717868, 
              c[ 0, 4]], 
            Times[ -0.010850668786773841, 
              c[ 1, 0]], 
            Times[ -0.01045964560745863, 
              c[ 1, 1]], 
            Times[ -0.010109339339163116, 
              c[ 1, 2]], 
            Times[ -0.0098257151175689238, 
              c[ 1, 3]], 
            Times[ -0.0096140121737475943, 
              c[ 1, 4]], 
            Times[ -0.010485749851205841, 
              c[ 2, 0]], 
            Times[ -0.0095770153173110779, 
              c[ 2, 1]], 
            Times[ -0.0088761711513301485, 
              c[ 2, 2]], 
            Times[ -0.008352772238490817, 
              c[ 2, 3]], 
            Times[ -0.0079738469059713844, 
              c[ 2, 4]], 
            Times[ -0.0061508809153733119, 
              c[ 3, 0]], 
            Times[ -0.0058933651325364534, 
              c[ 3, 1]], 
            Times[ -0.0056998075541016407, 
              c[ 3, 2]], 
            Times[ -0.0055642124074782194, 
              c[ 3, 3]], 
            Times[ -0.0054802402844682709, 
              c[ 3, 4]], 
            Times[ -0.0056049222622869006, 
              c[ 4, 0]], 
            Times[ -0.0052146797712062645, 
              c[ 4, 1]], 
            Times[ -0.0049324237817421415, 
              c[ 4, 2]], 
            Times[ -0.0047363860129731221, 
              c[ 4, 3]], 
            Times[ -0.0046097845069218071, 
              c[ 4, 4]]], -0.0071596813798492503]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{2, 
          4}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.016180741359767898`\
\)\ c[0, 0] - 0.016534433397738375`\ c[0, 1] - 
            0.016347521425702227`\ c[0, 2] - 0.01600477856717868`\ c[0, 3] - 
            0.015662114696107947`\ c[0, 4] - 0.009550770701694732`\ c[1, 0] - 
            0.009614290615458888`\ c[1, 1] - 0.009617585440610052`\ c[1, 2] - 
            0.009614012173747594`\ c[1, 3] - 0.009629745796650418`\ c[1, 4] - 
            0.008826234247746746`\ c[2, 0] - 0.008485562875459788`\ c[2, 1] - 
            0.008194213915721973`\ c[2, 2] - 0.007973846905971384`\ c[2, 3] - 
            0.007826682370701155`\ c[2, 4] - 0.005545883583719328`\ c[3, 0] - 
            0.005503804906830416`\ c[3, 1] - 0.005479260501230088`\ c[3, 2] - 
            0.005480240284468271`\ c[3, 3] - 0.005510165689203531`\ c[3, 4] - 
            0.00492782211471897`\ c[4, 0] - 0.004775382682019783`\ c[4, 1] - 
            0.0046697952900079265`\ c[4, 2] - 
            0.004609784506921807`\ c[4, 3] - 
            0.004591992972866244`\ c[4, 4] == \(-0.0059052697188147155`\)\)\),
      
      SequenceForm[ "eq", {2, 4}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.016180741359767898, 
              c[ 0, 0]], 
            Times[ -0.016534433397738375, 
              c[ 0, 1]], 
            Times[ -0.016347521425702227, 
              c[ 0, 2]], 
            Times[ -0.01600477856717868, 
              c[ 0, 3]], 
            Times[ -0.015662114696107947, 
              c[ 0, 4]], 
            Times[ -0.0095507707016947319, 
              c[ 1, 0]], 
            Times[ -0.009614290615458888, 
              c[ 1, 1]], 
            Times[ -0.0096175854406100516, 
              c[ 1, 2]], 
            Times[ -0.0096140121737475943, 
              c[ 1, 3]], 
            Times[ -0.0096297457966504178, 
              c[ 1, 4]], 
            Times[ -0.0088262342477467455, 
              c[ 2, 0]], 
            Times[ -0.0084855628754597883, 
              c[ 2, 1]], 
            Times[ -0.0081942139157219727, 
              c[ 2, 2]], 
            Times[ -0.0079738469059713844, 
              c[ 2, 3]], 
            Times[ -0.0078266823707011553, 
              c[ 2, 4]], 
            Times[ -0.0055458835837193278, 
              c[ 3, 0]], 
            Times[ -0.0055038049068304156, 
              c[ 3, 1]], 
            Times[ -0.0054792605012300884, 
              c[ 3, 2]], 
            Times[ -0.0054802402844682709, 
              c[ 3, 3]], 
            Times[ -0.0055101656892035311, 
              c[ 3, 4]], 
            Times[ -0.0049278221147189697, 
              c[ 4, 0]], 
            Times[ -0.0047753826820197834, 
              c[ 4, 1]], 
            Times[ -0.0046697952900079265, 
              c[ 4, 2]], 
            Times[ -0.0046097845069218071, 
              c[ 4, 3]], 
            Times[ -0.0045919929728662438, 
              c[ 4, 4]]], -0.0059052697188147155]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{3, 
          0}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.015880821839381908`\
\)\ c[0, 0] - 0.012563587654024454`\ c[0, 1] - 
            0.01048306087485224`\ c[0, 2] - 0.009093921920947861`\ c[0, 3] - 
            0.008127733109395886`\ c[0, 4] - 0.022454075839014462`\ c[1, 0] - 
            0.015851057252215223`\ c[1, 1] - 0.012106848422408103`\ c[1, 2] - 
            0.009803462370427049`\ c[1, 3] - 0.008303525424068736`\ c[1, 4] - 
            0.010154986942922238`\ c[2, 0] - 0.008254727701667155`\ c[2, 1] - 
            0.007007229919035119`\ c[2, 2] - 0.006150880915373312`\ c[2, 3] - 
            0.005545883583719328`\ c[2, 4] - 0.01119068442538073`\ c[3, 0] - 
            0.008502239135203229`\ c[3, 1] - 0.006861334783600878`\ c[3, 2] - 
            0.0058002264002220815`\ c[3, 3] - 
            0.005086380437487815`\ c[3, 4] - 0.005975716618244462`\ c[4, 0] - 
            0.005055085095407302`\ c[4, 1] - 0.00442629029432368`\ c[4, 2] - 
            0.003984357358829202`\ c[4, 3] - 
            0.0036690876737841076`\ c[4, 4] == \(-0.004457041641000588`\)\)\),
      
      SequenceForm[ "eq", {3, 0}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.015880821839381908, 
              c[ 0, 0]], 
            Times[ -0.012563587654024454, 
              c[ 0, 1]], 
            Times[ -0.01048306087485224, 
              c[ 0, 2]], 
            Times[ -0.009093921920947861, 
              c[ 0, 3]], 
            Times[ -0.0081277331093958863, 
              c[ 0, 4]], 
            Times[ -0.022454075839014462, 
              c[ 1, 0]], 
            Times[ -0.015851057252215223, 
              c[ 1, 1]], 
            Times[ -0.012106848422408103, 
              c[ 1, 2]], 
            Times[ -0.009803462370427049, 
              c[ 1, 3]], 
            Times[ -0.0083035254240687358, 
              c[ 1, 4]], 
            Times[ -0.010154986942922238, 
              c[ 2, 0]], 
            Times[ -0.0082547277016671548, 
              c[ 2, 1]], 
            Times[ -0.0070072299190351191, 
              c[ 2, 2]], 
            Times[ -0.0061508809153733119, 
              c[ 2, 3]], 
            Times[ -0.0055458835837193278, 
              c[ 2, 4]], 
            Times[ -0.01119068442538073, 
              c[ 3, 0]], 
            Times[ -0.0085022391352032288, 
              c[ 3, 1]], 
            Times[ -0.0068613347836008779, 
              c[ 3, 2]], 
            Times[ -0.0058002264002220815, 
              c[ 3, 3]], 
            Times[ -0.0050863804374878148, 
              c[ 3, 4]], 
            Times[ -0.0059757166182444624, 
              c[ 4, 0]], 
            Times[ -0.0050550850954073018, 
              c[ 4, 1]], 
            Times[ -0.0044262902943236803, 
              c[ 4, 2]], 
            Times[ -0.0039843573588292016, 
              c[ 4, 3]], 
            Times[ -0.0036690876737841076, 
              c[ 4, 4]]], -0.0044570416410005878]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{3, 
          1}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.012563587654024454`\
\)\ c[0, 0] - 0.010993256465558921`\ c[0, 1] - 
            0.009862441990431254`\ c[0, 2] - 0.009036608015159785`\ c[0, 3] - 
            0.00842887740212212`\ c[0, 4] - 0.015851057252215223`\ c[1, 0] - 
            0.012589712106469787`\ c[1, 1] - 0.010477165584573477`\ c[1, 2] - 
            0.009054306493633068`\ c[1, 3] - 0.008069049154051568`\ c[1, 4] - 
            0.008254727701667155`\ c[2, 0] - 
            0.0071850771171348814`\ c[2, 1] - 
            0.006432787826840065`\ c[2, 2] - 0.005893365132536453`\ c[2, 3] - 
            0.005503804906830416`\ c[2, 4] - 0.008502239135203229`\ c[3, 0] - 
            0.007022533114002327`\ c[3, 1] - 0.006042481890937538`\ c[3, 2] - 
            0.005373238093975111`\ c[3, 3] - 0.004908346620240498`\ c[3, 4] - 
            0.005055085095407302`\ c[4, 0] - 0.004503483619290428`\ c[4, 1] - 
            0.004111748968859301`\ c[4, 2] - 0.003831489007825308`\ c[4, 3] - 
            0.0036325391913967736`\ c[4, 4] == \(-0.003739702913881226`\)\)\),
      
      SequenceForm[ "eq", {3, 1}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.012563587654024454, 
              c[ 0, 0]], 
            Times[ -0.010993256465558921, 
              c[ 0, 1]], 
            Times[ -0.0098624419904312539, 
              c[ 0, 2]], 
            Times[ -0.0090366080151597847, 
              c[ 0, 3]], 
            Times[ -0.0084288774021221199, 
              c[ 0, 4]], 
            Times[ -0.015851057252215223, 
              c[ 1, 0]], 
            Times[ -0.012589712106469787, 
              c[ 1, 1]], 
            Times[ -0.010477165584573477, 
              c[ 1, 2]], 
            Times[ -0.0090543064936330683, 
              c[ 1, 3]], 
            Times[ -0.0080690491540515684, 
              c[ 1, 4]], 
            Times[ -0.0082547277016671548, 
              c[ 2, 0]], 
            Times[ -0.0071850771171348814, 
              c[ 2, 1]], 
            Times[ -0.0064327878268400649, 
              c[ 2, 2]], 
            Times[ -0.0058933651325364534, 
              c[ 2, 3]], 
            Times[ -0.0055038049068304156, 
              c[ 2, 4]], 
            Times[ -0.0085022391352032288, 
              c[ 3, 0]], 
            Times[ -0.0070225331140023267, 
              c[ 3, 1]], 
            Times[ -0.0060424818909375379, 
              c[ 3, 2]], 
            Times[ -0.0053732380939751113, 
              c[ 3, 3]], 
            Times[ -0.0049083466202404979, 
              c[ 3, 4]], 
            Times[ -0.0050550850954073018, 
              c[ 4, 0]], 
            Times[ -0.0045034836192904279, 
              c[ 4, 1]], 
            Times[ -0.0041117489688593011, 
              c[ 4, 2]], 
            Times[ -0.0038314890078253081, 
              c[ 4, 3]], 
            Times[ -0.0036325391913967736, 
              c[ 4, 4]]], -0.003739702913881226]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{3, 
          2}\[InvisibleSpace]" = \
"\[InvisibleSpace]\(\(-0.01048306087485224`\)\ c[0, 0] - 
            0.009862441990431254`\ c[0, 1] - 0.009339566317081084`\ c[0, 2] - 
            0.008923926125826348`\ c[0, 3] - 0.00860704236186341`\ c[0, 4] - 
            0.012106848422408103`\ c[1, 0] - 0.010477165584573477`\ c[1, 1] - 
            0.009304566850154513`\ c[1, 2] - 0.008459657429921929`\ c[1, 3] - 
            0.007851377836638139`\ c[1, 4] - 0.007007229919035119`\ c[2, 0] - 
            0.006432787826840065`\ c[2, 1] - 0.006009192315475497`\ c[2, 2] - 
            0.005699807554101641`\ c[2, 3] - 0.005479260501230088`\ c[2, 4] - 
            0.006861334783600878`\ c[3, 0] - 0.006042481890937538`\ c[3, 1] - 
            0.00546885731280421`\ c[3, 2] - 0.005065387719962856`\ c[3, 3] - 
            0.004784347313541393`\ c[3, 4] - 0.00442629029432368`\ c[4, 0] - 
            0.004111748968859301`\ c[4, 1] - 
            0.0038856227858390414`\ c[4, 2] - 
            0.0037268360787244955`\ c[4, 3] - 
            0.0036211656337744895`\ c[4, 
                4] == \(-0.0032606581135811354`\)\)\),
      SequenceForm[ "eq", {3, 2}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.01048306087485224, 
              c[ 0, 0]], 
            Times[ -0.0098624419904312539, 
              c[ 0, 1]], 
            Times[ -0.0093395663170810841, 
              c[ 0, 2]], 
            Times[ -0.008923926125826348, 
              c[ 0, 3]], 
            Times[ -0.0086070423618634095, 
              c[ 0, 4]], 
            Times[ -0.012106848422408103, 
              c[ 1, 0]], 
            Times[ -0.010477165584573477, 
              c[ 1, 1]], 
            Times[ -0.009304566850154513, 
              c[ 1, 2]], 
            Times[ -0.0084596574299219286, 
              c[ 1, 3]], 
            Times[ -0.0078513778366381386, 
              c[ 1, 4]], 
            Times[ -0.0070072299190351191, 
              c[ 2, 0]], 
            Times[ -0.0064327878268400649, 
              c[ 2, 1]], 
            Times[ -0.0060091923154754973, 
              c[ 2, 2]], 
            Times[ -0.0056998075541016407, 
              c[ 2, 3]], 
            Times[ -0.0054792605012300884, 
              c[ 2, 4]], 
            Times[ -0.0068613347836008779, 
              c[ 3, 0]], 
            Times[ -0.0060424818909375379, 
              c[ 3, 1]], 
            Times[ -0.0054688573128042102, 
              c[ 3, 2]], 
            Times[ -0.005065387719962856, 
              c[ 3, 3]], 
            Times[ -0.0047843473135413929, 
              c[ 3, 4]], 
            Times[ -0.0044262902943236803, 
              c[ 4, 0]], 
            Times[ -0.0041117489688593011, 
              c[ 4, 1]], 
            Times[ -0.0038856227858390414, 
              c[ 4, 2]], 
            Times[ -0.0037268360787244955, 
              c[ 4, 3]], 
            Times[ -0.0036211656337744895, 
              c[ 4, 4]]], -0.0032606581135811354]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{3, 
          3}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.009093921920947861`\
\)\ c[0, 0] - 0.009036608015159785`\ c[0, 1] - 
            0.008923926125826348`\ c[0, 2] - 0.008815172038822284`\ c[0, 3] - 
            0.008735578653956227`\ c[0, 4] - 0.009803462370427049`\ c[1, 0] - 
            0.009054306493633068`\ c[1, 1] - 0.008459657429921929`\ c[1, 2] - 
            0.008009936159406981`\ c[1, 3] - 0.00768386840556921`\ c[1, 4] - 
            0.006150880915373312`\ c[2, 0] - 0.005893365132536453`\ c[2, 1] - 
            0.005699807554101641`\ c[2, 2] - 0.005564212407478219`\ c[2, 3] - 
            0.005480240284468271`\ c[2, 4] - 
            0.0058002264002220815`\ c[3, 0] - 
            0.005373238093975111`\ c[3, 1] - 0.005065387719962856`\ c[3, 2] - 
            0.0048509380365065885`\ c[3, 3] - 
            0.004710750728874009`\ c[3, 4] - 0.003984357358829202`\ c[4, 0] - 
            0.003831489007825308`\ c[4, 1] - 
            0.0037268360787244955`\ c[4, 2] - 
            0.0036630908001951687`\ c[4, 3] - 
            0.0036347798659246973`\ c[4, 
                4] == \(-0.0029254909127239635`\)\)\),
      SequenceForm[ "eq", {3, 3}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.009093921920947861, 
              c[ 0, 0]], 
            Times[ -0.0090366080151597847, 
              c[ 0, 1]], 
            Times[ -0.008923926125826348, 
              c[ 0, 2]], 
            Times[ -0.0088151720388222835, 
              c[ 0, 3]], 
            Times[ -0.0087355786539562268, 
              c[ 0, 4]], 
            Times[ -0.009803462370427049, 
              c[ 1, 0]], 
            Times[ -0.0090543064936330683, 
              c[ 1, 1]], 
            Times[ -0.0084596574299219286, 
              c[ 1, 2]], 
            Times[ -0.0080099361594069812, 
              c[ 1, 3]], 
            Times[ -0.0076838684055692101, 
              c[ 1, 4]], 
            Times[ -0.0061508809153733119, 
              c[ 2, 0]], 
            Times[ -0.0058933651325364534, 
              c[ 2, 1]], 
            Times[ -0.0056998075541016407, 
              c[ 2, 2]], 
            Times[ -0.0055642124074782194, 
              c[ 2, 3]], 
            Times[ -0.0054802402844682709, 
              c[ 2, 4]], 
            Times[ -0.0058002264002220815, 
              c[ 3, 0]], 
            Times[ -0.0053732380939751113, 
              c[ 3, 1]], 
            Times[ -0.005065387719962856, 
              c[ 3, 2]], 
            Times[ -0.0048509380365065885, 
              c[ 3, 3]], 
            Times[ -0.0047107507288740094, 
              c[ 3, 4]], 
            Times[ -0.0039843573588292016, 
              c[ 4, 0]], 
            Times[ -0.0038314890078253081, 
              c[ 4, 1]], 
            Times[ -0.0037268360787244955, 
              c[ 4, 2]], 
            Times[ -0.0036630908001951687, 
              c[ 4, 3]], 
            Times[ -0.0036347798659246973, 
              c[ 4, 4]]], -0.0029254909127239635]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{3, 
          4}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.008127733109395886`\
\)\ c[0, 0] - 0.00842887740212212`\ c[0, 1] - 0.00860704236186341`\ c[0, 2] - 
            0.008735578653956227`\ c[0, 3] - 0.008853244905980365`\ c[0, 4] - 
            0.008303525424068736`\ c[1, 0] - 0.008069049154051568`\ c[1, 1] - 
            0.007851377836638139`\ c[1, 2] - 0.00768386840556921`\ c[1, 3] - 
            0.0075756649296774455`\ c[1, 4] - 
            0.005545883583719328`\ c[2, 0] - 0.005503804906830416`\ c[2, 1] - 
            0.005479260501230088`\ c[2, 2] - 0.005480240284468271`\ c[2, 3] - 
            0.005510165689203531`\ c[2, 4] - 0.005086380437487815`\ c[3, 0] - 
            0.004908346620240498`\ c[3, 1] - 0.004784347313541393`\ c[3, 2] - 
            0.004710750728874009`\ c[3, 3] - 0.004682736108486976`\ c[3, 4] - 
            0.0036690876737841076`\ c[4, 0] - 
            0.0036325391913967736`\ c[4, 1] - 
            0.0036211656337744895`\ c[4, 2] - 
            0.0036347798659246973`\ c[4, 3] - 
            0.003672829770052524`\ c[4, 4] == \(-0.0026843759077584874`\)\)\),
      
      SequenceForm[ "eq", {3, 4}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.0081277331093958863, 
              c[ 0, 0]], 
            Times[ -0.0084288774021221199, 
              c[ 0, 1]], 
            Times[ -0.0086070423618634095, 
              c[ 0, 2]], 
            Times[ -0.0087355786539562268, 
              c[ 0, 3]], 
            Times[ -0.0088532449059803651, 
              c[ 0, 4]], 
            Times[ -0.0083035254240687358, 
              c[ 1, 0]], 
            Times[ -0.0080690491540515684, 
              c[ 1, 1]], 
            Times[ -0.0078513778366381386, 
              c[ 1, 2]], 
            Times[ -0.0076838684055692101, 
              c[ 1, 3]], 
            Times[ -0.0075756649296774455, 
              c[ 1, 4]], 
            Times[ -0.0055458835837193278, 
              c[ 2, 0]], 
            Times[ -0.0055038049068304156, 
              c[ 2, 1]], 
            Times[ -0.0054792605012300884, 
              c[ 2, 2]], 
            Times[ -0.0054802402844682709, 
              c[ 2, 3]], 
            Times[ -0.0055101656892035311, 
              c[ 2, 4]], 
            Times[ -0.0050863804374878148, 
              c[ 3, 0]], 
            Times[ -0.0049083466202404979, 
              c[ 3, 1]], 
            Times[ -0.0047843473135413929, 
              c[ 3, 2]], 
            Times[ -0.0047107507288740094, 
              c[ 3, 3]], 
            Times[ -0.0046827361084869762, 
              c[ 3, 4]], 
            Times[ -0.0036690876737841076, 
              c[ 4, 0]], 
            Times[ -0.0036325391913967736, 
              c[ 4, 1]], 
            Times[ -0.0036211656337744895, 
              c[ 4, 2]], 
            Times[ -0.0036347798659246973, 
              c[ 4, 3]], 
            Times[ -0.0036728297700525242, 
              c[ 4, 4]]], -0.0026843759077584874]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{4, 
          0}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.015976413964149252`\
\)\ c[0, 0] - 0.011760381891013425`\ c[0, 1] - 
            0.009301716115560361`\ c[0, 2] - 0.007756599928090679`\ c[0, 3] - 
            0.006735398953034707`\ c[0, 4] - 0.00913459576150887`\ c[1, 0] - 
            0.007486207632183761`\ c[1, 1] - 0.006401313315192519`\ c[1, 2] - 
            0.0056558321916690855`\ c[1, 3] - 0.00512962422980158`\ c[1, 4] - 
            0.010707820741319048`\ c[2, 0] - 0.008165387528130017`\ c[2, 1] - 
            0.006611074427079434`\ c[2, 2] - 
            0.0056049222622869006`\ c[2, 3] - 0.00492782211471897`\ c[2, 4] - 
            0.005975716618244462`\ c[3, 0] - 0.005055085095407302`\ c[3, 1] - 
            0.00442629029432368`\ c[3, 2] - 0.003984357358829202`\ c[3, 3] - 
            0.0036690876737841076`\ c[3, 4] - 
            0.006196351317579794`\ c[4, 0] - 0.005006107300323158`\ c[4, 1] - 
            0.004238484430834086`\ c[4, 2] - 0.003723660011025707`\ c[4, 3] - 
            0.003370155517301354`\ c[4, 4] == \(-0.005532061103142007`\)\)\),
      SequenceForm[ "eq", {4, 0}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.015976413964149252, 
              c[ 0, 0]], 
            Times[ -0.011760381891013425, 
              c[ 0, 1]], 
            Times[ -0.0093017161155603614, 
              c[ 0, 2]], 
            Times[ -0.0077565999280906793, 
              c[ 0, 3]], 
            Times[ -0.0067353989530347068, 
              c[ 0, 4]], 
            Times[ -0.0091345957615088704, 
              c[ 1, 0]], 
            Times[ -0.007486207632183761, 
              c[ 1, 1]], 
            Times[ -0.0064013133151925193, 
              c[ 1, 2]], 
            Times[ -0.0056558321916690855, 
              c[ 1, 3]], 
            Times[ -0.0051296242298015798, 
              c[ 1, 4]], 
            Times[ -0.010707820741319048, 
              c[ 2, 0]], 
            Times[ -0.0081653875281300168, 
              c[ 2, 1]], 
            Times[ -0.0066110744270794341, 
              c[ 2, 2]], 
            Times[ -0.0056049222622869006, 
              c[ 2, 3]], 
            Times[ -0.0049278221147189697, 
              c[ 2, 4]], 
            Times[ -0.0059757166182444624, 
              c[ 3, 0]], 
            Times[ -0.0050550850954073018, 
              c[ 3, 1]], 
            Times[ -0.0044262902943236803, 
              c[ 3, 2]], 
            Times[ -0.0039843573588292016, 
              c[ 3, 3]], 
            Times[ -0.0036690876737841076, 
              c[ 3, 4]], 
            Times[ -0.0061963513175797942, 
              c[ 4, 0]], 
            Times[ -0.0050061073003231579, 
              c[ 4, 1]], 
            Times[ -0.0042384844308340861, 
              c[ 4, 2]], 
            Times[ -0.003723660011025707, 
              c[ 4, 3]], 
            Times[ -0.0033701555173013542, 
              c[ 4, 4]]], -0.0055320611031420067]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{4, 
          1}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.011760381891013425`\
\)\ c[0, 0] - 0.009784579799622044`\ c[0, 1] - 
            0.008430303142237104`\ c[0, 2] - 0.00748618002259904`\ c[0, 3] - 
            0.006819507989826906`\ c[0, 4] - 0.007486207632183761`\ c[1, 0] - 
            0.0065791605132922825`\ c[1, 1] - 
            0.0059377391031358384`\ c[1, 2] - 
            0.0054771057786187054`\ c[1, 3] - 
            0.0051453642139178595`\ c[1, 4] - 
            0.008165387528130017`\ c[2, 0] - 0.006772272757480883`\ c[2, 1] - 
            0.005847177753002358`\ c[2, 2] - 
            0.0052146797712062645`\ c[2, 3] - 
            0.004775382682019783`\ c[2, 4] - 0.005055085095407302`\ c[3, 0] - 
            0.004503483619290428`\ c[3, 1] - 0.004111748968859301`\ c[3, 2] - 
            0.003831489007825308`\ c[3, 3] - 
            0.0036325391913967736`\ c[3, 4] - 
            0.005006107300323158`\ c[4, 0] - 0.004306676036986969`\ c[4, 1] - 
            0.0038321717390644543`\ c[4, 2] - 
            0.003504859497603178`\ c[4, 3] - 
            0.0032789042969824044`\ c[4, 4] == \(-0.004126092225661819`\)\)\),
      
      SequenceForm[ "eq", {4, 1}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.011760381891013425, 
              c[ 0, 0]], 
            Times[ -0.0097845797996220438, 
              c[ 0, 1]], 
            Times[ -0.0084303031422371041, 
              c[ 0, 2]], 
            Times[ -0.0074861800225990401, 
              c[ 0, 3]], 
            Times[ -0.006819507989826906, 
              c[ 0, 4]], 
            Times[ -0.007486207632183761, 
              c[ 1, 0]], 
            Times[ -0.0065791605132922825, 
              c[ 1, 1]], 
            Times[ -0.0059377391031358384, 
              c[ 1, 2]], 
            Times[ -0.0054771057786187054, 
              c[ 1, 3]], 
            Times[ -0.0051453642139178595, 
              c[ 1, 4]], 
            Times[ -0.0081653875281300168, 
              c[ 2, 0]], 
            Times[ -0.0067722727574808829, 
              c[ 2, 1]], 
            Times[ -0.0058471777530023578, 
              c[ 2, 2]], 
            Times[ -0.0052146797712062645, 
              c[ 2, 3]], 
            Times[ -0.0047753826820197834, 
              c[ 2, 4]], 
            Times[ -0.0050550850954073018, 
              c[ 3, 0]], 
            Times[ -0.0045034836192904279, 
              c[ 3, 1]], 
            Times[ -0.0041117489688593011, 
              c[ 3, 2]], 
            Times[ -0.0038314890078253081, 
              c[ 3, 3]], 
            Times[ -0.0036325391913967736, 
              c[ 3, 4]], 
            Times[ -0.0050061073003231579, 
              c[ 4, 0]], 
            Times[ -0.0043066760369869688, 
              c[ 4, 1]], 
            Times[ -0.0038321717390644543, 
              c[ 4, 2]], 
            Times[ -0.0035048594976031782, 
              c[ 4, 3]], 
            Times[ -0.0032789042969824044, 
              c[ 4, 4]]], -0.0041260922256618187]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{4, 
          2}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.009301716115560361`\
\)\ c[0, 0] - 0.008430303142237104`\ c[0, 1] - 
            0.007736440379120484`\ c[0, 2] - 0.007210116265697266`\ c[0, 3] - 
            0.006822869599386631`\ c[0, 4] - 0.006401313315192519`\ c[1, 0] - 
            0.0059377391031358384`\ c[1, 1] - 
            0.005592932961557747`\ c[1, 2] - 0.005341366861189084`\ c[1, 3] - 
            0.005164329576180986`\ c[1, 4] - 0.006611074427079434`\ c[2, 0] - 
            0.005847177753002358`\ c[2, 1] - 0.005310298990035364`\ c[2, 2] - 
            0.0049324237817421415`\ c[2, 3] - 
            0.0046697952900079265`\ c[2, 4] - 0.00442629029432368`\ c[3, 0] - 
            0.004111748968859301`\ c[3, 1] - 
            0.0038856227858390414`\ c[3, 2] - 
            0.0037268360787244955`\ c[3, 3] - 
            0.0036211656337744895`\ c[3, 4] - 
            0.004238484430834086`\ c[4, 0] - 
            0.0038321717390644543`\ c[4, 1] - 
            0.0035497608243704516`\ c[4, 2] - 
            0.003355644533674814`\ c[4, 3] - 
            0.003227080832615768`\ c[4, 4] == \(-0.003291410245975625`\)\)\),
      SequenceForm[ "eq", {4, 2}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.0093017161155603614, 
              c[ 0, 0]], 
            Times[ -0.0084303031422371041, 
              c[ 0, 1]], 
            Times[ -0.0077364403791204839, 
              c[ 0, 2]], 
            Times[ -0.0072101162656972662, 
              c[ 0, 3]], 
            Times[ -0.0068228695993866311, 
              c[ 0, 4]], 
            Times[ -0.0064013133151925193, 
              c[ 1, 0]], 
            Times[ -0.0059377391031358384, 
              c[ 1, 1]], 
            Times[ -0.0055929329615577467, 
              c[ 1, 2]], 
            Times[ -0.0053413668611890838, 
              c[ 1, 3]], 
            Times[ -0.0051643295761809862, 
              c[ 1, 4]], 
            Times[ -0.0066110744270794341, 
              c[ 2, 0]], 
            Times[ -0.0058471777530023578, 
              c[ 2, 1]], 
            Times[ -0.0053102989900353642, 
              c[ 2, 2]], 
            Times[ -0.0049324237817421415, 
              c[ 2, 3]], 
            Times[ -0.0046697952900079265, 
              c[ 2, 4]], 
            Times[ -0.0044262902943236803, 
              c[ 3, 0]], 
            Times[ -0.0041117489688593011, 
              c[ 3, 1]], 
            Times[ -0.0038856227858390414, 
              c[ 3, 2]], 
            Times[ -0.0037268360787244955, 
              c[ 3, 3]], 
            Times[ -0.0036211656337744895, 
              c[ 3, 4]], 
            Times[ -0.0042384844308340861, 
              c[ 4, 0]], 
            Times[ -0.0038321717390644543, 
              c[ 4, 1]], 
            Times[ -0.0035497608243704516, 
              c[ 4, 2]], 
            Times[ -0.0033556445336748141, 
              c[ 4, 3]], 
            Times[ -0.0032270808326157678, 
              c[ 4, 4]]], -0.0032914102459756251]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{4, 
          3}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.007756599928090679`\
\)\ c[0, 0] - 0.00748618002259904`\ c[0, 1] - 
            0.007210116265697266`\ c[0, 2] - 0.006981427922155477`\ c[0, 3] - 
            0.006813932904362683`\ c[0, 4] - 
            0.0056558321916690855`\ c[1, 0] - 
            0.0054771057786187054`\ c[1, 1] - 
            0.005341366861189084`\ c[1, 2] - 0.005249281482429118`\ c[1, 3] - 
            0.005198701693497111`\ c[1, 4] - 
            0.0056049222622869006`\ c[2, 0] - 
            0.0052146797712062645`\ c[2, 1] - 
            0.0049324237817421415`\ c[2, 2] - 
            0.004736386012973122`\ c[2, 3] - 0.004609784506921807`\ c[2, 4] - 
            0.003984357358829202`\ c[3, 0] - 0.003831489007825308`\ c[3, 1] - 
            0.0037268360787244955`\ c[3, 2] - 
            0.0036630908001951687`\ c[3, 3] - 
            0.0036347798659246973`\ c[3, 4] - 
            0.003723660011025707`\ c[4, 0] - 0.003504859497603178`\ c[4, 1] - 
            0.003355644533674814`\ c[4, 2] - 0.003260751435497525`\ c[4, 3] - 
            0.0032096228313462406`\ c[4, 4] == \(-0.002760710085568981`\)\)\),
      
      SequenceForm[ "eq", {4, 3}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.0077565999280906793, 
              c[ 0, 0]], 
            Times[ -0.0074861800225990401, 
              c[ 0, 1]], 
            Times[ -0.0072101162656972662, 
              c[ 0, 2]], 
            Times[ -0.0069814279221554771, 
              c[ 0, 3]], 
            Times[ -0.0068139329043626828, 
              c[ 0, 4]], 
            Times[ -0.0056558321916690855, 
              c[ 1, 0]], 
            Times[ -0.0054771057786187054, 
              c[ 1, 1]], 
            Times[ -0.0053413668611890838, 
              c[ 1, 2]], 
            Times[ -0.0052492814824291181, 
              c[ 1, 3]], 
            Times[ -0.0051987016934971113, 
              c[ 1, 4]], 
            Times[ -0.0056049222622869006, 
              c[ 2, 0]], 
            Times[ -0.0052146797712062645, 
              c[ 2, 1]], 
            Times[ -0.0049324237817421415, 
              c[ 2, 2]], 
            Times[ -0.0047363860129731221, 
              c[ 2, 3]], 
            Times[ -0.0046097845069218071, 
              c[ 2, 4]], 
            Times[ -0.0039843573588292016, 
              c[ 3, 0]], 
            Times[ -0.0038314890078253081, 
              c[ 3, 1]], 
            Times[ -0.0037268360787244955, 
              c[ 3, 2]], 
            Times[ -0.0036630908001951687, 
              c[ 3, 3]], 
            Times[ -0.0036347798659246973, 
              c[ 3, 4]], 
            Times[ -0.003723660011025707, 
              c[ 4, 0]], 
            Times[ -0.0035048594976031782, 
              c[ 4, 1]], 
            Times[ -0.0033556445336748141, 
              c[ 4, 2]], 
            Times[ -0.0032607514354975249, 
              c[ 4, 3]], 
            Times[ -0.0032096228313462406, 
              c[ 4, 4]]], -0.0027607100855689811]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{4, 
          4}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.006735398953034707`\
\)\ c[0, 0] - 0.006819507989826906`\ c[0, 1] - 
            0.006822869599386631`\ c[0, 2] - 0.006813932904362683`\ c[0, 3] - 
            0.0068226126066063195`\ c[0, 4] - 0.00512962422980158`\ c[1, 0] - 
            0.0051453642139178595`\ c[1, 1] - 
            0.005164329576180986`\ c[1, 2] - 0.005198701693497111`\ c[1, 3] - 
            0.005254644949840944`\ c[1, 4] - 0.00492782211471897`\ c[2, 0] - 
            0.004775382682019783`\ c[2, 1] - 
            0.0046697952900079265`\ c[2, 2] - 
            0.004609784506921807`\ c[2, 3] - 0.004591992972866244`\ c[2, 4] - 
            0.0036690876737841076`\ c[3, 0] - 
            0.0036325391913967736`\ c[3, 1] - 
            0.0036211656337744895`\ c[3, 2] - 
            0.0036347798659246973`\ c[3, 3] - 
            0.003672829770052524`\ c[3, 4] - 0.003370155517301354`\ c[4, 0] - 
            0.0032789042969824044`\ c[4, 1] - 
            0.003227080832615768`\ c[4, 2] - 
            0.0032096228313462406`\ c[4, 3] - 
            0.0032226166097433797`\ c[4, 4] == \(-0.002407472758250739`\)\)\),
      
      SequenceForm[ "eq", {4, 4}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.0067353989530347068, 
              c[ 0, 0]], 
            Times[ -0.006819507989826906, 
              c[ 0, 1]], 
            Times[ -0.0068228695993866311, 
              c[ 0, 2]], 
            Times[ -0.0068139329043626828, 
              c[ 0, 3]], 
            Times[ -0.0068226126066063195, 
              c[ 0, 4]], 
            Times[ -0.0051296242298015798, 
              c[ 1, 0]], 
            Times[ -0.0051453642139178595, 
              c[ 1, 1]], 
            Times[ -0.0051643295761809862, 
              c[ 1, 2]], 
            Times[ -0.0051987016934971113, 
              c[ 1, 3]], 
            Times[ -0.0052546449498409439, 
              c[ 1, 4]], 
            Times[ -0.0049278221147189697, 
              c[ 2, 0]], 
            Times[ -0.0047753826820197834, 
              c[ 2, 1]], 
            Times[ -0.0046697952900079265, 
              c[ 2, 2]], 
            Times[ -0.0046097845069218071, 
              c[ 2, 3]], 
            Times[ -0.0045919929728662438, 
              c[ 2, 4]], 
            Times[ -0.0036690876737841076, 
              c[ 3, 0]], 
            Times[ -0.0036325391913967736, 
              c[ 3, 1]], 
            Times[ -0.0036211656337744895, 
              c[ 3, 2]], 
            Times[ -0.0036347798659246973, 
              c[ 3, 3]], 
            Times[ -0.0036728297700525242, 
              c[ 3, 4]], 
            Times[ -0.0033701555173013542, 
              c[ 4, 0]], 
            Times[ -0.0032789042969824044, 
              c[ 4, 1]], 
            Times[ -0.0032270808326157678, 
              c[ 4, 2]], 
            Times[ -0.0032096228313462406, 
              c[ 4, 3]], 
            Times[ -0.0032226166097433797, 
              c[ 4, 4]]], -0.002407472758250739]],
      Editable->False]], "Print"]
}, Closed]],

Cell[TextData[{
  "The module returns the approximate solution for the potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y)\)]],
  ". We plot the solution in Cell ",
  ButtonBox["6.21",
    ButtonData:>"Cell 6.21",
    ButtonStyle->"Hyperlink"],
  " as a contour plot."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ContourPlot[\[Phi][x, y]\ Boole[
            z[1, x, y] \[LessEqual] \ 0 && 
              z[2, x, y] \[GreaterEqual] 0], {x, \(-1\), 1.3}, {y, 0, 1.3}, 
        PlotPoints \[Rule] 100, FrameLabel \[Rule] {"\<x\>", "\<y\>"}, 
        Contours \[Rule] {0, \(- .02\), \(-0.04\), \(-0.06\), \
\(-0.08\)}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.21"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.437291 0.41806 0.0192308 0.739645 [
[.01923 -0.0125 -6 -9 ]
[.01923 -0.0125 6 0 ]
[.22826 -0.0125 -12 -9 ]
[.22826 -0.0125 12 0 ]
[.43729 -0.0125 -3 -9 ]
[.43729 -0.0125 3 0 ]
[.64632 -0.0125 -9 -9 ]
[.64632 -0.0125 9 0 ]
[.85535 -0.0125 -3 -9 ]
[.85535 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .16716 -18 -4.5 ]
[-0.0125 .16716 0 4.5 ]
[-0.0125 .31509 -18 -4.5 ]
[-0.0125 .31509 0 4.5 ]
[-0.0125 .46302 -18 -4.5 ]
[-0.0125 .46302 0 4.5 ]
[-0.0125 .61095 -18 -4.5 ]
[-0.0125 .61095 0 4.5 ]
[-0.0125 .75888 -6 -4.5 ]
[-0.0125 .75888 0 4.5 ]
[-0.0125 .9068 -18 -4.5 ]
[-0.0125 .9068 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -30 -5 ]
[-0.01875 .5 -18 5 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-1)] .01923 -0.0125 0 1 Mshowa
.22826 0 m
.22826 .00625 L
s
[(-0.5)] .22826 -0.0125 0 1 Mshowa
.43729 0 m
.43729 .00625 L
s
[(0)] .43729 -0.0125 0 1 Mshowa
.64632 0 m
.64632 .00625 L
s
[(0.5)] .64632 -0.0125 0 1 Mshowa
.85535 0 m
.85535 .00625 L
s
[(1)] .85535 -0.0125 0 1 Mshowa
.125 Mabswid
.06104 0 m
.06104 .00375 L
s
.10284 0 m
.10284 .00375 L
s
.14465 0 m
.14465 .00375 L
s
.18645 0 m
.18645 .00375 L
s
.27007 0 m
.27007 .00375 L
s
.31187 0 m
.31187 .00375 L
s
.35368 0 m
.35368 .00375 L
s
.39548 0 m
.39548 .00375 L
s
.4791 0 m
.4791 .00375 L
s
.5209 0 m
.5209 .00375 L
s
.56271 0 m
.56271 .00375 L
s
.60452 0 m
.60452 .00375 L
s
.68813 0 m
.68813 .00375 L
s
.72993 0 m
.72993 .00375 L
s
.77174 0 m
.77174 .00375 L
s
.81355 0 m
.81355 .00375 L
s
.89716 0 m
.89716 .00375 L
s
.93896 0 m
.93896 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .16716 m
.00625 .16716 L
s
[(0.2)] -0.0125 .16716 1 0 Mshowa
0 .31509 m
.00625 .31509 L
s
[(0.4)] -0.0125 .31509 1 0 Mshowa
0 .46302 m
.00625 .46302 L
s
[(0.6)] -0.0125 .46302 1 0 Mshowa
0 .61095 m
.00625 .61095 L
s
[(0.8)] -0.0125 .61095 1 0 Mshowa
0 .75888 m
.00625 .75888 L
s
[(1)] -0.0125 .75888 1 0 Mshowa
0 .9068 m
.00625 .9068 L
s
[(1.2)] -0.0125 .9068 1 0 Mshowa
.125 Mabswid
0 .05621 m
.00375 .05621 L
s
0 .0932 m
.00375 .0932 L
s
0 .13018 m
.00375 .13018 L
s
0 .20414 m
.00375 .20414 L
s
0 .24112 m
.00375 .24112 L
s
0 .27811 m
.00375 .27811 L
s
0 .35207 m
.00375 .35207 L
s
0 .38905 m
.00375 .38905 L
s
0 .42604 m
.00375 .42604 L
s
0 .5 m
.00375 .5 L
s
0 .53698 m
.00375 .53698 L
s
0 .57396 m
.00375 .57396 L
s
0 .64793 m
.00375 .64793 L
s
0 .68491 m
.00375 .68491 L
s
0 .72189 m
.00375 .72189 L
s
0 .79586 m
.00375 .79586 L
s
0 .83284 m
.00375 .83284 L
s
0 .86982 m
.00375 .86982 L
s
0 .94379 m
.00375 .94379 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -90 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10 translate
90 rotate
-66 -10 translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01923 .99375 m
.01923 1 L
s
.22826 .99375 m
.22826 1 L
s
.43729 .99375 m
.43729 1 L
s
.64632 .99375 m
.64632 1 L
s
.85535 .99375 m
.85535 1 L
s
.125 Mabswid
.06104 .99625 m
.06104 1 L
s
.10284 .99625 m
.10284 1 L
s
.14465 .99625 m
.14465 1 L
s
.18645 .99625 m
.18645 1 L
s
.27007 .99625 m
.27007 1 L
s
.31187 .99625 m
.31187 1 L
s
.35368 .99625 m
.35368 1 L
s
.39548 .99625 m
.39548 1 L
s
.4791 .99625 m
.4791 1 L
s
.5209 .99625 m
.5209 1 L
s
.56271 .99625 m
.56271 1 L
s
.60452 .99625 m
.60452 1 L
s
.68813 .99625 m
.68813 1 L
s
.72993 .99625 m
.72993 1 L
s
.77174 .99625 m
.77174 1 L
s
.81355 .99625 m
.81355 1 L
s
.89716 .99625 m
.89716 1 L
s
.93896 .99625 m
.93896 1 L
s
.98077 .99625 m
.98077 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .16716 m
1 .16716 L
s
.99375 .31509 m
1 .31509 L
s
.99375 .46302 m
1 .46302 L
s
.99375 .61095 m
1 .61095 L
s
.99375 .75888 m
1 .75888 L
s
.99375 .9068 m
1 .9068 L
s
.125 Mabswid
.99625 .05621 m
1 .05621 L
s
.99625 .0932 m
1 .0932 L
s
.99625 .13018 m
1 .13018 L
s
.99625 .20414 m
1 .20414 L
s
.99625 .24112 m
1 .24112 L
s
.99625 .27811 m
1 .27811 L
s
.99625 .35207 m
1 .35207 L
s
.99625 .38905 m
1 .38905 L
s
.99625 .42604 m
1 .42604 L
s
.99625 .5 m
1 .5 L
s
.99625 .53698 m
1 .53698 L
s
.99625 .57396 m
1 .57396 L
s
.99625 .64793 m
1 .64793 L
s
.99625 .68491 m
1 .68491 L
s
.99625 .72189 m
1 .72189 L
s
.99625 .79586 m
1 .79586 L
s
.99625 .83284 m
1 .83284 L
s
.99625 .86982 m
1 .86982 L
s
.99625 .94379 m
1 .94379 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.869 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
1 g
.39802 .01923 m
.40773 .01923 L
.41744 .01923 L
.42716 .01923 L
.43687 .01923 L
.44658 .01923 L
.45629 .01923 L
.46601 .01923 L
.47572 .01923 L
.48543 .02894 L
.48543 .02894 L
.49514 .02894 L
.50486 .02894 L
.51457 .03866 L
.51457 .03866 L
.52428 .04837 L
.52428 .04837 L
.53399 .05808 L
.53399 .05808 L
.54371 .05808 L
.55342 .06779 L
.55342 .06779 L
.56313 .07751 L
.56313 .07751 L
.57284 .08722 L
.57284 .09693 L
.57284 .09693 L
.58256 .10664 L
.58256 .10664 L
.59227 .11636 L
.59227 .11636 L
.60198 .12607 L
.60198 .12607 L
.61169 .13578 L
.61169 .14549 L
.61169 .14549 L
.62141 .15521 L
.62141 .15521 L
.63112 .16492 L
.63112 .17463 L
.63112 .17463 L
.64083 .18434 L
.64083 .19406 L
.64083 .19406 L
.65054 .20377 L
.65054 .20377 L
.66026 .21348 L
.66026 .22319 L
.66026 .22319 L
.66997 .23291 L
.66997 .24262 L
.66997 .24262 L
.67968 .25233 L
.67968 .26204 L
.67968 .26204 L
.68939 .27176 L
.68939 .28147 L
.68939 .28147 L
.69911 .29118 L
.69911 .30089 L
.69911 .30089 L
.70882 .31061 L
.70882 .32032 L
.70882 .33003 L
.70882 .33003 L
.71853 .33974 L
.71853 .34946 L
.71853 .34946 L
.72824 .35917 L
.72824 .36888 L
.72824 .36888 L
.73796 .37859 L
.73796 .38831 L
.73796 .39802 L
.73796 .39802 L
.74767 .40773 L
.74767 .41744 L
.74767 .41744 L
.75738 .42716 L
.75738 .43687 L
.75738 .44658 L
.75738 .44658 L
.76709 .45629 L
.76709 .46601 L
.76709 .47572 L
.76709 .47572 L
.77681 .48543 L
.77681 .49514 L
.77681 .50486 L
.77681 .50486 L
.78652 .51457 L
.78652 .52428 L
.78652 .53399 L
.78652 .53399 L
.79623 .54371 L
.79623 .55342 L
.79623 .56313 L
.79623 .56313 L
.80594 .57284 L
.80594 .58256 L
.80594 .59227 L
.80594 .59227 L
.81566 .60198 L
.81566 .61169 L
.81566 .62141 L
.81566 .62141 L
.82537 .63112 L
.82537 .64083 L
.82537 .65054 L
.82537 .65054 L
.83508 .66026 L
.83508 .66997 L
.83508 .67968 L
.83508 .67968 L
.84479 .68939 L
.84479 .69911 L
.84479 .70882 L
.84479 .71853 L
.84479 .71853 L
.85451 .72824 L
.85451 .73796 L
.85451 .74767 L
.85451 .74767 L
.86422 .75738 L
.86422 .76709 L
.86422 .77681 L
.86422 .78652 L
.86422 .78652 L
.87393 .79623 L
.87393 .80594 L
.87393 .81566 L
.87393 .82537 L
.87393 .82537 L
.88364 .83508 L
.88364 .84479 L
.88364 .85451 L
.88364 .85451 L
.89336 .86422 L
.89336 .87393 L
.89336 .88364 L
.88364 .89336 L
.87393 .89336 L
.86422 .89336 L
.85451 .88364 L
.85451 .88364 L
.84479 .88364 L
.83508 .88364 L
.82537 .87393 L
.82537 .87393 L
.81566 .87393 L
.80594 .87393 L
.79623 .87393 L
.78652 .86422 L
.78652 .86422 L
.77681 .86422 L
.76709 .86422 L
.75738 .85451 L
.75738 .85451 L
.74767 .85451 L
.73796 .85451 L
.72824 .84479 L
.72824 .84479 L
.71853 .84479 L
.70882 .84479 L
.69911 .84479 L
.68939 .83508 L
.68939 .83508 L
.67968 .83508 L
.66997 .83508 L
.66026 .82537 L
.66026 .82537 L
.65054 .82537 L
.64083 .82537 L
.63112 .82537 L
.62141 .81566 L
.62141 .81566 L
.61169 .81566 L
.60198 .81566 L
.59227 .80594 L
.59227 .80594 L
.58256 .80594 L
.57284 .80594 L
.56313 .79623 L
.56313 .79623 L
.55342 .79623 L
.54371 .79623 L
.53399 .79623 L
.52428 .78652 L
.52428 .78652 L
.51457 .78652 L
.50486 .78652 L
.49514 .77681 L
.49514 .77681 L
.48543 .77681 L
.47572 .77681 L
.46601 .77681 L
.45629 .76709 L
.45629 .76709 L
.44658 .76709 L
.43687 .76709 L
.42716 .75738 L
.42716 .75738 L
.41744 .75738 L
.40773 .75738 L
.39802 .74767 L
.39802 .74767 L
.38831 .74767 L
.37859 .74767 L
.36888 .74767 L
.35917 .73796 L
.35917 .73796 L
.34946 .73796 L
.33974 .73796 L
.33003 .72824 L
.33003 .72824 L
.32032 .72824 L
.31061 .72824 L
.30089 .72824 L
.29118 .71853 L
.29118 .71853 L
.28147 .71853 L
.27176 .71853 L
.26204 .70882 L
.26204 .70882 L
.25233 .70882 L
.24262 .70882 L
.23291 .69911 L
.23291 .69911 L
.22319 .69911 L
.21348 .69911 L
.20377 .69911 L
.19406 .68939 L
.19406 .68939 L
.18434 .68939 L
.17463 .68939 L
.16492 .67968 L
.16492 .67968 L
.15521 .67968 L
.14549 .67968 L
.13578 .67968 L
.12607 .66997 L
.12607 .66997 L
.11636 .66997 L
.10664 .66997 L
.09693 .66026 L
.09693 .66026 L
.08722 .66026 L
.07751 .66026 L
.06779 .65054 L
.06779 .65054 L
.05808 .65054 L
.04837 .64083 L
.04837 .63112 L
.05808 .62141 L
.05808 .62141 L
.05808 .61169 L
.05808 .60198 L
.06779 .59227 L
.06779 .59227 L
.06779 .58256 L
.06779 .57284 L
.07751 .56313 L
.07751 .56313 L
.07751 .55342 L
.07751 .54371 L
.08722 .53399 L
.08722 .53399 L
.08722 .52428 L
.08722 .51457 L
.09693 .50486 L
.09693 .50486 L
.09693 .49514 L
.09693 .48543 L
.10664 .47572 L
.10664 .47572 L
.10664 .46601 L
.10664 .45629 L
.11636 .44658 L
.11636 .44658 L
.11636 .43687 L
.12607 .42716 L
.12607 .42716 L
.12607 .41744 L
.12607 .40773 L
.13578 .39802 L
.13578 .39802 L
.13578 .38831 L
.14549 .37859 L
.14549 .37859 L
.14549 .36888 L
.14549 .35917 L
.15521 .34946 L
.15521 .34946 L
.15521 .33974 L
.16492 .33003 L
.16492 .33003 L
.16492 .32032 L
.17463 .31061 L
.17463 .31061 L
.17463 .30089 L
.17463 .29118 L
.18434 .28147 L
.18434 .28147 L
.18434 .27176 L
.19406 .26204 L
.19406 .26204 L
.19406 .25233 L
.20377 .24262 L
.20377 .24262 L
.20377 .23291 L
.21348 .22319 L
.21348 .22319 L
.21348 .21348 L
.22319 .20377 L
.22319 .20377 L
.23291 .19406 L
.23291 .19406 L
.23291 .18434 L
.24262 .17463 L
.24262 .17463 L
.24262 .16492 L
.25233 .15521 L
.25233 .15521 L
.26204 .14549 L
.26204 .14549 L
.26204 .13578 L
.27176 .12607 L
.27176 .12607 L
.28147 .11636 L
.28147 .11636 L
.29118 .10664 L
.29118 .10664 L
.30089 .09693 L
.30089 .09693 L
.30089 .08722 L
.31061 .07751 L
.31061 .07751 L
.32032 .06779 L
.33003 .06779 L
.33003 .06779 L
.33974 .05808 L
.33974 .05808 L
.34946 .04837 L
.34946 .04837 L
.35917 .03866 L
.36888 .03866 L
.36888 .03866 L
.37859 .02894 L
.38831 .02894 L
.38831 .02894 L
F
0 g
.39802 .01923 m
.40773 .01923 L
.41744 .01923 L
.42716 .01923 L
.43687 .01923 L
.44658 .01923 L
.45629 .01923 L
.46601 .01923 L
.47572 .01923 L
.48543 .02894 L
.48543 .02894 L
.49514 .02894 L
.50486 .02894 L
.51457 .03866 L
.51457 .03866 L
.52428 .04837 L
.52428 .04837 L
.53399 .05808 L
.53399 .05808 L
.54371 .05808 L
.55342 .06779 L
.55342 .06779 L
.56313 .07751 L
.56313 .07751 L
.57284 .08722 L
.57284 .09693 L
.57284 .09693 L
.58256 .10664 L
.58256 .10664 L
.59227 .11636 L
.59227 .11636 L
.60198 .12607 L
.60198 .12607 L
.61169 .13578 L
.61169 .14549 L
.61169 .14549 L
.62141 .15521 L
.62141 .15521 L
.63112 .16492 L
.63112 .17463 L
.63112 .17463 L
.64083 .18434 L
.64083 .19406 L
.64083 .19406 L
.65054 .20377 L
.65054 .20377 L
.66026 .21348 L
.66026 .22319 L
.66026 .22319 L
.66997 .23291 L
Mistroke
.66997 .24262 L
.66997 .24262 L
.67968 .25233 L
.67968 .26204 L
.67968 .26204 L
.68939 .27176 L
.68939 .28147 L
.68939 .28147 L
.69911 .29118 L
.69911 .30089 L
.69911 .30089 L
.70882 .31061 L
.70882 .32032 L
.70882 .33003 L
.70882 .33003 L
.71853 .33974 L
.71853 .34946 L
.71853 .34946 L
.72824 .35917 L
.72824 .36888 L
.72824 .36888 L
.73796 .37859 L
.73796 .38831 L
.73796 .39802 L
.73796 .39802 L
.74767 .40773 L
.74767 .41744 L
.74767 .41744 L
.75738 .42716 L
.75738 .43687 L
.75738 .44658 L
.75738 .44658 L
.76709 .45629 L
.76709 .46601 L
.76709 .47572 L
.76709 .47572 L
.77681 .48543 L
.77681 .49514 L
.77681 .50486 L
.77681 .50486 L
.78652 .51457 L
.78652 .52428 L
.78652 .53399 L
.78652 .53399 L
.79623 .54371 L
.79623 .55342 L
.79623 .56313 L
.79623 .56313 L
.80594 .57284 L
.80594 .58256 L
Mistroke
.80594 .59227 L
.80594 .59227 L
.81566 .60198 L
.81566 .61169 L
.81566 .62141 L
.81566 .62141 L
.82537 .63112 L
.82537 .64083 L
.82537 .65054 L
.82537 .65054 L
.83508 .66026 L
.83508 .66997 L
.83508 .67968 L
.83508 .67968 L
.84479 .68939 L
.84479 .69911 L
.84479 .70882 L
.84479 .71853 L
.84479 .71853 L
.85451 .72824 L
.85451 .73796 L
.85451 .74767 L
.85451 .74767 L
.86422 .75738 L
.86422 .76709 L
.86422 .77681 L
.86422 .78652 L
.86422 .78652 L
.87393 .79623 L
.87393 .80594 L
.87393 .81566 L
.87393 .82537 L
.87393 .82537 L
.88364 .83508 L
.88364 .84479 L
.88364 .85451 L
.88364 .85451 L
.89336 .86422 L
.89336 .87393 L
.89336 .88364 L
.88364 .89336 L
.87393 .89336 L
.86422 .89336 L
.85451 .88364 L
.85451 .88364 L
.84479 .88364 L
.83508 .88364 L
.82537 .87393 L
.82537 .87393 L
.81566 .87393 L
Mistroke
.80594 .87393 L
.79623 .87393 L
.78652 .86422 L
.78652 .86422 L
.77681 .86422 L
.76709 .86422 L
.75738 .85451 L
.75738 .85451 L
.74767 .85451 L
.73796 .85451 L
.72824 .84479 L
.72824 .84479 L
.71853 .84479 L
.70882 .84479 L
.69911 .84479 L
.68939 .83508 L
.68939 .83508 L
.67968 .83508 L
.66997 .83508 L
.66026 .82537 L
.66026 .82537 L
.65054 .82537 L
.64083 .82537 L
.63112 .82537 L
.62141 .81566 L
.62141 .81566 L
.61169 .81566 L
.60198 .81566 L
.59227 .80594 L
.59227 .80594 L
.58256 .80594 L
.57284 .80594 L
.56313 .79623 L
.56313 .79623 L
.55342 .79623 L
.54371 .79623 L
.53399 .79623 L
.52428 .78652 L
.52428 .78652 L
.51457 .78652 L
.50486 .78652 L
.49514 .77681 L
.49514 .77681 L
.48543 .77681 L
.47572 .77681 L
.46601 .77681 L
.45629 .76709 L
.45629 .76709 L
.44658 .76709 L
.43687 .76709 L
Mistroke
.42716 .75738 L
.42716 .75738 L
.41744 .75738 L
.40773 .75738 L
.39802 .74767 L
.39802 .74767 L
.38831 .74767 L
.37859 .74767 L
.36888 .74767 L
.35917 .73796 L
.35917 .73796 L
.34946 .73796 L
.33974 .73796 L
.33003 .72824 L
.33003 .72824 L
.32032 .72824 L
.31061 .72824 L
.30089 .72824 L
.29118 .71853 L
.29118 .71853 L
.28147 .71853 L
.27176 .71853 L
.26204 .70882 L
.26204 .70882 L
.25233 .70882 L
.24262 .70882 L
.23291 .69911 L
.23291 .69911 L
.22319 .69911 L
.21348 .69911 L
.20377 .69911 L
.19406 .68939 L
.19406 .68939 L
.18434 .68939 L
.17463 .68939 L
.16492 .67968 L
.16492 .67968 L
.15521 .67968 L
.14549 .67968 L
.13578 .67968 L
.12607 .66997 L
.12607 .66997 L
.11636 .66997 L
.10664 .66997 L
.09693 .66026 L
.09693 .66026 L
.08722 .66026 L
.07751 .66026 L
.06779 .65054 L
.06779 .65054 L
Mistroke
.05808 .65054 L
.04837 .64083 L
.04837 .63112 L
.05808 .62141 L
.05808 .62141 L
.05808 .61169 L
.05808 .60198 L
.06779 .59227 L
.06779 .59227 L
.06779 .58256 L
.06779 .57284 L
.07751 .56313 L
.07751 .56313 L
.07751 .55342 L
.07751 .54371 L
.08722 .53399 L
.08722 .53399 L
.08722 .52428 L
.08722 .51457 L
.09693 .50486 L
.09693 .50486 L
.09693 .49514 L
.09693 .48543 L
.10664 .47572 L
.10664 .47572 L
.10664 .46601 L
.10664 .45629 L
.11636 .44658 L
.11636 .44658 L
.11636 .43687 L
.12607 .42716 L
.12607 .42716 L
.12607 .41744 L
.12607 .40773 L
.13578 .39802 L
.13578 .39802 L
.13578 .38831 L
.14549 .37859 L
.14549 .37859 L
.14549 .36888 L
.14549 .35917 L
.15521 .34946 L
.15521 .34946 L
.15521 .33974 L
.16492 .33003 L
.16492 .33003 L
.16492 .32032 L
.17463 .31061 L
.17463 .31061 L
.17463 .30089 L
Mistroke
.17463 .29118 L
.18434 .28147 L
.18434 .28147 L
.18434 .27176 L
.19406 .26204 L
.19406 .26204 L
.19406 .25233 L
.20377 .24262 L
.20377 .24262 L
.20377 .23291 L
.21348 .22319 L
.21348 .22319 L
.21348 .21348 L
.22319 .20377 L
.22319 .20377 L
.23291 .19406 L
.23291 .19406 L
.23291 .18434 L
.24262 .17463 L
.24262 .17463 L
.24262 .16492 L
.25233 .15521 L
.25233 .15521 L
.26204 .14549 L
.26204 .14549 L
.26204 .13578 L
.27176 .12607 L
.27176 .12607 L
.28147 .11636 L
.28147 .11636 L
.29118 .10664 L
.29118 .10664 L
.30089 .09693 L
.30089 .09693 L
.30089 .08722 L
.31061 .07751 L
.31061 .07751 L
.32032 .06779 L
.33003 .06779 L
.33003 .06779 L
.33974 .05808 L
.33974 .05808 L
.34946 .04837 L
.34946 .04837 L
.35917 .03866 L
.36888 .03866 L
.36888 .03866 L
.37859 .02894 L
.38831 .02894 L
.38831 .02894 L
Mistroke
.39802 .01923 L
Mfstroke
.633 g
.40773 .07662 m
.41744 .07444 L
.42716 .07309 L
.43687 .0726 L
.44658 .07295 L
.45629 .07414 L
.46601 .07617 L
.47095 .07751 L
.47572 .07905 L
.48543 .08278 L
.4949 .08722 L
.49514 .08734 L
.50486 .09276 L
.51148 .09693 L
.51457 .09902 L
.52428 .10613 L
.52494 .10664 L
.53399 .1141 L
.53657 .11636 L
.54371 .12292 L
.54696 .12607 L
.55342 .1326 L
.55643 .13578 L
.56313 .14315 L
.56518 .14549 L
.57284 .15457 L
.57336 .15521 L
.58106 .16492 L
.58256 .16687 L
.58835 .17463 L
.59227 .18005 L
.5953 .18434 L
.60193 .19406 L
.60198 .19413 L
.6083 .20377 L
.61169 .20912 L
.61442 .21348 L
.62032 .22319 L
.62141 .22502 L
.62602 .23291 L
.63112 .24186 L
.63155 .24262 L
.6369 .25233 L
.64083 .25965 L
.6421 .26204 L
.64716 .27176 L
.65054 .27841 L
.65208 .28147 L
.65687 .29118 L
.66026 .29818 L
.66155 .30089 L
.66612 .31061 L
.66997 .31899 L
.67057 .32032 L
.67493 .33003 L
.67919 .33974 L
.67968 .34088 L
.68336 .34946 L
.68743 .35917 L
.68939 .36391 L
.69143 .36888 L
.69533 .37859 L
.69911 .38817 L
.69916 .38831 L
.70291 .39802 L
.70658 .40773 L
.70882 .41375 L
.71018 .41744 L
.7137 .42716 L
.71715 .43687 L
.71853 .44083 L
.72052 .44658 L
.72383 .45629 L
.72706 .46601 L
.72824 .46962 L
.73022 .47572 L
.73331 .48543 L
.73632 .49514 L
.73796 .50052 L
.73926 .50486 L
.74212 .51457 L
.74491 .52428 L
.74761 .53399 L
.74767 .53421 L
.75023 .54371 L
.75276 .55342 L
.7552 .56313 L
.75738 .57217 L
.75754 .57284 L
.75978 .58256 L
.7619 .59227 L
.76391 .60198 L
.76578 .61169 L
.76709 .61899 L
.76751 .62141 L
.76907 .63112 L
.77046 .64083 L
.77163 .65054 L
.77258 .66026 L
.77324 .66997 L
.77358 .67968 L
.77352 .68939 L
.77297 .69911 L
.77181 .70882 L
.76985 .71853 L
.76709 .72741 L
.76677 .72824 L
.76209 .73796 L
.75738 .74472 L
.7548 .74767 L
.74767 .75396 L
.74243 .75738 L
.73796 .75972 L
.72824 .76349 L
.71853 .76594 L
.71186 .76709 L
.70882 .76747 L
.69911 .76831 L
.68939 .76862 L
.67968 .7685 L
.66997 .76804 L
.66026 .7673 L
.65799 .76709 L
.65054 .76631 L
.64083 .76512 L
.63112 .76376 L
.62141 .76224 L
.61169 .76059 L
.60198 .75881 L
.59453 .75738 L
.59227 .75694 L
.58256 .75496 L
.57284 .7529 L
.56313 .75076 L
.55342 .74854 L
.54968 .74767 L
.54371 .74626 L
.53399 .74391 L
.52428 .74151 L
.51457 .73905 L
.51033 .73796 L
.50486 .73653 L
.49514 .73397 L
.48543 .73136 L
.47572 .7287 L
.47408 .72824 L
.46601 .72599 L
.45629 .72324 L
.44658 .72045 L
.44001 .71853 L
.43687 .71761 L
.42716 .71473 L
.41744 .7118 L
.40773 .70882 L
.40771 .70882 L
.39802 .7058 L
.38831 .70273 L
.37859 .69961 L
.37703 .69911 L
.36888 .69644 L
.35917 .69321 L
.34946 .68992 L
.34793 .68939 L
.33974 .68656 L
.33003 .68313 L
.32048 .67968 L
.32032 .67962 L
.31061 .67603 L
.30089 .67233 L
.29483 .66997 L
.29118 .66852 L
.28147 .66459 L
.27176 .66051 L
.27117 .66026 L
.26204 .65626 L
.25233 .6518 L
.24969 .65054 L
.24262 .64709 L
.23291 .64208 L
.23058 .64083 L
.22319 .6367 L
.21395 .63112 L
.21348 .63082 L
.20377 .6243 L
.19981 .62141 L
.19406 .61689 L
.18807 .61169 L
.18434 .60815 L
.17853 .60198 L
.17463 .59728 L
.17095 .59227 L
.16507 .58256 L
.16492 .58227 L
.16062 .57284 L
.15736 .56313 L
.15521 .55396 L
.15511 .55342 L
.15368 .54371 L
.15294 .53399 L
.15279 .52428 L
.15312 .51457 L
.15387 .50486 L
.15498 .49514 L
.15521 .49339 L
.1564 .48543 L
.15809 .47572 L
.16002 .46601 L
.16216 .45629 L
.1645 .44658 L
.16492 .44493 L
.16702 .43687 L
.1697 .42716 L
.17253 .41744 L
.17463 .41055 L
.17551 .40773 L
.17862 .39802 L
.18186 .38831 L
.18434 .3811 L
.18523 .37859 L
.18871 .36888 L
.19232 .35917 L
.19406 .3546 L
.19605 .34946 L
.19989 .33974 L
.20377 .33024 L
.20385 .33003 L
.20794 .32032 L
.21215 .31061 L
.21348 .30758 L
.21648 .30089 L
.22094 .29118 L
.22319 .28639 L
.22554 .28147 L
.23028 .27176 L
.23291 .2665 L
.23517 .26204 L
.24021 .25233 L
.24262 .2478 L
.24542 .24262 L
.2508 .23291 L
.25233 .23021 L
.25638 .22319 L
.26204 .21368 L
.26217 .21348 L
.26818 .20377 L
.27176 .19817 L
.27444 .19406 L
.28098 .18434 L
.28147 .18363 L
.28783 .17463 L
.29118 .17005 L
.29504 .16492 L
.30089 .1574 L
.30266 .15521 L
.31061 .14567 L
.31076 .14549 L
.31944 .13578 L
.32032 .13484 L
.32884 .12607 L
.33003 .1249 L
.33916 .11636 L
.33974 .11584 L
.34946 .10765 L
.35073 .10664 L
.35917 .10034 L
.36412 .09693 L
.36888 .09388 L
.37859 .08829 L
.38063 .08722 L
.38831 .08355 L
.39802 .07966 L
.40455 .07751 L
F
0 g
.40773 .07662 m
.41744 .07444 L
.42716 .07309 L
.43687 .0726 L
.44658 .07295 L
.45629 .07414 L
.46601 .07617 L
.47095 .07751 L
.47572 .07905 L
.48543 .08278 L
.4949 .08722 L
.49514 .08734 L
.50486 .09276 L
.51148 .09693 L
.51457 .09902 L
.52428 .10613 L
.52494 .10664 L
.53399 .1141 L
.53657 .11636 L
.54371 .12292 L
.54696 .12607 L
.55342 .1326 L
.55643 .13578 L
.56313 .14315 L
.56518 .14549 L
.57284 .15457 L
.57336 .15521 L
.58106 .16492 L
.58256 .16687 L
.58835 .17463 L
.59227 .18005 L
.5953 .18434 L
.60193 .19406 L
.60198 .19413 L
.6083 .20377 L
.61169 .20912 L
.61442 .21348 L
.62032 .22319 L
.62141 .22502 L
.62602 .23291 L
.63112 .24186 L
.63155 .24262 L
.6369 .25233 L
.64083 .25965 L
.6421 .26204 L
.64716 .27176 L
.65054 .27841 L
.65208 .28147 L
.65687 .29118 L
.66026 .29818 L
Mistroke
.66155 .30089 L
.66612 .31061 L
.66997 .31899 L
.67057 .32032 L
.67493 .33003 L
.67919 .33974 L
.67968 .34088 L
.68336 .34946 L
.68743 .35917 L
.68939 .36391 L
.69143 .36888 L
.69533 .37859 L
.69911 .38817 L
.69916 .38831 L
.70291 .39802 L
.70658 .40773 L
.70882 .41375 L
.71018 .41744 L
.7137 .42716 L
.71715 .43687 L
.71853 .44083 L
.72052 .44658 L
.72383 .45629 L
.72706 .46601 L
.72824 .46962 L
.73022 .47572 L
.73331 .48543 L
.73632 .49514 L
.73796 .50052 L
.73926 .50486 L
.74212 .51457 L
.74491 .52428 L
.74761 .53399 L
.74767 .53421 L
.75023 .54371 L
.75276 .55342 L
.7552 .56313 L
.75738 .57217 L
.75754 .57284 L
.75978 .58256 L
.7619 .59227 L
.76391 .60198 L
.76578 .61169 L
.76709 .61899 L
.76751 .62141 L
.76907 .63112 L
.77046 .64083 L
.77163 .65054 L
.77258 .66026 L
.77324 .66997 L
Mistroke
.77358 .67968 L
.77352 .68939 L
.77297 .69911 L
.77181 .70882 L
.76985 .71853 L
.76709 .72741 L
.76677 .72824 L
.76209 .73796 L
.75738 .74472 L
.7548 .74767 L
.74767 .75396 L
.74243 .75738 L
.73796 .75972 L
.72824 .76349 L
.71853 .76594 L
.71186 .76709 L
.70882 .76747 L
.69911 .76831 L
.68939 .76862 L
.67968 .7685 L
.66997 .76804 L
.66026 .7673 L
.65799 .76709 L
.65054 .76631 L
.64083 .76512 L
.63112 .76376 L
.62141 .76224 L
.61169 .76059 L
.60198 .75881 L
.59453 .75738 L
.59227 .75694 L
.58256 .75496 L
.57284 .7529 L
.56313 .75076 L
.55342 .74854 L
.54968 .74767 L
.54371 .74626 L
.53399 .74391 L
.52428 .74151 L
.51457 .73905 L
.51033 .73796 L
.50486 .73653 L
.49514 .73397 L
.48543 .73136 L
.47572 .7287 L
.47408 .72824 L
.46601 .72599 L
.45629 .72324 L
.44658 .72045 L
.44001 .71853 L
Mistroke
.43687 .71761 L
.42716 .71473 L
.41744 .7118 L
.40773 .70882 L
.40771 .70882 L
.39802 .7058 L
.38831 .70273 L
.37859 .69961 L
.37703 .69911 L
.36888 .69644 L
.35917 .69321 L
.34946 .68992 L
.34793 .68939 L
.33974 .68656 L
.33003 .68313 L
.32048 .67968 L
.32032 .67962 L
.31061 .67603 L
.30089 .67233 L
.29483 .66997 L
.29118 .66852 L
.28147 .66459 L
.27176 .66051 L
.27117 .66026 L
.26204 .65626 L
.25233 .6518 L
.24969 .65054 L
.24262 .64709 L
.23291 .64208 L
.23058 .64083 L
.22319 .6367 L
.21395 .63112 L
.21348 .63082 L
.20377 .6243 L
.19981 .62141 L
.19406 .61689 L
.18807 .61169 L
.18434 .60815 L
.17853 .60198 L
.17463 .59728 L
.17095 .59227 L
.16507 .58256 L
.16492 .58227 L
.16062 .57284 L
.15736 .56313 L
.15521 .55396 L
.15511 .55342 L
.15368 .54371 L
.15294 .53399 L
.15279 .52428 L
Mistroke
.15312 .51457 L
.15387 .50486 L
.15498 .49514 L
.15521 .49339 L
.1564 .48543 L
.15809 .47572 L
.16002 .46601 L
.16216 .45629 L
.1645 .44658 L
.16492 .44493 L
.16702 .43687 L
.1697 .42716 L
.17253 .41744 L
.17463 .41055 L
.17551 .40773 L
.17862 .39802 L
.18186 .38831 L
.18434 .3811 L
.18523 .37859 L
.18871 .36888 L
.19232 .35917 L
.19406 .3546 L
.19605 .34946 L
.19989 .33974 L
.20377 .33024 L
.20385 .33003 L
.20794 .32032 L
.21215 .31061 L
.21348 .30758 L
.21648 .30089 L
.22094 .29118 L
.22319 .28639 L
.22554 .28147 L
.23028 .27176 L
.23291 .2665 L
.23517 .26204 L
.24021 .25233 L
.24262 .2478 L
.24542 .24262 L
.2508 .23291 L
.25233 .23021 L
.25638 .22319 L
.26204 .21368 L
.26217 .21348 L
.26818 .20377 L
.27176 .19817 L
.27444 .19406 L
.28098 .18434 L
.28147 .18363 L
.28783 .17463 L
Mistroke
.29118 .17005 L
.29504 .16492 L
.30089 .1574 L
.30266 .15521 L
.31061 .14567 L
.31076 .14549 L
.31944 .13578 L
.32032 .13484 L
.32884 .12607 L
.33003 .1249 L
.33916 .11636 L
.33974 .11584 L
.34946 .10765 L
.35073 .10664 L
.35917 .10034 L
.36412 .09693 L
.36888 .09388 L
.37859 .08829 L
.38063 .08722 L
.38831 .08355 L
.39802 .07966 L
.40455 .07751 L
.40773 .07662 L
Mfstroke
.397 g
.42716 .13426 m
.43687 .13363 L
.44658 .13393 L
.45629 .13514 L
.45998 .13578 L
.46601 .13727 L
.47572 .14033 L
.48543 .1443 L
.488 .14549 L
.49514 .14919 L
.50486 .15502 L
.50514 .15521 L
.51457 .16178 L
.51868 .16492 L
.52428 .16949 L
.53018 .17463 L
.53399 .17815 L
.54036 .18434 L
.54371 .18777 L
.54957 .19406 L
.55342 .19838 L
.55803 .20377 L
.56313 .20999 L
.5659 .21348 L
.57284 .22262 L
.57326 .22319 L
.58021 .23291 L
.58256 .23631 L
.5868 .24262 L
.59227 .25108 L
.59306 .25233 L
.59904 .26204 L
.60198 .26698 L
.60477 .27176 L
.61026 .28147 L
.61169 .28406 L
.61555 .29118 L
.62063 .30089 L
.62141 .3024 L
.62554 .31061 L
.63027 .32032 L
.63112 .32209 L
.63485 .33003 L
.63927 .33974 L
.64083 .34325 L
.64355 .34946 L
.64769 .35917 L
.65054 .36607 L
.65169 .36888 L
.65556 .37859 L
.65931 .38831 L
.66026 .39082 L
.66293 .39802 L
.66643 .40773 L
.6698 .41744 L
.66997 .41794 L
.67306 .42716 L
.67619 .43687 L
.6792 .44658 L
.67968 .44818 L
.68208 .45629 L
.68484 .46601 L
.68746 .47572 L
.68939 .48321 L
.68995 .48543 L
.6923 .49514 L
.69449 .50486 L
.69653 .51457 L
.69841 .52428 L
.69911 .52815 L
.7001 .53399 L
.7016 .54371 L
.70288 .55342 L
.70393 .56313 L
.70472 .57284 L
.70521 .58256 L
.70537 .59227 L
.70514 .60198 L
.70445 .61169 L
.70321 .62141 L
.70131 .63112 L
.69911 .63917 L
.69856 .64083 L
.69473 .65054 L
.68939 .66024 L
.68939 .66026 L
.68185 .66997 L
.67968 .6722 L
.67067 .67968 L
.66997 .68016 L
.66026 .68579 L
.65179 .68939 L
.65054 .68984 L
.64083 .69277 L
.63112 .69483 L
.62141 .69621 L
.61169 .69704 L
.60198 .69742 L
.59227 .69741 L
.58256 .69706 L
.57284 .69643 L
.56313 .69555 L
.55342 .69444 L
.54371 .69312 L
.53399 .69163 L
.52428 .68996 L
.52119 .68939 L
.51457 .68813 L
.50486 .68616 L
.49514 .68405 L
.48543 .68181 L
.4767 .67968 L
.47572 .67944 L
.46601 .67695 L
.45629 .67433 L
.44658 .6716 L
.44096 .66997 L
.43687 .66876 L
.42716 .66579 L
.41744 .6627 L
.41003 .66026 L
.40773 .65948 L
.39802 .65614 L
.38831 .65266 L
.3826 .65054 L
.37859 .64903 L
.36888 .64524 L
.35917 .64129 L
.35808 .64083 L
.34946 .63714 L
.33974 .63279 L
.33615 .63112 L
.33003 .62819 L
.32032 .62333 L
.31664 .62141 L
.31061 .61815 L
.30089 .61259 L
.29939 .61169 L
.29118 .60658 L
.28429 .60198 L
.28147 .60001 L
.27176 .59273 L
.27118 .59227 L
.26204 .58451 L
.25992 .58256 L
.25233 .57499 L
.25035 .57284 L
.24262 .56354 L
.24231 .56313 L
.23562 .55342 L
.23291 .54888 L
.23013 .54371 L
.22571 .53399 L
.22319 .52727 L
.22222 .52428 L
.21954 .51457 L
.21759 .50486 L
.21627 .49514 L
.21551 .48543 L
.21525 .47572 L
.21543 .46601 L
.21601 .45629 L
.21695 .44658 L
.21822 .43687 L
.21979 .42716 L
.22163 .41744 L
.22319 .4101 L
.22373 .40773 L
.22608 .39802 L
.22865 .38831 L
.23144 .37859 L
.23291 .37377 L
.23444 .36888 L
.23765 .35917 L
.24106 .34946 L
.24262 .3452 L
.24467 .33974 L
.24848 .33003 L
.25233 .32069 L
.25249 .32032 L
.2567 .31061 L
.26113 .30089 L
.26204 .29895 L
.26577 .29118 L
.27065 .28147 L
.27176 .27932 L
.27576 .27176 L
.28114 .26204 L
.28147 .26146 L
.28679 .25233 L
.29118 .24513 L
.29275 .24262 L
.29905 .23291 L
.30089 .23017 L
.30574 .22319 L
.31061 .21649 L
.31286 .21348 L
.32032 .20399 L
.3205 .20377 L
.32875 .19406 L
.33003 .19262 L
.33775 .18434 L
.33974 .18232 L
.34774 .17463 L
.34946 .17308 L
.35908 .16492 L
.35917 .16484 L
.36888 .15761 L
.37242 .15521 L
.37859 .15135 L
.38831 .14605 L
.38942 .14549 L
.39802 .1417 L
.40773 .13829 L
.41744 .13581 L
.41751 .13578 L
F
0 g
.42716 .13426 m
.43687 .13363 L
.44658 .13393 L
.45629 .13514 L
.45998 .13578 L
.46601 .13727 L
.47572 .14033 L
.48543 .1443 L
.488 .14549 L
.49514 .14919 L
.50486 .15502 L
.50514 .15521 L
.51457 .16178 L
.51868 .16492 L
.52428 .16949 L
.53018 .17463 L
.53399 .17815 L
.54036 .18434 L
.54371 .18777 L
.54957 .19406 L
.55342 .19838 L
.55803 .20377 L
.56313 .20999 L
.5659 .21348 L
.57284 .22262 L
.57326 .22319 L
.58021 .23291 L
.58256 .23631 L
.5868 .24262 L
.59227 .25108 L
.59306 .25233 L
.59904 .26204 L
.60198 .26698 L
.60477 .27176 L
.61026 .28147 L
.61169 .28406 L
.61555 .29118 L
.62063 .30089 L
.62141 .3024 L
.62554 .31061 L
.63027 .32032 L
.63112 .32209 L
.63485 .33003 L
.63927 .33974 L
.64083 .34325 L
.64355 .34946 L
.64769 .35917 L
.65054 .36607 L
.65169 .36888 L
.65556 .37859 L
Mistroke
.65931 .38831 L
.66026 .39082 L
.66293 .39802 L
.66643 .40773 L
.6698 .41744 L
.66997 .41794 L
.67306 .42716 L
.67619 .43687 L
.6792 .44658 L
.67968 .44818 L
.68208 .45629 L
.68484 .46601 L
.68746 .47572 L
.68939 .48321 L
.68995 .48543 L
.6923 .49514 L
.69449 .50486 L
.69653 .51457 L
.69841 .52428 L
.69911 .52815 L
.7001 .53399 L
.7016 .54371 L
.70288 .55342 L
.70393 .56313 L
.70472 .57284 L
.70521 .58256 L
.70537 .59227 L
.70514 .60198 L
.70445 .61169 L
.70321 .62141 L
.70131 .63112 L
.69911 .63917 L
.69856 .64083 L
.69473 .65054 L
.68939 .66024 L
.68939 .66026 L
.68185 .66997 L
.67968 .6722 L
.67067 .67968 L
.66997 .68016 L
.66026 .68579 L
.65179 .68939 L
.65054 .68984 L
.64083 .69277 L
.63112 .69483 L
.62141 .69621 L
.61169 .69704 L
.60198 .69742 L
.59227 .69741 L
.58256 .69706 L
Mistroke
.57284 .69643 L
.56313 .69555 L
.55342 .69444 L
.54371 .69312 L
.53399 .69163 L
.52428 .68996 L
.52119 .68939 L
.51457 .68813 L
.50486 .68616 L
.49514 .68405 L
.48543 .68181 L
.4767 .67968 L
.47572 .67944 L
.46601 .67695 L
.45629 .67433 L
.44658 .6716 L
.44096 .66997 L
.43687 .66876 L
.42716 .66579 L
.41744 .6627 L
.41003 .66026 L
.40773 .65948 L
.39802 .65614 L
.38831 .65266 L
.3826 .65054 L
.37859 .64903 L
.36888 .64524 L
.35917 .64129 L
.35808 .64083 L
.34946 .63714 L
.33974 .63279 L
.33615 .63112 L
.33003 .62819 L
.32032 .62333 L
.31664 .62141 L
.31061 .61815 L
.30089 .61259 L
.29939 .61169 L
.29118 .60658 L
.28429 .60198 L
.28147 .60001 L
.27176 .59273 L
.27118 .59227 L
.26204 .58451 L
.25992 .58256 L
.25233 .57499 L
.25035 .57284 L
.24262 .56354 L
.24231 .56313 L
.23562 .55342 L
Mistroke
.23291 .54888 L
.23013 .54371 L
.22571 .53399 L
.22319 .52727 L
.22222 .52428 L
.21954 .51457 L
.21759 .50486 L
.21627 .49514 L
.21551 .48543 L
.21525 .47572 L
.21543 .46601 L
.21601 .45629 L
.21695 .44658 L
.21822 .43687 L
.21979 .42716 L
.22163 .41744 L
.22319 .4101 L
.22373 .40773 L
.22608 .39802 L
.22865 .38831 L
.23144 .37859 L
.23291 .37377 L
.23444 .36888 L
.23765 .35917 L
.24106 .34946 L
.24262 .3452 L
.24467 .33974 L
.24848 .33003 L
.25233 .32069 L
.25249 .32032 L
.2567 .31061 L
.26113 .30089 L
.26204 .29895 L
.26577 .29118 L
.27065 .28147 L
.27176 .27932 L
.27576 .27176 L
.28114 .26204 L
.28147 .26146 L
.28679 .25233 L
.29118 .24513 L
.29275 .24262 L
.29905 .23291 L
.30089 .23017 L
.30574 .22319 L
.31061 .21649 L
.31286 .21348 L
.32032 .20399 L
.3205 .20377 L
.32875 .19406 L
Mistroke
.33003 .19262 L
.33775 .18434 L
.33974 .18232 L
.34774 .17463 L
.34946 .17308 L
.35908 .16492 L
.35917 .16484 L
.36888 .15761 L
.37242 .15521 L
.37859 .15135 L
.38831 .14605 L
.38942 .14549 L
.39802 .1417 L
.40773 .13829 L
.41744 .13581 L
.41751 .13578 L
.42716 .13426 L
Mfstroke
.161 g
.41744 .21158 m
.42716 .20955 L
.43687 .2086 L
.44658 .20874 L
.45629 .20996 L
.46601 .21225 L
.47006 .21348 L
.47572 .21562 L
.48543 .22007 L
.49116 .22319 L
.49514 .22562 L
.50486 .23229 L
.50568 .23291 L
.51457 .2401 L
.51743 .24262 L
.52428 .24908 L
.52751 .25233 L
.53399 .25927 L
.53645 .26204 L
.54371 .27074 L
.54452 .27176 L
.55191 .28147 L
.55342 .28355 L
.55874 .29118 L
.56313 .29781 L
.56511 .30089 L
.57106 .31061 L
.57284 .31365 L
.57665 .32032 L
.58191 .33003 L
.58256 .33126 L
.58688 .33974 L
.59157 .34946 L
.59227 .35094 L
.59601 .35917 L
.6002 .36888 L
.60198 .37318 L
.60416 .37859 L
.60789 .38831 L
.6114 .39802 L
.61169 .39886 L
.61469 .40773 L
.61777 .41744 L
.62062 .42716 L
.62141 .42996 L
.62325 .43687 L
.62566 .44658 L
.62782 .45629 L
.62973 .46601 L
.63112 .47405 L
.63138 .47572 L
.63274 .48543 L
.6338 .49514 L
.63452 .50486 L
.63486 .51457 L
.63478 .52428 L
.63422 .53399 L
.63308 .54371 L
.63127 .55342 L
.63112 .55411 L
.62864 .56313 L
.62496 .57284 L
.62141 .57997 L
.61989 .58256 L
.61287 .59227 L
.61169 .59362 L
.60282 .60198 L
.60198 .60264 L
.59227 .60902 L
.58703 .61169 L
.58256 .61364 L
.57284 .61698 L
.56313 .61934 L
.55342 .62092 L
.54991 .62141 L
.54371 .62185 L
.53399 .62223 L
.52428 .62214 L
.51457 .62163 L
.51141 .62141 L
.50486 .62074 L
.49514 .61951 L
.48543 .61796 L
.47572 .61612 L
.46601 .61398 L
.45677 .61169 L
.45629 .61157 L
.44658 .60888 L
.43687 .60592 L
.42716 .60267 L
.42518 .60198 L
.41744 .59914 L
.40773 .5953 L
.4006 .59227 L
.39802 .59113 L
.38831 .58659 L
.38029 .58256 L
.37859 .58166 L
.36888 .57627 L
.36314 .57284 L
.35917 .57036 L
.34946 .5638 L
.34852 .56313 L
.33974 .55648 L
.33602 .55342 L
.33003 .54815 L
.32536 .54371 L
.32032 .5385 L
.3163 .53399 L
.31061 .52694 L
.30864 .52428 L
.30222 .51457 L
.30089 .51231 L
.29691 .50486 L
.29257 .49514 L
.29118 .49155 L
.2891 .48543 L
.28641 .47572 L
.28443 .46601 L
.28308 .45629 L
.28231 .44658 L
.28207 .43687 L
.28231 .42716 L
.28301 .41744 L
.28412 .40773 L
.28564 .39802 L
.28753 .38831 L
.28979 .37859 L
.29118 .37322 L
.29239 .36888 L
.29535 .35917 L
.29866 .34946 L
.30089 .3434 L
.30231 .33974 L
.30633 .33003 L
.31061 .32055 L
.31071 .32032 L
.31549 .31061 L
.32032 .30158 L
.3207 .30089 L
.32637 .29118 L
.33003 .28534 L
.33257 .28147 L
.33937 .27176 L
.33974 .27125 L
.34689 .26204 L
.34946 .25896 L
.35531 .25233 L
.35917 .24827 L
.36492 .24262 L
.36888 .23902 L
.37623 .23291 L
.37859 .2311 L
.38831 .22445 L
.39036 .22319 L
.39802 .21901 L
.40773 .21473 L
.41104 .21348 L
F
0 g
.41744 .21158 m
.42716 .20955 L
.43687 .2086 L
.44658 .20874 L
.45629 .20996 L
.46601 .21225 L
.47006 .21348 L
.47572 .21562 L
.48543 .22007 L
.49116 .22319 L
.49514 .22562 L
.50486 .23229 L
.50568 .23291 L
.51457 .2401 L
.51743 .24262 L
.52428 .24908 L
.52751 .25233 L
.53399 .25927 L
.53645 .26204 L
.54371 .27074 L
.54452 .27176 L
.55191 .28147 L
.55342 .28355 L
.55874 .29118 L
.56313 .29781 L
.56511 .30089 L
.57106 .31061 L
.57284 .31365 L
.57665 .32032 L
.58191 .33003 L
.58256 .33126 L
.58688 .33974 L
.59157 .34946 L
.59227 .35094 L
.59601 .35917 L
.6002 .36888 L
.60198 .37318 L
.60416 .37859 L
.60789 .38831 L
.6114 .39802 L
.61169 .39886 L
.61469 .40773 L
.61777 .41744 L
.62062 .42716 L
.62141 .42996 L
.62325 .43687 L
.62566 .44658 L
.62782 .45629 L
.62973 .46601 L
.63112 .47405 L
Mistroke
.63138 .47572 L
.63274 .48543 L
.6338 .49514 L
.63452 .50486 L
.63486 .51457 L
.63478 .52428 L
.63422 .53399 L
.63308 .54371 L
.63127 .55342 L
.63112 .55411 L
.62864 .56313 L
.62496 .57284 L
.62141 .57997 L
.61989 .58256 L
.61287 .59227 L
.61169 .59362 L
.60282 .60198 L
.60198 .60264 L
.59227 .60902 L
.58703 .61169 L
.58256 .61364 L
.57284 .61698 L
.56313 .61934 L
.55342 .62092 L
.54991 .62141 L
.54371 .62185 L
.53399 .62223 L
.52428 .62214 L
.51457 .62163 L
.51141 .62141 L
.50486 .62074 L
.49514 .61951 L
.48543 .61796 L
.47572 .61612 L
.46601 .61398 L
.45677 .61169 L
.45629 .61157 L
.44658 .60888 L
.43687 .60592 L
.42716 .60267 L
.42518 .60198 L
.41744 .59914 L
.40773 .5953 L
.4006 .59227 L
.39802 .59113 L
.38831 .58659 L
.38029 .58256 L
.37859 .58166 L
.36888 .57627 L
.36314 .57284 L
Mistroke
.35917 .57036 L
.34946 .5638 L
.34852 .56313 L
.33974 .55648 L
.33602 .55342 L
.33003 .54815 L
.32536 .54371 L
.32032 .5385 L
.3163 .53399 L
.31061 .52694 L
.30864 .52428 L
.30222 .51457 L
.30089 .51231 L
.29691 .50486 L
.29257 .49514 L
.29118 .49155 L
.2891 .48543 L
.28641 .47572 L
.28443 .46601 L
.28308 .45629 L
.28231 .44658 L
.28207 .43687 L
.28231 .42716 L
.28301 .41744 L
.28412 .40773 L
.28564 .39802 L
.28753 .38831 L
.28979 .37859 L
.29118 .37322 L
.29239 .36888 L
.29535 .35917 L
.29866 .34946 L
.30089 .3434 L
.30231 .33974 L
.30633 .33003 L
.31061 .32055 L
.31071 .32032 L
.31549 .31061 L
.32032 .30158 L
.3207 .30089 L
.32637 .29118 L
.33003 .28534 L
.33257 .28147 L
.33937 .27176 L
.33974 .27125 L
.34689 .26204 L
.34946 .25896 L
.35531 .25233 L
.35917 .24827 L
.36492 .24262 L
Mistroke
.36888 .23902 L
.37623 .23291 L
.37859 .2311 L
.38831 .22445 L
.39036 .22319 L
.39802 .21901 L
.40773 .21473 L
.41104 .21348 L
.41744 .21158 L
Mfstroke
.42716 .32878 m
.43687 .32586 L
.44658 .32494 L
.45629 .32589 L
.46601 .3287 L
.46942 .33003 L
.47572 .33339 L
.48503 .33974 L
.48543 .34007 L
.49514 .34895 L
.49563 .34946 L
.50392 .35917 L
.50486 .36042 L
.51072 .36888 L
.51457 .37526 L
.51642 .37859 L
.52124 .38831 L
.52428 .39543 L
.52528 .39802 L
.52862 .40773 L
.53127 .41744 L
.53323 .42716 L
.53399 .43236 L
.53448 .43687 L
.53496 .44658 L
.53454 .45629 L
.53399 .46088 L
.53308 .46601 L
.53028 .47572 L
.52562 .48543 L
.52428 .48755 L
.51806 .49514 L
.51457 .49827 L
.50486 .50445 L
.50408 .50486 L
.49514 .50806 L
.48543 .50987 L
.47572 .51028 L
.46601 .5095 L
.45629 .50764 L
.44693 .50486 L
.44658 .50472 L
.43687 .50073 L
.42716 .49554 L
.4265 .49514 L
.41744 .48895 L
.41308 .48543 L
.40773 .48053 L
.40316 .47572 L
.39802 .46941 L
.3956 .46601 L
.38981 .45629 L
.38831 .45328 L
.38549 .44658 L
.38241 .43687 L
.38044 .42716 L
.37947 .41744 L
.37946 .40773 L
.38036 .39802 L
.38219 .38831 L
.38498 .37859 L
.38831 .37004 L
.38883 .36888 L
.39392 .35917 L
.39802 .35294 L
.40063 .34946 L
.40773 .34168 L
.40978 .33974 L
.41744 .33391 L
.42415 .33003 L
F
.42716 .32878 m
.43687 .32586 L
.44658 .32494 L
.45629 .32589 L
.46601 .3287 L
.46942 .33003 L
.47572 .33339 L
.48503 .33974 L
.48543 .34007 L
.49514 .34895 L
.49563 .34946 L
.50392 .35917 L
.50486 .36042 L
.51072 .36888 L
.51457 .37526 L
.51642 .37859 L
.52124 .38831 L
.52428 .39543 L
.52528 .39802 L
.52862 .40773 L
.53127 .41744 L
.53323 .42716 L
.53399 .43236 L
.53448 .43687 L
.53496 .44658 L
.53454 .45629 L
.53399 .46088 L
.53308 .46601 L
.53028 .47572 L
.52562 .48543 L
.52428 .48755 L
.51806 .49514 L
.51457 .49827 L
.50486 .50445 L
.50408 .50486 L
.49514 .50806 L
.48543 .50987 L
.47572 .51028 L
.46601 .5095 L
.45629 .50764 L
.44693 .50486 L
.44658 .50472 L
.43687 .50073 L
.42716 .49554 L
.4265 .49514 L
.41744 .48895 L
.41308 .48543 L
.40773 .48053 L
.40316 .47572 L
.39802 .46941 L
Mistroke
.3956 .46601 L
.38981 .45629 L
.38831 .45328 L
.38549 .44658 L
.38241 .43687 L
.38044 .42716 L
.37947 .41744 L
.37946 .40773 L
.38036 .39802 L
.38219 .38831 L
.38498 .37859 L
.38831 .37004 L
.38883 .36888 L
.39392 .35917 L
.39802 .35294 L
.40063 .34946 L
.40773 .34168 L
.40978 .33974 L
.41744 .33391 L
.42415 .33003 L
.42716 .32878 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00a_ooool2o`0000;ooooo0_l0002Looooo`00a_ooool01_o^k^ko8B4Q
ohN7Qonj^[[o0000omgMgIcooooo0037ooooo`04omgMgOl0003o410@olc<c9gooooo0037ooooo`04
onk^k_lQ8B7o410@onk^kYgooooo0037ooooo`04ob4Q8OmgMgOoMgMgoc8b<Ygooooo0036ooooo`;o
00000_ooool2o`0009cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000cooooo`Co000000?o410@ooooooooool0<_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd0<?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03Gooooo1?l000000ol@413ooooooooo
o`0Zooooo`00=Oooool00ol0003oooooooooo`0dooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0;oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0fooooo`03
o`000?oooooooooo02cooooo000Zooooo`Ko00001Oooool00ol0003oooooooooo`0/ooooo`Ko0000
0_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0;_ooool01Ol@413o
oooooooooooooooo410@03Gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool0;?ooool003Gooooo00?o0000ooooooooool0=?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0;oooool01Ol0003ooooooooooooo
oooo000003Gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo03Kooooo
00?o0000ooooooooool0;?ooool003Gooooo00?o0000ooooooooool0=?ooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00`ooooo`05o`000?oooooooooooooo
ool00000=Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00gooooo`03o`000?oooooooooo02cooooo000eooooo`03o`000?oooooooooo03Cooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo03;ooooo00Go410@oooooooooooooooo
oa0@400eooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo02cooooo000eooooo`03o`000?oooooooooo03Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03o`000?oooooooooo03;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0eoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo02cooooo000cooooo`03oeEEEOmVIVKo000003Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co0000<Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Gooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co0000=_ooool00omEEEGoIVIVo`00000^ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00:oooooooo`0003go00000Ooo
ool002_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool00oooool1o`00007ooooo000[ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`3oooooocWooooo0Ol00001ooooo`00
8?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0ooooooliooooo`7o
00000Oooool0023ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oo
oooo>Oooool1o`00007ooooo000Pooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`0007[o
oooo6_l0002Rooooo`?o00000Oooool0023ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00?oooooMooNg]h00ol0003oooooooooo`0Fooooo`03o`000?oNg]kog]kN09co
g]kN1_ooool1o`00007ooooo000Pooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`03ooooogKog]kN00?o0000ooooooooool06?ooool00ol0003og]kNomkNgP2KomkNgPKo
oooo0Ol00001ooooo`008?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooooooo
ool00ooooomeomkNgP03o`000?oooooooooo01[ooooo0_l0002KomkNgPKooooo0Ol00001ooooo`00
8?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool00ooooomaomkNgPCo
00007_ooool7o`0009Gog]kN1_ooool1o`00007ooooo000Pooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oooooooooo`03ooooog3og]kN00?o0000ooooooooool09oooool00ol0003o
g]kNomkNgP2BomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooofkog]kN
0_l0000[ooooo`;o0000T_oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooo
oom[omkNgPCo0000;Oooool00ol0003og]kNomkNgP2@omkNgPKooooo0Ol00001ooooo`00:oooool0
0ol0003oooooooooo`03ooooof[og]kN00?o0000ooooooooool0<?ooool00ol0003og]kNomkNgP2?
omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooofSog]kN0_l0000doooo
o`;o0000SooNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooomXomkNgP03
o`000?oooooooooo03Cooooo00?o0000omkNg_oNg]h0SOoNg]h6ooooo`7o00000Oooool002_ooooo
00?o0000ooooooooool00ooooomWomkNgP03o`000?oooooooooo03Kooooo00?o0000omkNg_oNg]h0
S?oNg]h6ooooo`7o00000Oooool002_ooooo0_l00004ooooofKog]kN00?o0000ooooooooool0>?oo
ool00ol0003og]kNomkNgP2;omkNgPGooooo0_l00001ooooo`00:oooool00ol0003oooooooooo`03
ooooofGog]kN00?o0000ooooooooool0>_ooool4o`0008Wog]kN1_ooool1o`00007ooooo000[oooo
o`03o`000?oooooooooo00?oooooI?oNg]h00ol0003oooooooooo`0oooooo`03o`000?oNg]kog]kN
08Kog]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?oooooHooNg]h00ol0003o
ooooooooo`11ooooo`03o`000?oNg]kog]kN08Gog]kN1_ooool1o`00007ooooo000[ooooo`03o`00
0?oooooooooo00?oooooGooNg]h4o`0004Gooooo0_l00025omkNgPKooooo0Ol00001ooooo`00:ooo
ool00ol0003oooooooooo`03oooooekog]kN00?o0000ooooooooool07oooool:o`00023ooooo00?o
0000omkNg_oNg]h0P_oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooomM
omkNgP03o`000?oooooooooo01gooooo0ol0000:oj:RXPCo00007Oooool00ol0003og]kNomkNgP21
omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooecog]kN00?o0000oooo
ooooool06_ooool4o`00017oXZ:R1Ol0000Iooooo`03o`000?oNg]kog]kN083og]kN1_ooool1o`00
007ooooo000[ooooo`03o`000?oooooooooo00?oooooFooNg]h00ol0003oooooooooo`0Hooooo`?o
00006_nRXZ82o`0001Sooooo00?o0000omkNg_oNg]h0OooNg]h6ooooo`7o00000Oooool002_ooooo
00?o0000ooooooooool00ooooomJomkNgP03o`000?oooooooooo01Kooooo0ol0000Ooj:RXP03o`00
0?oooooooooo01Kooooo00?o0000omkNg_oNg]h0O_oNg]h6ooooo`7o00000Oooool002_ooooo00?o
0000ooooooooool00ooooomIomkNgP03o`000?oooooooooo01Cooooo0ol0000Soj:RXP;o00005ooo
ool00ol0003og]kNomkNgP1momkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03
oooooeWog]kN00?o0000ooooooooool04oooool00ol0003oXZ:Roj:RXP0Voj:RXP03o`000?oooooo
oooo01Cooooo00?o0000omkNg_oNg]h0OOoNg]h6ooooo`7o00000Oooool002_ooooo0_l00004oooo
oeWog]kN00?o0000ooooooooool04_ooool00ol0003oXZ:Roj:RXP0Xoj:RXP;o00005?ooool00ol0
003og]kNomkNgP1momkNgPGooooo0_l00001ooooo`00:oooool00ol0003oooooooooo`03oooooeWo
g]kN00?o0000ooooooooool04?ooool2o`0002goXZ:R00?o0000ooooooooool04Oooool00ol0003o
g]kNomkNgP1momkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooeSog]kN
00?o0000ooooooooool04?ooool00ol0003oXZ:Roj:RXP0^oj:RXP;o00004_ooool00ol0003og]kN
omkNgP1lomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooeOog]kN00?o
0000ooooooooool04?ooool00ol0003oXZ:Roj:RXP0aoj:RXP03o`000?oooooooooo013ooooo00?o
0000omkNg_oNg]h0NooNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooomF
omkNgP03o`000?oooooooooo00oooooo0_l0000eoj:RXP;o00004Oooool00ol0003og]kNomkNgP1j
omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooeGog]kN00?o0000oooo
ooooool03oooool00ol0003oXZ:Roj:RXP0goj:RXP03o`000?oooooooooo00oooooo00?o0000omkN
g_oNg]h0NOoNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooomDomkNgP03
o`000?oooooooooo00oooooo00?o0000oj:RX_nRXZ80>OnRXZ800ol0003oooooooooo`0?ooooo`03
o`000?oNg]kog]kN07Sog]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo
DooNg]h00ol0003oooooooooo`0?ooooo`03o`000?nRXZ;oXZ:R03_oXZ:R00?o0000ooooooooool0
3oooool00ol0003og]kNomkNgP1gomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003ooooooooo
o`03oooooe;og]kN00?o0000ooooooooool03oooool00ol0003oXZ:Roj:RXP0moj:RXP03o`000?oo
oooooooo00oooooo00?o0000omkNg_oNg]h0M_oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000
ooooooooool00ooooomAomkNgP03o`000?oooooooooo00oooooo00?o0000oj:RX_nRXZ80?onRXZ80
0ol0003oooooooooo`0?ooooo`03o`000?oNg]kog]kN07Gog]kN1_ooool1o`00007ooooo000[oooo
o`03o`000?oooooooooo00?oooooD?oNg]h00ol0003oooooooooo`0?ooooo`03o`000?nRXZ;oXZ:R
047oXZ:R00?o0000ooooooooool03oooool00ol0003og]kNomkNgP1domkNgPKooooo0Ol00001oooo
o`00:oooool2o`0000CoooooCooNg]h00ol0003oooooooooo`0?ooooo`03o`000?nRXZ;oXZ:R04?o
XZ:R00?o0000ooooooooool03oooool00ol0003og]kNomkNgP1comkNgPGooooo0_l00001ooooo`00
:oooool00ol0003oooooooooo`03ooooodkog]kN00?o0000ooooooooool03oooool00ol0003oXZ:R
oj:RXP15oj:RXP03o`000?oooooooooo00oooooo00?o0000omkNg_oNg]h0L_oNg]h6ooooo`7o0000
0Oooool002_ooooo00?o0000ooooooooool00ooooom=omkNgP03o`000?oooooooooo00oooooo00?o
0000oj:RX_nRXZ806onRXZ8@o`0001coXZ:R00?o0000ooooooooool03oooool00ol0003og]kNomkN
gP1aomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooodgog]kN00?o0000
ooooooooool03_ooool00ol0003oXZ:Roj:RXP0Hoj:RXPCo00004?mUIFD3o`0001[oXZ:R00?o0000
ooooooooool03_ooool00ol0003og]kNomkNgP1aomkNgPKooooo0Ol00001ooooo`00:oooool00ol0
003oooooooooo`03ooooodgog]kN00?o0000ooooooooool03Oooool00ol0003oXZ:Roj:RXP0Foj:R
XP?o00005omUIFD3o`0001SoXZ:R00?o0000ooooooooool03Oooool00ol0003og]kNomkNgP1aomkN
gPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooodgog]kN00?o0000oooooooo
ool03?ooool00ol0003oXZ:Roj:RXP0Doj:RXP?o00007OmUIFD3o`0001KoXZ:R00?o0000oooooooo
ool03?ooool00ol0003og]kNomkNgP1aomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003ooooo
ooooo`03ooooodcog]kN00?o0000ooooooooool03?ooool00ol0003oXZ:Roj:RXP0Doj:RXP03o`00
0?mUIFGoIFEU027oIFEU0_l0000Eoj:RXP03o`000?oooooooooo00cooooo00?o0000omkNg_oNg]h0
L?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooom;omkNgP03o`000?oo
oooooooo00cooooo00?o0000oj:RX_nRXZ804onRXZ82o`0002KoIFEU00?o0000oj:RX_nRXZ804onR
XZ800ol0003oooooooooo`0<ooooo`03o`000?oNg]kog]kN06oog]kN1_ooool1o`00007ooooo000[
ooooo`03o`000?oooooooooo00?oooooBOoNg]h2o`0000kooooo00?o0000oj:RX_nRXZ804onRXZ80
0ol0003oIFEUofEUI@0WofEUI@;o00005?nRXZ800ol0003oooooooooo`0<ooooo`03o`000?oNg]ko
g]kN06kog]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?oooooB?oNg]h00ol0
003oooooooooo`0>ooooo`03o`000?nRXZ;oXZ:R017oXZ:R0_l0000/ofEUI@03o`000?nRXZ;oXZ:R
017oXZ:R00?o0000ooooooooool03Oooool00ol0003og]kNomkNgP1]omkNgPKooooo0Ol00001oooo
o`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0
003oooooooooo`03ooooodOog]kN00?o0000ooooooooool03_ooool00ol0003oXZ:Roj:RXP0Aoj:R
XP03o`000?mUIFGoIFEU02goIFEU0_l0000Boj:RXP03o`000?oooooooooo00gooooo00?o0000omkN
g_oNg]h0K?oNg]h6ooooo`7o00000Oooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool00ooooom6
omkNgP03o`000?oooooooooo00kooooo00?o0000oj:RX_nRXZ804OnRXZ800ol0003oIFEUofEUI@0`
ofEUI@03o`000?nRXZ;oXZ:R013oXZ:R00?o0000ooooooooool03Oooool00ol0003og]kNomkNgP1[
omkNgPKooooo0Ol00001ooooo`004?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RH
ob4Q8Oo^k^h01oooool3o`0000?oooooA_oNg]h00ol0003oooooooooo`0>ooooo`03o`000?nRXZ;o
XZ:R013oXZ:R00?o0000ofEUIOmUIFD0<OmUIFD00ol0003oXZ:Roj:RXP0Aoj:RXP03o`000?oooooo
oooo00cooooo00?o0000omkNg_oNg]h0JooNg]h4ooooo`?o00000Oooool0013ooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool00ooooom6
omkNgP03o`000?oooooooooo00gooooo00?o0000oj:RX_nRXZ804?nRXZ800ol0003oIFEUofEUI@0c
ofEUI@;o00004OnRXZ800ol0003oooooooooo`0<ooooo`03o`000?oNg]kog]kN06_og]kN1_ooool1
o`00007ooooo000@ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05
ooooo`03o`000?oooooooooo00?oooooA_oNg]h2o`0000gooooo00?o0000oj:RX_nRXZ804?nRXZ80
0ol0003oIFEUofEUI@0fofEUI@03o`000?nRXZ;oXZ:R00ooXZ:R00?o0000ooooooooool02oooool0
0ol0003og]kNomkNgP1[omkNgPKooooo0Ol00001ooooo`004?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooodKog]kN00?o0000
ooooooooool03?ooool00ol0003oXZ:Roj:RXP0?oj:RXP03o`000?mUIFGoIFEU03OoIFEU00?o0000
oj:RX_nRXZ804?nRXZ800ol0003oooooooooo`0:ooooo`03o`000?oNg]kog]kN06_og]kN1_ooool1
o`00007ooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@00Kooooo00?o0000ooooooooool00ooooom5omkNgP03o`000?oooooooooo00cooooo00?o
0000oj:RX_nRXZ803onRXZ800ol0003oIFEUofEUI@0iofEUI@03o`000?nRXZ;oXZ:R013oXZ:R00?o
0000ooooooooool02_ooool00ol0003og]kNomkNgP1ZomkNgPKooooo0Ol00001ooooo`004?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo00?oooooA?oNg]h00ol0003oooooooooo`0<ooooo`03o`000?nRXZ;oXZ:R00ooXZ:R
00?o0000ofEUIOmUIFD0>omUIFD00ol0003oXZ:Roj:RXP0?oj:RXP03o`000?oooooooooo00_ooooo
00?o0000omkNg_oNg]h0JOoNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooo
oom3omkNgP03o`000?oooooooooo00gooooo00?o0000oj:RX_nRXZ803_nRXZ800ol0003oIFEUofEU
I@0mofEUI@03o`000?nRXZ;oXZ:R00ooXZ:R00?o0000ooooooooool02oooool00ol0003og]kNomkN
gP1XomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooood?og]kN00?o0000
ooooooooool03?ooool00ol0003oXZ:Roj:RXP0>oj:RXP03o`000?mUIFGoIFEU03ooIFEU00?o0000
oj:RX_nRXZ803_nRXZ800ol0003oooooooooo`0;ooooo`03o`000?oNg]kog]kN06Sog]kN1_ooool1
o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo@ooNg]h2o`0000cooooo00?o0000oj:R
X_nRXZ803_nRXZ800ol0003oIFEUofEUI@11ofEUI@03o`000?nRXZ;oXZ:R00koXZ:R0_l0000;oooo
o`03o`000?oNg]kog]kN06Sog]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?o
oooo@ooNg]h00ol0003oooooooooo`0:ooooo`03o`000?nRXZ;oXZ:R00ooXZ:R00?o0000ofEUIOmU
IFD0@_mUIFD00ol0003oXZ:Roj:RXP0>oj:RXP03o`000?oooooooooo00Wooooo00?o0000omkNg_oN
g]h0J?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooom2omkNgP03o`00
0?oooooooooo00_ooooo00?o0000oj:RX_nRXZ803_nRXZ800ol0003oIFEUofEUI@14ofEUI@03o`00
0?nRXZ;oXZ:R00goXZ:R00?o0000ooooooooool02_ooool00ol0003og]kNomkNgP1WomkNgPKooooo
0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooood7og]kN00?o0000ooooooooool03?oo
ool00ol0003oXZ:Roj:RXP0=oj:RXP03o`000?mUIFGoIFEU04KoIFEU00?o0000oj:RX_nRXZ803OnR
XZ800ol0003oooooooooo`0:ooooo`;o0000IooNg]h6ooooo`7o00000Oooool002_ooooo0_l00004
oooood3og]kN00?o0000ooooooooool03?ooool00ol0003oXZ:Roj:RXP0=oj:RXP03o`000?mUIFGo
IFEU04SoIFEU00?o0000oj:RX_nRXZ803OnRXZ800ol0003oooooooooo`0:ooooo`03o`000?oNg]ko
g]kN06Gog]kN1Oooool2o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo?ooNg]h00ol0
003oooooooooo`0=ooooo`03o`000?nRXZ;oXZ:R00goXZ:R00?o0000ofEUIOmUIFD07_mUIFD:o`00
027oIFEU00?o0000oj:RX_nRXZ803OnRXZ800ol0003oooooooooo`0:ooooo`03o`000?oNg]kog]kN
06Cog]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo?_oNg]h00ol0003o
ooooooooo`0=ooooo`03o`000?nRXZ;oXZ:R00goXZ:R00?o0000ofEUIOmUIFD07?mUIFD3o`0000[o
:BTY1?l0000NofEUI@03o`000?nRXZ;oXZ:R00coXZ:R00?o0000ooooooooool02oooool00ol0003o
g]kNomkNgP1SomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooocgog]kN
00?o0000ooooooooool03Oooool00ol0003oXZ:Roj:RXP0=oj:RXP03o`000?mUIFGoIFEU01WoIFEU
1?l0000AobTY:@Co00006_mUIFD00ol0003oXZ:Roj:RXP0=oj:RXP03o`000?oooooooooo00_ooooo
00?o0000omkNg_oNg]h0H_oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooo
oolmomkNgP03o`000?oooooooooo00gooooo00?o0000oj:RX_nRXZ803?nRXZ800ol0003oIFEUofEU
I@0HofEUI@;o00006OlY:BT00ol0003oIFEUofEUI@0HofEUI@03o`000?nRXZ;oXZ:R00coXZ:R00?o
0000ooooooooool02oooool00ol0003og]kNomkNgP1RomkNgPKooooo0Ol00001ooooo`00:oooool0
0ol0003oooooooooo`03ooooocgog]kN00?o0000ooooooooool03?ooool00ol0003oXZ:Roj:RXP0<
oj:RXP03o`000?mUIFGoIFEU01SoIFEU00?o0000obTY:OlY:BT06_lY:BT2o`0001WoIFEU00?o0000
oj:RX_nRXZ803?nRXZ800ol0003oooooooooo`0:ooooo`03o`000?oNg]kog]kN06;og]kN1_ooool1
o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo?OoNg]h00ol0003oooooooooo`0;oooo
o`03o`000?nRXZ;oXZ:R00coXZ:R00?o0000ofEUIOmUIFD05_mUIFD3o`0001oo:BTY00?o0000ofEU
IOmUIFD05omUIFD00ol0003oXZ:Roj:RXP0<oj:RXP03o`000?oooooooooo00Wooooo00?o0000omkN
g_oNg]h0H_oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooollomkNgP03
o`000?oooooooooo00cooooo00?o0000oj:RX_nRXZ803?nRXZ800ol0003oIFEUofEUI@0EofEUI@03
o`000?lY:BWo:BTY027o:BTY0_l0000GofEUI@03o`000?nRXZ;oXZ:R00coXZ:R00?o0000oooooooo
ool02_ooool00ol0003og]kNomkNgP1QomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003ooooo
ooooo`03oooooc_og]kN00?o0000ooooooooool03?ooool00ol0003oXZ:Roj:RXP0<oj:RXP03o`00
0?mUIFGoIFEU01GoIFEU00?o0000obTY:OlY:BT09?lY:BT00ol0003oIFEUofEUI@0EofEUI@03o`00
0?nRXZ;oXZ:R00coXZ:R00?o0000ooooooooool02_ooool00ol0003og]kNomkNgP1PomkNgPKooooo
0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooc[og]kN00?o0000ooooooooool03?oo
ool00ol0003oXZ:Roj:RXP0<oj:RXP03o`000?mUIFGoIFEU01GoIFEU0_l0000WobTY:@;o00005_mU
IFD00ol0003oXZ:Roj:RXP0;oj:RXP03o`000?oooooooooo00_ooooo00?o0000omkNg_oNg]h0GooN
g]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00oooooljomkNgP03o`000?oooooo
oooo00cooooo00?o0000oj:RX_nRXZ803?nRXZ800ol0003oIFEUofEUI@0DofEUI@03o`000?lY:BWo
:BTY02Wo:BTY00?o0000ofEUIOmUIFD05?mUIFD00ol0003oXZ:Roj:RXP0:oj:RXP03o`000?oooooo
oooo00_ooooo00?o0000omkNg_oNg]h0GooNg]h6ooooo`7o00000Oooool002_ooooo0_l00004oooo
oc[og]kN00?o0000ooooooooool02oooool00ol0003oXZ:Roj:RXP0<oj:RXP03o`000?mUIFGoIFEU
01CoIFEU00?o0000obTY:OlY:BT0:olY:BT00ol0003oIFEUofEUI@0CofEUI@03o`000?nRXZ;oXZ:R
00_oXZ:R00?o0000ooooooooool02_ooool00ol0003og]kNomkNgP1OomkNgPGooooo0_l00001oooo
o`00:oooool00ol0003oooooooooo`03oooooc[og]kN00?o0000ooooooooool02_ooool00ol0003o
XZ:Roj:RXP0<oj:RXP03o`000?mUIFGoIFEU01CoIFEU00?o0000obTY:OlY:BT0;OlY:BT00ol0003o
IFEUofEUI@0CofEUI@03o`000?nRXZ;oXZ:R00_oXZ:R00?o0000ooooooooool02Oooool00ol0003o
g]kNomkNgP1OomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooocWog]kN
00?o0000ooooooooool02oooool00ol0003oXZ:Roj:RXP0<oj:RXP03o`000?mUIFGoIFEU01?oIFEU
00?o0000obTY:OlY:BT0;olY:BT00ol0003oIFEUofEUI@0BofEUI@03o`000?nRXZ;oXZ:R00_oXZ:R
00?o0000ooooooooool02_ooool00ol0003og]kNomkNgP1NomkNgPKooooo0Ol00001ooooo`00:ooo
ool00ol0003oooooooooo`03ooooocSog]kN00?o0000ooooooooool02oooool00ol0003oXZ:Roj:R
XP0<oj:RXP03o`000?mUIFGoIFEU01?oIFEU00?o0000obTY:OlY:BT0<OlY:BT00ol0003oIFEUofEU
I@0BofEUI@03o`000?nRXZ;oXZ:R00_oXZ:R00?o0000ooooooooool02_ooool00ol0003og]kNomkN
gP1MomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooocOog]kN00?o0000
ooooooooool03?ooool00ol0003oXZ:Roj:RXP0;oj:RXP03o`000?mUIFGoIFEU01?oIFEU00?o0000
obTY:OlY:BT0<olY:BT00ol0003oIFEUofEUI@0BofEUI@03o`000?nRXZ;oXZ:R00_oXZ:R00?o0000
ooooooooool02_ooool00ol0003og]kNomkNgP1LomkNgPKooooo0Ol00001ooooo`00:oooool00ol0
003oooooooooo`03ooooocOog]kN00?o0000ooooooooool03?ooool00ol0003oXZ:Roj:RXP0;oj:R
XP03o`000?mUIFGoIFEU01;oIFEU00?o0000obTY:OlY:BT0=OlY:BT00ol0003oIFEUofEUI@0AofEU
I@03o`000?nRXZ;oXZ:R00_oXZ:R00?o0000ooooooooool02_ooool00ol0003og]kNomkNgP1LomkN
gPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooocOog]kN00?o0000oooooooo
ool02oooool00ol0003oXZ:Roj:RXP0;oj:RXP03o`000?mUIFGoIFEU01;oIFEU00?o0000obTY:OlY
:BT0=olY:BT00ol0003oIFEUofEUI@0AofEUI@03o`000?nRXZ;oXZ:R00_oXZ:R00?o0000oooooooo
ool02Oooool00ol0003og]kNomkNgP1LomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003ooooo
ooooo`03ooooocOog]kN00?o0000ooooooooool02_ooool00ol0003oXZ:Roj:RXP0<oj:RXP03o`00
0?mUIFGoIFEU017oIFEU00?o0000obTY:OlY:BT0>OlY:BT00ol0003oIFEUofEUI@0AofEUI@03o`00
0?nRXZ;oXZ:R00[oXZ:R00?o0000ooooooooool02Oooool00ol0003og]kNomkNgP1LomkNgPKooooo
0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooocKog]kN00?o0000ooooooooool02_oo
ool00ol0003oXZ:Roj:RXP0=oj:RXP03o`000?mUIFGoIFEU017oIFEU00?o0000obTY:OlY:BT0>OlY
:BT00ol0003oIFEUofEUI@0AofEUI@03o`000?nRXZ;oXZ:R00[oXZ:R00?o0000ooooooooool02_oo
ool00ol0003og]kNomkNgP1KomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03
ooooocGog]kN00?o0000ooooooooool02oooool00ol0003oXZ:Roj:RXP0<oj:RXP03o`000?mUIFGo
IFEU017oIFEU00?o0000obTY:OlY:BT0>olY:BT00ol0003oIFEUofEUI@0AofEUI@03o`000?nRXZ;o
XZ:R00[oXZ:R00?o0000ooooooooool02_ooool00ol0003og]kNomkNgP1JomkNgPKooooo0Ol00001
ooooo`00:oooool00ol0003oooooooooo`03ooooocCog]kN00?o0000ooooooooool03?ooool00ol0
003oXZ:Roj:RXP0;oj:RXP03o`000?mUIFGoIFEU017oIFEU00?o0000obTY:OlY:BT0?OlY:BT2o`00
01;oIFEU00?o0000oj:RX_nRXZ802_nRXZ800ol0003oooooooooo`0:ooooo`03o`000?oNg]kog]kN
05Wog]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo=?oNg]h00ol0003o
ooooooooo`0<ooooo`03o`000?nRXZ;oXZ:R00_oXZ:R00?o0000ofEUIOmUIFD04OmUIFD00ol0003o
:BTYobTY:@0nobTY:@03o`000?mUIFGoIFEU013oIFEU00?o0000oj:RX_nRXZ802_nRXZ800ol0003o
ooooooooo`0:ooooo`03o`000?oNg]kog]kN05Wog]kN1_ooool1o`00007ooooo000[ooooo`;o0000
1?ooooldomkNgP03o`000?oooooooooo00_ooooo00?o0000oj:RX_nRXZ802onRXZ800ol0003oIFEU
ofEUI@0AofEUI@03o`000?lY:BWo:BTY043o:BTY00?o0000ofEUIOmUIFD04?mUIFD00ol0003oXZ:R
oj:RXP0:oj:RXP03o`000?oooooooooo00Wooooo00?o0000omkNg_oNg]h0FOoNg]h5ooooo`;o0000
0Oooool002_ooooo00?o0000ooooooooool00oooooldomkNgP03o`000?oooooooooo00[ooooo00?o
0000oj:RX_nRXZ802onRXZ800ol0003oIFEUofEUI@0AofEUI@03o`000?lY:BWo:BTY04;o:BTY00?o
0000ofEUIOmUIFD03omUIFD00ol0003oXZ:Roj:RXP0;oj:RXP03o`000?oooooooooo00Sooooo0_l0
001JomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooc?og]kN00?o0000
ooooooooool02oooool00ol0003oXZ:Roj:RXP0;oj:RXP03o`000?mUIFGoIFEU013oIFEU00?o0000
obTY:OlY:BT0@olY:BT00ol0003oIFEUofEUI@0@ofEUI@03o`000?nRXZ;oXZ:R00[oXZ:R00?o0000
ooooooooool02Oooool00ol0003og]kNomkNgP1HomkNgPKooooo0Ol00001ooooo`00:oooool00ol0
003oooooooooo`03oooooc;og]kN00?o0000ooooooooool02oooool00ol0003oXZ:Roj:RXP0;oj:R
XP03o`000?mUIFGoIFEU017oIFEU00?o0000obTY:OlY:BT0A?lY:BT00ol0003oIFEUofEUI@0?ofEU
I@03o`000?nRXZ;oXZ:R00_oXZ:R00?o0000ooooooooool02Oooool00ol0003og]kNomkNgP1GomkN
gPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooc7og]kN00?o0000oooooooo
ool03?ooool00ol0003oXZ:Roj:RXP0;oj:RXP03o`000?mUIFGoIFEU013oIFEU00?o0000obTY:OlY
:BT0A_lY:BT00ol0003oIFEUofEUI@0?ofEUI@03o`000?nRXZ;oXZ:R00[oXZ:R00?o0000oooooooo
ool02_ooool00ol0003og]kNomkNgP1FomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003ooooo
ooooo`03oooooc7og]kN00?o0000ooooooooool03?ooool00ol0003oXZ:Roj:RXP0;oj:RXP03o`00
0?mUIFGoIFEU013oIFEU00?o0000obTY:OlY:BT0AolY:BT00ol0003oIFEUofEUI@0>ofEUI@03o`00
0?nRXZ;oXZ:R00[oXZ:R00?o0000ooooooooool02_ooool00ol0003og]kNomkNgP1FomkNgPKooooo
0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooc7og]kN00?o0000ooooooooool02ooo
ool00ol0003oXZ:Roj:RXP0;oj:RXP03o`000?mUIFGoIFEU013oIFEU00?o0000obTY:OlY:BT0BOlY
:BT00ol0003oIFEUofEUI@0>ofEUI@03o`000?nRXZ;oXZ:R00[oXZ:R00?o0000ooooooooool02Ooo
ool00ol0003og]kNomkNgP1FomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03
oooooc7og]kN00?o0000ooooooooool02_ooool00ol0003oXZ:Roj:RXP0;oj:RXP;o00004OmUIFD0
0ol0003o:BTYobTY:@1:obTY:@03o`000?mUIFGoIFEU00ooIFEU00?o0000oj:RX_nRXZ802_nRXZ80
0ol0003oooooooooo`08ooooo`;o0000EooNg]h6ooooo`7o00000Oooool002_ooooo00?o0000oooo
ooooool00ooooolaomkNgP03o`000?oooooooooo00[ooooo00?o0000oj:RX_nRXZ802onRXZ800ol0
003oIFEUofEUI@0@ofEUI@03o`000?lY:BWo:BTY04[o:BTY00?o0000ofEUIOmUIFD03omUIFD00ol0
003oXZ:Roj:RXP0:oj:RXP03o`000?oooooooooo00Wooooo00?o0000omkNg_oNg]h0EOoNg]h6oooo
o`7o00000Oooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`00
0003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool00ooooolaomkNgP03o`000?oooooooooo
00Wooooo00?o0000oj:RX_nRXZ802onRXZ800ol0003oIFEUofEUI@0@ofEUI@03o`000?lY:BWo:BTY
04co:BTY00?o0000ofEUIOmUIFD03_mUIFD00ol0003oXZ:Roj:RXP0;oj:RXP03o`000?oooooooooo
00Wooooo00?o0000omkNg_oNg]h0E?oNg]h6ooooo`7o00000Oooool0013ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo<OoNg]h00ol0003oooooooooo`09ooooo`03o`000?nRXZ;oXZ:R00_oXZ:R00?o0000ofEU
IOmUIFD03omUIFD00ol0003o:BTYobTY:@1>obTY:@03o`000?mUIFGoIFEU00koIFEU00?o0000oj:R
X_nRXZ802_nRXZ800ol0003oooooooooo`0:ooooo`03o`000?oNg]kog]kN05?og]kN1_ooool1o`00
007ooooo000@ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo00?o0000oooo
ooooool00oooool`omkNgP03o`000?oooooooooo00[ooooo00?o0000oj:RX_nRXZ802onRXZ800ol0
003oIFEUofEUI@0?ofEUI@03o`000?lY:BWo:BTY04oo:BTY00?o0000ofEUIOmUIFD03OmUIFD00ol0
003oXZ:Roj:RXP0:oj:RXP03o`000?oooooooooo00[ooooo00?o0000omkNg_oNg]h0DooNg]h6oooo
o`7o00000Oooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgooooo
o`0000Oooooo0ol00003oooooboog]kN00?o0000ooooooooool02_ooool00ol0003oXZ:Roj:RXP0;
oj:RXP03o`000?mUIFGoIFEU00ooIFEU00?o0000obTY:OlY:BT0D?lY:BT00ol0003oIFEUofEUI@0>
ofEUI@03o`000?nRXZ;oXZ:R00[oXZ:R00?o0000ooooooooool02Oooool00ol0003og]kNomkNgP1C
omkNgPCooooo0ol00001ooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`03ooooobkog]kN00?o0000ooooooooool02ooo
ool00ol0003oXZ:Roj:RXP0;oj:RXP03o`000?mUIFGoIFEU00ooIFEU00?o0000obTY:OlY:BT0DOlY
:BT00ol0003oIFEUofEUI@0>ofEUI@03o`000?nRXZ;oXZ:R00WoXZ:R00?o0000ooooooooool02Ooo
ool00ol0003og]kNomkNgP1ComkNgPKooooo0Ol00001ooooo`004?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`03ooooobkog]kN00?o
0000ooooooooool02oooool00ol0003oXZ:Roj:RXP0;oj:RXP03o`000?mUIFGoIFEU00ooIFEU00?o
0000obTY:OlY:BT0DOlY:BT00ol0003oIFEUofEUI@0>ofEUI@03o`000?nRXZ;oXZ:R00WoXZ:R00?o
0000ooooooooool02Oooool00ol0003og]kNomkNgP1ComkNgPKooooo0Ol00001ooooo`004?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003ooooooooo
o`03ooooobkog]kN00?o0000ooooooooool02_ooool00ol0003oXZ:Roj:RXP0;oj:RXP03o`000?mU
IFGoIFEU00ooIFEU00?o0000obTY:OlY:BT09OlY:BT:o`0002Co:BTY00?o0000ofEUIOmUIFD03OmU
IFD00ol0003oXZ:Roj:RXP0:oj:RXP03o`000?oooooooooo00Sooooo00?o0000omkNg_oNg]h0DooN
g]h6ooooo`7o00000Oooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0
003ooooo00Kooooo00?o0000ooooooooool00oooool^omkNgP03o`000?oooooooooo00Wooooo00?o
0000oj:RX_nRXZ802onRXZ800ol0003oIFEUofEUI@0@ofEUI@03o`000?lY:BWo:BTY02;o:BTY3ol0
000RobTY:@03o`000?mUIFGoIFEU00koIFEU00?o0000oj:RX_nRXZ802_nRXZ800ol0003ooooooooo
o`07ooooo`;o0000E?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00oooool^
omkNgP03o`000?oooooooooo00Wooooo00?o0000oj:RX_nRXZ802onRXZ800ol0003oIFEUofEUI@0@
ofEUI@03o`000?lY:BWo:BTY027o:BTY4Ol0000RobTY:@03o`000?mUIFGoIFEU00goIFEU00?o0000
oj:RX_nRXZ802_nRXZ800ol0003oooooooooo`08ooooo`03o`000?oNg]kog]kN05;og]kN1_ooool1
o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo;OoNg]h00ol0003oooooooooo`0:oooo
o`03o`000?nRXZ;oXZ:R00_oXZ:R00?o0000ofEUIOmUIFD03omUIFD00ol0003o:BTYobTY:@0PobTY
:AGo00008?lY:BT00ol0003oIFEUofEUI@0>ofEUI@03o`000?nRXZ;oXZ:R00WoXZ:R00?o0000oooo
ooooool02Oooool00ol0003og]kNomkNgP1AomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003o
ooooooooo`03ooooobcog]kN00?o0000ooooooooool02_ooool00ol0003oXZ:Roj:RXP0;oj:RXP03
o`000?mUIFGoIFEU013oIFEU00?o0000obTY:OlY:BT07olY:BTGo`00023o:BTY00?o0000ofEUIOmU
IFD03OmUIFD00ol0003oXZ:Roj:RXP0:oj:RXP03o`000?oooooooooo00Wooooo00?o0000omkNg_oN
g]h0D?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00oooool[omkNgP03o`00
0?oooooooooo00_ooooo00?o0000oj:RX_nRXZ802onRXZ800ol0003oIFEUofEUI@0?ofEUI@03o`00
0?lY:BWo:BTY01oo:BTY6_l0000NobTY:@03o`000?mUIFGoIFEU00koIFEU00?o0000oj:RX_nRXZ80
2OnRXZ800ol0003oooooooooo`0:ooooo`03o`000?oNg]kog]kN04oog]kN1_ooool1o`00007ooooo
000[ooooo`03o`000?oooooooooo00?ooooo:ooNg]h00ol0003oooooooooo`0;ooooo`03o`000?nR
XZ;oXZ:R00[oXZ:R00?o0000ofEUIOmUIFD04?mUIFD00ol0003o:BTYobTY:@0NobTY:Aco00007OlY
:BT00ol0003oIFEUofEUI@0>ofEUI@03o`000?nRXZ;oXZ:R00WoXZ:R00?o0000ooooooooool02_oo
ool00ol0003og]kNomkNgP1?omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03
ooooob_og]kN00?o0000ooooooooool02_ooool00ol0003oXZ:Roj:RXP0;oj:RXP03o`000?mUIFGo
IFEU013oIFEU00?o0000obTY:OlY:BT07OlY:BTNo`0001go:BTY00?o0000ofEUIOmUIFD03OmUIFD0
0ol0003oXZ:Roj:RXP0:oj:RXP03o`000?oooooooooo00Wooooo00?o0000omkNg_oNg]h0CooNg]h6
ooooo`7o00000Oooool002_ooooo0_l00004ooooob_og]kN00?o0000ooooooooool02_ooool00ol0
003oXZ:Roj:RXP0;oj:RXP03o`000?mUIFGoIFEU00ooIFEU00?o0000obTY:OlY:BT07OlY:BTOo`00
01ko:BTY00?o0000ofEUIOmUIFD03OmUIFD00ol0003oXZ:Roj:RXP09oj:RXP03o`000?oooooooooo
00Wooooo00?o0000omkNg_oNg]h0CooNg]h5ooooo`;o00000Oooool002_ooooo00?o0000oooooooo
ool00ooooolZomkNgP03o`000?oooooooooo00[ooooo00?o0000oj:RX_nRXZ803?nRXZ800ol0003o
IFEUofEUI@0?ofEUI@03o`000?lY:BWo:BTY01co:BTY8Ol0000MobTY:@03o`000?mUIFGoIFEU00go
IFEU00?o0000oj:RX_nRXZ802OnRXZ800ol0003oooooooooo`0:ooooo`03o`000?oNg]kog]kN04ko
g]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo:OoNg]h00ol0003ooooo
ooooo`0;ooooo`03o`000?nRXZ;oXZ:R00_oXZ:R00?o0000ofEUIOmUIFD03omUIFD00ol0003o:BTY
obTY:@0MobTY:B;o00007OlY:BT00ol0003oIFEUofEUI@0=ofEUI@03o`000?nRXZ;oXZ:R00WoXZ:R
00?o0000ooooooooool02_ooool00ol0003og]kNomkNgP1=omkNgPKooooo0Ol00001ooooo`00:ooo
ool00ol0003oooooooooo`03ooooobSog]kN00?o0000ooooooooool03?ooool00ol0003oXZ:Roj:R
XP0;oj:RXP03o`000?mUIFGoIFEU00ooIFEU00?o0000obTY:OlY:BT07?lY:BTTo`0001co:BTY00?o
0000ofEUIOmUIFD03OmUIFD00ol0003oXZ:Roj:RXP0:oj:RXP03o`000?oooooooooo00[ooooo00?o
0000omkNg_oNg]h0C?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooolX
omkNgP03o`000?oooooooooo00cooooo00?o0000oj:RX_nRXZ802onRXZ800ol0003oIFEUofEUI@0?
ofEUI@03o`000?lY:BWo:BTY01co:BTY9?l0000LobTY:@03o`000?mUIFGoIFEU00goIFEU00?o0000
oj:RX_nRXZ802_nRXZ800ol0003oooooooooo`0:ooooo`03o`000?oNg]kog]kN04cog]kN1_ooool1
o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo:?oNg]h00ol0003oooooooooo`0;oooo
o`03o`000?nRXZ;oXZ:R00_oXZ:R00?o0000ofEUIOmUIFD03omUIFD00ol0003o:BTYobTY:@0LobTY
:BKo00007?lY:BT00ol0003oIFEUofEUI@0=ofEUI@03o`000?nRXZ;oXZ:R00WoXZ:R00?o0000oooo
ooooool02_ooool00ol0003og]kNomkNgP1<omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003o
ooooooooo`03ooooobSog]kN00?o0000ooooooooool02_ooool00ol0003oXZ:Roj:RXP0<oj:RXP03
o`000?mUIFGoIFEU00ooIFEU00?o0000obTY:OlY:BT06olY:BTXo`0001_o:BTY00?o0000ofEUIOmU
IFD03OmUIFD00ol0003oXZ:Roj:RXP0:oj:RXP03o`000?oooooooooo00Wooooo00?o0000omkNg_oN
g]h0C?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooolXomkNgP03o`00
0?oooooooooo00[ooooo00?o0000oj:RX_nRXZ802onRXZ800ol0003oIFEUofEUI@0@ofEUI@03o`00
0?lY:BWo:BTY01_o:BTY:?l0000LobTY:@03o`000?mUIFGoIFEU00coIFEU00?o0000oj:RX_nRXZ80
2_nRXZ800ol0003oooooooooo`0:ooooo`03o`000?oNg]kog]kN04_og]kN1_ooool1o`00007ooooo
000[ooooo`03o`000?oooooooooo00?ooooo:?oNg]h00ol0003oooooooooo`09ooooo`03o`000?nR
XZ;oXZ:R00coXZ:R00?o0000ofEUIOmUIFD04?mUIFD00ol0003o:BTYobTY:@0JobTY:B[o00006olY
:BT00ol0003oIFEUofEUI@0=ofEUI@03o`000?nRXZ;oXZ:R00[oXZ:R00?o0000ooooooooool02_oo
ool00ol0003og]kNomkNgP1:omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03
ooooobSog]kN00?o0000ooooooooool02Oooool00ol0003oXZ:Roj:RXP0<oj:RXP03o`000?mUIFGo
IFEU00ooIFEU00?o0000obTY:OlY:BT06olY:BT[o`0001[o:BTY00?o0000ofEUIOmUIFD03_mUIFD0
0ol0003oXZ:Roj:RXP09oj:RXP03o`000?oooooooooo00_ooooo00?o0000omkNg_oNg]h0BOoNg]h6
ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooolWomkNgP03o`000?oooooooooo
00[ooooo00?o0000oj:RX_nRXZ803?nRXZ800ol0003oIFEUofEUI@0?ofEUI@03o`000?lY:BWo:BTY
01_o:BTY:ol0000JobTY:@03o`000?mUIFGoIFEU00koIFEU00?o0000oj:RX_nRXZ802OnRXZ800ol0
003oooooooooo`0;ooooo`03o`000?oNg]kog]kN04Wog]kN1_ooool1o`00007ooooo000[ooooo`03
o`000?oooooooooo00?ooooo9_oNg]h00ol0003oooooooooo`0;ooooo`03o`000?nRXZ;oXZ:R00_o
XZ:R00?o0000ofEUIOmUIFD04?mUIFD00ol0003o:BTYobTY:@0JobTY:Bgo00006_lY:BT00ol0003o
IFEUofEUI@0>ofEUI@03o`000?nRXZ;oXZ:R00WoXZ:R00?o0000ooooooooool02_ooool00ol0003o
g]kNomkNgP19omkNgPKooooo0Ol00001ooooo`00:oooool2o`0000Cooooo9OoNg]h00ol0003ooooo
ooooo`0;ooooo`03o`000?nRXZ;oXZ:R00coXZ:R00?o0000ofEUIOmUIFD04?mUIFD00ol0003o:BTY
obTY:@0JobTY:Bgo00006olY:BT00ol0003oIFEUofEUI@0=ofEUI@03o`000?nRXZ;oXZ:R00WoXZ:R
00?o0000ooooooooool02_ooool00ol0003og]kNomkNgP19omkNgPGooooo0_l00001ooooo`00:ooo
ool00ol0003oooooooooo`03ooooobGog]kN00?o0000ooooooooool02oooool00ol0003oXZ:Roj:R
XP0<oj:RXP03o`000?mUIFGoIFEU013oIFEU00?o0000obTY:OlY:BT06_lY:BT]o`0001_o:BTY00?o
0000ofEUIOmUIFD03OmUIFD00ol0003oXZ:Roj:RXP09oj:RXP03o`000?oooooooooo00[ooooo00?o
0000omkNg_oNg]h0BOoNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooolU
omkNgP03o`000?oooooooooo00[ooooo00?o0000oj:RX_nRXZ803?nRXZ800ol0003oIFEUofEUI@0@
ofEUI@03o`000?lY:BWo:BTY01_o:BTY;_l0000KobTY:@03o`000?mUIFGoIFEU00coIFEU00?o0000
oj:RX_nRXZ802_nRXZ800ol0003oooooooooo`09ooooo`03o`000?oNg]kog]kN04Wog]kN1_ooool1
o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo9OoNg]h00ol0003oooooooooo`0:oooo
o`03o`000?nRXZ;oXZ:R00coXZ:R00?o0000ofEUIOmUIFD04?mUIFD00ol0003o:BTYobTY:@0KobTY
:Boo00006_lY:BT00ol0003oIFEUofEUI@0=ofEUI@03o`000?nRXZ;oXZ:R00[oXZ:R00?o0000oooo
ooooool02?ooool00ol0003og]kNomkNgP19omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003o
ooooooooo`03ooooobCog]kN00?o0000ooooooooool02oooool00ol0003oXZ:Roj:RXP0<oj:RXP03
o`000?mUIFGoIFEU013oIFEU00?o0000obTY:OlY:BT06olY:BT_o`0001[o:BTY00?o0000ofEUIOmU
IFD03OmUIFD00ol0003oXZ:Roj:RXP0:oj:RXP03o`000?oooooooooo00Wooooo00?o0000omkNg_oN
g]h0B?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooolSomkNgP03o`00
0?oooooooooo00_ooooo00?o0000oj:RX_nRXZ803?nRXZ800ol0003oIFEUofEUI@0AofEUI@03o`00
0?lY:BWo:BTY01_o:BTY<?l0000JobTY:@03o`000?mUIFGoIFEU00goIFEU00?o0000oj:RX_nRXZ80
2_nRXZ800ol0003oooooooooo`09ooooo`03o`000?oNg]kog]kN04Oog]kN1_ooool1o`00007ooooo
000[ooooo`03o`000?oooooooooo00?ooooo8_oNg]h00ol0003oooooooooo`0<ooooo`03o`000?nR
XZ;oXZ:R00coXZ:R00?o0000ofEUIOmUIFD04OmUIFD00ol0003o:BTYobTY:@0KobTY:C3o00006_lY
:BT00ol0003oIFEUofEUI@0=ofEUI@03o`000?nRXZ;oXZ:R00[oXZ:R00?o0000ooooooooool02_oo
ool00ol0003og]kNomkNgP16omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03
ooooob;og]kN00?o0000ooooooooool03?ooool00ol0003oXZ:Roj:RXP0<oj:RXP03o`000?mUIFGo
IFEU017oIFEU00?o0000obTY:OlY:BT06olY:BT`o`0001[o:BTY00?o0000ofEUIOmUIFD03OmUIFD0
0ol0003oXZ:Roj:RXP0:oj:RXP03o`000?oooooooooo00[ooooo00?o0000omkNg_oNg]h0A_oNg]h6
ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooolRomkNgP03o`000?oooooooooo
00cooooo00?o0000oj:RX_nRXZ803?nRXZ800ol0003oIFEUofEUI@0@ofEUI@03o`000?lY:BWo:BTY
01co:BTY<?l0000KobTY:@03o`000?mUIFGoIFEU00goIFEU00?o0000oj:RX_nRXZ802OnRXZ800ol0
003oooooooooo`0:ooooo`03o`000?oNg]kog]kN04Kog]kN1_ooool1o`00007ooooo000[ooooo`03
o`000?oooooooooo00?ooooo8_oNg]h00ol0003oooooooooo`0;ooooo`03o`000?nRXZ;oXZ:R00go
XZ:R00?o0000ofEUIOmUIFD04?mUIFD00ol0003o:BTYobTY:@0LobTY:C3o00006olY:BT00ol0003o
IFEUofEUI@0=ofEUI@03o`000?nRXZ;oXZ:R00[oXZ:R00?o0000ooooooooool02Oooool00ol0003o
g]kNomkNgP16omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooob;og]kN
00?o0000ooooooooool02oooool00ol0003oXZ:Roj:RXP0=oj:RXP03o`000?mUIFGoIFEU013oIFEU
00?o0000obTY:OlY:BT07?lY:BT`o`0001_o:BTY00?o0000ofEUIOmUIFD03OmUIFD00ol0003oXZ:R
oj:RXP0:oj:RXP03o`000?oooooooooo00[ooooo00?o0000omkNg_oNg]h0AOoNg]h6ooooo`7o0000
0Oooool002_ooooo00?o0000ooooooooool00ooooolRomkNgP03o`000?oooooooooo00[ooooo00?o
0000oj:RX_nRXZ803OnRXZ800ol0003oIFEUofEUI@0AofEUI@03o`000?lY:BWo:BTY01co:BTY<Ol0
000KobTY:@03o`000?mUIFGoIFEU00goIFEU00?o0000oj:RX_nRXZ802_nRXZ800ol0003ooooooooo
o`0:ooooo`03o`000?oNg]kog]kN04Cog]kN1_ooool1o`00007ooooo000[ooooo`;o00001?oooolR
omkNgP03o`000?oooooooooo00[ooooo00?o0000oj:RX_nRXZ803OnRXZ800ol0003oIFEUofEUI@0A
ofEUI@03o`000?lY:BWo:BTY01co:BTY<Ol0000KobTY:@03o`000?mUIFGoIFEU00goIFEU00?o0000
oj:RX_nRXZ802_nRXZ800ol0003oooooooooo`0;ooooo`03o`000?oNg]kog]kN04?og]kN1Oooool2
o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo8OoNg]h00ol0003oooooooooo`0;oooo
o`03o`000?nRXZ;oXZ:R00goXZ:R00?o0000ofEUIOmUIFD04OmUIFD00ol0003o:BTYobTY:@0LobTY
:C7o00006olY:BT00ol0003oIFEUofEUI@0=ofEUI@03o`000?nRXZ;oXZ:R00[oXZ:R00?o0000oooo
ooooool02oooool00ol0003og]kNomkNgP13omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003o
ooooooooo`03ooooob3og]kN00?o0000ooooooooool03?ooool00ol0003oXZ:Roj:RXP0=oj:RXP03
o`000?mUIFGoIFEU017oIFEU00?o0000obTY:OlY:BT07OlY:BT`o`0001_o:BTY00?o0000ofEUIOmU
IFD03_mUIFD00ol0003oXZ:Roj:RXP0:oj:RXP03o`000?oooooooooo00[ooooo00?o0000omkNg_oN
g]h0@ooNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooolOomkNgP03o`00
0?oooooooooo00gooooo00?o0000oj:RX_nRXZ803OnRXZ800ol0003oIFEUofEUI@0AofEUI@03o`00
0?lY:BWo:BTY01go:BTY<Ol0000KobTY:@03o`000?mUIFGoIFEU00goIFEU00?o0000oj:RX_nRXZ80
2_nRXZ800ol0003oooooooooo`0:ooooo`03o`000?oNg]kog]kN04?og]kN1_ooool1o`00007ooooo
000[ooooo`03o`000?oooooooooo00?ooooo7ooNg]h00ol0003oooooooooo`0=ooooo`03o`000?nR
XZ;oXZ:R00goXZ:R00?o0000ofEUIOmUIFD04OmUIFD00ol0003o:BTYobTY:@0MobTY:C7o00006olY
:BT00ol0003oIFEUofEUI@0=ofEUI@03o`000?nRXZ;oXZ:R00_oXZ:R00?o0000ooooooooool02Ooo
ool00ol0003og]kNomkNgP13omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03
oooooaoog]kN00?o0000ooooooooool03?ooool00ol0003oXZ:Roj:RXP0=oj:RXP03o`000?mUIFGo
IFEU01;oIFEU00?o0000obTY:OlY:BT07_lY:BT`o`0001_o:BTY00?o0000ofEUIOmUIFD03_mUIFD0
0ol0003oXZ:Roj:RXP0:oj:RXP03o`000?oooooooooo00Wooooo00?o0000omkNg_oNg]h0@ooNg]h6
ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooolOomkNgP03o`000?oooooooooo
00cooooo00?o0000oj:RX_nRXZ803OnRXZ800ol0003oIFEUofEUI@0BofEUI@03o`000?lY:BWo:BTY
01ko:BTY<?l0000KobTY:@03o`000?mUIFGoIFEU00koIFEU00?o0000oj:RX_nRXZ802_nRXZ800ol0
003oooooooooo`09ooooo`03o`000?oNg]kog]kN04?og]kN1_ooool1o`00007ooooo000[ooooo`03
o`000?oooooooooo00?ooooo7_oNg]h00ol0003oooooooooo`0=ooooo`03o`000?nRXZ;oXZ:R00go
XZ:R00?o0000ofEUIOmUIFD04_mUIFD00ol0003o:BTYobTY:@0NobTY:C3o00006olY:BT00ol0003o
IFEUofEUI@0>ofEUI@03o`000?nRXZ;oXZ:R00[oXZ:R00?o0000ooooooooool02_ooool00ol0003o
g]kNomkNgP12omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooagog]kN
00?o0000ooooooooool03Oooool00ol0003oXZ:Roj:RXP0>oj:RXP03o`000?mUIFGoIFEU01;oIFEU
00?o0000obTY:OlY:BT07_lY:BT`o`0001co:BTY00?o0000ofEUIOmUIFD03OmUIFD00ol0003oXZ:R
oj:RXP0;oj:RXP03o`000?oooooooooo00[ooooo00?o0000omkNg_oNg]h0@OoNg]h6ooooo`7o0000
0Oooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<00Kooooo00?o0000ooooooooool00ooooolLomkNgP03o`000?oooooooooo00ko
oooo00?o0000oj:RX_nRXZ803_nRXZ800ol0003oIFEUofEUI@0BofEUI@03o`000?lY:BWo:BTY01oo
:BTY;ol0000LobTY:@03o`000?mUIFGoIFEU00koIFEU00?o0000oj:RX_nRXZ802_nRXZ800ol0003o
ooooooooo`0;ooooo`03o`000?oNg]kog]kN043og]kN1_ooool1o`00007ooooo000@ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo00?ooooo7?oNg]h00ol0003oooooooooo`0>ooooo`03o`000?nRXZ;oXZ:R
00koXZ:R00?o0000ofEUIOmUIFD04_mUIFD00ol0003o:BTYobTY:@0OobTY:Boo00007?lY:BT00ol0
003oIFEUofEUI@0>ofEUI@03o`000?nRXZ;oXZ:R00[oXZ:R00?o0000ooooooooool02oooool00ol0
003og]kNomkNgP10omkNgPKooooo0Ol00001ooooo`004?ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00000ooooolLomkNgP03o`000?oooooo
oooo00gooooo00?o0000oj:RX_nRXZ803onRXZ800ol0003oIFEUofEUI@0CofEUI@03o`000?lY:BWo
:BTY01oo:BTY;Ol0000NobTY:@03o`000?mUIFGoIFEU00koIFEU00?o0000oj:RX_nRXZ802_nRXZ80
0ol0003oooooooooo`0:ooooo`03o`000?oNg]kog]kN043og]kN1?ooool3o`00007ooooo000@oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool00ooooolLomkNgP03o`000?oooooooooo00gooooo00?o0000oj:RX_nRXZ803onR
XZ800ol0003oIFEUofEUI@0CofEUI@03o`000?lY:BWo:BTY023o:BTY;?l0000NobTY:@03o`000?mU
IFGoIFEU00koIFEU00?o0000oj:RX_nRXZ802_nRXZ800ol0003oooooooooo`0:ooooo`03o`000?oN
g]kog]kN043og]kN1_ooool1o`00007ooooo000@ooooo`05o`000?ooooooooooooooool000002ooo
ool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool00ooooolLomkNgP03o`00
0?oooooooooo00gooooo00?o0000oj:RX_nRXZ803onRXZ800ol0003oIFEUofEUI@0CofEUI@03o`00
0?lY:BWo:BTY023o:BTY;?l0000NobTY:@03o`000?mUIFGoIFEU00koIFEU00?o0000oj:RX_nRXZ80
2_nRXZ800ol0003oooooooooo`0:ooooo`03o`000?oNg]kog]kN043og]kN1_ooool1o`00007ooooo
000@ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`00
0?oooooooooo00?ooooo7?oNg]h00ol0003oooooooooo`0=ooooo`03o`000?nRXZ;oXZ:R00ooXZ:R
00?o0000ofEUIOmUIFD04omUIFD00ol0003o:BTYobTY:@0QobTY:B[o00007olY:BT00ol0003oIFEU
ofEUI@0?ofEUI@03o`000?nRXZ;oXZ:R00[oXZ:R00?o0000ooooooooool02Oooool00ol0003og]kN
omkNgP10omkNgPKooooo0Ol00001ooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`03oooooa_og]kN0_l0000?ooooo`03o`00
0?nRXZ;oXZ:R00ooXZ:R00?o0000ofEUIOmUIFD04omUIFD00ol0003o:BTYobTY:@0RobTY:BWo0000
7olY:BT00ol0003oIFEUofEUI@0?ofEUI@03o`000?nRXZ;oXZ:R00[oXZ:R00?o0000ooooooooool0
2Oooool00ol0003og]kNomkNgP10omkNgPKooooo0Ol00001ooooo`004?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`03oooooa[o
g]kN00?o0000ooooooooool03oooool00ol0003oXZ:Roj:RXP0?oj:RXP03o`000?mUIFGoIFEU01?o
IFEU00?o0000obTY:OlY:BT08olY:BTXo`0001oo:BTY00?o0000ofEUIOmUIFD03omUIFD00ol0003o
XZ:Roj:RXP0:oj:RXP03o`000?oooooooooo00[ooooo00?o0000omkNg_oNg]h0?ooNg]h6ooooo`7o
00000Oooool000_ooooo0ol000000ol@413oooooooooo`0Jooooo`03o`000?oooooooooo00?ooooo
6OoNg]h00ol0003oooooooooo`0?ooooo`03o`000?nRXZ;oXZ:R013oXZ:R00?o0000ofEUIOmUIFD0
5?mUIFD00ol0003o:BTYobTY:@0SobTY:BKo00008OlY:BT00ol0003oIFEUofEUI@0>ofEUI@03o`00
0?nRXZ;oXZ:R00_oXZ:R00?o0000ooooooooool02_ooool00ol0003og]kNomkNgP0nomkNgPKooooo
0Ol00001ooooo`003Oooool00ol@413o^[Zjooooo`0Kooooo`03o`000?oooooooooo00?ooooo6?oN
g]h00ol0003oooooooooo`0@ooooo`03o`000?nRXZ;oXZ:R013oXZ:R00?o0000ofEUIOmUIFD05?mU
IFD00ol0003o:BTYobTY:@0TobTY:BGo00008OlY:BT00ol0003oIFEUofEUI@0>ofEUI@;o00003?nR
XZ800ol0003oooooooooo`0;ooooo`03o`000?oNg]kog]kN03gog]kN1_ooool1o`00007ooooo000=
ooooo`03oiRHV?lb<S;ooooo01_ooooo00?o0000ooooooooool00ooooolHomkNgP03o`000?oooooo
oooo013ooooo00?o0000oj:RX_nRXZ804?nRXZ800ol0003oIFEUofEUI@0DofEUI@03o`000?lY:BWo
:BTY02Go:BTY8ol0000RobTY:@03o`000?mUIFGoIFEU00ooIFEU00?o0000oj:RX_nRXZ802_nRXZ80
0ol0003oooooooooo`0;ooooo`03o`000?oNg]kog]kN03gog]kN1_ooool1o`00007ooooo000=oooo
o`03omgMgOl0003o^[Zj01_ooooo00?o0000ooooooooool00ooooolHomkNgP03o`000?oooooooooo
013ooooo00?o0000oj:RX_nRXZ804?nRXZ800ol0003oIFEUofEUI@0EofEUI@03o`000?lY:BWo:BTY
02Go:BTY8_l0000RobTY:@03o`000?mUIFGoIFEU00ooIFEU00?o0000oj:RX_nRXZ802_nRXZ800ol0
003oooooooooo`0;ooooo`03o`000?oNg]kog]kN03gog]kN1_ooool1o`00007ooooo000=ooooo`03
oeEEEOmgMgOoA4A401_ooooo00?o0000ooooooooool00ooooolHomkNgP03o`000?oooooooooo013o
oooo00?o0000oj:RX_nRXZ804?nRXZ800ol0003oIFEUofEUI@0EofEUI@03o`000?lY:BWo:BTY02Ko
:BTY8?l0000SobTY:@03o`000?mUIFGoIFEU00ooIFEU00?o0000oj:RX_nRXZ802onRXZ800ol0003o
ooooooooo`0:ooooo`03o`000?oNg]kog]kN03gog]kN1_ooool1o`00007ooooo000<ooooo`05omgM
gOl@413oooooob4Q8OoMgMd06_ooool00ol0003oooooooooo`03oooooaSog]kN00?o0000oooooooo
ool04?ooool00ol0003oXZ:Roj:RXP0@oj:RXP03o`000?mUIFGoIFEU01GoIFEU00?o0000obTY:OlY
:BT09olY:BTNo`0002Co:BTY00?o0000ofEUIOmUIFD03omUIFD00ol0003oXZ:Roj:RXP0;oj:RXP03
o`000?oooooooooo00[ooooo00?o0000omkNg_oNg]h0?OoNg]h6ooooo`7o00000Oooool000cooooo
00GoIVIVohN7QoooooooV9RHoeEEE@0Jooooo`;o00001?oooolHomkNgP03o`000?oooooooooo013o
oooo00?o0000oj:RX_nRXZ804?nRXZ800ol0003oIFEUofEUI@0EofEUI@03o`000?lY:BWo:BTY02_o
:BTY6Ol0000UobTY:@03o`000?mUIFGoIFEU00ooIFEU00?o0000oj:RX_nRXZ803?nRXZ800ol0003o
ooooooooo`09ooooo`03o`000?oNg]kog]kN03gog]kN1Oooool2o`00007ooooo000;ooooo`03onk^
k_l0003ok^k^00;ooooo00?o0000omgMgOooool06?ooool00ol0003oooooooooo`03oooooaSog]kN
0_l0000@ooooo`03o`000?nRXZ;oXZ:R01;oXZ:R00?o0000ofEUIOmUIFD05OmUIFD00ol0003o:BTY
obTY:@0/obTY:AGo00009olY:BT00ol0003oIFEUofEUI@0@ofEUI@03o`000?nRXZ;oXZ:R00_oXZ:R
00?o0000ooooooooool02Oooool00ol0003og]kNomkNgP0momkNgPKooooo0Ol00001ooooo`002ooo
ool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Oooooo00?o0000ooooooooool0
0ooooolHomkNgP03o`000?oooooooooo00oooooo00?o0000oj:RX_nRXZ804_nRXZ800ol0003oIFEU
ofEUI@0FofEUI@03o`000?lY:BWo:BTY02co:BTY4ol0000XobTY:@03o`000?mUIFGoIFEU013oIFEU
00?o0000oj:RX_nRXZ802onRXZ800ol0003oooooooooo`09ooooo`03o`000?oNg]kog]kN03gog]kN
1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo5ooNg]h00ol0003ooooooooo
o`0@ooooo`03o`000?nRXZ;oXZ:R01;oXZ:R00?o0000ofEUIOmUIFD05_mUIFD00ol0003o:BTYobTY
:@0_obTY:@ko0000:_lY:BT00ol0003oIFEUofEUI@0@ofEUI@03o`000?nRXZ;oXZ:R00_oXZ:R00?o
0000ooooooooool02_ooool00ol0003og]kNomkNgP0lomkNgPKooooo0Ol00001ooooo`00:oooool0
0ol0003oooooooooo`03oooooaKog]kN00?o0000ooooooooool04Oooool00ol0003oXZ:Roj:RXP0B
oj:RXP03o`000?mUIFGoIFEU01OoIFEU00?o0000obTY:OlY:BT0I_lY:BT00ol0003oIFEUofEUI@0A
ofEUI@03o`000?nRXZ;oXZ:R00_oXZ:R00?o0000ooooooooool02_ooool00ol0003og]kNomkNgP0k
omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooaGog]kN00?o0000oooo
ooooool04_ooool00ol0003oXZ:Roj:RXP0Boj:RXP03o`000?mUIFGoIFEU01OoIFEU00?o0000obTY
:OlY:BT0I_lY:BT00ol0003oIFEUofEUI@0AofEUI@03o`000?nRXZ;oXZ:R00_oXZ:R00?o0000oooo
ooooool02oooool00ol0003og]kNomkNgP0jomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003o
ooooooooo`03oooooaGog]kN00?o0000ooooooooool04_ooool00ol0003oXZ:Roj:RXP0Boj:RXP03
o`000?mUIFGoIFEU01OoIFEU00?o0000obTY:OlY:BT0I_lY:BT00ol0003oIFEUofEUI@0AofEUI@03
o`000?nRXZ;oXZ:R00_oXZ:R00?o0000ooooooooool02oooool00ol0003og]kNomkNgP0jomkNgPKo
oooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooaGog]kN00?o0000ooooooooool0
4_ooool00ol0003oXZ:Roj:RXP0Coj:RXP03o`000?mUIFGoIFEU01OoIFEU00?o0000obTY:OlY:BT0
IOlY:BT00ol0003oIFEUofEUI@0AofEUI@03o`000?nRXZ;oXZ:R00coXZ:R00?o0000ooooooooool0
2_ooool00ol0003og]kNomkNgP0jomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003ooooooooo
o`03oooooaGog]kN00?o0000ooooooooool04_ooool00ol0003oXZ:Roj:RXP0Coj:RXP03o`000?mU
IFGoIFEU01SoIFEU00?o0000obTY:OlY:BT0I?lY:BT00ol0003oIFEUofEUI@0AofEUI@03o`000?nR
XZ;oXZ:R00coXZ:R00?o0000ooooooooool02_ooool00ol0003og]kNomkNgP0jomkNgPKooooo0Ol0
0001ooooo`00:oooool00ol0003oooooooooo`03oooooaGog]kN00?o0000ooooooooool04_ooool0
0ol0003oXZ:Roj:RXP0Coj:RXP03o`000?mUIFGoIFEU01WoIFEU00?o0000obTY:OlY:BT0HolY:BT0
0ol0003oIFEUofEUI@0AofEUI@03o`000?nRXZ;oXZ:R00coXZ:R00?o0000ooooooooool02_ooool0
0ol0003og]kNomkNgP0jomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooo
oaGog]kN00?o0000ooooooooool04_ooool00ol0003oXZ:Roj:RXP0Coj:RXP03o`000?mUIFGoIFEU
01[oIFEU00?o0000obTY:OlY:BT0H_lY:BT00ol0003oIFEUofEUI@0AofEUI@03o`000?nRXZ;oXZ:R
00goXZ:R00?o0000ooooooooool02Oooool00ol0003og]kNomkNgP0jomkNgPKooooo0Ol00001oooo
o`00:oooool00ol0003oooooooooo`03oooooaGog]kN0_l0000Cooooo`03o`000?nRXZ;oXZ:R01Co
XZ:R00?o0000ofEUIOmUIFD06_mUIFD00ol0003o:BTYobTY:@1QobTY:@03o`000?mUIFGoIFEU01;o
IFEU00?o0000oj:RX_nRXZ803?nRXZ800ol0003oooooooooo`09ooooo`03o`000?oNg]kog]kN03[o
g]kN1_ooool1o`00007ooooo000[ooooo`;o00001?oooolDomkNgP03o`000?oooooooooo01?ooooo
00?o0000oj:RX_nRXZ805?nRXZ800ol0003oIFEUofEUI@0KofEUI@03o`000?lY:BWo:BTY063o:BTY
00?o0000ofEUIOmUIFD04_mUIFD00ol0003oXZ:Roj:RXP0<oj:RXP03o`000?oooooooooo00[ooooo
00?o0000omkNg_oNg]h0>OoNg]h5ooooo`;o00000Oooool002_ooooo00?o0000ooooooooool00ooo
oolComkNgP03o`000?oooooooooo01Cooooo00?o0000oj:RX_nRXZ805OnRXZ800ol0003oIFEUofEU
I@0KofEUI@03o`000?lY:BWo:BTY05oo:BTY00?o0000ofEUIOmUIFD04_mUIFD00ol0003oXZ:Roj:R
XP0=oj:RXP03o`000?oooooooooo00[ooooo00?o0000omkNg_oNg]h0>?oNg]h6ooooo`7o00000Ooo
ool002_ooooo00?o0000ooooooooool00ooooolBomkNgP03o`000?oooooooooo01Gooooo00?o0000
oj:RX_nRXZ805_nRXZ800ol0003oIFEUofEUI@0KofEUI@03o`000?lY:BWo:BTY05ko:BTY00?o0000
ofEUIOmUIFD04_mUIFD00ol0003oXZ:Roj:RXP0=oj:RXP03o`000?oooooooooo00_ooooo00?o0000
omkNg_oNg]h0=ooNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooolBomkN
gP03o`000?oooooooooo01Gooooo00?o0000oj:RX_nRXZ805_nRXZ800ol0003oIFEUofEUI@0LofEU
I@03o`000?lY:BWo:BTY05go:BTY00?o0000ofEUIOmUIFD04_mUIFD00ol0003oXZ:Roj:RXP0=oj:R
XP03o`000?oooooooooo00_ooooo00?o0000omkNg_oNg]h0=ooNg]h6ooooo`7o00000Oooool002_o
oooo00?o0000ooooooooool00ooooolBomkNgP03o`000?oooooooooo01Kooooo00?o0000oj:RX_nR
XZ805OnRXZ800ol0003oIFEUofEUI@0MofEUI@03o`000?lY:BWo:BTY05_o:BTY00?o0000ofEUIOmU
IFD05?mUIFD00ol0003oXZ:Roj:RXP0<oj:RXP03o`000?oooooooooo00_ooooo00?o0000omkNg_oN
g]h0=ooNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooolBomkNgP03o`00
0?oooooooooo01Kooooo00?o0000oj:RX_nRXZ805_nRXZ800ol0003oIFEUofEUI@0MofEUI@03o`00
0?lY:BWo:BTY05[o:BTY00?o0000ofEUIOmUIFD05?mUIFD00ol0003oXZ:Roj:RXP0<oj:RXP03o`00
0?oooooooooo00_ooooo00?o0000omkNg_oNg]h0=ooNg]h6ooooo`7o00000Oooool002_ooooo00?o
0000ooooooooool00ooooolBomkNgP03o`000?oooooooooo01Kooooo00?o0000oj:RX_nRXZ805_nR
XZ800ol0003oIFEUofEUI@0NofEUI@;o0000F_lY:BT00ol0003oIFEUofEUI@0DofEUI@03o`000?nR
XZ;oXZ:R00coXZ:R00?o0000ooooooooool02oooool00ol0003og]kNomkNgP0gomkNgPKooooo0Ol0
0001ooooo`00:oooool00ol0003oooooooooo`03oooooa;og]kN00?o0000ooooooooool05oooool0
0ol0003oXZ:Roj:RXP0Foj:RXP03o`000?mUIFGoIFEU01ooIFEU00?o0000obTY:OlY:BT0E_lY:BT0
0ol0003oIFEUofEUI@0EofEUI@03o`000?nRXZ;oXZ:R00goXZ:R00?o0000ooooooooool02_ooool0
0ol0003og]kNomkNgP0gomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooo
oa;og]kN0_l0000Hooooo`03o`000?nRXZ;oXZ:R01OoXZ:R00?o0000ofEUIOmUIFD07omUIFD2o`00
05Ko:BTY00?o0000ofEUIOmUIFD05OmUIFD00ol0003oXZ:Roj:RXP0=oj:RXP03o`000?oooooooooo
00[ooooo00?o0000omkNg_oNg]h0=ooNg]h6ooooo`7o00000Oooool002_ooooo00?o0000oooooooo
ool00ooooolAomkNgP03o`000?oooooooooo01Sooooo00?o0000oj:RX_nRXZ806?nRXZ800ol0003o
IFEUofEUI@0PofEUI@03o`000?lY:BWo:BTY05?o:BTY00?o0000ofEUIOmUIFD05OmUIFD00ol0003o
XZ:Roj:RXP0=oj:RXP03o`000?oooooooooo00_ooooo00?o0000omkNg_oNg]h0=_oNg]h6ooooo`7o
00000Oooool002_ooooo00?o0000ooooooooool00oooool@omkNgP03o`000?oooooooooo01[ooooo
00?o0000oj:RX_nRXZ806?nRXZ800ol0003oIFEUofEUI@0PofEUI@03o`000?lY:BWo:BTY057o:BTY
00?o0000ofEUIOmUIFD05_mUIFD00ol0003oXZ:Roj:RXP0>oj:RXP03o`000?oooooooooo00_ooooo
00?o0000omkNg_oNg]h0=OoNg]h6ooooo`7o00000Oooool002_ooooo0_l00004ooooo`oog]kN00?o
0000ooooooooool06oooool00ol0003oXZ:Roj:RXP0Ioj:RXP03o`000?mUIFGoIFEU023oIFEU0_l0
001AobTY:@03o`000?mUIFGoIFEU01KoIFEU00?o0000oj:RX_nRXZ803_nRXZ800ol0003ooooooooo
o`0<ooooo`03o`000?oNg]kog]kN03Cog]kN1Oooool2o`00007ooooo000[ooooo`03o`000?oooooo
oooo00?ooooo3ooNg]h00ol0003oooooooooo`0Kooooo`03o`000?nRXZ;oXZ:R01[oXZ:R00?o0000
ofEUIOmUIFD08OmUIFD2o`0004oo:BTY00?o0000ofEUIOmUIFD05_mUIFD00ol0003oXZ:Roj:RXP0>
oj:RXP03o`000?oooooooooo00cooooo00?o0000omkNg_oNg]h0=?oNg]h6ooooo`7o00000Oooool0
02_ooooo00?o0000ooooooooool00oooool?omkNgP03o`000?oooooooooo01cooooo00?o0000oj:R
X_nRXZ806_nRXZ800ol0003oIFEUofEUI@0RofEUI@03o`000?lY:BWo:BTY04_o:BTY00?o0000ofEU
IOmUIFD05omUIFD00ol0003oXZ:Roj:RXP0?oj:RXP03o`000?oooooooooo00_ooooo00?o0000omkN
g_oNg]h0=?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00oooool?omkNgP03
o`000?oooooooooo01cooooo00?o0000oj:RX_nRXZ806onRXZ800ol0003oIFEUofEUI@0RofEUI@?o
0000BOlY:BT00ol0003oIFEUofEUI@0HofEUI@03o`000?nRXZ;oXZ:R00ooXZ:R00?o0000oooooooo
ool02oooool00ol0003og]kNomkNgP0domkNgPKooooo0Ol00001ooooo`00:oooool00ol0003ooooo
ooooo`03ooooo`oog]kN00?o0000ooooooooool07?ooool00ol0003oXZ:Roj:RXP0Loj:RXP03o`00
0?mUIFGoIFEU02CoIFEU0_l00017obTY:@03o`000?mUIFGoIFEU01SoIFEU00?o0000oj:RX_nRXZ80
3onRXZ800ol0003oooooooooo`0;ooooo`03o`000?oNg]kog]kN03Cog]kN1_ooool1o`00007ooooo
000[ooooo`03o`000?oooooooooo00?ooooo3ooNg]h00ol0003oooooooooo`0Mooooo`03o`000?nR
XZ;oXZ:R01coXZ:R00?o0000ofEUIOmUIFD09OmUIFD00ol0003o:BTYobTY:@13obTY:@03o`000?mU
IFGoIFEU01WoIFEU00?o0000oj:RX_nRXZ803onRXZ800ol0003oooooooooo`0;ooooo`03o`000?oN
g]kog]kN03Cog]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo3ooNg]h0
0ol0003oooooooooo`0Nooooo`03o`000?nRXZ;oXZ:R01coXZ:R0_l0000VofEUI@Co0000@?lY:BT0
0ol0003oIFEUofEUI@0JofEUI@03o`000?nRXZ;oXZ:R00ooXZ:R00?o0000ooooooooool02oooool0
0ol0003og]kNomkNgP0domkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooo
o`kog]kN00?o0000ooooooooool07oooool00ol0003oXZ:Roj:RXP0Noj:RXP03o`000?mUIFGoIFEU
02OoIFEU0ol0000lobTY:@;o00007?mUIFD00ol0003oXZ:Roj:RXP0?oj:RXP03o`000?oooooooooo
00cooooo00?o0000omkNg_oNg]h0<ooNg]h6ooooo`7o00000Oooool002_ooooo00?o0000oooooooo
ool00oooool=omkNgP03o`000?oooooooooo027ooooo00?o0000oj:RX_nRXZ807_nRXZ800ol0003o
IFEUofEUI@0YofEUI@;o0000>OlY:BT00ol0003oIFEUofEUI@0LofEUI@03o`000?nRXZ;oXZ:R013o
XZ:R00?o0000ooooooooool03?ooool00ol0003og]kNomkNgP0bomkNgPKooooo0Ol00001ooooo`00
:oooool00ol0003oooooooooo`03ooooo`cog]kN00?o0000ooooooooool08oooool00ol0003oXZ:R
oj:RXP0Noj:RXP;o0000:omUIFD3o`0003Co:BTY0_l0000OofEUI@03o`000?nRXZ;oXZ:R013oXZ:R
00?o0000ooooooooool03Oooool00ol0003og]kNomkNgP0aomkNgPKooooo0Ol00001ooooo`004?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`03ooooo`cog]kN00?o0000ooooooooool09?ooool00ol0003o
XZ:Roj:RXP0Ooj:RXP03o`000?mUIFGoIFEU02_oIFEU00?o0000obTY:OlY:BT0<?lY:BT00ol0003o
IFEUofEUI@0OofEUI@03o`000?nRXZ;oXZ:R013oXZ:R00?o0000ooooooooool03Oooool00ol0003o
g]kNomkNgP0aomkNgPKooooo0Ol00001ooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`03oooo
o`cog]kN00?o0000ooooooooool09Oooool00ol0003oXZ:Roj:RXP0Ooj:RXP;o0000;?mUIFD6o`00
02[o:BTY0_l0000RofEUI@03o`000?nRXZ;oXZ:R013oXZ:R00?o0000ooooooooool03Oooool00ol0
003og]kNomkNgP0aomkNgPKooooo0Ol00001ooooo`004?ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00000oooool<omkNgP03o`000?oooooo
oooo02Kooooo00?o0000oj:RX_nRXZ808?nRXZ800ol0003oIFEUofEUI@0_ofEUI@?o00009_lY:BT0
0ol0003oIFEUofEUI@0RofEUI@03o`000?nRXZ;oXZ:R013oXZ:R00?o0000ooooooooool03Oooool0
0ol0003og]kNomkNgP0aomkNgPCooooo0ol00001ooooo`004?ooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo00?ooooo3?oN
g]h00ol0003oooooooooo`0Wooooo`03o`000?nRXZ;oXZ:R023oXZ:R0ol0000aofEUI@?o00008OlY
:BT2o`0002GoIFEU00?o0000oj:RX_nRXZ804?nRXZ800ol0003oooooooooo`0=ooooo`03o`000?oN
g]kog]kN037og]kN1_ooool1o`00007ooooo000@ooooo`05o`000?ooooooooooooooool000002ooo
ool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool00oooool<omkNgP03o`00
0?oooooooooo02Sooooo0_l0000Soj:RXP;o0000<_mUIFD6o`0001So:BTY0ol0000WofEUI@03o`00
0?nRXZ;oXZ:R017oXZ:R00?o0000ooooooooool03?ooool00ol0003og]kNomkNgP0aomkNgPKooooo
0Ol00001ooooo`004?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo
^[Zjoa0@4006ooooo`03o`000?oooooooooo00?ooooo3?oNg]h00ol0003oooooooooo`0Zooooo`03
o`000?nRXZ;oXZ:R02;oXZ:R00?o0000ofEUIOmUIFD0=OmUIFD9o`0000Oo:BTY2?l0000ZofEUI@03
o`000?nRXZ;oXZ:R017oXZ:R00?o0000ooooooooool03?ooool00ol0003og]kNomkNgP0aomkNgPKo
oooo0Ol00001ooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
oooo^[Zjo`000006ooooo`03o`000?oooooooooo00?ooooo2ooNg]h00ol0003oooooooooo`0/oooo
o`;o00008onRXZ82o`0003koIFEU1ol0000bofEUI@03o`000?nRXZ;oXZ:R017oXZ:R00?o0000oooo
ooooool03Oooool00ol0003og]kNomkNgP0`omkNgPKooooo0Ol00001ooooo`004?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooo
oooo00?ooooo2_oNg]h00ol0003oooooooooo`0_ooooo`03o`000?nRXZ;oXZ:R02;oXZ:R00?o0000
ofEUIOmUIFD0LomUIFD00ol0003oXZ:Roj:RXP0Coj:RXP03o`000?oooooooooo00gooooo00?o0000
omkNg_oNg]h0;ooNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00oooool9omkN
gP03o`000?oooooooooo037ooooo0_l0000Soj:RXP?o0000L_mUIFD00ol0003oXZ:Roj:RXP0Coj:R
XP03o`000?oooooooooo00kooooo00?o0000omkNg_oNg]h0;_oNg]h6ooooo`7o00000Oooool002_o
oooo00?o0000ooooooooool00oooool9omkNgP03o`000?oooooooooo03?ooooo00?o0000oj:RX_nR
XZ808onRXZ83o`0006ooIFEU00?o0000oj:RX_nRXZ804onRXZ800ol0003oooooooooo`0>ooooo`03
o`000?oNg]kog]kN02kog]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo
2OoNg]h00ol0003oooooooooo`0dooooo`;o00009_nRXZ82o`0006coIFEU00?o0000oj:RX_nRXZ80
5?nRXZ800ol0003oooooooooo`0>ooooo`03o`000?oNg]kog]kN02kog]kN1_ooool1o`00007ooooo
000[ooooo`03o`000?oooooooooo00?ooooo2OoNg]h00ol0003oooooooooo`0fooooo`03o`000?nR
XZ;oXZ:R02GoXZ:R00?o0000ofEUIOmUIFD0JOmUIFD00ol0003oXZ:Roj:RXP0Doj:RXP03o`000?oo
oooooooo00kooooo00?o0000omkNg_oNg]h0;_oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000
ooooooooool00oooool9omkNgP03o`000?oooooooooo03Oooooo0ol0000Uoj:RXP?o0000J?mUIFD0
0ol0003oXZ:Roj:RXP0Doj:RXP03o`000?oooooooooo00kooooo00?o0000omkNg_oNg]h0;_oNg]h6
ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00oooool:omkNgP03o`000?oooooooooo
03Wooooo0_l0000Voj:RXP?o0000IOmUIFD00ol0003oXZ:Roj:RXP0Doj:RXP03o`000?oooooooooo
00kooooo00?o0000omkNg_oNg]h0;_oNg]h6ooooo`7o00000Oooool002_ooooo0_l00004ooooo`_o
g]kN00Go0000ooooooooooooooooo`00000hooooo`03o`000?nRXZ;oXZ:R02KoXZ:R0_l0001RofEU
I@03o`000?nRXZ;oXZ:R01GoXZ:R00?o0000ooooooooool03_ooool00ol0003og]kNomkNgP0^omkN
gPGooooo0_l00001ooooo`00:oooool00ol0003oooooooooo`03ooooo`cog]kN1?l0000iooooo`Co
00009_nRXZ84o`0005koIFEU00?o0000oj:RX_nRXZ805OnRXZ800ol0003oooooooooo`0>ooooo`03
o`000?oNg]kog]kN02kog]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo
4?oNg]h00ol0003oooooooooo`0jooooo`03o`000?nRXZ;oXZ:R02OoXZ:R0ol0001KofEUI@03o`00
0?nRXZ;oXZ:R01GoXZ:R00?o0000ooooooooool03oooool00ol0003og]kNomkNgP0]omkNgPKooooo
0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooa7og]kN00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0booooo`03o`000?nRXZ;oXZ:R02WoXZ:R0_l0001HofEUI@03o`000?nR
XZ;oXZ:R01OoXZ:R00?o0000ooooooooool03oooool00ol0003og]kNomkNgP0/omkNgPKooooo0Ol0
0001ooooo`00:oooool00ol0003oooooooooo`03oooooa;og]kN2?l0000eooooo`Co0000:?nRXZ86
o`0005;oIFEU00?o0000oj:RX_nRXZ806?nRXZ800ol0003oooooooooo`0@ooooo`03o`000?oNg]ko
g]kN02_og]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo6_oNg]h00ol0
003oooooooooo`0fooooo`?o0000:onRXZ83o`0004ooIFEU00?o0000oj:RX_nRXZ806?nRXZ800ol0
003oooooooooo`0@ooooo`03o`000?oNg]kog]kN02_og]kN1_ooool1o`00007ooooo000[ooooo`03
o`000?oooooooooo00?ooooo6ooNg]h00ol0003oooooooooo`0hooooo`03o`000?nRXZ;oXZ:R02_o
XZ:R00?o0000ofEUIOmUIFD0BomUIFD00ol0003oXZ:Roj:RXP0Ioj:RXP03o`000?oooooooooo013o
oooo00?o0000omkNg_oNg]h0:ooNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool0
0ooooolLomkNgPOo0000=?ooool4o`0002[oXZ:R1Ol00016ofEUI@;o00007?nRXZ800ol0003ooooo
ooooo`0@ooooo`03o`000?oNg]kog]kN02_og]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oo
oooooooo00?ooooo8ooNg]h00ol0003oooooooooo`0eooooo`03o`000?nRXZ;oXZ:R02coXZ:R0ol0
0012ofEUI@03o`000?nRXZ;oXZ:R01coXZ:R00?o0000ooooooooool04?ooool00ol0003og]kNomkN
gP0[omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooobCog]kN00?o0000
ooooooooool0=Oooool3o`0002koXZ:R0ol0000nofEUI@03o`000?nRXZ;oXZ:R01goXZ:R00?o0000
ooooooooool04?ooool00ol0003og]kNomkNgP0[omkNgPKooooo0Ol00001ooooo`00:oooool00ol0
003oooooooooo`03ooooobGog]kN2_l0000`ooooo`?o0000;_nRXZ86o`0003KoIFEU0_l0000Poj:R
XP03o`000?oooooooooo013ooooo0_l0000/omkNgPKooooo0Ol00001ooooo`00:oooool2o`0000Co
oooo;ooNg]h00ol0003oooooooooo`0`ooooo`?o0000<OnRXZ83o`0003;oIFEU00?o0000oj:RX_nR
XZ808?nRXZ800ol0003oooooooooo`0Aooooo`03o`000?oNg]kog]kN02[og]kN1Oooool2o`00007o
oooo000[ooooo`03o`000?oooooooooo00?ooooo<?oNg]h00ol0003oooooooooo`0booooo`?o0000
<OnRXZ85o`0002_oIFEU0_l0000Soj:RXP03o`000?oooooooooo01;ooooo00?o0000omkNg_oNg]h0
:OoNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooolaomkNgPOo0000<?oo
ool3o`0003?oXZ:R1?l0000TofEUI@?o00009OnRXZ800ol0003oooooooooo`0Cooooo`03o`000?oN
g]kog]kN02Sog]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo>?oNg]h0
0ol0003oooooooooo`0`ooooo`?o0000=?nRXZ89o`0001SoIFEU0ol0000Xoj:RXP03o`000?oooooo
oooo01?ooooo00?o0000omkNg_oNg]h0:?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000oooo
ooooool00oooooliomkNgP03o`000?oooooooooo03;ooooo0ol0000joj:RXQSo0000:onRXZ800ol0
003oooooooooo`0Cooooo`03o`000?oNg]kog]kN02Sog]kN1_ooool1o`00007ooooo000[ooooo`03
o`000?oooooooooo00?ooooo>_oNg]h;o`0002cooooo0ol0001joj:RXP03o`000?oooooooooo01?o
oooo00?o0000omkNg_oNg]h0:?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool0
0ooooom4omkNgP03o`000?oooooooooo02gooooo0ol0001goj:RXP03o`000?oooooooooo01?ooooo
00?o0000omkNg_oNg]h0:?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooo
oom5omkNgP03o`000?oooooooooo02oooooo0ol0001coj:RXP03o`000?oooooooooo01Cooooo00?o
0000omkNg_oNg]h0:?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooom6
omkNgPSo0000;?ooool4o`0006ooXZ:R00?o0000ooooooooool05?ooool00ol0003og]kNomkNgP0X
omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooodkog]kN00?o0000oooo
ooooool0;Oooool3o`0006coXZ:R00?o0000ooooooooool05?ooool00ol0003og]kNomkNgP0XomkN
gPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooodoog]kN00?o0000oooooooo
ool0;oooool3o`0006WoXZ:R00?o0000ooooooooool05?ooool00ol0003og]kNomkNgP0XomkNgPKo
oooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooe3og]kN1ol0000]ooooo`?o0000
I_nRXZ800ol0003oooooooooo`0Dooooo`;o0000:OoNg]h6ooooo`7o00000Oooool002_ooooo0_l0
0004oooooeOog]kN00?o0000ooooooooool0;Oooool3o`0006?oXZ:R00?o0000ooooooooool05Ooo
ool00ol0003og]kNomkNgP0WomkNgPGooooo0_l00001ooooo`00:oooool00ol0003oooooooooo`03
oooooeSog]kN00?o0000ooooooooool0;oooool5o`0005goXZ:R00?o0000ooooooooool05oooool0
0ol0003og]kNomkNgP0VomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooo
oeWog]kN2_l0000/ooooo`Co0000FOnRXZ800ol0003oooooooooo`0Hooooo`03o`000?oNg]kog]kN
02Gog]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?oooooHooNg]h00ol0003o
ooooooooo`0]ooooo`?o0000E_nRXZ800ol0003oooooooooo`0Hooooo`03o`000?oNg]kog]kN02Go
g]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?oooooI?oNg]h00ol0003ooooo
ooooo`0_ooooo`?o0000D_nRXZ800ol0003oooooooooo`0Iooooo`03o`000?oNg]kog]kN02Gog]kN
1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?oooooIOoNg]h7o`0002gooooo1_l0
001;oj:RXP03o`000?oooooooooo01[ooooo00?o0000omkNg_oNg]h09OoNg]h6ooooo`7o00000Ooo
ool002_ooooo00?o0000ooooooooool00ooooom/omkNgP03o`000?oooooooooo033ooooo0ol00018
oj:RXP03o`000?oooooooooo01[ooooo00?o0000omkNg_oNg]h09OoNg]h6ooooo`7o00000Oooool0
02_ooooo00?o0000ooooooooool00ooooom]omkNgP03o`000?oooooooooo03;ooooo0ol00014oj:R
XP03o`000?oooooooooo01_ooooo00?o0000omkNg_oNg]h09OoNg]h6ooooo`7o00000Oooool002_o
oooo00?o0000ooooooooool00ooooom^omkNgP_o0000;?ooool6o`0003goXZ:R00?o0000oooooooo
ool07?ooool2o`0002Kog]kN1_ooool1o`00007ooooo000Qooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`03ooooogWog]kN00?o0000ooooooooool0;oooool4o`0003SoXZ:R
00?o0000ooooooooool07oooool00ol0003og]kNomkNgP0SomkNgPKooooo0Ol00001ooooo`008ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?oooooN_oNg]h00ol0003ooooooooo
o`0booooo`?o0000<onRXZ82o`0002?ooooo00?o0000omkNg_oNg]h08_oNg]h6ooooo`7o00000Ooo
ool002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooog_og]kN1ol0000`
ooooo`Ko0000;?nRXZ800ol0003oooooooooo`0Tooooo`03o`000?oNg]kog]kN027og]kN1_ooool1
o`00007ooooo000Sooooo`03o`000?oooooooooo00Gooooo0ol00003oooooh;og]kN00?o0000oooo
ooooool0<oooool6o`0002CoXZ:R0_l0000Wooooo`03o`000?oNg]kog]kN027og]kN1?ooool3o`00
007ooooo000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooooon3omkNgP03
o`000?oooooooooo03Sooooo1_l0000Koj:RXP?o0000:Oooool00ol0003og]kNomkNgP0QomkNgPKo
oooo0Ol00001ooooo`008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
Q?oNg]h7o`0003Wooooo2Ol0000;oj:RXPOo0000;?ooool00ol0003og]kNomkNgP0QomkNgPKooooo
0Ol00001ooooo`008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?oooooRooN
g]h00ol0003oooooooooo`0oooooo`_o0000<oooool00ol0003og]kNomkNgP0QomkNgPKooooo0Ol0
0001ooooo`008Oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo00?oooooS?oNg]h0
0ol0003oooooooooo`1looooo`03o`000?oNg]kog]kN027og]kN1_ooool1o`00007ooooo000[oooo
o`03o`000?oooooooooo00?oooooSOoNg]h:o`0007Cooooo00?o0000omkNg_oNg]h08OoNg]h6oooo
o`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooonGomkNgP03o`000?oooooooooo077o
oooo00?o0000omkNg_oNg]h08OoNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool0
0ooooonHomkNgP03o`000?oooooooooo073ooooo00?o0000omkNg_oNg]h08OoNg]h6ooooo`7o0000
0Oooool002_ooooo00?o0000ooooooooool00ooooonIomkNgPOo0000Joooool00ol0003og]kNomkN
gP0QomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooioog]kN00?o0000
ooooooooool0JOooool00ol0003og]kNomkNgP0QomkNgPKooooo0Ol00001ooooo`00:oooool00ol0
003oooooooooo`03oooooj3og]kN00?o0000ooooooooool0JOooool00ol0003og]kNomkNgP0PomkN
gPKooooo0Ol00001ooooo`00:oooool2o`0000CoooooXOoNg]h00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo05kooooo00?o0000omkNg_oNg]h07ooNg]h5ooooo`;o00000Oooool002_ooooo
00?o0000ooooooooool00ooooonRomkNgP_o0000HOooool00ol0003og]kNomkNgP0NomkNgPKooooo
0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooojgog]kN00?o0000ooooooooool0G_oo
ool00ol0003og]kNomkNgP0NomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03
ooooojkog]kN00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Fooooo`03o`000?oNg]ko
g]kN01kog]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo[ooNg]h7o`00
05Sooooo00?o0000omkNg_oNg]h07_oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000oooooooo
ool00ooooonfomkNgP03o`000?oooooooooo05Gooooo00?o0000omkNg_oNg]h07_oNg]h6ooooo`7o
00000Oooool002_ooooo00?o0000ooooooooool00ooooongomkNgP03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0COooool00ol0003og]kNomkNgP0NomkNgPKooooo0Ol00001ooooo`00:ooo
ool00ol0003oooooooooo`03oooookSog]kN1ol0001?ooooo`03o`000?oNg]kog]kN01kog]kN1_oo
ool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo_ooNg]h00ol0003oooooooooo`1<
ooooo`03o`000?oNg]kog]kN01kog]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo
00?ooooo`?oNg]h00ol0003oooooooooo`1;ooooo`03o`000?oNg]kog]kN01kog]kN1_ooool1o`00
007ooooo000[ooooo`03o`000?oooooooooo00?ooooo`OoNg]h:o`0004?ooooo00?o0000omkNg_oN
g]h07_oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00oooooo;omkNgP03o`00
0?oooooooooo047ooooo00?o0000omkNg_oNg]h07OoNg]h6ooooo`7o00000Oooool002_ooooo0_l0
0004ooooolcog]kN00?o0000ooooooooool0@Oooool00ol0003og]kNomkNgP0LomkNgPGooooo0_l0
0001ooooo`00:oooool00ol0003oooooooooo`03ooooolgog]kN2?l0000looooo`03o`000?oNg]ko
g]kN01_og]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?oooooe?oNg]h00ol0
003oooooooooo`0jooooo`03o`000?oNg]kog]kN01_og]kN1_ooool1o`00007ooooo000[ooooo`03
o`000?oooooooooo00?oooooeOoNg]h00ol0003oooooooooo`0iooooo`03o`000?oNg]kog]kN01_o
g]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?oooooe_oNg]h;o`00033ooooo
00?o0000omkNg_oNg]h06ooNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooo
oooQomkNgP03o`000?oooooooooo02gooooo00?o0000omkNg_oNg]h06ooNg]h6ooooo`7o00000Ooo
ool002_ooooo00?o0000ooooooooool00ooooooRomkNgP03o`000?oooooooooo02cooooo00?o0000
omkNg_oNg]h06ooNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooooSomkN
gPOo00009oooool00ol0003og]kNomkNgP0KomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003o
ooooooooo`03ooooon[og]kN00?o0000ooooooooool09Oooool00ol0003og]kNomkNgP0JomkNgPKo
oooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooon_og]kN00?o0000ooooooooool0
9Oooool00ol0003og]kNomkNgP0IomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003ooooooooo
o`03oooooncog]kN1ol0000Qooooo`03o`000?oNg]kog]kN01Sog]kN1_ooool1o`00007ooooo000[
ooooo`03o`000?oooooooooo00?ooooolooNg]h00ol0003oooooooooo`0Nooooo`03o`000?oNg]ko
g]kN01Sog]kN1_ooool1o`00007ooooo000[ooooo`;o00001?ooooodomkNgP03o`000?oooooooooo
01gooooo00?o0000omkNg_oNg]h06?oNg]h5ooooo`;o00000Oooool002_ooooo00?o0000oooooooo
ool00ooooooeomkNgP[o00005Oooool00ol0003og]kNomkNgP0HomkNgPKooooo0Ol00001ooooo`00
:oooool00ol0003oooooooooo`03oooooooog]kN00?o0000ooooooooool04_ooool00ol0003og]kN
omkNgP0HomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooooog]kN0OoN
g]h00ol0003oooooooooo`0Aooooo`03o`000?oNg]kog]kN01Sog]kN1_ooool1o`00007ooooo000[
ooooo`03o`000?oooooooooo00?ooooooooNg]h2omkNgPSo00002oooool00ol0003og]kNomkNgP0H
omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooooog]kN2_oNg]h00ol0
003oooooooooo`07ooooo`03o`000?oNg]kog]kN01Wog]kN1_ooool1o`00007ooooo000[ooooo`03
o`000?oooooooooo00?ooooooooNg]h;omkNgP03o`000?oooooooooo00Gooooo00?o0000omkNg_oN
g]h06_oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00oooooooomkNgPcog]kN
1ol0000MomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooooog]kN<?oN
g]h6ooooo`7o00000Oooool0017ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5
o`0000Kooooo00?o0000ooooooooool00oooooooomkNgS3og]kN1_ooool1o`00007ooooo000Coooo
o`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool0
0ol0003oooooooooo`03oooooooog]kN<?oNg]h6ooooo`7o00000Oooool001?ooooo00?o0000oooo
ooooool02oooool00onHV9So8B4Qonk^kP07ooooo`?o00000oooooooomkNgS3og]kN1?ooool3o`00
007ooooo000Cooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003o
ooooooooo`03oooooooog]kN<?oNg]h6ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0
3Oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo00?ooooooooNg]h`omkNgPKooooo
0Ol00001ooooo`004oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooooooomkNgS3og]kN1_ooool1o`00007ooooo000Cooooo`03o`000?oooooo
oooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo00?ooooooooN
g]h`omkNgPKooooo0Ol00001ooooo`004Oooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`03oooooooog]kN<?oNg]h6ooooo`7o00000Ooo
ool002_ooooo00?o0000ooooooooool00oooooooomkNgS3og]kN1_ooool1o`00007ooooo000[oooo
o`03o`000?oooooooooo00?ooooooooNg]h`omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003o
ooooooooo`03oooooooog]kN<?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool0
0oooooooomkNgS3og]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooooooN
g]h`omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooooog]kN<?oNg]h6
ooooo`7o00000Oooool002_ooooo0_l00004oooooooog]kN<?oNg]h5ooooo`;o00000Oooool002_o
oooo00?o0000ooooooooool00oooooooomkNgS3og]kN1_ooool1o`00007ooooo000[ooooo`03o`00
0?oooooooooo00?ooooooooNg]h`omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003ooooooooo
o`03oooooooog]kN<?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooooo
omkNgS3og]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooooooNg]h`omkN
gPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooooog]kN<?oNg]h6ooooo`7o
00000Oooool002_ooooo00?o0000ooooooooool00oooooooomkNgS3og]kN1_ooool1o`00007ooooo
000[ooooo`03o`000?oooooooooo00?ooooooooNg]h`omkNgPKooooo0Ol00001ooooo`00:oooool0
0ol0003oooooooooo`03oooooooog]kN<?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000oooo
ooooool00oooooooomkNgS3og]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?o
oooooooNg]h`omkNgPKooooo0Ol00001ooooo`00:oooool2o`0000CooooooooNg]h`omkNgPGooooo
0_l00001ooooo`00:oooool00ol0003oooooooooo`3oooooocWooooo0Ol00001ooooo`00:oooool0
0ol0003oooooooooo`3oooooocWooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`3ooooo
ocWooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool0:_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0Ol00001ooooo`00:oooooooo`0003go00000Oooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1, 0, 0, 0}}]
}, Open  ]],

Cell["\<\
We can check how well our approximate solution solves the Poisson \
equation by substituting it into the PDE:\
\>", "Text"],

Cell[BoxData[
    \(\(L[\[Phi][x, y]] - 1\ ;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.22"],

Cell[TextData[{
  "The result deviates only slightly from zero, as shown in Cell ",
  ButtonBox["6.23",
    ButtonData:>"Cell 6.23",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot3D[
        Abs[%]\ Boole[
            z[1, x, y] \[LessEqual] \ 0 && 
              z[2, x, y] \[GreaterEqual] 0], {x, \(-1\), 1}, {y, 0, 1.3}, 
        PlotPoints \[Rule] 50];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.23"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -12 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.17646 .18758 -23.5978 -9 ]
[.17646 .18758 .40224 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.50253 .05935 -15.8219 -9 ]
[.50253 .05935 2.17811 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.82364 .18307 0 -6.079 ]
[.82364 .18307 18 2.921 ]
[.92719 .34165 0 -5.93039 ]
[.92719 .34165 6 3.06961 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01428 .32672 -30 -2.79442 ]
[.01428 .32672 0 6.20558 ]
[.00405 .39084 -30 -2.84887 ]
[.00405 .39084 0 6.15113 ]
[-0.0066 .45763 -30 -2.90583 ]
[-0.0066 .45763 0 6.09417 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-1)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.5)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.5)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.81126 .18741 m
.80507 .18959 L
s
[(0.5)] .82364 .18307 -1 .35089 Mshowa
.91468 .34562 m
.90843 .34761 L
s
[(1)] .92719 .34165 -1 .31786 Mshowa
.125 Mabswid
.71502 .0402 m
.71134 .04161 L
s
.74036 .07897 m
.73668 .08035 L
s
.76482 .11638 m
.76112 .11774 L
s
.78844 .15251 m
.78473 .15384 L
s
.83332 .22116 m
.82959 .22244 L
s
.85466 .2538 m
.85093 .25506 L
s
.87531 .28539 m
.87157 .28663 L
s
.89531 .31598 m
.89156 .3172 L
s
.93346 .37435 m
.92971 .37552 L
s
.95168 .40221 m
.94791 .40336 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02655 .32206 m
.03269 .31974 L
s
[(0.002)] .01428 .32672 1 -0.37902 Mshowa
.01637 .38632 m
.02253 .38406 L
s
[(0.004)] .00405 .39084 1 -0.36692 Mshowa
.00576 .45325 m
.01195 .45106 L
s
[(0.006)] -0.0066 .45763 1 -0.35426 Mshowa
.125 Mabswid
.03393 .27554 m
.0376 .27411 L
s
.03149 .29089 m
.03517 .28948 L
s
.02904 .3064 m
.03271 .305 L
s
.02405 .33789 m
.02773 .3365 L
s
.02151 .35387 m
.0252 .35249 L
s
.01896 .37001 m
.02265 .36864 L
s
.01376 .40279 m
.01746 .40145 L
s
.01112 .41944 m
.01483 .4181 L
s
.00846 .43626 m
.01216 .43493 L
s
.00304 .47042 m
.00676 .46912 L
s
.00029 .48778 m
.00401 .48648 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.664 .741 .908 r
.39889 .59791 .40512 .60371 .41558 .60058 .40937 .59475 Metetra
.664 .741 .908 r
.40937 .59475 .41558 .60058 .42607 .59743 .41989 .59158 Metetra
.664 .741 .908 r
.41989 .59158 .42607 .59743 .4366 .59427 .43045 .5884 Metetra
.664 .741 .908 r
.43045 .5884 .4366 .59427 .44718 .59109 .44106 .5852 Metetra
.664 .741 .908 r
.44106 .5852 .44718 .59109 .4578 .58791 .4517 .582 Metetra
.664 .741 .908 r
.4517 .582 .4578 .58791 .46846 .58471 .46239 .57878 Metetra
.664 .741 .908 r
.46239 .57878 .46846 .58471 .47916 .5815 .47312 .57554 Metetra
.664 .741 .908 r
.47312 .57554 .47916 .5815 .4899 .57828 .48389 .57229 Metetra
.664 .741 .908 r
.48389 .57229 .4899 .57828 .50069 .57504 .4947 .56904 Metetra
.664 .741 .908 r
.4947 .56904 .50069 .57504 .51152 .57179 .50556 .56576 Metetra
.664 .741 .908 r
.50556 .56576 .51152 .57179 .52239 .56853 .51646 .56248 Metetra
.664 .741 .908 r
.51646 .56248 .52239 .56853 .5333 .56526 .5274 .55918 Metetra
.664 .741 .908 r
.5274 .55918 .5333 .56526 .54426 .56197 .53839 .55587 Metetra
.664 .741 .908 r
.53839 .55587 .54426 .56197 .55526 .55867 .54942 .55254 Metetra
.664 .741 .908 r
.54942 .55254 .55526 .55867 .56631 .55536 .56049 .5492 Metetra
.664 .741 .908 r
.56049 .5492 .56631 .55536 .5774 .55203 .57161 .54585 Metetra
.664 .741 .908 r
.57161 .54585 .5774 .55203 .58853 .54869 .58277 .54249 Metetra
.664 .741 .908 r
.58277 .54249 .58853 .54869 .59971 .54534 .59398 .53911 Metetra
.664 .741 .908 r
.59398 .53911 .59971 .54534 .61094 .54197 .60524 .53572 Metetra
.664 .741 .908 r
.60524 .53572 .61094 .54197 .62221 .53859 .61654 .53231 Metetra
.664 .741 .908 r
.61654 .53231 .62221 .53859 .63352 .53519 .62788 .52889 Metetra
.664 .741 .908 r
.62788 .52889 .63352 .53519 .64488 .53178 .63928 .52546 Metetra
.664 .741 .908 r
.63928 .52546 .64488 .53178 .65629 .52836 .65071 .52201 Metetra
.664 .741 .908 r
.65071 .52201 .65629 .52836 .66774 .52493 .6622 .51855 Metetra
.664 .741 .908 r
.6622 .51855 .66774 .52493 .67924 .52148 .67373 .51507 Metetra
.664 .741 .908 r
.67373 .51507 .67924 .52148 .69079 .51801 .68531 .51158 Metetra
.664 .741 .908 r
.68531 .51158 .69079 .51801 .70238 .51453 .69694 .50808 Metetra
.664 .741 .908 r
.69694 .50808 .70238 .51453 .71403 .51104 .70861 .50456 Metetra
.664 .741 .908 r
.70861 .50456 .71403 .51104 .72572 .50753 .72034 .50102 Metetra
.664 .741 .908 r
.72034 .50102 .72572 .50753 .73745 .50401 .73211 .49747 Metetra
.664 .741 .908 r
.73211 .49747 .73745 .50401 .74924 .50048 .74393 .49391 Metetra
.664 .741 .908 r
.74393 .49391 .74924 .50048 .76108 .49693 .7558 .49033 Metetra
.664 .741 .908 r
.7558 .49033 .76108 .49693 .77296 .49336 .76772 .48674 Metetra
.664 .741 .908 r
.76772 .48674 .77296 .49336 .78489 .48978 .77968 .48313 Metetra
.664 .741 .908 r
.77968 .48313 .78489 .48978 .79688 .48619 .7917 .47951 Metetra
.664 .741 .908 r
.7917 .47951 .79688 .48619 .80891 .48258 .80377 .47587 Metetra
.664 .741 .908 r
.80377 .47587 .80891 .48258 .82099 .47895 .81589 .47222 Metetra
.664 .741 .908 r
.81589 .47222 .82099 .47895 .83313 .47531 .82806 .46855 Metetra
.664 .741 .908 r
.82806 .46855 .83313 .47531 .84531 .47166 .84028 .46487 Metetra
.664 .741 .908 r
.84028 .46487 .84531 .47166 .85755 .46799 .85256 .46117 Metetra
.664 .741 .908 r
.85256 .46117 .85755 .46799 .86983 .4643 .86488 .45745 Metetra
.664 .741 .908 r
.86488 .45745 .86983 .4643 .88217 .4606 .87726 .45372 Metetra
.664 .741 .908 r
.87726 .45372 .88217 .4606 .89457 .45688 .88969 .44998 Metetra
.664 .741 .908 r
.88969 .44998 .89457 .45688 .90701 .45315 .90217 .44621 Metetra
.664 .741 .908 r
.90217 .44621 .90701 .45315 .91951 .4494 .91471 .44243 Metetra
.664 .741 .908 r
.91471 .44243 .91951 .4494 .93206 .44563 .9273 .43864 Metetra
.664 .741 .908 r
.9273 .43864 .93206 .44563 .94466 .44185 .93994 .43483 Metetra
.664 .741 .908 r
.93994 .43483 .94466 .44185 .95732 .43805 .95264 .431 Metetra
.664 .741 .908 r
.95264 .431 .95732 .43805 .97003 .43424 .96539 .42716 Metetra
.664 .741 .908 r
.39262 .59207 .39889 .59791 .40937 .59475 .40313 .58889 Metetra
.664 .741 .908 r
.40313 .58889 .40937 .59475 .41989 .59158 .41367 .5857 Metetra
.664 .741 .908 r
.41367 .5857 .41989 .59158 .43045 .5884 .42426 .58249 Metetra
.664 .741 .908 r
.42426 .58249 .43045 .5884 .44106 .5852 .43489 .57927 Metetra
.664 .741 .908 r
.43489 .57927 .44106 .5852 .4517 .582 .44556 .57604 Metetra
.664 .741 .908 r
.44556 .57604 .4517 .582 .46239 .57878 .45627 .5728 Metetra
.664 .741 .908 r
.45627 .5728 .46239 .57878 .47312 .57554 .46703 .56954 Metetra
.664 .741 .908 r
.46703 .56954 .47312 .57554 .48389 .57229 .47782 .56627 Metetra
.664 .741 .908 r
.47782 .56627 .48389 .57229 .4947 .56904 .48867 .56298 Metetra
.664 .741 .908 r
.48867 .56298 .4947 .56904 .50556 .56576 .49955 .55969 Metetra
.664 .741 .908 r
.49955 .55969 .50556 .56576 .51646 .56248 .51048 .55638 Metetra
.664 .741 .908 r
.51048 .55638 .51646 .56248 .5274 .55918 .52145 .55305 Metetra
.664 .741 .908 r
.52145 .55305 .5274 .55918 .53839 .55587 .53246 .54972 Metetra
.664 .741 .908 r
.53246 .54972 .53839 .55587 .54942 .55254 .54352 .54637 Metetra
.664 .741 .908 r
.54352 .54637 .54942 .55254 .56049 .5492 .55463 .54301 Metetra
.664 .741 .908 r
.55463 .54301 .56049 .5492 .57161 .54585 .56578 .53963 Metetra
.664 .741 .908 r
.56578 .53963 .57161 .54585 .58277 .54249 .57697 .53624 Metetra
.664 .741 .908 r
.57697 .53624 .58277 .54249 .59398 .53911 .58821 .53284 Metetra
.664 .741 .908 r
.58821 .53284 .59398 .53911 .60524 .53572 .5995 .52942 Metetra
.664 .741 .908 r
.5995 .52942 .60524 .53572 .61654 .53231 .61083 .52599 Metetra
.664 .741 .908 r
.61083 .52599 .61654 .53231 .62788 .52889 .6222 .52254 Metetra
.664 .741 .908 r
.6222 .52254 .62788 .52889 .63928 .52546 .63363 .51908 Metetra
.664 .741 .908 r
.63363 .51908 .63928 .52546 .65071 .52201 .6451 .51561 Metetra
.664 .741 .908 r
.6451 .51561 .65071 .52201 .6622 .51855 .65661 .51212 Metetra
.664 .741 .908 r
.65661 .51212 .6622 .51855 .67373 .51507 .66818 .50862 Metetra
.664 .741 .908 r
.66818 .50862 .67373 .51507 .68531 .51158 .67979 .5051 Metetra
.664 .741 .908 r
.67979 .5051 .68531 .51158 .69694 .50808 .69145 .50157 Metetra
.664 .741 .908 r
.69145 .50157 .69694 .50808 .70861 .50456 .70316 .49802 Metetra
.664 .741 .908 r
.70316 .49802 .70861 .50456 .72034 .50102 .71492 .49446 Metetra
.664 .741 .908 r
.71492 .49446 .72034 .50102 .73211 .49747 .72672 .49089 Metetra
.664 .741 .908 r
.72672 .49089 .73211 .49747 .74393 .49391 .73858 .48729 Metetra
.664 .741 .908 r
.73858 .48729 .74393 .49391 .7558 .49033 .75048 .48369 Metetra
.664 .741 .908 r
.75048 .48369 .7558 .49033 .76772 .48674 .76243 .48007 Metetra
.664 .741 .908 r
.76243 .48007 .76772 .48674 .77968 .48313 .77444 .47643 Metetra
.664 .741 .908 r
.77444 .47643 .77968 .48313 .7917 .47951 .78649 .47278 Metetra
.664 .741 .908 r
.78649 .47278 .7917 .47951 .80377 .47587 .79859 .46912 Metetra
.664 .741 .908 r
.79859 .46912 .80377 .47587 .81589 .47222 .81075 .46544 Metetra
.664 .741 .908 r
.81075 .46544 .81589 .47222 .82806 .46855 .82296 .46174 Metetra
.664 .741 .908 r
.82296 .46174 .82806 .46855 .84028 .46487 .83522 .45803 Metetra
.664 .741 .908 r
.83522 .45803 .84028 .46487 .85256 .46117 .84753 .4543 Metetra
.664 .741 .908 r
.84753 .4543 .85256 .46117 .86488 .45745 .85989 .45055 Metetra
.664 .741 .908 r
.85989 .45055 .86488 .45745 .87726 .45372 .8723 .44679 Metetra
.664 .741 .908 r
.8723 .44679 .87726 .45372 .88969 .44998 .88477 .44302 Metetra
.664 .741 .908 r
.88477 .44302 .88969 .44998 .90217 .44621 .89729 .43922 Metetra
.664 .741 .908 r
.89729 .43922 .90217 .44621 .91471 .44243 .90987 .43542 Metetra
.664 .741 .908 r
.90987 .43542 .91471 .44243 .9273 .43864 .9225 .43159 Metetra
.664 .741 .908 r
.9225 .43159 .9273 .43864 .93994 .43483 .93518 .42775 Metetra
.664 .741 .908 r
.93518 .42775 .93994 .43483 .95264 .431 .94792 .42389 Metetra
.664 .741 .908 r
.94792 .42389 .95264 .431 .96539 .42716 .96071 .42002 Metetra
.664 .741 .908 r
.3863 .58619 .39262 .59207 .40313 .58889 .39683 .58298 Metetra
.664 .741 .908 r
.39683 .58298 .40313 .58889 .41367 .5857 .4074 .57977 Metetra
.664 .741 .908 r
.4074 .57977 .41367 .5857 .42426 .58249 .41802 .57654 Metetra
.664 .741 .908 r
.41802 .57654 .42426 .58249 .43489 .57927 .42867 .5733 Metetra
.664 .741 .908 r
.42867 .5733 .43489 .57927 .44556 .57604 .43937 .57004 Metetra
.664 .741 .908 r
.43937 .57004 .44556 .57604 .45627 .5728 .45011 .56677 Metetra
.664 .741 .908 r
.45011 .56677 .45627 .5728 .46703 .56954 .46089 .56349 Metetra
.664 .741 .908 r
.46089 .56349 .46703 .56954 .47782 .56627 .47172 .5602 Metetra
.664 .741 .908 r
.47172 .5602 .47782 .56627 .48867 .56298 .48259 .55689 Metetra
.664 .741 .908 r
.48259 .55689 .48867 .56298 .49955 .55969 .4935 .55357 Metetra
.664 .741 .908 r
.4935 .55357 .49955 .55969 .51048 .55638 .50446 .55023 Metetra
.664 .741 .908 r
.50446 .55023 .51048 .55638 .52145 .55305 .51546 .54689 Metetra
.664 .741 .908 r
.51546 .54689 .52145 .55305 .53246 .54972 .5265 .54352 Metetra
.664 .741 .908 r
.5265 .54352 .53246 .54972 .54352 .54637 .53759 .54015 Metetra
.664 .741 .908 r
.53759 .54015 .54352 .54637 .55463 .54301 .54872 .53676 Metetra
.664 .741 .908 r
.54872 .53676 .55463 .54301 .56578 .53963 .5599 .53336 Metetra
.664 .741 .908 r
.5599 .53336 .56578 .53963 .57697 .53624 .57113 .52994 Metetra
.664 .741 .908 r
.57113 .52994 .57697 .53624 .58821 .53284 .58239 .52651 Metetra
.664 .741 .908 r
.58239 .52651 .58821 .53284 .5995 .52942 .59371 .52307 Metetra
.664 .741 .908 r
.59371 .52307 .5995 .52942 .61083 .52599 .60507 .51961 Metetra
.664 .741 .908 r
.60507 .51961 .61083 .52599 .6222 .52254 .61648 .51614 Metetra
.664 .741 .908 r
.61648 .51614 .6222 .52254 .63363 .51908 .62794 .51266 Metetra
.664 .741 .908 r
.62794 .51266 .63363 .51908 .6451 .51561 .63944 .50916 Metetra
.664 .741 .908 r
.63944 .50916 .6451 .51561 .65661 .51212 .65099 .50564 Metetra
.664 .741 .908 r
.65099 .50564 .65661 .51212 .66818 .50862 .66258 .50211 Metetra
.664 .741 .908 r
.66258 .50211 .66818 .50862 .67979 .5051 .67423 .49857 Metetra
.664 .741 .908 r
.67423 .49857 .67979 .5051 .69145 .50157 .68592 .49501 Metetra
.664 .741 .908 r
.68592 .49501 .69145 .50157 .70316 .49802 .69766 .49144 Metetra
.664 .741 .908 r
.69766 .49144 .70316 .49802 .71492 .49446 .70945 .48785 Metetra
.664 .741 .908 r
.70945 .48785 .71492 .49446 .72672 .49089 .72129 .48425 Metetra
.664 .741 .908 r
.72129 .48425 .72672 .49089 .73858 .48729 .73318 .48063 Metetra
.664 .741 .908 r
.73318 .48063 .73858 .48729 .75048 .48369 .74512 .47699 Metetra
.664 .741 .908 r
.74512 .47699 .75048 .48369 .76243 .48007 .75711 .47335 Metetra
.664 .741 .908 r
.75711 .47335 .76243 .48007 .77444 .47643 .76915 .46968 Metetra
.664 .741 .908 r
.76915 .46968 .77444 .47643 .78649 .47278 .78124 .466 Metetra
.664 .741 .908 r
.78124 .466 .78649 .47278 .79859 .46912 .79338 .46231 Metetra
.664 .741 .908 r
.79338 .46231 .79859 .46912 .81075 .46544 .80557 .4586 Metetra
.664 .741 .908 r
.80557 .4586 .81075 .46544 .82296 .46174 .81781 .45487 Metetra
.664 .741 .908 r
.81781 .45487 .82296 .46174 .83522 .45803 .83011 .45113 Metetra
.664 .741 .908 r
.83011 .45113 .83522 .45803 .84753 .4543 .84246 .44737 Metetra
.664 .741 .908 r
.84246 .44737 .84753 .4543 .85989 .45055 .85486 .4436 Metetra
.664 .741 .908 r
.85486 .4436 .85989 .45055 .8723 .44679 .86731 .43981 Metetra
.664 .741 .908 r
.86731 .43981 .8723 .44679 .88477 .44302 .87982 .436 Metetra
.664 .741 .908 r
.87982 .436 .88477 .44302 .89729 .43922 .89238 .43218 Metetra
.664 .741 .908 r
.89238 .43218 .89729 .43922 .90987 .43542 .90499 .42834 Metetra
.664 .741 .908 r
.90499 .42834 .90987 .43542 .9225 .43159 .91766 .42449 Metetra
.664 .741 .908 r
.91766 .42449 .9225 .43159 .93518 .42775 .93038 .42061 Metetra
.664 .741 .908 r
.93038 .42061 .93518 .42775 .94792 .42389 .94316 .41673 Metetra
.664 .741 .908 r
.94316 .41673 .94792 .42389 .96071 .42002 .956 .41282 Metetra
.664 .741 .908 r
.37994 .58026 .3863 .58619 .39683 .58298 .39049 .57704 Metetra
.664 .741 .908 r
.39049 .57704 .39683 .58298 .4074 .57977 .40109 .57379 Metetra
.664 .741 .908 r
.40109 .57379 .4074 .57977 .41802 .57654 .41173 .57054 Metetra
.664 .741 .908 r
.41173 .57054 .41802 .57654 .42867 .5733 .42241 .56727 Metetra
.664 .741 .908 r
.42241 .56727 .42867 .5733 .43937 .57004 .43314 .564 Metetra
.664 .741 .908 r
.43314 .564 .43937 .57004 .45011 .56677 .4439 .5607 Metetra
.664 .741 .908 r
.4439 .5607 .45011 .56677 .46089 .56349 .45471 .5574 Metetra
.664 .741 .908 r
.45471 .5574 .46089 .56349 .47172 .5602 .46557 .55408 Metetra
.664 .741 .908 r
.46557 .55408 .47172 .5602 .48259 .55689 .47646 .55075 Metetra
.664 .741 .908 r
.47646 .55075 .48259 .55689 .4935 .55357 .4874 .5474 Metetra
.664 .741 .908 r
.4874 .5474 .4935 .55357 .50446 .55023 .49839 .54404 Metetra
.664 .741 .908 r
.49839 .54404 .50446 .55023 .51546 .54689 .50942 .54067 Metetra
.664 .741 .908 r
.50942 .54067 .51546 .54689 .5265 .54352 .52049 .53728 Metetra
.664 .741 .908 r
.52049 .53728 .5265 .54352 .53759 .54015 .53161 .53388 Metetra
.664 .741 .908 r
.53161 .53388 .53759 .54015 .54872 .53676 .54277 .53047 Metetra
.664 .741 .908 r
.54277 .53047 .54872 .53676 .5599 .53336 .55398 .52704 Metetra
.664 .741 .908 r
.55398 .52704 .5599 .53336 .57113 .52994 .56524 .5236 Metetra
.664 .741 .908 r
.56524 .5236 .57113 .52994 .58239 .52651 .57654 .52015 Metetra
.664 .741 .908 r
.57654 .52015 .58239 .52651 .59371 .52307 .58788 .51668 Metetra
.664 .741 .908 r
.58788 .51668 .59371 .52307 .60507 .51961 .59927 .51319 Metetra
.664 .741 .908 r
.59927 .51319 .60507 .51961 .61648 .51614 .61071 .50969 Metetra
.664 .741 .908 r
.61071 .50969 .61648 .51614 .62794 .51266 .6222 .50618 Metetra
.664 .741 .908 r
.6222 .50618 .62794 .51266 .63944 .50916 .63373 .50266 Metetra
.664 .741 .908 r
.63373 .50266 .63944 .50916 .65099 .50564 .64532 .49911 Metetra
.664 .741 .908 r
.64532 .49911 .65099 .50564 .66258 .50211 .65694 .49556 Metetra
.664 .741 .908 r
.65694 .49556 .66258 .50211 .67423 .49857 .66862 .49199 Metetra
.664 .741 .908 r
.66862 .49199 .67423 .49857 .68592 .49501 .68035 .4884 Metetra
.664 .741 .908 r
.68035 .4884 .68592 .49501 .69766 .49144 .69212 .4848 Metetra
.664 .741 .908 r
.69212 .4848 .69766 .49144 .70945 .48785 .70395 .48118 Metetra
.664 .741 .908 r
.70395 .48118 .70945 .48785 .72129 .48425 .71582 .47755 Metetra
.664 .741 .908 r
.71582 .47755 .72129 .48425 .73318 .48063 .72774 .47391 Metetra
.664 .741 .908 r
.72774 .47391 .73318 .48063 .74512 .47699 .73972 .47025 Metetra
.664 .741 .908 r
.73972 .47025 .74512 .47699 .75711 .47335 .75174 .46657 Metetra
.664 .741 .908 r
.75174 .46657 .75711 .47335 .76915 .46968 .76382 .46288 Metetra
.664 .741 .908 r
.76382 .46288 .76915 .46968 .78124 .466 .77594 .45917 Metetra
.664 .741 .908 r
.77594 .45917 .78124 .466 .79338 .46231 .78812 .45545 Metetra
.664 .741 .908 r
.78812 .45545 .79338 .46231 .80557 .4586 .80035 .45171 Metetra
.664 .741 .908 r
.80035 .45171 .80557 .4586 .81781 .45487 .81263 .44795 Metetra
.664 .741 .908 r
.81263 .44795 .81781 .45487 .83011 .45113 .82496 .44418 Metetra
.664 .741 .908 r
.82496 .44418 .83011 .45113 .84246 .44737 .83735 .44039 Metetra
.664 .741 .908 r
.83735 .44039 .84246 .44737 .85486 .4436 .84978 .43659 Metetra
.664 .741 .908 r
.84978 .43659 .85486 .4436 .86731 .43981 .86228 .43277 Metetra
.664 .741 .908 r
.86228 .43277 .86731 .43981 .87982 .436 .87482 .42893 Metetra
.664 .741 .908 r
.87482 .42893 .87982 .436 .89238 .43218 .88742 .42508 Metetra
.664 .741 .908 r
.88742 .42508 .89238 .43218 .90499 .42834 .90008 .42121 Metetra
.664 .741 .908 r
.90008 .42121 .90499 .42834 .91766 .42449 .91278 .41732 Metetra
.664 .741 .908 r
.91278 .41732 .91766 .42449 .93038 .42061 .92555 .41342 Metetra
.664 .741 .908 r
.92555 .41342 .93038 .42061 .94316 .41673 .93837 .4095 Metetra
.664 .741 .908 r
.93837 .4095 .94316 .41673 .956 .41282 .95124 .40556 Metetra
.664 .741 .908 r
.37353 .57429 .37994 .58026 .39049 .57704 .38411 .57104 Metetra
.664 .741 .908 r
.38411 .57104 .39049 .57704 .40109 .57379 .39473 .56778 Metetra
.664 .741 .908 r
.39473 .56778 .40109 .57379 .41173 .57054 .4054 .5645 Metetra
.664 .741 .908 r
.4054 .5645 .41173 .57054 .42241 .56727 .41611 .56121 Metetra
.664 .741 .908 r
.41611 .56121 .42241 .56727 .43314 .564 .42686 .55791 Metetra
.664 .741 .908 r
.42686 .55791 .43314 .564 .4439 .5607 .43765 .55459 Metetra
.664 .741 .908 r
.43765 .55459 .4439 .5607 .45471 .5574 .44849 .55126 Metetra
.664 .741 .908 r
.44849 .55126 .45471 .5574 .46557 .55408 .45937 .54792 Metetra
.664 .741 .908 r
.45937 .54792 .46557 .55408 .47646 .55075 .4703 .54456 Metetra
.664 .741 .908 r
.4703 .54456 .47646 .55075 .4874 .5474 .48126 .54119 Metetra
.664 .741 .908 r
.48126 .54119 .4874 .5474 .49839 .54404 .49228 .53781 Metetra
.664 .741 .908 r
.49228 .53781 .49839 .54404 .50942 .54067 .50334 .53441 Metetra
.664 .741 .908 r
.50334 .53441 .50942 .54067 .52049 .53728 .51444 .531 Metetra
.664 .741 .908 r
.51444 .531 .52049 .53728 .53161 .53388 .52558 .52757 Metetra
.664 .741 .908 r
.52558 .52757 .53161 .53388 .54277 .53047 .53678 .52413 Metetra
.664 .741 .908 r
.53678 .52413 .54277 .53047 .55398 .52704 .54802 .52068 Metetra
.664 .741 .908 r
.54802 .52068 .55398 .52704 .56524 .5236 .5593 .51721 Metetra
.664 .741 .908 r
.5593 .51721 .56524 .5236 .57654 .52015 .57063 .51373 Metetra
.664 .741 .908 r
.57063 .51373 .57654 .52015 .58788 .51668 .58201 .51023 Metetra
.664 .741 .908 r
.58201 .51023 .58788 .51668 .59927 .51319 .59343 .50672 Metetra
.664 .741 .908 r
.59343 .50672 .59927 .51319 .61071 .50969 .6049 .5032 Metetra
.664 .741 .908 r
.6049 .5032 .61071 .50969 .6222 .50618 .61642 .49966 Metetra
.664 .741 .908 r
.61642 .49966 .6222 .50618 .63373 .50266 .62799 .49611 Metetra
.664 .741 .908 r
.62799 .49611 .63373 .50266 .64532 .49911 .6396 .49254 Metetra
.664 .741 .908 r
.6396 .49254 .64532 .49911 .65694 .49556 .65126 .48895 Metetra
.664 .741 .908 r
.65126 .48895 .65694 .49556 .66862 .49199 .66297 .48536 Metetra
.664 .741 .908 r
.66297 .48536 .66862 .49199 .68035 .4884 .67473 .48174 Metetra
.664 .741 .908 r
.67473 .48174 .68035 .4884 .69212 .4848 .68654 .47811 Metetra
.664 .741 .908 r
.68654 .47811 .69212 .4848 .70395 .48118 .6984 .47447 Metetra
.664 .741 .908 r
.6984 .47447 .70395 .48118 .71582 .47755 .71031 .47081 Metetra
.664 .741 .908 r
.71031 .47081 .71582 .47755 .72774 .47391 .72227 .46714 Metetra
.664 .741 .908 r
.72227 .46714 .72774 .47391 .73972 .47025 .73427 .46345 Metetra
.664 .741 .908 r
.73427 .46345 .73972 .47025 .75174 .46657 .74633 .45974 Metetra
.664 .741 .908 r
.74633 .45974 .75174 .46657 .76382 .46288 .75844 .45602 Metetra
.664 .741 .908 r
.75844 .45602 .76382 .46288 .77594 .45917 .77061 .45228 Metetra
.664 .741 .908 r
.77061 .45228 .77594 .45917 .78812 .45545 .78282 .44853 Metetra
.664 .741 .908 r
.78282 .44853 .78812 .45545 .80035 .45171 .79508 .44476 Metetra
.664 .741 .908 r
.79508 .44476 .80035 .45171 .81263 .44795 .8074 .44098 Metetra
.664 .741 .908 r
.8074 .44098 .81263 .44795 .82496 .44418 .81977 .43718 Metetra
.664 .741 .908 r
.81977 .43718 .82496 .44418 .83735 .44039 .8322 .43336 Metetra
.664 .741 .908 r
.8322 .43336 .83735 .44039 .84978 .43659 .84467 .42952 Metetra
.664 .741 .908 r
.84467 .42952 .84978 .43659 .86228 .43277 .8572 .42567 Metetra
.664 .741 .908 r
.8572 .42567 .86228 .43277 .87482 .42893 .86979 .42181 Metetra
.664 .741 .908 r
.86979 .42181 .87482 .42893 .88742 .42508 .88243 .41792 Metetra
.664 .741 .908 r
.88243 .41792 .88742 .42508 .90008 .42121 .89512 .41402 Metetra
.664 .741 .908 r
.89512 .41402 .90008 .42121 .91278 .41732 .90787 .41011 Metetra
.664 .741 .908 r
.90787 .41011 .91278 .41732 .92555 .41342 .92067 .40617 Metetra
.664 .741 .908 r
.92067 .40617 .92555 .41342 .93837 .4095 .93353 .40222 Metetra
.664 .741 .908 r
.93353 .40222 .93837 .4095 .95124 .40556 .94645 .39825 Metetra
.664 .741 .908 r
.36707 .56828 .37353 .57429 .38411 .57104 .37768 .56501 Metetra
.664 .741 .908 r
.37768 .56501 .38411 .57104 .39473 .56778 .38833 .56172 Metetra
.664 .741 .908 r
.38833 .56172 .39473 .56778 .4054 .5645 .39902 .55842 Metetra
.664 .741 .908 r
.39902 .55842 .4054 .5645 .41611 .56121 .40975 .5551 Metetra
.664 .741 .908 r
.40975 .5551 .41611 .56121 .42686 .55791 .42053 .55177 Metetra
.664 .741 .908 r
.42053 .55177 .42686 .55791 .43765 .55459 .43135 .54843 Metetra
.664 .741 .908 r
.43135 .54843 .43765 .55459 .44849 .55126 .44222 .54508 Metetra
.664 .741 .908 r
.44222 .54508 .44849 .55126 .45937 .54792 .45313 .54171 Metetra
.664 .741 .908 r
.45313 .54171 .45937 .54792 .4703 .54456 .46408 .53833 Metetra
.664 .741 .908 r
.46408 .53833 .4703 .54456 .48126 .54119 .47508 .53493 Metetra
.664 .741 .908 r
.47508 .53493 .48126 .54119 .49228 .53781 .48612 .53152 Metetra
.664 .741 .908 r
.48612 .53152 .49228 .53781 .50334 .53441 .49721 .5281 Metetra
.664 .741 .908 r
.49721 .5281 .50334 .53441 .51444 .531 .50834 .52466 Metetra
.664 .741 .908 r
.50834 .52466 .51444 .531 .52558 .52757 .51952 .52121 Metetra
.664 .741 .908 r
.51952 .52121 .52558 .52757 .53678 .52413 .53074 .51775 Metetra
.664 .741 .908 r
.53074 .51775 .53678 .52413 .54802 .52068 .54201 .51427 Metetra
.664 .741 .908 r
.54201 .51427 .54802 .52068 .5593 .51721 .55332 .51077 Metetra
.664 .741 .908 r
.55332 .51077 .5593 .51721 .57063 .51373 .56468 .50726 Metetra
.664 .741 .908 r
.56468 .50726 .57063 .51373 .58201 .51023 .57609 .50374 Metetra
.664 .741 .908 r
.57609 .50374 .58201 .51023 .59343 .50672 .58755 .50021 Metetra
.664 .741 .908 r
.58755 .50021 .59343 .50672 .6049 .5032 .59905 .49665 Metetra
.664 .741 .908 r
.59905 .49665 .6049 .5032 .61642 .49966 .6106 .49309 Metetra
.664 .741 .908 r
.6106 .49309 .61642 .49966 .62799 .49611 .6222 .48951 Metetra
.664 .741 .908 r
.6222 .48951 .62799 .49611 .6396 .49254 .63384 .48591 Metetra
.664 .741 .908 r
.63384 .48591 .6396 .49254 .65126 .48895 .64554 .4823 Metetra
.664 .741 .908 r
.64554 .4823 .65126 .48895 .66297 .48536 .65728 .47867 Metetra
.664 .741 .908 r
.65728 .47867 .66297 .48536 .67473 .48174 .66907 .47503 Metetra
.664 .741 .908 r
.66907 .47503 .67473 .48174 .68654 .47811 .68092 .47137 Metetra
.664 .741 .908 r
.68092 .47137 .68654 .47811 .6984 .47447 .69281 .4677 Metetra
.664 .741 .908 r
.69281 .4677 .6984 .47447 .71031 .47081 .70475 .46402 Metetra
.664 .741 .908 r
.70475 .46402 .71031 .47081 .72227 .46714 .71675 .46031 Metetra
.664 .741 .908 r
.71675 .46031 .72227 .46714 .73427 .46345 .72879 .45659 Metetra
.664 .741 .908 r
.72879 .45659 .73427 .46345 .74633 .45974 .74088 .45286 Metetra
.664 .741 .908 r
.74088 .45286 .74633 .45974 .75844 .45602 .75303 .44911 Metetra
.664 .741 .908 r
.75303 .44911 .75844 .45602 .77061 .45228 .76523 .44534 Metetra
.664 .741 .908 r
.76523 .44534 .77061 .45228 .78282 .44853 .77748 .44156 Metetra
.664 .741 .908 r
.77748 .44156 .78282 .44853 .79508 .44476 .78978 .43776 Metetra
.664 .741 .908 r
.78978 .43776 .79508 .44476 .8074 .44098 .80214 .43395 Metetra
.664 .741 .908 r
.80214 .43395 .8074 .44098 .81977 .43718 .81454 .43012 Metetra
.664 .741 .908 r
.81454 .43012 .81977 .43718 .8322 .43336 .827 .42627 Metetra
.664 .741 .908 r
.827 .42627 .8322 .43336 .84467 .42952 .83952 .4224 Metetra
.664 .741 .908 r
.83952 .4224 .84467 .42952 .8572 .42567 .85209 .41852 Metetra
.664 .741 .908 r
.85209 .41852 .8572 .42567 .86979 .42181 .86471 .41462 Metetra
.664 .741 .908 r
.86471 .41462 .86979 .42181 .88243 .41792 .87739 .41071 Metetra
.664 .741 .908 r
.87739 .41071 .88243 .41792 .89512 .41402 .89013 .40678 Metetra
.94 .587 .182 r
.89013 .40678 .89512 .41402 .90787 .41011 .91597 .51423 Metetra
.299 .14 .49 r
.91597 .51423 .90787 .41011 .92067 .40617 .92046 .43758 Metetra
.908 .574 .4 r
.92046 .43758 .92067 .40617 .93353 .40222 .95111 .57373 Metetra
.619 .381 .534 r
.95111 .57373 .93353 .40222 .94645 .39825 .97041 .61284 Metetra
.664 .741 .908 r
.36056 .56222 .36707 .56828 .37768 .56501 .3712 .55892 Metetra
.664 .741 .908 r
.3712 .55892 .37768 .56501 .38833 .56172 .38187 .55561 Metetra
.664 .741 .908 r
.38187 .55561 .38833 .56172 .39902 .55842 .39259 .55229 Metetra
.664 .741 .908 r
.39259 .55229 .39902 .55842 .40975 .5551 .40336 .54895 Metetra
.664 .741 .908 r
.40336 .54895 .40975 .5551 .42053 .55177 .41416 .54559 Metetra
.664 .741 .908 r
.41416 .54559 .42053 .55177 .43135 .54843 .42501 .54223 Metetra
.664 .741 .908 r
.42501 .54223 .43135 .54843 .44222 .54508 .4359 .53885 Metetra
.664 .741 .908 r
.4359 .53885 .44222 .54508 .45313 .54171 .44684 .53545 Metetra
.664 .741 .908 r
.44684 .53545 .45313 .54171 .46408 .53833 .45782 .53205 Metetra
.664 .741 .908 r
.45782 .53205 .46408 .53833 .47508 .53493 .46885 .52863 Metetra
.664 .741 .908 r
.46885 .52863 .47508 .53493 .48612 .53152 .47992 .52519 Metetra
.664 .741 .908 r
.47992 .52519 .48612 .53152 .49721 .5281 .49103 .52174 Metetra
.664 .741 .908 r
.49103 .52174 .49721 .5281 .50834 .52466 .50219 .51828 Metetra
.664 .741 .908 r
.50219 .51828 .50834 .52466 .51952 .52121 .5134 .5148 Metetra
.664 .741 .908 r
.5134 .5148 .51952 .52121 .53074 .51775 .52465 .51131 Metetra
.664 .741 .908 r
.52465 .51131 .53074 .51775 .54201 .51427 .53595 .50781 Metetra
.664 .741 .908 r
.53595 .50781 .54201 .51427 .55332 .51077 .5473 .50429 Metetra
.664 .741 .908 r
.5473 .50429 .55332 .51077 .56468 .50726 .55869 .50075 Metetra
.664 .741 .908 r
.55869 .50075 .56468 .50726 .57609 .50374 .57013 .4972 Metetra
.664 .741 .908 r
.57013 .4972 .57609 .50374 .58755 .50021 .58161 .49364 Metetra
.664 .741 .908 r
.58161 .49364 .58755 .50021 .59905 .49665 .59315 .49006 Metetra
.664 .741 .908 r
.59315 .49006 .59905 .49665 .6106 .49309 .60473 .48646 Metetra
.664 .741 .908 r
.60473 .48646 .6106 .49309 .6222 .48951 .61636 .48286 Metetra
.664 .741 .908 r
.61636 .48286 .6222 .48951 .63384 .48591 .62804 .47923 Metetra
.664 .741 .908 r
.62804 .47923 .63384 .48591 .64554 .4823 .63977 .47559 Metetra
.664 .741 .908 r
.63977 .47559 .64554 .4823 .65728 .47867 .65155 .47194 Metetra
.664 .741 .908 r
.65155 .47194 .65728 .47867 .66907 .47503 .66337 .46827 Metetra
.664 .741 .908 r
.66337 .46827 .66907 .47503 .68092 .47137 .67525 .46458 Metetra
.664 .741 .908 r
.67525 .46458 .68092 .47137 .69281 .4677 .68718 .46088 Metetra
.664 .741 .908 r
.68718 .46088 .69281 .4677 .70475 .46402 .69915 .45717 Metetra
.664 .741 .908 r
.69915 .45717 .70475 .46402 .71675 .46031 .71118 .45343 Metetra
.664 .741 .908 r
.71118 .45343 .71675 .46031 .72879 .45659 .72326 .44969 Metetra
.664 .741 .908 r
.72326 .44969 .72879 .45659 .74088 .45286 .73539 .44592 Metetra
.664 .741 .908 r
.73539 .44592 .74088 .45286 .75303 .44911 .74757 .44214 Metetra
.664 .741 .908 r
.74757 .44214 .75303 .44911 .76523 .44534 .75981 .43835 Metetra
.664 .741 .908 r
.75981 .43835 .76523 .44534 .77748 .44156 .77209 .43453 Metetra
.664 .741 .908 r
.77209 .43453 .77748 .44156 .78978 .43776 .78443 .43071 Metetra
.664 .741 .908 r
.78443 .43071 .78978 .43776 .80214 .43395 .79683 .42686 Metetra
.664 .741 .908 r
.79683 .42686 .80214 .43395 .81454 .43012 .80927 .423 Metetra
.664 .741 .908 r
.80927 .423 .81454 .43012 .827 .42627 .82177 .41912 Metetra
.664 .741 .908 r
.82177 .41912 .827 .42627 .83952 .4224 .83433 .41523 Metetra
.967 .641 .294 r
.83433 .41523 .83952 .4224 .85209 .41852 .86891 .63202 Metetra
.56 .34 .538 r
.86891 .63202 .85209 .41852 .86471 .41462 .88249 .62833 Metetra
.556 .337 .538 r
.88249 .62833 .86471 .41462 .87739 .41071 .89586 .62202 Metetra
.395 .221 .523 r
.89586 .62202 .87739 .41071 .89013 .40678 .89796 .51462 Metetra
.156 .038 .456 r
.89796 .51462 .89013 .40678 .91597 .51423 .8991 .40563 Metetra
.336 .225 .577 r
.8991 .40563 .91597 .51423 .92046 .43758 .92085 .47516 Metetra
.803 .48 .443 r
.92085 .47516 .92046 .43758 .95111 .57373 .94222 .53614 Metetra
.583 .447 .661 r
.94222 .53614 .95111 .57373 .97041 .61284 .95624 .53518 Metetra
.664 .741 .908 r
.35401 .55612 .36056 .56222 .3712 .55892 .36467 .5528 Metetra
.664 .741 .908 r
.36467 .5528 .3712 .55892 .38187 .55561 .37537 .54946 Metetra
.664 .741 .908 r
.37537 .54946 .38187 .55561 .39259 .55229 .38612 .54611 Metetra
.664 .741 .908 r
.38612 .54611 .39259 .55229 .40336 .54895 .39691 .54275 Metetra
.664 .741 .908 r
.39691 .54275 .40336 .54895 .41416 .54559 .40774 .53937 Metetra
.664 .741 .908 r
.40774 .53937 .41416 .54559 .42501 .54223 .41862 .53598 Metetra
.664 .741 .908 r
.41862 .53598 .42501 .54223 .4359 .53885 .42954 .53257 Metetra
.664 .741 .908 r
.42954 .53257 .4359 .53885 .44684 .53545 .4405 .52915 Metetra
.664 .741 .908 r
.4405 .52915 .44684 .53545 .45782 .53205 .45151 .52572 Metetra
.664 .741 .908 r
.45151 .52572 .45782 .53205 .46885 .52863 .46257 .52227 Metetra
.664 .741 .908 r
.46257 .52227 .46885 .52863 .47992 .52519 .47367 .51881 Metetra
.664 .741 .908 r
.47367 .51881 .47992 .52519 .49103 .52174 .48481 .51534 Metetra
.664 .741 .908 r
.48481 .51534 .49103 .52174 .50219 .51828 .496 .51185 Metetra
.664 .741 .908 r
.496 .51185 .50219 .51828 .5134 .5148 .50724 .50835 Metetra
.664 .741 .908 r
.50724 .50835 .5134 .5148 .52465 .51131 .51852 .50483 Metetra
.664 .741 .908 r
.51852 .50483 .52465 .51131 .53595 .50781 .52985 .5013 Metetra
.664 .741 .908 r
.52985 .5013 .53595 .50781 .5473 .50429 .54123 .49775 Metetra
.664 .741 .908 r
.54123 .49775 .5473 .50429 .55869 .50075 .55265 .49419 Metetra
.664 .741 .908 r
.55265 .49419 .55869 .50075 .57013 .4972 .56412 .49061 Metetra
.664 .741 .908 r
.56412 .49061 .57013 .4972 .58161 .49364 .57564 .48702 Metetra
.664 .741 .908 r
.57564 .48702 .58161 .49364 .59315 .49006 .5872 .48341 Metetra
.664 .741 .908 r
.5872 .48341 .59315 .49006 .60473 .48646 .59882 .47979 Metetra
.664 .741 .908 r
.59882 .47979 .60473 .48646 .61636 .48286 .61048 .47615 Metetra
.664 .741 .908 r
.61048 .47615 .61636 .48286 .62804 .47923 .62219 .4725 Metetra
.664 .741 .908 r
.62219 .4725 .62804 .47923 .63977 .47559 .63395 .46883 Metetra
.664 .741 .908 r
.63395 .46883 .63977 .47559 .65155 .47194 .64577 .46515 Metetra
.664 .741 .908 r
.64577 .46515 .65155 .47194 .66337 .46827 .65763 .46145 Metetra
.664 .741 .908 r
.65763 .46145 .66337 .46827 .67525 .46458 .66954 .45774 Metetra
.664 .741 .908 r
.66954 .45774 .67525 .46458 .68718 .46088 .6815 .45401 Metetra
.664 .741 .908 r
.6815 .45401 .68718 .46088 .69915 .45717 .69351 .45026 Metetra
.664 .741 .908 r
.69351 .45026 .69915 .45717 .71118 .45343 .70557 .4465 Metetra
.664 .741 .908 r
.70557 .4465 .71118 .45343 .72326 .44969 .71769 .44273 Metetra
.664 .741 .908 r
.71769 .44273 .72326 .44969 .73539 .44592 .72985 .43893 Metetra
.664 .741 .908 r
.72985 .43893 .73539 .44592 .74757 .44214 .74207 .43512 Metetra
.664 .741 .908 r
.74207 .43512 .74757 .44214 .75981 .43835 .75434 .4313 Metetra
.664 .741 .908 r
.75434 .4313 .75981 .43835 .77209 .43453 .76667 .42745 Metetra
.664 .741 .908 r
.76667 .42745 .77209 .43453 .78443 .43071 .77904 .42359 Metetra
.964 .635 .296 r
.77904 .42359 .78443 .43071 .79683 .42686 .80399 .57191 Metetra
.645 .398 .53 r
.80399 .57191 .79683 .42686 .80927 .423 .82174 .62212 Metetra
.577 .351 .536 r
.82174 .62212 .80927 .423 .82177 .41912 .83639 .63258 Metetra
.558 .338 .536 r
.83639 .63258 .82177 .41912 .83433 .41523 .84989 .6289 Metetra
.534 .32 .535 r
.84989 .6289 .83433 .41523 .86891 .63202 .8617 .60736 Metetra
.884 .656 .589 r
.8617 .60736 .86891 .63202 .88249 .62833 .86981 .55034 Metetra
.763 .529 .579 r
.86981 .55034 .88249 .62833 .89586 .62202 .87601 .47891 Metetra
.697 .469 .573 r
.87601 .47891 .89586 .62202 .89796 .51462 .88141 .40473 Metetra
.474 .319 .589 r
.88141 .40473 .89796 .51462 .8991 .40563 .89841 .43632 Metetra
.741 .417 .434 r
.89841 .43632 .8991 .40563 .92085 .47516 .91585 .46856 Metetra
.886 .827 .784 r
.91585 .46856 .92085 .47516 .94222 .53614 .9277 .45238 Metetra
.741 .509 .579 r
.9277 .45238 .94222 .53614 .95624 .53518 .93341 .38829 Metetra
.664 .741 .908 r
.34741 .54998 .35401 .55612 .36467 .5528 .3581 .54663 Metetra
.664 .741 .908 r
.3581 .54663 .36467 .5528 .37537 .54946 .36882 .54327 Metetra
.664 .741 .908 r
.36882 .54327 .37537 .54946 .38612 .54611 .3796 .53989 Metetra
.664 .741 .908 r
.3796 .53989 .38612 .54611 .39691 .54275 .39041 .5365 Metetra
.664 .741 .908 r
.39041 .5365 .39691 .54275 .40774 .53937 .40127 .5331 Metetra
.664 .741 .908 r
.40127 .5331 .40774 .53937 .41862 .53598 .41218 .52968 Metetra
.664 .741 .908 r
.41218 .52968 .41862 .53598 .42954 .53257 .42313 .52625 Metetra
.664 .741 .908 r
.42313 .52625 .42954 .53257 .4405 .52915 .43412 .52281 Metetra
.664 .741 .908 r
.43412 .52281 .4405 .52915 .45151 .52572 .44516 .51935 Metetra
.664 .741 .908 r
.44516 .51935 .45151 .52572 .46257 .52227 .45624 .51587 Metetra
.664 .741 .908 r
.45624 .51587 .46257 .52227 .47367 .51881 .46737 .51239 Metetra
.664 .741 .908 r
.46737 .51239 .47367 .51881 .48481 .51534 .47854 .50889 Metetra
.664 .741 .908 r
.47854 .50889 .48481 .51534 .496 .51185 .48976 .50537 Metetra
.664 .741 .908 r
.48976 .50537 .496 .51185 .50724 .50835 .50103 .50184 Metetra
.664 .741 .908 r
.50103 .50184 .50724 .50835 .51852 .50483 .51234 .49829 Metetra
.664 .741 .908 r
.51234 .49829 .51852 .50483 .52985 .5013 .5237 .49474 Metetra
.664 .741 .908 r
.5237 .49474 .52985 .5013 .54123 .49775 .53511 .49116 Metetra
.664 .741 .908 r
.53511 .49116 .54123 .49775 .55265 .49419 .54656 .48757 Metetra
.664 .741 .908 r
.54656 .48757 .55265 .49419 .56412 .49061 .55806 .48397 Metetra
.664 .741 .908 r
.55806 .48397 .56412 .49061 .57564 .48702 .56961 .48035 Metetra
.664 .741 .908 r
.56961 .48035 .57564 .48702 .5872 .48341 .58121 .47671 Metetra
.664 .741 .908 r
.58121 .47671 .5872 .48341 .59882 .47979 .59286 .47306 Metetra
.664 .741 .908 r
.59286 .47306 .59882 .47979 .61048 .47615 .60455 .4694 Metetra
.664 .741 .908 r
.60455 .4694 .61048 .47615 .62219 .4725 .6163 .46572 Metetra
.664 .741 .908 r
.6163 .46572 .62219 .4725 .63395 .46883 .62809 .46202 Metetra
.664 .741 .908 r
.62809 .46202 .63395 .46883 .64577 .46515 .63994 .45831 Metetra
.664 .741 .908 r
.63994 .45831 .64577 .46515 .65763 .46145 .65183 .45458 Metetra
.664 .741 .908 r
.65183 .45458 .65763 .46145 .66954 .45774 .66378 .45084 Metetra
.664 .741 .908 r
.66378 .45084 .66954 .45774 .6815 .45401 .67578 .44708 Metetra
.664 .741 .908 r
.67578 .44708 .6815 .45401 .69351 .45026 .68782 .44331 Metetra
.664 .741 .908 r
.68782 .44331 .69351 .45026 .70557 .4465 .69992 .43952 Metetra
.664 .741 .908 r
.69992 .43952 .70557 .4465 .71769 .44273 .71207 .43571 Metetra
.664 .741 .908 r
.71207 .43571 .71769 .44273 .72985 .43893 .72427 .43189 Metetra
.962 .629 .299 r
.72427 .43189 .72985 .43893 .74207 .43512 .74412 .5447 Metetra
.27 .107 .467 r
.74412 .5447 .74207 .43512 .75434 .4313 .75183 .46765 Metetra
.258 .04 .381 r
.75183 .46765 .75434 .4313 .76667 .42745 .76276 .44169 Metetra
.867 .516 .383 r
.76276 .44169 .76667 .42745 .77904 .42359 .77947 .4927 Metetra
.677 .406 .503 r
.77947 .4927 .77904 .42359 .80399 .57191 .79551 .52925 Metetra
.42 .326 .643 r
.79551 .52925 .80399 .57191 .82174 .62212 .81032 .54695 Metetra
.584 .407 .608 r
.81032 .54695 .82174 .62212 .83639 .63258 .8235 .54357 Metetra
.643 .442 .596 r
.8235 .54357 .83639 .63258 .84989 .6289 .83485 .51972 Metetra
.666 .453 .586 r
.83485 .51972 .84989 .6289 .8617 .60736 .84448 .47911 Metetra
.672 .453 .579 r
.84448 .47911 .8617 .60736 .86981 .55034 .85283 .42832 Metetra
.63 .424 .584 r
.85283 .42832 .86981 .55034 .87601 .47891 .86336 .40126 Metetra
.404 .281 .598 r
.86336 .40126 .87601 .47891 .88141 .40473 .88063 .43724 Metetra
.64 .335 .438 r
.88063 .43724 .88141 .40473 .89841 .43632 .89572 .45045 Metetra
0 0 .016 r
.89572 .45045 .89841 .43632 .91585 .46856 .90615 .42227 Metetra
.636 .464 .634 r
.90615 .42227 .91585 .46856 .9277 .45238 .91856 .41154 Metetra
.789 .511 0 r
.91856 .41154 .9277 .45238 .93341 .38829 .95465 .58876 Metetra
.664 .741 .908 r
.34076 .54378 .34741 .54998 .3581 .54663 .35147 .54041 Metetra
.664 .741 .908 r
.35147 .54041 .3581 .54663 .36882 .54327 .36223 .53702 Metetra
.664 .741 .908 r
.36223 .53702 .36882 .54327 .3796 .53989 .37303 .53362 Metetra
.664 .741 .908 r
.37303 .53362 .3796 .53989 .39041 .5365 .38387 .53021 Metetra
.664 .741 .908 r
.38387 .53021 .39041 .5365 .40127 .5331 .39476 .52678 Metetra
.664 .741 .908 r
.39476 .52678 .40127 .5331 .41218 .52968 .40569 .52334 Metetra
.664 .741 .908 r
.40569 .52334 .41218 .52968 .42313 .52625 .41667 .51988 Metetra
.664 .741 .908 r
.41667 .51988 .42313 .52625 .43412 .52281 .42769 .51641 Metetra
.664 .741 .908 r
.42769 .51641 .43412 .52281 .44516 .51935 .43875 .51292 Metetra
.664 .741 .908 r
.43875 .51292 .44516 .51935 .45624 .51587 .44986 .50943 Metetra
.664 .741 .908 r
.44986 .50943 .45624 .51587 .46737 .51239 .46102 .50591 Metetra
.664 .741 .908 r
.46102 .50591 .46737 .51239 .47854 .50889 .47223 .50238 Metetra
.664 .741 .908 r
.47223 .50238 .47854 .50889 .48976 .50537 .48348 .49884 Metetra
.664 .741 .908 r
.48348 .49884 .48976 .50537 .50103 .50184 .49477 .49528 Metetra
.664 .741 .908 r
.49477 .49528 .50103 .50184 .51234 .49829 .50612 .49171 Metetra
.664 .741 .908 r
.50612 .49171 .51234 .49829 .5237 .49474 .51751 .48812 Metetra
.664 .741 .908 r
.51751 .48812 .5237 .49474 .53511 .49116 .52894 .48452 Metetra
.664 .741 .908 r
.52894 .48452 .53511 .49116 .54656 .48757 .54043 .48091 Metetra
.664 .741 .908 r
.54043 .48091 .54656 .48757 .55806 .48397 .55196 .47727 Metetra
.664 .741 .908 r
.55196 .47727 .55806 .48397 .56961 .48035 .56354 .47363 Metetra
.664 .741 .908 r
.56354 .47363 .56961 .48035 .58121 .47671 .57517 .46996 Metetra
.664 .741 .908 r
.57517 .46996 .58121 .47671 .59286 .47306 .58685 .46629 Metetra
.664 .741 .908 r
.58685 .46629 .59286 .47306 .60455 .4694 .59858 .46259 Metetra
.664 .741 .908 r
.59858 .46259 .60455 .4694 .6163 .46572 .61036 .45888 Metetra
.664 .741 .908 r
.61036 .45888 .6163 .46572 .62809 .46202 .62219 .45516 Metetra
.664 .741 .908 r
.62219 .45516 .62809 .46202 .63994 .45831 .63407 .45142 Metetra
.664 .741 .908 r
.63407 .45142 .63994 .45831 .65183 .45458 .646 .44766 Metetra
.664 .741 .908 r
.646 .44766 .65183 .45458 .66378 .45084 .65798 .44389 Metetra
.664 .741 .908 r
.65798 .44389 .66378 .45084 .67578 .44708 .67001 .4401 Metetra
.969 .661 .378 r
.67001 .4401 .67578 .44708 .68782 .44331 .69266 .65542 Metetra
.535 .318 .531 r
.69266 .65542 .68782 .44331 .69992 .43952 .70489 .63741 Metetra
.468 .266 .521 r
.70489 .63741 .69992 .43952 .71207 .43571 .71502 .58288 Metetra
.415 .22 .506 r
.71502 .58288 .71207 .43571 .72427 .43189 .72456 .52391 Metetra
.303 .124 .464 r
.72456 .52391 .72427 .43189 .74412 .5447 .73382 .46615 Metetra
.711 .494 .592 r
.73382 .46615 .74412 .5447 .75183 .46765 .74346 .41968 Metetra
.251 .197 .6 r
.74346 .41968 .75183 .46765 .76276 .44169 .75867 .45496 Metetra
.778 .404 .349 r
.75867 .45496 .76276 .44169 .77947 .4927 .77335 .4785 Metetra
.313 .407 .799 r
.77335 .4785 .77947 .4927 .79551 .52925 .78713 .48718 Metetra
.623 .462 .643 r
.78713 .48718 .79551 .52925 .81032 .54695 .79972 .47964 Metetra
.66 .463 .606 r
.79972 .47964 .81032 .54695 .8235 .54357 .811 .45671 Metetra
.674 .463 .592 r
.811 .45671 .8235 .54357 .83485 .51972 .82107 .42157 Metetra
.632 .43 .591 r
.82107 .42157 .83485 .51972 .84448 .47911 .83215 .39909 Metetra
.411 .284 .595 r
.83215 .39909 .84448 .47911 .85283 .42832 .84883 .43381 Metetra
.833 .401 .207 r
.84883 .43381 .85283 .42832 .86336 .40126 .86498 .45979 Metetra
.571 .312 .484 r
.86498 .45979 .86336 .40126 .88063 .43724 .87907 .46376 Metetra
.001 0 .269 r
.87907 .46376 .88063 .43724 .89572 .45045 .88908 .43014 Metetra
.858 .658 .631 r
.88908 .43014 .89572 .45045 .90615 .42227 .89867 .39457 Metetra
.875 .563 .048 r
.89867 .39457 .90615 .42227 .91856 .41154 .93168 .55513 Metetra
.611 .367 .523 r
.93168 .55513 .91856 .41154 .95465 .58876 .94981 .58454 Metetra
.664 .741 .908 r
.33406 .53754 .34076 .54378 .35147 .54041 .3448 .53415 Metetra
.664 .741 .908 r
.3448 .53415 .35147 .54041 .36223 .53702 .35558 .53073 Metetra
.664 .741 .908 r
.35558 .53073 .36223 .53702 .37303 .53362 .36641 .52731 Metetra
.664 .741 .908 r
.36641 .52731 .37303 .53362 .38387 .53021 .37728 .52387 Metetra
.664 .741 .908 r
.37728 .52387 .38387 .53021 .39476 .52678 .38819 .52041 Metetra
.664 .741 .908 r
.38819 .52041 .39476 .52678 .40569 .52334 .39915 .51694 Metetra
.664 .741 .908 r
.39915 .51694 .40569 .52334 .41667 .51988 .41016 .51346 Metetra
.664 .741 .908 r
.41016 .51346 .41667 .51988 .42769 .51641 .42121 .50996 Metetra
.664 .741 .908 r
.42121 .50996 .42769 .51641 .43875 .51292 .4323 .50645 Metetra
.664 .741 .908 r
.4323 .50645 .43875 .51292 .44986 .50943 .44344 .50293 Metetra
.664 .741 .908 r
.44344 .50293 .44986 .50943 .46102 .50591 .45463 .49939 Metetra
.664 .741 .908 r
.45463 .49939 .46102 .50591 .47223 .50238 .46586 .49583 Metetra
.664 .741 .908 r
.46586 .49583 .47223 .50238 .48348 .49884 .47714 .49226 Metetra
.664 .741 .908 r
.47714 .49226 .48348 .49884 .49477 .49528 .48847 .48868 Metetra
.664 .741 .908 r
.48847 .48868 .49477 .49528 .50612 .49171 .49984 .48508 Metetra
.664 .741 .908 r
.49984 .48508 .50612 .49171 .51751 .48812 .51126 .48146 Metetra
.664 .741 .908 r
.51126 .48146 .51751 .48812 .52894 .48452 .52273 .47783 Metetra
.664 .741 .908 r
.52273 .47783 .52894 .48452 .54043 .48091 .53425 .47419 Metetra
.664 .741 .908 r
.53425 .47419 .54043 .48091 .55196 .47727 .54581 .47053 Metetra
.664 .741 .908 r
.54581 .47053 .55196 .47727 .56354 .47363 .55743 .46685 Metetra
.664 .741 .908 r
.55743 .46685 .56354 .47363 .57517 .46996 .56909 .46316 Metetra
.664 .741 .908 r
.56909 .46316 .57517 .46996 .58685 .46629 .5808 .45946 Metetra
.664 .741 .908 r
.5808 .45946 .58685 .46629 .59858 .46259 .59256 .45573 Metetra
.664 .741 .908 r
.59256 .45573 .59858 .46259 .61036 .45888 .60438 .452 Metetra
.664 .741 .908 r
.60438 .452 .61036 .45888 .62219 .45516 .61624 .44824 Metetra
.966 .658 .386 r
.61624 .44824 .62219 .45516 .63407 .45142 .63352 .61424 Metetra
.588 .355 .53 r
.63352 .61424 .63407 .45142 .646 .44766 .64683 .63098 Metetra
.554 .33 .529 r
.64683 .63098 .646 .44766 .65798 .44389 .65959 .62802 Metetra
.525 .307 .526 r
.65959 .62802 .65798 .44389 .67001 .4401 .67167 .60789 Metetra
.493 .281 .519 r
.67167 .60789 .67001 .4401 .69266 .65542 .68308 .57453 Metetra
.697 .484 .595 r
.68308 .57453 .69266 .65542 .70489 .63741 .69389 .53271 Metetra
.68 .465 .587 r
.69389 .53271 .70489 .63741 .71502 .58288 .70427 .48736 Metetra
.686 .471 .589 r
.70427 .48736 .71502 .58288 .72456 .52391 .71446 .44312 Metetra
.637 .439 .599 r
.71446 .44312 .72456 .52391 .73382 .46615 .72591 .42349 Metetra
.342 .268 .627 r
.72591 .42349 .73382 .46615 .74346 .41968 .74015 .44716 Metetra
.651 .336 .426 r
.74015 .44716 .74346 .41968 .75867 .45496 .75391 .46015 Metetra
.373 0 0 r
.75391 .46015 .75867 .45496 .77335 .4785 .76691 .46015 Metetra
.743 .611 .712 r
.76691 .46015 .77335 .4785 .78713 .48718 .77893 .44643 Metetra
.723 .529 .627 r
.77893 .44643 .78713 .48718 .79972 .47964 .7899 .42006 Metetra
.675 .477 .61 r
.7899 .42006 .79972 .47964 .811 .45671 .80092 .39584 Metetra
.352 .254 .602 r
.80092 .39584 .811 .45671 .82107 .42157 .81706 .4297 Metetra
.854 .455 .284 r
.81706 .4297 .82107 .42157 .83215 .39909 .83357 .46355 Metetra
.647 .374 .492 r
.83357 .46355 .83215 .39909 .84883 .43381 .84955 .48827 Metetra
.569 .305 .477 r
.84955 .48827 .84883 .43381 .86498 .45979 .86367 .49185 Metetra
.141 0 .336 r
.86367 .49185 .86498 .45979 .87907 .46376 .87419 .46037 Metetra
.993 .754 .463 r
.87419 .46037 .87907 .46376 .88908 .43014 .87917 .38038 Metetra
0 0 .336 r
.87917 .38038 .88908 .43014 .89867 .39457 .90534 .48984 Metetra
.742 .457 .498 r
.90534 .48984 .89867 .39457 .93168 .55513 .93038 .58123 Metetra
.488 .185 .378 r
.93038 .58123 .93168 .55513 .94981 .58454 .94454 .57731 Metetra
.664 .741 .908 r
.32731 .53126 .33406 .53754 .3448 .53415 .33807 .52784 Metetra
.664 .741 .908 r
.33807 .52784 .3448 .53415 .35558 .53073 .34888 .5244 Metetra
.664 .741 .908 r
.34888 .5244 .35558 .53073 .36641 .52731 .35974 .52094 Metetra
.664 .741 .908 r
.35974 .52094 .36641 .52731 .37728 .52387 .37063 .51748 Metetra
.664 .741 .908 r
.37063 .51748 .37728 .52387 .38819 .52041 .38158 .514 Metetra
.664 .741 .908 r
.38158 .514 .38819 .52041 .39915 .51694 .39256 .5105 Metetra
.664 .741 .908 r
.39256 .5105 .39915 .51694 .41016 .51346 .4036 .50699 Metetra
.664 .741 .908 r
.4036 .50699 .41016 .51346 .42121 .50996 .41468 .50347 Metetra
.664 .741 .908 r
.41468 .50347 .42121 .50996 .4323 .50645 .4258 .49993 Metetra
.664 .741 .908 r
.4258 .49993 .4323 .50645 .44344 .50293 .43697 .49638 Metetra
.664 .741 .908 r
.43697 .49638 .44344 .50293 .45463 .49939 .44819 .49281 Metetra
.664 .741 .908 r
.44819 .49281 .45463 .49939 .46586 .49583 .45945 .48923 Metetra
.664 .741 .908 r
.45945 .48923 .46586 .49583 .47714 .49226 .47076 .48563 Metetra
.664 .741 .908 r
.47076 .48563 .47714 .49226 .48847 .48868 .48211 .48202 Metetra
.664 .741 .908 r
.48211 .48202 .48847 .48868 .49984 .48508 .49352 .47839 Metetra
.664 .741 .908 r
.49352 .47839 .49984 .48508 .51126 .48146 .50497 .47475 Metetra
.664 .741 .908 r
.50497 .47475 .51126 .48146 .52273 .47783 .51647 .47109 Metetra
.664 .741 .908 r
.51647 .47109 .52273 .47783 .53425 .47419 .52802 .46742 Metetra
.664 .741 .908 r
.52802 .46742 .53425 .47419 .54581 .47053 .53962 .46373 Metetra
.664 .741 .908 r
.53962 .46373 .54581 .47053 .55743 .46685 .55126 .46003 Metetra
.664 .741 .908 r
.55126 .46003 .55743 .46685 .56909 .46316 .56296 .45631 Metetra
.556 .073 0 r
.56296 .45631 .56909 .46316 .5808 .45946 .57497 .47026 Metetra
.79 .424 .363 r
.57497 .47026 .5808 .45946 .59256 .45573 .58733 .49296 Metetra
.762 .464 .481 r
.58733 .49296 .59256 .45573 .60438 .452 .60042 .53761 Metetra
.641 .384 .514 r
.60042 .53761 .60438 .452 .61624 .44824 .6135 .56613 Metetra
.584 .345 .52 r
.6135 .56613 .61624 .44824 .63352 .61424 .62636 .57742 Metetra
.613 .465 .656 r
.62636 .57742 .63352 .61424 .64683 .63098 .63884 .57226 Metetra
.659 .468 .616 r
.63884 .57226 .64683 .63098 .65959 .62802 .65083 .55297 Metetra
.673 .469 .601 r
.65083 .55297 .65959 .62802 .67167 .60789 .66232 .52306 Metetra
.68 .469 .594 r
.66232 .52306 .67167 .60789 .68308 .57453 .67338 .48665 Metetra
.682 .469 .592 r
.67338 .48665 .68308 .57453 .69389 .53271 .68414 .448 Metetra
.664 .457 .595 r
.68414 .448 .69389 .53271 .70427 .48736 .69512 .41753 Metetra
.433 .3 .599 r
.69512 .41753 .70427 .48736 .71446 .44312 .70904 .4419 Metetra
.772 .263 0 r
.70904 .4419 .71446 .44312 .72591 .42349 .72277 .45854 Metetra
.589 .298 .442 r
.72277 .45854 .72591 .42349 .74015 .44716 .73603 .46452 Metetra
.383 .053 .276 r
.73603 .46452 .74015 .44716 .75391 .46015 .74858 .45802 Metetra
.945 .905 .751 r
.74858 .45802 .75391 .46015 .76691 .46015 .76023 .43863 Metetra
.826 .636 .646 r
.76023 .43863 .76691 .46015 .77893 .44643 .77094 .40764 Metetra
.589 .443 .651 r
.77094 .40764 .77893 .44643 .7899 .42006 .78378 .4053 Metetra
0 0 .306 r
.78378 .4053 .7899 .42006 .80092 .39584 .80006 .44294 Metetra
.716 .419 .472 r
.80006 .44294 .80092 .39584 .81706 .4297 .81676 .48076 Metetra
.681 .391 .476 r
.81676 .48076 .81706 .4297 .83357 .46355 .8331 .51032 Metetra
.604 .324 .465 r
.8331 .51032 .83357 .46355 .84955 .48827 .8479 .52048 Metetra
.277 .042 .366 r
.8479 .52048 .84955 .48827 .86367 .49185 .85962 .49819 Metetra
.986 .793 .395 r
.85962 .49819 .86367 .49185 .87419 .46037 .86648 .43049 Metetra
.735 .558 .653 r
.86648 .43049 .87419 .46037 .87917 .38038 .87798 .40965 Metetra
.927 .592 .384 r
.87798 .40965 .87917 .38038 .90534 .48984 .91087 .57791 Metetra
.541 .3 .5 r
.91087 .57791 .90534 .48984 .93038 .58123 .92502 .57397 Metetra
.982 .695 .37 r
.92502 .57397 .93038 .58123 .94454 .57731 .91179 .34535 Metetra
.664 .741 .908 r
.32051 .52493 .32731 .53126 .33807 .52784 .3313 .52148 Metetra
.664 .741 .908 r
.3313 .52148 .33807 .52784 .34888 .5244 .34214 .51801 Metetra
.664 .741 .908 r
.34214 .51801 .34888 .5244 .35974 .52094 .35302 .51453 Metetra
.664 .741 .908 r
.35302 .51453 .35974 .52094 .37063 .51748 .36394 .51104 Metetra
.664 .741 .908 r
.36394 .51104 .37063 .51748 .38158 .514 .37491 .50753 Metetra
.664 .741 .908 r
.37491 .50753 .38158 .514 .39256 .5105 .38593 .50401 Metetra
.664 .741 .908 r
.38593 .50401 .39256 .5105 .4036 .50699 .39699 .50048 Metetra
.664 .741 .908 r
.39699 .50048 .4036 .50699 .41468 .50347 .4081 .49693 Metetra
.664 .741 .908 r
.4081 .49693 .41468 .50347 .4258 .49993 .41925 .49336 Metetra
.664 .741 .908 r
.41925 .49336 .4258 .49993 .43697 .49638 .43045 .48978 Metetra
.664 .741 .908 r
.43045 .48978 .43697 .49638 .44819 .49281 .44169 .48619 Metetra
.664 .741 .908 r
.44169 .48619 .44819 .49281 .45945 .48923 .45299 .48258 Metetra
.664 .741 .908 r
.45299 .48258 .45945 .48923 .47076 .48563 .46433 .47895 Metetra
.664 .741 .908 r
.46433 .47895 .47076 .48563 .48211 .48202 .47571 .47531 Metetra
.664 .741 .908 r
.47571 .47531 .48211 .48202 .49352 .47839 .48715 .47166 Metetra
.664 .741 .908 r
.48715 .47166 .49352 .47839 .50497 .47475 .49863 .46799 Metetra
.664 .741 .908 r
.49863 .46799 .50497 .47475 .51647 .47109 .51016 .4643 Metetra
.96 .669 .439 r
.51016 .4643 .51647 .47109 .52802 .46742 .52153 .67815 Metetra
.427 .228 .506 r
.52153 .67815 .52802 .46742 .53962 .46373 .53376 .60783 Metetra
.309 .129 .466 r
.53376 .60783 .53962 .46373 .55126 .46003 .54552 .52912 Metetra
0 0 .308 r
.54552 .52912 .55126 .46003 .56296 .45631 .55688 .46013 Metetra
.862 .473 .305 r
.55688 .46013 .56296 .45631 .57497 .47026 .56912 .48805 Metetra
.809 .477 .428 r
.56912 .48805 .57497 .47026 .58733 .49296 .58179 .52454 Metetra
.692 .388 .456 r
.58179 .52454 .58733 .49296 .60042 .53761 .59449 .5458 Metetra
.6 .164 .186 r
.59449 .5458 .60042 .53761 .6135 .56613 .60704 .55117 Metetra
.722 .628 .752 r
.60704 .55117 .6135 .56613 .62636 .57742 .6193 .54168 Metetra
.718 .535 .642 r
.6193 .54168 .62636 .57742 .63884 .57226 .63117 .51975 Metetra
.712 .51 .614 r
.63117 .51975 .63884 .57226 .65083 .55297 .64264 .48877 Metetra
.706 .497 .603 r
.64264 .48877 .65083 .55297 .66232 .52306 .65376 .45264 Metetra
.7 .489 .599 r
.65376 .45264 .66232 .52306 .67338 .48665 .66463 .41532 Metetra
.416 .286 .594 r
.66463 .41532 .67338 .48665 .68414 .448 .67832 .44211 Metetra
.777 .31 0 r
.67832 .44211 .68414 .448 .69512 .41753 .69209 .46474 Metetra
.626 .346 .473 r
.69209 .46474 .69512 .41753 .70904 .4419 .70566 .47899 Metetra
.566 .28 .442 r
.70566 .47899 .70904 .4419 .72277 .45854 .71877 .48211 Metetra
.376 .082 .332 r
.71877 .48211 .72277 .45854 .73603 .46452 .7312 .47239 Metetra
.733 .849 .411 r
.7312 .47239 .73603 .46452 .74858 .45802 .74276 .44955 Metetra
.934 .76 .643 r
.74276 .44955 .74858 .45802 .76023 .43863 .7534 .41491 Metetra
.757 .59 .67 r
.7534 .41491 .76023 .43863 .77094 .40764 .76495 .39499 Metetra
.767 .395 0 r
.76495 .39499 .77094 .40764 .78378 .4053 .78129 .43692 Metetra
.777 .453 .44 r
.78129 .43692 .78378 .4053 .80006 .44294 .79821 .48047 Metetra
.739 .425 .452 r
.79821 .48047 .80006 .44294 .81676 .48076 .81504 .51792 Metetra
.672 .366 .446 r
.81504 .51792 .81676 .48076 .8331 .51032 .83078 .53892 Metetra
.442 .155 .38 r
.83078 .53892 .8331 .51032 .8479 .52048 .84404 .53101 Metetra
.904 .804 .326 r
.84404 .53101 .8479 .52048 .85962 .49819 .85318 .48124 Metetra
.961 .701 .496 r
.85318 .48124 .85962 .49819 .86648 .43049 .85656 .37899 Metetra
0 0 .313 r
.85656 .37899 .86648 .43049 .87798 .40965 .88244 .49255 Metetra
.74 .451 .491 r
.88244 .49255 .87798 .40965 .91087 .57791 .90541 .57062 Metetra
.645 .763 .934 r
.90541 .57062 .91087 .57791 .92502 .57397 .91961 .56665 Metetra
.982 .695 .37 r
.91961 .56665 .92502 .57397 .91179 .34535 .90668 .33755 Metetra
.664 .741 .908 r
.31365 .51855 .32051 .52493 .3313 .52148 .32447 .51507 Metetra
.664 .741 .908 r
.32447 .51507 .3313 .52148 .34214 .51801 .33534 .51158 Metetra
.664 .741 .908 r
.33534 .51158 .34214 .51801 .35302 .51453 .34625 .50808 Metetra
.664 .741 .908 r
.34625 .50808 .35302 .51453 .36394 .51104 .3572 .50456 Metetra
.664 .741 .908 r
.3572 .50456 .36394 .51104 .37491 .50753 .3682 .50102 Metetra
.664 .741 .908 r
.3682 .50102 .37491 .50753 .38593 .50401 .37924 .49747 Metetra
.664 .741 .908 r
.37924 .49747 .38593 .50401 .39699 .50048 .39033 .49391 Metetra
.664 .741 .908 r
.39033 .49391 .39699 .50048 .4081 .49693 .40147 .49033 Metetra
.664 .741 .908 r
.40147 .49033 .4081 .49693 .41925 .49336 .41265 .48674 Metetra
.664 .741 .908 r
.41265 .48674 .41925 .49336 .43045 .48978 .42388 .48313 Metetra
.664 .741 .908 r
.42388 .48313 .43045 .48978 .44169 .48619 .43515 .47951 Metetra
.664 .741 .908 r
.43515 .47951 .44169 .48619 .45299 .48258 .44647 .47587 Metetra
.664 .741 .908 r
.44647 .47587 .45299 .48258 .46433 .47895 .45784 .47222 Metetra
.956 .67 .456 r
.45784 .47222 .46433 .47895 .47571 .47531 .46559 .68558 Metetra
.55 .326 .527 r
.46559 .68558 .47571 .47531 .48715 .47166 .47781 .68214 Metetra
.55 .326 .527 r
.47781 .68214 .48715 .47166 .49863 .46799 .49008 .67868 Metetra
.523 .303 .523 r
.49008 .67868 .49863 .46799 .51016 .4643 .50251 .65812 Metetra
.387 .194 .492 r
.50251 .65812 .51016 .4643 .52153 .67815 .51505 .58008 Metetra
.738 .511 .586 r
.51505 .58008 .52153 .67815 .53376 .60783 .52711 .50587 Metetra
.701 .482 .587 r
.52711 .50587 .53376 .60783 .54552 .52912 .53881 .45108 Metetra
.277 .176 .555 r
.53881 .45108 .54552 .52912 .55688 .46013 .55098 .49673 Metetra
.726 .429 .475 r
.55098 .49673 .55688 .46013 .56912 .48805 .5634 .52908 Metetra
.649 .362 .47 r
.5634 .52908 .56912 .48805 .58179 .52454 .57591 .54597 Metetra
.536 .209 .36 r
.57591 .54597 .58179 .52454 .59449 .5458 .58832 .54697 Metetra
.873 .991 .813 r
.58832 .54697 .59449 .5458 .60704 .55117 .60049 .53335 Metetra
.819 .65 .673 r
.60049 .53335 .60704 .55117 .6193 .54168 .61233 .50769 Metetra
.774 .574 .628 r
.61233 .50769 .6193 .54168 .63117 .51975 .6238 .47347 Metetra
.752 .542 .612 r
.6238 .47347 .63117 .51975 .64264 .48877 .63495 .43462 Metetra
.602 .43 .621 r
.63495 .43462 .64264 .48877 .65376 .45264 .6471 .42834 Metetra
0 0 .548 r
.6471 .42834 .65376 .45264 .66463 .41532 .6608 .4585 Metetra
.68 .388 .472 r
.6608 .4585 .66463 .41532 .67832 .44211 .67458 .48339 Metetra
.643 .352 .463 r
.67458 .48339 .67832 .44211 .69209 .46474 .68821 .49948 Metetra
.575 .282 .434 r
.68821 .49948 .69209 .46474 .70566 .47899 .70143 .50388 Metetra
.393 .099 .342 r
.70143 .50388 .70566 .47899 .71877 .48211 .71401 .49477 Metetra
.71401 .49477 .71877 .48211 .7312 .47239 .72575 .47171 Metetra
.989 .848 .609 r
.72575 .47171 .7312 .47239 .74276 .44955 .73657 .43585 Metetra
.918 .71 .607 r
.73657 .43585 .74276 .44955 .7534 .41491 .74649 .38993 Metetra
.098 .164 .644 r
.74649 .38993 .7534 .41491 .76495 .39499 .76126 .41412 Metetra
.84 .491 .394 r
.76126 .41412 .76495 .39499 .78129 .43692 .77818 .4625 Metetra
.805 .467 .417 r
.77818 .4625 .78129 .43692 .79821 .48047 .79535 .50791 Metetra
.755 .421 .419 r
.79535 .50791 .79821 .48047 .81504 .51792 .81193 .54094 Metetra
.62 .282 .376 r
.81193 .54094 .81504 .51792 .83078 .53892 .82673 .54986 Metetra
.82673 .54986 .83078 .53892 .84404 .53101 .83822 .52169 Metetra
.975 .736 .511 r
.83822 .52169 .84404 .53101 .85318 .48124 .8448 .44467 Metetra
.849 .612 .58 r
.8448 .44467 .85318 .48124 .85656 .37899 .85234 .38256 Metetra
.959 .621 .298 r
.85234 .38256 .85656 .37899 .88244 .49255 .88573 .56726 Metetra
.533 .286 .487 r
.88573 .56726 .88244 .49255 .90541 .57062 .89991 .56327 Metetra
.645 .763 .934 r
.89991 .56327 .90541 .57062 .91961 .56665 .91415 .55926 Metetra
.982 .695 .37 r
.91415 .55926 .91961 .56665 .90668 .33755 .90152 .32967 Metetra
.664 .741 .908 r
.30675 .51212 .31365 .51855 .32447 .51507 .3176 .50862 Metetra
.664 .741 .908 r
.3176 .50862 .32447 .51507 .33534 .51158 .32849 .5051 Metetra
.664 .741 .908 r
.32849 .5051 .33534 .51158 .34625 .50808 .33942 .50157 Metetra
.664 .741 .908 r
.33942 .50157 .34625 .50808 .3572 .50456 .3504 .49802 Metetra
.664 .741 .908 r
.3504 .49802 .3572 .50456 .3682 .50102 .36143 .49446 Metetra
.664 .741 .908 r
.36143 .49446 .3682 .50102 .37924 .49747 .3725 .49089 Metetra
.664 .741 .908 r
.3725 .49089 .37924 .49747 .39033 .49391 .38362 .48729 Metetra
.664 .741 .908 r
.38362 .48729 .39033 .49391 .40147 .49033 .39478 .48369 Metetra
.664 .741 .908 r
.39478 .48369 .40147 .49033 .41265 .48674 .40599 .48007 Metetra
.664 .741 .908 r
.40599 .48007 .41265 .48674 .42388 .48313 .41725 .47643 Metetra
.953 .667 .458 r
.41725 .47643 .42388 .48313 .43515 .47951 .42342 .64853 Metetra
.618 .378 .533 r
.42342 .64853 .43515 .47951 .44647 .47587 .43431 .68611 Metetra
.549 .324 .526 r
.43431 .68611 .44647 .47587 .45784 .47222 .44645 .68267 Metetra
.549 .324 .526 r
.44645 .68267 .45784 .47222 .46559 .68558 .45864 .67921 Metetra
.645 .763 .934 r
.45864 .67921 .46559 .68558 .47781 .68214 .4709 .67575 Metetra
.91 .765 .688 r
.4709 .67575 .47781 .68214 .49008 .67868 .48351 .64644 Metetra
.864 .636 .591 r
.48351 .64644 .49008 .67868 .50251 .65812 .49642 .56629 Metetra
.747 .52 .586 r
.49642 .56629 .50251 .65812 .51505 .58008 .50883 .49037 Metetra
.656 .45 .594 r
.50883 .49037 .51505 .58008 .52711 .50587 .52071 .46153 Metetra
0 0 .471 r
.52071 .46153 .52711 .50587 .53881 .45108 .53264 .50859 Metetra
.685 .409 .499 r
.53264 .50859 .53881 .45108 .55098 .49673 .5449 .54154 Metetra
.641 .358 .474 r
.5449 .54154 .55098 .49673 .5634 .52908 .55733 .55809 Metetra
.528 .228 .401 r
.55733 .55809 .5634 .52908 .57591 .54597 .56974 .55782 Metetra
.56974 .55782 .57591 .54597 .58832 .54697 .58196 .54207 Metetra
.934 .798 .685 r
.58196 .54207 .58832 .54697 .60049 .53335 .59389 .51355 Metetra
.85 .654 .638 r
.59389 .51355 .60049 .53335 .61233 .50769 .60547 .47593 Metetra
.809 .599 .619 r
.60547 .47593 .61233 .50769 .6238 .47347 .6167 .43328 Metetra
.614 .456 .644 r
.6167 .43328 .6238 .47347 .63495 .43462 .62887 .42711 Metetra
.884 .473 .048 r
.62887 .42711 .63495 .43462 .6471 .42834 .64253 .46179 Metetra
.724 .414 .455 r
.64253 .46179 .6471 .42834 .6608 .4585 .65635 .49155 Metetra
.685 .376 .447 r
.65635 .49155 .6608 .4585 .67458 .48339 .67011 .51267 Metetra
.617 .305 .419 r
.67011 .51267 .67458 .48339 .68821 .49948 .68356 .52194 Metetra
.447 .131 .335 r
.68356 .52194 .68821 .49948 .70143 .50388 .69646 .51716 Metetra
.69646 .51716 .70143 .50388 .71401 .49477 .70858 .4975 Metetra
.99 .889 .587 r
.70858 .4975 .71401 .49477 .72575 .47171 .7198 .46369 Metetra
.952 .756 .601 r
.7198 .46369 .72575 .47171 .73657 .43585 .73009 .41811 Metetra
.875 .676 .63 r
.73009 .41811 .73657 .43585 .74649 .38993 .7406 .37982 Metetra
.883 .501 .035 r
.7406 .37982 .74649 .38993 .76126 .41412 .75724 .43042 Metetra
.858 .503 .377 r
.75724 .43042 .76126 .41412 .77818 .4625 .77443 .48156 Metetra
.827 .472 .385 r
.77443 .48156 .77818 .4625 .79535 .50791 .79152 .52507 Metetra
.761 .392 .355 r
.79152 .52507 .79535 .50791 .81193 .54094 .80754 .55023 Metetra
.237 0 .018 r
.80754 .55023 .81193 .54094 .82673 .54986 .82114 .5445 Metetra
.982 .786 .567 r
.82114 .5445 .82673 .54986 .83822 .52169 .83079 .4953 Metetra
.933 .673 .52 r
.83079 .4953 .83822 .52169 .8448 .44467 .835 .39292 Metetra
.043 .055 .545 r
.835 .39292 .8448 .44467 .85234 .38256 .85463 .45135 Metetra
.806 .499 .47 r
.85463 .45135 .85234 .38256 .88573 .56726 .88012 .55987 Metetra
.645 .763 .934 r
.88012 .55987 .88573 .56726 .89991 .56327 .89435 .55585 Metetra
.983 .696 .377 r
.89435 .55585 .89991 .56327 .91415 .55926 .88297 .32604 Metetra
.565 .363 .565 r
.88297 .32604 .91415 .55926 .90152 .32967 .89632 .32173 Metetra
.664 .741 .908 r
.29979 .50564 .30675 .51212 .3176 .50862 .31067 .50211 Metetra
.664 .741 .908 r
.31067 .50211 .3176 .50862 .32849 .5051 .32158 .49857 Metetra
.664 .741 .908 r
.32158 .49857 .32849 .5051 .33942 .50157 .33255 .49501 Metetra
.664 .741 .908 r
.33255 .49501 .33942 .50157 .3504 .49802 .34356 .49144 Metetra
.664 .741 .908 r
.34356 .49144 .3504 .49802 .36143 .49446 .35461 .48785 Metetra
.664 .741 .908 r
.35461 .48785 .36143 .49446 .3725 .49089 .36571 .48425 Metetra
.948 .671 .481 r
.36571 .48425 .3725 .49089 .38362 .48729 .36717 .69685 Metetra
.548 .322 .524 r
.36717 .69685 .38362 .48729 .39478 .48369 .37907 .69346 Metetra
.059 0 .374 r
.37907 .69346 .39478 .48369 .40599 .48007 .39723 .52737 Metetra
.828 .549 .516 r
.39723 .52737 .40599 .48007 .41725 .47643 .40486 .63451 Metetra
.637 .394 .533 r
.40486 .63451 .41725 .47643 .42342 .64853 .41511 .6832 Metetra
.498 .211 .41 r
.41511 .6832 .42342 .64853 .43431 .68611 .42723 .67975 Metetra
.645 .763 .934 r
.42723 .67975 .43431 .68611 .44645 .68267 .43941 .67628 Metetra
.645 .763 .934 r
.43941 .67628 .44645 .68267 .45864 .67921 .45164 .6728 Metetra
.839 .788 .802 r
.45164 .6728 .45864 .67921 .4709 .67575 .4641 .65909 Metetra
.914 .687 .581 r
.4641 .65909 .4709 .67575 .48351 .64644 .47756 .57278 Metetra
.782 .551 .587 r
.47756 .57278 .48351 .64644 .49642 .56629 .49045 .49045 Metetra
.671 .466 .6 r
.49045 .49045 .49642 .56629 .50883 .49037 .50247 .46106 Metetra
0 0 .16 r
.50247 .46106 .50883 .49037 .52071 .46153 .51409 .51395 Metetra
.709 .427 .496 r
.51409 .51395 .52071 .46153 .53264 .50859 .52616 .55216 Metetra
.663 .376 .475 r
.52616 .55216 .53264 .50859 .5449 .54154 .53852 .57294 Metetra
.558 .259 .417 r
.53852 .57294 .5449 .54154 .55733 .55809 .55098 .57549 Metetra
.082 0 .12 r
.55098 .57549 .55733 .55809 .56974 .55782 .56335 .56096 Metetra
.982 .906 .649 r
.56335 .56096 .56974 .55782 .58196 .54207 .57547 .53205 Metetra
.914 .73 .639 r
.57547 .53205 .58196 .54207 .59389 .51355 .58726 .49254 Metetra
.864 .656 .62 r
.58726 .49254 .59389 .51355 .60547 .47593 .5987 .44673 Metetra
.799 .598 .63 r
.5987 .44673 .60547 .47593 .6167 .43328 .61015 .41101 Metetra
0 0 .327 r
.61015 .41101 .6167 .43328 .62887 .42711 .62367 .45033 Metetra
.782 .452 .429 r
.62367 .45033 .62887 .42711 .64253 .46179 .63745 .4859 Metetra
.747 .416 .424 r
.63745 .4859 .64253 .46179 .65635 .49155 .65129 .51375 Metetra
.689 .351 .398 r
.65129 .51375 .65635 .49155 .67011 .51267 .66497 .5303 Metetra
.548 .192 .316 r
.66497 .5303 .67011 .51267 .68356 .52194 .67823 .53283 Metetra
.67823 .53283 .68356 .52194 .69646 .51716 .69084 .51988 Metetra
.977 .919 .625 r
.69084 .51988 .69646 .51716 .70858 .4975 .7026 .49156 Metetra
.961 .779 .612 r
.7026 .49156 .70858 .4975 .7198 .46369 .71346 .44966 Metetra
.924 .71 .593 r
.71346 .44966 .7198 .46369 .73009 .41811 .72343 .39749 Metetra
.669 .558 .72 r
.72343 .39749 .73009 .41811 .7406 .37982 .736 .38992 Metetra
.89 .524 .342 r
.736 .38992 .7406 .37982 .75724 .43042 .75286 .44333 Metetra
.872 .507 .353 r
.75286 .44333 .75724 .43042 .77443 .48156 .77004 .49384 Metetra
.844 .464 .332 r
.77004 .49384 .77443 .48156 .79152 .52507 .78679 .53217 Metetra
.727 .274 .174 r
.78679 .53217 .79152 .52507 .80754 .55023 .80199 .54675 Metetra
.949 .888 .737 r
.80199 .54675 .80754 .55023 .82114 .5445 .81428 .52494 Metetra
.929 .691 .557 r
.81428 .52494 .82114 .5445 .83079 .4953 .82214 .45528 Metetra
.907 .642 .526 r
.82214 .45528 .83079 .4953 .835 .39292 .82517 .33988 Metetra
.792 .532 0 r
.82517 .33988 .835 .39292 .85463 .45135 .85803 .534 Metetra
.608 .344 .493 r
.85803 .534 .85463 .45135 .88012 .55987 .87447 .55242 Metetra
.645 .763 .934 r
.87447 .55242 .88012 .55987 .89435 .55585 .88874 .54836 Metetra
.983 .696 .377 r
.88874 .54836 .89435 .55585 .88297 .32604 .87768 .31807 Metetra
.664 .741 .908 r
.87768 .31807 .88297 .32604 .89632 .32173 .89107 .31372 Metetra
.664 .741 .908 r
.29278 .49911 .29979 .50564 .31067 .50211 .30368 .49556 Metetra
.664 .741 .908 r
.30368 .49556 .31067 .50211 .32158 .49857 .31463 .49199 Metetra
.943 .671 .493 r
.31463 .49199 .32158 .49857 .33255 .49501 .31264 .7041 Metetra
.546 .32 .523 r
.31264 .7041 .33255 .49501 .34356 .49144 .32437 .70074 Metetra
.546 .32 .523 r
.32437 .70074 .34356 .49144 .35461 .48785 .33615 .69737 Metetra
.546 .32 .523 r
.33615 .69737 .35461 .48785 .36571 .48425 .34798 .69398 Metetra
.546 .32 .523 r
.34798 .69398 .36571 .48425 .36717 .69685 .35987 .69058 Metetra
.934 .719 .589 r
.35987 .69058 .36717 .69685 .37907 .69346 .3752 .60929 Metetra
.614 .421 .597 r
.3752 .60929 .37907 .69346 .39723 .52737 .38734 .59561 Metetra
.769 .497 .523 r
.38734 .59561 .39723 .52737 .40486 .63451 .39584 .68028 Metetra
.511 .241 .441 r
.39584 .68028 .40486 .63451 .41511 .6832 .40794 .67681 Metetra
.645 .763 .934 r
.40794 .67681 .41511 .6832 .42723 .67975 .4201 .67334 Metetra
.645 .763 .934 r
.4201 .67334 .42723 .67975 .43941 .67628 .43231 .66984 Metetra
.645 .763 .934 r
.43231 .66984 .43941 .67628 .45164 .6728 .44457 .66633 Metetra
.939 .732 .596 r
.44457 .66633 .45164 .6728 .4641 .65909 .45809 .60139 Metetra
.819 .587 .586 r
.45809 .60139 .4641 .65909 .47756 .57278 .47165 .51024 Metetra
.776 .551 .594 r
.47165 .51024 .47756 .57278 .49045 .49045 .48434 .44382 Metetra
0 0 .322 r
.48434 .44382 .49045 .49045 .50247 .46106 .4955 .50528 Metetra
.75 .459 .491 r
.4955 .50528 .50247 .46106 .51409 .51395 .50725 .55242 Metetra
.709 .412 .472 r
.50725 .55242 .51409 .51395 .52616 .55216 .51945 .58162 Metetra
.622 .312 .425 r
.51945 .58162 .52616 .55216 .53852 .57294 .53191 .59134 Metetra
.287 0 .218 r
.53191 .59134 .53852 .57294 .55098 .57549 .54442 .58216 Metetra
.933 .944 .602 r
.54442 .58216 .55098 .57549 .56335 .56096 .55679 .55644 Metetra
.95 .783 .64 r
.55679 .55644 .56335 .56096 .57547 .53205 .56888 .51792 Metetra
.901 .699 .62 r
.56888 .51792 .57547 .53205 .58726 .49254 .58063 .471 Metetra
.871 .658 .611 r
.58063 .471 .58726 .49254 .5987 .44673 .59203 .42028 Metetra
.485 .41 .697 r
.59203 .42028 .5987 .44673 .61015 .41101 .6045 .4257 Metetra
.838 .491 .398 r
.6045 .4257 .61015 .41101 .62367 .45033 .6181 .46633 Metetra
.812 .462 .394 r
.6181 .46633 .62367 .45033 .63745 .4859 .63191 .50093 Metetra
.772 .409 .368 r
.63191 .50093 .63745 .4859 .65129 .51375 .64571 .52561 Metetra
.681 .283 .286 r
.64571 .52561 .65129 .51375 .66497 .5303 .65927 .53711 Metetra
.203 0 0 r
.65927 .53711 .66497 .5303 .67823 .53283 .67233 .53328 Metetra
.946 .951 .74 r
.67233 .53328 .67823 .53283 .69084 .51988 .68469 .5134 Metetra
.947 .784 .647 r
.68469 .5134 .69084 .51988 .7026 .49156 .6962 .47845 Metetra
.922 .716 .607 r
.6962 .47845 .7026 .49156 .71346 .44966 .70683 .43102 Metetra
.906 .683 .59 r
.70683 .43102 .71346 .44966 .72343 .39749 .71666 .37514 Metetra
.005 .119 .633 r
.71666 .37514 .72343 .39749 .736 .38992 .73124 .3991 Metetra
.894 .524 .332 r
.73124 .3991 .736 .38992 .75286 .44333 .74811 .45238 Metetra
.882 .503 .317 r
.74811 .45238 .75286 .44333 .77004 .49384 .76506 .4993 Metetra
.851 .429 .228 r
.76506 .4993 .77004 .49384 .78679 .53217 .78123 .5298 Metetra
.042 .579 .852 r
.78123 .5298 .78679 .53217 .80199 .54675 .79548 .53199 Metetra
.903 .712 .633 r
.79548 .53199 .80199 .54675 .81428 .52494 .80642 .49375 Metetra
.906 .654 .545 r
.80642 .49375 .81428 .52494 .82214 .45528 .81266 .40531 Metetra
.623 .45 .627 r
.81266 .40531 .82214 .45528 .82517 .33988 .82556 .39522 Metetra
.872 .552 .441 r
.82556 .39522 .82517 .33988 .85803 .534 .8545 .54898 Metetra
.401 .031 .216 r
.8545 .54898 .85803 .534 .87447 .55242 .86876 .5449 Metetra
.645 .763 .934 r
.86876 .5449 .87447 .55242 .88874 .54836 .88309 .5408 Metetra
.983 .696 .377 r
.88309 .5408 .88874 .54836 .87768 .31807 .87234 .31003 Metetra
.664 .741 .908 r
.87234 .31003 .87768 .31807 .89107 .31372 .88578 .30565 Metetra
.664 .741 .908 r
.28572 .49254 .29278 .49911 .30368 .49556 .29665 .48895 Metetra
.664 .741 .908 r
.29665 .48895 .30368 .49556 .31463 .49199 .30762 .48536 Metetra
.943 .671 .493 r
.30762 .48536 .31463 .49199 .31264 .7041 .30515 .69789 Metetra
.645 .763 .934 r
.30515 .69789 .31264 .7041 .32437 .70074 .31691 .6945 Metetra
.645 .763 .934 r
.31691 .6945 .32437 .70074 .33615 .69737 .32872 .6911 Metetra
.645 .763 .934 r
.32872 .6911 .33615 .69737 .34798 .69398 .34058 .68769 Metetra
.645 .763 .934 r
.34058 .68769 .34798 .69398 .35987 .69058 .3525 .68426 Metetra
.941 .702 .547 r
.3525 .68426 .35987 .69058 .3752 .60929 .37275 .50012 Metetra
.725 .577 0 r
.37275 .50012 .3752 .60929 .38734 .59561 .3765 .67735 Metetra
.53 .283 .486 r
.3765 .67735 .38734 .59561 .39584 .68028 .38858 .67387 Metetra
.645 .763 .934 r
.38858 .67387 .39584 .68028 .40794 .67681 .40072 .67038 Metetra
.645 .763 .934 r
.40072 .67038 .40794 .67681 .4201 .67334 .4129 .66687 Metetra
.645 .763 .934 r
.4129 .66687 .4201 .67334 .43231 .66984 .42515 .66335 Metetra
.843 .786 .796 r
.42515 .66335 .43231 .66984 .44457 .66633 .43772 .64905 Metetra
.917 .686 .573 r
.43772 .64905 .44457 .66633 .45809 .60139 .45211 .54975 Metetra
.831 .598 .585 r
.45211 .54975 .45809 .60139 .47165 .51024 .46572 .45864 Metetra
.378 .27 .602 r
.46572 .45864 .47165 .51024 .48434 .44382 .47715 .47877 Metetra
.798 .499 .483 r
.47715 .47877 .48434 .44382 .4955 .50528 .4884 .53649 Metetra
.768 .461 .467 r
.4884 .53649 .4955 .50528 .50725 .55242 .50028 .57695 Metetra
.708 .384 .427 r
.50028 .57695 .50725 .55242 .51945 .58162 .5126 .59749 Metetra
.5 .132 .273 r
.5126 .59749 .51945 .58162 .53191 .59134 .52515 .59772 Metetra
.812 .954 .616 r
.52515 .59772 .53191 .59134 .54442 .58216 .53772 .57927 Metetra
.956 .811 .66 r
.53772 .57927 .54442 .58216 .55679 .55644 .55012 .54547 Metetra
.916 .722 .626 r
.55012 .54547 .55679 .55644 .56888 .51792 .56223 .50064 Metetra
.892 .682 .612 r
.56223 .50064 .56888 .51792 .58063 .471 .574 .4495 Metetra
.876 .66 .607 r
.574 .4495 .58063 .471 .59203 .42028 .58543 .39667 Metetra
0 0 .347 r
.58543 .39667 .59203 .42028 .6045 .4257 .59862 .43549 Metetra
.861 .499 .364 r
.59862 .43549 .6045 .4257 .6181 .46633 .61222 .47536 Metetra
.841 .463 .336 r
.61222 .47536 .6181 .46633 .63191 .50093 .62597 .50741 Metetra
.797 .378 .252 r
.62597 .50741 .63191 .50093 .64571 .52561 .63968 .528 Metetra
.561 .01 0 r
.63968 .528 .64571 .52561 .65927 .53711 .65309 .53429 Metetra
.808 .929 .914 r
.65309 .53429 .65927 .53711 .67233 .53328 .66597 .52473 Metetra
.903 .769 .702 r
.66597 .52473 .67233 .53328 .68469 .5134 .67815 .49932 Metetra
.901 .708 .633 r
.67815 .49932 .68469 .5134 .6962 .47845 .6895 .45974 Metetra
.896 .681 .603 r
.6895 .45974 .6962 .47845 .70683 .43102 .70003 .40918 Metetra
.889 .666 .594 r
.70003 .40918 .70683 .43102 .71666 .37514 .71001 .35475 Metetra
.703 .396 0 r
.71001 .35475 .71666 .37514 .73124 .3991 .72628 .40666 Metetra
.896 .519 .314 r
.72628 .40666 .73124 .3991 .74811 .45238 .74298 .45724 Metetra
.887 .486 .258 r
.74298 .45724 .74811 .45238 .76506 .4993 .75951 .49812 Metetra
.788 .289 0 r
.75951 .49812 .76506 .4993 .78123 .5298 .77498 .51886 Metetra
.775 .722 .804 r
.77498 .51886 .78123 .5298 .79548 .53199 .7882 .50776 Metetra
.884 .659 .593 r
.7882 .50776 .79548 .53199 .80642 .49375 .79786 .45375 Metetra
.898 .637 .536 r
.79786 .45375 .80642 .49375 .81266 .40531 .80271 .34907 Metetra
0 0 .327 r
.80271 .34907 .81266 .40531 .82556 .39522 .82642 .45814 Metetra
.782 .474 .467 r
.82642 .45814 .82556 .39522 .8545 .54898 .84869 .54143 Metetra
.645 .763 .934 r
.84869 .54143 .8545 .54898 .86876 .5449 .863 .53731 Metetra
.983 .698 .383 r
.863 .53731 .86876 .5449 .88309 .5408 .85355 .30632 Metetra
.562 .358 .562 r
.85355 .30632 .88309 .5408 .87234 .31003 .86696 .30192 Metetra
.664 .741 .908 r
.86696 .30192 .87234 .31003 .88578 .30565 .88044 .2975 Metetra
.664 .741 .908 r
.2786 .48591 .28572 .49254 .29665 .48895 .28956 .4823 Metetra
.664 .741 .908 r
.28956 .4823 .29665 .48895 .30762 .48536 .30056 .47867 Metetra
.943 .671 .493 r
.30056 .47867 .30762 .48536 .30515 .69789 .29759 .69163 Metetra
.645 .763 .934 r
.29759 .69163 .30515 .69789 .31691 .6945 .30939 .68821 Metetra
.645 .763 .934 r
.30939 .68821 .31691 .6945 .32872 .6911 .32123 .68479 Metetra
.645 .763 .934 r
.32123 .68479 .32872 .6911 .34058 .68769 .33313 .68134 Metetra
.931 .722 .599 r
.33313 .68134 .34058 .68769 .3525 .68426 .34863 .60869 Metetra
.587 .403 .599 r
.34863 .60869 .3525 .68426 .37275 .50012 .36053 .60258 Metetra
.703 .443 .528 r
.36053 .60258 .37275 .50012 .3765 .67735 .36914 .67092 Metetra
.645 .763 .934 r
.36914 .67092 .3765 .67735 .38858 .67387 .38126 .66741 Metetra
.645 .763 .934 r
.38126 .66741 .38858 .67387 .40072 .67038 .39343 .66389 Metetra
.645 .763 .934 r
.39343 .66389 .40072 .67038 .4129 .66687 .40565 .66035 Metetra
.645 .763 .934 r
.40565 .66035 .4129 .66687 .42515 .66335 .41793 .6568 Metetra
.933 .739 .619 r
.41793 .6568 .42515 .66335 .43772 .64905 .4316 .60431 Metetra
.853 .618 .582 r
.4316 .60431 .43772 .64905 .45211 .54975 .44609 .50497 Metetra
.819 .593 .596 r
.44609 .50497 .45211 .54975 .46572 .45864 .45935 .43521 Metetra
.932 .62 .159 r
.45935 .43521 .46572 .45864 .47715 .47877 .46993 .50258 Metetra
.822 .509 .46 r
.46993 .50258 .47715 .47877 .4884 .53649 .48127 .55489 Metetra
.794 .46 .424 r
.48127 .55489 .4884 .53649 .50028 .57695 .49324 .58824 Metetra
.702 .312 .306 r
.49324 .58824 .50028 .57695 .5126 .59749 .50566 .60092 Metetra
.429 .846 .682 r
.50566 .60092 .5126 .59749 .52515 .59772 .51829 .59344 Metetra
.928 .816 .715 r
.51829 .59344 .52515 .59772 .53772 .57927 .53093 .56829 Metetra
.905 .723 .644 r
.53093 .56829 .53772 .57927 .55012 .54547 .54339 .52931 Metetra
.892 .687 .619 r
.54339 .52931 .55012 .54547 .56223 .50064 .55555 .48114 Metetra
.884 .671 .609 r
.55555 .48114 .56223 .50064 .574 .4495 .56738 .42851 Metetra
.822 .637 .651 r
.56738 .42851 .574 .4495 .58543 .39667 .57926 .3979 Metetra
.91 .532 .296 r
.57926 .3979 .58543 .39667 .59862 .43549 .59252 .44051 Metetra
.88 .5 .314 r
.59252 .44051 .59862 .43549 .61222 .47536 .60606 .47789 Metetra
.864 .447 .233 r
.60606 .47789 .61222 .47536 .62597 .50741 .61972 .50619 Metetra
.762 .249 0 r
.61972 .50619 .62597 .50741 .63968 .528 .63329 .52209 Metetra
.371 .674 .975 r
.63329 .52209 .63968 .528 .65309 .53429 .64655 .52328 Metetra
.81 .722 .768 r
.64655 .52328 .65309 .53429 .66597 .52473 .65927 .50883 Metetra
.857 .684 .667 r
.65927 .50883 .66597 .52473 .67815 .49932 .67131 .47933 Metetra
.871 .667 .623 r
.67131 .47933 .67815 .49932 .6895 .45974 .68258 .437 Metetra
.878 .659 .602 r
.68258 .437 .6895 .45974 .70003 .40918 .69312 .38542 Metetra
.778 .603 .663 r
.69312 .38542 .70003 .40918 .71001 .35475 .70494 .36226 Metetra
.895 .52 .318 r
.70494 .36226 .71001 .35475 .72628 .40666 .72109 .41201 Metetra
.896 .507 .282 r
.72109 .41201 .72628 .40666 .74298 .45724 .73748 .45773 Metetra
.876 .442 .146 r
.73748 .45773 .74298 .45724 .75951 .49812 .75347 .49071 Metetra
0 .299 .786 r
.75347 .49071 .75951 .49812 .77498 .51886 .76814 .50052 Metetra
.822 .66 .681 r
.76814 .50052 .77498 .51886 .7882 .50776 .78035 .47612 Metetra
.879 .639 .572 r
.78035 .47612 .7882 .50776 .79786 .45375 .78886 .40783 Metetra
.827 .588 .577 r
.78886 .40783 .79786 .45375 .80271 .34907 .7971 .34194 Metetra
.961 .628 .266 r
.7971 .34194 .80271 .34907 .82642 .45814 .82742 .52563 Metetra
.576 .308 .473 r
.82742 .52563 .82642 .45814 .84869 .54143 .84283 .53381 Metetra
.645 .763 .934 r
.84283 .53381 .84869 .54143 .863 .53731 .85718 .52966 Metetra
.983 .698 .383 r
.85718 .52966 .863 .53731 .85355 .30632 .84808 .29819 Metetra
.664 .741 .908 r
.84808 .29819 .85355 .30632 .86696 .30192 .86154 .29375 Metetra
.664 .741 .908 r
.86154 .29375 .86696 .30192 .88044 .2975 .87506 .28929 Metetra
.664 .741 .908 r
.27143 .47923 .2786 .48591 .28956 .4823 .28241 .47559 Metetra
.664 .741 .908 r
.28241 .47559 .28956 .4823 .30056 .47867 .29344 .47194 Metetra
.664 .741 .908 r
.29344 .47194 .30056 .47867 .29759 .69163 .30451 .46827 Metetra
0 0 .293 r
.30451 .46827 .29759 .69163 .30939 .68821 .3018 .68187 Metetra
.645 .763 .934 r
.3018 .68187 .30939 .68821 .32123 .68479 .31368 .67842 Metetra
.645 .763 .934 r
.31368 .67842 .32123 .68479 .33313 .68134 .32561 .67494 Metetra
.94 .703 .553 r
.32561 .67494 .33313 .68134 .34863 .60869 .34634 .50824 Metetra
0 0 .077 r
.34634 .50824 .34863 .60869 .36053 .60258 .35045 .65166 Metetra
.616 .337 .472 r
.35045 .65166 .36053 .60258 .36914 .67092 .36172 .66443 Metetra
.645 .763 .934 r
.36172 .66443 .36914 .67092 .38126 .66741 .37387 .6609 Metetra
.645 .763 .934 r
.37387 .6609 .38126 .66741 .39343 .66389 .38608 .65734 Metetra
.645 .763 .934 r
.38608 .65734 .39343 .66389 .40565 .66035 .39833 .65378 Metetra
.645 .763 .934 r
.39833 .65378 .40565 .66035 .41793 .6568 .41065 .65019 Metetra
.943 .722 .573 r
.41065 .65019 .41793 .6568 .4316 .60431 .4255 .56232 Metetra
.855 .621 .583 r
.4255 .56232 .4316 .60431 .44609 .50497 .43999 .46724 Metetra
.669 .497 .644 r
.43999 .46724 .44609 .50497 .45935 .43521 .45207 .4534 Metetra
.859 .545 .454 r
.45207 .4534 .45935 .43521 .46993 .50258 .46272 .51557 Metetra
.854 .52 .42 r
.46272 .51557 .46993 .50258 .48127 .55489 .47414 .56134 Metetra
.832 .448 .324 r
.47414 .56134 .48127 .55489 .49324 .58824 .48621 .58761 Metetra
.479 0 0 r
.48621 .58761 .49324 .58824 .50566 .60092 .4987 .59349 Metetra
.829 .779 .805 r
.4987 .59349 .50566 .60092 .51829 .59344 .5114 .58021 Metetra
.866 .701 .676 r
.5114 .58021 .51829 .59344 .53093 .56829 .5241 .55076 Metetra
.872 .675 .635 r
.5241 .55076 .53093 .56829 .54339 .52931 .53661 .50923 Metetra
.874 .666 .617 r
.53661 .50923 .54339 .52931 .55555 .48114 .54885 .46026 Metetra
.877 .663 .61 r
.54885 .46026 .55555 .48114 .56738 .42851 .56077 .40842 Metetra
.667 .559 .723 r
.56077 .40842 .56738 .42851 .57926 .3979 .57304 .4012 Metetra
.895 .517 .309 r
.57304 .4012 .57926 .3979 .59252 .44051 .58624 .44107 Metetra
.892 .486 .237 r
.58624 .44107 .59252 .44051 .60606 .47789 .59968 .4746 Metetra
.843 .379 .026 r
.59968 .4746 .60606 .47789 .61972 .50619 .61321 .49827 Metetra
0 .194 .708 r
.61321 .49827 .61972 .50619 .63329 .52209 .62663 .50922 Metetra
.634 .625 .824 r
.62663 .50922 .63329 .52209 .64655 .52328 .63974 .50569 Metetra
.786 .644 .705 r
.63974 .50569 .64655 .52328 .65927 .50883 .65233 .48728 Metetra
.831 .643 .648 r
.65233 .48728 .65927 .50883 .67131 .47933 .66429 .45511 Metetra
.852 .643 .619 r
.66429 .45511 .67131 .47933 .68258 .437 .67556 .41174 Metetra
.865 .645 .603 r
.67556 .41174 .68258 .437 .69312 .38542 .68619 .36095 Metetra
.429 .388 .712 r
.68619 .36095 .69312 .38542 .70494 .36226 .69972 .36889 Metetra
.891 .508 .302 r
.69972 .36889 .70494 .36226 .72109 .41201 .71564 .41465 Metetra
.891 .483 .226 r
.71564 .41465 .72109 .41201 .73748 .45773 .73162 .45383 Metetra
.791 .308 0 r
.73162 .45383 .73748 .45773 .75347 .49071 .747 .47768 Metetra
.585 .604 .837 r
.747 .47768 .75347 .49071 .76814 .50052 .76086 .47615 Metetra
.838 .637 .631 r
.76086 .47615 .76814 .50052 .78035 .47612 .77213 .43919 Metetra
.879 .631 .559 r
.77213 .43919 .78035 .47612 .78886 .40783 .7797 .35873 Metetra
.3 .231 .61 r
.7797 .35873 .78886 .40783 .7971 .34194 .79597 .38834 Metetra
.88 .555 .429 r
.79597 .38834 .7971 .34194 .82742 .52563 .82257 .5303 Metetra
.075 0 0 r
.82257 .5303 .82742 .52563 .84283 .53381 .83691 .52612 Metetra
.982 .699 .39 r
.83691 .52612 .84283 .53381 .85718 .52966 .82911 .29443 Metetra
.559 .354 .559 r
.82911 .29443 .85718 .52966 .84808 .29819 .84256 .28998 Metetra
.664 .741 .908 r
.84256 .28998 .84808 .29819 .86154 .29375 .85606 .2855 Metetra
.664 .741 .908 r
.85606 .2855 .86154 .29375 .87506 .28929 .86963 .28101 Metetra
.664 .741 .908 r
.2642 .4725 .27143 .47923 .28241 .47559 .27521 .46883 Metetra
.664 .741 .908 r
.27521 .46883 .28241 .47559 .29344 .47194 .28627 .46515 Metetra
.664 .741 .908 r
.28627 .46515 .29344 .47194 .30451 .46827 .29737 .46145 Metetra
.944 .671 .49 r
.29737 .46145 .30451 .46827 .3018 .68187 .29416 .67548 Metetra
.645 .763 .934 r
.29416 .67548 .3018 .68187 .31368 .67842 .30606 .67199 Metetra
.645 .763 .934 r
.30606 .67199 .31368 .67842 .32561 .67494 .31803 .66849 Metetra
.941 .7 .546 r
.31803 .66849 .32561 .67494 .34634 .50824 .34128 .46378 Metetra
.987 .716 .397 r
.34128 .46378 .34634 .50824 .35045 .65166 .34244 .6552 Metetra
.458 0 0 r
.34244 .6552 .35045 .65166 .36172 .66443 .35424 .65789 Metetra
.645 .763 .934 r
.35424 .65789 .36172 .66443 .37387 .6609 .36642 .65433 Metetra
.645 .763 .934 r
.36642 .65433 .37387 .6609 .38608 .65734 .37866 .65074 Metetra
.645 .763 .934 r
.37866 .65074 .38608 .65734 .39833 .65378 .39096 .64715 Metetra
.902 .765 .7 r
.39096 .64715 .39833 .65378 .41065 .65019 .40415 .61961 Metetra
.881 .649 .583 r
.40415 .61961 .41065 .65019 .4255 .56232 .41937 .52413 Metetra
.857 .625 .586 r
.41937 .52413 .4255 .56232 .43999 .46724 .43377 .43632 Metetra
0 .037 .554 r
.43377 .43632 .43999 .46724 .45207 .4534 .44483 .46326 Metetra
.883 .554 .421 r
.44483 .46326 .45207 .4534 .46272 .51557 .45557 .51859 Metetra
.891 .525 .342 r
.45557 .51859 .46272 .51557 .47414 .56134 .46709 .55722 Metetra
.826 .35 0 r
.46709 .55722 .47414 .56134 .48621 .58761 .47922 .57679 Metetra
.522 .607 .879 r
.47922 .57679 .48621 .58761 .4987 .59349 .49178 .5771 Metetra
.783 .648 .714 r
.49178 .5771 .4987 .59349 .5114 .58021 .50452 .55987 Metetra
.828 .645 .656 r
.50452 .55987 .5114 .58021 .5241 .55076 .51726 .52828 Metetra
.847 .646 .63 r
.51726 .52828 .5241 .55076 .53661 .50923 .52984 .48644 Metetra
.86 .65 .618 r
.52984 .48644 .53661 .50923 .54885 .46026 .54215 .43876 Metetra
.87 .658 .614 r
.54215 .43876 .54885 .46026 .56077 .40842 .55417 .38951 Metetra
.213 .289 .726 r
.55417 .38951 .56077 .40842 .57304 .4012 .5667 .40178 Metetra
.898 .502 .257 r
.5667 .40178 .57304 .4012 .58624 .44107 .5798 .43755 Metetra
.88 .444 .105 r
.5798 .43755 .58624 .44107 .59968 .4746 .59313 .46627 Metetra
.616 .156 0 r
.59313 .46627 .59968 .4746 .61321 .49827 .60652 .48481 Metetra
.339 .453 .831 r
.60652 .48481 .61321 .49827 .62663 .50922 .61979 .49085 Metetra
.68 .585 .743 r
.61979 .49085 .62663 .50922 .63974 .50569 .63275 .48314 Metetra
.774 .609 .676 r
.63275 .48314 .63974 .50569 .65233 .48728 .64525 .46178 Metetra
.815 .619 .639 r
.64525 .46178 .65233 .48728 .66429 .45511 .65717 .42825 Metetra
.839 .628 .618 r
.65717 .42825 .66429 .45511 .67556 .41174 .66849 .38531 Metetra
.856 .637 .606 r
.66849 .38531 .67556 .41174 .68619 .36095 .67929 .3368 Metetra
0 0 .456 r
.67929 .3368 .68619 .36095 .69972 .36889 .69432 .3739 Metetra
.886 .49 .27 r
.69432 .3739 .69972 .36889 .71564 .41465 .70993 .41421 Metetra
.873 .433 .122 r
.70993 .41421 .71564 .41465 .73162 .45383 .72544 .44568 Metetra
0 .107 .64 r
.72544 .44568 .73162 .45383 .747 .47768 .74017 .45979 Metetra
.737 .623 .732 r
.74017 .45979 .747 .47768 .76086 .47615 .75327 .4472 Metetra
.849 .629 .604 r
.75327 .4472 .76086 .47615 .77213 .43919 .76372 .39908 Metetra
.882 .628 .55 r
.76372 .39908 .77213 .43919 .7797 .35873 .77056 .30895 Metetra
0 0 .164 r
.77056 .30895 .7797 .35873 .79597 .38834 .79466 .43533 Metetra
.824 .5 .441 r
.79466 .43533 .79597 .38834 .82257 .5303 .81655 .52258 Metetra
.645 .763 .934 r
.81655 .52258 .82257 .5303 .83691 .52612 .83094 .51836 Metetra
.982 .699 .39 r
.83094 .51836 .83691 .52612 .82911 .29443 .8235 .28619 Metetra
.664 .741 .908 r
.8235 .28619 .82911 .29443 .84256 .28998 .83699 .2817 Metetra
.664 .741 .908 r
.83699 .2817 .84256 .28998 .85606 .2855 .85054 .27718 Metetra
.664 .741 .908 r
.85054 .27718 .85606 .2855 .86963 .28101 .86416 .27265 Metetra
.664 .741 .908 r
.25692 .46572 .2642 .4725 .27521 .46883 .26796 .46202 Metetra
.664 .741 .908 r
.26796 .46202 .27521 .46883 .28627 .46515 .27904 .45831 Metetra
.664 .741 .908 r
.27904 .45831 .28627 .46515 .29737 .46145 .29017 .45458 Metetra
.944 .671 .49 r
.29017 .45458 .29737 .46145 .29416 .67548 .28645 .66903 Metetra
.645 .763 .934 r
.28645 .66903 .29416 .67548 .30606 .67199 .29839 .66552 Metetra
.645 .763 .934 r
.29839 .66552 .30606 .67199 .31803 .66849 .31038 .66199 Metetra
.94 .7 .547 r
.31038 .66199 .31803 .66849 .34128 .46378 .33406 .45858 Metetra
.947 .664 .47 r
.33406 .45858 .34128 .46378 .34244 .6552 .33622 .62419 Metetra
0 0 .529 r
.33622 .62419 .34244 .6552 .35424 .65789 .3467 .6513 Metetra
.645 .763 .934 r
.3467 .6513 .35424 .65789 .36642 .65433 .35891 .6477 Metetra
.645 .763 .934 r
.35891 .6477 .36642 .65433 .37866 .65074 .37119 .64409 Metetra
.645 .763 .934 r
.37119 .64409 .37866 .65074 .39096 .64715 .38352 .64046 Metetra
.936 .732 .601 r
.38352 .64046 .39096 .64715 .40415 .61961 .39815 .57647 Metetra
.844 .613 .589 r
.39815 .57647 .40415 .61961 .41937 .52413 .41316 .49027 Metetra
.859 .63 .591 r
.41316 .49027 .41937 .52413 .43377 .43632 .42741 .41172 Metetra
.86 .558 .031 r
.42741 .41172 .43377 .43632 .44483 .46326 .43766 .46545 Metetra
.909 .559 .366 r
.43766 .46545 .44483 .46326 .45557 .51859 .44852 .51291 Metetra
.908 .499 .165 r
.44852 .51291 .45557 .51859 .46709 .55722 .46013 .54424 Metetra
0 .139 .685 r
.46013 .54424 .46709 .55722 .47922 .57679 .47232 .55778 Metetra
.627 .549 .747 r
.47232 .55778 .47922 .57679 .49178 .5771 .48491 .5538 Metetra
.756 .596 .678 r
.48491 .5538 .49178 .5771 .50452 .55987 .49768 .53428 Metetra
.802 .613 .646 r
.49768 .53428 .50452 .55987 .51726 .52828 .51045 .5024 Metetra
.828 .626 .629 r
.51045 .5024 .51726 .52828 .52984 .48644 .52307 .46206 Metetra
.847 .639 .622 r
.52307 .46206 .52984 .48644 .54215 .43876 .53545 .41731 Metetra
.862 .655 .62 r
.53545 .41731 .54215 .43876 .55417 .38951 .54757 .37202 Metetra
0 0 .4 r
.54757 .37202 .55417 .38951 .5667 .40178 .56023 .39975 Metetra
.892 .471 .174 r
.56023 .39975 .5667 .40178 .5798 .43755 .57324 .43046 Metetra
.791 .331 0 r
.57324 .43046 .5798 .43755 .59313 .46627 .58644 .45376 Metetra
0 .195 .723 r
.58644 .45376 .59313 .46627 .60652 .48481 .59969 .46703 Metetra
.525 .504 .775 r
.59969 .46703 .60652 .48481 .61979 .49085 .61282 .46843 Metetra
.698 .568 .705 r
.61282 .46843 .61979 .49085 .63275 .48314 .62566 .45723 Metetra
.767 .592 .661 r
.62566 .45723 .63275 .48314 .64525 .46178 .63809 .43392 Metetra
.804 .606 .635 r
.63809 .43392 .64525 .46178 .65717 .42825 .65002 .40021 Metetra
.829 .619 .619 r
.65002 .40021 .65717 .42825 .66849 .38531 .66145 .35893 Metetra
.746 .576 .664 r
.66145 .35893 .66849 .38531 .67929 .3368 .67364 .33901 Metetra
.892 .484 .229 r
.67364 .33901 .67929 .3368 .69432 .3739 .6887 .37667 Metetra
.877 .458 .212 r
.6887 .37667 .69432 .3739 .70993 .41421 .70397 .41047 Metetra
.793 .308 0 r
.70397 .41047 .70993 .41421 .72544 .44568 .71898 .43357 Metetra
.385 .511 .862 r
.71898 .43357 .72544 .44568 .74017 .45979 .73309 .43795 Metetra
.79 .624 .675 r
.73309 .43795 .74017 .45979 .75327 .4472 .74549 .41519 Metetra
.858 .627 .587 r
.74549 .41519 .75327 .4472 .76372 .39908 .75528 .35776 Metetra
.722 .525 .624 r
.75528 .35776 .76372 .39908 .77056 .30895 .7671 .33172 Metetra
.928 .592 .378 r
.7671 .33172 .77056 .30895 .79466 .43533 .79294 .48009 Metetra
.707 .392 .442 r
.79294 .48009 .79466 .43533 .81655 .52258 .81047 .51478 Metetra
.645 .763 .934 r
.81047 .51478 .81655 .52258 .83094 .51836 .82491 .51053 Metetra
.982 .699 .39 r
.82491 .51053 .83094 .51836 .8235 .28619 .81785 .27788 Metetra
.664 .741 .908 r
.81785 .27788 .8235 .28619 .83699 .2817 .83138 .27335 Metetra
.664 .741 .908 r
.83138 .27335 .83699 .2817 .85054 .27718 .84498 .2688 Metetra
.664 .741 .908 r
.84498 .2688 .85054 .27718 .86416 .27265 .85864 .26422 Metetra
.664 .741 .908 r
.24958 .45888 .25692 .46572 .26796 .46202 .26064 .45516 Metetra
.664 .741 .908 r
.26064 .45516 .26796 .46202 .27904 .45831 .27175 .45142 Metetra
.664 .741 .908 r
.27175 .45142 .27904 .45831 .29017 .45458 .28291 .44766 Metetra
.664 .741 .908 r
.28291 .44766 .29017 .45458 .28645 .66903 .29412 .44389 Metetra
0 0 .279 r
.29412 .44389 .28645 .66903 .29839 .66552 .29064 .65899 Metetra
.645 .763 .934 r
.29064 .65899 .29839 .66552 .31038 .66199 .30267 .65542 Metetra
.94 .702 .552 r
.30267 .65542 .31038 .66199 .33406 .45858 .3251 .48081 Metetra
.869 .576 .49 r
.3251 .48081 .33406 .45858 .33622 .62419 .33134 .5703 Metetra
0 0 .139 r
.33134 .5703 .33622 .62419 .3467 .6513 .33909 .64464 Metetra
.645 .763 .934 r
.33909 .64464 .3467 .6513 .35891 .6477 .35134 .64102 Metetra
.645 .763 .934 r
.35134 .64102 .35891 .6477 .37119 .64409 .36365 .63737 Metetra
.902 .763 .698 r
.36365 .63737 .37119 .64409 .38352 .64046 .37707 .60915 Metetra
.859 .635 .598 r
.37707 .60915 .38352 .64046 .39815 .57647 .39216 .53575 Metetra
.837 .609 .594 r
.39216 .53575 .39815 .57647 .41316 .49027 .40686 .46089 Metetra
.833 .62 .615 r
.40686 .46089 .41316 .49027 .42741 .41172 .42033 .40989 Metetra
.93 .582 .351 r
.42033 .40989 .42741 .41172 .43766 .46545 .43058 .46095 Metetra
.927 .549 .264 r
.43058 .46095 .43766 .46545 .44852 .51291 .44159 .50007 Metetra
.705 .31 0 r
.44159 .50007 .44852 .51291 .46013 .54424 .45328 .52435 Metetra
.344 .37 .745 r
.45328 .52435 .46013 .54424 .47232 .55778 .46552 .53266 Metetra
.647 .524 .699 r
.46552 .53266 .47232 .55778 .48491 .5538 .47812 .52562 Metetra
.738 .567 .662 r
.47812 .52562 .48491 .5538 .49768 .53428 .49089 .50525 Metetra
.783 .592 .642 r
.49089 .50525 .49768 .53428 .51045 .5024 .50366 .47457 Metetra
.812 .611 .631 r
.50366 .47457 .51045 .5024 .52307 .46206 .51631 .4371 Metetra
.834 .631 .628 r
.51631 .4371 .52307 .46206 .53545 .41731 .52875 .39647 Metetra
.826 .64 .651 r
.52875 .39647 .53545 .41731 .54757 .37202 .54102 .3655 Metetra
.88 .453 .054 r
.54102 .3655 .54757 .37202 .56023 .39975 .55367 .39528 Metetra
.856 .404 .033 r
.55367 .39528 .56023 .39975 .57324 .43046 .56659 .42034 Metetra
0 0 .48 r
.56659 .42034 .57324 .43046 .58644 .45376 .57967 .438 Metetra
.296 .39 .79 r
.57967 .438 .58644 .45376 .59969 .46703 .59278 .44611 Metetra
.602 .522 .737 r
.59278 .44611 .59969 .46703 .61282 .46843 .60579 .44337 Metetra
.71 .562 .685 r
.60579 .44337 .61282 .46843 .62566 .45723 .61854 .42945 Metetra
.763 .583 .654 r
.61854 .42945 .62566 .45723 .63809 .43392 .63093 .40513 Metetra
.797 .599 .634 r
.63093 .40513 .63809 .43392 .65002 .40021 .64291 .37226 Metetra
.822 .615 .623 r
.64291 .37226 .65002 .40021 .66145 .35893 .65447 .33362 Metetra
.366 .343 .701 r
.65447 .33362 .66145 .35893 .67364 .33901 .66805 .34447 Metetra
.86 .451 .255 r
.66805 .34447 .67364 .33901 .6887 .37667 .68287 .37672 Metetra
.852 .397 .102 r
.68287 .37672 .6887 .37667 .70397 .41047 .69776 .40338 Metetra
0 .032 .552 r
.69776 .40338 .70397 .41047 .71898 .43357 .71227 .41796 Metetra
.647 .6 .788 r
.71227 .41796 .71898 .43357 .73309 .43795 .72581 .41315 Metetra
.816 .624 .643 r
.72581 .41315 .73309 .43795 .74549 .41519 .73764 .38159 Metetra
.866 .628 .576 r
.73764 .38159 .74549 .41519 .75528 .35776 .74696 .31703 Metetra
0 .017 .536 r
.74696 .31703 .75528 .35776 .7671 .33172 .76411 .36285 Metetra
.913 .58 .398 r
.76411 .36285 .7671 .33172 .79294 .48009 .78992 .51119 Metetra
.47 .165 .366 r
.78992 .51119 .79294 .48009 .81047 .51478 .80434 .50692 Metetra
.982 .7 .396 r
.80434 .50692 .81047 .51478 .82491 .51053 .79862 .27405 Metetra
.556 .349 .555 r
.79862 .27405 .82491 .51053 .81785 .27788 .81214 .2695 Metetra
.664 .741 .908 r
.81214 .2695 .81785 .27788 .83138 .27335 .82572 .26493 Metetra
.664 .741 .908 r
.82572 .26493 .83138 .27335 .84498 .2688 .83936 .26033 Metetra
.664 .741 .908 r
.83936 .26033 .84498 .2688 .85864 .26422 .85307 .25572 Metetra
.664 .741 .908 r
.24218 .452 .24958 .45888 .26064 .45516 .25327 .44824 Metetra
.664 .741 .908 r
.25327 .44824 .26064 .45516 .27175 .45142 .26441 .44447 Metetra
.664 .741 .908 r
.26441 .44447 .27175 .45142 .28291 .44766 .2756 .44069 Metetra
.664 .741 .908 r
.2756 .44069 .28291 .44766 .29412 .44389 .28683 .43688 Metetra
.945 .671 .487 r
.28683 .43688 .29412 .44389 .29064 .65899 .28284 .6524 Metetra
.645 .763 .934 r
.28284 .6524 .29064 .65899 .30267 .65542 .2949 .64881 Metetra
.938 .708 .565 r
.2949 .64881 .30267 .65542 .3251 .48081 .31482 .52103 Metetra
.305 .041 .338 r
.31482 .52103 .3251 .48081 .33134 .5703 .32734 .50419 Metetra
0 0 .097 r
.32734 .50419 .33134 .5703 .33909 .64464 .3337 .59699 Metetra
.188 .136 .564 r
.3337 .59699 .33909 .64464 .35134 .64102 .34418 .62505 Metetra
.793 .654 .71 r
.34418 .62505 .35134 .64102 .36365 .63737 .35723 .60625 Metetra
.818 .611 .622 r
.35723 .60625 .36365 .63737 .37707 .60915 .37153 .55892 Metetra
.792 .57 .601 r
.37153 .55892 .37707 .60915 .39216 .53575 .38612 .49839 Metetra
.828 .607 .603 r
.38612 .49839 .39216 .53575 .40686 .46089 .40043 .43587 Metetra
.781 .6 .655 r
.40043 .43587 .40686 .46089 .42033 .40989 .41313 .40937 Metetra
.914 .552 .332 r
.41313 .40937 .42033 .40989 .43058 .46095 .42361 .45095 Metetra
.889 .485 .056 r
.42361 .45095 .43058 .46095 .44159 .50007 .43477 .48175 Metetra
0 .073 .624 r
.43477 .48175 .44159 .50007 .45328 .52435 .44655 .49949 Metetra
.488 .424 .711 r
.44655 .49949 .45328 .52435 .46552 .53266 .45881 .50347 Metetra
.654 .511 .677 r
.45881 .50347 .46552 .53266 .47812 .52562 .47141 .49448 Metetra
.725 .55 .654 r
.47141 .49448 .47812 .52562 .49089 .50525 .48416 .47444 Metetra
.766 .577 .642 r
.48416 .47444 .49089 .50525 .50366 .47457 .49691 .44605 Metetra
.796 .6 .636 r
.49691 .44605 .50366 .47457 .51631 .4371 .50957 .41243 Metetra
.822 .625 .636 r
.50957 .41243 .51631 .4371 .52875 .39647 .52205 .3767 Metetra
.721 .592 .711 r
.52205 .3767 .52875 .39647 .54102 .3655 .53442 .3645 Metetra
.86 .417 .14 r
.53442 .3645 .54102 .3655 .55367 .39528 .54703 .38859 Metetra
.735 .254 0 r
.54703 .38859 .55367 .39528 .56659 .42034 .55986 .40778 Metetra
0 .229 .745 r
.55986 .40778 .56659 .42034 .57967 .438 .57284 .41987 Metetra
.476 .471 .773 r
.57284 .41987 .57967 .438 .59278 .44611 .58584 .42322 Metetra
.644 .534 .714 r
.58584 .42322 .59278 .44611 .60579 .44337 .59874 .41696 Metetra
.718 .561 .675 r
.59874 .41696 .60579 .44337 .61854 .42945 .61142 .40112 Metetra
.762 .58 .651 r
.61142 .40112 .61854 .42945 .63093 .40513 .62381 .37666 Metetra
.792 .597 .637 r
.62381 .37666 .63093 .40513 .64291 .37226 .63585 .34546 Metetra
.778 .593 .649 r
.63585 .34546 .64291 .37226 .65447 .33362 .64794 .31928 Metetra
0 0 .376 r
.64794 .31928 .65447 .33362 .66805 .34447 .66225 .34747 Metetra
.845 .406 .18 r
.66225 .34747 .66805 .34447 .68287 .37672 .67681 .37372 Metetra
.762 .255 0 r
.67681 .37372 .68287 .37672 .69776 .40338 .69132 .39302 Metetra
.232 .459 .873 r
.69132 .39302 .69776 .40338 .71227 .41796 .70538 .39941 Metetra
.738 .618 .726 r
.70538 .39941 .71227 .41796 .72581 .41315 .71843 .38642 Metetra
.833 .626 .623 r
.71843 .38642 .72581 .41315 .73764 .38159 .72981 .34779 Metetra
.855 .62 .584 r
.72981 .34779 .73764 .38159 .74696 .31703 .73958 .28911 Metetra
.838 .534 0 r
.73958 .28911 .74696 .31703 .76411 .36285 .76066 .39021 Metetra
.9 .56 .391 r
.76066 .39021 .76411 .36285 .78992 .51119 .78368 .50329 Metetra
.645 .763 .934 r
.78368 .50329 .78992 .51119 .80434 .50692 .79815 .49898 Metetra
.982 .7 .396 r
.79815 .49898 .80434 .50692 .79862 .27405 .79282 .26563 Metetra
.664 .741 .908 r
.79282 .26563 .79862 .27405 .81214 .2695 .80638 .26104 Metetra
.664 .741 .908 r
.80638 .26104 .81214 .2695 .82572 .26493 .82001 .25643 Metetra
.664 .741 .908 r
.82001 .25643 .82572 .26493 .83936 .26033 .83369 .2518 Metetra
.664 .741 .908 r
.83369 .2518 .83936 .26033 .85307 .25572 .84745 .24714 Metetra
.664 .741 .908 r
.23472 .44505 .24218 .452 .25327 .44824 .24584 .44127 Metetra
.664 .741 .908 r
.24584 .44127 .25327 .44824 .26441 .44447 .25701 .43747 Metetra
.664 .741 .908 r
.25701 .43747 .26441 .44447 .2756 .44069 .26822 .43365 Metetra
.664 .741 .908 r
.26822 .43365 .2756 .44069 .28683 .43688 .27949 .42982 Metetra
.945 .671 .487 r
.27949 .42982 .28683 .43688 .28284 .6524 .27496 .64576 Metetra
.645 .763 .934 r
.27496 .64576 .28284 .6524 .2949 .64881 .28706 .64214 Metetra
.93 .723 .601 r
.28706 .64214 .2949 .64881 .31482 .52103 .30362 .57087 Metetra
.991 .811 .43 r
.30362 .57087 .31482 .52103 .32734 .50419 .32378 .43461 Metetra
0 0 .16 r
.32378 .43461 .32734 .50419 .3337 .59699 .32995 .5234 Metetra
.304 .187 .55 r
.32995 .5234 .3337 .59699 .34418 .62505 .33993 .55566 Metetra
.598 .412 .601 r
.33993 .55566 .34418 .62505 .35723 .60625 .35232 .54671 Metetra
.71 .503 .607 r
.35232 .54671 .35723 .60625 .37153 .55892 .36595 .5121 Metetra
.772 .558 .609 r
.36595 .5121 .37153 .55892 .38612 .49839 .37998 .46493 Metetra
.817 .604 .614 r
.37998 .46493 .38612 .49839 .40043 .43587 .39385 .41495 Metetra
.697 .57 .708 r
.39385 .41495 .40043 .43587 .41313 .40937 .40599 .40463 Metetra
.914 .517 .217 r
.40599 .40463 .41313 .40937 .42361 .45095 .41672 .43672 Metetra
0 0 .326 r
.41672 .43672 .42361 .45095 .43477 .48175 .42805 .45962 Metetra
.249 .286 .705 r
.42805 .45962 .43477 .48175 .44655 .49949 .43991 .47155 Metetra
.547 .446 .691 r
.43991 .47155 .44655 .49949 .45881 .50347 .45219 .47211 Metetra
.656 .505 .667 r
.45219 .47211 .45881 .50347 .47141 .49448 .46476 .46211 Metetra
.713 .539 .652 r
.46476 .46211 .47141 .49448 .48416 .47444 .47747 .44329 Metetra
.752 .566 .645 r
.47747 .44329 .48416 .47444 .49691 .44605 .49019 .41797 Metetra
.782 .592 .644 r
.49019 .41797 .49691 .44605 .50957 .41243 .50283 .38879 Metetra
.809 .621 .648 r
.50283 .38879 .50957 .41243 .52205 .3767 .51534 .35837 Metetra
.473 .463 .766 r
.51534 .35837 .52205 .3767 .53442 .3645 .52774 .36173 Metetra
.803 .311 0 r
.52774 .36173 .53442 .3645 .54703 .38859 .54032 .37995 Metetra
0 .041 .579 r
.54032 .37995 .54703 .38859 .55986 .40778 .55309 .39337 Metetra
.305 .417 .812 r
.55309 .39337 .55986 .40778 .57284 .41987 .56597 .40025 Metetra
.569 .512 .752 r
.56597 .40025 .57284 .41987 .58584 .42322 .57888 .39941 Metetra
.671 .545 .702 r
.57888 .39941 .58584 .42322 .59874 .41696 .5917 .39036 Metetra
.725 .564 .672 r
.5917 .39036 .59874 .41696 .61142 .40112 .60435 .37339 Metetra
.762 .581 .654 r
.60435 .37339 .61142 .40112 .62381 .37666 .61675 .34956 Metetra
.789 .599 .644 r
.61675 .34956 .62381 .37666 .63585 .34546 .62889 .3207 Metetra
.498 .432 .713 r
.62889 .3207 .63585 .34546 .64794 .31928 .64209 .32425 Metetra
.82 .385 .206 r
.64209 .32425 .64794 .31928 .66225 .34747 .65624 .34752 Metetra
.804 .316 .029 r
.65624 .34752 .66225 .34747 .67681 .37372 .67053 .36752 Metetra
0 .098 .593 r
.67053 .36752 .67681 .37372 .69132 .39302 .6847 .37965 Metetra
.568 .591 .837 r
.6847 .37965 .69132 .39302 .70538 .39941 .69836 .3786 Metetra
.778 .623 .688 r
.69836 .3786 .70538 .39941 .71843 .38642 .71102 .35881 Metetra
.845 .629 .611 r
.71102 .35881 .71843 .38642 .72981 .34779 .7221 .31506 Metetra
.623 .481 .667 r
.7221 .31506 .72981 .34779 .73958 .28911 .73539 .3082 Metetra
.914 .567 .37 r
.73539 .3082 .73958 .28911 .76066 .39021 .75663 .41178 Metetra
.889 .537 .372 r
.75663 .41178 .76066 .39021 .78368 .50329 .77738 .49532 Metetra
.645 .763 .934 r
.77738 .49532 .78368 .50329 .79815 .49898 .7919 .49097 Metetra
.982 .7 .396 r
.7919 .49097 .79815 .49898 .79282 .26563 .78697 .25714 Metetra
.664 .741 .908 r
.78697 .25714 .79282 .26563 .80638 .26104 .80057 .25251 Metetra
.664 .741 .908 r
.80057 .25251 .80638 .26104 .82001 .25643 .81424 .24786 Metetra
.664 .741 .908 r
.81424 .24786 .82001 .25643 .83369 .2518 .82798 .24319 Metetra
.664 .741 .908 r
.82798 .24319 .83369 .2518 .84745 .24714 .84178 .23849 Metetra
.664 .741 .908 r
.22721 .43805 .23472 .44505 .24584 .44127 .23835 .43424 Metetra
.664 .741 .908 r
.23835 .43424 .24584 .44127 .25701 .43747 .24955 .43041 Metetra
.664 .741 .908 r
.24955 .43041 .25701 .43747 .26822 .43365 .26079 .42656 Metetra
.664 .741 .908 r
.26079 .42656 .26822 .43365 .27949 .42982 .27209 .4227 Metetra
.664 .741 .908 r
.27209 .4227 .27949 .42982 .27496 .64576 .28343 .41882 Metetra
0 0 .264 r
.28343 .41882 .27496 .64576 .28706 .64214 .27915 .63541 Metetra
.826 .782 .81 r
.27915 .63541 .28706 .64214 .30362 .57087 .29196 .62241 Metetra
.999 .793 .463 r
.29196 .62241 .30362 .57087 .32378 .43461 .31519 .4469 Metetra
.629 .239 .286 r
.31519 .4469 .32378 .43461 .32995 .5234 .32619 .45414 Metetra
.222 .127 .53 r
.32619 .45414 .32995 .5234 .33993 .55566 .33562 .49114 Metetra
.544 .374 .601 r
.33562 .49114 .33993 .55566 .35232 .54671 .34732 .49207 Metetra
.675 .48 .614 r
.34732 .49207 .35232 .54671 .36595 .5121 .36027 .4699 Metetra
.748 .546 .621 r
.36027 .4699 .36595 .5121 .37998 .46493 .3737 .43568 Metetra
.803 .603 .631 r
.3737 .43568 .37998 .46493 .39385 .41495 .38712 .39777 Metetra
.58 .534 .768 r
.38712 .39777 .39385 .41495 .40599 .40463 .39891 .39644 Metetra
.844 .403 0 r
.39891 .39644 .40599 .40463 .41672 .43672 .40991 .41953 Metetra
0 .104 .648 r
.40991 .41953 .41672 .43672 .42805 .45962 .4214 .43525 Metetra
.415 .378 .709 r
.4214 .43525 .42805 .45962 .43991 .47155 .43333 .44223 Metetra
.579 .461 .682 r
.43333 .44223 .43991 .47155 .45219 .47211 .44562 .44023 Metetra
.656 .503 .664 r
.44562 .44023 .45219 .47211 .46476 .46211 .45815 .43001 Metetra
.703 .533 .655 r
.45815 .43001 .46476 .46211 .47747 .44329 .47081 .41304 Metetra
.738 .56 .652 r
.47081 .41304 .47747 .44329 .49019 .41797 .48348 .39124 Metetra
.767 .587 .655 r
.48348 .39124 .49019 .41797 .50283 .38879 .4961 .36676 Metetra
.794 .62 .664 r
.4961 .36676 .50283 .38879 .51534 .35837 .50862 .34182 Metetra
0 .149 .678 r
.50862 .34182 .51534 .35837 .52774 .36173 .52098 .35717 Metetra
.62 .081 0 r
.52098 .35717 .52774 .36173 .54032 .37995 .53355 .36968 Metetra
.078 .362 .83 r
.53355 .36968 .54032 .37995 .55309 .39337 .54627 .37769 Metetra
.486 .506 .803 r
.54627 .37769 .55309 .39337 .56597 .40025 .5591 .37993 Metetra
.625 .539 .737 r
.5591 .37993 .56597 .40025 .57888 .39941 .57193 .37562 Metetra
.691 .556 .697 r
.57193 .37562 .57888 .39941 .5917 .39036 .5847 .36455 Metetra
.732 .571 .673 r
.5847 .36455 .5917 .39036 .60435 .37339 .59733 .3472 Metetra
.762 .587 .66 r
.59733 .3472 .60435 .37339 .61675 .34956 .60978 .32465 Metetra
.737 .577 .675 r
.60978 .32465 .61675 .34956 .62889 .3207 .62229 .30727 Metetra
0 .012 .586 r
.62229 .30727 .62889 .3207 .64209 .32425 .63604 .32621 Metetra
.788 .306 .078 r
.63604 .32621 .64209 .32425 .65624 .34752 .65001 .3443 Metetra
.645 .101 0 r
.65001 .3443 .65624 .34752 .67053 .36752 .66405 .35815 Metetra
.23 .487 .893 r
.66405 .35815 .67053 .36752 .6847 .37965 .67791 .36365 Metetra
.686 .616 .772 r
.67791 .36365 .6847 .37965 .69836 .3786 .69125 .35625 Metetra
.8 .626 .666 r
.69125 .35625 .69836 .3786 .71102 .35881 .70363 .3313 Metetra
.854 .634 .604 r
.70363 .3313 .71102 .35881 .7221 .31506 .71456 .28455 Metetra
0 0 .522 r
.71456 .28455 .7221 .31506 .73539 .3082 .73078 .32318 Metetra
.923 .572 .352 r
.73078 .32318 .73539 .3082 .75663 .41178 .75191 .42574 Metetra
.886 .513 .328 r
.75191 .42574 .75663 .41178 .77738 .49532 .77102 .48727 Metetra
.982 .701 .403 r
.77102 .48727 .77738 .49532 .7919 .49097 .76748 .25323 Metetra
.552 .343 .551 r
.76748 .25323 .7919 .49097 .78697 .25714 .78107 .24858 Metetra
.664 .741 .908 r
.78107 .24858 .78697 .25714 .80057 .25251 .79472 .24391 Metetra
.664 .741 .908 r
.79472 .24391 .80057 .25251 .81424 .24786 .80843 .23922 Metetra
.664 .741 .908 r
.80843 .23922 .81424 .24786 .82798 .24319 .82221 .2345 Metetra
.664 .741 .908 r
.82221 .2345 .82798 .24319 .84178 .23849 .83606 .22976 Metetra
.664 .741 .908 r
.21963 .431 .22721 .43805 .23835 .43424 .23081 .42716 Metetra
.664 .741 .908 r
.23081 .42716 .23835 .43424 .24955 .43041 .24203 .4233 Metetra
.664 .741 .908 r
.24203 .4233 .24955 .43041 .26079 .42656 .2533 .41942 Metetra
.664 .741 .908 r
.2533 .41942 .26079 .42656 .27209 .4227 .26462 .41553 Metetra
.664 .741 .908 r
.26462 .41553 .27209 .4227 .28343 .41882 .27599 .41161 Metetra
.946 .671 .484 r
.27599 .41161 .28343 .41882 .27915 .63541 .27117 .62862 Metetra
.645 .763 .934 r
.27117 .62862 .27915 .63541 .29196 .62241 .28339 .62492 Metetra
.957 .73 .554 r
.28339 .62492 .29196 .62241 .31519 .4469 .30406 .49511 Metetra
.921 .809 .342 r
.30406 .49511 .31519 .4469 .32619 .45414 .32179 .39865 Metetra
.119 .066 .517 r
.32179 .39865 .32619 .45414 .33562 .49114 .33107 .43415 Metetra
.469 .323 .6 r
.33107 .43415 .33562 .49114 .34732 .49207 .34212 .44399 Metetra
.628 .452 .624 r
.34212 .44399 .34732 .49207 .36027 .4699 .3544 .43314 Metetra
.717 .532 .638 r
.3544 .43314 .36027 .4699 .3737 .43568 .36725 .41077 Metetra
.784 .602 .655 r
.36725 .41077 .3737 .43568 .38712 .39777 .38022 .38392 Metetra
.486 .526 .824 r
.38022 .38392 .38712 .39777 .39891 .39644 .39189 .38563 Metetra
0 0 .501 r
.39189 .38563 .39891 .39644 .40991 .41953 .40315 .40057 Metetra
.263 .325 .739 r
.40315 .40057 .40991 .41953 .4214 .43525 .4148 .41006 Metetra
.502 .429 .707 r
.4148 .41006 .4214 .43525 .43333 .44223 .4268 .413 Metetra
.599 .474 .681 r
.4268 .413 .43333 .44223 .44562 .44023 .43908 .40925 Metetra
.655 .504 .667 r
.43908 .40925 .44562 .44023 .45815 .43001 .45156 .39942 Metetra
.694 .53 .662 r
.45156 .39942 .45815 .43001 .47081 .41304 .46415 .38469 Metetra
.725 .557 .662 r
.46415 .38469 .47081 .41304 .48348 .39124 .47676 .3666 Metetra
.752 .586 .67 r
.47676 .3666 .48348 .39124 .4961 .36676 .48934 .34681 Metetra
.649 .552 .732 r
.48934 .34681 .4961 .36676 .50862 .34182 .50176 .3409 Metetra
.649 .092 0 r
.50176 .3409 .50862 .34182 .52098 .35717 .51416 .35087 Metetra
0 .317 .777 r
.51416 .35087 .52098 .35717 .53355 .36968 .52673 .35807 Metetra
.4 .528 .871 r
.52673 .35807 .53355 .36968 .54627 .37769 .53943 .36129 Metetra
.584 .552 .785 r
.53943 .36129 .54627 .37769 .5591 .37993 .55221 .35963 Metetra
.661 .56 .73 r
.55221 .35963 .5591 .37993 .57193 .37562 .565 .35264 Metetra
.706 .569 .698 r
.565 .35264 .57193 .37562 .5847 .36455 .57775 .34035 Metetra
.738 .581 .68 r
.57775 .34035 .5847 .36455 .59733 .3472 .59038 .3233 Metetra
.764 .597 .671 r
.59038 .3233 .59733 .3472 .60978 .32465 .60289 .30257 Metetra
.398 .387 .731 r
.60289 .30257 .60978 .32465 .62229 .30727 .61613 .31 Metetra
.748 .256 .062 r
.61613 .31 .62229 .30727 .63604 .32621 .62978 .32476 Metetra
.676 .127 0 r
.62978 .32476 .63604 .32621 .65001 .3443 .64359 .33769 Metetra
0 .322 .789 r
.64359 .33769 .65001 .3443 .66405 .35815 .6574 .34578 Metetra
.539 .595 .858 r
.6574 .34578 .66405 .35815 .67791 .36365 .67101 .34553 Metetra
.735 .621 .731 r
.67101 .34553 .67791 .36365 .69125 .35625 .6841 .33315 Metetra
.813 .629 .653 r
.6841 .33315 .69125 .35625 .70363 .3313 .69631 .30484 Metetra
.826 .622 .628 r
.69631 .30484 .70363 .3313 .71456 .28455 .70795 .26913 Metetra
.864 .509 .006 r
.70795 .26913 .71456 .28455 .73078 .32318 .72569 .33274 Metetra
.932 .576 .325 r
.72569 .33274 .73078 .32318 .75191 .42574 .74644 .43065 Metetra
.895 .491 .232 r
.74644 .43065 .75191 .42574 .77102 .48727 .7646 .47915 Metetra
.982 .701 .403 r
.7646 .47915 .77102 .48727 .76748 .25323 .76148 .24463 Metetra
.664 .741 .908 r
.76148 .24463 .76748 .25323 .78107 .24858 .77511 .23994 Metetra
.664 .741 .908 r
.77511 .23994 .78107 .24858 .79472 .24391 .78881 .23523 Metetra
.664 .741 .908 r
.78881 .23523 .79472 .24391 .80843 .23922 .80257 .23049 Metetra
.664 .741 .908 r
.80257 .23049 .80843 .23922 .82221 .2345 .8164 .22574 Metetra
.664 .741 .908 r
.8164 .22574 .82221 .2345 .83606 .22976 .83029 .22096 Metetra
.664 .741 .908 r
.212 .42389 .21963 .431 .23081 .42716 .2232 .42002 Metetra
.664 .741 .908 r
.2232 .42002 .23081 .42716 .24203 .4233 .23445 .41613 Metetra
.664 .741 .908 r
.23445 .41613 .24203 .4233 .2533 .41942 .24575 .41222 Metetra
.664 .741 .908 r
.24575 .41222 .2533 .41942 .26462 .41553 .2571 .40829 Metetra
.664 .741 .908 r
.2571 .40829 .26462 .41553 .27599 .41161 .2685 .40435 Metetra
.664 .741 .908 r
.2685 .40435 .27599 .41161 .27117 .62862 .27995 .40039 Metetra
0 0 .257 r
.27995 .40039 .27117 .62862 .28339 .62492 .27538 .61804 Metetra
.934 .719 .588 r
.27538 .61804 .28339 .62492 .30406 .49511 .29324 .53382 Metetra
.981 .83 .432 r
.29324 .53382 .30406 .49511 .32179 .39865 .31149 .43589 Metetra
.31149 .43589 .32179 .39865 .33107 .43415 .32613 .38643 Metetra
.353 .25 .597 r
.32613 .38643 .33107 .43415 .34212 .44399 .3366 .40356 Metetra
.562 .415 .64 r
.3366 .40356 .34212 .44399 .3544 .43314 .34828 .40232 Metetra
.674 .516 .663 r
.34828 .40232 .3544 .43314 .36725 .41077 .3606 .39018 Metetra
.756 .605 .69 r
.3606 .39018 .36725 .41077 .38022 .38392 .37314 .37301 Metetra
.528 .604 .873 r
.37314 .37301 .38022 .38392 .39189 .38563 .3849 .37295 Metetra
.141 .345 .806 r
.3849 .37295 .39189 .38563 .40315 .40057 .39641 .3809 Metetra
.444 .432 .751 r
.39641 .3809 .40315 .40057 .4148 .41006 .4082 .38524 Metetra
.554 .464 .707 r
.4082 .38524 .4148 .41006 .4268 .413 .42025 .38508 Metetra
.613 .487 .685 r
.42025 .38508 .4268 .413 .43908 .40925 .43252 .38028 Metetra
.653 .509 .675 r
.43252 .38028 .43908 .40925 .45156 .39942 .44495 .3713 Metetra
.684 .532 .673 r
.44495 .3713 .45156 .39942 .46415 .38469 .45747 .35902 Metetra
.711 .557 .678 r
.45747 .35902 .46415 .38469 .47676 .3666 .47001 .34459 Metetra
.718 .579 .697 r
.47001 .34459 .47676 .3666 .48934 .34681 .48252 .3314 Metetra
.324 .411 .798 r
.48252 .3314 .48934 .34681 .50176 .3409 .49483 .33789 Metetra
0 .33 .675 r
.49483 .33789 .50176 .3409 .51416 .35087 .50728 .34294 Metetra
.332 .591 .939 r
.50728 .34294 .51416 .35087 .52673 .35807 .51987 .34548 Metetra
.558 .594 .846 r
.51987 .34548 .52673 .35807 .53943 .36129 .53257 .34468 Metetra
.641 .581 .772 r
.53257 .34468 .53943 .36129 .55221 .35963 .54533 .33997 Metetra
.686 .579 .729 r
.54533 .33997 .55221 .35963 .565 .35264 .5581 .33114 Metetra
.718 .584 .704 r
.5581 .33114 .565 .35264 .57775 .34035 .57083 .31838 Metetra
.743 .595 .691 r
.57083 .31838 .57775 .34035 .59038 .3233 .5835 .30226 Metetra
.616 .528 .733 r
.5835 .30226 .59038 .3233 .60289 .30257 .59641 .29829 Metetra
.51 0 0 r
.59641 .29829 .60289 .30257 .61613 .31 .60978 .3092 Metetra
.626 .061 0 r
.60978 .3092 .61613 .31 .62978 .32476 .62333 .31973 Metetra
0 .261 .702 r
.62333 .31973 .62978 .32476 .64359 .33769 .63699 .32776 Metetra
.375 .561 .907 r
.63699 .32776 .64359 .33769 .6574 .34578 .65061 .33077 Metetra
.648 .61 .797 r
.65061 .33077 .6574 .34578 .67101 .34553 .66402 .3259 Metetra
.757 .62 .708 r
.66402 .3259 .67101 .34553 .6841 .33315 .67695 .31007 Metetra
.821 .633 .649 r
.67695 .31007 .6841 .33315 .69631 .30484 .68912 .28028 Metetra
.614 .509 .711 r
.68912 .28028 .69631 .30484 .70795 .26913 .70257 .27574 Metetra
.911 .531 .288 r
.70257 .27574 .70795 .26913 .72569 .33274 .72008 .33579 Metetra
.939 .576 .281 r
.72008 .33579 .72569 .33274 .74644 .43065 .74021 .42559 Metetra
.985 .712 .415 r
.74021 .42559 .74644 .43065 .7646 .47915 .74181 .24066 Metetra
.549 .339 .548 r
.74181 .24066 .7646 .47915 .76148 .24463 .75543 .23595 Metetra
.664 .741 .908 r
.75543 .23595 .76148 .24463 .77511 .23994 .7691 .23122 Metetra
.664 .741 .908 r
.7691 .23122 .77511 .23994 .78881 .23523 .78285 .22647 Metetra
.664 .741 .908 r
.78285 .22647 .78881 .23523 .80257 .23049 .79665 .2217 Metetra
.664 .741 .908 r
.79665 .2217 .80257 .23049 .8164 .22574 .81053 .2169 Metetra
.664 .741 .908 r
.81053 .2169 .8164 .22574 .83029 .22096 .82447 .21208 Metetra
.664 .741 .908 r
.2043 .41673 .212 .42389 .2232 .42002 .21553 .41282 Metetra
.664 .741 .908 r
.21553 .41282 .2232 .42002 .23445 .41613 .22681 .4089 Metetra
.664 .741 .908 r
.22681 .4089 .23445 .41613 .24575 .41222 .23814 .40496 Metetra
.664 .741 .908 r
.23814 .40496 .24575 .41222 .2571 .40829 .24952 .401 Metetra
.664 .741 .908 r
.24952 .401 .2571 .40829 .2685 .40435 .26095 .39703 Metetra
.664 .741 .908 r
.26095 .39703 .2685 .40435 .27995 .40039 .27243 .39303 Metetra
.948 .671 .481 r
.27243 .39303 .27995 .40039 .27538 .61804 .2673 .6111 Metetra
.924 .735 .628 r
.2673 .6111 .27538 .61804 .29324 .53382 .28311 .55882 Metetra
1 .815 .51 r
.28311 .55882 .29324 .53382 .31149 .43589 .30165 .46223 Metetra
.936 .858 .427 r
.30165 .46223 .31149 .43589 .32613 .38643 .31703 .40528 Metetra
.75 .83 .37 r
.31703 .40528 .32613 .38643 .3366 .40356 .3305 .37423 Metetra
.496 .402 .678 r
.3305 .37423 .3366 .40356 .34828 .40232 .34186 .37767 Metetra
.608 .497 .702 r
.34186 .37767 .34828 .40232 .3606 .39018 .35372 .37382 Metetra
.71 .612 .745 r
.35372 .37382 .3606 .39018 .37314 .37301 .3659 .3646 Metetra
.698 .731 .876 r
.3659 .3646 .37314 .37301 .3849 .37295 .37792 .35911 Metetra
.459 .514 .828 r
.37792 .35911 .3849 .37295 .39641 .3809 .38966 .36142 Metetra
.54 .492 .751 r
.38966 .36142 .39641 .3809 .4082 .38524 .40157 .36177 Metetra
.588 .492 .714 r
.40157 .36177 .4082 .38524 .42025 .38508 .41366 .35942 Metetra
.622 .503 .696 r
.41366 .35942 .42025 .38508 .43252 .38028 .42591 .3542 Metetra
.65 .518 .689 r
.42591 .3542 .43252 .38028 .44495 .3713 .43828 .34638 Metetra
.674 .538 .691 r
.43828 .34638 .44495 .3713 .45747 .35902 .45073 .33658 Metetra
.673 .551 .707 r
.45073 .33658 .45747 .35902 .47001 .34459 .46317 .32781 Metetra
.47 .481 .787 r
.46317 .32781 .47001 .34459 .48252 .3314 .47544 .33054 Metetra
.155 0 0 r
.47544 .33054 .48252 .3314 .49483 .33789 .48784 .33273 Metetra
.334 .689 .98 r
.48784 .33273 .49483 .33789 .50728 .34294 .50036 .33352 Metetra
.56 .664 .907 r
.50036 .33352 .50728 .34294 .51987 .34548 .51298 .33223 Metetra
.637 .623 .819 r
.51298 .33223 .51987 .34548 .53257 .34468 .52568 .3283 Metetra
.677 .602 .765 r
.52568 .3283 .53257 .34468 .54533 .33997 .53844 .32145 Metetra
.704 .597 .734 r
.53844 .32145 .54533 .33997 .5581 .33114 .55121 .31163 Metetra
.727 .602 .717 r
.55121 .31163 .5581 .33114 .57083 .31838 .56396 .29911 Metetra
.691 .584 .731 r
.56396 .29911 .57083 .31838 .5835 .30226 .57676 .29003 Metetra
.22 .409 .837 r
.57676 .29003 .5835 .30226 .59641 .29829 .58992 .29717 Metetra
.496 0 0 r
.58992 .29717 .59641 .29829 .60978 .3092 .60325 .30467 Metetra
0 .337 .748 r
.60325 .30467 .60978 .3092 .62333 .31973 .61671 .31112 Metetra
.292 .551 .923 r
.61671 .31112 .62333 .31973 .63699 .32776 .63023 .31478 Metetra
.565 .599 .846 r
.63023 .31478 .63699 .32776 .65061 .33077 .64371 .31363 Metetra
.691 .608 .759 r
.64371 .31363 .65061 .33077 .66402 .3259 .65698 .30543 Metetra
.766 .62 .697 r
.65698 .30543 .66402 .3259 .67695 .31007 .66985 .28779 Metetra
.824 .638 .651 r
.66985 .28779 .67695 .31007 .68912 .28028 .68207 .25836 Metetra
.067 .175 .668 r
.68207 .25836 .68912 .28028 .70257 .27574 .69683 .27773 Metetra
.915 .521 .23 r
.69683 .27773 .70257 .27574 .72008 .33579 .71395 .33163 Metetra
.938 .567 .207 r
.71395 .33163 .72008 .33579 .74021 .42559 .73326 .41035 Metetra
.975 .699 .441 r
.73326 .41035 .74021 .42559 .74181 .24066 .73566 .23195 Metetra
.664 .741 .908 r
.73566 .23195 .74181 .24066 .75543 .23595 .74932 .2272 Metetra
.664 .741 .908 r
.74932 .2272 .75543 .23595 .7691 .23122 .76304 .22243 Metetra
.664 .741 .908 r
.76304 .22243 .7691 .23122 .78285 .22647 .77683 .21764 Metetra
.664 .741 .908 r
.77683 .21764 .78285 .22647 .79665 .2217 .79069 .21282 Metetra
.664 .741 .908 r
.79069 .21282 .79665 .2217 .81053 .2169 .80461 .20798 Metetra
.664 .741 .908 r
.80461 .20798 .81053 .2169 .82447 .21208 .8186 .20311 Metetra
.664 .741 .908 r
.19654 .4095 .2043 .41673 .21553 .41282 .2078 .40556 Metetra
.664 .741 .908 r
.2078 .40556 .21553 .41282 .22681 .4089 .21911 .40161 Metetra
.664 .741 .908 r
.21911 .40161 .22681 .4089 .23814 .40496 .23047 .39764 Metetra
.664 .741 .908 r
.23047 .39764 .23814 .40496 .24952 .401 .24188 .39365 Metetra
.664 .741 .908 r
.24188 .39365 .24952 .401 .26095 .39703 .25334 .38964 Metetra
.664 .741 .908 r
.25334 .38964 .26095 .39703 .27243 .39303 .26485 .38562 Metetra
.664 .741 .908 r
.26485 .38562 .27243 .39303 .2673 .6111 .2764 .38158 Metetra
0 0 .33 r
.2764 .38158 .2673 .6111 .28311 .55882 .27397 .56731 Metetra
.977 .771 .561 r
.27397 .56731 .28311 .55882 .30165 .46223 .29249 .47546 Metetra
.997 .846 .563 r
.29249 .47546 .30165 .46223 .31703 .40528 .30815 .41783 Metetra
.962 .918 .569 r
.30815 .41783 .31703 .40528 .3305 .37423 .32204 .38294 Metetra
.845 .959 .62 r
.32204 .38294 .3305 .37423 .34186 .37767 .33486 .36298 Metetra
.58 .566 .802 r
.33486 .36298 .34186 .37767 .35372 .37382 .34659 .3615 Metetra
.626 .625 .83 r
.34659 .3615 .35372 .37382 .3659 .3646 .35848 .35831 Metetra
.716 .794 .913 r
.35848 .35831 .3659 .3646 .37792 .35911 .37056 .35247 Metetra
.732 .788 .897 r
.37056 .35247 .37792 .35911 .38966 .36142 .38271 .34594 Metetra
.662 .599 .774 r
.38271 .34594 .38966 .36142 .40157 .36177 .39486 .34038 Metetra
.611 .52 .726 r
.39486 .34038 .40157 .36177 .41366 .35942 .40698 .33671 Metetra
.627 .521 .714 r
.40698 .33671 .41366 .35942 .42591 .3542 .41921 .3317 Metetra
.584 .497 .722 r
.41921 .3317 .42591 .3542 .43828 .34638 .43139 .32958 Metetra
.571 .538 .78 r
.43139 .32958 .43828 .34638 .45073 .33658 .44363 .32841 Metetra
.522 .68 .937 r
.44363 .32841 .45073 .33658 .46317 .32781 .45593 .3277 Metetra
.099 .655 .77 r
.45593 .3277 .46317 .32781 .47544 .33054 .46833 .3269 Metetra
.438 .796 .997 r
.46833 .3269 .47544 .33054 .48784 .33273 .48081 .32545 Metetra
.597 .741 .945 r
.48081 .32545 .48784 .33273 .50036 .33352 .49339 .32283 Metetra
.652 .676 .86 r
.49339 .32283 .50036 .33352 .51298 .33223 .50605 .31862 Metetra
.679 .637 .802 r
.50605 .31862 .51298 .33223 .52568 .3283 .51877 .31254 Metetra
.698 .62 .766 r
.51877 .31254 .52568 .3283 .53844 .32145 .53154 .30446 Metetra
.715 .616 .746 r
.53154 .30446 .53844 .32145 .55121 .31163 .54432 .29447 Metetra
.719 .617 .742 r
.54432 .29447 .55121 .31163 .56396 .29911 .55711 .28404 Metetra
.419 .48 .816 r
.55711 .28404 .56396 .29911 .57676 .29003 .57013 .2879 Metetra
.233 0 0 r
.57013 .2879 .57676 .29003 .58992 .29717 .58328 .29232 Metetra
.023 .501 .877 r
.58328 .29232 .58992 .29717 .60325 .30467 .59656 .29645 Metetra
.33 .587 .937 r
.59656 .29645 .60325 .30467 .61671 .31112 .60994 .29917 Metetra
.524 .597 .87 r
.60994 .29917 .61671 .31112 .63023 .31478 .62336 .29919 Metetra
.633 .596 .794 r
.62336 .29919 .63023 .31478 .64371 .31363 .63674 .29496 Metetra
.706 .602 .738 r
.63674 .29496 .64371 .31363 .65698 .30543 .64994 .28483 Metetra
.767 .619 .696 r
.64994 .28483 .65698 .30543 .66985 .28779 .66281 .267 Metetra
.798 .634 .678 r
.66281 .267 .66985 .28779 .68207 .25836 .67541 .24453 Metetra
0 0 .35 r
.67541 .24453 .68207 .25836 .69683 .27773 .69072 .2745 Metetra
.902 .49 .123 r
.69072 .2745 .69683 .27773 .71395 .33163 .70732 .32004 Metetra
.972 .723 .5 r
.70732 .32004 .71395 .33163 .73326 .41035 .71582 .22794 Metetra
.549 .342 .552 r
.71582 .22794 .73326 .41035 .73566 .23195 .72945 .22317 Metetra
.664 .741 .908 r
.72945 .22317 .73566 .23195 .74932 .2272 .74316 .21838 Metetra
.664 .741 .908 r
.74316 .21838 .74932 .2272 .76304 .22243 .75693 .21356 Metetra
.664 .741 .908 r
.75693 .21356 .76304 .22243 .77683 .21764 .77076 .20872 Metetra
.664 .741 .908 r
.77076 .20872 .77683 .21764 .79069 .21282 .78467 .20386 Metetra
.664 .741 .908 r
.78467 .20386 .79069 .21282 .80461 .20798 .79864 .19898 Metetra
.664 .741 .908 r
.79864 .19898 .80461 .20798 .8186 .20311 .81267 .19407 Metetra
.664 .741 .908 r
.18872 .40222 .19654 .4095 .2078 .40556 .20001 .39825 Metetra
.664 .741 .908 r
.20001 .39825 .2078 .40556 .21911 .40161 .21135 .39426 Metetra
.664 .741 .908 r
.21135 .39426 .21911 .40161 .23047 .39764 .22273 .39026 Metetra
.664 .741 .908 r
.22273 .39026 .23047 .39764 .24188 .39365 .23417 .38624 Metetra
.664 .741 .908 r
.23417 .38624 .24188 .39365 .25334 .38964 .24566 .3822 Metetra
.664 .741 .908 r
.24566 .3822 .25334 .38964 .26485 .38562 .2572 .37814 Metetra
.664 .741 .908 r
.2572 .37814 .26485 .38562 .2764 .38158 .26879 .37407 Metetra
.949 .668 .471 r
.26879 .37407 .2764 .38158 .27397 .56731 .26601 .55835 Metetra
.93 .713 .588 r
.26601 .55835 .27397 .56731 .29249 .47546 .28418 .47468 Metetra
.956 .77 .613 r
.28418 .47468 .29249 .47546 .30815 .41783 .29987 .41933 Metetra
.967 .833 .658 r
.29987 .41933 .30815 .41783 .32204 .38294 .31398 .38323 Metetra
.949 .88 .733 r
.31398 .38323 .32204 .38294 .33486 .36298 .3271 .36013 Metetra
.757 .905 .942 r
.3271 .36013 .33486 .36298 .34659 .3615 .33921 .3529 Metetra
.446 .63 .932 r
.33921 .3529 .34659 .3615 .35848 .35831 .3509 .35374 Metetra
.547 .806 .994 r
.3509 .35374 .35848 .35831 .37056 .35247 .36285 .35143 Metetra
.515 .895 .961 r
.36285 .35143 .37056 .35247 .38271 .34594 .37494 .34754 Metetra
.358 .829 .793 r
.37494 .34754 .38271 .34594 .39486 .34038 .38711 .34311 Metetra
.242 .742 .671 r
.38711 .34311 .39486 .34038 .40698 .33671 .39933 .33874 Metetra
.267 .767 .725 r
.39933 .33874 .40698 .33671 .41921 .3317 .41159 .3347 Metetra
.41159 .3347 .41921 .3317 .43139 .32958 .4239 .33104 Metetra
.247 .758 .749 r
.4239 .33104 .43139 .32958 .44363 .32841 .43626 .32761 Metetra
.437 .865 .934 r
.43626 .32761 .44363 .32841 .45593 .3277 .44869 .32419 Metetra
.591 .864 .994 r
.44869 .32419 .45593 .3277 .46833 .3269 .46118 .32048 Metetra
.657 .789 .945 r
.46118 .32048 .46833 .3269 .48081 .32545 .47375 .3162 Metetra
.68 .719 .879 r
.47375 .3162 .48081 .32545 .49339 .32283 .48639 .31109 Metetra
.69 .672 .828 r
.48639 .31109 .49339 .32283 .50605 .31862 .49909 .30496 Metetra
.698 .646 .794 r
.49909 .30496 .50605 .31862 .51877 .31254 .51184 .2977 Metetra
.708 .636 .774 r
.51184 .2977 .51877 .31254 .53154 .30446 .52462 .2893 Metetra
.72 .638 .766 r
.52462 .2893 .53154 .30446 .54432 .29447 .53743 .27987 Metetra
.515 .542 .822 r
.53743 .27987 .54432 .29447 .55711 .28404 .55034 .28056 Metetra
.137 .626 .915 r
.55034 .28056 .55711 .28404 .57013 .2879 .56336 .2822 Metetra
.29 .65 .969 r
.56336 .2822 .57013 .2879 .58328 .29232 .5765 .28382 Metetra
.435 .637 .941 r
.5765 .28382 .58328 .29232 .59656 .29645 .58974 .28479 Metetra
.535 .61 .874 r
.58974 .28479 .59656 .29645 .60994 .29917 .60306 .28435 Metetra
.603 .591 .811 r
.60306 .28435 .60994 .29917 .62336 .29919 .6164 .2816 Metetra
.657 .587 .764 r
.6164 .2816 .62336 .29919 .63674 .29496 .62972 .27549 Metetra
.708 .597 .73 r
.62972 .27549 .63674 .29496 .64994 .28483 .64291 .26484 Metetra
.761 .62 .704 r
.64291 .26484 .64994 .28483 .66281 .267 .65586 .24836 Metetra
.654 .575 .754 r
.65586 .24836 .66281 .267 .67541 .24453 .66926 .24217 Metetra
.808 .323 0 r
.66926 .24217 .67541 .24453 .69072 .2745 .68425 .26578 Metetra
.814 .39 0 r
.68425 .26578 .69072 .2745 .70732 .32004 .70024 .30133 Metetra
.947 .699 .53 r
.70024 .30133 .70732 .32004 .71582 .22794 .70951 .21912 Metetra
.664 .741 .908 r
.70951 .21912 .71582 .22794 .72945 .22317 .72319 .2143 Metetra
.664 .741 .908 r
.72319 .2143 .72945 .22317 .74316 .21838 .73694 .20947 Metetra
.664 .741 .908 r
.73694 .20947 .74316 .21838 .75693 .21356 .75076 .20461 Metetra
.664 .741 .908 r
.75076 .20461 .75693 .21356 .77076 .20872 .76464 .19973 Metetra
.664 .741 .908 r
.76464 .19973 .77076 .20872 .78467 .20386 .77859 .19483 Metetra
.664 .741 .908 r
.77859 .19483 .78467 .20386 .79864 .19898 .79261 .1899 Metetra
.664 .741 .908 r
.79261 .1899 .79864 .19898 .81267 .19407 .80669 .18495 Metetra
.664 .741 .908 r
.18084 .39488 .18872 .40222 .20001 .39825 .19215 .39088 Metetra
.664 .741 .908 r
.19215 .39088 .20001 .39825 .21135 .39426 .20352 .38686 Metetra
.664 .741 .908 r
.20352 .38686 .21135 .39426 .22273 .39026 .21494 .38282 Metetra
.664 .741 .908 r
.21494 .38282 .22273 .39026 .23417 .38624 .2264 .37877 Metetra
.664 .741 .908 r
.2264 .37877 .23417 .38624 .24566 .3822 .23792 .3747 Metetra
.664 .741 .908 r
.23792 .3747 .24566 .3822 .2572 .37814 .24949 .37061 Metetra
.664 .741 .908 r
.24949 .37061 .2572 .37814 .26879 .37407 .26111 .3665 Metetra
.664 .741 .908 r
.26111 .3665 .26879 .37407 .26601 .55835 .27278 .36237 Metetra
.2 .062 .458 r
.27278 .36237 .26601 .55835 .28418 .47468 .27678 .46052 Metetra
.893 .694 .627 r
.27678 .46052 .28418 .47468 .29987 .41933 .29225 .41018 Metetra
.899 .731 .665 r
.29225 .41018 .29987 .41933 .31398 .38323 .30637 .37546 Metetra
.885 .756 .715 r
.30637 .37546 .31398 .38323 .3271 .36013 .31961 .35163 Metetra
.656 .719 .895 r
.31961 .35163 .3271 .36013 .33921 .3529 .33156 .34761 Metetra
.12 .56 .919 r
.33156 .34761 .33921 .3529 .3509 .35374 .34317 .35046 Metetra
.336 .754 .977 r
.34317 .35046 .3509 .35374 .36285 .35143 .35506 .34995 Metetra
.427 .847 .959 r
.35506 .34995 .36285 .35143 .37494 .34754 .36714 .3473 Metetra
.459 .881 .921 r
.36714 .3473 .37494 .34754 .38711 .34311 .37935 .34336 Metetra
.486 .898 .904 r
.37935 .34336 .38711 .34311 .39933 .33874 .39165 .33871 Metetra
.535 .919 .923 r
.39165 .33871 .39933 .33874 .41159 .3347 .40401 .33366 Metetra
.604 .931 .961 r
.40401 .33366 .41159 .3347 .4239 .33104 .41644 .32839 Metetra
.666 .91 .978 r
.41644 .32839 .4239 .33104 .43626 .32761 .42891 .32295 Metetra
.7 .855 .957 r
.42891 .32295 .43626 .32761 .44869 .32419 .44145 .31732 Metetra
.709 .789 .914 r
.44145 .31732 .44869 .32419 .46118 .32048 .45403 .31142 Metetra
.707 .733 .871 r
.45403 .31142 .46118 .32048 .47375 .3162 .46667 .3052 Metetra
.704 .691 .835 r
.46667 .3052 .47375 .3162 .48639 .31109 .47935 .29857 Metetra
.702 .665 .811 r
.47935 .29857 .48639 .31109 .49909 .30496 .49209 .29151 Metetra
.703 .653 .796 r
.49209 .29151 .49909 .30496 .51184 .2977 .50486 .28402 Metetra
.708 .652 .791 r
.50486 .28402 .51184 .2977 .52462 .2893 .51767 .27612 Metetra
.574 .597 .839 r
.51767 .27612 .52462 .2893 .53743 .27987 .53052 .2746 Metetra
.442 .748 .993 r
.53052 .2746 .53743 .27987 .55034 .28056 .54346 .27387 Metetra
.488 .722 .975 r
.54346 .27387 .55034 .28056 .56336 .2822 .5565 .27308 Metetra
.541 .673 .924 r
.5565 .27308 .56336 .2822 .5765 .28382 .56962 .27197 Metetra
.578 .628 .865 r
.56962 .27197 .5765 .28382 .58974 .28479 .58283 .27017 Metetra
.606 .595 .814 r
.58283 .27017 .58974 .28479 .60306 .28435 .59609 .26728 Metetra
.632 .579 .776 r
.59609 .26728 .60306 .28435 .6164 .2816 .60939 .26276 Metetra
.661 .577 .75 r
.60939 .26276 .6164 .2816 .62972 .27549 .62269 .25597 Metetra
.698 .591 .733 r
.62269 .25597 .62972 .27549 .64291 .26484 .63592 .24616 Metetra
.746 .623 .723 r
.63592 .24616 .64291 .26484 .65586 .24836 .64901 .23242 Metetra
.446 .489 .81 r
.64901 .23242 .65586 .24836 .66926 .24217 .66285 .23568 Metetra
.551 .053 0 r
.66285 .23568 .66926 .24217 .68425 .26578 .67746 .25166 Metetra
.911 .723 .636 r
.67746 .25166 .68425 .26578 .70024 .30133 .68948 .21505 Metetra
.56 .37 .581 r
.68948 .21505 .70024 .30133 .70951 .21912 .70315 .21022 Metetra
.664 .741 .908 r
.70315 .21022 .70951 .21912 .72319 .2143 .71687 .20536 Metetra
.664 .741 .908 r
.71687 .20536 .72319 .2143 .73694 .20947 .73067 .20048 Metetra
.664 .741 .908 r
.73067 .20048 .73694 .20947 .75076 .20461 .74453 .19558 Metetra
.664 .741 .908 r
.74453 .19558 .75076 .20461 .76464 .19973 .75846 .19066 Metetra
.664 .741 .908 r
.75846 .19066 .76464 .19973 .77859 .19483 .77246 .18571 Metetra
.664 .741 .908 r
.77246 .18571 .77859 .19483 .79261 .1899 .78653 .18074 Metetra
.664 .741 .908 r
.78653 .18074 .79261 .1899 .80669 .18495 .80066 .17574 Metetra
.664 .741 .908 r
.17289 .38748 .18084 .39488 .19215 .39088 .18423 .38345 Metetra
.664 .741 .908 r
.18423 .38345 .19215 .39088 .20352 .38686 .19563 .37939 Metetra
.664 .741 .908 r
.19563 .37939 .20352 .38686 .21494 .38282 .20708 .37532 Metetra
.664 .741 .908 r
.20708 .37532 .21494 .38282 .2264 .37877 .21857 .37124 Metetra
.664 .741 .908 r
.21857 .37124 .2264 .37877 .23792 .3747 .23012 .36713 Metetra
.664 .741 .908 r
.23012 .36713 .23792 .3747 .24949 .37061 .24172 .36301 Metetra
.664 .741 .908 r
.24172 .36301 .24949 .37061 .26111 .3665 .25337 .35886 Metetra
.664 .741 .908 r
.25337 .35886 .26111 .3665 .27278 .36237 .26507 .3547 Metetra
.951 .641 .409 r
.26507 .3547 .27278 .36237 .27678 .46052 .2702 .43527 Metetra
.834 .632 .63 r
.2702 .43527 .27678 .46052 .29225 .41018 .28524 .39194 Metetra
.836 .657 .661 r
.28524 .39194 .29225 .41018 .30637 .37546 .29918 .36073 Metetra
.825 .675 .697 r
.29918 .36073 .30637 .37546 .31961 .35163 .31238 .33833 Metetra
.206 .381 .817 r
.31238 .33833 .31961 .35163 .33156 .34761 .32366 .34501 Metetra
0 .446 .739 r
.32366 .34501 .33156 .34761 .34317 .35046 .33529 .34802 Metetra
.254 .73 .937 r
.33529 .34802 .34317 .35046 .35506 .34995 .34722 .34768 Metetra
.48 .854 .986 r
.34722 .34768 .35506 .34995 .36714 .3473 .35936 .34493 Metetra
.607 .899 .987 r
.35936 .34493 .36714 .3473 .37935 .34336 .37164 .3405 Metetra
.681 .905 .975 r
.37164 .3405 .37935 .34336 .39165 .33871 .38403 .33491 Metetra
.722 .884 .955 r
.38403 .33491 .39165 .33871 .40401 .33366 .3965 .32856 Metetra
.74 .846 .929 r
.3965 .32856 .40401 .33366 .41644 .32839 .40903 .32172 Metetra
.742 .801 .899 r
.40903 .32172 .41644 .32839 .42891 .32295 .42161 .31459 Metetra
.735 .756 .87 r
.42161 .31459 .42891 .32295 .44145 .31732 .43422 .30732 Metetra
.724 .718 .844 r
.43422 .30732 .44145 .31732 .45403 .31142 .44688 .30001 Metetra
.713 .688 .824 r
.44688 .30001 .45403 .31142 .46667 .3052 .45956 .29274 Metetra
.705 .668 .811 r
.45956 .29274 .46667 .3052 .47935 .29857 .47228 .28556 Metetra
.698 .657 .806 r
.47228 .28556 .47935 .29857 .49209 .29151 .48504 .27852 Metetra
.684 .652 .812 r
.48504 .27852 .49209 .29151 .50486 .28402 .49783 .27225 Metetra
.598 .636 .86 r
.49783 .27225 .50486 .28402 .51767 .27612 .51065 .26982 Metetra
.58 .775 .972 r
.51065 .26982 .51767 .27612 .53052 .2746 .52354 .26712 Metetra
.603 .747 .946 r
.52354 .26712 .53052 .2746 .54346 .27387 .53651 .26416 Metetra
.621 .694 .896 r
.53651 .26416 .54346 .27387 .5565 .27308 .54955 .2609 Metetra
.628 .645 .848 r
.54955 .2609 .5565 .27308 .56962 .27197 .56266 .2573 Metetra
.63 .607 .808 r
.56266 .2573 .56962 .27197 .58283 .27017 .57584 .25329 Metetra
.633 .581 .778 r
.57584 .25329 .58283 .27017 .59609 .26728 .58908 .24876 Metetra
.639 .568 .759 r
.58908 .24876 .59609 .26728 .60939 .26276 .60236 .2435 Metetra
.652 .569 .749 r
.60236 .2435 .60939 .26276 .62269 .25597 .61567 .23722 Metetra
.675 .586 .748 r
.61567 .23722 .62269 .25597 .63592 .24616 .62898 .22946 Metetra
.688 .613 .767 r
.62898 .22946 .63592 .24616 .64901 .23242 .64233 .2216 Metetra
.364 .54 .895 r
.64233 .2216 .64901 .23242 .66285 .23568 .65619 .22497 Metetra
.131 .397 .848 r
.65619 .22497 .66285 .23568 .67746 .25166 .67041 .23272 Metetra
.838 .666 .669 r
.67041 .23272 .67746 .25166 .68948 .21505 .68302 .20611 Metetra
.664 .741 .908 r
.68302 .20611 .68948 .21505 .70315 .21022 .69673 .20124 Metetra
.664 .741 .908 r
.69673 .20124 .70315 .21022 .71687 .20536 .7105 .19634 Metetra
.664 .741 .908 r
.7105 .19634 .71687 .20536 .73067 .20048 .72434 .19142 Metetra
.664 .741 .908 r
.72434 .19142 .73067 .20048 .74453 .19558 .73825 .18647 Metetra
.664 .741 .908 r
.73825 .18647 .74453 .19558 .75846 .19066 .75223 .1815 Metetra
.664 .741 .908 r
.75223 .1815 .75846 .19066 .77246 .18571 .76628 .17651 Metetra
.664 .741 .908 r
.76628 .17651 .77246 .18571 .78653 .18074 .78039 .17149 Metetra
.664 .741 .908 r
.78039 .17149 .78653 .18074 .80066 .17574 .79457 .16645 Metetra
.664 .741 .908 r
.16488 .38002 .17289 .38748 .18423 .38345 .17625 .37595 Metetra
.664 .741 .908 r
.17625 .37595 .18423 .38345 .19563 .37939 .18767 .37187 Metetra
.664 .741 .908 r
.18767 .37187 .19563 .37939 .20708 .37532 .19915 .36776 Metetra
.664 .741 .908 r
.19915 .36776 .20708 .37532 .21857 .37124 .21068 .36364 Metetra
.664 .741 .908 r
.21068 .36364 .21857 .37124 .23012 .36713 .22225 .3595 Metetra
.664 .741 .908 r
.22225 .3595 .23012 .36713 .24172 .36301 .23388 .35535 Metetra
.664 .741 .908 r
.23388 .35535 .24172 .36301 .25337 .35886 .24557 .35117 Metetra
.664 .741 .908 r
.24557 .35117 .25337 .35886 .26507 .3547 .2573 .34697 Metetra
.664 .741 .908 r
.2573 .34697 .26507 .3547 .2702 .43527 .26909 .34276 Metetra
.388 .23 .543 r
.26909 .34276 .2702 .43527 .28524 .39194 .2787 .36737 Metetra
.785 .606 .657 r
.2787 .36737 .28524 .39194 .29918 .36073 .29233 .34099 Metetra
.592 .522 .745 r
.29233 .34099 .29918 .36073 .31238 .33833 .30418 .33849 Metetra
.525 0 0 r
.30418 .33849 .31238 .33833 .32366 .34501 .31555 .34422 Metetra
.124 0 0 r
.31555 .34422 .32366 .34501 .33529 .34802 .3273 .34584 Metetra
.362 .799 .963 r
.3273 .34584 .33529 .34802 .34722 .34768 .33935 .34429 Metetra
.608 .87 .991 r
.33935 .34429 .34722 .34768 .35936 .34493 .3516 .3403 Metetra
.706 .854 .953 r
.3516 .3403 .35936 .34493 .37164 .3405 .364 .33453 Metetra
.743 .819 .911 r
.364 .33453 .37164 .3405 .38403 .33491 .3765 .32749 Metetra
.753 .782 .876 r
.3765 .32749 .38403 .33491 .3965 .32856 .38908 .31964 Metetra
.751 .746 .848 r
.38908 .31964 .3965 .32856 .40903 .32172 .4017 .31134 Metetra
.741 .715 .827 r
.4017 .31134 .40903 .32172 .42161 .31459 .41436 .30291 Metetra
.729 .689 .812 r
.41436 .30291 .42161 .31459 .43422 .30732 .42703 .29461 Metetra
.716 .668 .802 r
.42703 .29461 .43422 .30732 .44688 .30001 .43973 .28665 Metetra
.703 .654 .798 r
.43973 .28665 .44688 .30001 .45956 .29274 .45244 .27919 Metetra
.681 .642 .805 r
.45244 .27919 .45956 .29274 .47228 .28556 .46517 .27296 Metetra
.611 .627 .842 r
.46517 .27296 .47228 .28556 .48504 .27852 .47789 .27002 Metetra
.634 .728 .916 r
.47789 .27002 .48504 .27852 .49783 .27225 .49069 .26638 Metetra
.647 .813 .963 r
.49069 .26638 .49783 .27225 .51065 .26982 .50356 .26205 Metetra
.673 .764 .919 r
.50356 .26205 .51065 .26982 .52354 .26712 .5165 .25716 Metetra
.678 .711 .873 r
.5165 .25716 .52354 .26712 .53651 .26416 .5295 .25182 Metetra
.673 .663 .832 r
.5295 .25182 .53651 .26416 .54955 .2609 .54255 .24623 Metetra
.663 .623 .799 r
.54255 .24623 .54955 .2609 .56266 .2573 .55565 .24056 Metetra
.63 .581 .781 r
.55565 .24056 .56266 .2573 .57584 .25329 .56883 .23617 Metetra
.625 .575 .778 r
.56883 .23617 .57584 .25329 .58908 .24876 .58208 .23199 Metetra
.632 .583 .781 r
.58208 .23199 .58908 .24876 .60236 .2435 .59538 .22745 Metetra
.64 .596 .789 r
.59538 .22745 .60236 .2435 .61567 .23722 .60875 .2226 Metetra
.647 .619 .808 r
.60875 .2226 .61567 .23722 .62898 .22946 .62218 .2177 Metetra
.646 .667 .856 r
.62218 .2177 .62898 .22946 .64233 .2216 .63569 .21329 Metetra
.602 .732 .936 r
.63569 .21329 .64233 .2216 .65619 .22497 .64932 .21026 Metetra
.706 .648 .79 r
.64932 .21026 .65619 .22497 .67041 .23272 .66281 .20199 Metetra
.6 .473 .679 r
.66281 .20199 .67041 .23272 .68302 .20611 .67649 .19709 Metetra
.664 .741 .908 r
.67649 .19709 .68302 .20611 .69673 .20124 .69025 .19218 Metetra
.664 .741 .908 r
.69025 .19218 .69673 .20124 .7105 .19634 .70407 .18723 Metetra
.664 .741 .908 r
.70407 .18723 .7105 .19634 .72434 .19142 .71796 .18227 Metetra
.664 .741 .908 r
.71796 .18227 .72434 .19142 .73825 .18647 .73191 .17728 Metetra
.664 .741 .908 r
.73191 .17728 .73825 .18647 .75223 .1815 .74594 .17226 Metetra
.664 .741 .908 r
.74594 .17226 .75223 .1815 .76628 .17651 .76003 .16722 Metetra
.664 .741 .908 r
.76003 .16722 .76628 .17651 .78039 .17149 .7742 .16216 Metetra
.664 .741 .908 r
.7742 .16216 .78039 .17149 .79457 .16645 .78843 .15707 Metetra
.664 .741 .908 r
.1568 .3725 .16488 .38002 .17625 .37595 .1682 .3684 Metetra
.664 .741 .908 r
.1682 .3684 .17625 .37595 .18767 .37187 .17965 .36428 Metetra
.664 .741 .908 r
.17965 .36428 .18767 .37187 .19915 .36776 .19116 .36014 Metetra
.664 .741 .908 r
.19116 .36014 .19915 .36776 .21068 .36364 .20271 .35599 Metetra
.664 .741 .908 r
.20271 .35599 .21068 .36364 .22225 .3595 .21432 .35181 Metetra
.664 .741 .908 r
.21432 .35181 .22225 .3595 .23388 .35535 .22598 .34762 Metetra
.664 .741 .908 r
.22598 .34762 .23388 .35535 .24557 .35117 .2377 .34341 Metetra
.664 .741 .908 r
.2377 .34341 .24557 .35117 .2573 .34697 .24946 .33918 Metetra
.664 .741 .908 r
.24946 .33918 .2573 .34697 .26909 .34276 .26128 .33493 Metetra
0 .396 .848 r
.26128 .33493 .26909 .34276 .2787 .36737 .27237 .34041 Metetra
.633 .503 .687 r
.27237 .34041 .2787 .36737 .29233 .34099 .28452 .33375 Metetra
0 .242 .72 r
.28452 .33375 .29233 .34099 .30418 .33849 .29568 .34114 Metetra
.419 0 0 r
.29568 .34114 .30418 .33849 .31555 .34422 .30729 .34402 Metetra
.114 .666 .785 r
.30729 .34402 .31555 .34422 .3273 .34584 .31925 .34321 Metetra
.571 .881 .992 r
.31925 .34321 .3273 .34584 .33935 .34429 .33147 .33944 Metetra
.716 .849 .945 r
.33147 .33944 .33935 .34429 .3516 .3403 .34388 .33338 Metetra
.754 .794 .886 r
.34388 .33338 .3516 .3403 .364 .33453 .35643 .32565 Metetra
.76 .749 .843 r
.35643 .32565 .364 .33453 .3765 .32749 .36906 .31682 Metetra
.754 .713 .813 r
.36906 .31682 .3765 .32749 .38908 .31964 .38174 .30739 Metetra
.744 .685 .794 r
.38174 .30739 .38908 .31964 .4017 .31134 .39445 .29782 Metetra
.73 .662 .783 r
.39445 .29782 .4017 .31134 .41436 .30291 .40716 .28851 Metetra
.716 .645 .778 r
.40716 .28851 .41436 .30291 .42703 .29461 .41987 .27977 Metetra
.65 .61 .796 r
.41987 .27977 .42703 .29461 .43973 .28665 .43249 .27483 Metetra
.59 .632 .861 r
.43249 .27483 .43973 .28665 .45244 .27919 .4451 .27261 Metetra
.615 .778 .959 r
.4451 .27261 .45244 .27919 .46517 .27296 .45781 .26922 Metetra
.63 .876 .987 r
.45781 .26922 .46517 .27296 .47789 .27002 .47062 .26466 Metetra
.695 .842 .953 r
.47062 .26466 .47789 .27002 .49069 .26638 .48349 .25898 Metetra
.722 .789 .905 r
.48349 .25898 .49069 .26638 .50356 .26205 .49643 .25237 Metetra
.697 .725 .872 r
.49643 .25237 .50356 .26205 .5165 .25716 .50941 .24633 Metetra
.57 .648 .888 r
.50941 .24633 .5165 .25716 .5295 .25182 .52243 .24461 Metetra
.543 .736 .965 r
.52243 .24461 .5295 .25182 .54255 .24623 .53555 .24282 Metetra
.46 .825 .994 r
.53555 .24282 .54255 .24623 .55565 .24056 .54874 .24056 Metetra
.305 .799 .846 r
.54874 .24056 .55565 .24056 .56883 .23617 .56202 .2374 Metetra
.311 .799 .772 r
.56202 .2374 .56883 .23617 .58208 .23199 .57534 .23299 Metetra
.451 .882 .825 r
.57534 .23299 .58208 .23199 .59538 .22745 .58871 .22709 Metetra
.64 .962 .911 r
.58871 .22709 .59538 .22745 .60875 .2226 .60209 .21965 Metetra
.769 .944 .937 r
.60209 .21965 .60875 .2226 .62218 .2177 .61548 .21088 Metetra
.722 .82 .926 r
.61548 .21088 .62218 .2177 .63569 .21329 .62896 .20411 Metetra
.508 .666 .933 r
.62896 .20411 .63569 .21329 .64932 .21026 .64273 .20355 Metetra
.809 .844 .876 r
.64273 .20355 .64932 .21026 .66281 .20199 .65618 .19293 Metetra
.664 .741 .908 r
.65618 .19293 .66281 .20199 .67649 .19709 .66991 .188 Metetra
.664 .741 .908 r
.66991 .188 .67649 .19709 .69025 .19218 .68371 .18303 Metetra
.664 .741 .908 r
.68371 .18303 .69025 .19218 .70407 .18723 .69758 .17805 Metetra
.664 .741 .908 r
.69758 .17805 .70407 .18723 .71796 .18227 .71151 .17304 Metetra
.664 .741 .908 r
.71151 .17304 .71796 .18227 .73191 .17728 .72552 .168 Metetra
.664 .741 .908 r
.72552 .168 .73191 .17728 .74594 .17226 .73959 .16294 Metetra
.664 .741 .908 r
.73959 .16294 .74594 .17226 .76003 .16722 .75373 .15786 Metetra
.664 .741 .908 r
.75373 .15786 .76003 .16722 .7742 .16216 .76795 .15274 Metetra
.664 .741 .908 r
.76795 .15274 .7742 .16216 .78843 .15707 .78223 .14761 Metetra
.664 .741 .908 r
.14865 .36491 .1568 .3725 .1682 .3684 .16008 .36078 Metetra
.664 .741 .908 r
.16008 .36078 .1682 .3684 .17965 .36428 .17157 .35663 Metetra
.664 .741 .908 r
.17157 .35663 .17965 .36428 .19116 .36014 .1831 .35246 Metetra
.664 .741 .908 r
.1831 .35246 .19116 .36014 .20271 .35599 .19469 .34827 Metetra
.664 .741 .908 r
.19469 .34827 .20271 .35599 .21432 .35181 .20633 .34406 Metetra
.664 .741 .908 r
.20633 .34406 .21432 .35181 .22598 .34762 .21802 .33983 Metetra
.664 .741 .908 r
.21802 .33983 .22598 .34762 .2377 .34341 .22976 .33558 Metetra
.664 .741 .908 r
.22976 .33558 .2377 .34341 .24946 .33918 .24156 .33132 Metetra
.664 .741 .908 r
.24156 .33132 .24946 .33918 .26128 .33493 .25341 .32703 Metetra
.664 .741 .908 r
.25341 .32703 .26128 .33493 .27237 .34041 .26531 .32273 Metetra
0 .011 .584 r
.26531 .32273 .27237 .34041 .28452 .33375 .27568 .33855 Metetra
.526 .011 0 r
.27568 .33855 .28452 .33375 .29568 .34114 .28712 .3428 Metetra
.123 0 0 r
.28712 .3428 .29568 .34114 .30729 .34402 .29899 .34276 Metetra
.494 .882 .964 r
.29899 .34276 .30729 .34402 .31925 .34321 .31119 .33916 Metetra
.726 .875 .951 r
.31119 .33916 .31925 .34321 .33147 .33944 .32362 .33273 Metetra
.772 .802 .878 r
.32362 .33273 .33147 .33944 .34388 .33338 .33623 .32419 Metetra
.775 .745 .826 r
.33623 .32419 .34388 .33338 .35643 .32565 .34894 .31422 Metetra
.766 .704 .793 r
.34894 .31422 .35643 .32565 .36906 .31682 .3617 .30347 Metetra
.752 .673 .773 r
.3617 .30347 .36906 .31682 .38174 .30739 .37448 .29254 Metetra
.737 .649 .762 r
.37448 .29254 .38174 .30739 .39445 .29782 .38725 .28196 Metetra
.665 .605 .778 r
.38725 .28196 .39445 .29782 .40716 .28851 .39985 .27593 Metetra
.533 .59 .858 r
.39985 .27593 .40716 .28851 .41987 .27977 .41229 .27549 Metetra
.482 .803 1 r
.41229 .27549 .41987 .27977 .43249 .27483 .42487 .27361 Metetra
.455 .869 .949 r
.42487 .27361 .43249 .27483 .4451 .27261 .43757 .27011 Metetra
.629 .912 .982 r
.43757 .27011 .4451 .27261 .45781 .26922 .45038 .26495 Metetra
.726 .883 .953 r
.45038 .26495 .45781 .26922 .47062 .26466 .46328 .25823 Metetra
.762 .824 .901 r
.46328 .25823 .47062 .26466 .48349 .25898 .47625 .25017 Metetra
.74 .759 .868 r
.47625 .25017 .48349 .25898 .49643 .25237 .48924 .2424 Metetra
.483 .628 .916 r
.48924 .2424 .49643 .25237 .50941 .24633 .50221 .24265 Metetra
.264 .708 .96 r
.50221 .24265 .50941 .24633 .52243 .24461 .51529 .24291 Metetra
.171 .693 .876 r
.51529 .24291 .52243 .24461 .53555 .24282 .52847 .2426 Metetra
.165 .703 .803 r
.52847 .2426 .53555 .24282 .54874 .24056 .54174 .2411 Metetra
.268 .775 .801 r
.54174 .2411 .54874 .24056 .56202 .2374 .55509 .23782 Metetra
.47 .893 .864 r
.55509 .23782 .56202 .2374 .57534 .23299 .56849 .23227 Metetra
.692 .973 .92 r
.56849 .23227 .57534 .23299 .58871 .22709 .58189 .22415 Metetra
.822 .944 .904 r
.58189 .22415 .58871 .22709 .60209 .21965 .59527 .21341 Metetra
.849 .853 .845 r
.59527 .21341 .60209 .21965 .61548 .21088 .60861 .20042 Metetra
.456 .607 .911 r
.60861 .20042 .61548 .21088 .62896 .20411 .62238 .20139 Metetra
.859 .952 .872 r
.62238 .20139 .62896 .20411 .64273 .20355 .63578 .18876 Metetra
.645 .621 .811 r
.63578 .18876 .64273 .20355 .65618 .19293 .64949 .1838 Metetra
.664 .741 .908 r
.64949 .1838 .65618 .19293 .66991 .188 .66327 .17882 Metetra
.664 .741 .908 r
.66327 .17882 .66991 .188 .68371 .18303 .67711 .17381 Metetra
.664 .741 .908 r
.67711 .17381 .68371 .18303 .69758 .17805 .69103 .16878 Metetra
.664 .741 .908 r
.69103 .16878 .69758 .17805 .71151 .17304 .70501 .16372 Metetra
.664 .741 .908 r
.70501 .16372 .71151 .17304 .72552 .168 .71906 .15864 Metetra
.664 .741 .908 r
.71906 .15864 .72552 .168 .73959 .16294 .73319 .15353 Metetra
.664 .741 .908 r
.73319 .15353 .73959 .16294 .75373 .15786 .74738 .1484 Metetra
.664 .741 .908 r
.74738 .1484 .75373 .15786 .76795 .15274 .76164 .14324 Metetra
.664 .741 .908 r
.76164 .14324 .76795 .15274 .78223 .14761 .77598 .13806 Metetra
.664 .741 .908 r
.14044 .35727 .14865 .36491 .16008 .36078 .1519 .3531 Metetra
.664 .741 .908 r
.1519 .3531 .16008 .36078 .17157 .35663 .16341 .34891 Metetra
.664 .741 .908 r
.16341 .34891 .17157 .35663 .1831 .35246 .17498 .34471 Metetra
.664 .741 .908 r
.17498 .34471 .1831 .35246 .19469 .34827 .18659 .34048 Metetra
.664 .741 .908 r
.18659 .34048 .19469 .34827 .20633 .34406 .19826 .33624 Metetra
.664 .741 .908 r
.19826 .33624 .20633 .34406 .21802 .33983 .20998 .33197 Metetra
.664 .741 .908 r
.20998 .33197 .21802 .33983 .22976 .33558 .22176 .32769 Metetra
.664 .741 .908 r
.22176 .32769 .22976 .33558 .24156 .33132 .23358 .32339 Metetra
.664 .741 .908 r
.23358 .32339 .24156 .33132 .25341 .32703 .24547 .31907 Metetra
.664 .741 .908 r
.24547 .31907 .25341 .32703 .26531 .32273 .2574 .31473 Metetra
.867 .427 .035 r
.2574 .31473 .26531 .32273 .27568 .33855 .26722 .33704 Metetra
.228 0 0 r
.26722 .33704 .27568 .33855 .28712 .3428 .27879 .34005 Metetra
.419 .815 .984 r
.27879 .34005 .28712 .3428 .29899 .34276 .29083 .33821 Metetra
.704 .857 .955 r
.29083 .33821 .29899 .34276 .31119 .33916 .30322 .33243 Metetra
.776 .802 .874 r
.30322 .33243 .31119 .33916 .32362 .33273 .31586 .32364 Metetra
.788 .75 .818 r
.31586 .32364 .32362 .33273 .33623 .32419 .32865 .31276 Metetra
.782 .709 .783 r
.32865 .31276 .33623 .32419 .34894 .31422 .34152 .30066 Metetra
.768 .676 .761 r
.34152 .30066 .34894 .31422 .3617 .30347 .35441 .28816 Metetra
.752 .65 .749 r
.35441 .28816 .3617 .30347 .37448 .29254 .36728 .27596 Metetra
.536 .529 .795 r
.36728 .27596 .37448 .29254 .38725 .28196 .37958 .27574 Metetra
.353 .676 .977 r
.37958 .27574 .38725 .28196 .39985 .27593 .39193 .27652 Metetra
.063 .627 .711 r
.39193 .27652 .39985 .27593 .41229 .27549 .40445 .27549 Metetra
.329 .812 .865 r
.40445 .27549 .41229 .27549 .42487 .27361 .41714 .2724 Metetra
.586 .925 .96 r
.41714 .2724 .42487 .27361 .43757 .27011 .42996 .26716 Metetra
.736 .923 .954 r
.42996 .26716 .43757 .27011 .45038 .26495 .44289 .25984 Metetra
.791 .865 .904 r
.44289 .25984 .45038 .26495 .46328 .25823 .4559 .25069 Metetra
.8 .801 .852 r
.4559 .25069 .46328 .25823 .47625 .25017 .46897 .24012 Metetra
.599 .682 .9 r
.46897 .24012 .47625 .25017 .48924 .2424 .48193 .23743 Metetra
.16 .604 .935 r
.48193 .23743 .48924 .2424 .50221 .24265 .49492 .23969 Metetra
.06 .591 .864 r
.49492 .23969 .50221 .24265 .51529 .24291 .50804 .24147 Metetra
.067 .621 .816 r
.50804 .24147 .51529 .24291 .52847 .2426 .52128 .24197 Metetra
.202 .727 .84 r
.52128 .24197 .52847 .2426 .54174 .2411 .53463 .24043 Metetra
.45 .877 .916 r
.53463 .24043 .54174 .2411 .55509 .23782 .54804 .23614 Metetra
.699 .958 .947 r
.54804 .23614 .55509 .23782 .56849 .23227 .56149 .22858 Metetra
.83 .923 .896 r
.56149 .22858 .56849 .23227 .58189 .22415 .57492 .21752 Metetra
.862 .842 .824 r
.57492 .21752 .58189 .22415 .59527 .21341 .5883 .20314 Metetra
.771 .749 .833 r
.5883 .20314 .59527 .21341 .60861 .20042 .60176 .19292 Metetra
0 .299 .777 r
.60176 .19292 .60861 .20042 .62238 .20139 .6158 .20152 Metetra
.952 .95 .72 r
.6158 .20152 .62238 .20139 .63578 .18876 .62898 .17958 Metetra
.664 .741 .908 r
.62898 .17958 .63578 .18876 .64949 .1838 .64274 .17458 Metetra
.664 .741 .908 r
.64274 .17458 .64949 .1838 .66327 .17882 .65657 .16955 Metetra
.664 .741 .908 r
.65657 .16955 .66327 .17882 .67711 .17381 .67046 .1645 Metetra
.664 .741 .908 r
.67046 .1645 .67711 .17381 .69103 .16878 .68442 .15942 Metetra
.664 .741 .908 r
.68442 .15942 .69103 .16878 .70501 .16372 .69845 .15432 Metetra
.664 .741 .908 r
.69845 .15432 .70501 .16372 .71906 .15864 .71255 .14919 Metetra
.664 .741 .908 r
.71255 .14919 .71906 .15864 .73319 .15353 .72672 .14404 Metetra
.664 .741 .908 r
.72672 .14404 .73319 .15353 .74738 .1484 .74096 .13886 Metetra
.664 .741 .908 r
.74096 .13886 .74738 .1484 .76164 .14324 .75528 .13365 Metetra
.664 .741 .908 r
.75528 .13365 .76164 .14324 .77598 .13806 .76966 .12842 Metetra
.664 .741 .908 r
.13216 .34956 .14044 .35727 .1519 .3531 .14365 .34535 Metetra
.664 .741 .908 r
.14365 .34535 .1519 .3531 .16341 .34891 .15519 .34113 Metetra
.664 .741 .908 r
.15519 .34113 .16341 .34891 .17498 .34471 .16679 .33689 Metetra
.664 .741 .908 r
.16679 .33689 .17498 .34471 .18659 .34048 .17843 .33263 Metetra
.664 .741 .908 r
.17843 .33263 .18659 .34048 .19826 .33624 .19013 .32835 Metetra
.664 .741 .908 r
.19013 .32835 .19826 .33624 .20998 .33197 .20188 .32405 Metetra
.664 .741 .908 r
.20188 .32405 .20998 .33197 .22176 .32769 .21369 .31974 Metetra
.664 .741 .908 r
.21369 .31974 .22176 .32769 .23358 .32339 .22555 .3154 Metetra
.664 .741 .908 r
.22555 .3154 .23358 .32339 .24547 .31907 .23746 .31104 Metetra
.664 .741 .908 r
.23746 .31104 .24547 .31907 .2574 .31473 .24943 .30666 Metetra
.664 .741 .908 r
.24943 .30666 .2574 .31473 .26722 .33704 .26145 .30226 Metetra
0 0 .503 r
.26145 .30226 .26722 .33704 .27879 .34005 .27106 .32847 Metetra
.547 .617 .874 r
.27106 .32847 .27879 .34005 .29083 .33821 .28305 .32747 Metetra
.695 .695 .846 r
.28305 .32747 .29083 .33821 .30322 .33243 .29549 .32133 Metetra
.757 .708 .805 r
.29549 .32133 .30322 .33243 .31586 .32364 .30824 .31143 Metetra
.778 .697 .774 r
.30824 .31143 .31586 .32364 .32865 .31276 .32116 .29907 Metetra
.778 .678 .753 r
.32116 .29907 .32865 .31276 .34152 .30066 .33416 .28547 Metetra
.768 .659 .741 r
.33416 .28547 .34152 .30066 .35441 .28816 .34715 .27169 Metetra
.454 .485 .802 r
.34715 .27169 .35441 .28816 .36728 .27596 .35926 .27405 Metetra
0 .464 .717 r
.35926 .27405 .36728 .27596 .37958 .27574 .37147 .27656 Metetra
.111 0 0 r
.37147 .27656 .37958 .27574 .39193 .27652 .3839 .27703 Metetra
.172 .709 .774 r
.3839 .27703 .39193 .27652 .40445 .27549 .39653 .27505 Metetra
.498 .9 .928 r
.39653 .27505 .40445 .27549 .41714 .2724 .40933 .27043 Metetra
.716 .945 .956 r
.40933 .27043 .41714 .2724 .42996 .26716 .42229 .26319 Metetra
.804 .898 .909 r
.42229 .26319 .42996 .26716 .44289 .25984 .43535 .25357 Metetra
.825 .834 .855 r
.43535 .25357 .44289 .25984 .4559 .25069 .44848 .24202 Metetra
.82 .778 .813 r
.44848 .24202 .4559 .25069 .46897 .24012 .46164 .22914 Metetra
.315 .514 .892 r
.46164 .22914 .46897 .24012 .48193 .23743 .47452 .23288 Metetra
0 .496 .854 r
.47452 .23288 .48193 .23743 .49492 .23969 .48754 .23661 Metetra
0 .535 .83 r
.48754 .23661 .49492 .23969 .50804 .24147 .5007 .23917 Metetra
.137 .66 .88 r
.5007 .23917 .50804 .24147 .52128 .24197 .514 .23963 Metetra
.412 .83 .967 r
.514 .23963 .52128 .24197 .53463 .24043 .52741 .2371 Metetra
.677 .914 .975 r
.52741 .2371 .53463 .24043 .54804 .23614 .54088 .23089 Metetra
.81 .879 .896 r
.54088 .23089 .54804 .23614 .56149 .22858 .55437 .22058 Metetra
.848 .81 .812 r
.55437 .22058 .56149 .22858 .57492 .21752 .56782 .20618 Metetra
.847 .747 .753 r
.56782 .20618 .57492 .21752 .5883 .20314 .58118 .18825 Metetra
.369 .468 .831 r
.58118 .18825 .5883 .20314 .60176 .19292 .59502 .19277 Metetra
.914 .975 .782 r
.59502 .19277 .60176 .19292 .6158 .20152 .60839 .17535 Metetra
.608 .5 .705 r
.60839 .17535 .6158 .20152 .62898 .17958 .62213 .17033 Metetra
.664 .741 .908 r
.62213 .17033 .62898 .17958 .64274 .17458 .63593 .16528 Metetra
.664 .741 .908 r
.63593 .16528 .64274 .17458 .65657 .16955 .6498 .16021 Metetra
.664 .741 .908 r
.6498 .16021 .65657 .16955 .67046 .1645 .66374 .15511 Metetra
.664 .741 .908 r
.66374 .15511 .67046 .1645 .68442 .15942 .67775 .14998 Metetra
.664 .741 .908 r
.67775 .14998 .68442 .15942 .69845 .15432 .69183 .14483 Metetra
.664 .741 .908 r
.69183 .14483 .69845 .15432 .71255 .14919 .70598 .13966 Metetra
.664 .741 .908 r
.70598 .13966 .71255 .14919 .72672 .14404 .7202 .13446 Metetra
.664 .741 .908 r
.7202 .13446 .72672 .14404 .74096 .13886 .73449 .12923 Metetra
.664 .741 .908 r
.73449 .12923 .74096 .13886 .75528 .13365 .74885 .12397 Metetra
.664 .741 .908 r
.74885 .12397 .75528 .13365 .76966 .12842 .76329 .11869 Metetra
.664 .741 .908 r
.12381 .34178 .13216 .34956 .14365 .34535 .13533 .33755 Metetra
.664 .741 .908 r
.13533 .33755 .14365 .34535 .15519 .34113 .1469 .33329 Metetra
.664 .741 .908 r
.1469 .33329 .15519 .34113 .16679 .33689 .15852 .32901 Metetra
.664 .741 .908 r
.15852 .32901 .16679 .33689 .17843 .33263 .1702 .32472 Metetra
.664 .741 .908 r
.1702 .32472 .17843 .33263 .19013 .32835 .18193 .3204 Metetra
.664 .741 .908 r
.18193 .3204 .19013 .32835 .20188 .32405 .19371 .31607 Metetra
.664 .741 .908 r
.19371 .31607 .20188 .32405 .21369 .31974 .20555 .31171 Metetra
.664 .741 .908 r
.20555 .31171 .21369 .31974 .22555 .3154 .21744 .30734 Metetra
.664 .741 .908 r
.21744 .30734 .22555 .3154 .23746 .31104 .22939 .30294 Metetra
.664 .741 .908 r
.22939 .30294 .23746 .31104 .24943 .30666 .24139 .29853 Metetra
.664 .741 .908 r
.24139 .29853 .24943 .30666 .26145 .30226 .25344 .29409 Metetra
0 .167 .667 r
.25344 .29409 .26145 .30226 .27106 .32847 .26447 .30267 Metetra
.444 .39 .703 r
.26447 .30267 .27106 .32847 .28305 .32747 .27599 .30695 Metetra
.598 .524 .743 r
.27599 .30695 .28305 .32747 .29549 .32133 .2882 .30372 Metetra
.694 .602 .749 r
.2882 .30372 .29549 .32133 .30824 .31143 .30087 .29507 Metetra
.743 .637 .742 r
.30087 .29507 .30824 .31143 .32116 .29907 .3138 .28295 Metetra
.762 .648 .735 r
.3138 .28295 .32116 .29907 .33416 .28547 .32684 .26908 Metetra
.497 .512 .802 r
.32684 .26908 .33416 .28547 .34715 .27169 .33897 .27002 Metetra
.304 0 0 r
.33897 .27002 .34715 .27169 .35926 .27405 .35102 .27417 Metetra
.242 0 0 r
.35102 .27417 .35926 .27405 .37147 .27656 .3633 .27649 Metetra
.029 .601 .728 r
.3633 .27649 .37147 .27656 .3839 .27703 .37581 .27627 Metetra
.393 .843 .919 r
.37581 .27627 .3839 .27703 .39653 .27505 .38855 .27309 Metetra
.67 .936 .968 r
.38855 .27309 .39653 .27505 .40933 .27043 .40149 .26682 Metetra
.794 .908 .92 r
.40149 .26682 .40933 .27043 .42229 .26319 .41458 .2576 Metetra
.833 .852 .86 r
.41458 .2576 .42229 .26319 .43535 .25357 .42777 .24587 Metetra
.837 .8 .815 r
.42777 .24587 .43535 .25357 .44848 .24202 .44102 .23226 Metetra
.762 .747 .839 r
.44102 .23226 .44848 .24202 .46164 .22914 .45415 .22283 Metetra
0 .432 .85 r
.45415 .22283 .46164 .22914 .47452 .23288 .46704 .22805 Metetra
0 .459 .834 r
.46704 .22805 .47452 .23288 .48754 .23661 .48008 .23239 Metetra
.091 .583 .901 r
.48008 .23239 .48754 .23661 .5007 .23917 .49329 .23475 Metetra
.37 .753 .989 r
.49329 .23475 .5007 .23917 .514 .23963 .50664 .23411 Metetra
.636 .836 .977 r
.50664 .23411 .514 .23963 .52741 .2371 .5201 .22958 Metetra
.77 .812 .886 r
.5201 .22958 .52741 .2371 .54088 .23089 .53362 .22058 Metetra
.816 .759 .799 r
.53362 .22058 .54088 .23089 .55437 .22058 .54714 .20696 Metetra
.824 .711 .74 r
.54714 .20696 .55437 .22058 .56782 .20618 .56059 .18918 Metetra
.641 .592 .784 r
.56059 .18918 .56782 .20618 .58118 .18825 .5742 .18391 Metetra
.547 0 0 r
.5742 .18391 .58118 .18825 .59502 .19277 .58824 .19607 Metetra
.971 .925 .614 r
.58824 .19607 .59502 .19277 .60839 .17535 .60143 .16606 Metetra
.664 .741 .908 r
.60143 .16606 .60839 .17535 .62213 .17033 .61521 .16099 Metetra
.664 .741 .908 r
.61521 .16099 .62213 .17033 .63593 .16528 .62906 .15589 Metetra
.664 .741 .908 r
.62906 .15589 .63593 .16528 .6498 .16021 .64298 .15077 Metetra
.664 .741 .908 r
.64298 .15077 .6498 .16021 .66374 .15511 .65696 .14563 Metetra
.664 .741 .908 r
.65696 .14563 .66374 .15511 .67775 .14998 .67102 .14045 Metetra
.664 .741 .908 r
.67102 .14045 .67775 .14998 .69183 .14483 .68515 .13526 Metetra
.664 .741 .908 r
.68515 .13526 .69183 .14483 .70598 .13966 .69934 .13003 Metetra
.664 .741 .908 r
.69934 .13003 .70598 .13966 .7202 .13446 .71361 .12478 Metetra
.664 .741 .908 r
.71361 .12478 .7202 .13446 .73449 .12923 .72795 .11951 Metetra
.664 .741 .908 r
.72795 .11951 .73449 .12923 .74885 .12397 .74237 .1142 Metetra
.664 .741 .908 r
.74237 .1142 .74885 .12397 .76329 .11869 .75685 .10887 Metetra
.664 .741 .908 r
.11539 .33394 .12381 .34178 .13533 .33755 .12694 .32967 Metetra
.664 .741 .908 r
.12694 .32967 .13533 .33755 .1469 .33329 .13854 .32538 Metetra
.664 .741 .908 r
.13854 .32538 .1469 .33329 .15852 .32901 .15019 .32107 Metetra
.664 .741 .908 r
.15019 .32107 .15852 .32901 .1702 .32472 .1619 .31673 Metetra
.664 .741 .908 r
.1619 .31673 .1702 .32472 .18193 .3204 .17366 .31238 Metetra
.664 .741 .908 r
.17366 .31238 .18193 .3204 .19371 .31607 .18547 .30801 Metetra
.664 .741 .908 r
.18547 .30801 .19371 .31607 .20555 .31171 .19734 .30362 Metetra
.664 .741 .908 r
.19734 .30362 .20555 .31171 .21744 .30734 .20926 .29921 Metetra
.664 .741 .908 r
.20926 .29921 .21744 .30734 .22939 .30294 .22124 .29477 Metetra
.664 .741 .908 r
.22124 .29477 .22939 .30294 .24139 .29853 .23328 .29032 Metetra
.664 .741 .908 r
.23328 .29032 .24139 .29853 .25344 .29409 .24536 .28585 Metetra
.664 .741 .908 r
.24536 .28585 .25344 .29409 .26447 .30267 .25751 .28135 Metetra
.53 .477 .741 r
.25751 .28135 .26447 .30267 .27599 .30695 .26934 .28134 Metetra
.604 .494 .701 r
.26934 .28134 .27599 .30695 .2882 .30372 .28161 .2769 Metetra
.591 .479 .695 r
.28161 .2769 .2882 .30372 .30087 .29507 .29388 .27319 Metetra
.678 .561 .715 r
.29388 .27319 .30087 .29507 .3138 .28295 .3066 .26402 Metetra
.493 .48 .77 r
.3066 .26402 .3138 .28295 .32684 .26908 .31864 .26532 Metetra
0 .409 .751 r
.31864 .26532 .32684 .26908 .33897 .27002 .33062 .26934 Metetra
.294 0 0 r
.33062 .26934 .33897 .27002 .35102 .27417 .34276 .27273 Metetra
0 .528 .743 r
.34276 .27273 .35102 .27417 .3633 .27649 .35512 .27423 Metetra
.308 .771 .944 r
.35512 .27423 .3633 .27649 .37581 .27627 .36774 .27298 Metetra
.608 .885 .99 r
.36774 .27298 .37581 .27627 .38855 .27309 .38059 .26849 Metetra
.757 .878 .934 r
.38059 .26849 .38855 .27309 .40149 .26682 .39365 .26067 Metetra
.814 .838 .867 r
.39365 .26067 .40149 .26682 .41458 .2576 .40686 .2498 Metetra
.833 .798 .818 r
.40686 .2498 .41458 .2576 .42777 .24587 .42017 .23648 Metetra
.834 .767 .787 r
.42017 .23648 .42777 .24587 .44102 .23226 .43352 .22154 Metetra
.66 .696 .873 r
.43352 .22154 .44102 .23226 .45415 .22283 .44658 .21667 Metetra
0 .412 .832 r
.44658 .21667 .45415 .22283 .46704 .22805 .45948 .22209 Metetra
.074 .52 .9 r
.45948 .22209 .46704 .22805 .48008 .23239 .47257 .22586 Metetra
.341 .669 .975 r
.47257 .22586 .48008 .23239 .49329 .23475 .48583 .22678 Metetra
.591 .745 .95 r
.48583 .22678 .49329 .23475 .50664 .23411 .49924 .22382 Metetra
.723 .735 .861 r
.49924 .22382 .50664 .23411 .5201 .22958 .51275 .21622 Metetra
.775 .699 .779 r
.51275 .21622 .5201 .22958 .53362 .22058 .5263 .20368 Metetra
.791 .665 .724 r
.5263 .20368 .53362 .22058 .54714 .20696 .53983 .18651 Metetra
.675 .577 .738 r
.53983 .18651 .54714 .20696 .56059 .18918 .55339 .178 Metetra
0 .163 .7 r
.55339 .178 .56059 .18918 .5742 .18391 .56729 .19063 Metetra
.919 .93 .559 r
.56729 .19063 .5742 .18391 .58824 .19607 .58065 .16177 Metetra
.59 .454 .664 r
.58065 .16177 .58824 .19607 .60143 .16606 .5944 .15668 Metetra
.664 .741 .908 r
.5944 .15668 .60143 .16606 .61521 .16099 .60823 .15156 Metetra
.664 .741 .908 r
.60823 .15156 .61521 .16099 .62906 .15589 .62212 .14642 Metetra
.664 .741 .908 r
.62212 .14642 .62906 .15589 .64298 .15077 .63609 .14125 Metetra
.664 .741 .908 r
.63609 .14125 .64298 .15077 .65696 .14563 .65012 .13606 Metetra
.664 .741 .908 r
.65012 .13606 .65696 .14563 .67102 .14045 .66423 .13084 Metetra
.664 .741 .908 r
.66423 .13084 .67102 .14045 .68515 .13526 .6784 .12559 Metetra
.664 .741 .908 r
.6784 .12559 .68515 .13526 .69934 .13003 .69265 .12032 Metetra
.664 .741 .908 r
.69265 .12032 .69934 .13003 .71361 .12478 .70697 .11502 Metetra
.664 .741 .908 r
.70697 .11502 .71361 .12478 .72795 .11951 .72136 .1097 Metetra
.664 .741 .908 r
.72136 .1097 .72795 .11951 .74237 .1142 .73582 .10434 Metetra
.664 .741 .908 r
.73582 .10434 .74237 .1142 .75685 .10887 .75036 .09896 Metetra
.664 .741 .908 r
.1069 .32604 .11539 .33394 .12694 .32967 .11848 .32173 Metetra
.664 .741 .908 r
.11848 .32173 .12694 .32967 .13854 .32538 .13011 .3174 Metetra
.664 .741 .908 r
.13011 .3174 .13854 .32538 .15019 .32107 .14179 .31305 Metetra
.664 .741 .908 r
.14179 .31305 .15019 .32107 .1619 .31673 .15353 .30868 Metetra
.664 .741 .908 r
.15353 .30868 .1619 .31673 .17366 .31238 .16532 .3043 Metetra
.664 .741 .908 r
.16532 .3043 .17366 .31238 .18547 .30801 .17717 .29989 Metetra
.664 .741 .908 r
.17717 .29989 .18547 .30801 .19734 .30362 .18906 .29546 Metetra
.664 .741 .908 r
.18906 .29546 .19734 .30362 .20926 .29921 .20102 .29101 Metetra
.664 .741 .908 r
.20102 .29101 .20926 .29921 .22124 .29477 .21303 .28654 Metetra
.664 .741 .908 r
.21303 .28654 .22124 .29477 .23328 .29032 .22509 .28204 Metetra
.664 .741 .908 r
.22509 .28204 .23328 .29032 .24536 .28585 .23722 .27753 Metetra
.664 .741 .908 r
.23722 .27753 .24536 .28585 .25751 .28135 .2494 .273 Metetra
.664 .741 .908 r
.2494 .273 .25751 .28135 .26934 .28134 .26163 .26844 Metetra
.763 .35 0 r
.26163 .26844 .26934 .28134 .28161 .2769 .27176 .29049 Metetra
.27176 .29049 .28161 .2769 .29388 .27319 .28508 .27471 Metetra
.584 .945 .873 r
.28508 .27471 .29388 .27319 .3066 .26402 .29772 .26782 Metetra
.101 0 0 r
.29772 .26782 .3066 .26402 .31864 .26532 .31002 .2663 Metetra
.171 0 0 r
.31002 .2663 .31864 .26532 .33062 .26934 .32224 .2673 Metetra
.015 .576 .807 r
.32224 .2673 .33062 .26934 .34276 .27273 .33455 .26857 Metetra
.312 .727 .976 r
.33455 .26857 .34276 .27273 .35512 .27423 .34704 .26845 Metetra
.557 .792 .987 r
.34704 .26845 .35512 .27423 .36774 .27298 .35977 .26581 Metetra
.695 .794 .926 r
.35977 .26581 .36774 .27298 .38059 .26849 .37273 .26004 Metetra
.764 .777 .863 r
.37273 .26004 .38059 .26849 .39365 .26067 .38589 .25105 Metetra
.798 .758 .816 r
.38589 .25105 .39365 .26067 .40686 .2498 .39919 .23919 Metetra
.813 .743 .786 r
.39919 .23919 .40686 .2498 .42017 .23648 .41258 .22519 Metetra
.819 .734 .771 r
.41258 .22519 .42017 .23648 .43352 .22154 .42598 .21004 Metetra
.505 .611 .892 r
.42598 .21004 .43352 .22154 .44658 .21667 .43894 .20984 Metetra
.082 .5 .9 r
.43894 .20984 .44658 .21667 .45948 .22209 .4519 .21405 Metetra
.339 .621 .955 r
.4519 .21405 .45948 .22209 .47257 .22586 .46505 .21574 Metetra
.565 .677 .914 r
.46505 .21574 .47257 .22586 .48583 .22678 .47837 .21373 Metetra
.686 .669 .828 r
.47837 .21373 .48583 .22678 .49924 .22382 .49184 .20711 Metetra
.738 .644 .755 r
.49184 .20711 .49924 .22382 .51275 .21622 .50539 .19541 Metetra
.759 .619 .704 r
.50539 .19541 .51275 .21622 .5263 .20368 .51896 .17879 Metetra
.559 .477 .72 r
.51896 .17879 .5263 .20368 .53983 .18651 .53253 .17709 Metetra
0 .094 .627 r
.53253 .17709 .53983 .18651 .55339 .178 .5463 .1901 Metetra
.831 .869 .425 r
.5463 .1901 .55339 .178 .56729 .19063 .55977 .15746 Metetra
.592 .459 .669 r
.55977 .15746 .56729 .19063 .58065 .16177 .57351 .15235 Metetra
.664 .741 .908 r
.57351 .15235 .58065 .16177 .5944 .15668 .58731 .14721 Metetra
.664 .741 .908 r
.58731 .14721 .5944 .15668 .60823 .15156 .60118 .14205 Metetra
.664 .741 .908 r
.60118 .14205 .60823 .15156 .62212 .14642 .61512 .13686 Metetra
.664 .741 .908 r
.61512 .13686 .62212 .14642 .63609 .14125 .62914 .13164 Metetra
.664 .741 .908 r
.62914 .13164 .63609 .14125 .65012 .13606 .64322 .1264 Metetra
.664 .741 .908 r
.64322 .1264 .65012 .13606 .66423 .13084 .65737 .12113 Metetra
.664 .741 .908 r
.65737 .12113 .66423 .13084 .6784 .12559 .67159 .11584 Metetra
.664 .741 .908 r
.67159 .11584 .6784 .12559 .69265 .12032 .68589 .11052 Metetra
.664 .741 .908 r
.68589 .11052 .69265 .12032 .70697 .11502 .70026 .10517 Metetra
.664 .741 .908 r
.70026 .10517 .70697 .11502 .72136 .1097 .7147 .09979 Metetra
.664 .741 .908 r
.7147 .09979 .72136 .1097 .73582 .10434 .72922 .09439 Metetra
.664 .741 .908 r
.72922 .09439 .73582 .10434 .75036 .09896 .74381 .08896 Metetra
.664 .741 .908 r
.09834 .31807 .1069 .32604 .11848 .32173 .10995 .31372 Metetra
.664 .741 .908 r
.10995 .31372 .11848 .32173 .13011 .3174 .12161 .30936 Metetra
.664 .741 .908 r
.12161 .30936 .13011 .3174 .14179 .31305 .13332 .30497 Metetra
.664 .741 .908 r
.13332 .30497 .14179 .31305 .15353 .30868 .14509 .30057 Metetra
.664 .741 .908 r
.14509 .30057 .15353 .30868 .16532 .3043 .15691 .29614 Metetra
.664 .741 .908 r
.15691 .29614 .16532 .3043 .17717 .29989 .16879 .29169 Metetra
.664 .741 .908 r
.16879 .29169 .17717 .29989 .18906 .29546 .18072 .28723 Metetra
.664 .741 .908 r
.18072 .28723 .18906 .29546 .20102 .29101 .1927 .28274 Metetra
.664 .741 .908 r
.1927 .28274 .20102 .29101 .21303 .28654 .20475 .27823 Metetra
.664 .741 .908 r
.20475 .27823 .21303 .28654 .22509 .28204 .21684 .2737 Metetra
.664 .741 .908 r
.21684 .2737 .22509 .28204 .23722 .27753 .229 .26915 Metetra
.664 .741 .908 r
.229 .26915 .23722 .27753 .2494 .273 .24121 .26457 Metetra
.664 .741 .908 r
.24121 .26457 .2494 .273 .26163 .26844 .25348 .25998 Metetra
.954 .629 .368 r
.25348 .25998 .26163 .26844 .27176 .29049 .25937 .3318 Metetra
0 0 .071 r
.25937 .3318 .27176 .29049 .28508 .27471 .27443 .29764 Metetra
.27443 .29764 .28508 .27471 .29772 .26782 .28819 .27818 Metetra
.28819 .27818 .29772 .26782 .31002 .2663 .30121 .26809 Metetra
.375 .84 .801 r
.30121 .26809 .31002 .2663 .32224 .2673 .31389 .26327 Metetra
.514 .83 1 r
.31389 .26327 .32224 .2673 .33455 .26857 .32648 .26062 Metetra
.588 .738 .947 r
.32648 .26062 .33455 .26857 .34704 .26845 .33916 .25785 Metetra
.648 .694 .879 r
.33916 .25785 .34704 .26845 .35977 .26581 .35201 .25344 Metetra
.696 .679 .829 r
.35201 .25344 .35977 .26581 .37273 .26004 .36505 .24657 Metetra
.733 .676 .795 r
.36505 .24657 .37273 .26004 .38589 .25105 .37827 .23705 Metetra
.76 .679 .773 r
.37827 .23705 .38589 .25105 .39919 .23919 .3916 .22521 Metetra
.777 .686 .763 r
.3916 .22521 .39919 .23919 .41258 .22519 .40501 .21184 Metetra
.783 .696 .768 r
.40501 .21184 .41258 .22519 .42598 .21004 .4184 .19844 Metetra
.338 .521 .889 r
.4184 .19844 .42598 .21004 .43894 .20984 .43126 .20169 Metetra
.373 .637 .958 r
.43126 .20169 .43894 .20984 .4519 .21405 .44432 .20286 Metetra
.575 .657 .892 r
.44432 .20286 .4519 .21405 .46505 .21574 .45757 .20066 Metetra
.674 .634 .801 r
.45757 .20066 .46505 .21574 .47837 .21373 .47099 .19403 Metetra
.718 .606 .731 r
.47099 .19403 .47837 .21373 .49184 .20711 .48452 .18236 Metetra
.685 .554 .7 r
.48452 .18236 .49184 .20711 .50539 .19541 .49806 .17114 Metetra
.259 .291 .705 r
.49806 .17114 .50539 .19541 .51896 .17879 .51151 .18221 Metetra
.716 .211 .031 r
.51151 .18221 .51896 .17879 .53253 .17709 .52517 .19618 Metetra
.656 .261 .286 r
.52517 .19618 .53253 .17709 .5463 .1901 .53908 .21022 Metetra
.917 .818 .353 r
.53908 .21022 .5463 .1901 .55977 .15746 .55253 .148 Metetra
.664 .741 .908 r
.55253 .148 .55977 .15746 .57351 .15235 .56631 .14284 Metetra
.664 .741 .908 r
.56631 .14284 .57351 .15235 .58731 .14721 .58015 .13766 Metetra
.664 .741 .908 r
.58015 .13766 .58731 .14721 .60118 .14205 .59407 .13245 Metetra
.664 .741 .908 r
.59407 .13245 .60118 .14205 .61512 .13686 .60806 .12721 Metetra
.664 .741 .908 r
.60806 .12721 .61512 .13686 .62914 .13164 .62212 .12195 Metetra
.664 .741 .908 r
.62212 .12195 .62914 .13164 .64322 .1264 .63625 .11666 Metetra
.664 .741 .908 r
.63625 .11666 .64322 .1264 .65737 .12113 .65045 .11134 Metetra
.664 .741 .908 r
.65045 .11134 .65737 .12113 .67159 .11584 .66472 .10599 Metetra
.664 .741 .908 r
.66472 .10599 .67159 .11584 .68589 .11052 .67907 .10062 Metetra
.664 .741 .908 r
.67907 .10062 .68589 .11052 .70026 .10517 .69349 .09522 Metetra
.664 .741 .908 r
.69349 .09522 .70026 .10517 .7147 .09979 .70798 .0898 Metetra
.664 .741 .908 r
.70798 .0898 .7147 .09979 .72922 .09439 .72255 .08434 Metetra
.664 .741 .908 r
.72255 .08434 .72922 .09439 .74381 .08896 .73719 .07886 Metetra
.664 .741 .908 r
.08971 .31003 .09834 .31807 .10995 .31372 .10135 .30565 Metetra
.664 .741 .908 r
.10135 .30565 .10995 .31372 .12161 .30936 .11304 .30125 Metetra
.664 .741 .908 r
.11304 .30125 .12161 .30936 .13332 .30497 .12478 .29682 Metetra
.664 .741 .908 r
.12478 .29682 .13332 .30497 .14509 .30057 .13658 .29238 Metetra
.664 .741 .908 r
.13658 .29238 .14509 .30057 .15691 .29614 .14843 .28791 Metetra
.664 .741 .908 r
.14843 .28791 .15691 .29614 .16879 .29169 .16033 .28343 Metetra
.664 .741 .908 r
.16033 .28343 .16879 .29169 .18072 .28723 .1723 .27892 Metetra
.664 .741 .908 r
.1723 .27892 .18072 .28723 .1927 .28274 .18432 .2744 Metetra
.664 .741 .908 r
.18432 .2744 .1927 .28274 .20475 .27823 .19639 .26985 Metetra
.664 .741 .908 r
.19639 .26985 .20475 .27823 .21684 .2737 .20852 .26528 Metetra
.664 .741 .908 r
.20852 .26528 .21684 .2737 .229 .26915 .22071 .26069 Metetra
.664 .741 .908 r
.22071 .26069 .229 .26915 .24121 .26457 .23296 .25608 Metetra
.664 .741 .908 r
.23296 .25608 .24121 .26457 .25348 .25998 .24526 .25144 Metetra
.664 .741 .908 r
.24526 .25144 .25348 .25998 .25937 .3318 .25762 .24678 Metetra
0 0 .2 r
.25762 .24678 .25937 .3318 .27443 .29764 .26229 .33538 Metetra
.26229 .33538 .27443 .29764 .28819 .27818 .27793 .29537 Metetra
.62 .799 .368 r
.27793 .29537 .28819 .27818 .30121 .26809 .29216 .27122 Metetra
.847 .998 .805 r
.29216 .27122 .30121 .26809 .31389 .26327 .3056 .25688 Metetra
.778 .827 .891 r
.3056 .25688 .31389 .26327 .32648 .26062 .31866 .24794 Metetra
.691 .671 .826 r
.31866 .24794 .32648 .26062 .33916 .25785 .3316 .24124 Metetra
.667 .607 .778 r
.3316 .24124 .33916 .25785 .35201 .25344 .34458 .23466 Metetra
.672 .587 .752 r
.34458 .23466 .35201 .25344 .36505 .24657 .35766 .227 Metetra
.689 .589 .739 r
.35766 .227 .36505 .24657 .37827 .23705 .37086 .21783 Metetra
.707 .602 .737 r
.37086 .21783 .37827 .23705 .3916 .22521 .38415 .20737 Metetra
.722 .622 .745 r
.38415 .20737 .3916 .22521 .40501 .21184 .39747 .19633 Metetra
.616 .598 .809 r
.39747 .19633 .40501 .21184 .4184 .19844 .41054 .19251 Metetra
.45 .748 .992 r
.41054 .19251 .4184 .19844 .43126 .20169 .42358 .19147 Metetra
.634 .704 .897 r
.42358 .19147 .43126 .20169 .44432 .20286 .43681 .18741 Metetra
.699 .64 .787 r
.43681 .18741 .44432 .20286 .45757 .20066 .45021 .17922 Metetra
.65 .555 .735 r
.45021 .17922 .45757 .20066 .47099 .19403 .46363 .17218 Metetra
.308 .344 .736 r
.46363 .17218 .47099 .19403 .48452 .18236 .47685 .18031 Metetra
.668 .116 0 r
.47685 .18031 .48452 .18236 .49806 .17114 .4902 .19317 Metetra
.666 .286 .316 r
.4902 .19317 .49806 .17114 .51151 .18221 .50376 .20936 Metetra
.653 .289 .341 r
.50376 .20936 .51151 .18221 .52517 .19618 .51758 .22613 Metetra
.901 .784 .297 r
.51758 .22613 .52517 .19618 .53908 .21022 .53145 .14364 Metetra
.555 .372 .588 r
.53145 .14364 .53908 .21022 .55253 .148 .54521 .13846 Metetra
.664 .741 .908 r
.54521 .13846 .55253 .148 .56631 .14284 .55904 .13325 Metetra
.664 .741 .908 r
.55904 .13325 .56631 .14284 .58015 .13766 .57293 .12802 Metetra
.664 .741 .908 r
.57293 .12802 .58015 .13766 .59407 .13245 .5869 .12276 Metetra
.664 .741 .908 r
.5869 .12276 .59407 .13245 .60806 .12721 .60093 .11747 Metetra
.664 .741 .908 r
.60093 .11747 .60806 .12721 .62212 .12195 .61504 .11216 Metetra
.664 .741 .908 r
.61504 .11216 .62212 .12195 .63625 .11666 .62921 .10682 Metetra
.664 .741 .908 r
.62921 .10682 .63625 .11666 .65045 .11134 .64346 .10145 Metetra
.664 .741 .908 r
.64346 .10145 .65045 .11134 .66472 .10599 .65779 .09606 Metetra
.664 .741 .908 r
.65779 .09606 .66472 .10599 .67907 .10062 .67218 .09063 Metetra
.664 .741 .908 r
.67218 .09063 .67907 .10062 .69349 .09522 .68665 .08518 Metetra
.664 .741 .908 r
.68665 .08518 .69349 .09522 .70798 .0898 .7012 .0797 Metetra
.664 .741 .908 r
.7012 .0797 .70798 .0898 .72255 .08434 .71581 .0742 Metetra
.664 .741 .908 r
.71581 .0742 .72255 .08434 .73719 .07886 .73051 .06866 Metetra
.664 .741 .908 r
.081 .30192 .08971 .31003 .10135 .30565 .09267 .2975 Metetra
.664 .741 .908 r
.09267 .2975 .10135 .30565 .11304 .30125 .10439 .29306 Metetra
.664 .741 .908 r
.10439 .29306 .11304 .30125 .12478 .29682 .11616 .2886 Metetra
.664 .741 .908 r
.11616 .2886 .12478 .29682 .13658 .29238 .12799 .28412 Metetra
.664 .741 .908 r
.12799 .28412 .13658 .29238 .14843 .28791 .13987 .27962 Metetra
.664 .741 .908 r
.13987 .27962 .14843 .28791 .16033 .28343 .15181 .27509 Metetra
.664 .741 .908 r
.15181 .27509 .16033 .28343 .1723 .27892 .1638 .27055 Metetra
.664 .741 .908 r
.1638 .27055 .1723 .27892 .18432 .2744 .17585 .26598 Metetra
.664 .741 .908 r
.17585 .26598 .18432 .2744 .19639 .26985 .18796 .2614 Metetra
.664 .741 .908 r
.18796 .2614 .19639 .26985 .20852 .26528 .20013 .25679 Metetra
.664 .741 .908 r
.20013 .25679 .20852 .26528 .22071 .26069 .21235 .25216 Metetra
.664 .741 .908 r
.21235 .25216 .22071 .26069 .23296 .25608 .22463 .2475 Metetra
.664 .741 .908 r
.22463 .2475 .23296 .25608 .24526 .25144 .23697 .24283 Metetra
.664 .741 .908 r
.23697 .24283 .24526 .25144 .25762 .24678 .24936 .23813 Metetra
.664 .741 .908 r
.24936 .23813 .25762 .24678 .26229 .33538 .26182 .23341 Metetra
0 0 .288 r
.26182 .23341 .26229 .33538 .27793 .29537 .26664 .32234 Metetra
.818 .835 .365 r
.26664 .32234 .27793 .29537 .29216 .27122 .28278 .27675 Metetra
.971 .928 .674 r
.28278 .27675 .29216 .27122 .3056 .25688 .2974 .24808 Metetra
.861 .771 .762 r
.2974 .24808 .3056 .25688 .31866 .24794 .31115 .22987 Metetra
.734 .624 .736 r
.31115 .22987 .31866 .24794 .3316 .24124 .32446 .21765 Metetra
.669 .549 .709 r
.32446 .21765 .3316 .24124 .34458 .23466 .33758 .20842 Metetra
.644 .519 .696 r
.33758 .20842 .34458 .23466 .35766 .227 .35066 .20038 Metetra
.581 .478 .702 r
.35066 .20038 .35766 .227 .37086 .21783 .36353 .19697 Metetra
.574 .515 .751 r
.36353 .19697 .37086 .21783 .38415 .20737 .37642 .19455 Metetra
.608 .638 .855 r
.37642 .19455 .38415 .20737 .39747 .19633 .38944 .19127 Metetra
.653 .854 .977 r
.38944 .19127 .39747 .19633 .41054 .19251 .4026 .18623 Metetra
.751 .841 .919 r
.4026 .18623 .41054 .19251 .42358 .19147 .41593 .17834 Metetra
.65 .653 .84 r
.41593 .17834 .42358 .19147 .43681 .18741 .42921 .17335 Metetra
.217 .399 .829 r
.42921 .17335 .43681 .18741 .45021 .17922 .44224 .17985 Metetra
.675 .133 0 r
.44224 .17985 .45021 .17922 .46363 .17218 .45531 .19154 Metetra
.681 .291 .302 r
.45531 .19154 .46363 .17218 .47685 .18031 .46851 .2082 Metetra
.678 .317 .354 r
.46851 .2082 .47685 .18031 .4902 .19317 .48192 .22862 Metetra
.662 .317 .377 r
.48192 .22862 .4902 .19317 .50376 .20936 .49562 .2502 Metetra
.911 .768 .28 r
.49562 .2502 .50376 .20936 .51758 .22613 .51029 .13926 Metetra
.544 .349 .567 r
.51029 .13926 .51758 .22613 .53145 .14364 .52403 .13405 Metetra
.664 .741 .908 r
.52403 .13405 .53145 .14364 .54521 .13846 .53783 .12882 Metetra
.664 .741 .908 r
.53783 .12882 .54521 .13846 .55904 .13325 .5517 .12357 Metetra
.664 .741 .908 r
.5517 .12357 .55904 .13325 .57293 .12802 .56564 .11829 Metetra
.664 .741 .908 r
.56564 .11829 .57293 .12802 .5869 .12276 .57965 .11298 Metetra
.664 .741 .908 r
.57965 .11298 .5869 .12276 .60093 .11747 .59373 .10764 Metetra
.664 .741 .908 r
.59373 .10764 .60093 .11747 .61504 .11216 .60789 .10228 Metetra
.664 .741 .908 r
.60789 .10228 .61504 .11216 .62921 .10682 .62211 .09689 Metetra
.664 .741 .908 r
.62211 .09689 .62921 .10682 .64346 .10145 .63641 .09147 Metetra
.664 .741 .908 r
.63641 .09147 .64346 .10145 .65779 .09606 .65078 .08602 Metetra
.664 .741 .908 r
.65078 .08602 .65779 .09606 .67218 .09063 .66523 .08055 Metetra
.664 .741 .908 r
.66523 .08055 .67218 .09063 .68665 .08518 .67975 .07505 Metetra
.664 .741 .908 r
.67975 .07505 .68665 .08518 .7012 .0797 .69435 .06952 Metetra
.664 .741 .908 r
.69435 .06952 .7012 .0797 .71581 .0742 .70902 .06396 Metetra
.664 .741 .908 r
.70902 .06396 .71581 .0742 .73051 .06866 .72376 .05837 Metetra
.664 .741 .908 r
.07222 .29375 .081 .30192 .09267 .2975 .08392 .28929 Metetra
.664 .741 .908 r
.08392 .28929 .09267 .2975 .10439 .29306 .09567 .28481 Metetra
.664 .741 .908 r
.09567 .28481 .10439 .29306 .11616 .2886 .10747 .28031 Metetra
.664 .741 .908 r
.10747 .28031 .11616 .2886 .12799 .28412 .11933 .27579 Metetra
.664 .741 .908 r
.11933 .27579 .12799 .28412 .13987 .27962 .13124 .27125 Metetra
.664 .741 .908 r
.13124 .27125 .13987 .27962 .15181 .27509 .14321 .26669 Metetra
.664 .741 .908 r
.14321 .26669 .15181 .27509 .1638 .27055 .15524 .2621 Metetra
.664 .741 .908 r
.15524 .2621 .1638 .27055 .17585 .26598 .16732 .2575 Metetra
.664 .741 .908 r
.16732 .2575 .17585 .26598 .18796 .2614 .17946 .25287 Metetra
.664 .741 .908 r
.17946 .25287 .18796 .2614 .20013 .25679 .19166 .24822 Metetra
.664 .741 .908 r
.19166 .24822 .20013 .25679 .21235 .25216 .20391 .24355 Metetra
.664 .741 .908 r
.20391 .24355 .21235 .25216 .22463 .2475 .21623 .23885 Metetra
.664 .741 .908 r
.21623 .23885 .22463 .2475 .23697 .24283 .2286 .23414 Metetra
.664 .741 .908 r
.2286 .23414 .23697 .24283 .24936 .23813 .24103 .2294 Metetra
.664 .741 .908 r
.24103 .2294 .24936 .23813 .26182 .23341 .25352 .22464 Metetra
.664 .741 .908 r
.25352 .22464 .26182 .23341 .26664 .32234 .26607 .21985 Metetra
0 0 .401 r
.26607 .21985 .26664 .32234 .28278 .27675 .2729 .28642 Metetra
.995 .864 .583 r
.2729 .28642 .28278 .27675 .2974 .24808 .28927 .23726 Metetra
.896 .738 .678 r
.28927 .23726 .2974 .24808 .31115 .22987 .30403 .20611 Metetra
.288 .309 .709 r
.30403 .20611 .31115 .22987 .32446 .21765 .31591 .21465 Metetra
0 .48 .772 r
.31591 .21465 .32446 .21765 .33758 .20842 .32832 .21749 Metetra
.268 0 0 r
.32832 .21749 .33758 .20842 .35066 .20038 .34114 .21571 Metetra
.252 0 .042 r
.34114 .21571 .35066 .20038 .36353 .19697 .35423 .21076 Metetra
.101 0 0 r
.35423 .21076 .36353 .19697 .37642 .19455 .36752 .20318 Metetra
.36752 .20318 .37642 .19455 .38944 .19127 .38098 .19283 Metetra
.84 .998 .829 r
.38098 .19283 .38944 .19127 .4026 .18623 .39461 .17915 Metetra
.777 .824 .889 r
.39461 .17915 .4026 .18623 .41593 .17834 .40805 .16992 Metetra
0 .026 .537 r
.40805 .16992 .41593 .17834 .42921 .17335 .42076 .1824 Metetra
.744 .307 .212 r
.42076 .1824 .42921 .17335 .44224 .17985 .43354 .20028 Metetra
.726 .346 .329 r
.43354 .20028 .44224 .17985 .45531 .19154 .44644 .22348 Metetra
.706 .355 .378 r
.44644 .22348 .45531 .19154 .46851 .2082 .45959 .25097 Metetra
.684 .349 .401 r
.45959 .25097 .46851 .2082 .48192 .22862 .47306 .28036 Metetra
.931 .764 .287 r
.47306 .28036 .48192 .22862 .49562 .2502 .48904 .13486 Metetra
.534 .329 .548 r
.48904 .13486 .49562 .2502 .51029 .13926 .50275 .12963 Metetra
.664 .741 .908 r
.50275 .12963 .51029 .13926 .52403 .13405 .51653 .12438 Metetra
.664 .741 .908 r
.51653 .12438 .52403 .13405 .53783 .12882 .53038 .1191 Metetra
.664 .741 .908 r
.53038 .1191 .53783 .12882 .5517 .12357 .54429 .1138 Metetra
.664 .741 .908 r
.54429 .1138 .5517 .12357 .56564 .11829 .55828 .10846 Metetra
.664 .741 .908 r
.55828 .10846 .56564 .11829 .57965 .11298 .57234 .1031 Metetra
.664 .741 .908 r
.57234 .1031 .57965 .11298 .59373 .10764 .58647 .09772 Metetra
.664 .741 .908 r
.58647 .09772 .59373 .10764 .60789 .10228 .60067 .0923 Metetra
.664 .741 .908 r
.60067 .0923 .60789 .10228 .62211 .09689 .61495 .08686 Metetra
.664 .741 .908 r
.61495 .08686 .62211 .09689 .63641 .09147 .62929 .08139 Metetra
.664 .741 .908 r
.62929 .08139 .63641 .09147 .65078 .08602 .64372 .0759 Metetra
.664 .741 .908 r
.64372 .0759 .65078 .08602 .66523 .08055 .65821 .07037 Metetra
.664 .741 .908 r
.65821 .07037 .66523 .08055 .67975 .07505 .67278 .06481 Metetra
.664 .741 .908 r
.67278 .06481 .67975 .07505 .69435 .06952 .68743 .05923 Metetra
.664 .741 .908 r
.68743 .05923 .69435 .06952 .70902 .06396 .70215 .05362 Metetra
.664 .741 .908 r
.70215 .05362 .70902 .06396 .72376 .05837 .71695 .04798 Metetra
.664 .741 .908 r
.06337 .2855 .07222 .29375 .08392 .28929 .07509 .28101 Metetra
.664 .741 .908 r
.07509 .28101 .08392 .28929 .09567 .28481 .08687 .27649 Metetra
.664 .741 .908 r
.08687 .27649 .09567 .28481 .10747 .28031 .0987 .27195 Metetra
.664 .741 .908 r
.0987 .27195 .10747 .28031 .11933 .27579 .11059 .26739 Metetra
.664 .741 .908 r
.11059 .26739 .11933 .27579 .13124 .27125 .12254 .26281 Metetra
.664 .741 .908 r
.12254 .26281 .13124 .27125 .14321 .26669 .13454 .25821 Metetra
.664 .741 .908 r
.13454 .25821 .14321 .26669 .15524 .2621 .1466 .25358 Metetra
.664 .741 .908 r
.1466 .25358 .15524 .2621 .16732 .2575 .15871 .24894 Metetra
.664 .741 .908 r
.15871 .24894 .16732 .2575 .17946 .25287 .17088 .24427 Metetra
.664 .741 .908 r
.17088 .24427 .17946 .25287 .19166 .24822 .18312 .23958 Metetra
.664 .741 .908 r
.18312 .23958 .19166 .24822 .20391 .24355 .1954 .23486 Metetra
.664 .741 .908 r
.1954 .23486 .20391 .24355 .21623 .23885 .20775 .23013 Metetra
.664 .741 .908 r
.20775 .23013 .21623 .23885 .2286 .23414 .22016 .22537 Metetra
.664 .741 .908 r
.22016 .22537 .2286 .23414 .24103 .2294 .23262 .22059 Metetra
.664 .741 .908 r
.23262 .22059 .24103 .2294 .25352 .22464 .24515 .21579 Metetra
.664 .741 .908 r
.24515 .21579 .25352 .22464 .26607 .21985 .25774 .21096 Metetra
.664 .741 .908 r
.25774 .21096 .26607 .21985 .2729 .28642 .27038 .20611 Metetra
.368 .215 .539 r
.27038 .20611 .2729 .28642 .28927 .23726 .28116 .2254 Metetra
.742 .706 .818 r
.28116 .2254 .28927 .23726 .30403 .20611 .29436 .21611 Metetra
.768 .36 .278 r
.29436 .21611 .30403 .20611 .31591 .21465 .30544 .23672 Metetra
.572 .194 .286 r
.30544 .23672 .31591 .21465 .32832 .21749 .3177 .24408 Metetra
.416 .059 .248 r
.3177 .24408 .32832 .21749 .34114 .21571 .33073 .24181 Metetra
.249 0 .17 r
.33073 .24181 .34114 .21571 .35423 .21076 .34427 .23233 Metetra
.34427 .23233 .35423 .21076 .36752 .20318 .35816 .21701 Metetra
.35816 .21701 .36752 .20318 .38098 .19283 .37229 .19643 Metetra
.961 .943 .691 r
.37229 .19643 .38098 .19283 .39461 .17915 .38659 .17071 Metetra
.293 .593 .947 r
.38659 .17071 .39461 .17915 .40805 .16992 .39961 .1729 Metetra
.844 .411 .2 r
.39961 .1729 .40805 .16992 .42076 .1824 .41183 .1998 Metetra
.793 .414 .339 r
.41183 .1998 .42076 .1824 .43354 .20028 .4242 .23276 Metetra
.752 .403 .392 r
.4242 .23276 .43354 .20028 .44644 .22348 .43684 .2709 Metetra
.718 .387 .417 r
.43684 .2709 .44644 .22348 .45959 .25097 .44987 .31203 Metetra
.951 .764 .305 r
.44987 .31203 .45959 .25097 .47306 .28036 .4677 .13044 Metetra
.526 .314 .534 r
.4677 .13044 .47306 .28036 .48904 .13486 .48139 .12519 Metetra
.664 .741 .908 r
.48139 .12519 .48904 .13486 .50275 .12963 .49514 .11991 Metetra
.664 .741 .908 r
.49514 .11991 .50275 .12963 .51653 .12438 .50896 .11461 Metetra
.664 .741 .908 r
.50896 .11461 .51653 .12438 .53038 .1191 .52286 .10929 Metetra
.664 .741 .908 r
.52286 .10929 .53038 .1191 .54429 .1138 .53682 .10393 Metetra
.664 .741 .908 r
.53682 .10393 .54429 .1138 .55828 .10846 .55085 .09855 Metetra
.664 .741 .908 r
.55085 .09855 .55828 .10846 .57234 .1031 .56496 .09314 Metetra
.664 .741 .908 r
.56496 .09314 .57234 .1031 .58647 .09772 .57914 .0877 Metetra
.664 .741 .908 r
.57914 .0877 .58647 .09772 .60067 .0923 .59339 .08224 Metetra
.664 .741 .908 r
.59339 .08224 .60067 .0923 .61495 .08686 .60771 .07674 Metetra
.664 .741 .908 r
.60771 .07674 .61495 .08686 .62929 .08139 .62211 .07122 Metetra
.664 .741 .908 r
.62211 .07122 .62929 .08139 .64372 .0759 .63658 .06567 Metetra
.664 .741 .908 r
.63658 .06567 .64372 .0759 .65821 .07037 .65113 .06009 Metetra
.664 .741 .908 r
.65113 .06009 .65821 .07037 .67278 .06481 .66575 .05448 Metetra
.664 .741 .908 r
.66575 .05448 .67278 .06481 .68743 .05923 .68045 .04885 Metetra
.664 .741 .908 r
.68045 .04885 .68743 .05923 .70215 .05362 .69523 .04318 Metetra
.664 .741 .908 r
.69523 .04318 .70215 .05362 .71695 .04798 .71008 .03748 Metetra
.664 .741 .908 r
.05443 .27718 .06337 .2855 .07509 .28101 .06619 .27265 Metetra
.664 .741 .908 r
.06619 .27265 .07509 .28101 .08687 .27649 .078 .26809 Metetra
.664 .741 .908 r
.078 .26809 .08687 .27649 .0987 .27195 .08986 .26352 Metetra
.664 .741 .908 r
.08986 .26352 .0987 .27195 .11059 .26739 .10178 .25892 Metetra
.664 .741 .908 r
.10178 .25892 .11059 .26739 .12254 .26281 .11376 .2543 Metetra
.664 .741 .908 r
.11376 .2543 .12254 .26281 .13454 .25821 .12579 .24965 Metetra
.664 .741 .908 r
.12579 .24965 .13454 .25821 .1466 .25358 .13788 .24499 Metetra
.664 .741 .908 r
.13788 .24499 .1466 .25358 .15871 .24894 .15003 .2403 Metetra
.664 .741 .908 r
.15003 .2403 .15871 .24894 .17088 .24427 .16223 .23559 Metetra
.664 .741 .908 r
.16223 .23559 .17088 .24427 .18312 .23958 .1745 .23086 Metetra
.664 .741 .908 r
.1745 .23086 .18312 .23958 .1954 .23486 .18682 .22611 Metetra
.664 .741 .908 r
.18682 .22611 .1954 .23486 .20775 .23013 .1992 .22133 Metetra
.664 .741 .908 r
.1992 .22133 .20775 .23013 .22016 .22537 .21164 .21653 Metetra
.664 .741 .908 r
.21164 .21653 .22016 .22537 .23262 .22059 .22414 .2117 Metetra
.664 .741 .908 r
.22414 .2117 .23262 .22059 .24515 .21579 .2367 .20686 Metetra
.664 .741 .908 r
.2367 .20686 .24515 .21579 .25774 .21096 .24933 .20199 Metetra
.664 .741 .908 r
.24933 .20199 .25774 .21096 .27038 .20611 .26201 .19709 Metetra
.664 .741 .908 r
.26201 .19709 .27038 .20611 .28116 .2254 .27476 .19218 Metetra
0 0 .215 r
.27476 .19218 .28116 .2254 .29436 .21611 .28394 .23315 Metetra
.805 .442 .371 r
.28394 .23315 .29436 .21611 .30544 .23672 .294 .26834 Metetra
.617 .269 .357 r
.294 .26834 .30544 .23672 .3177 .24408 .30599 .28188 Metetra
.428 .102 .308 r
.30599 .28188 .3177 .24408 .33073 .24181 .31931 .27872 Metetra
.201 0 .212 r
.31931 .27872 .33073 .24181 .34427 .23233 .3335 .26268 Metetra
0 0 .005 r
.3335 .26268 .34427 .23233 .35816 .21701 .34826 .23648 Metetra
.764 .838 .381 r
.34826 .23648 .35816 .21701 .37229 .19643 .36334 .20191 Metetra
.992 .876 .6 r
.36334 .20191 .37229 .19643 .38659 .17071 .37859 .16029 Metetra
.728 .277 0 r
.37859 .16029 .38659 .17071 .39961 .1729 .39076 .1817 Metetra
.874 .497 .325 r
.39076 .1817 .39961 .1729 .41183 .1998 .40226 .22742 Metetra
.813 .464 .395 r
.40226 .22742 .41183 .1998 .4242 .23276 .41403 .28002 Metetra
.766 .435 .425 r
.41403 .28002 .4242 .23276 .43684 .2709 .42625 .33744 Metetra
.966 .765 .327 r
.42625 .33744 .43684 .2709 .44987 .31203 .44627 .126 Metetra
.52 .303 .524 r
.44627 .126 .44987 .31203 .4677 .13044 .45993 .12073 Metetra
.664 .741 .908 r
.45993 .12073 .4677 .13044 .48139 .12519 .47366 .11543 Metetra
.664 .741 .908 r
.47366 .11543 .48139 .12519 .49514 .11991 .48746 .11011 Metetra
.664 .741 .908 r
.48746 .11011 .49514 .11991 .50896 .11461 .50132 .10476 Metetra
.664 .741 .908 r
.50132 .10476 .50896 .11461 .52286 .10929 .51526 .09938 Metetra
.664 .741 .908 r
.51526 .09938 .52286 .10929 .53682 .10393 .52927 .09397 Metetra
.664 .741 .908 r
.52927 .09397 .53682 .10393 .55085 .09855 .54335 .08854 Metetra
.664 .741 .908 r
.54335 .08854 .55085 .09855 .56496 .09314 .55751 .08308 Metetra
.664 .741 .908 r
.55751 .08308 .56496 .09314 .57914 .0877 .57173 .07759 Metetra
.664 .741 .908 r
.57173 .07759 .57914 .0877 .59339 .08224 .58603 .07207 Metetra
.664 .741 .908 r
.58603 .07207 .59339 .08224 .60771 .07674 .60041 .06653 Metetra
.664 .741 .908 r
.60041 .06653 .60771 .07674 .62211 .07122 .61485 .06095 Metetra
.664 .741 .908 r
.61485 .06095 .62211 .07122 .63658 .06567 .62938 .05535 Metetra
.664 .741 .908 r
.62938 .05535 .63658 .06567 .65113 .06009 .64397 .04972 Metetra
.664 .741 .908 r
.64397 .04972 .65113 .06009 .66575 .05448 .65865 .04405 Metetra
.664 .741 .908 r
.65865 .04405 .66575 .05448 .68045 .04885 .6734 .03836 Metetra
.664 .741 .908 r
.6734 .03836 .68045 .04885 .69523 .04318 .68823 .03264 Metetra
.664 .741 .908 r
.68823 .03264 .69523 .04318 .71008 .03748 .70314 .02689 Metetra
.664 .741 .908 r
.04542 .2688 .05443 .27718 .06619 .27265 .05721 .26422 Metetra
.664 .741 .908 r
.05721 .26422 .06619 .27265 .078 .26809 .06905 .25963 Metetra
.664 .741 .908 r
.06905 .25963 .078 .26809 .08986 .26352 .08094 .25501 Metetra
.664 .741 .908 r
.08094 .25501 .08986 .26352 .10178 .25892 .09289 .25037 Metetra
.664 .741 .908 r
.09289 .25037 .10178 .25892 .11376 .2543 .1049 .24571 Metetra
.664 .741 .908 r
.1049 .24571 .11376 .2543 .12579 .24965 .11697 .24102 Metetra
.664 .741 .908 r
.11697 .24102 .12579 .24965 .13788 .24499 .12909 .23632 Metetra
.664 .741 .908 r
.12909 .23632 .13788 .24499 .15003 .2403 .14127 .23159 Metetra
.664 .741 .908 r
.14127 .23159 .15003 .2403 .16223 .23559 .15351 .22684 Metetra
.664 .741 .908 r
.15351 .22684 .16223 .23559 .1745 .23086 .1658 .22206 Metetra
.664 .741 .908 r
.1658 .22206 .1745 .23086 .18682 .22611 .17816 .21727 Metetra
.664 .741 .908 r
.17816 .21727 .18682 .22611 .1992 .22133 .19057 .21245 Metetra
.664 .741 .908 r
.19057 .21245 .1992 .22133 .21164 .21653 .20305 .2076 Metetra
.664 .741 .908 r
.20305 .2076 .21164 .21653 .22414 .2117 .21559 .20274 Metetra
.664 .741 .908 r
.21559 .20274 .22414 .2117 .2367 .20686 .22818 .19785 Metetra
.664 .741 .908 r
.22818 .19785 .2367 .20686 .24933 .20199 .24084 .19293 Metetra
.664 .741 .908 r
.24084 .19293 .24933 .20199 .26201 .19709 .25356 .188 Metetra
.664 .741 .908 r
.25356 .188 .26201 .19709 .27476 .19218 .26634 .18303 Metetra
.664 .741 .908 r
.26634 .18303 .27476 .19218 .28394 .23315 .27919 .17805 Metetra
.556 .381 .6 r
.27919 .17805 .28394 .23315 .294 .26834 .2921 .17304 Metetra
.817 .637 .084 r
.2921 .17304 .294 .26834 .30599 .28188 .293 .33216 Metetra
.432 .125 .342 r
.293 .33216 .30599 .28188 .31931 .27872 .30668 .32783 Metetra
.138 0 .226 r
.30668 .32783 .31931 .27872 .3335 .26268 .32178 .30282 Metetra
.32178 .30282 .3335 .26268 .34826 .23648 .33774 .26194 Metetra
.877 .845 .383 r
.33774 .26194 .34826 .23648 .36334 .20191 .35414 .20902 Metetra
.997 .827 .548 r
.35414 .20902 .36334 .20191 .37859 .16029 .37065 .14719 Metetra
.93 .562 .158 r
.37065 .14719 .37859 .16029 .39076 .1817 .38139 .19765 Metetra
.884 .535 .381 r
.38139 .19765 .39076 .1817 .40226 .22742 .39185 .26753 Metetra
.983 .791 .385 r
.39185 .26753 .40226 .22742 .41403 .28002 .41118 .12681 Metetra
.522 .308 .53 r
.41118 .12681 .41403 .28002 .42625 .33744 .42475 .12154 Metetra
.516 .295 .517 r
.42475 .12154 .42625 .33744 .44627 .126 .43838 .11625 Metetra
.664 .741 .908 r
.43838 .11625 .44627 .126 .45993 .12073 .45209 .11093 Metetra
.664 .741 .908 r
.45209 .11093 .45993 .12073 .47366 .11543 .46586 .10558 Metetra
.664 .741 .908 r
.46586 .10558 .47366 .11543 .48746 .11011 .4797 .10021 Metetra
.664 .741 .908 r
.4797 .10021 .48746 .11011 .50132 .10476 .49362 .09481 Metetra
.664 .741 .908 r
.49362 .09481 .50132 .10476 .51526 .09938 .5076 .08938 Metetra
.664 .741 .908 r
.5076 .08938 .51526 .09938 .52927 .09397 .52166 .08392 Metetra
.664 .741 .908 r
.52166 .08392 .52927 .09397 .54335 .08854 .53578 .07844 Metetra
.664 .741 .908 r
.53578 .07844 .54335 .08854 .55751 .08308 .54998 .07292 Metetra
.664 .741 .908 r
.54998 .07292 .55751 .08308 .57173 .07759 .56426 .06738 Metetra
.664 .741 .908 r
.56426 .06738 .57173 .07759 .58603 .07207 .57861 .06181 Metetra
.664 .741 .908 r
.57861 .06181 .58603 .07207 .60041 .06653 .59303 .05621 Metetra
.664 .741 .908 r
.59303 .05621 .60041 .06653 .61485 .06095 .60753 .05058 Metetra
.664 .741 .908 r
.60753 .05058 .61485 .06095 .62938 .05535 .6221 .04493 Metetra
.664 .741 .908 r
.6221 .04493 .62938 .05535 .64397 .04972 .63675 .03924 Metetra
.664 .741 .908 r
.63675 .03924 .64397 .04972 .65865 .04405 .65148 .03352 Metetra
.664 .741 .908 r
.65148 .03352 .65865 .04405 .6734 .03836 .66628 .02778 Metetra
.664 .741 .908 r
.66628 .02778 .6734 .03836 .68823 .03264 .68117 .022 Metetra
.664 .741 .908 r
.68117 .022 .68823 .03264 .70314 .02689 .69613 .01619 Metetra
.664 .741 .908 r
.03634 .26033 .04542 .2688 .05721 .26422 .04815 .25572 Metetra
.664 .741 .908 r
.04815 .25572 .05721 .26422 .06905 .25963 .06002 .25108 Metetra
.664 .741 .908 r
.06002 .25108 .06905 .25963 .08094 .25501 .07194 .24643 Metetra
.664 .741 .908 r
.07194 .24643 .08094 .25501 .09289 .25037 .08393 .24175 Metetra
.664 .741 .908 r
.08393 .24175 .09289 .25037 .1049 .24571 .09597 .23704 Metetra
.664 .741 .908 r
.09597 .23704 .1049 .24571 .11697 .24102 .10806 .23232 Metetra
.664 .741 .908 r
.10806 .23232 .11697 .24102 .12909 .23632 .12022 .22757 Metetra
.664 .741 .908 r
.12022 .22757 .12909 .23632 .14127 .23159 .13243 .2228 Metetra
.664 .741 .908 r
.13243 .2228 .14127 .23159 .15351 .22684 .1447 .21801 Metetra
.664 .741 .908 r
.1447 .21801 .15351 .22684 .1658 .22206 .15703 .21319 Metetra
.664 .741 .908 r
.15703 .21319 .1658 .22206 .17816 .21727 .16942 .20835 Metetra
.664 .741 .908 r
.16942 .20835 .17816 .21727 .19057 .21245 .18187 .20349 Metetra
.664 .741 .908 r
.18187 .20349 .19057 .21245 .20305 .2076 .19438 .1986 Metetra
.664 .741 .908 r
.19438 .1986 .20305 .2076 .21559 .20274 .20695 .19369 Metetra
.664 .741 .908 r
.20695 .19369 .21559 .20274 .22818 .19785 .21959 .18876 Metetra
.664 .741 .908 r
.21959 .18876 .22818 .19785 .24084 .19293 .23228 .1838 Metetra
.664 .741 .908 r
.23228 .1838 .24084 .19293 .25356 .188 .24504 .17882 Metetra
.664 .741 .908 r
.24504 .17882 .25356 .188 .26634 .18303 .25786 .17381 Metetra
.664 .741 .908 r
.25786 .17381 .26634 .18303 .27919 .17805 .27074 .16878 Metetra
.664 .741 .908 r
.27074 .16878 .27919 .17805 .2921 .17304 .28368 .16372 Metetra
.664 .741 .908 r
.28368 .16372 .2921 .17304 .293 .33216 .29669 .15864 Metetra
.517 .299 .522 r
.29669 .15864 .293 .33216 .30668 .32783 .30977 .15353 Metetra
.517 .299 .522 r
.30977 .15353 .30668 .32783 .32178 .30282 .32291 .1484 Metetra
.52 .304 .527 r
.32291 .1484 .32178 .30282 .33774 .26194 .33611 .14324 Metetra
.526 .318 .54 r
.33611 .14324 .33774 .26194 .35414 .20902 .34938 .13806 Metetra
.543 .355 .576 r
.34938 .13806 .35414 .20902 .37065 .14719 .36272 .13285 Metetra
.646 .639 .829 r
.36272 .13285 .37065 .14719 .38139 .19765 .37612 .12761 Metetra
.544 .357 .577 r
.37612 .12761 .38139 .19765 .39185 .26753 .3896 .12235 Metetra
.521 .307 .53 r
.3896 .12235 .39185 .26753 .41118 .12681 .40314 .11706 Metetra
.664 .741 .908 r
.40314 .11706 .41118 .12681 .42475 .12154 .41674 .11175 Metetra
.664 .741 .908 r
.41674 .11175 .42475 .12154 .43838 .11625 .43042 .10641 Metetra
.664 .741 .908 r
.43042 .10641 .43838 .11625 .45209 .11093 .44417 .10104 Metetra
.664 .741 .908 r
.44417 .10104 .45209 .11093 .46586 .10558 .45799 .09564 Metetra
.664 .741 .908 r
.45799 .09564 .46586 .10558 .4797 .10021 .47187 .09021 Metetra
.664 .741 .908 r
.47187 .09021 .4797 .10021 .49362 .09481 .48583 .08476 Metetra
.664 .741 .908 r
.48583 .08476 .49362 .09481 .5076 .08938 .49986 .07928 Metetra
.664 .741 .908 r
.49986 .07928 .5076 .08938 .52166 .08392 .51397 .07377 Metetra
.664 .741 .908 r
.51397 .07377 .52166 .08392 .53578 .07844 .52814 .06824 Metetra
.664 .741 .908 r
.52814 .06824 .53578 .07844 .54998 .07292 .54239 .06267 Metetra
.664 .741 .908 r
.54239 .06267 .54998 .07292 .56426 .06738 .55671 .05708 Metetra
.664 .741 .908 r
.55671 .05708 .56426 .06738 .57861 .06181 .57111 .05145 Metetra
.664 .741 .908 r
.57111 .05145 .57861 .06181 .59303 .05621 .58558 .0458 Metetra
.664 .741 .908 r
.58558 .0458 .59303 .05621 .60753 .05058 .60013 .04012 Metetra
.664 .741 .908 r
.60013 .04012 .60753 .05058 .6221 .04493 .61476 .0344 Metetra
.664 .741 .908 r
.61476 .0344 .6221 .04493 .63675 .03924 .62946 .02866 Metetra
.664 .741 .908 r
.62946 .02866 .63675 .03924 .65148 .03352 .64424 .02289 Metetra
.664 .741 .908 r
.64424 .02289 .65148 .03352 .66628 .02778 .6591 .01709 Metetra
.664 .741 .908 r
.6591 .01709 .66628 .02778 .68117 .022 .67403 .01125 Metetra
.664 .741 .908 r
.67403 .01125 .68117 .022 .69613 .01619 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-1)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.5)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.5)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00o?ooool4
o`000003oa0@4?oooooooooo06Gooooo003nooooo`03o`000?oooooooooo06Oooooo003nooooo`03
o`000?oooooooooo06Oooooo003nooooo`03o`000?oooooooooo06Oooooo003nooooo`03o`000?oo
oooooooo06Oooooo003nooooo`03o`000?oooooooooo06Oooooo003nooooo`03o`000?oooooooooo
00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Kooooo`00o?ooool00omEEEGoIVIVo`000009oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0Foooool00?oooooo2Oooool01Ol@413ooooooooooooooooo
410@05_ooooo003oooooo`Wooooo00Go0000ooooooooooooooooo`00001Kooooo`00ooooool9oooo
o`05o`000?ooooooooooooooool00000Foooool00?oooooo2Oooool01Ol@413ooooooooooooooooo
410@05_ooooo003oooooo`Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Kooooo`00ooooool3oooo
o`;o00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^05_ooooo003oooooo`?o000000?oooooo`00
0?ooool0Hoooool00?gooooo0_l00002ooooo`Co0000Hoooool00?[ooooo1ol00002ojVmj003o`00
0?oooooo000006;ooooo003gooooo`?o000000Goooooo`000?l0003oZKgXo`000004ojVmj0?o0000
H_ooool00?Gooooo0_l000001?oooooo0000o`000?l00004ojVmj004o`000?nY_NSoZKgXojVmj0Co
0000HOooool00?;ooooo0ol000001_oooooo0000o`000?l0003oZKgXo`0000GoZKgX00Co0000ojVm
j?l0003o00000_nY_NP2o`00063ooooo003`ooooo`;o00000_ooool2o`0000GoZKgX00?o0000ojVm
j?nY_NP00_nY_NP2o`000003ojVmj?l0003oZKgX00;oZKgX00?o0000ooooooooool0G_ooool00>go
oooo0ol000001_oooooo0000o`000?l0003oZKgXo`0000GoZKgX00?o0000ojVmj?l000000_l00000
1?nY_NSo0000ojVmj?l00003ojVmj0;o0000Goooool00>_ooooo0_l00002ooooo`;o00001OnY_NP0
0ol0003oZKgXojVmj002ojVmj0;o00001OnY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003o
000005kooooo002cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@0Oooooo`?o000000Koooooo`000?l0003o0000ojVmj?l00005ojVmj003
o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP01?nY_NP3o`0000CoZKgX00?o0000oooooooo
ool0G?ooool00;?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`0Kooooo`?o00000_ooool2o`0000GoZKgX00Co0000ojVmj?nY_NSoZKgX0ol00005ojVm
j003o`000?nY_NSo000000;o000000?oZKgXo`000?l000001?nY_NP2o`0005gooooo002cooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Hooooo`;o00000oooool2o`00
00;oZKgX00?o0000ojVmj?nY_NP00_nY_NP4o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP2o`00
00GoZKgX00?o0000ojVmj?nY_NP00_nY_NP3o`0005cooooo002cooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`0Fooooo`?o00000oooool2o`0000GoZKgX00Ko0000ojVm
j?l0003o0000ojVmj?l00005ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP01?nY
_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003o000005cooooo002cooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Gooooo0_l000000ooooooo0000
ooooo`03o`000003ojVmj?l0003oZKgX00CoZKgX0_l00004ojVmj003o`000?nY_NSoZKgX00;oZKgX
0_l00005ojVmj004o`000?nY_NSoZKgXojVmj0?o00001OnY_NP2o`0005_ooooo002cooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Dooooo`?o00000_ooool3o`0000Go
ZKgX00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj004ojVmj004o`000?nY_NSo0000o`00
00;oZKgX00?o0000ojVmj?nY_NP00_nY_NP4o`000003ojVmj?l0003o000000GoZKgX0ol0001Joooo
o`00/oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool2o`00
00;ooooo0ol00003ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00005ojVmj003o`000?nY_NSoZKgX
00;oZKgX0_l00005ojVmj006o`000?nY_NSo0000o`000?nY_NSo00000onY_NP01?l0003oZKgXo`00
0?nY_NP3o`000003ojVmj?l0003o000005[ooooo002cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`0000kooooo0ol000001_oooooo0000o`000?l0003oZKgXo`0000GoZKgX00Ko0000ojVm
j?l0003o0000ojVmj?l00005ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP01?nY
_NP2o`0000CoZKgX00Go0000ojVmj?nY_NSo0000ojVmj002o`0000GoZKgX0_l0001Iooooo`00dooo
ool3o`0000;ooooo0_l00005ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00004ojVmj004o`000?nY
_NSoZKgXojVmj0?o00001OnY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003oZKgX00CoZKgX
00Co0000ojVmj?l0003o00000_nY_NP00ol0003oZKgXojVmj002ojVmj0;o0000FOooool00=7ooooo
0_l00002ooooo`?o000000?oZKgXo`000?nY_NP01?nY_NP00ol0003oZKgXo`000002o`000003ojVm
j?l0003oZKgX00?oZKgX1?l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX0_l00005ojVmj003o`00
0?nY_NSoZKgX00;oZKgX0ol00004ojVmj003o`000?nY_NSoZKgX00Co0000F?ooool00<kooooo0ol0
0002ooooo`;o00001OnY_NP01?l0003oZKgXojVmj?nY_NP3o`0000GoZKgX00Ko0000ojVmj?l0003o
0000ojVmj?l00005ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP01?nY_NP00ol0
003oZKgXo`000002o`000003ojVmj?l0003o000000CoZKgX0ol00002ojVmj003o`000?oooooo0000
05Oooooo003<ooooo`;o00000oooool2o`0000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP4o`0000;o
ZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000CoZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`0000Go
ZKgX00Co0000ojVmj?nY_NSoZKgX0ol00005ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`00
0?nY_NP00onY_NP2o`0005Oooooo0039ooooo`?o00000_ooool3o`0000GoZKgX00Ko0000ojVmj?l0
003o0000ojVmj?l00005ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP01?nY_NP0
1?l0003oZKgXo`000?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX1?l00002ojVmj003o`000?nY
_NSoZKgX00?oZKgX0_l00005ojVmj004o`000?nY_NSoZKgXojVmj0?o0000E_ooool00<Oooooo0_l0
00000ooooooo0000o`000002o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000CoZKgX00?o
0000ojVmj?nY_NP00_nY_NP2o`0000GoZKgX00Co0000ojVmj?nY_NSoZKgX0ol00005ojVmj006o`00
0?nY_NSo0000o`000?nY_NSo00001OnY_NP00ol0003oZKgXo`000004o`0000GoZKgX00Co0000ojVm
j?l0003o00000_nY_NP2o`0005Gooooo0034ooooo`?o000000Goooooo`000?l0003oZKgXo`000005
ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP01?nY_NP01?l0003oZKgXo`000?l0
0002ojVmj003o`000?nY_NSoZKgX00;oZKgX1?l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX0_l0
0004ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00004ojVmj0;o00000onY_NP3o`0000GoZKgX00?o
0000ooooooooool0Doooool00<;ooooo0_l00002ooooo`;o00001?nY_NP00ol0003oZKgXojVmj002
ojVmj0;o00001OnY_NP01?l0003oZKgXojVmj?nY_NP3o`0000GoZKgX00Ko0000ojVmj?l0003o0000
ojVmj?l00005ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP01?nY_NP01_l0003o
ZKgXo`000?l0003oZKgXo`0000CoZKgX1Ol00002ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol0001C
ooooo`00_oooool3o`000006ooooool0003o0000o`000?nY_NSo00001OnY_NP01?l0003oZKgXo`00
0?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX1?l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX
0_l00004ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00005ojVmj004o`000?nY_NSoZKgXojVmj0?o
00001?nY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003oZKgX00CoZKgX00?o0000ojVmj?l0
00000_l000000onY_NSo0000o`00001Cooooo`00_?ooool3o`000004ooooool0003o0000o`0000Go
ZKgX00Co0000ojVmj?nY_NSoZKgX0ol00005ojVmj006o`000?nY_NSo0000o`000?nY_NSo00001OnY
_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003oZKgX00CoZKgX00Ko0000ojVmj?l0003o0000
ojVmj?l00005ojVmj0Co00000_nY_NP00ol0003oZKgXojVmj002ojVmj0;o00000_nY_NP01?l0003o
ZKgXojVmj?l00004ojVmj0;o00001OnY_NP00ol0003oooooooooo`1Aooooo`00^_ooool2o`0000?o
oooo0_l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX1?l00002ojVmj003o`000?nY_NSoZKgX00?o
ZKgX0_l00004ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00005ojVmj004o`000?nY_NSoZKgXojVm
j0?o00001?nY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003oZKgX00CoZKgX00Co0000ojVm
j?l0003o00000_nY_NP00ol0003oZKgXo`000002ojVmj003o`000?nY_NSo000000;o000000?oZKgX
o`000?nY_NP01?nY_NP2o`0005;ooooo002gooooo`?o00000_ooool3o`0000GoZKgX00Ko0000ojVm
j?l0003o0000ojVmj?l00005ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP01?nY
_NP01_l0003oZKgXo`000?l0003oZKgXo`0000GoZKgX1?l00002ojVmj003o`000?nY_NSoZKgX00;o
ZKgX0_l00005ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00005ojVmj0;o000000CoZKgXo`000?l0
003o00001OnY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003o0000057ooooo002eooooo`;o
000000?oooooo`000?l000000_l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX0_l00004ojVmj003
o`000?nY_NSoZKgX00;oZKgX0_l00005ojVmj004o`000?nY_NSoZKgXojVmj0?o00001?nY_NP00ol0
003oZKgXo`000002o`000003ojVmj?l0003oZKgX00CoZKgX00Co0000ojVmj?l0003o00000_nY_NP0
0ol0003oZKgXojVmj002ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP01?nY_NP3
o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000GoZKgX00?o0000ooooooooool0Coooool0
08_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Rooooo`?o000000Goooooo`000?l0003oZKgXo`00
0005ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP01?nY_NP01?l0003oZKgXo`00
0?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX1?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX
0_l00005ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00005ojVmj003o`000?nY_NSoZKgX00?o0000
1OnY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003oZKgX00?oZKgX00?o0000ojVmj?l00000
0_l000000onY_NSo0000ojVmj004ojVmj0;o0000D?ooool008_ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Pooooo`;o00000_ooool2o`0000CoZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`0000GoZKgX
00Co0000ojVmj?nY_NSoZKgX0ol00005ojVmj006o`000?nY_NSo0000o`000?nY_NSo00001OnY_NP0
1?l0003oZKgXo`000?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX00?o0000ojVmj?l000000_l0
00000onY_NSo0000ojVmj004ojVmj0?o00000_nY_NP00ol0003oZKgXojVmj003ojVmj0;o00001?nY
_NP2o`0000;oZKgX0ol00005ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?l00000Cooo
ool008_ooooo00Go410@oooooooooooooooooa0@400Mooooo`?o00000_ooool2o`0000;oZKgX00?o
0000ojVmj?nY_NP00_nY_NP01?l0003oZKgXo`000?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX
1?l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX0_l00004ojVmj003o`000?nY_NSoZKgX00;oZKgX
0_l00005ojVmj003o`000?nY_NSoZKgX00?o00001OnY_NP00ol0003oZKgXo`000002o`000003ojVm
j?l0003oZKgX00?oZKgX00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj003ojVmj0Co0000
0onY_NP00ol0003oZKgXojVmj002ojVmj0;o00001OnY_NP00ol0003oooooooooo`1=ooooo`00Rooo
ool01Ol0003ooooooooooooooooo000001[ooooo0ol00003ooooo`;o00001OnY_NP00ol0003oZKgX
ojVmj003o`0000GoZKgX00Co0000ojVmj?l0003o00000_nY_NP00ol0003oZKgXojVmj002ojVmj003
o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP00onY_NP00ol0003oZKgXo`000002o`000003
ojVmj?l0003oZKgX00CoZKgX0ol00003ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00005ojVmj003
o`000?nY_NSoZKgX00?o00001OnY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003oZKgX00Co
ZKgX00Ko0000ojVmj?l0003o0000ojVmj?l00005ojVmj0;o0000C_ooool008_ooooo00Go0000oooo
ooooooooooooo`00000Hooooo`?o00000_ooool3o`000003ojVmj?l0003oZKgX00CoZKgX0ol00002
ojVmj003o`000?nY_NSoZKgX00?oZKgX0_l00005ojVmj003o`000?nY_NSoZKgX00?o00001OnY_NP0
0ol0003oZKgXojVmj003o`0000GoZKgX00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj004
ojVmj006o`000?nY_NSo0000o`000?nY_NSo00001OnY_NP3o`0000?oZKgX00?o0000ojVmj?nY_NP0
0_nY_NP2o`0000;oZKgX00Co0000ojVmj?nY_NSo00001?nY_NP2o`0000CoZKgX00Co0000ojVmj?nY
_NSoZKgX1?l0001=ooooo`00Roooool01Ol@413ooooooooooooooooo410@01Gooooo0ol00002oooo
o`?o00001OnY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003oZKgX00?oZKgX00?o0000ojVm
j?l000000_l000000onY_NSo0000ojVmj004ojVmj0?o00000onY_NP00ol0003oZKgXojVmj002ojVm
j0?o00000onY_NP00ol0003oZKgXojVmj002ojVmj0;o00001OnY_NP01?l0003oZKgXojVmj?nY_NP3
o`0000CoZKgX00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj004ojVmj006o`000?nY_NSo
0000o`000?nY_NSo00000_nY_NP01Ol0003oZKgXojVmj?l0003oZKgX00?o000000?oZKgXo`000?nY
_NP00onY_NP4o`0000;oZKgX0_l0001=ooooo`00Roooool01OmgMgOoV9RHoooooonHV9SoMgMg01?o
oooo0_l00002ooooo`?o00000onY_NP00ol0003oZKgXojVmj002ojVmj0;o00001OnY_NP00ol0003o
ZKgXojVmj003o`0000GoZKgX00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj004ojVmj006
o`000?nY_NSo0000o`000?nY_NSo00001OnY_NP01?l0003oZKgXo`000?l00002ojVmj003o`000?nY
_NSoZKgX00;oZKgX1?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00005ojVmj003o`000?nY
_NSoZKgX00;oZKgX0_l00004ojVmj004o`000?nY_NSo0000ojVmj0?o00001OnY_NP01_l0003oZKgX
o`000?l0003oZKgXo`0000GoZKgX0_l0001<ooooo`00Roooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
013ooooo0ol00002ooooo`;o000000?oQDj7o`000?nY_NP01?nY_NP01?l0003oZKgXo`000?l00002
ohA;Q003o`000?nY_NSoZKgX00;oZKgX0ol00003ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00005
ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00004ojVmj004o`000?nY_NSoZKgXojVmj0?o00001OnY
_NP01_l0003oZKgXo`000?l0003oZKgXo`0000GoZKgX00Co0000ojVmj?l0003o00000_nY_NP00ol0
003oZKgXojVmj002ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP00onY_NP4o`00
00;oZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000CoZKgX00Co0000ojVmj?nY_NSoZKgX1?l0001;
ooooo`00W_ooool2o`0000?ooooo0_l00004ohE>Q`04o`000?nY_NSoZKgXojVmj0?o00001On4Bh@0
1_l0003oZKgXo`000?l0003oQDf6o`0000GoZKgX00Co0000ojVmj?l0003o00000_nY_NP00ol0003o
ZKgXojVmj002ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP00onY_NP4o`0000;o
ZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000CoZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`0000Go
ZKgX00?o0000ojVmj?nY_NP00ol00005ojVmj005o`000?nY_NSo0000o`000?nY_NP00_l00004ojVm
j003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP00onY_NP4o`0000;oZKgX0_l0001;oooo
o`00Voooool3o`0000;ooooo0ol000000on;Fi?o0000ohE>Q`04ohE>Q`?o00000_n5CXL00ol0003o
Q4^4ohA;Q004ohA;Q003o`000?n5CHKoQDf600;oQDf600?o0000ojVmj?nY_NP00_nY_NP2o`0000Go
ZKgX00?o0000ojVmj?nY_NP00ol00005ojVmj004o`000?nY_NSo0000o`0000;oZKgX00?o0000ojVm
j?nY_NP00_nY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003oZKgX00?oZKgX00?o0000ojVm
j?l000000_l000000onY_NSo0000ojVmj004ojVmj0?o00000_nY_NP00ol0003oZKgXojVmj003ojVm
j0;o00001?nY_NP2o`0000;oZKgX0ol00005ojVmj006o`000?nY_NSo0000o`000?nY_NSo00001OnY
_NP2o`0004[ooooo002Hooooo`?o00000_ooool3o`0000CoRe^C00?o0000ohE>Qon5CXL00on5CXL0
0ol0003oQDj7ohE>Q`02ohE>Q`03o`000?n4BhCoQ4^400CoQ4^400?o0000ohE=Q_n5CHH00_n5CHH0
0ol0003oZKgXo`000002o`000003ohI@R?l0003oZKgX00CoZKgX0ol00002ojVmj003o`000?nY_NSo
ZKgX00?oZKgX0_l00005ojVmj003o`000?nY_NSoZKgX00?o00001OnY_NP00ol0003oZKgXojVmj003
o`0000GoZKgX00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj003ojVmj003o`000?nY_NSo
000000;o000000?oZKgXo`000?nY_NP00onY_NP4o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP2
o`0000CoZKgX00?o0000ojVmj?nY_NP00_nY_NP3o`0004Wooooo002Fooooo`;o00000_ooool3o`00
00;oYJ?D00?o0000oh]KTon;Fi<00_n;Fi<00ol0003oQDj7ohE>Q`03ohE>Q`03o`000?n5CXOoQDj7
00;oQDj700?o0000ohA;Q?n4Bh@01?n4Bh@00ol0003oQDf6ohE=QP03ohE=QP03o`000?n6D8SoQU28
00?oQU2800?o0000ojVmj?l000000_l000000on8E8co0000ojVmj003ojVmj003o`000?nY_NSo0000
00;o000000?oZKgXo`000?nY_NP01?nY_NP3o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP3o`00
00?oZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`0000GoZKgX00?o0000ojVmj?nY_NP00ol00005ojVm
j005o`000?nY_NSo0000o`000?nY_NP00_l00004ojVmj003o`000?nY_NSo000000;o000000?oZKgX
o`000?nY_NP00onY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003o000004Wooooo002Coooo
o`?o00000_ooool2o`000003oh]JTol0003oYJ?D00;oYJ?D00?o0000oh]KTon;Fi<00_n;Fi<00ol0
003oQDj7ohE>Q`03ohE>Q`03o`000?n5CXOoQDj700;oQDj700?o0000ohA;Q?n4Bh@01?n4Bh@00ol0
003oQDf6ohE=QP03ohE=QP03o`000?n6D8SoQU2800CoQU2800?o0000ohQDS?n8E8`00on8E8`00ol0
003oZKgXojVmj003o`0000GoZKgX00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj003ojVm
j003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP01?nY_NP01_l0003oZKgXo`000?l0003o
ZKgXo`0000GoZKgX0ol00002ojVmj003o`000?nY_NSoZKgX00?oZKgX0_l00003ojVmj003o`000?nY
_NSo000000;oZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00?o00001OnY_NP2o`0004Sooooo002A
ooooo`;o00000_ooool3o`0000CoReZC00Co0000ojFSe?nUXmCo00001?n;Fi<00ol0003oQDj7ohE>
Q`03ohE>Q`03o`000?n5CXOoQDj700;oQDj700?o0000ohA;Q?n4Bh@01?n4Bh@00ol0003oQDf6ohE=
QP03ohE=QP03o`000?n6D8SoQU2800CoQU2800?o0000ohQDS?n8E8`01?n8E8`2o`0000?oReVA00?o
0000ojVmj?nY_NP00_nY_NP2o`0000GoZKgX00?o0000ojVmj?nY_NP00ol00005ojVmj004o`000?nY
_NSoZKgXojVmj0?o00001?nY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003oZKgX00?oZKgX
00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj002ojVmj003o`000?nY_NSo000000;o0000
0_nY_NP00ol0003oZKgXojVmj003ojVmj0?o00000_nY_NP00ol0003oZKgXojVmj003ojVmj0?o0000
Aoooool008kooooo0ol00002ooooo`Go00001?n;FY<01?l0003oYJ?DojFSe?l00004oh]KT`03o`00
0?n5CXOoQDj700;oQDj70_l00004ohE>Q`03o`000?n4BhCoQ4^400CoQ4^400?o0000ohE=Q_n5CHH0
0on5CHH00ol0003oQU28ohI@R004ohI@R003o`000?n8E8coR5B<00CoR5B<00?o0000oh]ITOn;FI40
0on;FI401?l0003oZKgXo`000?l00002ohiOUP03o`000?nY_NSoZKgX00;oZKgX0ol00003ojVmj003
o`000?nY_NSoZKgX00;oZKgX1?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00005ojVmj003
o`000?nY_NSoZKgX00?o00001OnY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003oZKgX00?o
ZKgX00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj003ojVmj003o`000?nY_NSo000000;o
000000?oZKgXo`000?l00000Aoooool008cooooo0_l00002ooooo`?o00001?n6DHX00ol0003oReZC
oh]JT`02oh]JT`04o`000?nUXmCoYJ?Do`0000CoRe^C00?o0000ohE>Qon5CXL00_n5CXL2o`0000Co
QDj700?o0000ohA;Q?n4Bh@00on4Bh@2o`0000GoQDf600?o0000ohI@R?n6D8P01?n6D8P00ol0003o
R5B<ohQDS004ohQDS003o`000?n;FI7oReVA00CoReVA00?o0000ohiOU_n>GiH00on>GiH01_l0003o
ZKgXo`000?l0003oZKgXo`0000GoZKgX00Ko0000ojVmj?l0003o0000ojVmj?l00005ojVmj006o`00
0?nY_NSo0000o`000?nY_NSo00001OnY_NP3o`0000?oZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`00
0003ojVmj?l0003oZKgX00;oZKgX00Co0000ojVmj?nY_NSoZKgX0_l00005ojVmj003o`000?nY_NSo
ZKgX00?o00001OnY_NP2o`0004Kooooo0029ooooo`?o000000Coooooo`000?l0003o00000_n5CHH0
0ol0003oQU6:ohIARP02ohIARP03o`000?n;FY?oReZC00?oReZC00Co0000ojFSe?nUXmCo00000on;
Fi<00ol0003oQDj7ohE>Q`02ohE>Q`;o00001?n5CXL00ol0003oQ4^4ohA;Q003ohA;Q0;o00001On5
CHH00ol0003oQU28ohI@R004ohI@R003o`000?n8E8coR5B<00CoR5B<00?o0000oh]ITOn;FI401?n;
FI400ol0003oSUnFohiOUP04ohiOUP03o`000?nY_NSoZKgX00;oZKgX00?o0000ojVmj?nY_NP00_nY
_NP2o`0000CoZKgX00Co0000ojVmj?nY_NSoZKgX0ol00004ojVmj003o`000?nY_NSo000000;o0000
00?oZKgXo`000?nY_NP01?nY_NP02?l0003oZKgXo`000?l0003oZKgXo`000?nY_NSo00000onY_NP0
1_l0003oZKgXo`000?l0003oZKgXo`0000GoZKgX0ol00002ojVmj003o`000?nY_NSoZKgX00?oZKgX
0ol00015ooooo`00Q_ooool3o`0000;ooooo0_l000000on4C8Go0000ohE=QP02ohE=QP03o`000?n6
DH[oQU6:00;oQU6:00?o0000oh]JTon;FY<00on;FY<01?l0003oYJ?DojFSe?l00003oh]KT`03o`00
0?n5CXOoQDj700;oQDj70_l00004ohE>Q`03o`000?n4BhCoQ4^400?oQ4^40_l00005ohE=QP03o`00
0?n6D8SoQU2800CoQU2800?o0000ohQDS?n8E8`01?n8E8`00ol0003oReVAoh]IT@04oh]IT@03o`00
0?n>GiKoSUnF00CoSUnF00?o0000ojVmj?nY_NP00_nY_NP00ol0003oZKgXo`000002o`000003ojVm
j?l0003oZKgX00?oZKgX1?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00005ojVmj004o`00
0?nY_NSoZKgXojVmj0?o00001?nY_NP2o`0000;oZKgX0ol00004ojVmj003o`000?nY_NSo000000;o
000000?oZKgXo`000?nY_NP00onY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003o000004Go
oooo0024ooooo`;o00000oooool2o`0000?oQ4b500Go0000ohE=Q_n5CHKoQDf6o`000004ohIARP03
o`000?n;FY?oReZC00?oReZC00Co0000ojFSe?nUXmCo00000on;Fi<00ol0003oQDj7ohE>Q`02ohE>
Q`;o00001?n5CXL00ol0003oQ4^4ohA;Q003ohA;Q0;o00001?n5CHH2o`0000GoQU280_l00005ohQD
S0;o00001_n;FI400ol0003oSUnFohiOUP04ohiOUP;o00000_nY_NP3o`0000GoZKgX00Co0000ojVm
j?l0003o00000_nY_NP00ol0003oZKgXojVmj002ojVmj004o`000?nY_NSo0000o`0000;oZKgX00?o
0000ojVmj?nY_NP00_nY_NP4o`0000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP4o`0000;oZKgX00?o
0000ojVmj?nY_NP00_nY_NP2o`0000GoZKgX00?o0000ojVmj?nY_NP00ol00005ojVmj0;o0000A?oo
ool0087ooooo0ol00003ooooo`;o000000?oQ4b5o`000?n4C8D00_n4C8D01Ol0003oQDf6ohE=Q_n5
CHKo000000CoQU6:00?o0000oh]JTon;FY<00_n;FY<01Ol0003oom><o`000?nUXmCo000000?oRe^C
00?o0000ohE>Qon5CXL00_n5CXL2o`0000CoQDj700?o0000ohA;Q?n4Bh@00on4Bh@2o`0000CoQDf6
0_l00005ohI@R0;o00001On8E8`2o`0000GoReVA0_l00005ohiOUP03o`000?oZdE[oj]5J00;o0000
0onGMJ/00ol0003oZKgXojVmj002ojVmj0;o00001OnY_NP00ol0003oZKgXojVmj003o`0000GoZKgX
00Ko0000ojVmj?l0003o0000ojVmj?l00005ojVmj006o`000?nY_NSo0000o`000?nY_NSo00001OnY
_NP01_l0003oZKgXo`000?l0003oZKgXo`0000GoZKgX0ol00002ojVmj003o`000?nY_NSoZKgX00?o
ZKgX0ol00013ooooo`00BOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd08?ooool2o`0000?ooooo0ol00003ohA<Q@05o`000?n4C8GoQ4b5
ohA<QOl000000on5CHH00ol0003oQU6:ohIARP02ohIARP03o`000?n;FY?oReZC00;oReZC00Go0000
oooCS?l0003oYJ?Do`000003oh]KT`03o`000?n5CXOoQDj700;oQDj70_l00004ohE>Q`03o`000?n4
BhCoQ4^400?oQ4^40_l00004ohE=QP;o00001On6D8P2o`0000GoR5B<0_l00005oh]IT@;o00001On>
GiH01?l0003oj]5Jon[AF_l00005oiMeZ`06o`000?nY_NSo0000o`000?nGM:Wo00001OnY_NP3o`00
00;oZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000CoZKgX00Co0000ojVmj?nY_NSoZKgX0ol00003
ojVmj0;o00000onY_NP3o`0000CoZKgX00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj003
ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?l00000@oooool004Wooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Looooo`?o00000_ooool3
o`0000;oZKgX00Go0000ohA<QOn4C8GoQ4b5o`000003ohA<Q@05o`000?n5CHKoQDf6ohE=Q_l00000
1?n6DHX00ol0003oReZCoh]JT`02oh]JT`05o`000?oodhco0000ojFSe?l000000on;Fi<01ol0003o
QDj7ohE>Qon5CXOo0000oo_:H_l000001?n5CXL00ol0003oQ4^4ohA;Q003ohA;Q0;o00001?n5CHH2
o`0000GoQU280_l00005ohQDS003o`000?oYa4Oo000000CoReVA00?o0000onK8C?l000001?n>GiH0
1?l0003oj]5Jo`000?l00006oiMeZ`03o`000?nGM:WoUgBY00;oUgBY00?o0000ojVmj?l000000_l0
00000onY_NSo0000ojVmj003ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP00onY
_NP4o`0000;oZKgX00Co0000ojVmj?nY_NSoZKgX1Ol00002ojVmj003o`000?nY_NSoZKgX00;oZKgX
0_l00005ojVmj003o`000?nY_NSoZKgX00?o00001OnY_NP2o`0004;ooooo0011ooooo`Ko00000_oo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool06Oooool2o`0000?ooooo
0_l000000onY_NSo0000ojVmj002ojVmj005o`000?n4C8GoQ4b5ohA<QOl000000on4C8D01Ol0003o
QDf6ohE=Q_n5CHKo000000CoQU6:00?o0000oh]JTon;FY<00_n;FY<01Ol0003oom><o`000?nUXmCo
000000?oRe^C00Oo0000ohE>Qon5CXOoQDj7o`000?okbV;o000000CoQDj700?o0000ohA;Q?n4Bh@0
0on4Bh@2o`0000CoQDf60_l00005ohI@R003o`000?o^`dWo000000CoR5B<00?o0000onW4Aol00000
1?n;FI400ol0003oi/Q<o`000004ohiOUP04o`000?oZdE[o0000o`0000KoUgF[00?o0000oiMdZOnG
M:T00onGM:T00ol0003oZKgXojVmj003ojVmj003o`000?nY_NSoZKgX00?o00001OnY_NP01_l0003o
ZKgXo`000?l0003oZKgXo`0000GoZKgX00Ko0000ojVmj?l0003o0000ojVmj?l00005ojVmj006o`00
0?nY_NSo0000o`000?nY_NSo00001OnY_NP3o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP2o`00
04;ooooo0019ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Goooo
o`?o00000_ooool3o`0000CoZKgX00Co0000ojVmj?nY_NSo00000on4C8D01Ol0003oQ4b5ohA<QOn4
C8Go000000?oQDf600?o0000ohIAR_n6DHX00_n6DHX01Ol0003oReZCoh]JTon;FY?o000000?oom><
0_l00003oh]KT`07o`000?n5CXOoQDj7ohE>Qol0003onlYRo`000004ohE>Q`03o`000?n4BhCoQ4^4
00?oQ4^40_l00004ohE=QP;o00001On6D8P00ol0003ok/=9o`000004ohQDS003o`000?oYa4Oo0000
00CoReVA00?o0000onK8C?l000000on>GiH01_l0003oj]5Jon[AF_l0003oe=i/o`0000CoUgF[0_l0
0005oiMdZ@03o`000?nY_NSoZKgX00?oZKgX0ol00002ojVmj003o`000?nY_NSoZKgX00?oZKgX0_l0
0004ojVmj004o`000?nY_NSoZKgXojVmj0?o000000GoZKgXo`000?nY_NSoZKgXo`000003ojVmj0?o
00001?nY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003oZKgX00?oZKgX00?o0000ojVmj?l0
00000_l000000onY_NSo0000o`000008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Sooooo`00BOooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Eooooo`?o000000?oooooo`000?l000000_l0
0002ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l000000onY_NSo0000ohA<Q@02ohA<Q@05o`000?n4
C8GoQ4b5ohA<QOl000000on5CHH00ol0003oQU6:ohIARP02ohIARP05o`000?n;FY?oReZCoh]JTol0
00000ooodh`2o`0000?oRe^C00Oo0000ohE>Qon5CXOoQDj7o`000?okbV;o000000CoQDj700?o0000
ohA;Q?n4Bh@00on4Bh@2o`0000CoQDf600?o0000oo?3C_l000001?n6D8P00ol0003ok/=9o`000004
ohQDS003o`000?oYa4Oo000000?oReVA00Co0000onK8C?oVb4co00000on>GiH00ol0003oj]5Jo`00
0002omCNK003o`000?nGMJ_oUgF[00;oUgF[00?o0000on_^Sol000000onGM:T01?l0003on>bMo`00
0?nY_NP3o`000003oi]o]?l0003oZKgX00?oZKgX00?o0000ojVmj?l000000_l000000onY_NSo0000
ojVmj003ojVmj0Co00000_nY_NP00ol0003oZKgXo`000002ojVmj0Co00000onY_NP00ol0003oZKgX
ojVmj003o`0000GoZKgX00?o0000ojVmj?nY_NP00ol00005ojVmj0;o00001oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo02;ooooo0019ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Eooooo`;o00000_ooool2o`0000;o
ZKgX00?o0000ojVmj?nY_NP00_nY_NP02?l0003oZKgXo`000?l0003oSV6Io`000?nY_NSo00000on4
C8D01Ol0003oQ4b5ohA<QOn4C8Go000000?oQDf600?o0000ohIAR_n6DHX00on6DHX01?l0003oReZC
oh]JTol00002oooCS0?o00000on;Fi<01ol0003oQDj7ohE>Qon5CXOo0000oo_:H_l000001?n5CXL0
0ol0003oQ4^4ohA;Q002ohA;Q003o`000?og`e?o000000CoQDf600?o0000oo?3C_l000001?n6D8P0
0ol0003ok/=9o`000003ohQDS004o`000?oYa4OojLA7o`0000?oReVA00Co0000onK8C?oVb4co0000
0on>GiH00ol0003oj]5Jo`000002omCNK005o`000?nGMJ_oUgF[oiMeZol000000_o[kXl01Ol0003o
UgBYoiMdZOnGM:Wo000000;on>bM00?o0000oi]o]?nKOk@00onKOk@00ol0003oZKgXojVmj003o`00
00GoZKgX00Ko0000ojVmj?l0003o0000ojVmj?l00005ojVmj006o`000?nY_NSo0000o`000?nY_NSo
00001OnY_NP3o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000;oZKgX00?o0000ojVmj?nY
_NP00onY_NP2o`0000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo
027ooooo0019ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Boooo
o`?o00000_ooool2o`0000GoZKgX00?o0000ojVmj?nY_NP00ol00003ohiQV@03o`000?nY_NSo0000
00?oQ4b500Go0000ohA<QOn4C8GoQ4b5o`000003ohE=QP03o`000?n6DH[oQU6:00?oQU6:00Co0000
oh]JTon;FY?o00000_oodh`3o`0000?oRe^C00Oo0000ohE>Qon5CXOoQDj7o`000?okbV;o000000Co
QDj700?o0000ohA;Q?n4Bh@00_n4Bh@00ol0003oml=Co`000004ohE=QP03o`000?oc`dko000000Co
QU2800?o0000onk3BOl000000on8E8`01?l0003ojLA7onW4Aol00003oh]IT@04o`000?oVb4coi/Q<
o`0000?oSUnF00?o0000on[AF_l000000_oDgV`01?l0003oUgF[oiMeZol00003on_^S`04o`000?nG
M:WoUgBYo`0000?on>bM00?o0000oi]o]?nKOk@01?nKOk@2o`0000?oZKgX00?o0000ojVmj?nY_NP0
0_nY_NP2o`0000CoZKgX00Co0000ojVmj?nY_NSoZKgX1?l00003ojVmj003o`000?nY_NSo000000;o
000000?oZKgXo`000?nY_NP00onY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003oZKgX00?o
ZKgX00?o0000ojVmj?l000000_l000000onY_NSo0000o`000006ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`0Rooooo`00BOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l0000?ooooo`;o00000oooool2o`0000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP3o`00
00;oZKgX00Oo0000ohiQVOn>HIWoSV6Io`000?nY_NSo000000?oQ4b500Go0000ohA<QOn4C8GoQ4b5
o`000003ohE=QP03o`000?n6DH[oQU6:00?oQU6:00?o0000oh]JTol000000_oodh`00ol0003ooN2I
oogPV@02o`0000;oRe^C00Oo0000ohE>Qon5CXOoQDj7o`000?okbV;o000000CoQDj700?o0000ohA;
Q?n4Bh@00_n4Bh@00ol0003oml=Co`000004ohE=QP03o`000?oc`dko000000?oQU2800Co0000onk3
BOo^`dWo00000on8E8`01?l0003ojLA7onW4Aol00003oh]IT@04o`000?oVb4coi/Q<o`0000;oSUnF
00?o0000on[AF_l000000_l000001OoDgVco0000oiMeZonGMJ_o000000?ojnj?00Co0000oiMdZOnG
M:Wo00000_ohk9d00ol0003ojOW8o`000005oi]o]003o`000?nY_NSoZKgX00?oZKgX00Ko0000ojVm
j?l0003o0000ojVmj?l00004ojVmj0Co00000_nY_NP2o`0000?oZKgX0_l00005ojVmj003o`000?nY
_NSoZKgX00?o00001OnY_NP00ol0003oZKgXojVmj003o`0000GoZKgX0_l00005ooooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<02?ooooo001Zooooo`?o0000
0_ooool4o`0000CoZKgX00Co0000ojVmj?l0003o00000_nY_NP01?l0003oZKgXojVmj?l00003ohiQ
V@03o`000?nY_NSo000000?oQ4b500Go0000ohA<QOn4C8GoQ4b5o`000003ohE=QP03o`000?n6DH[o
QU6:00?oQU6:00?o0000oh]JTol000000_oodh`00ol0003ooN2IoogPV@02o`0000;oRe^C00Oo0000
ohE>Qon5CXOoQDj7o`000?okbV;o000000CoQDj700?o0000ohA;Q?n4Bh@00_n4Bh@00ol0003oml=C
o`000004ohE=QP03o`000?oc`dko000000?oQU2800Co0000onk3BOo^`dWo00000on8E8`01?l0003o
jLA7onW4Aol00003oh]IT@04o`000?oVb4coi/Q<o`0000;oSUnF00Co0000on[AF_l0003o[9>l0_l0
00000ooDgVco0000o`000003o`000007on_^Sol0003oUgBYoiMdZOl0003on>bMo`000002onWib003
o`000?nKOkCoVgnd00;oVgnd00?o0000oo?c^?l000000onY_NP3o`0000CoZKgX00Co0000ojVmj?l0
003o00000_nY_NP00ol0003oZKgXojVmj002ojVmj006o`000?nY_NSo0000o`000?nY_NSo00001OnY
_NP3o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000;oZKgX00?o0000ojVmj?nY_NP00onY
_NP2o`0000Gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo02Gooooo
001Xooooo`;o00000_ooool3o`0000CoZKgX00?o0000ojVmj?nY_NP00ol00005ojVmj003o`000?nY
_NSo000000?oSV6I00?o0000ojVmj?l000000on4C8D01Ol0003oQ4b5ohA<QOn4C8Go000000?oQDf6
00?o0000ohIAR_n6DHX00on6DHX00ol0003oReZCo`000002oooCS003o`000?omh9WooN2I00;o0000
0_n;Fi<01?l0003oQDj7ohE>Qol00002oo_:HP03o`000?n5CXOoQDj700;oQDj700?o0000ohA;Q?n4
Bh@00_n4Bh@00ol0003oml=Co`000003ohE=QP04o`000?oc`dkoll=>o`0000?oQU2800Co0000onk3
BOo^`dWo00000on8E8`01?l0003ojLA7onW4Aol00002oh]IT@05o`000?oVb4coi/Q<onK8C?l00000
0_n>GiH00ol0003oj]5Jo`000002ojbC_0Co00000onTUlP01_l0003ojnj?o`000?l0003on>bMo`00
00?ojOW800?o0000oi]o]?nKOk@00_nKOk@00ol0003olo>hoo?c^003o`0000?oYIk?00?o0000ojVm
j?nY_NP00ol00005ojVmj003o`000?nY_NSoZKgX00?o00001?nY_NP00ol0003oZKgXo`000002o`00
0003ojVmj?l0003oZKgX00?oZKgX00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj003ojVm
j003o`000?nY_NSo000000;o000000?oZKgXo`000?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool09Oooool006Gooooo0ol00002ooooo`;o00000_nY_NP00ol0
003oZKgXojVmj002ojVmj0?o00000onY_NP00ol0003oZKgXojVmj002ojVmj0?o00000on>HIT00ol0
003oZKgXo`000003ohA<Q@05o`000?n4C8GoQ4b5ohA<QOl000000on5CHH00ol0003oQU6:ohIARP03
ohIARP05o`000?n;FY?o0000oooCS?l000000_omh9T3o`0000;oRe^C00Co0000ohE>Qon5CXOo0000
0_okbV800ol0003oQDj7ohE>Q`02ohE>Q`03o`000?n4BhCoQ4^400;oQ4^400?o0000ooO3Dol00000
0on5CHH01?l0003oll=>oo?3C_l00003ohI@R004o`000?o^`dWok/=9o`0000?oR5B<00Co0000onW4
AooYa4Oo00000_n;FI401Ol0003oi/Q<onK8C?oVb4co000000;oSUnF0_l00003ojbC_003o`000?nT
UlSo000000CoY9O82?l00002onWib004o`000?nKOkCoVgndo`0000;olo>h0_l00005ojFNc`?o0000
0_nY_NP00ol0003oZKgXojVmj003ojVmj0?o000000?oZKgXo`000?l000001?nY_NP2o`0000GoZKgX
00?o0000ojVmj?nY_NP00ol00005ojVmj003o`000?nY_NSoZKgX00?o00001OnY_NP2o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00009?ooool006?ooooo0_l00002ooooo`?o0000
1OnY_NP01?l0003oZKgXo`000?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX00So0000ojVmj?l0
003o0000ojVmj?l0003oZKgXo`0000;oSV6I00?o0000ojVmj?l000000on4C8D01Ol0003oQ4b5ohA<
QOn4C8Go000000?oQDf600?o0000ohIAR_n6DHX00on6DHX2o`0000;oom><00?o0000oogPVOomh9T0
0ol00002oh]KT`04o`000?n5CXOoQDj7o`0000;onlYR00?o0000ohE>Qon5CXL00_n5CXL00ol0003o
Q4^4ohA;Q002ohA;Q003o`000?og`e?o000000?oQDf600Co0000oo?3C_oc`dko00000on6D8P01?l0
003ok/=9onk3BOl00003ohQDS004o`000?oYa4OojLA7o`0000;oReVA00Wo0000onK8C?oVb4coi/Q<
o`000?n>GiKo0000on[AF_l000000_n/Tk`00ol0003od[Jmo`000004ojBGb004o`000?oH_l3o0000
o`0000;oGWOD0_l000001_l0C<Ko0000o`000?l0003oVgndo`0000;olo>h00Co0000om_cgooKlmoo
00000onUW/l00ol0003ocmSPo`000004ojVmj003o`000?nY_NSo000000;o000000SoZKgXo`000?nY
_NSoZKgXo`000?nY_NSo0000ojVmj0;o000000?oZKgXo`000?nY_NP01?nY_NP3o`0000;oZKgX00?o
0000ojVmj?nY_NP00onY_NP3o`0000?oZKgX00Co0000ojVmj?nY_NSoZKgX0ol0000looooo`00H?oo
ool7o`0000?oZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`0000GoZKgX00?o0000ojVmj?nY_NP00ol0
0003ojVmj003o`000?nY_NSo000000;oSV6I00?o0000ojVmj?l000000on4C8D01Ol0003oQ4b5ohA<
QOn4C8Go000000?oQDf600?o0000ohIAR_n6DHX00on6DHX2o`0000;oom><1?l000001OnKXm[o0000
oh]KTon;Fi?o000000;oQDj700Co0000oo_:H_okbV;o00001?n5CXL00ol0003oQ4^4ohA;Q002ohA;
Q003o`000?og`e?o000000?oQDf600Co0000oo?3C_oc`dko00000on6D8P01?l0003ok/=9onk3BOl0
0002ohQDS005o`000?oYa4OojLA7onW4Aol000000_n;FI42o`0000?oi/Q<0ol00002ojbC_004o`00
0?oB][god[Jmo`0000?oY9O800Co0000omRo`?oH_l3o00000_mNMm@01?l0003oaKoEolFoeOl00002
o`1<aP05o`000?nKOkCo0000oo?c^?l000000ooKlml01?l0003oYIk?ojFNcol00003oloHh003o`00
0?nY_NSoZKgX00?o00001OnY_NP00ol0003oZKgXo`000003o`0000CoZKgX00?o0000ojVmj?l00000
0_l000000onY_NSo0000ojVmj003ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP0
0onY_NP4o`0000;oZKgX0_l0000kooooo`00GOooool3o`0000;ooooo0ol000000onY_NSo0000ojVm
j003ojVmj004o`000?nY_NSo0000o`0000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP3o`0000;oZKgX
00Co0000ojVmj?nY_NSoZKgX0ol00002ohiQV@03o`000?nY_NSo000000?oQ4b500Go0000ohA<QOn4
C8GoQ4b5o`000003ohE=QP03o`000?n6DH[oQU6:00?oQU6:0_l000001_oodhco0000o`000?o3eV7o
0000oi:3`0;o00000_n;Fi<01?l0003oQDj7ohE>Qol00002oo_:HP03o`000?n5CXOoQDj700;oQDj7
00?o0000ohA;Q?n4Bh@00_n4Bh@00ol0003oml=Co`000003ohE=QP04o`000?oc`dkoll=>o`0000?o
QU2800Co0000onk3BOo^`dWo00000_n8E8`01Ol0003ojLA7onW4AooYa4Oo000000;oReVA0ol00002
onK8C0?o00000_n/Tk`01?l0003od[Jmom:f_Ol00002ojBGb007o`000?oH_l3of;o0omRo`?l0003o
GWODo`000004olFoe@Oo00000ooKlml00ol0003oYIk?o`000004oloHh0?o00000_nINJd00ol0003o
ZKgXojVmj003ojVmj0?o00000onY_NP00ol0003oZKgXojVmj003o`0000GoZKgX00?o0000ojVmj?nY
_NP00ol00005ojVmj006o`000?nY_NSo0000o`000?nY_NSo00001OnY_NP2o`0003[ooooo001Koooo
o`;o00000_ooool3o`0000GoZKgX00?o0000ojVmj?nY_NP01?l00004ojVmj006o`000?nY_NSo0000
o`000?nY_NSo00001?nY_NP01?l0003oZKgXojVmj?nY_NP2o`0000;oSV6I00?o0000ojVmj?l00000
0on4C8D01Ol0003oQ4b5ohA<QOn4C8Go000000?oQDf600?o0000ohIAR_n6DHX00on6DHX4o`000003
ol?FHOl0003oTX?000;oTX?000Co0000oh]KTon;Fi?o00000_n5CXL01Ol0003onlYRoo_:H_okbV;o
000000?oQDj700Go0000ohA;Q?n4BhCoQ4^4o`000002ooO3D`05o`000?n5CHKoQDf6ohE=Q_l00000
0_oc`dh01Ol0003oQU28ohI@R?n6D8So000000;ok/=900Co0000ohQDS?n8E8co00000ooYa4L00ol0
003oReVAo`000002o`000003olZZ^Ol0003oi/Q<00;o000000?obZZio`000?l000001?oB][d2o`00
00Gof;o000?o0000olFoeOo5_mD00_o5_mD00ol0003ofM[Ho`000004ogBKj@Ko00000oo?f>02o`00
0003okBUb_l0003oVGV]00?oVGV]00?o0000ojVmj?l000000_l000000onY_NSo0000o`000003ojVm
j0?o00000_nY_NP00ol0003oZKgXojVmj003ojVmj0?o00000_nY_NP00ol0003oZKgXojVmj003ojVm
j0;o00001?nY_NP01?l0003oZKgXojVmj?nY_NP3o`0003[ooooo001Hooooo`?o000000Coooooo`00
0?l0003o00000onY_NP00ol0003oZKgXojVmj002ojVmj0?o00001?nY_NP00ol0003oZKgXojVmj003
o`0000CoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj0;o00000_n>HIT00ol0003oZKgXo`000003
ohA<Q@05o`000?n4C8GoQ4b5ohA<QOl000001?n5CHH00ol0003oQU6:ohIARP02ohIARP?o000000?o
`mIQo`000?nBPl000onBPl001?l0003oRe^Coh]KTol00002ohE>Q`05o`000?okbV;onlYRoo_:H_l0
00000on5CXL01Ol0003oQ4^4ohA;Q?n4BhCo000000;oml=C00Go0000ohE=Q_n5CHKoQDf6o`000002
oo?3CP05o`000?n6D8SoQU28ohI@R?l000000_o^`dT01?l0003oR5B<ohQDS?l00004onW4A`Co0000
0_o:Z[T3o`000003olZZ^Ol0003od[Jm00Cod[Jm00?o0000omRo`?oH_l000ooH_l02o`0000?oaKoE
00Ko0000omWJf?oIf]SofM[Ho`000?mdVnT2o`000003okSAkOl0003oPZ[^00?oPZ[^00?o0000oloH
h?l000000ondYLX00ol0003oVGV]oiUi[@03oiUi[@03o`000?nY_NSoZKgX00?oZKgX00Ko0000ojVm
j?l0003o0000ojVmj?l00004ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP00onY
_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003oZKgX00?oZKgX1?l00002ojVmj0;o0000>Ooo
ool005Kooooo0_l000001?oooooo0000o`000?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX00Co
0000ojVmj?l0003o00000_nY_NP00ol0003oZKgXojVmj002ojVmj0?o00000_nY_NP00ol0003oZKgX
ojVmj002ojVmj0?o00000_nY_NP00ol0003oZKgXojVmj002o`0000;oSV6I00?o0000ojVmj?l00000
0on4C8D01Ol0003oQ4b5ohA<QOn4C8Go000000CoQDf600?o0000ohIAR_n6DHX00_n6DHX01?l0003o
h=QRo`000?o3eV42o`0000;oTX?00_l00002oh]KT`03o`000?n5CXOo000000ConlYR00Go0000ohE>
Qon5CXOoQDj7o`000003ohA;Q004o`000?og`e?oml=Co`0000?oQDf600Co0000oo?3C_oc`dko0000
0_n6D8P01Ol0003ok/=9onk3BOo^`dWo000000;oR5B<0_l00003onW4A`?o000000Koa[;7o`000?o:
Z[WobZZio`000?o:Z[T2o`0000Cod[Jm00?o0000omW?col000000ooH_l001_l0003og=OBomcGd_l0
003oaKoEo`0000CofM[H0_l00004okSAk@03o`000?n2Z^koPZ[^00?o00001OndYLX00ol0003oVGV]
oiUi[@02oiUi[@03o`000?nY_NSoZKgX00?oZKgX0_l00004ojVmj003o`000?nY_NSoZKgX00?o0000
1OnY_NP00ol0003oZKgXojVmj003o`0000GoZKgX00Ko0000ojVmj?l0003o0000ojVmj?l00005ojVm
j0;o0000>?ooool005?ooooo0ol00002ooooo`;o00001OnY_NP00ol0003oZKgXojVmj003o`0000Go
ZKgX00Ko0000ojVmj?l0003o0000ojVmj?l00004ojVmj004o`000?nY_NSo0000o`0000;oZKgX00?o
0000ojVmj?nY_NP00_l000000onY_NSo0000o`000002ohiQV@03o`000?nY_NSo000000?oQ4b500Go
0000ohA<QOn4C8GoQ4b5o`000004ohE=QP03o`000?n6DH[oQU6:00;oQU6:0_l000001_o3eV7o0000
oiAj/ol0003oTX?0o`0000;o]9Zl00Go0000oh]KTol0003oQDj7o`000004oo_:HP05o`000?n5CXOo
QDj7ohE>Qol000000on4Bh@01?l0003oml=CooO3Dol00003ohE=QP04o`000?oc`dkoll=>o`0000;o
QU2800Go0000onk3BOo^`dWok/=9o`000002ohQDS0;o00000ooYa4L2o`0000?oa[;700Co0000olZZ
^Oo:Z[Wo00000_o@`/`01?l0003od[Jmom:f_Ol00003omW?c`03o`000?oH_l3o000000?og=OB0_l0
0003omWJf0;o00000_o4lNl00ol0003o^=7]okSAk@04o`0000;oV[__00?o0000okBUb_ndYLX00ond
YLX02?l0003oVGV]oiUi[OnINJgo0000omJZZol0003oZKgX1Ol00004ojVmj0?o00000_nY_NP00ol0
003oZKgXojVmj003ojVmj0?o00000onY_NP01?l0003oZKgXojVmj?nY_NP3o`0000CoZKgX00?o0000
ojVmj?nY_NP01?l0000hooooo`00DOooool2o`0000?ooooo0_l00002ojVmj003o`000?nY_NSoZKgX
00;oZKgX0ol00003ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00004ojVmj003o`000?nY_NSoZKgX
00?o00001OnY_NP01?l0003oZKgXo`000?mN=hT3o`0000;oSV6I00?o0000ojVmj?l000000on4C8D0
1Ol0003oQ4b5ohA<QOn4C8Go000000CoQDf600?o0000ohIAR_n6DHX00_n6DHX3o`0000;oU7Zc0_l0
0003okBJ_005o`000?n;Fi?o0000ohE>Qol000001?okbV801Ol0003oQDj7ohE>Qon5CXOo000000?o
Q4^400Co0000ooO3Doog`e?o00000on5CHH01?l0003oll=>oo?3C_l00002ohI@R005o`000?o^`dWo
k/=9onk3BOl000000_n8E8`3o`0000;ojLA70_l00003olJba`03o`000?o:Z[Wo000000?od<;<00?o
0000om:f_Ol000001?oIcll2o`0000?og=OB00Ko0000om;aiooBlNOo0000omWJf?l00004olCak`?o
00000_nUZ]/00ol0003oV[__oiZkk`02oiZkk`03o`000?ndYL[o]:G:00;o]:G:00Go0000oiUi[OnI
NJgoVGV]o`000002omJZZ`08o`000?n?GYCoSejDohmNU?l0003oSejDo`000?nY_NP2o`000003ojVm
j?l0003oZKgX00?oZKgX00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj003ojVmj0Co0000
0_nY_NP00ol0003oZKgXojVmj002ojVmj0?o00000onY_NP2o`0003Oooooo000Zooooo`Co000000?o
410@ooooooooool07Oooool3o`0000;ooooo1?l00004ojVmj004o`000?nY_NSo0000o`0000;oZKgX
00?o0000ojVmj?nY_NP00_nY_NP01_l0003oZKgXo`000?l0003oZKgXo`0000CoZKgX0ol00003ojVm
j003o`000?nY_NSoZKgX00;oZKgX0ol000001?mN=hWo0000ojVmj?l00002ohiQV@03o`000?nY_NSo
000000?oQ4b500Go0000ohA<QOn4C8GoQ4b5o`000004ohE=QP04o`000?n6DH[oQU6:ohIARP;o0000
00Ko`mIQo`000?l0003o0000ok2F_Ol00003okBJ_005o`000?n;Fi?o0000ohE>Qol000001?okbV80
1Ol0003oQDj7ohE>Qon5CXOo000000?oQ4^400Co0000ooO3Doog`e?o00000on5CHH01?l0003oll=>
oo?3C_l00002ohI@R006o`000?o^`dWok/=9onk3BOl0003oR5B<1Ol000000ooYa4Oo0000o`000003
olJba`;o00001Oo@`/`00ol0003ofLo?omW?c`02omW?c`06o`000?oDk>Goe>cUo`000?oLem;o0000
0ooBlNL4o`000005olCakol0003o0000ojFNc_l000001?nUZ]/00ol0003oV[__oiZkk`02oiZkk`05
o`000?ndYL[o]:G:okBUb_l000000_nINJd01Ol0003oeZZ[omJZZooFZZ_o000000?oSejD00Co0000
ohmNU?n?GYCo00001?nY_NP00ol0003oZKgXojVmj003o`0000GoZKgX00Ko0000ojVmj?l0003o0000
ojVmj?l00005ojVmj006o`000?nY_NSo0000o`000?nY_NSo00001?nY_NP3o`0003Kooooo000/oooo
o`03o`000?oooooooooo01cooooo0ol00002ooooo`?o00001?nY_NP00ol0003oZKgXojVmj003o`00
00GoZKgX00?o0000ojVmj?nY_NP00ol00004ojVmj004o`000?nY_NSo0000o`0000;oZKgX00?o0000
ojVmj?nY_NP00_nY_NP01Ol0003oZKgXo`000?l0003oZKgX00;o00000_mN=hT3o`000004ohiQVOl0
003oZKgXo`0000?oQ4b500Go0000ohA<QOn4C8GoQ4b5o`000004ohE=QP04o`000?n6DH[oQU6:ohIA
RPCo00000on`U[d02Ol0003o]9ZlokBJ_?ndV[co0000oh]KTol0003oQDj7o`000004oo_:HP05o`00
0?n5CXOoQDj7ohE>Qol000000on4Bh@01Ol0003oml=CooO3Doog`e?o000000;oQDf600Co0000oo?3
C_oc`dko00000_n6D8P01_l0003ok/=9onk3BOo^`dWo0000ohQDS0;o00000oni_=`2o`0000;oa[;7
0_l000000oo5cn;o0000om32c003om32c0;o00000ooIcll01?l0003oe>cUomC/iOoDk>D3o`000003
om;aiol0003o000000?oXoKY0_l00004ojFNcP04o`000?nUZ]_oYJ[KojFZf`Ko00000ondYLX01?l0
003oVGV]oiUi[Ol00002omJZZ`;o00001?n?GY@00ol0003oSejDo`000004ojVmj0?o00000onY_NP0
1?l0003oZKgXojVmj?nY_NP3o`0000CoZKgX00Co0000ojVmj?nY_NSoZKgX0ol00004ojVmj005o`00
0?nY_NSo0000o`000?nY_NP00_l0000fooooo`008Oooool6o`0000Gooooo00?o0000ooooooooool0
6_ooool2o`0000Cooooo00Co0000ojVmj?nY_NSo00001?nY_NP3o`0000?oZKgX00?o0000ojVmj?nY
_NP00_nY_NP3o`0000?oZKgX00?o0000ojVmj?nY_NP00ol00005ojVmj003o`000?nY_NSoZKgX00Co
00000_nY_NP2o`0000?oGSN90_l000001?n>HIWo0000ojVmj?l00003ohA<Q@05o`000?n4C8GoQ4b5
ohA<QOl000001?n5CHH01?l0003oQU6:ohIAR_n6DHX3o`0000Go/9Jm00So0000okBJ_?ndV[co0000
oh]KTol0003oQDj7o`0000ConlYR00Go0000ohE>Qon5CXOoQDj7o`000003ohA;Q007o`000?og`e?o
ml=CooO3Dol0003oQDf6o`000003oo?3CP04o`000?n6D8SoQU28o`0000Cok/=90ol00004okVlg003
o`000?o6//Oo000000CoaLoR00Co0000om32c?o@`/co00000_o?hND00ol0003ofLo?o`000003omC/
i@03o`000?nanN_o/OW[00?o000000KoXoKYo`000?l0003o0000oj>HbOl00004ojFNcP06o`000?nU
Z]_o0000o`000?n`W<Co00000omMR^D3o`0000;o]:G:0_l00003omJZZ`;o00001?n?GY@01Ol0003o
SejDo`000?l0003oZKgX00;o000000?oS5N=o`000?nY_NP00onY_NP4o`0000;oZKgX00?o0000ojVm
j?nY_NP00_nY_NP4o`0000;oZKgX00Co0000ojVmj?nY_NSoZKgX0ol00004ojVmj0;o0000=Oooool0
02cooooo00?o0000ooooooooool05oooool3o`0000?ooooo0ol00004ojVmj004o`000?nY_NSo0000
o`0000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP01?l0003oZKgXo`000?l00002ojVmj004o`000?nY
_NSoZKgXojVmj0?o00000onY_NP00ol0003oZKgXojVmj002ojVmj0?o00001?nY_NP01?l0003oZKgX
o`000?l00003oehgR@;o000000CoSV6Io`000?nY_NSo00000on4C8D01Ol0003oQ4b5ohA<QOn4C8Go
000000CoQDf600?o0000ohIAR_n6DHX01?l00005ok2F_@0:o`000?ndV[co]9Zlo`000?n;Fi?o0000
ohE>Qol0003onlYRo`0000;onlYR00Go0000ohE>Qon5CXOoQDj7o`000003ohA;Q007o`000?og`e?o
ml=CooO3Dol0003oQDf6o`000003oo?3CP03o`000?n6D8SoQU2800;o00000oo^`dT4o`0000?o^KcL
0_l00005olG?hP03o`000?o@`/co000000?ocn7U1?l000000ooDk>Go0000ok7ij`02o`000004og?Q
dol0003o0000o`0000GoXiS900Co0000ojFNc_nUW/koYIk>0_l00004ok2La006o`000?mMR^GoGH[U
oef:iOl0003o8FGI1?l00003omJZZ`03o`000?oY^J;o000000?oSejD00Go0000ohmNU?l0003ol[:7
o`000004ohaGS@06o`000?nY_NSo0000o`000?nY_NSo00001OnY_NP01_l0003oZKgXo`000?l0003o
ZKgXo`0000CoZKgX1?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX0ol0000dooooo`00;?ooool0
0ol0003oooooooooo`0Eooooo`?o00000_ooool3o`0000?oZKgX00?o0000ojVmj?nY_NP00ol00005
ojVmj003o`000?nY_NSoZKgX00Co00001?nY_NP00ol0003oZKgXo`000002ojVmj003o`000?nY_NSo
ZKgX00;oZKgX00Co0000ojVmj?l0003o00000_nY_NP00ol0003oZKgXojVmj002ojVmj0Co00001?mN
=hT01Ol0003oSV6Io`000?nY_NSo000000?oQ4b500Go0000ohA<QOn4C8GoQ4b5o`000004ohE=QP03
o`000?n6DH[oQU6:00;o00000_n/U/000ol0003o/9Jmok2F_@02ok2F_@0:o`000?ndV[co]9Zlo`00
0?n;Fi?o0000ohE>Qol0003onlYRo`0000;onlYR00Go0000ohE>Qon5CXOoQDj7o`000003ohA;Q007
o`000?og`e?oml=CooO3Dol0003oQDf6o`000003oo?3CP03o`000?n6D8SoQU2800;o00000oo^`dT2
o`000003oiNnlol0003o^KcL00;o00000_nRe_X00ol0003oaLoRolG?hP02olG?hP?o000000?ocn7U
o`000?l000000onbmO87o`0000;oXIG700?o0000oj>HbOnSV<T00onSV<T01_l0003oYIk>ojFNc_l0
003o[9Joo`0000Go/9c41Ol00002ob5Uf@05o`000?oFZZ_oeZZ[omJZZol000000_oY^J802Ol0003o
SejDohmNU?n?GYCo0000ohmNU?l0003ol[:7o`000005ohaGS@03o`000?nY_NSoZKgX00;oZKgX00Co
0000ojVmj?nY_NSoZKgX0ol00004ojVmj006o`000?nY_NSo0000o`000?nY_NSo00001OnY_NP01Ol0
003oZKgXo`000?l0003oZKgX00;o0000=?ooool002cooooo00?o0000ooooooooool04_ooool3o`00
00?ooooo0_l000000onY_NSo0000ojVmj003ojVmj0?o00000onY_NP00ol0003oZKgXojVmj002ojVm
j0?o00001?nY_NP00ol0003oZKgXojVmj003o`0000CoZKgX00?o0000ojVmj?nY_NP01?l00004ojVm
j005o`000?nY_NSo0000o`000?nY_NP00ol00004oehgR@05o`000?n>HIWo0000ojVmj?l000000on4
C8D01Ol0003oQ4b5ohA<QOn4C8Go000000CoQDf600Co0000ohIAR_n6DH[o00000on/U/000ol0003o
/9Jmok2F_@03ok2F_@;o000000Go`Zg5o`000?l0003o0000oo_:HP02o`0000;onlYR00Go0000ohE>
Qon5CXOoQDj7o`000002ohA;Q003o`000?og`e?oml=C00;oml=C00?o0000ohE=Q_l000000ooc`dh0
0ol0003oQU28ohI@R003o`0000;ok/=91_l00004oj;FnP04o`000?o5cn;o0000o`0000;o[NWi0ol0
00000onbmO;o0000o`000004o`0000;oWi?700?o0000oj6EaonQULL00_nQULL00ol0003oXiS9oj>H
b@02oj>Hb@03o`000?nUW/ko000000?o[9Jo00Co0000ok2La?n`W<Co/9c40_l00003og9mc`;o0000
00?o8FGIo`000?oFZZ/00_oFZZ/01?l0003ojKVRonViX_l00003ohmNU0;o00000_ob/XL00ol0003o
S5N=ohaGS@03ohaGS@03o`000?nY_NSoZKgX00;oZKgX1?l00002ojVmj003o`000?nY_NSoZKgX00;o
ZKgX0_l00004ojVmj004o`000?nY_NSoZKgXojVmj0?o00001?nY_NP2o`0003?ooooo000/ooooo`03
o`000?oooooooooo013ooooo0_l00003ooooo`Co00000onY_NP01?l0003oZKgXo`000?l00002ojVm
j003o`000?nY_NSoZKgX00;oZKgX00Co0000ojVmj?l0003o00000_nY_NP00ol0003oZKgXojVmj002
ojVmj0?o00000_nY_NP00ol0003oZKgXojVmj002ojVmj0?o00001?nY_NP00ol0003oZKgXojVmj003
o`0000?oZKgX0ol00004oehgR@05o`000?n>HIWo0000ojVmj?l000000on4C8D01Ol0003oQ4b5ohA<
QOn4C8Go000000CoQDf600Co0000ohIAR_l0003o00001?n/U/001?l0003o/9Jmok2F_On`U[d2o`00
00;o`Zg50ol000000ookbV;o0000o`000002oo_:HP05o`000?n5CXOoQDj7ohE>Qol000000_n4Bh@0
0ol0003oml=CooO3D`02ooO3D`03o`000?n5CHKo000000?oll=>00Co0000ohI@R?l0003ok/=90_l0
0002onk3B@go000000Co[NWio`000?l0003oLn3Z1_l000000onQU<Oo0000oinCa`03oinCa`05o`00
0?nQULOoXIG7oj6Eaol000001?nSV<T2o`0000Co[9Jo00Co0000ok2La?n`W<Co00000_nnWkT01Ol0
003oLWg?og9mcombOLoo000000;o8FGI00Co0000omJZZooFZZ_o00000_oY^J801?l0003oSejDohmN
U?n?GY@2o`0000;ol[:700?o0000ohaGSOn<Ehd00on<Ehd2o`000005ojVmj?l0003o0000ohaFS?l0
00001OnY_NP01_l0003oZKgXo`000?l0003oZKgXo`0000CoZKgX1?l00002ojVmj003o`000?nY_NSo
ZKgX00;oZKgX0ol0000booooo`00:_ooool00omEEEGoIVIVo`00000?ooooo`?o00000_ooool3o`00
00CoZKgX00?o0000ojVmj?nY_NP00_l00005ojVmj003o`000?nY_NSoZKgX00Co00001?nY_NP01_l0
003oZKgXo`000?l0003oZKgXo`0000CoZKgX00Co0000ojVmj?l0003o00000_nY_NP00ol0003oZKgX
ojVmj002ojVmj0?o00000_nY_NP01?l0003oZKgXojVmj?nY_NP3o`0000GoGSN90_l000000onY_NSo
0000ohA<Q@02ohA<Q@05o`000?n4C8GoQ4b5ohA<QOl000001?n5CHH01?l0003oQU6:o`000?l00004
ojbF`006o`000?n`U[go/9Jmo`000?nk[L_o00000_o2[LD3o`000006oo_:H_l0003od;k9o`000?ok
bV;o00000on5CXL01?l0003oQ4^4ohA;Q?l00004ooO3D`03o`000?n5CHKo000000?oll=>00Go0000
ohI@R?l0003o0000oiV^iP02o`000003onk3BOl0003o000001?o00001?nQU<L01Ol0003oWi?7oinC
aonOTlOo000000?oXIG700?o0000oj>HbOl000000_l000000onVTKoo0000ojbF_`03ojbF_`03o`00
0?n`W<Co000000Co_Yni00Wo0000og9mcombOLooLWg?o`000?lQIMWo0000omJZZol000000ooY^J80
1?l0003oSejDohmNU?n?GY@2o`0000;ol[:700?o0000ohaGSOn<Ehd00on<Ehd00ol0003onK9`o`00
0004ohaFS004o`000?nY_NSoZKgXojVmj0?o00001?nY_NP01_l0003oZKgXo`000?l0003oZKgXo`00
00GoZKgX00Go0000ojVmj?l0003o0000ojVmj002o`0003;ooooo000iooooo`Co00000_ooool2o`00
00;oZKgX00?o0000ojVmj?nY_NP00_nY_NP3o`0000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP3o`00
00CoZKgX00?o0000ojVmj?nY_NP00ol00004ojVmj003o`000?nY_NSoZKgX00Co00001?nY_NP01_l0
003oZKgXo`000?l0003oZKgXo`0000CoZKgX00?o0000ojVmj?nY_NP00ol00005oehgR@;o000000Go
ZKgXo`000?n4C8GoQ4b5o`000004ohA<Q@03o`000?n5CHKoQDf600;oQDf600Co0000ohIAR_l0003o
00001?n/U/000ol0003o/9Jmo`000003ok^]b`03o`000?o2[LGo000000?o000000Goc<;@o`000?l0
003onlYRo`000003ohE>Q`04o`000?n4BhCoQ4^4o`0000Coml=C00?o0000ohE=Q_l000001?oc`dh4
o`0000;o_L;N0ol00002og^PjP03o`000?m3]OGo@kGe00Co00000on;_?L00ol0003oMM?no`000002
o`000003ojVOc?l0003oXIC700?oXIC700Go0000oinCaonOTlOoWi?7o`000002oj6Ea`?o00001OnV
TKl00ol0003o[9JoojbF_`02ojbF_`03o`000?nnWkWo_Yni00?o_Yni00Go0000og9mcol0003o0000
ojNC`@02o`000003omJZZol0003ojKVR00;ojKVR00?o0000ohmNU?n?GY@00ol00002oo:bQ`03o`00
0?n<EhgoS5N=00?oS5N=00?o0000ooVbL?l000001On<EX`3o`0000?oZKgX00?o0000ojVmj?nY_NP0
0ol00004ojVmj004o`000?nY_NSoZKgXojVmj0?o00001?nY_NP2o`00037ooooo000gooooo`;o0000
0oooool4o`0000CoZKgX00Ko0000ojVmj?l0003o0000ojVmj?l00004ojVmj004o`000?nY_NSo0000
o`0000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP3o`0000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP3
o`0000CoZKgX00?o0000ojVmj?nY_NP00ol00004ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgX
o`000?l000000_l00004oehgR@?o00000on4C8D00ol0003oQ4b5ohA<Q@02ohA<Q@03o`000?n5CHKo
QDf600;oQDf600Go0000ohIAR_l0003oZY_7o`000003ojbF`0;o00001?nk[L/00ol0003o`Zg5o`00
0003o`000005olc2d?l0003o0000oo_:H_l000000on5CXL01?l0003oQ4^4ohA;Q?l00004ooO3D`03
o`000?n5CHKo000000Coll=>0ol00003okg2gP;o00000_mkX>X4o`0000?oTJGS00?o0000oh^lmon;
_?L00ol00005ojVOc005o`000?nQU<OoXIC7oj6Daol000000onOTlL3o`0000;oXi7200?o0000ojJA
_onVTKl00onVTKl01?l0003o[9JoojbF_on/U[l2o`0000Ko_Yni00?o0000ojNC`OnWTl400_nWTl43
o`0000?ojKVR0ol000001?n?GYCo0000o`000?ob/XL2o`0000GoS5N=00?o0000ooVbL?l000001On<
EX`00ol0003oZKgXojVmj003ojVmj0?o00000_nY_NP00ol0003oZKgXojVmj002ojVmj0Co00000_nY
_NP01?l0003oZKgXojVmj?nY_NP4o`00033ooooo000dooooo`?o00000_ooool3o`0000CoZKgX00?o
0000ojVmj?nY_NP00ol00004ojVmj003o`000?nY_NSoZKgX00Co00001?nY_NP01?l0003oZKgXo`00
0?l00002ojVmj006o`000?nY_NSoZKgXojVmj?l0003oZKgX0_l00002ojVmj003o`000?nY_NSoZKgX
00;oZKgX0ol00003ojVmj004o`000?nY_NSoZKgXojVmj0?o00000_nY_NP00ol0003oZKgXo`000003
o`0000CoGSN90ol00003ohA<Q@03o`000?n4C8GoQ4b500;oQ4b500?o0000ohE=Q_n5CHH00_n5CHH2
o`0000;oZY_700Ko0000ojbF`?l0003o0000ok:]e?l00004ok^]b`Ko000000Goc<;@o`000?l0003o
nlYRo`000003ohE>Q`04o`000?n4BhCoQ4^4o`0000Coml=C00Co0000ohE=Q_l0003o00000ooc`dh3
o`0000Co_L;N0ol00002ok:ig`03o`000?nAYN?oTJGS00;oTJGS0ol00002ojbYe003o`000?nYWlco
ZIo<00?oZIo<00?o0000oj6DaonQU<L00_nQU<L3o`000003oj:Daol0003oXi7200?oXi7200?o0000
ojJA_onVTKl00_nVTKl01?l0003o[9JoojbF_ol00002ok:G^`03o`000?nnWkWo_Yni00;o_Yni0_l0
0004ojNC`@;o000000KojKVRo`000?l0003o0000onViX_l00003ohmNU005o`000?ob/XOo0000ooRi
Ool000001?n<Ehd00ol0003onK9`o`000005ohaFS0;o000000KoZKgXo`000?l0003o0000oheGSOl0
0004ojVmj006o`000?nY_NSo0000o`000?nY_NSo00001?nY_NP4o`0000;oZKgX0_l0000`ooooo`00
<oooool2o`0000;ooooo0_l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX0ol00003ojVmj004o`00
0?nY_NSoZKgXojVmj0?o00001?nY_NP00ol0003oZKgXojVmj003o`0000GoZKgX00?o0000ojVmj?nY
_NP00ol00004ojVmj004o`000?nY_NSo0000o`0000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP00ol0
003oZKgXo`000002ojVmj005o`000?nY_NSoZKgXo`000?nY_NP01?l00003oehgR@04o`000?ongIGo
0000o`0000?oQ4b500?o0000ohA<QOn4C8D00_n4C8D00ol0003oQDf6ohE=QP02ohE=QP;o000000Co
ZY_7o`000?l0003o00001?nb[M@01?l0003o^jg;ok^]bol00002ol?6g0?o000000Koc<;@o`000?o@
e]go0000oo_:H_l00003ohE>Q`04o`000?n4BhCoQ4^4o`0000Coml=C00Co0000ohE=Q_l0003o0000
0ooc`dh3o`0000?o_L;N00?o0000okS9iol000001?nb^Ml01_l0003oTJGSo`000?l0003o[KKOo`00
00Co[:WD00?o0000ojVOc?nYWl`00_nYWl`00ol0003oXIC7oj6Da`03o`0000CoXYC700Go0000oj>A
`_nSTL;oXi72o`000005ojJA_`;o00000onbUk/01Ol0003o_YniokjO^OnnWkWo000000;o`Yjd00Co
0000ojNC`OnWTl7oYi?10ol00004onViXP04o`000?n?GYCoSejDohmNU0?o000000?on;Uoo`000?n<
Ehd00on<Ehd00ol0003onK9`o`000005ohaFS003o`000?ok/fOo000000GoSEN=00?o0000ojVmj?nY
_NP00ol00004ojVmj006o`000?nY_NSo0000o`000?nY_NSo00001OnY_NP2o`0002oooooo000coooo
o`Go00001?nY_NP01?l0003oZKgXo`000?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX00?o0000
ojVmj?l000000_nY_NP00ol0003oZKgXojVmj002ojVmj0?o00000onY_NP00ol0003oZKgXojVmj002
ojVmj0?o00000onY_NP00ol0003oZKgXojVmj003o`0000GoZKgX00?o0000ojVmj?nY_NP00ol00004
ojVmj004o`000?nY_NSo0000ojVmj0Co00000omN=hT01?l0003oo]fEo`000?l00003ohA<Q@03o`00
0?n4C8GoQ4b500;oQ4b500?o0000ohE=Q_n5CHH00_n5CHH3o`0000;oYK7Q00?o0000ok:]e?nb[M@0
0_nb[M@00ol0003o^jg;o`000004ol?6g0?o00000oo@e]d2o`0000?oQDj700Co0000ohA;Q?n4BhCo
00001?og`e<00ol0003oQDf6o`000002o`0000;oll=>0_l000001?o3d^Ko0000okg2g_l00003okS9
i`04o`000?nb^Moo/[WOok:ig`;o00001?n]]]l00ol0003o[:WDojbYe002ojbYe003o`000?nYWlco
ZIo<00Co00000_nQVlh00ol0003oXYC7oj:Da`02oj:Da`03o`000?nSTL;oXi7200;oXi7200Co0000
ojJA_onVTKooYY6o0_l00004ok:G^`04o`000?nnWkWo_Ynio`0000?o`Yjd1?l00002olbR[@03o`00
0?oY^J;ojKVR00;ojKVR00Wo0000ohmNU?n?GYCoSejDo`000?ob/XOo0000ooRiOol000001?n<Ehd0
0ol0003onK9`o`000005ohaFS003o`000?ok/fOo000000GoSEN=0ol00003ojVmj003o`000?nY_NSo
ZKgX00?o00001?nY_NP01?l0003oZKgXojVmj?nY_NP4o`0002kooooo000cooooo`?o00000_nY_NP0
0ol0003oZKgXojVmj004o`0000CoZKgX00?o0000ojVmj?nY_NP00ol00004ojVmj004o`000?nY_NSo
0000o`0000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP01_l0003oZKgXo`000?l0003oZKgXo`0000Co
ZKgX0ol00003ojVmj003o`000?nY_NSoZKgX00;oZKgX0ol00003ojVmj003o`000?nY_NSoZKgX00Co
000000?oZKgXo`000?l000000_l00002oehgR@03o`000?ongIGoo]fE00;o00000on4C8D00ol0003o
Q4b5ohA<Q@02ohA<Q@03o`000?n5CHKoQDf600;oQDf600?o0000ojFahOnU/N400onU/N401?l0003o
/ZgDok:]e?nb[M@2o`0000Go`lKL0_l00003om3Fg@?o00000on5CXL01?l0003oQ4^4ohA;Q?l00004
ooO3D`03o`000?n5CHKo000000;o00000_oc`dh5o`0000Co^<WW00Ko0000ok:igol0003o0000ojc3
jol00004ojffg`04o`000?n/ZMCo[:WDojbYe0Co00000_nPYMT00ol0003oXI_>oj6KcP02oj6KcP05
o`000?nRU<OoXYC7oj:Daol000001?nSTL801_l0003oYY6oo`000?l0003oZI>oo`0000Go/YNk0_l0
0002ol:N]0?o000000?oYi?1o`000?o<XZd00_o<XZd2o`0000?ojKVR00Wo0000ohmNU?n?GYCoSejD
o`000?ob/XOo0000ooRiOol000001?n<Ehd01?l0003onK9`o`000?l00004ohaFS003o`000?ok/fOo
000000GoSEN=00?o0000ojVmj?nY_NP00onY_NP3o`0000?oZKgX00?o0000ojVmj?nY_NP01Ol00002
ojVmj0;o0000;_ooool003?ooooo0_l00003ojVmj0?o00001?nY_NP00ol0003oZKgXojVmj004o`00
00?oZKgX00?o0000ojVmj?nY_NP00ol00005ojVmj003o`000?nY_NSoZKgX00?o00001?nY_NP01?l0
003oZKgXo`000?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX00Ko0000ojVmj?l0003o0000ojVm
j?l00004ojVmj0?o00000_nY_NP2o`000003ojVmj?l0003o000000;o00000_mN=hT00ol0003oo]fE
o`000002o`0000?oQ4b500?o0000ohA<QOn4C8D00_n4C8D00ol0003oQDf6ohE=QP02ohE=QP;o0000
1?nU/N401?l0003o/ZgDo`000?l00002ok7;k@04o`000?o3a]co`lKLol?6g0;o000000Go`N3_o`00
0?o@e]go0000ol_Xj`02o`0000?oQDj700Co0000ohA;Q?n4BhCo00001?og`e<3o`0000;o^N;c00Co
0000oo?3C_l0003o00000onaeo<00ol0003o^<WWokS9i`03o`0000Co[<?[00?o0000ojffgon]]]l0
1Ol00002oijai@03o`000?nPYMWoX:GI00;oX:GI00Go0000oj6Kc_nQVlkoXI_>o`000004oj:Da`03
o`000?nSTL;oXi7200?o00001?nYTkl00ol0003o/YNkok:G^`02ok:G^`Co00000oo2W[@2o`0000?o
c::]0_l00003onViXP04o`000?n?GYCoSejDo`0000;ol[:70ol00004ohaGS@04o`000?oi/W3o0000
o`0000CoS5J<00?o0000oo^cIol000001On=Ehd2o`000006ojVmj?l0003o0000o`000?nY_NSo0000
1?nY_NP3o`0000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP3o`0002gooooo000Xooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool01_l0003oooooooooool0003oZKgXo`0000;oZKgX00?o0000ojVm
j?nY_NP00_nY_NP3o`0000?oZKgX00Co0000ojVmj?nY_NSoZKgX0ol00003ojVmj003o`000?nY_NSo
ZKgX00;oZKgX0ol00003ojVmj003o`000?nY_NSoZKgX00?o00001OnY_NP00ol0003oZKgXojVmj003
o`0000CoZKgX00Co0000ojVmj?l0003o00000_nY_NP00ol0003oZKgXojVmj002o`000003ojVmj?l0
003o000000;o00000_mN=hT01Ol0003oo]fEo`000?ohkJco000000?oQ4b500?o0000ohA<QOn4C8D0
0_n4C8D00ol0003oQDf6ohE=QP02ohE=QP03o`000?nF_?;o000000;oYK7Q1?l00004ok7;k@06o`00
0?o3a]co0000ol7Pkol0003o`N3_1_l00003ohE>Q`03o`000?n4BhCo000000Goml=C1_l000000ooc
`dko0000o`000002ok7Gl`Co00000onUd?H00ol0003o[<?[ojc3j`04o`0000?oV[ob00?o0000oija
iOnN/ND00_nN/ND01Ol0003oX:GIoj2UfOnPYMWo000000?oXI_>00?o0000oj:DaonRU<L01Ol00002
oj6DaP03o`000?nYTkooZI>o00;oZI>o00?o0000ok:G^onbUk/00ol00006ol:N]003o`000?o<XZgo
c::]00;oc::]00?o0000om:SY_l000000_oY^J801?l0003oSejDohmNU?l00002oo:bQ`03o`000?oh
^Goo000000CoS5N=00Co0000ooVbL?l0003o00001?n<EX`00ol0003onk=Wo`000005oheGS@03o`00
0?ok/fGo000000GoZKgX1?l000000onY_NSo0000ojVmj003ojVmj008o`000?nY_NSo0000o`000?nY
_NSo0000ooooool0000/ooooo`00:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00Go0000
ooooooooooooooooo`000004ojVmj004o`000?nY_NSo0000o`0000;oZKgX00?o0000ojVmj?nY_NP0
0_nY_NP00ol0003oZKgXo`000002ojVmj003o`000?nY_NSoZKgX00;oZKgX00Co0000ojVmj?l0003o
00000_nY_NP01?l0003oZKgXojVmj?nY_NP3o`0000?oZKgX00?o0000ojVmj?nY_NP00_nY_NP3o`00
00?oZKgX00?o0000ojVmj?nY_NP00ol00005ojVmj005o`000?nY_NSo0000o`000?nY_NP01?l00000
0omN=hWo0000ookMU@04o`0000?oQ4b500?o0000ohA<QOn4C8D00_n4C8D01?l0003oQDf6ohE=Q_n5
CHH7o`0000?oS/[l00?o0000ok7;kOnabnd01?l000000oo1h>oo0000o`000003oj__m`?o00000on5
CXL01Ol0003oQ4^4o`000?og`e?o000000?oml=C1_l000000ooc`dko0000o`000002o`0000?oX[[Z
00?o0000ojG@m_nUd?H01?l00003oiC6n003o`000?nJ_o;oV[ob00;oV[ob00Go0000oijaiOnN/NGo
W[7Uo`000003oj2Uf@03o`000?nQVlkoXI_>00Co00000_nKV=000ol0003oXIC6oj6DaP03oj6DaP04
o`000?nYTkooZI>oojVC_`Co00000_neV;X00ol0003o`Yjdol:N]003ol:N]003o`000?o<XZgoc::]
00;oc::]00?o0000om:SY_l000000_oY^J801?l0003oSejDohmNU?l00002oo:bQ`03o`000?oh^Goo
000000CoS5N=00Co0000ooVbL?l0003o00001?n<EX`00ol0003onk=Wo`000005oheGS@04o`000?ok
/fGo0000o`0000;oZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00?o00001?nY_NP2o`0002cooooo
000Xooooo`05oa0@4?ooooooooooooooool@41001Oooool2o`0000?ooooo00?o0000ojVmj?nY_NP0
0ol00005ojVmj003o`000?nY_NSoZKgX00?o00001?nY_NP00ol0003oZKgXojVmj004o`0000CoZKgX
00?o0000ojVmj?l000000_nY_NP00ol0003oZKgXojVmj002ojVmj004o`000?nY_NSo0000o`0000;o
ZKgX00Co0000ojVmj?nY_NSoZKgX0ol00003ojVmj003o`000?nY_NSoZKgX00;oZKgX1ol000001ol0
06Ko0000oehgROl0003oo]fEo`000?oAeEd00_l00003ohA<Q@03o`000?n4C8GoQ4b500;oQ4b500Ko
0000ohE=Q_n5CHKoQDf6o`000?moPld;o`0000;oVn;m1Ol000001?n[koOo0000o`000?moi^d2o`00
00?oQDj700Go0000ohA;Q?l0003oml=Co`000003ooO3D`?o000000?oWLOeo`000?l000000_l00000
0onLX=Oo0000oj:jjP03oj:jjP?o00000onIX]`00ol0003oU<KhoiC6n002oiC6n003o`000?nJ_o;o
V[ob00co00000_nCX=d00ol0003oViS@oi^Hd002oi^Hd003o`000?nQU<KoXIC600;oXIC600Go0000
ojVC_ol0003o0000ojVC_`02o`0000?o]IRj00?o0000ol:N]?o2W[@00_o2W[@2o`0000?oc::]00?o
0000om:SY_oBXjH00_l00002onViXP03o`000?n?GYCo000000;ol[:700Co0000ooRiOol0003o0000
0on<Ehd01?l0003onK9`o`000?l00004ohaFS004o`000?ok/fOo0000o`0000CoSEN=00Co0000oo^c
IOl0003onk=U0_l00002ohiISP03o`000?nY_NSoZKgX00?oZKgX0ol00003ojVmj003o`000?nY_NSo
ZKgX00Co0000:oooool002Sooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo00?ooooo0_l00003ojVmj003o`000?nY_NSoZKgX00;oZKgX0ol00003ojVmj003o`000?nY_NSo
ZKgX00Co00001?nY_NP00ol0003oZKgXojVmj003o`0000CoZKgX00?o0000ojVmj?nY_NP01?l00004
ojVmj003o`000?nY_NSo000000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP01Ol0003oZKgXo`000?l0
003oZKgX00Ko000000Ko001Vo`000?l0003oo]fEo`000?oAeEd3o`0000?oQ4b500?o0000ohA<QOn4
C8D00_n4C8D01Ol0003oQDf6ohE=Q_n5CHKo000000;oOh?=0_l00003ogAlcA;o00000on5CXL01Ol0
003oQ4^4o`000?og`e?o000000?oml=C1?l000001?n^Y<ko0000o`000?l00002oibPe`06o`000?nR
^^[o0000o`000?n_Y/oo00001?nIX]`8o`0000?oLKon00Co0000ogbhnOml^?Wo00000on:[>`00ol0
003oTj3Moi>Pg@02oi>Pg@05o`000?nKV=3oViS@oi^Hd?l000000onQU<H3o`0000;oZI>o0_l00005
okFH^P04o`000?o2W[Co`Yjdo`0000;oa9jb00Co0000olbR[Oo<XZgo00000ooBXjH02?l0003ojKVR
onViX_l0003oSejDo`000?ob/XOo00000_oh^Gl00ol0003oS5N=o`000002ohaGS@04o`000?oi/W3o
0000o`0000CoS5J<00Co0000oo^cIol0003o00001?n=Ehd01Ol0003onk=Uo`000?ok/fGo000000Co
SUV>00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj003ojVmj0?o00000_nY_NP2o`0002_o
oooo000Xooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`04ooooo`03
o`000?nY_NSoZKgX00;oZKgX00Co0000ojVmj?l0003o00000_nY_NP01?l0003oZKgXojVmj?nY_NP3
o`0000?oZKgX00?o0000ojVmj?nY_NP00_nY_NP3o`0000?oZKgX00?o0000ojVmj?nY_NP01?l00004
ojVmj003o`000?nY_NSoZKgX00?o00001?nY_NP00ol0003oZKgXojVmj003o`0000CoZKgX1Ol00000
0ol006Ko0000o`000002o`000004om7EGOl0003oUgZao`0000?oQ4b500?o0000ohA<QOn4C8D00_n4
C8D01?l0003oQDf6ohE=Q_l00002ogn3c@04o`000?o4Z;goa:Rmo`0000?oM7c=0_l00005ohV7b`06
o`000?mJ[O[o0000o`000?nZV/Oo00000on8Um/02?l0003oQDj7ohE>Qon5CXOo0000ohA;Q?l0003o
ml=C0_l00002ooO3D`?o00000on^Y<h2o`0000;oW:3G0_l00004ojnVc`06o`000?nIX]coVJ;Lo`00
0?neY/[o00001OnBV=H9o`0000?oRZc/00Go0000oi>PgOnCX=goTj3Mo`000004oi^Hd0?o00000_nQ
U<H3o`000003ojRF`ol0003o]IRj00Co]IRj00Co0000ol:N]?o2W[Co00000_o4W[800ol0003oc::]
o`000004om:SYP;o000000KojKVRo`000?n?GYCo0000oo:bQol00002ooRiO`07o`000?n<EhgoS5N=
o`000?n<Ehgo0000ooVbL002o`0000CoS5J<00Co0000oo^cIol0003o00001?n=Ehd01Ol0003onk=U
o`000?ok/fGo000000GoSUV>00?o0000ojVmj?nY_NP00onY_NP4o`000003ojVmj?l0003oZKgX00?o
ZKgX0_l0000Zooooo`00:?ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oZKgXojVmj004o`0000CoZKgX00?o0000ojVmj?l000000_nY_NP00ol0003o
ZKgXojVmj002ojVmj004o`000?nY_NSo0000o`0000;oZKgX00Co0000ojVmj?nY_NSoZKgX0ol00003
ojVmj003o`000?nY_NSoZKgX00;oZKgX0ol00003ojVmj003o`000?nY_NSoZKgX00Co00000onY_NP0
0ol0003oZKgXojVmj006o`000005o`00I_l0003o0000o`000?oAeEd00_l000000onGN[7o0000ohA<
Q@02ohA<Q@03o`000?n4C8GoQ4b500;oQ4b500Ko0000ohE=Q_n5CHKo0000ogn3cOl00003olBX_@04
o`000?mdO<goM7c=o`0000;o`:Jo00?o0000ohV7bon9Ql/00_n9Ql/2o`0000CoZY[700Co0000ohRG
fon8Um_o00000on5CXL00ol0003oQ4^4o`000003o`0000;oml=C0ol00003ojjTcP06o`000?nLX=Oo
0000o`000?nbZ<ko00001?n_Y/l00ol0003oVJ;Lo`000003okFVbP07o`000?nBV=KoTYSFoi:He_l0
003o^:?4o`000004oh>:dP03o`000?lSX>[o000000Co00000onCX=d00ol0003oViS@o`000003o`00
00;oXIC60ol00004ojRF``03o`000?neV;[o]IRj00;o]IRj00?o0000ol:N]?l000000oo4W[800ol0
003oc::]o`000004om:SYP;o000000KojKVRo`000?n?GYCo0000oo:bQol00002ooRiO`07o`000?n<
EhgoS5N=o`000?n<Ehgo0000ooVbL002o`0000CoS5J<00Co0000oo^cIol0003o00001?n=Ehd01Ol0
003onk=Uo`000?ok/fGo000000GoSUV>0_l00002ojVmj0?o00001OnY_NP00ol0003oZKgXojVmj004
o`0002Wooooo000Xooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`07
ooooo`;o00001?nY_NP00ol0003oZKgXojVmj003o`0000CoZKgX00?o0000ojVmj?nY_NP01?l00004
ojVmj003o`000?nY_NSo000000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP01_l0003oZKgXo`000?l0
003oZKgXo`0000CoZKgX0ol00003ojVmj004o`000?nY_NSoZKgXojVmj0?o00000_nY_NP4o`000006
o`00I_l0003o001Vo`000?oAeEgo00000_nGN[401Ol0003oQ4b5ohA<QOn4C8Go000000CoQ4b500Go
0000ohE=Q_l0003o`jFlo`000004olBX_@03o`000?mdO<go000000Co`:Jo00Ko0000ohV7bon9Ql_o
0000okbV`ol00004ojZJa`04o`000?n8Um_o0000o`0000?oQDj700?o0000ohA;Q?l000000ol00002
ooO3D`?o00000on^Y<h2o`0000Co/ZS>00Co0000ojnVcon_Y/oo[jK?0_l00005okFVbP03o`000?nB
V=Ko000000?o^:?400Co0000oh>:d_n3R];oPh[B1Ol000000om:Y_So0000o`00000:o`0000;oVYO?
00?o0000ojRF`onXU/<00_nXU/<00ol0003o]IRjokFH^P02okFH^P;o00001Oo4W[82o`0000?odZ>V
00?o0000om:RY_l000000_l000001?n?GYCo0000oo:bQol00003ooRiO`03o`000?n<EhgoS5N=00;o
000000?onK9`o`000?l000001?n<EX`01?l0003onk=Wo`000?l00004oheGS@05o`000?ok/fGo0000
oo^cIOl000001On>FHh01?l0003onk9So`000?l00003ojVmj004o`000?nY_NSoZKgXojVmj0Co0000
0onY_NP2o`0002Sooooo000Xooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool2o`0000Wooooo
00?o0000ojVmj?nY_NP00_nY_NP3o`0000?oZKgX00?o0000ojVmj?nY_NP01?l00004ojVmj003o`00
0?nY_NSoZKgX00?o00001?nY_NP00ol0003oZKgXojVmj003o`0000CoZKgX00Co0000ojVmj?l0003o
00000_nY_NP00ol0003oZKgXojVmj002ojVmj003o`000?nY_NSo000000;oZKgX00?o0000ojVmj?nY
_NP01?l00003o`00IP?o00000_nGN[401Ol0003oQ4b5ohA<QOn4C8Go000000CoQ4b500?o0000ohE=
Q_l000000_l00005olBX_@03o`000?o0Y[oo`:Jo00?o`:Jo00?o0000ohV7bol000000onlY/<01?l0
003oZY[7ojZJaonZV/L2o`0000;o]jG700Go0000ohE>Qon5CXOo0000ohA;Q002o`000004okN[cOl0
003o0000ooO3D`?o000000Go[ZC>o`000?l0003o]:_?o`000004ok:XcP06o`000?n_Y/oo0000o`00
0?ncYl_o00001OneY/X2o`0000Co^:?400Ko0000oh>:d_n3R];o0000okRM_Ol00002of]jd0Go0000
0_m_Xo000ol0003oR9cOohRLg`02ohRLg`03o`000?nJUlooVYO?00;oVYO?00Go0000ojRF`onXU/?o
Z9K3o`000002okFH^P;o000000?o]9Zlo`000?o4W[801?o4W[800ol0003odZ>Vom:SYP02om:SYP03
o`000?oBXZKo000000;o000000CoSejDo`000?ob/XOo00000ooh^Gl01_l0003oS5N=ohaGSOn<Ehgo
0000ooVbL0;o00001?n<EX`01?l0003onk=Wo`000?l00004oheGS@04o`000?ok/fGo0000oo^cI@;o
00001?n>FHh00ol0003onk9So`000004ojVmj0Co00000_nY_NP00ol0003oZKgXojVmj002ojVmj0;o
0000:?ooool0037ooooo00?o0000ooooooooool02Oooool01?l0003oZKgXo`000?l00002ojVmj004
o`000?nY_NSoZKgXojVmj0?o00000onY_NP00ol0003oZKgXojVmj002ojVmj0?o00000onY_NP00ol0
003oZKgXojVmj004o`0000?oZKgX00?o0000ojVmj?nY_NP01?l00004ojVmj003o`000?nY_NSoZKgX
00?o00001?nY_NP00ol0003oZKgXo`000003o`0000;o001V00Co0000om7EGOl0003o00000_nGN[40
1Ol0003oQ4b5ohA<QOn4C8Go000000CoQ4b500?o0000ohE=Q_l000000_o7[L001?l0003oa:RmolBX
_Oo4Z;d2o`0000Ko`:Jo00?o0000okbV`onlY/<00_nlY/<01_l0003oZY[7ojZJaol0003o^ZW8o`00
00;o]jG700Go0000ohE>Qon5CXOo0000ohA;Q002o`0000;o]j_=00?o0000ooO3Dol000000ol00004
okB[c`04o`000?nbZ<ko/ZS>ok:XcP;o00001?ncYl/01ol0003o]JK:okFVb_neY/[o0000okFRa_l0
00001?nhXl@00ol0003oPh[Bo`000003okRM_@Wo000000?oKj?`o`000?n8W=l00on8W=l01Ol0003o
VYO?oiZGconJUloo000000CoZ9K30_l00004okBJ_003o`000?o4W[;oa9jb00;oa9jb00?o0000om:S
Y_oBXjH00_oBXjH00ol0003odZ:Vo`000003o`0000;ol[:700Go0000ooRiOooh^Goon;Uoo`000003
ohaGS@Co00001?n<EX`01?l0003onk=Wo`000?l00004oheGS@04o`000?ok/fGo0000oo^cI@;o0000
1?n>FHh01Ol0003onk9So`000?l0003oZKgX00;o000000?oSeZ?o`000?nY_NP01?nY_NP4o`000003
ojVmj?l0003o000002Oooooo000aooooo`03o`000?oooooooooo00[ooooo0_l00004ojVmj003o`00
0?nY_NSo000000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP01_l0003oZKgXo`000?l0003oZKgXo`00
00CoZKgX0ol00003ojVmj004o`000?nY_NSoZKgXojVmj0?o00001?nY_NP00ol0003oZKgXojVmj004
o`0000?oZKgX00?o0000ojVmj?nY_NP01ol00002o`00IP;o000000GoVWjco`000?nGN[7oUgZao`00
0003ohA<Q@03o`000?n4C8GoQ4b500;oQ4b50_l00003olN]`004o`000?o4Z;goa:Rmo`0000;oa:g2
00?o0000ol2V_oo0Y[l00_o0Y[l2o`0000Co_:K300?o0000ojZJaol000000onjZLP00ol0003o]jG7
o`000002ohE>Q`;o000000Koml=Co`000?ngZlgo]j_=o`000?og`e<2o`000003okJ`d_l0003o]:_?
00?o]:_?00Ko0000ok:Xc_l0003o0000ok>Zcol00005ok>Wb`03o`000?neY/[o000000?o]J;600Co
0000okRSa?nhXlCo^:?40_l00002okRM_@?o000000KoJg[@o`000?l0003o/9Fko`000?lhJ=H5o`00
00?oR9cO00Go0000oiZGconJUlooVYO?o`000002ojRF``?o00001OndV[`01?l0003oa9jbolBN/_o4
W[82o`0000?odZ>V00Co0000om:RY_oBXZKodZ:V0ol00002oo:bQ`05o`000?oh^Goon;UoooRiOol0
00000on<Ehd3o`000003oobfJ_l0003oS5J<00;oS5J<00Co0000oo^cIol0003o00001?n=Ehd01?l0
003onk=Uo`000?ok/fD2o`0000CoSUV>00Go0000oo^bHol0003onk9So`000004ohmJS`03o`000?nY
_NSoZKgX00?o00001OnY_NP00ol0003oooooooooo`0Uooooo`00<Oooool00ol0003oooooooooo`0<
ooooo`03o`000?nY_NSoZKgX00?o00001?nY_NP00ol0003oZKgXojVmj004o`0000?oZKgX00Co0000
ojVmj?l0003o00000_nY_NP00ol0003oZKgXojVmj002ojVmj003o`000?nY_NSo000000;oZKgX00?o
0000ojVmj?nY_NP00_nY_NP3o`0000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP3o`0000?oZKgX1?l0
0002o`00IP;o000000GoVWjco`000?nGN[7oUgZao`000003ohA<Q@03o`000?n4C8GoQ4b500;oQ4b5
0_l00003olN]`003o`000?o4Z;go000000Coa:g200Co0000ol2V_oo0Y[oo00000_o0[<D01?l0003o
_:K3okbV`onlY/<2o`0000Co^ZW800?o0000okNUaol000000_n5CXL3o`0000?o]j_=00Co0000ooO3
Dol0003o00000_nf/=801?l0003o]:_?okB[condZll2o`0000Co/j[?00?o0000ok>WboncYl/00_nc
Yl/2o`0000Co]J;600Go0000okRSa?nhXlCo0000okNM_P03o`0000?o^9fm00?o0000ok2E^on`UK/0
0_n`UK/01?l0003o>6SFocQXe_lhJ=H<o`0000;oXYS;00?o0000okBJ_?ndV[`00ondV[`01?l0003o
a9jbolBN/_l00002olBN/P04o`000?oBXjKodZ>Vo`0000?odZ:V0ol00002oo:bQ`05o`000?oh^Goo
n;UoooRiOol000000on<Ehd01Ol0003onK9`o`000?ol]V[o000000?oS5J<00Co0000oo^cIol0003o
00001?n=Ehd01?l0003onk=Uo`000?ok/fD2o`0000CoSUV>00Go0000oo^bHol0003onk9So`000005
ohmJS`;o00000onY_NP00ol0003oZKgXojVmj004o`0002Kooooo000aooooo`03o`000?oooooooooo
00gooooo0_l00003ojVmj003o`000?nY_NSoZKgX00Co00001?nY_NP00ol0003oZKgXojVmj003o`00
00CoZKgX00?o0000ojVmj?nY_NP00ol00004ojVmj004o`000?nY_NSo0000o`0000;oZKgX00Ko0000
ojVmj?nY_NSoZKgXo`000?nY_NP2o`0000;oZKgX00Co0000ojVmj?nY_NSoZKgX1?l000000ol006Ko
0000o`000003oiYn/`?o00000on4C8D00ol0003oQ4b5ohA<Q@02ohA<Q@;o00001?o7[L000ol0003o
a:g2olB]`P03olB]`P03o`000?o0Y[oo000000?o`:c500Ko0000okbV`onlY/?o0000okj_bol00004
okZYb003o`000?ngYLOo000000;oQDj70ol00003okN[c@Co00000_nf/=801_l0003o]:_?o`000?l0
003o];3Eo`0000Go/j[?00Ko0000ok>Wbol0003o0000ok:Ubol00004okFRaP03o`000?nhXlCo0000
00Co00000onhWKd2o`0000Go/9Fk0ol00002oif7^`;o00000_mDU^l01Ol0003oQYSNohJHg_n6V=ko
000000CoXYS;00?o0000okBJ_?ndV[`00ondV[`2o`0000?oa9jb00?o0000om:SY_l000001?oBXZH3
o`0000;ol[:700Go0000ooRiOooh^Goon;Uoo`000003ohaGS@03o`000?oi/W3o000000;o00000on<
EX`01Ol0003onk=Wo`000?ok/fOo000000?oSEN=00Co0000oo^cIOl0003onk=U0_l00004ohiISP05
o`000?ok/V?o0000oo^bHol000001On?FXl00ol0003oZKgXojVmj002ojVmj0?o00000onY_NP2o`00
02Gooooo000aooooo`;o00003oooool01?l0003oZKgXojVmj?nY_NP3o`0000?oZKgX00?o0000ojVm
j?nY_NP00_nY_NP3o`0000?oZKgX00?o0000ojVmj?nY_NP01?l00003ojVmj003o`000?nY_NSoZKgX
00Co00001?nY_NP00ol0003oZKgXojVmj003o`0000CoZKgX00?o0000ojVmj?l000001?l000001?l0
06Ko0000o`000?nJO[<3o`000003ok6J_ol0003oQ4b500;oQ4b500?o0000ohA<QOn4C8D00_n4C8D2
o`0000?oajg00_l00005olB]`P;o00001?o0[<D00ol0003o_:K3o`000003okj_b`04o`000?njZLSo
^ZW8okZYb0;o000000?o^[3?o`000?n5CXL00ol000001?ngZlgo0000o`000?ni]mP3o`0000;o][3B
0_l00004okB`e@03o`000?ncZ/oo/j[?00;o/j[?0_l00004ok:Ub`04o`000?neX/Ko]J;6okFRaP?o
00000ongWKh01_l0003o^9fmokRM_Ol0003o^YZgo`0000Go/9Fk00?o0000oif7^onMQk/01?nMQk/2
o`000003oeBFkol0003oQYSN00;oQYSN00Go0000oj:HbonRV<_oXYS;o`000004okBJ_0;o00001?o4
W[800ol0003odZ>Vo`000005om:RYP;o00000_ob/XL01Ol0003on;UoooRiOooh^Goo000000?oS5N=
00?o0000ooVbL?l000000_l00003ohaFS005o`000?ok/fOo0000oo^cIol000000on=Ehd01?l0003o
nk=Uo`000?ok/fD2o`0000CoSUV>00Go0000oo^bHol0003onk9So`000005ohmJS`;o000000GoZKgX
o`000?l0003oSe^?o`000004ojVmj0;o00009Oooool0033ooooo00?o0000ooooooooool04?ooool0
0ol0003oZKgXo`000002ojVmj003o`000?nY_NSoZKgX00;oZKgX00Ko0000ojVmj?l0003o0000ojVm
j?l00004ojVmj0?o00000onY_NP01?l0003oZKgXojVmj?nY_NP3o`0000CoZKgX00?o0000ojVmj?nY
_NP01?l00003ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?l000000_l000001?l006Ko
0000o`000?l00002oiV6_P03o`000?naV[oo000000?oQ4b500?o0000ohA<QOn4C8D00_n4C8D2o`00
00;oajg000Co0000olReb?o8]LSo00000oo4[L800ol0003oa;C;o`000004ol2/a@;o00001?nn[l/0
1?l0003o^ZW8o`000?l00002okfgd`;o000000?oQDj7o`000?l000000_l00003okVgf0;o000000Go
][3Bo`000?l0003o];_No`000004okB`e@03o`000?ncZ/oo000000;o000000?o/:cCo`000?nbYL/0
0onbYL/4o`000003ok:Na?l0003o]ifn00?o]ifn00?o0000okRM_Ol000000onjV[L01ol0003o/9Fk
ok2E^on`UK_o0000okjH/?l000001OnMQk/4o`0000?oQYSN00?o0000oj:HbonRV</00_nRV</01_l0
003o]9ZlokBJ_?l0003o/9_2o`0000Goa9jb0_l00005om:RYPCo00001?oh^Gl02Ol0003oS5N=ohaG
SOn<Ehgo0000ooVbL?l0003oo;IZo`000003ohaFS005o`000?ok/fOo0000oo^cIol000000on=Ehd0
1?l0003onk=Uo`000?ok/fD2o`0000CoSUV>00Go0000oo^bHol0003onk9So`000005ohmJS`03o`00
0?ok/V;o000000CoSe^?00Go0000ojVmj?l0003o0000ojVmj002o`0002Cooooo000`ooooo`03o`00
0?oooooooooo017ooooo0_l00003ojVmj003o`000?nY_NSoZKgX00Co00000onY_NP01?l0003oZKgX
o`000?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX00?o0000ojVmj?l000000_nY_NP00ol0003o
ZKgXojVmj002ojVmj0?o00000_nY_NP00ol0003oZKgXojVmj002ojVmj0?o00000onY_NP8o`0000Co
VHJn0_l00003ohA<Q@09o`000?n4C8GoQ4b5ohA<QOl0003oak;6o`000?o7[L3o000000Cob;G800?o
0000olB]`_l000000oo4]</01_l0003o`:c5ol2/aOl0003o`KK@o`0000Co_Zo;0_l00005okfgd`03
o`000?n5CXOo000000?o00001?ni]mP2o`0000Co];_N00Co0000okB`eOnd/=Go];3E0_l00005ok2/
d`03o`000?nbYL_o000000;o000000?o]J;6o`000?nbW/@00_nbW/@00ol0003o]ifnokNM_P02okNM
_P03o`000?njV[Oo^YZg00;o^YZg00Co0000ok2E^on`UK_o00000_nnV;000ol0003oWHNkoif7^`02
oif7^`;o000000?oIF>ko`000?l000001?l00004oj:Hb`03o`000?ndV[co000000;o/9_200?o0000
olBN/_o4W[800oo4W[800ol0003odZ:Vom:RYP03om:RYP;o000000?odinPo`000?l000001?oh^Gl0
2?l0003oS5N=ohaGSOn<Ehgo0000ooVbL?l0003oo;IZ0_l00002ohaFS005o`000?ok/fOo0000oo^c
Iol000000on=Ehd01?l0003onk=Uo`000?ok/fD2o`0000CoSUV>00Co0000oo^bHol0003onk9S0_l0
0004ohmJS`03o`000?ok/V;o000000GoSe^?00?o0000ojVmj?nY_NP00_nY_NP2o`0002?ooooo000`
ooooo`03o`000?oooooooooo01?ooooo00?o0000ojVmj?nY_NP00ol00004ojVmj003o`000?nY_NSo
ZKgX00?o00001?nY_NP00ol0003oZKgXojVmj003o`0000CoZKgX00Ko0000ojVmj?l0003o0000ojVm
j?l00004ojVmj004o`000?nY_NSo0000o`0000;oZKgX00Co0000ojVmj?nY_NSoZKgX1ol000000oma
Hk?o0000oiV6_P02oiV6_P;o00000on4C8D01?l0003oQ4b5ohA<QOl00002olNbaP;o00001Oo8]LP2
o`0000Coa;C;00?o0000ol2/aOl000000oo1]]001_l0003o_Zo;okj_bol0003o`;kIo`0000Go_KOC
00?o0000ohE>Qol000000_l000000onl`Mko0000okVgf004o`0000Co];_N00Ko0000okB`eOl0003o
0000ojjhhOl00004ok2/d`?o00000_nbYL/2o`0000Co/Yk400Co0000okNM__ngWKko]ifn0_l00004
okZJ]`04o`000?n`UK_o/9Fko`0000?o_YR`00Co0000oif7^onMQk_o00000_o3V:/01?l0003oIF>k
ofES^ol00002odZ=k0Oo00001?n`Vl800ol0003oa9jbolBN/P02olBN/P03o`000?oBXZKodZ:V00?o
dZ:V00?o0000om2QYol000000_l00004ooRiO`0Ao`000?n<EhgoS5N=ohaGSOl0003onK9`o`000?ol
]V[o0000ohaFS?l0003oS5J<o`000?ok/fOo0000oo^cIol000000on=Ehd01?l0003onk=Uo`000?ok
/fD2o`0000CoSUV>00Co0000oo^bHol0003onk9S0_l00004ohmJS`03o`000?ok/V;o000000GoSe^?
00Co0000ojVmj?nY_NSoZKgX0ol0000Sooooo`00<?ooool00ol0003oooooooooo`0Dooooo`;o0000
0_nY_NP00ol0003oZKgXojVmj002ojVmj0?o00000onY_NP00ol0003oZKgXojVmj004o`0000?oZKgX
00?o0000ojVmj?nY_NP01?l00003ojVmj003o`000?nY_NSoZKgX00Co00001?nY_NP01?l0003oZKgX
o`000?nY_NP5o`0000;oLF>c00Co0000oiV6__nIQ[koVHJn0_l00003ohA<Q@08o`000?n4C8GoQ4b5
o`000?o7//Ko0000olVodOl00003olReb0;o000000?oa[kCo`000?o4]</00oo4]</2o`0000Co`KK@
00?o0000okj_bol000000oo0_]T01?l0003o_KOCokfgdonm]m<2o`000003ohE>Qol0003o000000;o
_<7N0_l00004okG9j@03o`000?nd^mko];_N00?o00001?n^^>44o`000003ok2/dol0003o/ZG;00;o
000000?o[J?=o`000?nbW/@00onbW/@01_l0003o]ifnokNM__l0003o]9Rko`0000Go^YZg0_l00004
okjH/004o`000?nMQk_oWHNko`0000;o`iR[00?o0000ofES^omUHk/00_l00002odZ=k003o`000?n@
VMSoT9WH00;oT9WH00?o0000ok2K`_n`Vl800_n`Vl801ol0003oa9jbolBN/_o4W[;o0000ol6N]Ol0
00000ooBXZH00ol0003od:6Wom2QY`03o`0000Con;Uo017o0000ohaGSOn<EhgoS5N=o`000?oi/W3o
0000oobfJ_l0003oS5J<o`000?n<EXco0000oo^cIol0003onk=Wo`000003oheGS@07o`000?ok/fGo
0000oo^cIOl0003onk=Uo`000003ohiISP04o`000?ok/V?o0000oo^bH`;o00001?n?FXl00ol0003o
nk9Ro`000005ohmKS`Co00000_nY_NP2o`0002;ooooo000`ooooo`?o00005?ooool00ol0003oZKgX
ojVmj002ojVmj006o`000?nY_NSo0000o`000?nY_NSo00001?nY_NP3o`0000;oZKgX00?o0000ojVm
j?nY_NP00_nY_NP3o`0000CoZKgX00?o0000ojVmj?nY_NP00ol00004ojVmj003o`000?nY_NSoZKgX
00?o00000onY_NP4o`0000?oLF>c00Go0000oiV6__nIQ[koVHJno`000003ohA<Q@05o`000?n4C8Go
0000olNba_l000000oo9_m400ol0003ob;G8o`000004olJnd`06o`000?o4]<_oa;C;o`000?o2_mOo
00001?o1]]02o`0000Go`;kI00?o0000okfgdol000000_nmcNH5o`0000;o/m[d00?o0000okG9jOne
bNT01?l00003ojS9l@03o`000?n^^>7o000000?o00000_n`[=<3o`0000Co[J?=00?o0000ok:Na?nb
W/@00_nbW/@2o`0000?o]9Rk00?o0000okZJ]onjV[L00_njV[L00ol0003o_YR`okjH/003okjH/003
o`000?nMQk_o000000?o`iR[00Go0000ofES^omUHk_o0000okbC[002o`000003odZ=k?l0003oT9WH
00?oT9WH00Go0000ok2K`_n`Vl;o/9_2o`000002olBN/P04o`000?o1W[Go`Ijeo`0000?odZ:V00Ko
0000om2QYoo@XJOo0000om>OX?l00004ooRiO`09o`000?n<EhgoS5N=ohaGSOl0003onK9`o`000?ol
]V[o000000;oS5J<0_l000001?ok/fOo0000oo^cIol00004oheGS@;o000000Conk=Uo`000?ok/fGo
00001?n>FHh2o`000003oo^bHol0003o000000CoSeZ?00?o0000oo^bH_l000001On?Fhl2o`0000Go
ZKgX0_l0000Qooooo`00<?ooool00ol0003oooooooooo`0Eooooo`03o`000?nY_NSoZKgX00Co0000
0onY_NP01?l0003oZKgXo`000?l00002ojVmj006o`000?nY_NSoZKgXojVmj?l0003oZKgX0_l00002
ojVmj003o`000?nY_NSoZKgX00;oZKgX0ol00002ojVmj003o`000?nY_NSoZKgX00;oZKgX0ol00003
ojVmj003o`000?nY_NSoZKgX00Co00000omaHk<00ol0003oVHJnoiV6_P02o`0000?oQ4b500Co0000
ohA<QOl0003o00001?o9_m42o`0000Goa[kC00?o0000olBdbol000000oo2_mL01?l0003o`KK@o`00
0?l00002ol38h003o`000?o0_]Wo`;kI00;o`;kI0_l00003okg=iP?o00001?ncf_@3o`0000CoUmgn
00?o0000ojS9lOl000000_l00002ojjhh@Co00000_nV[M`00ol0003o[J?=ojfSc@02ojfSc@04o`00
0?nbW/Co/Yk4ok:Na0;o00001?ndV;/01?l0003o^YZgokZJ]onjV[L2o`0000Ko_YR`00?o0000ol>H
Zoo3V:/00oo3V:/2o`0000?o_9>/1?l00003oi2If003o`000?n`Vl;o/9_200;o/9_20_l00004ol6N
]@04o`000?oBXZKodZ:Vo`0000;od:6W00?o0000om>OX?l000001Ooh^Gl00ol0003oS5N=o`000002
ooVbL003o`000?ol]V[o000000?oS5J<00Go0000oo^cIol0003onk=Wo`000004oheGS@;o000000Co
nk=Uo`000?ok/fGo00001?n>FHh2o`000003oo^bHol0003o000000CoSeZ?00Co0000oo^bH_l0003o
00001?n?Fhl3o`0000;oZKgX1?l0000Qooooo`001Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo1Ol00005ooooo`03o`000?oooooooooo01Oooooo0_l00004ojVmj003o`000?nY_NSo
ZKgX00?o00001?nY_NP00ol0003oZKgXojVmj003o`0000CoZKgX00Ko0000ojVmj?l0003o0000ojVm
j?l00004ojVmj006o`000?nY_NSo0000o`000?nY_NSo00001?nY_NP6o`000003o`00P?l0003oLF>c
00Co000000?o/K7Ho`000?n4C8D00_n4C8D2o`000003olK=gol0003obKoA00;obKoA00Co0000olG=
h?o5cN3o00001?o6_]<2o`0000Co`[oG0_l00005ol38h004o`000?o0_]Wo0000o`0000;o_MS]00?o
0000okg=i_l000001?l000000oncf_Co0000o`000003ofoMk`03o`000?nGgOkoUmgn00So00000_nH
_O400ol0003oYZgLojJ]g002ojJ]g006o`000?n]Xlgo[J?=ojfScOl0003o/Yk40_l000000on]V/?o
0000okBH^`03okBH^`04o`000?njV[Oo^YZgo`0000;o]iFd00?o0000okjH/?nnV;000onnV;000ol0
003o`iR[ol>HZ`03ol>HZ`03o`000?nlTjco_9>/00;o_9>/1?l00003oi2If004o`000?n`Vl;o/9_2
ok2K`P;o00001Oo1W[D00ol0003odZ:Vo`000003om2QY`;o000000?ofZ:Jo`000?oh^Gl00ooh^Gl0
0ol0003oS5N=o`000002ooVbL003o`000?ol]V[o000000?oS5J<00Go0000oo^cIol0003onk=Wo`00
0004oheGS@06o`000?ok/fGo0000o`000?ok/fGo00001?n>FHh00ol0003onk9So`000002o`0000Co
SeZ?00Co0000oo^bH_l0003o00001?n?Fhl2o`000003oo^bH?l0003o000000?oT5b@0_l00009oooo
o`Co000000?o410@ooooooooool04?ooool000Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003oooooooooo`0Hooooo`03o`00
0?nY_NSoZKgX00;oZKgX0ol00003ojVmj003o`000?nY_NSoZKgX00Co00000onY_NP00ol0003oZKgX
ojVmj003o`0000CoZKgX00?o0000ojVmj?nY_NP00ol00004ojVmj004o`000?nY_NSo0000o`0000;o
ZKgX1?l000000ol0083o0000o`000002ohbMg`05o`000?na/MSo/K7Ho`000?n4C8D00ol00003olK=
g`03o`000?o9_m7o000000CoaLgP00Ko0000olJndol0003o0000ol7;h_l00003ol:oe`04o`000?nn
dNWo_]7Yo`0000Co`<SP0ol00002okgHkAWo00000onH_O401Ol0003oYZgLojJ]g?nV[Mco000000;o
[J?=0ol00004ojfJ``03o`000?ndV;_o]9Rk00;o]9Rk0_l00003okNE]003o`000?nnV;3o_YR`00;o
_YR`0_l00005ol>HZ`03o`000?nlTjco_9>/00;o_9>/00?o0000olVIY?l000001?l000001_n@VMSo
0000o`000?l0003oYIc<o`0000Go`Ije00?o0000om:RY_l000001?o@XJL00ol0003ofZ:Jo`000004
ooRiO`03o`000?n<Ehgo000000;onK9`00Co0000oobfJ_ol]V[o00000_n<EX`3o`000003oo^cIol0
003oSEN=00?oSEN=00Ko0000oo^cIOl0003o0000oo^cIOl00004ohiISP03o`000?ok/V?o000000;o
00001?n?FXl01?l0003onk9Ro`000?l00004ohmKS`;o000000?onk9Po`000?n@G9001?n@G902o`00
00[ooooo00?o0000ooooooooool04_ooool000Gooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
V9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0Iooooo`06o`000?nY_NSo0000o`000?nY_NSo
00001?nY_NP3o`0000?oZKgX00?o0000ojVmj?nY_NP01?l00003ojVmj003o`000?nY_NSoZKgX00Co
00000onY_NP00ol0003oZKgXojVmj004o`0000CoZKgX0ol000000ol0083o0000ohbMg`03ohbMg`03
o`000?na/MSo000000Co00000oo6cMl3o`0000CoaLgP0_l00004ol7;hP03o`000?o2_mOo000000Co
_]7Y00Co0000ol38h?l0003o00000_nhh_@4o`0000;oV^kf1Ol00004oi:9a`Co000000?o[8fdo`00
0?mhNlT01?mhNlT<o`0000;oXioA00?o0000ojfJ`on]V/<00_n]V/<01?l0003o]9RkokBH^ondV;/2
o`0000Go]iFd00Co0000okjH/?nnV;3o00000_nlU:h01?l0003o`iR[ol>HZoo3V:/2o`0000Co_9>/
00Go0000olVIY?l0003oOfjfo`000002oen?j0;o00001?nUW<`00ol0003o`Ijeol6N]@02ol6N]@;o
00001Oo@XJL01?l0003ofZ:JomZRV_l00003ooRiO`03o`000?n<Ehgo000000;onK9`00Co0000oobf
J_ol]V[o00000_n<EX`00ol0003onk=Wo`000002oo^cI`06o`000?n=EhgoSEN=oheGSOl0003onk=U
0_l000000ook/fGo0000ohiISP03ohiISP03o`000?ok/V?o000000;o00001?n?FXl01?l0003onk9R
o`000?l00004ohmKS`;o000000?onk9Po`000?n@G9001?n@G902o`0000[ooooo00?o0000oooooooo
ool04_ooool000Gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?oV9RHob4Q8Oo^k^h01Oooool2
o`0001_ooooo0_l00003ojVmj004o`000?nY_NSo0000o`0000;oZKgX00Co0000ojVmj?nY_NSoZKgX
0ol00003ojVmj004o`000?nY_NSoZKgXojVmj0?o00001?nY_NP00ol0003oZKgXojVmj003o`0000Co
ZKgX00?o0000ojVmj?nY_NP01?l00002o`00P006o`000?n<WMooS9gOohbMgol0003o/K7H0_l00003
okCKm003o`000?o6cMoo000000?o^Moc00Ko0000olG=h?l0003o0000okOIlOl00004ol7;hP?o0000
1?nndNT3o`000003okSRm?l0003o000000;oR>_/1Ol000001?nEOkSo0000oiEo^?nEOkP4o`000003
oi:9aol0003o[8fd00?o[8fd00Co0000ogQkbOmhNlWoN7_90_l000000omBJLco0000o`000002oeF`
nP05o`000?n?ZNSoSjWXohnYj?l000001?nSWm401_l0003o[I[3ojfJ`on]V/?o0000okBH^`;o0000
00?o[iBjo`000?ngUK@01?ngUK@01?l0003o_YR`okjH/?l00002okbD[P07o`000?o3V:_o`iR[ol>H
Zol0003o`iJXo`000002okbC[004o`000?o9VJCobIVTo`0000;oOfjf00Co0000oen?j?mOSnSo0000
1?nUW<`01ol0003o`Ijeol6N]Oo1W[Go0000okbN^ol000001Oo@XJL01?l0003ofZ:JomZRV_l00003
ooRiO`03o`000?n<Ehgo000000;onK9`00Co0000oobfJ_ol]V[o00000_n<EX`01_l0003onk=Wo`00
0?l0003onk=Wo`0000?oSEN=00Co0000oo^cIOl0003onk=U0_l00004ohiISP06o`000?ok/V?o0000
o`000?ok/V?o00000on?FXl01?l0003onk9Ro`000?l00004ohmKS`;o000000?onk9Po`000?n@G900
1?n@G903o`0000Wooooo00?o0000ooooooooool04_ooool000Gooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`0Looooo`03o`000?nY_NSoZKgX
00?o00001?nY_NP00ol0003oZKgXo`000002ojVmj003o`000?nY_NSoZKgX00;oZKgX00?o0000ojVm
j?l000000_nY_NP00ol0003oZKgXojVmj002ojVmj0?o00000_nY_NP00ol0003oZKgXojVmj002ojVm
j0?o00000onY_NP;o`0000;o]=_d1?l00002okWOl`?o00001?ngfO401?l0003o`L_Ro`000?l00003
okCJl`04o`000?nndNWo0000o`0000;o[^Oi1ol00003oj25]P03o`000?nEOkSo000000?o00000onB
RLL2o`0000Co[8fd00Co0000ogQkbOmhNlWo00000_ngU;800ol0003oDVW<oe9Yc004o`0000?oSjWX
00Go0000oj>OdOnSWm7oXioAo`000003ojfJ``;o00001?n_U;X00ol0003o]iFdokNE]002okNE]003
o`000?nnV;3o000000?o_9B^00Co0000ol>HZoo3V:_o00000_o3UZP01?l0003o_9>/okbC[?l00002
olVIY004o`000?moK[Ko0000olNGYP;o000000?oGhoXo`000?nUW<`00_nUW<`01?l0003o`Ijeol6N
]Ol00002okbN^`03o`000?o@XJOod:6W00;od:6W0_l00002omZRVP07o`000?oh^Goon;UoooRiOol0
003oS5N=o`000002ooVbL004o`000?ol]V[oo;IZo`0000;oS5J<00Ko0000oo^cIol0003o0000oo^c
Iol00003oheGS@04o`000?ok/fGo0000oo^cI@;o00001?n>FHh01_l0003onk9So`000?l0003onk9S
o`0000CoSeZ?0ol00004ohmKS`;o000000?onk9Po`000?n@G9001?n@G9001?l0003onk5No`000?l0
0008ooooo`03o`000?oooooooooo01;ooooo0005ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4007ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool07Oooool2o`0000?oZKgX00?o0000ojVmj?nY
_NP00ol00004ojVmj003o`000?nY_NSoZKgX00?o00001?nY_NP01_l0003oZKgXo`000?l0003oZKgX
o`0000CoZKgX00Ko0000ojVmj?l0003o0000ojVmj?l00004ojVmj0?o00000onRP:l7o`0000;oO^7f
1Ol00002oi;Qo@03o`000?ngfO7o]mWa00Go00000_ndf_<4o`000003ojkWnOl0003o000000?o0000
0onLQKT01?l0003oX8Ffoj25]_nPQKH3o`0000;oUGnh00Ko0000oi:9aonBRLOo0000ojb9/?l00004
ojb=]003o`000?mhNlWo000000?o]iBb00Co0000oe9Yc?mBJLcoDVW<1ol00003oj>Od@06o`000?n]
V/?o0000o`000?nTU<Go00001?n_U;X00ol0003o]iFdokNE]003okNE]003o`000?nlU:ko_9B^00;o
_9B^00?o0000ol>HZol000000oo3UZP00ol0003o_9>/o`000004olVIY0;o00000_o7UjH3o`0000Co
YIc<0_l00004okbN^`07o`000?o@XJOod:6Wom2QYol0003oc:2Zo`000002omZRVP06o`000?oh^Goo
n;Uoo`000?n<Ehgo00000_oi/W001?l0003oo;IZoobfJ_l00002ohaFS004o`000?ok/fOo0000oo^c
I`;o00000on=Ehd01ol0003onk=Uo`000?ok/fGo0000oo^cIOl000000on>FHh01_l0003onk9So`00
0?l0003onk9So`0000CoSeZ?0ol00004ohmKS`;o000000?onk9Po`000?l000001?n@G9001?l0003o
nk5No`000?l00008ooooo`03o`000?oooooooooo01;ooooo0005ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0Nooooo`03o`00
0?nY_NSoZKgX00;oZKgX0ol00003ojVmj003o`000?nY_NSoZKgX00Co00000onY_NP00ol0003oZKgX
ojVmj004o`0000?oZKgX00?o0000ojVmj?nY_NP01?l00003ojVmj005o`000?nY_NSo0000o`000?nY
_NP00_l00005oj:0[`03o`000?nGQKkoUhFn00;oUhFn3Ol00002oi_No@Co00000_nKi_`5o`0000;o
ZIW600?o0000oib5^OnLQKT00_nLQKT3o`000003oj25]_l0003oUGnh00?oUGnh0_l00003ojb9/003
o`000?n/SKCo[8fd00;o[8fd00?o0000okND/_ngU;800_ngU;801?l0003oDVW<o`000?l00003ojJ=
^`03o`000?mDUo3oE9O`00Ko00000onTU<D00ol0003o[iBjojnD^P03ojnD^P04o`000?ngUKCo]iFd
okNE]0;o00001OnlU:h2o`0000?o`iJX00?o0000okbC[?l000001?o9VJ@00ol0003oaiNVolNGYP02
olNGYP03o`000?l0D/Wo000000Co00001OnlW[/01?l0003od:6Wom2QYol00002olbPZP04o`000?oJ
XY[o0000o`0000;on;Uo00?o0000ohaGSOl000000_oi/W001?l0003oo;IZoobfJ_l00002ohaFS003
o`000?ok/fOo000000;onk=W00_o0000oheGSOn=EhgoSEN=o`000?ok/fGo0000oo^cIOl0003onk=U
o`000003ohiISP06o`000?ok/V?o0000o`000?ok/V?o00001?n?FXl3o`0000CoSe^?0_l000000ook
/V3o0000o`000004oi1LT003o`000?ok/Eko000000;o00001oooool00ol0003oooooooooo`0Boooo
o`001Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo
00?o0000ooooooooool07oooool01?l0003oZKgXo`000?l00002ojVmj004o`000?nY_NSoZKgXojVm
j0?o00001?nY_NP00ol0003oZKgXojVmj003o`0000CoZKgX00?o0000ojVmj?nY_NP00ol00004ojVm
j003o`000?nY_NSoZKgX00?o00000_nY_NP2o`0000CoXX2_00?o0000olRKZ?l000001?nGQKh00ol0
003odjbbo`000002ocAQd@[o00000_mjf_`5o`000003ok_9iOl0003oZIW600?oZIW61Ol00003oj25
]P04o`000?nEOkSoUGnhoiEo^0;o00001?n/RK000ol0003o[8fdojb=]002ojb=]003o`000?ngU;;o
]iBb00?o]iBb00?o0000ojJ=^onVSK/00onVSK/2o`0000;oE9O`00Go0000ohjHf?n>V=SoSYSHo`00
0004ojBDa@03o`000?n_U;[o[iBj00;o[iBj00Ko0000okNE]?ngUKCo0000okBA/_l00005okbD[P03
o`000?o3UZSo`iJX00?o`iJX0_l00004olVIY003o`000?o7UjKoaiNV00;oaiNV0ol00003ohVHf`03
o`000?nlW[_o_9jk00?o_9jk00Co0000om2QYoo@XJOo00000_o<X:X01?l0003ofZ:Jo`000?l00002
ooRiO`03o`000?n<Ehgo000000;onK9`00Co0000oobfJ_ol]V[o00000_n<EX`00ol0003onk=Wo`00
0002oo^cI`;o00000_n=Ehd01ol0003onk=Uo`000?ok/fGo0000oo^cIOl000000on>FHh01_l0003o
nk9So`000?l0003onk9So`0000CoSeZ?00Co0000oo^bH_l0003o00000on?Fhl00ol0003onk9Po`00
0002o`0000CoT5b@00Ko0000oo^aG_l0003o0000ooooool00004ooooo`03oeEEEOmVIVKo000001Co
oooo000^ooooo`;o00008Oooool2o`0000CoZKgX00?o0000ojVmj?l000000_nY_NP00ol0003oZKgX
ojVmj002ojVmj0?o00000_nY_NP00ol0003oZKgXojVmj002ojVmj0?o00000onY_NP00ol0003oZKgX
ojVmj004o`0000?oZKgX00?o0000ojVmj?l000000_l00003oj:0[`03o`000?o8VjSo000000?oUhFn
00Co0000om>//_oC[;;odjbb0_l00003ojNhi@03o`000?lNSn_o000000Wo00001?nkbND00ol0003o
ZIW6o`000002o`0000?oW8Fi00?o0000oj25]_nPQKH00_nPQKH3o`000003ojJ4/?l0003o[8V`00?o
[8V`00Co0000ojb=]?n/SKCo[8fd0_l00005okND/P03o`000?nVSK_oYXfk00?oYXfk00Ko0000ol^N
ZOl0003o0000oeBGl?l00003ohjHf005o`000?nTU<GoY9C5ojBDaOl000001?n_U;X00ol0003o]iFd
o`000003okBA/P03o`000?nlU:ko_9B^00;o_9B^00?o0000ol>FZ?o3UZP00oo3UZP00ol0003obIVT
olVIY002olVIY0;o00000oo7UjH00ol0003odYfOom:MW`02o`0000?oRISK00?o0000okbN^onlW[/0
0_nlW[/00ol0003od:6Wo`000003olbPZP04o`000?oJXY[o0000o`0000;on;Uo00?o0000ohaGSOl0
00000_oi/W001?l0003oo;IZoobfJ_l00002ohaFS003o`000?ok/fOo000000;onk=W0_l00002oheG
S@07o`000?ok/fGo0000oo^cIOl0003onk=Uo`000003ohiISP06o`000?ok/V?o0000o`000?ok/V?o
00001?n?FXl01?l0003onk9Ro`000?l00004ohmKS`Co00001?n@G9001_l0003onk5No`000?l0003o
ooooo`0001_ooooo000^ooooo`03o`000?oooooooooo02;ooooo00?o0000ojVmj?nY_NP00ol00004
ojVmj006o`000?nY_NSo0000o`000?nY_NSo00001?nY_NP01_l0003oZKgXo`000?l0003oZKgXo`00
00CoZKgX0ol00003ojVmj003o`000?nY_NSoZKgX00Ko00000_nRP:l01ol0003ob9^XolRKZ?o8VjSo
0000oiN5__l000001?oC[;82o`0000?oYkSU2?l000001On<c_ko0000okO;jOngbnWo000000?o^lWU
0_l00002ojVIaP05o`000?nLQKWoW8Fioib5^Ol000000onPQKH2o`0000?oYXB`00?o0000ojb9/?n/
RK000_n/RK001?l0003o[8fdojb=]?l00002okJ>[@07o`000?ngU;;o]iBbokND/_l0003o`9J[o`00
0003ojJ=^`05o`000?o;WZWobijYo`000?l09Zd00_l00003ohjHf005o`000?nTU<GoY9C5ojBDaOl0
00001?n_U;X2o`0000Co]96b00Co0000okbD[_nlU:ko_9B^0_l00005ol>FZ003o`000?o9VJCobIVT
00;obIVT00?o0000olZHXol000000_o7UjH00ol0003odYfOom:MW`02o`0000?oRISK00?o0000okbN
^onlW[/00onlW[/2o`0000Coc:2Z00So0000omRQW?oHXIco0000ooRiOol0003oS5N=o`0000;onK9`
00Co0000oobfJ_ol]V[o00000_n<EX`00ol0003onk=Wo`000002oo^cI`0;o`000?n=Ehgo0000oheG
SOl0003onk=Uo`000?ok/fGo0000oo^cIOl000000on>FHh01?l0003onk9So`000?ok/V<2o`0000Co
SeZ?00Co0000oo^bH_l0003o00001?n?Fhl4o`0000CoT5b@00Co0000oo^aG_l0003o00000_ooool0
0ol0003oooooooooo`0Hooooo`00;_ooool00ol0003oooooooooo`0Sooooo`;o00000onY_NP00ol0
003oZKgXojVmj003o`0000CoZKgX00?o0000ojVmj?nY_NP00ol00004ojVmj006o`000?nY_NSo0000
o`000?nY_NSo00001?nY_NP3o`0000;oZKgX0_l000001OmS>X_o0000oj:0[onRP:oo000000?ob9^X
00?o0000oiN5__l000000ooC[;801_l0003oh/6gon;1]ol0003oYkSUo`0000?o`NOa00?o0000og:Q
k_mbXNh00ol00004okO;j@?o000000?o^lWUo`000?nYVLH00_nYVLH01?l0003oW8Fioib5^OnLQKT3
o`000003oin0/_l0003oYXB`00?oYXB`00?o0000ojb9/?n/RK000_n/RK02o`0000?o]Xj]00Co0000
okND/_ngU;;o00000_o0UZ/01Ol0003oYXfkojJ=^onVSK_o000000?obijY1ol00004ojBDa@Co0000
00?oZHnjo`000?ndTK800ondTK801?l0003o_9B^okbD[_l00002ok^B[004o`000?o3UZSo`iJXol>F
Z0;o00001?o9VJ@00ol0003obYRSo`000002olNGYP04o`000?oBWIoodYfOom:MW`?o00000_n9V=/0
1?l0003o_9jkokbN^onlW[/2o`0000Goc:2Z00So0000omRQW?oHXIco0000ooRiOol0003oS5N=o`00
00;onK9`00Co0000oobfJ_ol]V[o00000_n<EX`00ol0003onk=Wo`000002oo^cI`03o`000?n=Ehgo
SEN=00;o000000Konk=Uo`000?ok/fGo0000oo^cIOl00003ohiISP04o`000?ok/V?o0000oo^bH`;o
00001?n?FXl01?l0003onk9Ro`000?l00004ohmKS`;o000000?onk9Po`000?n@G9000on@G9000ol0
003onk5No`000002o`0000;ooooo00?o0000ooooooooool05oooool002kooooo00?o0000oooooooo
ool09Oooool00ol0003oZKgXojVmj003o`0000?oZKgX00?o0000ojVmj?nY_NP01?l00003ojVmj003
o`000?nY_NSoZKgX00Co00000onY_NP01?l0003oZKgXo`000?l00002ojVmj003o`000?nY_NSoZKgX
00;o000000CoHcZ;o`000?nRP:oo00001Oo8VjP00ol0003odjbbom>//P02om>//P04o`000?oR`KOo
h/6gon;1]`;o00000_o1io44o`0000?oX9oD4Ol00003oin0/P03o`000?nVQ;3oYXB`00;oYXB`00Co
0000ojb9/?n/RK3o[8V`0_l00004okJ>[@04o`000?ngU;;o]iBbo`0000?o`9J[00?o0000ojJ=^ol0
00001?o;WZT01?l0003oNGK4ogUfa?l00002ofJ7gPKo00001?nYSkX00ol0003o]96bokBA/P03okBA
/P;o00000onkTZ`01ol0003o`iJXol>FZ?o3UZSo0000ol>DYol000000_o9VJ@01_l0003obYRSolZH
Xol0003oaiNVo`0000CodYfO0_l000001OljO>Co0000o`000?l0003o_9jk00;o000000?o[ig5o`00
0?o<X:X01?o<X:X01?l0003of:6LomRQW?l00002ooRiO`;o00000_oi/W001?l0003oo;IZoobfJ_l0
0002ohaFS003o`000?ok/fOo000000?onk=W00[o0000oheGSOl0003o0000oo^cIOl0003onk=Uo`00
0?ok/fGo00000on>FHh01?l0003onk9So`000?ok/V<2o`0000CoSeZ?00Co0000oo^bH_l0003o0000
1?n?Fhl2o`000003oo^bH?l0003oT5b@00CoT5b@1?l00002ooooo`03o`000?oooooooooo01Oooooo
000]ooooo`03o`000?oooooooooo02Oooooo0_l00002ojVmj004o`000?nY_NSoZKgXojVmj0?o0000
1?nY_NP00ol0003oZKgXojVmj003o`0000CoZKgX00?o0000ojVmj?nY_NP00ol00004ojVmj005o`00
0?nY_NSo0000o`000?mS>X/00ol00005olRKZ005o`000?oC[;;odjbbom>//_l000001?oR`KL01?l0
003ol^6ko`000?l00002oiB@c@03o`000?nPWmCoX9oD00Go00000_nb^n001Ol0003oMH?CogF3dome
Pm?o000000;oRWg000Go0000oiIm]_nFOKKoUWffo`000004oin0/P05o`000?nVQ;3oYXB`ojJ4/?l0
00000_n/RK000ol0003o[hR/o`000005okJ>[@;o00001?o0UZ/00ol0003oYXfko`000003ol^NZ@03
o`000?o?WZGo000000;oNGK400Co0000ofJ7g_mVQmko00000onESLP00ol0003oZHnjojV?^P03ojV?
^P03o`000?ndTK;o]96b00;o]96b00?o0000ok^B[?nkTZ`00_nkTZ`01?l0003o`iJXol>FZ?l00002
ol>DY`04o`000?o9VJCobIVTo`0000;obYRS00?o0000olNGY_l000001?oBWIl00ol0003o_Y>Yo`00
0003ocYli005o`000?n_WLGo[ig5ojnMaOl000001?o<X:X01Ol0003oain`o`000?oHXIco000000;o
n;Uo0_l00002ooVbL005o`000?ol]V[oo;IZoobfJ_l000000_n<EX`2o`0000?onk=W00[o0000oheG
SOn=Ehgo0000oo^cIOl0003onk=Uo`000?ok/fGo00000on>FHh01ol0003onk9So`000?ok/V?o0000
oo^bHol000000on?FXl01?l0003onk9Ro`000?l00004ohmKS`;o000000?onk9Po`000?l000001?n@
G904o`0000?ooooo00?o0000ooooooooool05_ooool002gooooo00?o0000ooooooooool09oooool0
0ol0003oZKgXojVmj002ojVmj003o`000?nY_NSo000000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP3
o`0000?oZKgX00?o0000ojVmj?nY_NP01?l00003ojVmj003o`000?nY_NSoZKgX00Go00000_mS>X/0
0ol0003ob9^XolRKZ003olRKZ003o`000?oFZ:Wo000000;odjbb00Go0000on;1]ooR`KOoh/6go`00
0002oo;Q^`04o`000?nDT<goU93=oiB@c@?o000000CoX9oDo`000?neW;ko00001?nb^n001?l0003o
MH?CogF3dol00002ohYm`005o`000?nFOKKoUWffoiIm]_l000001?nOP;800ol0003oYXB`ojJ4/002
ojJ4/0;o00000_n_R:`00ol0003o]Xj]okJ>[@03okJ>[@03o`000?o0UZ_o`9J[00Co`9J[00?o0000
ol^NZOo;WZT00_o;WZT00ol0003ocijUo`000003ogUfa004o`000?mVQmkoIXONo`0000?oUHg800?o
0000ojV?^_nYSkX00_nYSkX01?l0003o]96bokBA/_ndTK82o`0000Co^i:/00?o0000ol>FZ?l00000
0oo3U:L00ol0003obIVTo`000003olZHX`03o`000?o7UjKo000000CodYfO0_l000001OnnTjWo0000
o`000?ljO>Co000000Co[ig500Oo0000olbPZ_o<X:[oc:2Zo`000?o7Wk3o000000;of:6L00Co0000
ooRiOol0003o00000_oi/W001Ol0003oo;IZoobfJ_ol]V[o000000;oS5J<0_l00003oo^cI`03o`00
0?n=EhgoSEN=00?o000000Conk=Uo`000?ok/fGo00000on>FHh01ol0003onk9So`000?ok/V?o0000
oo^bHol000000on?FXl01?l0003onk9Ro`000?l00004ohmKS`;o000000?onk9Po`000?l000001?n@
G904o`0000Cooooo00?o0000ooooooooool05Oooool002gooooo0_l0000Yooooo`03o`000?nY_NSo
ZKgX00?o00001?nY_NP01_l0003oZKgXo`000?l0003oZKgXo`0000CoZKgX0ol00002ojVmj003o`00
0?nY_NSoZKgX00;oZKgX0ol00003ojVmj0;o00000_mS>X/00ol0003ob9^XolRKZ003olRKZ005o`00
0?oFZ:Wo0000om>//_l000000ooR`KL01Ol0003ol^6koo;Q^ol0003of?FN00?o000000CoU93=o`00
0?nPWmCo00000oneW;h01Ol0003o/[_Pok:kh?nb^n3o000000?oMH?C00Co0000ohYm`?n:OL3o0000
0onFOKH01Ol0003oWh2boin0/_nOP;;o000000?oYXB`0_l00004ojn8[003o`000?nfSZgo]Xj]00;o
]Xj]00?o0000ol2FZoo0UZ/01?o0UZ/00ol0003obijYol^NZ@02ol^NZ@03o`000?o?WZGo000000;o
NGK400?o0000okRG]_l000000_l00003oiF=b003o`000?nYSk[oZHnj00;oZHnj00Ko0000okBA/_nd
TK;o0000ok2>/_l00005ok^B[0;o00000oo3U:L00ol0003obIVTo`000004olZHX`03o`000?oBWIoo
dYfO00;odYfO00?o0000omBNW_l000000_nnTjT2o`000003ocYli?l0003o[ig500;o[ig500Co0000
olbPZ_o<X:[o00000_o7Wk001Ol0003of:6LomRQW?l0003on;Uo00;o00000_oi/W001Ol0003oo;IZ
oobfJ_ol]V[o000000;oS5J<0_l00003oo^cI`08o`000?n=EhgoSEN=o`000?ok/fGo0000oo^cIOl0
0002oo^cI@0:o`000?n>FHkoSUV>o`000?ok/V?o0000oo^bHol0003onk9So`0000?oSeZ?00Co0000
oo^bH_l0003o00001?n?Fhl2o`000003oo^bH?l0003o000000CoT5b@00Co0000oo^aG_l0003o0000
1?ooool00ol0003oooooooooo`0Eooooo`00;Oooool00ol0003oooooooooo`0Yooooo`;o00000onY
_NP00ol0003oZKgXojVmj004o`0000?oZKgX00Ko0000ojVmj?l0003o0000ojVmj?l00004ojVmj006
o`000?nY_NSo0000o`000?nY_NSo00001?nY_NP2o`0000;oHcZ;00?o0000olRKZ?o8VjP00_o8VjP0
1_l0003oeZRYomJXZOl0003odjbbo`0000;oh/6g00?o0000oo;Q^oobhK/01?l00002oiB@c@?o0000
1OneW;h6o`000005ogF3dol0003oRWg0ohYm`?l000000onFOKH01Ol0003oWh2boin0/_nOP;;o0000
00;oYXB`00?o0000ojN2[?l000001?n_R:`01ol0003o]Xj]okJ>[OnfSZgo0000okV>ZOl000001?o0
UZ/2o`0000?obijY00Co0000olnNYOo?WZGocijU0_l00002okRG]P04o`000?lCG=Co0000o`0000?o
UHg800?o0000ojV?^_nYSkX00_nYSkX2o`0000?o/8jb00?o0000ok^B[?nkTZ`00_nkTZ`00ol0003o
`iBWol>DY`03ol>DY`;o00001?o:V:<00ol0003odYfOom:MW`02om:MW`03o`000?oDWYko000000;o
_Y>Y1?l00003ojnMa@03o`000?o<X:[o000000Coain`00Co0000omRQW?l0003on;Uo0_l00002ooVb
L005o`000?ol]V[oo;IZoobfJ_l000000_n<EX`00ol0003onk=Wo`000002oo^cI`08o`000?n=Ehgo
SEN=o`000?ok/fGo0000oo^cIOl00002oo^cI@0:o`000?n>FHkoSUV>o`000?ok/V?o0000oo^bHol0
003onk9So`0000?oSeZ?00Co0000oo^bH_l0003o00001?n?Fhl2o`000003oo^bH?l0003o000000Co
T5b@00Co0000oo^aG_l0003o00001Oooool00ol0003oooooooooo`0Dooooo`00;Oooool00ol0003o
ooooooooo`0[ooooo`03o`000?nY_NSoZKgX00?o00001?nY_NP00ol0003oZKgXojVmj003o`0000?o
ZKgX00?o0000ojVmj?nY_NP01?l00003ojVmj003o`000?nY_NSo000000?o00000omS>X/01Ol0003o
b9^XolRKZ?o8VjSo000000?oeZRY00Co0000on;1]ooR`KOoh/6g1Ol00002ogiV[@;o00000_nKOk<0
0ol0003o]IbnokFL_P03okFL_P;o00000_n7V]l01?l0003o95S>o`000?l00002ohYm`005o`000?nF
OKKoUWffoiIm]_l000001?nOP;82o`0000;oYh:/00?o0000ojn8[?n_R:`00_n_R:`01?l0003o]Xj]
okJ>[Ol00002okV>Z@03o`000?o0UZ_o`9J[00;o`9J[00?o0000olBFYol000000_o;WZT01Ol0003o
cijUolnNYOo?WZGo000000Co^9Nf00?o0000oa=Le?l000000onESLP00ol0003oZHnjojV?^P03o`00
00Co/8jb00?o0000ok^B[?nkTZ`00_nkTZ`00ol0003o`iBWol>DY`03ol>DY`03o`000?o:V:?obYRS
00?obYRS00?o0000om:MWooBWIl00_oBWIl01Ol0003oe9jNomBNW_l0003o_Y>Y00;o000000?o01VG
o`000?n_WLD00on_WLD2o`0000Coain`00Co0000omRQW?l0003on;Uo0_l00002ooVbL005o`000?ol
]V[oo;IZoobfJ_l000000_n<EX`00ol0003onk=Wo`000002oo^cI`05o`000?n=EhgoSEN=o`000?ok
/fD00ol00002oo^cI@0:o`000?n>FHkoSUV>o`000?ok/V?o0000oo^bHol0003onk9So`0000?oSeZ?
00Go0000oo^bH_l0003onk9Ro`000003ohmKS`;o000000?onk9Po`000?l000001?n@G9001?l0003o
nk5No`000?l00004ooooo`03o`000?oooooo000001Gooooo000]ooooo`03o`000?oooooooooo02co
oooo0_l00003ojVmj003o`000?nY_NSoZKgX00Co00000onY_NP00ol0003oZKgXojVmj003o`0000Co
ZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000o`000003of<jR`04o`000?o8VjSob9^Xo`00
00CoeZRY1?l00002oo;Q^`?o00000_mnIZd00ol0003oVgncoi]o/`02oi]o/`05o`000?neW;ko]Ibn
okFL__l000000_o1V[001Ol0003oQi[OohNJgol0003o95S>00;o000000?oRWg0o`000?nFOKH00_nF
OKH01?l0003oWh2boin0/_nOP;82o`0000CoYh:/00Go0000ojn8[?n_R:co[hR/o`000002okJ>[@04
o`000?niSZWo^HjYo`0000?o`9J[00Ko0000olBFYoo4UZOo0000ol^NZOl00004olnNY@03o`000?nh
UkKo^9Nf00;o^9Nf0_l000000olCG=Co0000o`000004o`0000;oWhVl00?o0000ok2>/_n`S[800_n`
S[801?l0003o^i:/ok^B[?nkTZ`2o`0000Go`iBW00?o0000olZHXoo:V:<00oo:V:<2o`0000?odYfO
00?o0000omBNW_oDWYh00_l00002om^SV`03o`000?l06IOo000000Co00001Oo7Wk001?l0003of:6L
o`000?oh^Gl2o`0000;onK9`00Go0000oobfJ_ol]V[oo;IZo`000002ohaFS003o`000?ok/fOo0000
00;onk=W00So0000oheGSOn=Ehgo0000oo^cIOl0003onk=Uo`0000;onk=U00[o0000ohiIS_n>FHko
0000oo^bHol0003onk9So`000?ok/V?o00000on?FXl01Ol0003onk9Ro`000?ok/V;o000000?oSe^?
0_l000000ook/V3o0000o`000004oi1LT003o`000?ok/Eko000000;o00001Oooool00ol0003ooooo
ooooo`0Cooooo`00;Oooool00ol0003oooooooooo`0/ooooo`03o`000?nY_NSoZKgX00;oZKgX0ol0
0003ojVmj003o`000?nY_NSoZKgX00Co00000onY_NP00ol0003oZKgXojVmj004o`0000?oZKgX0ol0
0003of<jR`04o`000?o8VjSob9^Xo`0000?oeZRY1ol000001_ofji7o0000okoDG_l0003oOVJ]o`00
00CoVgnc00Co0000okFL__neW;ko00001?o1V[03o`0000;o95S>1?l00003oiIm]P?o000000?oW7b_
o`000?nWPZ`00onWPZ`00ol0003o[hR/ojn8[002ojn8[0;o00001?niSZT01?l0003o`9J[ol2FZol0
0002olBFY`03o`000?o;WZWo000000?ocijU0_l00003okRG]P05o`000?oCXjKo0000oa=Le?l00000
0omlPLd01Ol0003oWhVloin9_?nORKco000000Co/8jb00Co0000ok^B[?nkTZco00000_niT:`01ol0
003o`iBWol>DYoo3U:Oo0000ol>DY_l000000oo:V:<00ol0003oc9VRo`000002om:MW`04o`000?oD
WYkoe9jNomBNWP;o00000ooKXi/2o`0000?oTIOF00?o0000olNO/?o7Wk001?o7Wk000ol0003oeJ2O
o`000002o`0000;onK9`00Go0000oobfJ_ol]V[oo;IZo`000002ohaFS003o`000?ok/fOo000000;o
nk=W00Oo0000oheGSOn=Ehgo0000oo^cIOl0003onk=U00;o000000_onk=Uo`000?n>FHkoSUV>o`00
0?ok/V?o0000oo^bHol0003onk9So`000003ohmJS`05o`000?ok/V;o0000oo^bH_l000000on?Fhl2
o`000003oo^bH?l0003o000000CoT5b@00?o0000oo^aG_l000000_l00006ooooo`03o`000?oooooo
oooo01;ooooo000/ooooo`?o0000;_ooool01_l0003oZKgXo`000?l0003oZKgXo`0000CoZKgX0ol0
0002ojVmj003o`000?nY_NSoZKgX00;oZKgX0ol00003ojVmj003o`000?nY_NSoZKgX00Co00000omS
>X/01?l0003ob9^Xo`000?oFZ:T4o`0000;oi[^Z00?o0000ooOEZ?ogeJP00_l00002okoDGP04o`00
0?mnIZgoOVJ]o`0000?oVgnc00?o0000okFL__l000001Oo1V[001_l0003oO8KBogb6d_l0003o95S>
o`0000;oLFk01Ol00003oial[`03o`000?nWPZcoYh:/00;oYh:/00?o0000ojn8[?n_R:`00_n_R:`0
0ol0003o^HjYokV>Z@03okV>Z@03o`000?o0UZ_o000000Coa9JW0_l00003olnNY@03o`000?oBWj;o
000000;o^9Nf00Ko0000om>SY_oCXjKo0000oa=Le?l00002ogb1c@03o`000?nORKcoWhVl00;oWhVl
00Go0000ok2>/_n`S[;o/8jbo`000002ok^B[004o`000?niT:co^I2/o`0000?o`iBW00?o0000ol>D
Y_l000000oo:V:<00ol0003oc9VRo`000002om:MW`03o`000?oDWYkoe9jN00;oe9jN00Co0000om^S
VooKXi_ofj>K0ol00003oi6GeP03o`000?o7Wk3oain`00;oain`0_l000001?oEX9oo0000o`000?l0
0002ooVbL005o`000?ol]V[oo;IZoobfJ_l000000_n<EX`00ol0003onk=Wo`000002oo^cI`07o`00
0?n=EhgoSEN=o`000?ok/fGo0000oo^cI@02o`00000;oo^cIOl0003oSUV>ohiIS_l0003onk9So`00
0?ok/V?o0000oo^bHol000000on?FXl01Ol0003onk9Ro`000?ok/V;o000000?oSe^?0_l000001?ok
/V3o0000oo^bH?l00003oi1LT003o`000?ok/Eko000000;o00001_ooool00ol0003oooooooooo`0B
ooooo`00;?ooool00ol0003oooooooooo`0_ooooo`;o00000onY_NP01?l0003oZKgXo`000?l00002
ojVmj006o`000?nY_NSoZKgXojVmj?l0003oZKgX0_l000000onY_NSo0000ojVmj003ojVmj0?o0000
0_nY_NP2o`0000CoHcZ;0ol00002omJXZ@04o`000?oV^j[oi[^Zo`0000;ommFX00?o0000ooK[TOl0
00000_noe5h01?l0003oOVJ]ogiV[Ol00004oi]o/`03o`000?o1V[3o`IZ`00?o`IZ`00Go0000olRJ
Yol0003oO8KBo`000002obAHcP03o`000?maK/3o000000?oSGJd00?o0000oial[onLO:l00_nLO:l0
1Ol0003oYh:/ojN2[?nWPZco000000?o[hR/0_l00005okV>Z@03o`000?o0UZ_o000000Coa9JW00?o
0000olnNYOo?WZD00_o?WZD01Ol0003odYnRo`000?nhUkKo000000?odj>V0ol00003ogb1c@05o`00
0?nORKcoWhVloin9_?l000001?n`S[82o`0000?o^I2/00Co0000ol>DYoo3U:Oo00000_o3U:H01Ol0
003obYRSolZHXoo:V:?o000000;oc9VR00?o0000om:MWol000001?oDWYh01?l0003ofj>Kom^SVol0
0002omfUVP05o`000?nAUmKoTIOFoi6Ge_l000000oo7Wk001?l0003o_9jio`000?oEX9l3o`0000;o
nK9`00Go0000oobfJ_ol]V[oo;IZo`000002ohaFS003o`000?ok/fOo000000;onk=W00Wo0000oheG
SOn=Ehgo0000oo^cIOl0003onk=Uo`000?ok/fD00_l00002ohiISP05o`000?ok/V?o0000oo^bHol0
00000_ok/V<02?l0003oSeZ?ohmJSol0003onk9Ro`000?ok/V;o00000on?Fhl2o`000004oo^bH?l0
003onk9Po`0000?oT5b@00?o0000oo^aG_l000000_l00004ooooo`04o`000?ooooooooooo`0001?o
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l000000ol@413ooooooooo
o`04ooooo`03o`000?oooooooooo037ooooo00?o0000ojVmj?nY_NP00ol00004ojVmj003o`000?nY
_NSoZKgX00?o00000onY_NP01_l0003oZKgXo`000?l0003oZKgXo`0000?oZKgX0_l000000omS>X_o
0000o`000002o`0000CoeZRY00Co0000onJkZ_oV^j[o00000_ogeJP4o`000005okoDG_l0003oOVJ]
ogiV[Ol000000onKOk<2o`0000Go`IZ`00?o0000olRJYol000000_mlQ]800ol0003o95S>o`000002
og5^`004o`000?n=M[CoSGJdo`0000CoW7b_00Go0000ojN2[?nWPZcoYh:/o`000002ojn8[003o`00
0?naQjWo000000Ko^HjY00?o0000olBFYoo4UZL00oo4UZL01Ol0003ocijUolnNYOo?WZGo000000;o
dYnR00?o0000okRG]_l000000_oCXjH01?l0003og:NNo`000?l00003ogb1c@05o`000?nORKcoWhVl
oin9_?l000000on`S[82o`0000Co^I2/00Co0000ol>DYoo3U:Oo00000oo3U:H00ol0003obYRSo`00
0003olbIXP03o`000?oBWIoo000000Coe9jN00Co0000om^SVooKXi_o00000ooMYIX2o`000005oi6G
e_l0003oain`olNO/?l000000_nlW[T00ol0003oeJ2Oo`000002o`0000;onK9`00Go0000oobfJ_ol
]V[oo;IZo`000002ohaFS003o`000?ok/fOo000000?onk=W00Oo0000oheGSOl0003onk=Uo`000?ok
/fGo000000;onk=U00So0000ohiIS_n>FHko0000oo^bHol0003onk9So`0000;onk9S00So0000ohmJ
Son?FXoo0000oo^bH_l0003onk9Ro`0000?oSe^?0_l000001?ok/V3o0000oo^bH?l00003oi1LT003
o`000?ok/Eko000000;o00001?ooool01Ol0003ooooooooooooooooo000001;ooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0booooo`;o00000onY_NP00ol0003oZKgXojVmj004o`0000?oZKgX00?o0000ojVmj?nY_NP0
0ol00003ojVmj003o`000?nY_NSo000000?o00000omS>X/01Ol0003oeZRYomJXZOoFZ:Wo000000?o
i[^Z00?o0000ooOEZ?ogeJP00ol000000omJ?iSo0000o`000002ogiV[@06o`000?nKOk?oVgnco`00
0?n/Q:Wo00001?o1V[001?l0003ob9ZWolRJYol00002ogb6dP?o00000_maK/001Ol0003oSGJdohef
]?n=M[Co000000?oW7b_00?o0000ojN2[?nWPZ`00_nWPZ`2o`0000?o/HNY00?o0000okV>ZOniSZT0
0oniSZT00ol0003oa9JWolBFY`02olBFY`;o00000oo?WZD01?l0003odYnRom:OX_oBWj82o`0000;o
dj>V00?o0000ombWW_oLYih00ol000000omlPLgo0000oin9_003oin9_0?o000000?oZh^co`000?ni
T:`00oniT:`00ol0003o`iBWo`000004ol>DYP03o`000?o:V:?o000000?oc9VR00?o0000om:MWol0
00000ooDWYh01Ol0003oeZ2No`000?oKXi_o000000?ogJFJ00?o0000oc]egol000000ol00004okbN
^@04o`000?oEX9oo0000o`0000;onK9`00Go0000oobfJ_ol]V[oo;IZo`000002ohaFS003o`000?ok
/fOo000000?onk=W00Oo0000oheGSOl0003onk=Uo`000?ok/fGo000000;onk=U0_l000001_n>FHko
0000oo^bHol0003onk9So`0000;onk9S00So0000ohmJSon?FXoo0000oo^bH_l0003onk9Ro`0000?o
Se^?0_l000001?ok/V3o0000oo^bH?l00003oi1LT003o`000?ok/Eko000000;o00001?ooool01Ol0
003ooooooooooooooooo000001;ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00Wooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool5o`0000Kooooo00?o0000ooooooooool0<oooool00ol0003oZKgXojVmj004o`0000?oZKgX00?o
0000ojVmj?nY_NP01?l00003ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?mS>X/00_mS
>X/00ol0003oeJ6Qo`000002omJXZ@04o`000?oV^j[oi[^Zo`0000;ommFX1?l000001?mJ?iSo0000
okoDG_l00002ogiV[@;o00000on/Q:T01?l0003o`IZ`ol6J/?l00004olRJY`;o00000_nDR<@2o`00
0003og5^`?l0003oSGJd00;oSGJd00Go0000oial[onLO:ooW7b_o`000004ojN2[003o`000?naQjWo
/HNY00;o/HNY00?o0000okV>ZOniSZT00_niSZT2o`0000Coa9JW00?o0000olRGY?l000000_o?WZD0
1Ol0003odYnRom:OX_oBWj;o000000?odj>V00?o0000ombWW_oLYih00_l000001Om>J/oo0000o`00
0?l0003oWhVl00?o00000on[Rk<00ol0003o^I2/okV@[003okV@[0;o00001?o3U:H00ol0003obYRS
o`000004olbIXP03o`000?oDWYkoe9jN00;oe9jN00Go0000omJPW_l0003ofj>Ko`000002omfUVP03
o`000?oPZ9[o000000;o>gGO00?o0000okbN^OnlW[T00onlW[T01?l0003oeJ2Oo`000?l00002ooVb
L003o`000?ol]V[oo;IZ00;oo;IZ00Go0000ohaFS?l0003onk=Wo`000003oo^cI`07o`000?n=Ehgo
0000oo^cIOl0003onk=Uo`000003oo^cI@03o`000?n>FHkoSUV>00;o000000Gonk9So`000?ok/V?o
nk9So`000002ohmJS`05o`000?ok/V;o0000oo^bH_l000000on?Fhl2o`000004oo^bH?l0003onk9P
o`0000?oT5b@00?o0000oo^aG_l000000_l00004ooooo`03o`000?oooooo000000?o00004Oooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04odA4A?oMgMgoooooo`0000Oooooo
0_l0000eooooo`;o00000onY_NP00ol0003oZKgXojVmj004o`0000?oZKgX00?o0000ojVmj?nY_NP0
1?l00003ojVmj0;o00000omS>X/00ol0003oeJ6Qo`000002omJXZ@04o`000?oV^j[oi[^Zo`0000;o
mmFX1Ol000001?mJ?iSo0000o`000?mnIZd2o`0000Co[8BY00Co0000ol6J/?o1V[3o00001?o8VZL0
0ol0003oU8S4oiB8a002oiB8a0;o000000GoLFk0o`000?n=M[CoSGJdo`000003oial[`04o`000?nW
PZcoYh:/ojN2[0;o00001?naQjT01Ol0003o^HjYokV>ZOniSZWo000000;o_8nV00Co0000olBFYoo4
UZOo00000_o8Uj@00ol0003ocijUo`000004om:OXP05o`000?oCXjKodj>Vom>SY_l000000_oLYih3
o`0000;oCV[?0_l00002oi63`003o`000?n[Rk?oZh^c00;oZh^c00?o0000okV@[?niT:`00_niT:`0
0ol0003o`iBVol>DYP04ol>DYP03o`000?o<VJ;oc9VR00?oc9VR00?o0000omBNW_oDWYh00_oDWYh0
1Ol0003oeZ2No`000?oKXi_o000000;ogJFJ00?o0000on2XV_l000000_lkMMl00ol0003o_9jiokbN
^@03okbN^@04o`000?oEX9oo0000o`0000;onK9`00?o0000oobfJ_ol]VX00_ol]VX01Ol0003oS5J<
o`000?ok/fOo000000?onk=W00Oo0000oheGSOl0003onk=Uo`000?ok/fGo000000?onk=U0_l00000
1On>FHko0000o`000?ok/V?o000000;onk9S00Ko0000ohmJSon?FXoo0000oo^bH_l00002oo^bHP03
o`000?n?FhooSe^?00;o000000Conk9Po`000?ok/V3o00000on@G9001_l0003onk5No`000?l0003o
nk5No`0000;ooooo0ol00002oiiQR0?o00004?ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`04omgMgOmEEEGoooooo`0000Kooooo0_l0000gooooo`04o`000?nY_NSoZKgXojVm
j0?o00001?nY_NP00ol0003oZKgXojVmj004o`0000;oZKgX00?o0000ojVmj?nY_NP00ol00003of<j
R`05o`000?oEXJ7o0000omJXZOl000000ooV^jX01Ol0003ommFXooOEZ?l0003okm]]00?o00000_mJ
?iP2o`000003ohmZXol0003o[8BY00?o[8BY00?o0000ol6J/?l000001?o8VZL00ol0003ocIZQo`00
0003oiB8a004o`000?m3Dkgo0000o`0000;oSGJd00?o0000oial[onLO:l00_nLO:l01Ol0003oYh:/
o`000?nWPJ[o000000Co/HNY00Co0000okV>ZOniSZWo00000onlSjH01?l0003oa9JWolBFYol00002
olRGY003o`000?o?WZGo000000?odYnR00Go0000omFQX?l0003odj>Vo`000003ombWWP03o`000?oN
Z9go000000;oCV[?00Go0000oi63`?nAPl3oTH?0o`000004oj^;/`03o`000?niT:co^I2/00;o^I2/
00?o0000ol>DY_o3U:H01?o3U:H00ol0003oc9VRolbIXP03olbIXP05o`000?oDWYkoe9jNomBNW_l0
00000_oFX9h2o`0000?ogJFJ00?o0000on2XV_oPZ9X00_l000000olkMMoo0000okbN^@03okbN^@04
o`000?oEX9oo0000o`0000;onK9`00?o0000oobfJ_ol]VX00_ol]VX01Ol0003oS5J<o`000?ok/fOo
000000?onk=W00Oo0000oheGSOl0003onk=Uo`000?ok/fGo000000?onk=U00Go0000ohiIS_l0003o
0000oo^bH`02o`0000;onk9S00Ko0000ohmJSon?FXoo0000oo^bH_l00002oo^bHP03o`000?n?Fhoo
Se^?00;o000000Conk9Po`000?ok/V3o00000on@G9001Ol0003onk5No`000?l0003onk5N00?o0000
00?oj99Vo`000?l000000_nNHHP3o`00013ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00Wooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41001?ooool00omgMgOoc<c<o`000006ooooo`03o`000?oooooooooo03Oooooo00?o0000ojVmj?l0
00000_nY_NP00ol0003oZKgXojVmj002ojVmj0Co000000?oZKgXo`000?nY_NP00_nY_NP3o`0000;o
ZKgX00Co0000of<jRomS>X_o00000ooEXJ42o`0000;oi[^Z00?o0000ooOEZ?ogeJP01_l00002oeXo
V004o`000?n?JZ?oSfZSo`0000Go[8BY0_l00004olRJY`03o`000?o=VZ7o000000;oU8S40ol00000
1Om3Dkgo0000ohef]?n=M[Co000000CoW7b_0_l00003ojN1ZP05o`000?naQjWo/HNYok67ZOl00000
0_niSZT01Ol0003o_8nVokb?Y_nlSjKo000000;oa9JW00Ko0000olRGY?o8UjCo0000olnNYOl00003
om:OXP05o`000?oEXJ3o0000om>SY_l000000ooLYih01?l0003ogZRMomjXWOl00002odiZc`05o`00
0?nAPl3oTH?0oi63`?l000000on[Rk<01ol0003o^I2/okV@[?niT:co0000okN?[?l000001Oo3U:H0
0ol0003oc9VRolbIXP02olbIXP;o00000ooDWYh01Ol0003oeZ2NomJPW_oFX9ko000000?ogJFJ00?o
0000on2XV_oPZ9X01?l00004okbN^@04o`000?oEX9oo0000o`0000;onK9`00?o0000oobfJ_ol]VX0
0_ol]VX01Ol0003oS5J<o`000?ok/fOo000000?onk=W00Oo0000oheGSOl0003onk=Uo`000?ok/fGo
000000?onk=U00Go0000ohiIS_l0003o0000oo^bH`02o`0000;onk9S00Ko0000ohmJSon?FXoo0000
oo^bH_l00002oo^bHP05o`000?n?FhooSe^?o`000?ok/V000_l000000ook/V3o0000oi1LT002oi1L
T006o`000?ok/Eko0000o`000?ok/Eko00000_oXTVH00ol0003obH80o`000002oiiQR004o`000?nY
_NSo0000o`0000oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00oo^k^koA4A4o`000006
ooooo`03o`000?oooooooooo03Sooooo00?o0000ojVmj?nY_NP00_nY_NP00ol0003oZKgXo`000003
o`0000CoZKgX00?o0000ojVmj?l000000_nY_NP01?l0003oZKgXojVmj?l00002of<jR`05o`000?oE
XJ7oeJ6QomFQXOl000000ooV^jX00ol0003ommFXooOEZ006o`0000;oFSnH00Go0000ohmZXon?JZ?o
SfZSo`000004ojb4Z@03o`000?o8VZOob9ZW00?ob9ZW00Go0000olfJXOl0003oU8S4o`000002ok:A
]@03o`000?m3Dkgo@e>m00Co000000CoW7b_o`000?l0003o00001?nWPJX00ol0003o/HNYok67Z@02
ok67Z@;o00001?nlSjH00ol0003oa9JWo`000004olRGY003o`000?oBWj;odYnR00;odYnR00Go0000
omFQX?l0003odj>Vo`000002ombWWP04o`000?oNZ9gogZRMomjXW@;o000000?oCV[?o`000?nAPl00
0_nAPl001Ol0003oZh^coj^;/on[Rk?o000000;o^I2/00Co0000okN?[?ngSjco00001?o3U:H2o`00
00Coc9VR00?o0000olfKX_l000000_oDWYh01Ol0003oeZ2NomJPW_oFX9ko000000?ogJFJ00Co0000
on2XV_oPZ9[oh:RJ1?l00004okbN^@?o00000_oi/W000ol0003oo;IZoobfJP02oobfJP05o`000?n<
EXco0000oo^cIol000000ook/fL01ol0003oSEN=o`000?ok/fGo0000oo^cIOl000000ook/fD01Ol0
003oSUV>ohiIS_l0003onk9S00;o00000_ok/V<01_l0003oSeZ?ohmJSol0003onk9Ro`0000;onk9R
00Go0000ohmKSon?Fhoo0000oo^bH002o`0000;onk9P00Go0000oi1LT?n@G93o0000oo^aGP02o`00
0007oo^aG_l0003oj99VonRBI_l0003obH80o`000002oiiQR003o`000?nY_NSoZKgX00;o00003_oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03ogMgMol0003ooooo00Gooooo00?o0000oooo
ooooool0>Oooool00ol0003oZKgXojVmj004o`0000?oZKgX00?o0000ojVmj?nY_NP00ol00004ojVm
j003o`000?nY_NSo000000;oHcZ;00Co0000omFQXOoEXJ7oeJ6Q0_l00002onJkZP05o`000?ogeJSo
mmFXo`000?o_ffd01?l00002oeXoV005o`000?n?JZ?oSfZSohmZXol000001?n/Q:T00ol0003ob9ZW
olRJY`02olRJY`05o`000?o=VZ7ocIZQolfJXOl000000onbTKD01?l0003o@e>mod=C_Ol00002oh1]
]0;o00000_nINJh00ol0003oYh6ZojN1ZP02ojN1ZP03o`000?naQjWo/HNY00;o/HNY00?o0000okb?
Y_nlSjH01?nlSjH2o`0000Cob9NT00Go0000om:OX_oBWj;odYnRo`000003omFQX005o`000?oLYiko
g:NNombWW_l000000ooNZ9d4o`0000?oTH?000?o0000oj^;/on[Rk<00_n[Rk<2o`0000?o]hn/00?o
0000ol>DY_o3U:H00_o3U:H00ol0003o`iFWo`000003olbIXP03o`000?o=Vj;o000000;oe9jN00Go
0000omJPW_oFX9koeZ2No`000002omfUVP03o`000?oPZ9[oh:RJ00;oh:RJ0_l000001?l028go0000
okbN^OnlW[T3o`000005om2OY?l0003onK9`ooVbL?l000001?ol]VX01Ol0003oS5J<o`000?ok/fOo
000000?onk=W00Oo0000oheGSOl0003onk=Uo`000?ok/fGo000000?onk=U00?o0000ohiIS_n>FHh0
1?l00003oo^bH`05o`000?n?FXoo0000oo^bH_l000000_ok/V802_l0003oSe^?ohmKSol0003onk9P
o`000?ok/V3o0000oo^bH?l00002oi1LT006o`000?ok/Eko0000o`000?ok/Eko00000_oXTVH00ol0
003obH80o`000003oiiQR0Co00003_ooool002_ooooo0_l0000kooooo`?o00000_nY_NP00ol0003o
ZKgXojVmj004o`0000?oZKgX00?o0000ojVmj?nY_NP01?l000000omS>X_o0000omFQX@03omFQX@05
o`000?oT/J3o0000o`000?ogeJP00ol000000oo_ffgo0000o`000002o`0000;oFSnH00Go0000ohmZ
Xon?JZ?oSfZSo`000003ojb4Z@;o00001?o8VZL01Ol0003ocIZQolfJXOo=VZ7o000000?o/Y6e0_l0
00001Om3Dkgo0000oh1]]?n0KKCo000000?oVGV^00?o0000ojN1Z_nWPJX00_nWPJX00ol0003o/HNY
ok67Z@02ok67Z@03o`000?nlSjKo_8nV00Co_8nV00?o0000olRGY?o8Uj@00oo8Uj@01Ol0003odYnR
om:OX_oBWj;o000000?oeJ6P00Go0000ombWW_oLYikog:NNo`000002omjXW@04o`000?oPZIco0000
o`0j_P;o00000_nAPl001?l0003oZh^coj^;/on[Rk<2o`0000Go]hn/00Co0000ol>DY_o3U:Ko0000
0_o3UJL01?l0003oc9VRolbIX_l00002olfKXP03o`000?oDWYko000000CoeZ2N00Co0000omfUV_oM
YI[o00001?oPZ9X01?l0003ohjZHo`000?l028d2o`0000;oYIW900Ko0000om2OY?o@WjCo0000ooVb
L?l00004oobfJP05o`000?n<EXco0000oo^cIol000000ook/fL01ol0003oSEN=o`000?ok/fGo0000
oo^cIOl000000ook/fD01Ol0003oSUV>ohiIS_l0003onk9S00;o00000ook/V<00ol0003oSeZ?ohmJ
S`02o`0000;onk9R00[o0000ohmKSon?Fhoo0000oo^bH?l0003onk9Po`000?ok/V3o00000on@G902
o`000003oo^aG_l0003o000000;oj99V00?o0000olV20?l000000onNHHP00ol0003oZKgXojVmj002
o`0000gooooo000[ooooo`03o`000?oooooooooo03Oooooo0ol00002ooooo`03o`000?nY_NSoZKgX
00?o00000onY_NP00ol0003oZKgXojVmj004o`0000?oZKgX00?o0000of<jRol000000ooEXJ401?l0
003oi;6PonBaX?oT/J02o`000003ooC5W?l0003o000000?o000000Go7Q24o`000?mJ?iSoFSnHo`00
0003ohmZX`07o`000?n/Q:Wo[8BYojb4ZOl0003o]hRSo`000002olRJY`03o`000?o=VZ7ocIZQ00;o
cIZQ00?o0000ok:A]OnbTKD00_nbTKD01?l0003o@e>mod=C_Ol00002oh1]]005o`000?nINJkoVGV^
oiUi[_l000000onWPJX01ol0003o/HNYok67ZOnaQjWo0000ok>8Yol000001OnlSjH00ol0003ob9NT
olRGY002olRGY0;o00000ooBWj801Ol0003oeJ6PomFQX?oEXJ3o000000?og:NN00Go0000omjXWOoN
Z9go0000on2YW002o`000005o`0j__l0003o0000o`000?nAPl000ol000000onTR;Ko0000okN?[004
okN?[004o`000?o3U:Ko`iBVo`0000;o`iFW00Co0000olbIX_o<VJ;o00000_o=Vj800ol0003oe9jN
o`000003omJPWP05o`000?oJY9ko0000omfUV_l000000ooPZ9X01?l0003oiJjJo`000?oSZYP2o`00
00?oYIW900Co0000om2OY?o@WjCod9nT0_l00004oobfJP05o`000?n<EXco0000oo^cIol000001?ok
/fL2o`000004oo^cIOl0003onk=Uo`0000Conk=U00Co0000ohiIS_l0003onk9S0_l00003oo^bH`03
o`000?n?FXooSeZ?00;o00000_ok/V802_l0003oSe^?ohmKSol0003onk9Po`000?ok/V3o0000oo^b
H?l00003oi1LT0;o000000?onk5No`000?l000000_oXTVH01?l0003obH80o`000?l00002oiiQR003
o`000?nY_NSo000000?o00003?ooool002[ooooo00?o0000ooooooooool0=Oooool3o`0000Kooooo
0_l00003ojVmj003o`000?nY_NSoZKgX00?o00000onY_NP00ol0003oZKgXojVmj002o`000003of<j
Rol0003oeJ6Q00;oeJ6Q00Go0000onBaX?oT/J3oi;6Po`000002ooC5W0Go000000Go7Q24o`000?mJ
?iSoFSnHo`000003ohmZX`04o`000?n/Q:Wo[8BYo`0000;o]hRS00Co0000olRJYoo8VZOo00000oo=
VZ400ol0003odIZMo`000002ok:A]@;o00000_m3Dkd01?l0003oP6fdoh1]]?l00003oiUi[P03o`00
0?nWPJ[oYh6Z00;oYh6Z00?o0000ok67ZOl000000_ncR:L00ol0003o_8nVokb?YP02okb?YP;o0000
1?o8Uj@01Ol0003obiVRo`000?oBWj;o000000CoeJ6P00Co0000ombWW_oLYiko00000ooNZ9d01_l0
003oh:VLo`000?l0003o03Zno`0000;oNGS50_l00004ojB8]P03o`000?ngSjco]hn/00;o]hn/00?o
0000ol>DY_l000000oo3UJL00ol0003oc9VRo`000003olfKXP03o`000?oDWYko000000?oeZ2N00Go
0000omZTW_l0003ogJFJo`000003on2XVP04o`000?oU[Y[o0000on>ZV0?o00000onUVLT00ol0003o
d9nTom2OY002o`0000Coo;IZ00Go0000ohaFS?l0003onk=Wo`000004oo^cI`;o000000Conk=Uo`00
0?ok/fGo00001?ok/fD01?l0003oSUV>o`000?ok/V<2o`0000?onk9S00So0000ohmJSon?FXoo0000
oo^bH_l0003onk9Ro`0000;oSe^?00Oo0000oo^bH?l0003onk9Po`000?ok/V3o000000?oT5b@0_l0
00001ook/Eko0000oo^aG_l0003oj99Vo`000?o9PP000_l00002oiiQR0;o00000_nY_NP2o`0000co
oooo000Zooooo`03o`000?oooooooooo03;ooooo0ol00009ooooo`03o`000?nY_NSoZKgX00;oZKgX
0ol00003ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?l000001?oEXJ401_l0003oi;6P
onBaX?oT/J3o0000ooC5W0;o000000Gokm]]o`000?o[ceOo0000oah@Q002o`0000;oFSnH00Co0000
ohmZXon?JZ?oSfZS0_l00003okN8X`03o`000?o8VZOo000000CocIZQ00?o0000om6JWOl000000_nb
TKD01Ol0003oaiVWo`000?m3Dkgo000000;oP6fd00Go0000oiUi[_nINJkoVGV^o`000004ojN1ZP;o
00000oncR:L00ol0003o_8nVokb?YP02okb?YP03o`000?o0T:Go000000?ob9NT00Go0000ol^IX_l0
003odYnRo`000003omFQX005o`000?oHXioo0000ombWW_l000000ooNZ9d00ol0003oh:VLon2YW002
o`000005o`0j__l0003oNGS5ogUhaOl000001?nTR;H00ol0003o]hn/okN?[003okN?[0;o00000oo3
UJL00ol0003oc9VRo`000004olfKXP03o`000?oFX9koeZ2N00;oeZ2N00Go0000omZTW_l0003ogJFJ
o`000003on2XVP05o`000?oU[Y[o0000o`000?oW[YL00_l00003ojFIb@03o`000?o@WjCod9nT00?o
00000ool]VX01Ol0003oS5J<o`000?ok/fOo000000Conk=W0_l000001?ok/fGo0000oo^cIOl00004
oo^cI@04o`000?n>FHko0000oo^bH`?o00000_ok/V<01_l0003oSeZ?ohmJSol0003onk9Ro`0000;o
nk9R00Wo0000ohmKSol0003onk9Po`000?ok/V3o0000oo^bH?l000000on@G9002Ol0003onk5No`00
0?l0003onk5No`000?oXTVKo0000olV20002o`0000;oWV6800Co0000ojVmj?nY_NSoZKgX0ol0000;
ooooo`00:_ooool00ol0003oooooooooo`0_ooooo`?o00003Oooool01_l0003oZKgXo`000?l0003o
ZKgXo`0000CoZKgX0ol00003ojVmj0?o00001?oEXJ401?l0003oi;6PonBaX?l00002ooC5W0;o0000
00Cokm]]o`000?o[ceOojlmG0ol00002oeXoV004o`000?n?JZ?oSfZSohmZX`;o00000ongR:<00ol0
003ob9ZWo`000004olfJX@05o`000?oAVYgo0000ok:A]Ol000000_o7VJL3o`0000?oP6fd00Co0000
oiUi[_nINJko00000onWPJX2o`0000Go/hRW00Co0000okb?Y_nlSjKo00000_o0T:D01?l0003ob9NT
olRGY?l00002ol^IXP03o`000?oBWj;o000000?oeJ6P00Go0000omRSWol0003og:NNo`000002omjX
W@06o`000?oPZIcoh:VLon2YW?l0003odZ>V0_l00002ogUha@03o`000?nTR;KoY8Rf00;oY8Rf00?o
0000okN?[?ngSj`00ongSj`00ol0003o`iFWol>EY`03ol>EY`;o00001?o=Vj801Ol0003oeZ2NomJP
W_oFX9ko000000;ofZBN0_l00004on2XVP04o`000?oU[Y[oiJjJo`0000;oijjG00Go0000ojFIbOnU
VLWoYIW9o`000002om2OY004o`000?o:WjcobYn/o`0000;oo;IZ00Go0000ohaFS?l0003onk=Wo`00
0004oo^cI`;o000000Conk=Uo`000?ok/fGo00001?ok/fD01?l0003oSUV>o`000?ok/V<3o`0000;o
nk9S00Ko0000ohmJSon?FXoo0000oo^bH_l00002oo^bHP03o`000?n?FhooSe^?00;o000000Conk9P
o`000?ok/V3o00000on@G9002Ol0003onk5No`000?l0003onk5No`000?oXTVKo0000olV20002o`00
00;oWV681?l000001?nY_NSo0000o`000?l0000:ooooo`00:_ooool00ol0003oooooooooo`0/oooo
o`?o00004Oooool2o`0000?oZKgX00Ko0000ojVmj?l0003o0000ojVmj?l00004ojVmj0?o00000ooE
XJ401Ol0003oi;6PonBaX?oT/J3o000000;om<FL1?l00002on_?E`03o`000?lN48Co000000;oFSnH
00Go0000ohmZXon?JZ?oSfZSo`000005okN8X`;o00000oo=VZ401?l0003odIZMom6JWOoAVYd2o`00
00;oaiVW00Co0000o`0JYOl0003o00000_n0KK@01?l0003oVGV^oiUi[_l00002ojN1ZP03o`000?nW
P:Wo000000Go/hRW00Co0000okb?Y_nlSjKo00000_o0T:D01?l0003ob9NTolRGY?l00003ol^IXP03
o`000?oEXJ3oeJ6P00;oeJ6P00Go0000omRSWol0003og:NNo`000002omjXW@06o`000?oPZIcoh:VL
on2YW?l0003odZ>V0_l00003ogUha@03o`000?nTR;KoY8Rf00;oY8Rf00Co0000okN?[?ngSjco]hn/
0_l00005ol>EY`03o`000?o=Vj;ocI^R00?ocI^R00Go0000omJPW_oFX9koeZ2No`000003omZTWP05
o`000?oPZ9[oh:RJon2XV_l000000ooU[YX00ol0003oijjGonN^U`03o`000004ojFIbOl0003od9nT
o`0000?obYn/00Co0000oobfJ_ol]V[oo;IZ0_l000000ook/fOo0000oo^cI`03oo^cI`;o000000Co
nk=Uo`000?ok/fGo00001?ok/fD01?l0003oSUV>o`000?ok/V<2o`000004oo^bHol0003onk9So`00
00;oSeZ?00?o0000oo^bH_l000000_ok/V800ol0003oSe^?ohmKS`02o`000005oo^bH?l0003onk9P
oo^bH?l000000_n@G9002Ol0003onk5No`000?l0003onk5No`000?oXTVKo0000olV20002o`0000;o
WV680_l00004ojVmj0;o00002_ooool002[ooooo0_l0000[ooooo`;o00005_ooool00ol0003oZKgX
ojVmj003o`0000?oZKgX00Ko0000ojVmj?l0003o0000ojVmj?l00004omFQX@05o`000?oT/J3oi;6P
onBaX?l000000_odaI`01?l0003okm]]o`000?l00002on_?E`03o`000?lN48Co000000;oFSnH00?o
0000ohmZXon?JZ<00_l00005okN8X`03o`000?o=VZ7ocIZQ00;ocIZQ00Go0000om6JWOoAVYgodIZM
o`000003olNIY`;o000000Go01ZUo`000?l0003oP6fdo`000003oiUi[P;o00000_nWP:T00ol0003o
/hRWok>8Y`03ok>8Y`03o`000?nlSjKo000000?o`92U00?o0000olRGY?l000001?o;VJ801Ol0003o
eJ6PomFQX?oEXJ3o000000?of:>O00Go0000omjXWOoNZ9gogZRMo`000003on2YW0;o000000?odZ>V
o`000?l000000_miN<D00ol0003oY8RfojB8]P02ojB8]P06o`000?ngSjco]hn/o`000?neSjoo0000
1Oo3UJL00ol0003ocI^RolfKXP02olfKXP;o00000ooFX9h01Ol0003ofZBNomZTW_oJY9ko000000?o
h:RJ00Go0000onF^V_oU[Y[oiJjJo`000002onN^U`;o000000?oHX;Lo`000?l000000_l00003olZO
[004o`000?ol]V[oo;IZoobfJP;o000000?onk=Wo`000?ok/fL00ook/fL01_l0003oSEN=o`000?l0
003onk=Uo`0000Conk=U00Co0000ohiIS_l0003onk9S0_l00002oo^bH`;o00000_n?FXl00ol0003o
nk9Ro`000002oo^bHP03o`000?n?FhooSe^?00;o000000Gonk9Po`000?ok/V3onk9Po`000002oi1L
T008o`000?ok/Eko0000o`000?ok/Eko0000onRBI_l00002olV20006o`000?nNHHSoWV68o`000?nY
_NSo00000_nY_NP3o`0000[ooooo000Zooooo`03o`000?oooooooooo02Oooooo0ol0000Iooooo`;o
00000onY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000omFQXOoEXJ400_oEXJ401?l0003o
i;6PonBaX?l00002ooC5W0;o000000?okm]]o`000?l000000_o[ceL02_l0003o7Q24o`000?l0003o
FSnHo`000?n?JZ?o0000oj1cWol00005okN8X`03o`000?o=VZ7ocIZQ00;ocIZQ00Go0000om6JWOoA
VYgodIZMo`000003olNIY`;o000000?o01ZUo`000?mZH;D00ol000000onINJko0000o`000004ojN0
Z@03o`000?ncR:Oo/hRW00?o/hRW0_l00003ol2@Y@03o`000?o8UjCo000000CobiVR00Go0000omFQ
X?oEXJ3oeJ6Po`000003omRSW`05o`000?oNZ9gogZRMomjXWOl000000ooPZI`2o`000006om:SY_l0
003o0000o`000?miN<Go00001?nTR;H00ol0003o]hn/o`000003okF?[`04o`000?o3UJOo`iFWol>E
Y`;o00001?o=Vj800ol0003od9jSo`000002omJPWP05o`000?oJY9kofZBNomZTW_l000000ooPZ9X0
1?l0003oiJjJonF^V_oU[YX2o`000004onN^Uol0003ok;FGo`0000;oHX;L00?o0000olZO[?o:Wj`0
0oo:Wj`00ol0003oo;IZoobfJP02o`000003oo^cIol0003onk=W00?onk=W00Ko0000oheGSOl0003o
0000oo^cIOl00004oo^cI@04o`000?n>FHko0000oo^bH`;o00000ook/V<01_l0003oSeZ?ohmJSol0
003onk9Ro`0000;onk9R00?o0000ohmKSon?Fhl00_l000001Ook/V3o0000oo^bH?ok/V3o000000;o
T5b@00Go0000oo^aG_l0003o0000oo^aGP02o`0000?obH800_l000000onNHHSo0000o`000003o`00
00;ooooo00?o0000ooooooooool02?ooool002Wooooo00?o0000ooooooooool09Oooool3o`0001go
oooo00?o0000ojVmj?nY_NP01?l00003ojVmj004o`000?nY_NSo0000o`0000?oeJ6Q00Co0000onBa
X?oT/J3o00000_odaI`4o`0000?ojlmG00Co0000oah@Q?l0003oN5:I0ol00002oj1cW`03o`000?ng
R:?o]hRS00;o]hRS0_l00003olfJX@03o`000?oAVYgodIZM00;odIZM00Ko0000olNIYoo7VJOoaiVW
o`000?oEWYd2o`0000?oJV2e0_l000000onDMZko0000ojN0Z@03ojN0Z@03o`000?ncR:Oo/hRW00?o
/hRW00?o0000ol2@YOo0T:D00oo0T:D2o`0000?obiVR0_l00003omFQX005o`000?oHXioof:>OomRS
Wol000000ooNZ9d01ol0003oh:VLon2YW?l0003ohZ^Ko`000?oBXjH00_l000001?m;Hl[o0000o`00
0?l00002ojB8]P?o00001?neSjl01ol0003o`iFWol>EYoo3UJOo0000olBGZOl000000oo=Vj801Ol0
003od9jSo`000?oFX9ko000000CofZBN00Go0000on2XV_oPZ9[oh:RJo`000002onF^VP04o`000?o/
]i_o0000o`0000;ok;FG00Co0000of:2g?mRP]co00001Oo:Wj`00ol0003oo;IZoobfJP02o`000003
oo^cIol0003onk=W00?onk=W00Co0000oheGSOl0003onk=U0_l00004oo^cI@04o`000?n>FHko0000
oo^bH`;o00000ook/V<2o`000004ohmJSol0003onk9Ro`0000;onk9R00?o0000ohmKSon?Fhl00_l0
00001Ook/V3o0000oo^bH?ok/V3o000000;oT5b@00Co0000oo^aG_l0003o00000_ok/Eh01?l0003o
bH80olV20?o9PP02o`0000;oWV6800?o0000ooooooooool00oooool00ol0003oooooooooo`08oooo
o`00:Oooool00ol0003oooooooooo`0Rooooo`?o00008Oooool2o`0000?oZKgX00?o0000ojVmj?nY
_NP01Ol00002omFQX@05o`000?oT/J3oi;6PonBaX?l000000_odaI`4o`0000?ojlmG00?o0000oah@
Q?l000000_mhDYT00ol0003oX7>Ooj1cW`02oj1cW`07o`000?ngR:?o]hRSokN8Xol0003o_h^No`00
0002olfJX@09o`000?oAVYgodIZMom6JWOl0003odi^Jo`000?o7VJOo000000;oeIjM00?o0000o`0J
YOl000000_mZH;D01?l0003oU7J^oiAf[_l00004ojN0Z@03o`000?ncR:Oo/hRW00?o/hRW00?o0000
ol2@YOo0T:D00oo0T:D00ol0003obiVRol^IXP02ol^IXP03o`000?o?W:7o000000;oeJ6P00Go0000
omRSWooHXioof:>Oo`000002omjXW@05o`000?oPZIcoh:VLon2YW?l000000_oRZi/01?l0003oh:RK
o`000?l00002od]SbP?o00000_nJQK`00ol0003o]Hn_okF?[`02okF?[`04o`000?o3UJOo`iFWo`00
00;oa9NY00Co0000olfKX_o=Vj;o00000_o@WZ<00ol0003oeZ2No`000003omZTWP05o`000?oNZYoo
0000on2XV_l000000ooU[YX01?l0003ok;NKo`000?l00002onbeU`;o00000_mRP]`00ol0003obYn/
olZO[002olZO[003o`000?ol]V[oo;IZ00;o000000?onk=Wo`000?ok/fL00ook/fL01?l0003oSEN=
o`000?ok/fD2o`0000Conk=U00Co0000ohiIS_l0003onk9S0_l00004oo^bH`05o`000?n?FXoo0000
oo^bH_l000000_ok/V800ol0003oSe^?ohmKS`02o`000005oo^bH?l0003onk9Poo^bH?l000000_n@
G9001?l0003onk5No`000?l00002oo^aGP04o`000?o9PP3obH80olV200;o00000_nNHHP00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Oooooo000Yooooo`03o`000?oooooooooo01oooooo
0ol0000Uooooo`03o`000?nY_NSoZKgX00Co00000onY_NP2o`0000;oeJ6Q00Co0000onBaX?oT/J3o
00000_odaI`7o`000004on_?Eol0003o7Q24o`0000;oN5:I00?o0000oj1cWonPLil00_nPLil01ol0
003o]hRSokN8XongR:?o0000okn;W_l000000_o=VZ402Ol0003odIZMom6JWOoAVYgo0000om>KV_l0
003oaiVWo`000002omFNW@?o00000_mZH;D01Ol0003oU7J^oiAf[_nDMZko000000CoYh2Y00Co0000
ok>8YoncR:Oo/hRW0_l00005ol2@Y@03o`000?o;VJ;obiVR00;obiVR00Go0000olnLXOl0003oeJ6P
o`000003omRSW`05o`000?oLYYko0000omjXWOl000000ooPZI`01?l0003ohZ^Kon:[Vol00002on2X
V`04o`000?m;Hl[oBf?:o`0000CoVXFl00?o0000okF?[oneSjl00_neSjl01?l0003o`iFWol>EYol0
0002olBGZ@04o`000?o=Vj;ocI^Ro`0000;od9jS00?o0000omJPW_l000000ooJY9h01Ol0003ogZZO
o`000?oPZ9[o000000?oiJjJ00Co0000onbgVoo/]i_o00000_o/]IL3o`000003of:2g?l0003obYn/
00CobYn/00Ko0000oobfJ_l0003o0000oo^cIol00004oo^cI`04o`000?n=Ehgo0000oo^cI@;o0000
1Ook/fD2o`000003oo^bHol0003o000000Conk9S0ol000001Ook/V;o0000oo^bH_ok/V;o000000;o
Se^?0_l000001Ook/V3o0000oo^bH?ok/V3o000000;oT5b@00Co0000oo^aG_l0003o00000_ok/Eh0
1?l0003obH80olV20?o9PP02o`0000;oWV6800?o0000ooooooooool01?ooool00ol0003ooooooooo
o`07ooooo`00:Oooool3o`0001cooooo0ol0000Yooooo`;o00000onY_NP00ol0003oZKgXojVmj002
o`000004oc<?MOl0003oeJ6Qo`0000;oi;6P00?o0000ooC5W?odaI`01_l000001OoobgKo0000o`00
0?lN48Co000000;oN5:I00?o0000oj1cWonPLil00_nPLil01?l0003o]hRSokN8Xol00002okn;WP03
o`000?o=VZ7o000000CodIZM00Go0000om>KV_l0003oaiVWo`000002omFNW@?o00000omZH;D01?l0
003oU7J^oiAf[_l00004ojN0Z@04o`000?ncR:Oo/hRWo`0000;o]XVV00Co0000ol2@YOo0T:Go`92U
0_l00003ol^IXP06o`000?o?W:7ocibQo`000?oEXJ3o00000ooHXil01Ol0003og:JNo`000?oNZ9go
000000?oh:VL00Co0000on:[VooRZi_o00000_oPZ9/01Ol0003oBf?:od]Sb_m;Hl[o000000CoVXFl
00Oo0000okF?[oneSjoo]Hn_o`000?o3UJOo000000?oa9NY00?o0000olfKX_l000001?o@WZ<00ol0
003ofZBNomZTWP02omZTWP05o`000?oNZYoo0000on2XV_l000000ooU[YX01?l0003ok;NKonbgVol0
0002onbeU`06o`000?oc`IWo0000o`000?mRP]co00000oo:Wj`2o`000005oobfJ_l0003o0000oo^c
Iol000001Ook/fL2o`000004oo^cIOl0003onk=Uo`0000Conk=U0_l000000ook/V?o0000o`000004
oo^bH`05o`000?n?FXoo0000oo^bH_l000000_ok/V800ol0003oSe^?ohmKS`02o`000005oo^bH?l0
003onk9Poo^bH?l000000_n@G9001?l0003onk5No`000?l00002oo^aGP04o`000?o9PP3obH80olV2
00;o00000_nNHHP00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo000Yooooo`03
o`000?oooooooooo01Wooooo0ol0000^ooooo`03o`000?nY_NSoZKgX00?o000000KoZKgXo`000?lc
3gGo0000omFQXOl00002onBaX003o`000?odaIcom<FL00Ko000000Gool]fo`000?l0003o7Q24o`00
0002ogQBV@03o`000?nPLiooX7>O00;oX7>O00Co0000okN8XongR:?o00000_noRih00ol0003ocIZQ
o`000004om6JW@05o`000?oCVi[o0000olNIYol000000_oEWYd3o`0000?oJV2e00Co0000oiAf[_nD
MZko00001?nWP:T01?l0003o/hRWok>8Yol00002okJ9YP07o`000?o0T:Go`92Uol2@YOl0003oa9>T
o`000002ol^IXP06o`000?o?W:7ocibQo`000?oEXJ3o00000ooHXil01Ol0003og:JNo`000?oNZ9go
000000?oh:VL00?o0000on:[VooRZi/00_l00002on2XV`;o000000?oBf?:o`000?nJQK`00onJQK`0
0ol0003o]Hn_okF?[`02okF?[`;o00000oo4UjT00ol0003ocI^Ro`000004om2NX`03o`000?oJY9ko
fZBN00;ofZBN00Go0000omjZWol0003oh:RJo`000002onF^VP04o`000?o/]i_ok;NKonbgV`;o0000
00Cok;FGo`000?oc`IWoll6I0ol00002olZO[004o`000?nlWk_o0000oobfJP;o000000?onk=Wo`00
0?ok/fL01?ok/fL2o`000004oo^cIOl0003onk=Uo`0000Conk=U0_l000000ook/V?o0000o`000004
oo^bH`05o`000?n?FXoo0000oo^bH_l000000ook/V801_l0003oSe^?o`000?l0003onk9Po`0000;o
nk9P00Go0000oi1LT?n@G93o0000oo^aGP02o`0000;onk5N00Co0000olV20?o9PP3obH800_l00002
oiiQR003o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00003o`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo01Kooooo
0ol0000booooo`;o00000onY_NP2o`000003oc<?MOl0003o000000?oi;6P00?o0000ooC5W?odaI`0
0_l000001Oood8;o0000o`000?l0003ool]f00;o000000Go7Q24o`000?mhDYWoN5:Io`000004oj1c
W`04o`000?ngR:?o]hRSo`0000;o_h^N00?o0000olfJXOl000000ooAVYd01Ol0003odi^Jom>KV_oC
Vi[o000000?oeIjM00Co0000om^QUol0003o00000_mZH;D01Ol0003oU7J^oiAf[_nDMZko000000Co
Yh2Y0_l00003okJ9YP04o`000?o0T:Go`92Uo`0000;oa9>T00Co0000ol^IX_o;VJ;o00000oo?W:40
0ol0003of:>OomRSW`02omRSW`04o`000?oLYYkog:JNo`0000?oh:VL00Co0000on:[VooRZi_ohZ^K
0_l00002on2XV`05o`000?l0<KWo0000od]Sb_l000000onJQK`01?l0003o]Hn_okF?[oneSjl2o`00
00Goa9NY0_l00004om2NX`03o`000?oJY9kofZBN00;ofZBN00Co0000omjZWooNZYoo00000ooU[YX0
1Ol0003ok;NKonbgVol0003om/NL00;o00000_oc`IT2o`000004o`0KXol0003obYn/o`0000?o_9nk
0ol000000ook/fOo0000oo^cI`04oo^cI`;o000000Conk=Uo`000?ok/fGo00001?ok/fD2o`000003
oo^bHol0003o000000Conk9S00?o0000ohmJSol000000_l00003oo^bHP06o`000?n?Fhoo0000o`00
0?ok/V3o00000ook/V001?l0003oT5b@o`000?ok/Eh2o`0000;onk5N00Wo0000olV20?o9PP3obH80
o`000?nmPYCo0000oiiQR?l000001_ooool00ol0003oooooooooo`07ooooo`0000?ooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool05?oo
ool2o`0003Gooooo00?o0000ojVmj?nY_NP00_nY_NP2o`0000;o<`me00Co0000onBaX?oT/J3o0000
0_odaI`3o`000003ooo@P_l0003o000000;ool]f0_l000000olN48Co0000ogQBV@02ogQBV@07o`00
0?nPLiooX7>Ooj1cWol0003o]hRSo`000004okn;WP03o`000?oAVYgodIZM00;odIZM00Go0000om>K
V_oCVi[odi^Jo`000003omFNW@03o`000?oKXIOo000000;o000000?oJV2eo`000?nDMZh00_nDMZh0
0ol0003oYh2YojN0Z@02ojN0Z@03o`000?nfRJKo]XVV00;o]XVV00Co0000ol2@YOo0T:Go00000_o4
Tj@00ol0003obiVRo`000004olnLX@05o`000?oHXioof:>OomRSWol000000ooLYYh01Ol0003oh:VL
on2YW?oPZIco000000;ohZ^K00Go0000onB^W?oT[Yco0000on2XV`02o`000003o`0a^Ol0003o0000
00?oVXFl00Ko0000okF?[oneSjoo0000ok:A]?l00005olBGZ@03o`000?o@WZ?od9jS00;od9jS00?o
0000omBTYOl000000_oJY9h01Ol0003ogZZOomjZWooNZYoo000000?oiJjJ00Go0000onbgVoo/]i_o
0000ooK7W002o`0000;oll6I00Go0000oogIVol0003o01^So`000004okbO^`?o000000?onk=Wo`00
0?ok/fL01?ok/fL2o`000004oo^cIOl0003onk=Uo`0000Conk=U0_l000000ook/V?o0000o`000004
oo^bH`05o`000?n?FXoo0000oo^bH_l000000ook/V801_l0003oSe^?o`000?l0003onk9Po`0000?o
nk9P00Wo0000oi1LT?l0003onk5No`000?ok/Eko0000oo^aG_l000000oo9PP001Ol0003o_H:Do`00
0?nNHHSo000000Kooooo00?o0000ooooooooool01oooool000;ooooo00?o410@ooooooooool02Ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Booooo`?o0000>?ooool01_l0
003oZKgXo`000?l0003oZKgXo`0000;o<`me00Co0000onBaX?oT/J3o00000_odaI`2o`000004ooo@
P_l0003o0000o`0000;ool]f1?l00003ogQBV@03o`000?nPLiooX7>O00;oX7>O0_l00004okn;WP03
o`000?oAVYgodIZM00;odIZM00Go0000om>KV_oCVi[odi^Jo`000003omFNW@05o`000?oKXIOo0000
o`000?loBK@00_l00003oiAf[P04o`000?nWP:WoYh2YojN0Z@;o00001?nfRJH01?l0003o`92Uol2@
YOl00002olBCY003o`000?o;VJ;o000000CocibQ00Go0000omRSWooHXioof:>Oo`000003ombVWP05
o`000?oPZIcoh:VLon2YW?l000000_oRZi/00ol0003oi:jLonB^W002o`0000;ogZRL00?o0000o`0a
^Ol000001?nJQK`2o`0000;o/Y6d00?o0000olBGZOo4UjT00oo4UjT00ol0003od9jSom2NX`02om2N
X`03o`000?oDY:Go000000;ofZBN00Go0000omjZWooNZYoogZZOo`000002onF^VP05o`000?o/]i_o
k;NKonbgVol000000_ofai`01Ol0003oll6Ioo?1VOl0003ooMVK00?o00001?nlWk/3o`000003oo^c
Iol0003onk=W00Conk=W0_l000001?ok/fGo0000oo^cIOl00004oo^cI@;o000000?onk9So`000?l0
00001?ok/V<01Ol0003oSeZ?o`000?ok/V;o000000?onk9R00Co0000ohmKSol0003onk9P0_l00003
oo^bH007o`000?n@G93o0000oo^aG_l0003onk5No`000002oo^aGP04o`000?o9PP3obH80olV200;o
000000?oWV68o`000?ooool01Oooool00ol0003oooooooooo`07ooooo`000_ooool00ol0003ooooo
ooooo`09ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo00oooooo0ol0000l
ooooo`03o`000?nY_NSoZKgX00;o00000olc3gD00ol0003oi;6Po`000002ooC5W0;o000000Ooom22
o`000?l0003o0000ooo;M_l0003ooLm^00;o000000Go7Q24o`000?mhDYWoN5:Io`000004oj1cW`;o
00001?noRih00ol0003odIZMom6JW@02om6JW@05o`000?oCVi[odi^Jom>KV_l000000_oEWYd01Ol0
003ofj6Gom^QUooKXIOo000000;o?dVd0_l00002oiAf[P06o`000?nWP:WoYh2Yo`000?nWPJ[o0000
1OnfRJH2o`0000?oa9>T00?o0000ol^IX_l000001?o?W:401Ol0003of:>OomRSWooHXioo000000?o
g:JN0_l00002on2YW004o`000?oRZi_ohZ^Ko`0000;oi:jL0_l00003omjXW003o`000?l0<KWo0000
00Co00001?nbTK@01?l0003oa9NYolBGZOo4UjT2o`0000Cod9jS00?o0000omBTYOl000000_oJY9h0
1?l0003ogZZOomjZWooNZYl2o`000003onF^V_l0003ok;NK00;ok;NK00Co0000ooK7W?ofaico0000
0_oc`IT01?l0003ooMVKo`000?nfOYL2o`0000?o_9nk0ol000000ook/fOo0000oo^cI`04oo^cI`;o
000000Conk=Uo`000?ok/fGo00001?ok/fD2o`000003oo^bHol0003o000000Gonk9S0_l000000ook
/V;o0000o`000002oo^bHP04o`000?n?Fhoo0000oo^bH0;o00000ook/V001ol0003oT5b@o`000?ok
/Eko0000oo^aG_l000000_ok/Eh01?l0003obH80olV20?o9PP02o`000003oiiQR?l0003ooooo00Ko
oooo00?o0000ooooooooool01_ooool000;ooooo00?o0000ooooooooool02Oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?mEEEGo0000
oa0@4?o<c<`01Oooool2o`0000gooooo0ol00010ooooo`04o`000?nY_NSo0000o`0000?o<`me0_l0
0003ooC5W0;o000000Ooom22o`000?l0003o0000ooo;M_l0003ooLm^00;o000000Go7Q24o`000?mh
DYWoN5:Io`000004oj1cW`03o`000?noRiko_h^N00?o_h^N00Go0000om6JWOoAVYgodIZMo`000003
om>KVP05o`000?oFViSo0000omFNWOl000000ooKXIL2o`0000;o?dVd0ol000000onDMZko0000o`00
0002ojN1ZP03o`000?nfRJKo]XVV00?o]XVV0_l00004olBCY003o`000?o?W:7ocibQ00;ocibQ00Go
0000om>PXOl0003of:>Oo`000003ombVWP03o`000?oOZYgo000000;oh:VL00Co0000on:[VooRZi_o
00000ooT[Y`01ol0003ogZRLomjXW?oNZ9co0000o`0a^Ol000000on6PLH00ol0003o/Y6dok:A]002
ok:A]007o`000?o4UjWoa9NYolBGZOl0003oaY^]o`000002om2NX`07o`000?oDY:Goe:BUomBTYOl0
003ofZBNo`000002omjZW`05o`000?oV]J;o0000onF^V_l000000oo/]i/01?l0003om/NLo`000?om
hiH2o`0000;ooMVK00Co0000okInUol0003o00000onlWk/3o`000003oo^cIol0003onk=W00Conk=W
0_l000001?ok/fGo0000oo^cIOl00004oo^cI@;o000000Conk9So`000?ok/V?o00001?ok/V<2o`00
0009oo^bH_l0003onk9Ro`000?ok/V;o0000ohmKSol0003onk9P00;o00000ook/V001ol0003oT5b@
o`000?ok/Eko0000oo^aG_l000000_ok/Eh01?l0003obH80olV20?o9PP02o`0000;oWV6800?o0000
ooooooooool01?ooool00ol0003oooooooooo`06ooooo`000_ooool00ol@413oooooooooo`09oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o
EEEEohN7Qoooool01oooool00ol0003oooooooooo`09ooooo`?o0000A?ooool3o`0000Co<`me1_l0
00001oood8;o0000o`000?l0003ool]fo`000?omcfh00_l000001OlN48Co0000ogQBVOmhDYWo0000
00CoX7>O00?o0000okn;W_noRih00_noRih2o`0000?odIZM00Wo0000om>KV_oCVi[odi^Jo`000?oF
ViSo0000omFNWOl000000ooKXIL2o`0000;o?dVd00?o0000ohab/?n<L[000_l00004ojN1ZP03o`00
0?nfRJKo]XVV00;o]XVV00?o0000olBCY?o4Tj@00oo4Tj@00ol0003ocibQolnLX@02olnLX@05o`00
0?oCX:7o0000omRSWol000000ooLYYh01_l0003ogjZMomnZWOl0003oh:VLo`0000;ohZ^K00Go0000
onB^W?oT[Ycoi:jLo`000002omjXW005o`000?oMYiko0000o`0a^Ol000000_n6PLH00ol0003o/Y6d
ok:A]002ok:A]004o`000?o4UjWoa9NYo`0000;oaY^]00Co0000om2NXoo@WZ?o00000ooDY:D00ol0
003ofZBNo`000002omjZW`05o`000?oV]J;o0000onF^V_l000000_o/]i/01?l0003om/NLooK7W?l0
0002oogSUP?o00000onfOYL00ol0003o_9nkokbO^`02okbO^`;o000000?onk=Wo`000?ok/fL01?ok
/fL2o`000004oo^cIOl0003onk=Uo`0000Gonk=U00Go0000oo^bHol0003onk9So`000004oo^bH`;o
000000Conk9Ro`000?ok/V;onk9R0_l000001_n?Fhoo0000oo^bH?l0003onk9Po`0000;onk9P00Oo
0000oi1LT?l0003onk5No`000?ok/Eko000000;onk5N00Wo0000olV20?o9PP3obH80o`000?nmPYCo
0000oiiQR?l000001_ooool00ol0003oooooooooo`06ooooo`0000?ooooooiRHV?mgMgL02oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03omgM
gOl@413oV9RH00Oooooo00?o0000ooooooooool01_ooool3o`0004Sooooo0_l00004oc<?M@03o`00
0?o^]YKok[JF00;o00000_ood883o`000005ooo;M_l0003ooLm^o`000?lh88L00_l00002ogQBV@04
o`000?nPLiooX7>Ooj1cW`;o00001?noRih00ol0003oaHjKo`000002om6JW@09o`000?oCVi[odi^J
om>KV_l0003oeY^Ho`000?oEWYgo000000?ofj6G0_l00002ocm9]005o`000?n<L[3oS7:`ohab/?l0
00001?nWPJX00ol0003o]XVVokJ9YP02okJ9YP03o`000?o4TjCoa9>T00?oa9>T00?o0000olnLXOo?
W:400_o?W:401Ol0003odj2Qo`000?oHXioo000000?og:JN00?o0000omnZWOoOZYd00_l00002on:[
V`03o`000?oT[Ycoi:jL00;oi:jL00Co0000omjXW?oNZ9co00000_oMYih2o`0000?oQX7600Oo0000
ok:A]?nbTKCo/Y6do`000?o4UjWo000000?oaY^]00Co0000om2NXoo@WZ?o00000ooDY:D2o`0000?o
gZZO00Co0000onJeX_oV]J;o00000oo/]i/01?l0003om/NLooK7W?l00002oogSUP03o`000?nSL9Wo
000000Co]WjG1_l000000ook/fOo0000oo^cI`04oo^cI`;o000000Conk=Uo`000?ok/fGo00001Ook
/fD3o`000003oo^bHol0003onk9S00?onk9S0_l000001?ok/V;o0000oo^bH_ok/V82o`000006ohmK
Sol0003onk9Po`000?ok/V3o00000_ok/V000ol0003oT5b@oi1LT002o`000005oo^aG_l0003onk5N
oo^aG_l000000oo9PP001Ol0003o_H:Do`000?nNHHSo000000Kooooo00?o0000ooooooooool01_oo
ool00003o`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01?ooool01?o<c<coA4A4o`000?l@4105ooooo`03o`000?oooooooooo00?o
oooo0ol0001;ooooo`;o00001?lc3gD00ol0003ok[JFonjfUP02o`00000:ooo@P_l0003o0000ooBj
SOl0003ool]fo`000?omcfko0000ocPPQ`;o00000_mhDYT01?l0003oX7>Ooj1cWonPLil2o`0000Co
_h^N00?o0000olF>Vol000000_oAVYd02Ol0003odi^Jom>KV_oCVi[o0000omJKV?l0003oeIjMo`00
0003om^QU`?o00000_loBK@01?l0003oS7:`ohab/?l00004ojN1ZP04o`000?nfRJKo]XVVokJ9YP;o
00001?o4Tj@2o`0000?ocibQ00Ko0000om>PXOoCX:7o0000omRSWol00003ombVWP03o`000?oOZYgo
gjZM00;o00000_oRZi/02Ol0003oi:jLonB^W?oT[Yco0000onJbW_l0003ogZRLo`000002omfWWP;o
00000on6PLH00ol0003o/Y6dok:A]002ok:A]0;o00000oo6Vjd00ol0003od9jSo`000005omBTY@05
o`000?oNZYoogZZOomjZWol000000_oV]J801ol0003ok;NKonbgVoo/]i_o0000ooK7W?l000000_om
hiH00ol0003oXg2Ioj=`V@02o`0000?o]WjG00Co0000oiFJe_nEV]KoUI[F0_l000000ook/fOo0000
oo^cI`05oo^cI`05o`000?ok/fGo0000oo^cIOl000001Ook/fD3o`000003oo^bHol0003onk9S00?o
nk9S0_l000000ook/V;o0000oo^bHP02oo^bHP?o000000Conk9Po`000?ok/V3o00000ook/V001_l0
003oT5b@o`000?l0003onk5No`0000;onk5N0_l00002olV20005o`000?nmPYCo0000oiiQR?l00000
1_ooool00ol0003oooooooooo`06ooooo`009oooool01?l0003oooooooooooooool3o`0004kooooo
0_l00003oc<?M@04o`000?o^]YKok[JFonjfUP;o000000Coom22o`000?l0003o00000_oobgH01?l0
003ooLm^o`000?lh88L2o`0000?oN5:I00?o0000oj1cWol000000_n/NYd02Ol0003o_h^Nokn;W_no
Riko0000olF>Vol0003odIZMo`000004om>KVP04o`000?oFViSo0000o`0000?ofj6G00Co0000om^O
U_oKWiKo00000_loBK@01Ol0003oS7:`ohab/?n<L[3o000000?oYh6Z00Oo0000okJ9Y_nfRJKo]XVV
o`000?niS:Oo000000?oa9>T00?o0000olRGY?l000000_o?W:401Ol0003odj2Qom>PXOoCX:7o0000
00?og:JN00?o0000omnZWOoOZYd00_oOZYd01?l0003ohZ^Kon:[Vol00003onB^W005o`000?oV/Yko
0000omjXW?l000000ooMYih2o`0000;oQX7600Co0000ok:A]?nbTKCo/Y6d0_l00004olJK[@03o`00
0?o@WZ?o000000Goe:BU00Co0000omjZWooNZYoo00000ooV]J801ol0003ok;NKonbgVoo/]i_o0000
ooK7W?l000000_omhiH00ol0003oXg2Io`000002o`0000?o]WjG0_l00002oiFJeP;o000000?onk=W
o`000?ok/fL01Ook/fL01Ol0003onk=Uo`000?ok/fGo000000Gonk=U0_l000000ook/V?o0000o`00
0004oo^bH`;o000000?onk9Ro`000?ok/V800ook/V82o`000004oo^bH?l0003onk9Po`0000?onk9P
00Ko0000oi1LT?l0003o0000oo^aG_l00002oo^aGP;o00000_o9PP001Ol0003o_H:Do`000?nNHHSo
000000Kooooo00?o0000ooooooooool01_ooool002Oooooo1?l0001Aooooo`;o00000olc3gD01ol0
003ok[JFonjfU_l0003on/F?o`000?ood8800ol000001_oobgKo0000oog?K_omcfko0000ocPPQ`;o
00000omhDYT2o`0000?o[7ZM00Co0000okn;W_noRiko00000_o5SY/00ol0003odIZMo`000003om>K
VP05o`000?oFViSoeY^HomJKV?l000000ooKXIL01?l0003ofinFom^OU_l00002ocm9]005o`000?n<
L[3oS7:`ohab/?l000000onWPJX01?l0003o]XVVokJ9Y_l00002okV<Y`07o`000?o4TjCoa9>TolBC
Y?l0003ob9NTo`000002olnLX@05o`000?oCX:7odj2Qom>PXOl000000ooLYYh00ol0003ogjZMomnZ
W@02omnZW@04o`000?oRZi_ohZ^Ko`0000?oi:jL00Go0000onJbW_l0003ogZRLo`000002omfWWP06
o`000?oIYj?o0000o`000?n6PLKo00000_nbTK@00ol0003o[YFno`000005olJK[@;o00001?oDY:D0
1Ol0003ofjnZo`000?oNZYoo000000?oi[FR0_l00002onbgV`05o`000?ofaico0000oogSU_l00000
0_nSL9T3o`0000Co]WjG00Co0000oiFJe_nEV]KoUI[F0ol00006oo^cI`05o`000?ok/fGo0000oo^c
IOl000001Ook/fD2o`000003oo^bHol0003o000000Conk9S0_l000000ook/V;o0000oo^bHP03oo^b
HP;o000000Conk9Po`000?ok/V3o00000ook/V001?l0003oT5b@o`000?ok/Eh2o`0000?onk5N00So
0000olV20?o9PP3o0000okf2U?l0003oWV68o`0000Kooooo00?o0000ooooooooool01_ooool002Oo
oooo0_l0001Cooooo`;o00000olc3gD01ol0003ok[JFonjfU_l0003on/F?o`000?ood8800ol00000
1OoobgKo0000oog?K_omcfko000000;o>22700Co0000ogQBVOmhDYWoN5:I0_l00003ojajW@04o`00
0?noRiko_h^No`0000;oaHjK00?o0000om6JWOl000000ooCViX01Ol0003oeY^HomJKV?oFViSo0000
00?ofj6G00Oo0000om^OU_oKWiKofinFo`000?loBKCo000000?oS7:`00?o0000ojN1Z_nWPJX00_nW
PJX2o`0000?o^HbW00Co0000olBCY?o4TjCo00000_o8Uj@00ol0003ocibQo`000004om>PX@05o`00
0?oLYYkog:JNombVW_l000001?oOZYd2o`000003on:[Vol0003oi:jL00;oi:jL00Co0000onJbW_oV
/Yko00000ooMYih01?l0003ofJNSo`000?mFLm@4o`0000;o[YFn00?o0000olJK[Oo6Vjd00oo6Vjd0
0ol0003oe:BUomBTY@03omBTY@05o`000?oK[j[o0000omjZWol000000_oV]J800ol0003ol/RUoo;8
Y@02o`000003ooK7W?l0003ooN>F00;o00000_nSL9T3o`0000?o]WjG0_l00003oiFJeP03o`000?oF
Xj7o000000Konk=W00Go0000oo^cIOl0003onk=Uo`000005oo^cI@;o000000?onk9So`000?l00000
1?ok/V<2o`000003oo^bH_l0003onk9R00?onk9R0_l000001?ok/V3o0000oo^bH?l00003oo^bH004
o`000?n@G93o0000oo^aGP;o00000ook/Eh02?l0003obH80olV20?l0003o_H:Do`000?nNHHSo0000
1oooool00ol0003oooooooooo`05ooooo`00:Oooool00ol0003oooooooooo`1@ooooo`;o00000olc
3gD03?l0003ok[JFonjfU_l0003on/F?o`000?ood8;o0000ooBjSOl0003ool]fo`0000?ooLm^00?o
0000ocPPQol000001?l00004ojajW@04o`000?noRiko_h^No`0000?oaHjK0_l00003om>KVP05o`00
0?oFViSoeY^HomJKV?l000000ooKXIL01?l0003ofinFom^OU_oKWiH3o`0000?oS7:`00?o0000ojN1
Z_nWPJX00_nWPJX2o`0000?o^HbW00Co0000olBCY?o4TjCo00000_o8Uj@00ol0003ocibQo`000004
om>PX@05o`000?oLYYkog:JNombVW_l000000ooOZYd01Ol0003oi:nNo`000?oRZi_o000000;oi:jL
00Go0000onJbW_oV/Ykoi[:No`000003omfWWP04o`000?oIYj?o0000o`0000;oEW?D00?o0000ojjE
__n^UKh00_n^UKh00ol0003oaY^]olJK[@02olJK[@03o`000?oDY:Goe:BU00;oe:BU00Ko0000om^_
Z_oK[j[o0000omjZWol00002onJeXP08o`000?obb:Gol/RUoo;8YOl0003om/NLo`000?omhiH2o`00
00;oXg2I00?o0000ojVmj?l000000onfOYL4o`000005oiFJe_l0003oeZ>QomJSXOl000000ook/fL3
o`000004oo^cIOl0003onk=Uo`0000Gonk=U0_l000000ook/V?o0000o`000005oo^bH`03o`000?ok
/V;o000000Conk9R1?l000000ook/V3o0000oo^bH002oo^bH004o`000?n@G93o0000oo^aGP;o0000
0ook/Eh01_l0003obH80olV20?o9PP3o0000okf2U0;o00001oooool00ol0003oooooooooo`05oooo
o`00:_ooool00ol0003oooooooooo`1?ooooo`;o00000olc3gD00ol0003ok[JFonjfUP02o`000007
ooo@P_l0003o0000ooBjSOl0003ool]fo`000003oog?KP03o`000?lh88Oo000000?oRenI00?o0000
ojajWOn/NYd00_n/NYd00ol0003o_h^No`000004olF>V`03o`000?oCVi[odi^J00;odi^J00Go0000
omJKV?oFViSoeY^Ho`000003om^QU`06o`000?oKWiKofinFom^OU_l0003o01:O0_l00002ohab/004
o`000?nWPJ[oYh6ZojN1ZP;o00001?niS:L00ol0003oa9>To`000003olRGY003o`000?o?W:7o0000
00?odj2Q00Go0000omRUXOl0003og:JNo`000004omnZW@04o`000?oT[iko0000o`0000?oi:jL00Go
0000onJbW_oV/Ykoi[:No`000003omfWWP04o`000?oIYj?ofJNSo`0000;oEW?D00?o0000ojjE__n^
UKh00_n^UKh01ol0003oaY^]olJK[Oo6Vjgo0000olVT]?l000000ooDY:D01Ol0003ofjnZom^_Z_oK
[j[o000000?oi[FR00Ko0000oo;8YOobb:Gol/RUo`000?ofai`2o`0000;o[gRF00Go0000oj=`VOl0
003oZKgXo`000003okInU`03o`000?nY_NSoZKgX00?o000000?oeZ>Qo`000?oBZ:h00ol00003ojG3
k`;o000000?onk=Uo`000?ok/fD01?ok/fD2o`000003oo^bHol0003o000000Gonk9S0ol00004oo^b
HP;o000000Conk9Po`000?ok/V3o00000ook/V001?l0003oT5b@o`000?ok/Eh2o`0000?onk5N0_l0
0002olV20005o`000?nmPYCo0000oiiQR?l000001_ooool00ol0003oooooooooo`05ooooo`00:ooo
ool00ol0003oooooooooo`1>ooooo`;o00000_lc3gD01?l0003ok[JFonjfU_o^]YH2o`000007ooo@
P_l0003o0000ooBjSOl0003ool]fo`000003oog?KP03o`000?lh88Oo000000?oRenI00?o0000ojaj
WOn/NYd00_n/NYd00ol0003o_h^No`000004olF>V`03o`000?oCVi[odi^J00;odi^J00Go0000omJK
V?oFViSoeY^Ho`000003om^QU`07o`000?oKWiKofinFo`000?oJWYGo0000o`0BW`02o`0000;oS7:`
00Go0000ojN1Z_l0003oYh:]o`000005okV<Y`;o00001?o8Uj@00ol0003odj2Qom>PX@02om>PX@05
o`000?oHYJ7o0000ombVW_l000001?oOZYd01?l0003oi:nNonB_W_l00003onB^W005o`000?oV/Yko
i[:NonJbW_l000000_oMYih01?l0003ofJNSomVWXooIYj<2o`0000;oEW?D00Go0000ojjE__n^UKko
[YFno`000002olJK[@04o`000?o9Y;CobJBdo`0000?oe:BU00Go0000om^_Z_oK[j[ofjnZo`000002
onJeXP07o`000?obb:Gol/RUoo;8YOl0003on^^Oo`000004ojmhUP03o`000?nSL9Wo000000?o0000
0_nfOYL00ol0003oZKgXo`000005o`000003om:X[_l0003oYL?_00CoYL?_0_l000000ook/fGo0000
oo^cI@04oo^cI@;o000000?onk9So`000?l000001Ook/V<3o`0000Conk9R0_l000001?ok/V3o0000
oo^bH?l00003oo^bH004o`000?n@G93o0000oo^aGP;o00000ook/Eh2o`0000;obH8000Go0000okf2
U?l0003oWV68o`000006ooooo`03o`000?oooooooooo00Gooooo000/ooooo`;o0000C_ooool2o`00
00;o<`me00Oo0000onjfU_o^]YKo0000oo[5Sol0003oom2200;o000000Com;Z=o`000?oobgKo0000
0oomcfh00ol0003o>227o`000003oh]OV@03o`000?n/NYgo[7ZM00;o[7ZM00?o0000okn;W_l00000
1?o5SY/01Ol0003odi^Jom>KV_oCVi[o000000?oeY^H00Go0000omRLU_l0003ofj6Go`000003om^O
UP06o`000?oJWYGo0000o`0BWol0003oO6bf1?l00002ojN2[@03o`000?niS:Oo^HbW00?o^HbW0_l0
0004olRGY003o`000?oCX:7odj2Q00;odj2Q00Go0000omRUXOl0003og:JNo`000004omnZW@04o`00
0?oT[ikoi:nNo`0000;oi:jL00Wo0000onJbW_oV/Ykoi[:No`000?oY^Z?o0000omfWW_l000000ooI
Yj<3o`000003oeIce?l0003o[YFn00?o[YFn0_l00004olVT]003o`000?oDY:Go000000CofjnZ00Co
0000onJeX_oV]J;o00000oobb:D00ol0003on^^Oo`000004ojmhUP04o`000?nSL9Wo0000ojVmj0;o
00000_nfOYL2o`0000;ooooo00?o0000o`1<bOl000000ooBZ:h00ol0003oYL?_o`000002o`000004
ojG3kol0003onk=Uo`0000Konk=U00Co0000oo^bHol0003o00001Ook/V<2o`000003oo^bH_l0003o
nk9R00;onk9R0_l000001?ok/V3o0000o`000?l00004oo^bH0;o000000?onk5No`000?l000000ook
/Eh2o`0000;obH8000Go0000okf2U?l0003oWV68o`000006ooooo`03o`000?oooooooooo00Gooooo
000^ooooo`03o`000?oooooooooo04_ooooo0_l00002oc<?M@07o`000?o^]YKok[JFo`000?ojaHoo
0000ooo@PP03o`000003ooo;M_l0003ooLm^00?ooLm^00?o0000ocPPQol000000on;GiT00ol0003o
[7ZMojajW@03ojajW@;o00001?o5SY/01Ol0003odi^Jom>KV_oCVi[o000000?oeY^H00Go0000omRL
U_l0003ofj6Go`000003om^OUP05o`000?oJWYGo0000o`0BWol000000omlK;H00ol0003oYh:]ojN2
[@02ojN2[@03o`000?niS:Oo^HbW00;o^HbW00?o0000olRGY?o8Uj@00oo8Uj@01Ol0003odj2Qom>P
XOoCX:7o000000;of:FQ00?o0000ombVW_l000000ooOZYd01Ol0003oi:nNonB_W_oT[iko000000;o
i:jL00Wo0000onJbW_oV/Ykoi[:No`000?oY^Z?o0000omfWW_l000001?oIYj<4o`0000?o[YFn0_l0
0005olVT]003o`000?oDY:Go000000?ofjnZ00Go0000onO4/ol0003oi[FRo`000002oo;8Y@03o`00
0?ojjioo000000Go[gRF00?o0000oj=`VOl000000ol00002okInU`03o`000?oooooooooo00;ooooo
0_l00004om:X[P03o`000?nU`nooYL?_00?oYL?_0_l00006oo^cI@04o`000?ok/V?o0000o`0000Go
nk9S0_l000000ook/V;o0000oo^bHP03oo^bHP05o`000?ok/V3o0000oo^bH?l000001?ok/V02o`00
0003oo^aG_l0003o000000Conk5N00So0000olV20?o9PP3o0000okf2U?l0003oWV68o`0000Kooooo
00?o0000ooooooooool01Oooool002oooooo00?o0000ooooooooool0B_ooool2o`0000;o<`me00co
0000onjfU_o^]YKo0000oo[5Sol0003oom22o`000?od^Xgo0000ooo;M_l00004oog?KP03o`000?lh
88Oo000000CoRenI00?o0000ojajWOn/NYd00_n/NYd00ol0003oaHjKolF>V`02olF>V`;o00000ooC
ViX02Ol0003oeY^HomJKV?oFViSo0000omRLU_l0003ofj6Go`000003om^OUP06o`000?oJWYGofYjE
o`000?l04Yoo00000_mlK;H00ol0003oYh:]ojN2[@02ojN2[@03o`000?niS:Oo^HbW00;o^HbW00?o
0000olRGY?o8Uj@00_o8Uj@2o`0000?odj2Q00Go0000omRUXOoHYJ7of:FQo`000004omnZW@04o`00
0?oT[ikoi:nNonB_WP;o000000?oi:jLo`000?oV/Yh00_oV/Yh01Ol0003ojKZSo`000?oMYiko0000
00CofJNS00?o0000olJBX?l000001?l000000onRWm;o0000olVT]005olVT]003o`000?oK[j[ofjnZ
00;ofjnZ00Go0000onO4/ol0003oi[FRo`000002oo;8Y@04o`000?ojjioo0000o`0000Co[gRF00?o
0000oj=`VOl000000_ooool01?l0003o]WjGokInUol00005ooooo`;o00001?oBZ:h01?l0003oYL?_
ojG3konU`nl3o`0000Konk=U00Co0000oo^bHol0003o00001Ook/V<2o`000003oo^bH_l0003onk9R
00?onk9R0ol000000ook/V3o0000o`000003oo^bH0;o000000Conk5No`000?ok/Eko00000ook/Eh0
2?l0003obH80olV20?l0003o_H:Do`000?nNHHSo00001_ooool00ol0003oooooooooo`05ooooo`00
<?ooool00ol0003oooooooooo`19ooooo`04o`000?lc3gGo<`meo`0000?ok[JF00?o0000oo[5Sol0
00000_l000001?od^Xgo0000ooo;M_l00003oog?KP;o00000_lh88L01Ol0003oRenIoh]OVOn;GiWo
000000Co[7ZM00?o0000olF>Voo5SY/00_o5SY/00ol0003obY6Io`000002om>KVP09o`000?oFViSo
eY^HomJKV?l0003of9bFo`000?oKXIOo000000?ofinF00Ko0000omZNUOoJWYGo0000o`0BWol00002
oga/]P03o`000?nWPZgoYh:]00;oYh:]00Co0000okV<YoniS:Oo^HbW0_l00004olRGY003o`000?o=
W:Go000000;odj2Q00Go0000omRUXOoHYJ7of:FQo`000004omnZW@08o`000?oT[ikoi:nNo`000?oZ
^:3o0000onB^W?l00002onJbWP05o`000?oY^Z?ojKZSonVjXol000001OoIYj<01Ol0003oaY:Po`00
0?l0<KGo000000CoXYoB00?o0000olVT]?o9Y;@00oo9Y;@01Ol0003ofjnZom^_Z_oK[j[o000000;o
ilBc0_l00003oo;8Y@;o000000?o[WNFo`000?n_N9H00on_N9H2o`0000?ooooo00Co0000okInUonf
OYOo00001_ooool00ol0003odZR^om:X[P02om:X[PCo000000CohZRGo`000?oW]Z;o00000ook/fD3
o`000003oo^bHol0003o000000Gonk9S0_l000000ook/V;o0000oo^bHP03oo^bHP?o000000?onk9P
o`000?l000000ook/V02o`000004oo^aG_l0003onk5No`0000?onk5N0_l000001?o9PP3o0000okf2
U?nmPY@2o`0000Oooooo00?o0000ooooooooool01?ooool0037ooooo00?o0000ooooooooool0B?oo
ool01?l0003o<`meoc<?MOl00003onjfUP;o000000Ooom22o`000?l0003om;Z=o`000?oobgKo0000
00;ooLm^00?o0000oo2cSOl000000_lh88L01Ol0003oRenIoh]OVOn;GiWo000000Co[7ZM00?o0000
olF>Voo5SY/00_o5SY/00ol0003obY6Io`000002om>KVP09o`000?oFViSoeY^HomJKV?l0003of9bF
o`000?oKXIOo000000?ofinF00Co0000omZNUOoJWYGofYjE0_l00003oga/]P05o`000?nWPZgoYh:]
ojN2[Ol000000oniS:L00ol0003o_96Yo`000003olRGY003o`000?o=W:Go000000;odj2Q00Go0000
omRUXOoHYJ7of:FQo`000003omnZW@06o`000?oT[ikoi:nNonB_W_l0003oj[RP0_l00003onJbWP05
o`000?oY^Z?ojKZSonVjXol000001?oIYj<2o`0000;oaY:P0_l00004oj:OdP03o`000?o9Y;CobJBd
00;obJBd00?o0000olnha?l000000_oK[jX01Ol0003oilBconO4/ooWa;?o000000;ol/RU00Go0000
oo[[Wol0003o[WNFo`000004ojmhUP;o00000oooool01?l0003o]WjGokInUol00006ooooo`;o0000
0_oBZ:h00ol0003oa[S=o`000003on:XU`03o`000?oW]Z;oikJR00?o00000onU`nl3o`0000Gonk9S
0_l000000ook/V;o0000oo^bHP03oo^bHP?o000000Conk9Po`000?ok/V3o00000_ok/V02o`000004
oo^aG_l0003onk5No`0000?onk5N0_l000001?o9PP3o0000okf2U?nmPY@2o`0000Oooooo00?o0000
ooooooooool01?ooool003;ooooo0_l00018ooooo`04o`000?lc3gGo<`meo`0000;ok[JF00Co0000
oo[5Sol0003oom220_l000001Ood^Xgo0000ooo;M_l0003ooLm^00;o000000Gol;>=o`000?lh88Oo
>227o`000003oh]OV@04o`000?n/NYgo[7ZMojajW@;o00001?o5SY/01Ol0003obY6Io`000?oCVi[o
000000?oeY^H00Go0000omRLU_oHW9Kof9bFo`000003om^OUP04o`000?oJWYGofYjEomZNU@?o0000
0omlK;H01Ol0003oYh:]ojN2[OnWPZgo000000;o^HbW00Co0000okbAZOnlTJWo00000_o8Uj@01_l0
003ocIbUolfLYOl0003odj2Qo`0000Cof:FQ0_l00002omnZW@05o`000?oT[ikoi:nNonB_W_l00000
0_oZ^:001Ol0003oi[:NonJbW_oV/Yko000000?ojKZS00?o0000omVWXooIYj<00_oIYj<2o`0000?o
aY:P0_l00004oj:OdP04o`000?o9Y;CobJBdo`0000;ockS400?o0000om^_Z_l000001?oWa;<2o`00
0003oo;8YOl0003o000000;o[WNF00?o0000ojmhU_n_N9H00on_N9H01Ol0003ooooooooooooooooo
000000;o]WjG00?o0000ooooooooool01Oooool00ol0003odZR^o`000003olJhc@04o`000?oRZ9Oo
hZRGo`0000;oikJR00?o0000ojG3konU`nl00onU`nl3o`0000Gonk9S0_l000000ook/V;o0000oo^b
HP03oo^bHP?o000000Konk9Po`000?ok/V3onk9Po`000?ok/V02o`000004oo^aG_l0003onk5No`00
00?onk5N0_l000001?o9PP3o0000okf2U?nmPY@2o`0000Oooooo00?o0000ooooooooool01?ooool0
03Cooooo00?o0000ooooooooool0AOooool01?l0003o<`meoc<?MOl00002onjfUP04o`000?ojaHoo
0000ooo@PP;o000000?om;Z=o`000?oobgH00ol00002oo2cS@04o`000?lh88Oo>227o`0000?oRenI
00Co0000ojajWOn/NYgo[7ZM0_l00004olF>V`05o`000?o:TIWo0000om>KV_l000000ooFViP01Ol0
003of9bFomRLU_oHW9Ko000000?ofinF00Ko0000omZNUOoJWYGofYjEo`000?oJWY@2o`0000;oO6bf
00?o0000ojN2[OnWPZd00_nWPZd2o`0000?o_96Y00Co0000olRGY?o8UjCo00000_o=W:D00ol0003o
dj2Qo`000003omRUX@03o`000?oO[:;o000000;ogjZM00Co0000onB_W_oT[iko00000ooZ^:001?l0
003oi[:NonJbW_l00003onVjX`03o`000?o_c:oo000000;ofJNS00Co0000om6V[?oAYZco00000oo6
TZ000ol0003oXYoBoj:OdP02oj:OdP03o`000?o9Y;Co000000?ockS400?o0000om^_Z_l000000ooW
a;<00ol0003ol_>moo;c_@03o`0000;o[WNF00?o0000ojmhU_n_N9H00on_N9H01?l0003ooooooooo
ooooool2o`000003okInUol0003ooooo00Oooooo00?o0000olJhcOo6^<d00_o6^<d00ol0003ohZRG
o`000004onNfXP03o`000?nU`noo000000;o000000?oYL?_o`000?l000001_ok/V<00ol0003onk9R
o`000004oo^bHP?o000000Konk9Po`000?ok/V3onk9Po`000?ok/V02o`000004oo^aG_l0003onk5N
o`0000?onk5N0_l00002olV20004o`000?nmPYCo0000o`0000Oooooo00?o0000ooooooooool01?oo
ool003Gooooo00?o0000ooooooooool0A?ooool01?l0003o<`meoc<?MOl00002onjfUP04o`000?oj
aHoo0000ooo@PP;o000000?om;Z=o`000?oobgH00ol000000oo`/hgo0000o`000002ocPPQ`05o`00
0?n;GiWoRenIoh]OVOl000000on/NYd2o`0000?oaHjK00Ko0000olZAVOo:TIWo0000om>KV_l00003
omJKV005o`000?oHW9Kof9bFomRLU_l000000ooKWiH01_l0003ofYjEomZNUOoJWYGo0000omZNU0?o
000000?oO6bfo`000?nWPZd00onWPZd2o`0000?o_96Y00Co0000olRGY?o8UjCo00000_o=W:D00ol0
003odj2Qo`000003omRUX@06o`000?oO[:;ogjbRo`000?oOZYgo00000_oT[ih01?l0003oj[RPonZh
X?oZ^:02o`000003onJbW_l0003ojKZS00;ojKZS00?o0000ono<[ol000000_oIYj<01?l0003odJJ/
om6V[?l00004olJBX0Ko00001Oo?^<@01Ol0003oilBconO4/ooWa;?o000000;ol_>m00Co0000ojih
Uol0003o00000_n^MiH00ol0003o[gRFojmhUP03ojmhUP03o`000?oooooooooo00;ooooo00?o0000
okInUol000002?ooool00ol0003oa[S=olJhc@02olJhc@03o`000?oRZ9Oo000000CoikJR0_l00005
ojG3k`03o`000?ok/V?onk9S00Conk9S00?o0000oo^bH_l000001?ok/V82o`000003oo^bH?l0003o
000000?onk9P0ol000001?ok/Eko0000oo^aG_l00003oo^aGP;o00000_o9PP001Ol0003o_H:Do`00
0?nNHHSo000000Kooooo00?o0000ooooooooool01?ooool003Kooooo00?o0000ooooooooool0@ooo
ool00ol0003o<`meo`000003onjfUP03o`000?ojaHoo000000Co000000?ool]fo`000?omcfh00_l0
00000oo`/hgo0000o`000002ocPPQ`05o`000?n;GiWoRenIoh]OVOl000000_n/NYd01?l0003o]H2K
okF0Vol00002olF>V`06o`000?o:TIWobY6Io`000?oCVi[o00000ooFViP01Ol0003of9bFomRLU_oH
W9Ko000000?ofinF00Ko0000omZNUOoJWYGofYjEo`000?oJWY@2o`000003oeQN__l0003o000000?o
Yh:]0_l00004okbAZ@03o`000?o8UjCo000000CocIbU00?o0000omRUXOoHYJ400_oHYJ400ol0003o
gjbRomn/XP02o`0000?oi:nN00So0000onZhX?oZ^:3o0000oo?8Xol0003oi[:No`0000;ojKZS00Ko
0000ono<[oo_c:oo0000omVWXol00003om6V[004o`000?o6TZ3oaY:PolJBX0?o00000omN[?T00ol0
003ockS4olnha002olnha0;o00000ooWa;<00ol0003ol_>mo`000002ojihU`;o00000_n^MiH00ol0
003o[gRFojmhUP03ojmhUP03o`000?oooooooooo00;ooooo00?o0000okInUol000002Oooool01ol0
003oa[S=olJhcOo6^<go0000on:XUol000001?oW]Z800ol0003okK2>o`000002ojG3k`?o00001_ok
/V<00ol0003onk9Ro`000004oo^bHP;o000000?onk9Po`000?l000001?ok/V02o`000004oo^aG_l0
003onk5No`0000Conk5N0_l000001_o9PP3o0000okf2U?l0003oWV68o`0000Kooooo00?o0000oooo
ooooool01?ooool003Oooooo0_l00013ooooo`03o`000?lc3gGo000000?ok[JF00?o0000oo[5Sol0
00000_l000000ood^Xgo0000ooo;MP04o`000006oo2cSOl0003o0000o`000?lh88Oo00000on;GiT0
1?l0003o[7ZMojajWOl00002okF0V`04o`000?o5SY_oaHjKo`0000?obY6I0_l00003omJKV005o`00
0?oHW9Kof9bFomRLU_l000000ooKWiH01_l0003ofYjEomZNUOoJWYGo0000omZNU0;o00000_mHG[h4
o`000003ojF6/_l0003o_96Y00Co_96Y0_l00004olfLY@03o`000?oHYJ7of:FQ00;of:FQ00Go0000
omn/X_oO[:;ogjbRo`000003onB_WP05o`000?oZ^:3oj[RPo`000?ocb:<00_l00003onVjX`04o`00
0?o_c:ooklb_ono<[`;o00000ooAYZ`01?l0003oaY:PolJBX?o6TZ02o`000003okJ2WOl0003o0000
00;oGZci00Co0000olnha?o?^<Co00000_o>kNT01Ol0003oilBco`000?oblkgo000000?o[WRG00Go
0000ojigU_n^MiKo[WNFo`000005ojmhUP03o`000?oooooooooo00;ooooo0_l0000;ooooo`?o0000
00?oa[S=o`000?oW]Z801?oW]Z800ol0003okK2>onf`SP02o`000004oo_9TOl0003o0000o`0000?o
nk9S0ol000000ook/V;o0000oo^bHP03oo^bHP;o000000Conk9Po`000?ok/V3o00001?ok/V001Ol0
003onk5No`000?ok/Eko000000Conk5N0_l000001?o9PP3o0000okf2U?nmPY@2o`0000Kooooo00?o
0000ooooooooool01?ooool003Wooooo00?o0000ooooooooool0@?ooool00ol0003o<`meo`000002
onjfUP04o`000?ojaHoo0000ooo@PP;o000000?om;Z=o`000?oobgH00_l000000oo`]I3o0000oo2c
S@03o`000003ocPPQol0003oRenI00;oRenI00Co0000ojajWOn/NYgo00000_neP9/01?l0003oaHjK
olF>Vol00003olZAV@03o`000?oFViSoeY^H00;oeY^H00Go0000omRLU_oHW9Kof9bFo`000003om^O
UP06o`000?oJWYGofYjEomZNUOl0003ofYjD0ol00002oeQN_P05o`000?nUQ[;oYHJbojF6/_l00000
1OnlTJT2o`0000CocIbU00Go0000omRUXOoHYJ7of:FQo`000004omn/XP04o`000?oT[ikoi:nNo`00
00?oj[RP00Co0000oo?8Xoocb:?o00000ooY^Z<01Ol0003oklb_ono<[oo_c:oo000000CodJJ/00Ko
0000olJBX?o6TZ3o0000okN8Y?l00003okJ2W@?o000000CockS4o`000?o>kNWoc^gY1Ol00004ojih
U`05o`000?n^MiKo[WNFojigU_l000001?n_N9H00ol0003oooooooooo`03ooooo`;o00003?ooool4
o`0000CoikJR00Go0000oo;S_?l0003okK2>o`000002oo_9T@Ko00000onU`nl2o`0000Gonk9R00Go
0000oo^bH?l0003onk9Po`000004oo^bH0?o000000?onk5No`000?ok/Eh00ook/Eh2o`000004olV2
0?l0003o_H:Dokf2U0;o00001oooool00ol0003oooooooooo`03ooooo`00>_ooool00ol0003ooooo
ooooo`0oooooo`03o`000?lc3gGo000000;ok[JF00Co0000oo[5Sol0003oom220_l000000ood^Xgo
0000ooo;MP02o`000003oo2eT?l0003ol;>=00?o000000?o>227o`000?n;GiT00on;GiT2o`0000?o
]H2K00Co0000olF>Voo5SY_o00000oo:TIT01Ol0003oeY^HomJKV?oFViSo000000?of9bF00Go0000
on6VUOl0003ofinFo`000004omZNU@05o`000?oJWYCo0000om6GV?l000000_mHG[h00ol0003oYHJb
ojF6/P02ojF6/P03o`000?nlTJWo_96Y00;o_96Y00?o0000olfLYOo=W:D00_o=W:D00ol0003odjFW
o`000002omRUX@09o`000?oO[:;ogjbRomn/X_l0003oikVTo`000?oT[iko000000;oj[RP00Go0000
oo?8Xoocb:?ollRSo`000002onVjX`03o`000?o_c:ooklb_00;oklb_00?o0000om6V[?oAYZ`00ooA
YZ`2o`0000?o]hRT00Ko0000okJ2WOnfPYgo]X:Mo`000?ndOiX4o`0000Co[WRH00?o0000ojihUon^
N9L00_n^N9L01Ol0003o[WNFojigU_n^MiKo000000Co[gRF00?o0000ooooooooool00oooool2o`00
00kooooo0_l00003onNfXP06o`000?obhkcol^>lo`000?o]/8ko00000_okbI401?l0003oY76Ho`00
0?l00005ojG3k`;o00001Ook/V801Ol0003onk9Po`000?ok/V3o000000Conk9P0ol000000ook/Eko
0000oo^aGP03oo^aGP;o000000?obH80o`000?l000000ol00007ooooo`03o`000?oooooooooo00?o
oooo000kooooo`03o`000?oooooooooo03kooooo0_l00003onjfUP03o`000?ojaHoo000000?o0000
00?om;Z=o`000?oobgH00_l000000oo`]I3o0000oo2cS@02o`000003odd_S?l0003o000000CoRenI
0_l00003okF0V`03o`000?o5SY_o000000CobY6I00Go0000omJKV?oFViSoeY^Ho`000003omRLUP05
o`000?oQYYGo0000om^OU_l000000ooJWYD01?l0003ofYjDomZNU?oJWY@2o`0000;oF5jn00?o0000
ojF6/_nUQ[800_nUQ[800ol0003o_96YokbAZ@02okbAZ@03o`000?o=W:GocIbU00;ocIbU00?o0000
om>UYol000000_oHYJ402Ol0003ogjbRomn/X_oO[:;o0000onNiY?l0003oi:nNo`000002onZhX008
o`000?ocb:?ollRSo`000?okijKo0000onVjXol00003ono<[`03o`000?oOoM3o000000CodJJ/0_l0
0003okN8Y005o`000?nfPYgo]X:MokJ2WOl000000_ndOiX01?l0003o[7RIojahVOl00003ojihV003
o`000?n^N9Oo[WRG00;o[WRG00?o0000ojigU_n^MiH00_n^MiH01Ol0003o[gRFojmhU_n_N9Ko0000
00Kooooo00?o0000ooooooooool03Oooool2o`0000;oikJR00?o0000oo;S_?obhk`00_l00003oo_9
T@06o`000?nTLISo0000ojYcU_l0003oYL?_0ol000000onU`noo0000oo^bHP04oo^bHP05o`000?ok
/V3o0000oo^bH?l000001?ok/V03o`000003oo^aG_l0003onk5N00?onk5N00Co0000oiaMQOl0003o
00000_nELZT2o`0000Oooooo00?o0000ooooooooool00oooool003cooooo0_l0000nooooo`;o0000
0oo^]YH02Ol0003on/F?o`000?l0003okkRFo`000?od^Xgo0000ooo;MP02o`000003oo2eT?l0003o
l;>=00;o000000CoCBn<o`000?lh88Oo00000on;GiT2o`0000?o]H2K00?o0000olF>Vol000001?o:
TIT01Ol0003oeY^HomJKV?oFViSo000000?of9bF00Go0000on6VUOl0003ofinFo`000003omZNU@04
o`000?oJWYCofYjDomZNU0?o00000_mHG[h01Ol0003oYHJbojF6/_nUQ[;o000000?o_96Y0_l00004
olfLY@06o`000?oCYJOodjFWo`000?oHYJ7o00000ooO[:801?l0003oikVTo`000?l00003onZhX004
o`000?ocb:?ollRSo`0000;onnNV00Go0000ono<[oo_c:ooklb_o`000002omomd004o`000?oAYZco
dJJ/om6V[0;o00001?ngR:@01Ol0003o]X:MokJ2WOnfPYgo000000;o]7nJ00Co0000ojahVOn/N9Wo
00000on^N9P01?l0003o[WRGojihUon^N9L2o`0000Co[WNF00Go0000ojmhU_n_N9Ko[gRFo`000006
ooooo`03o`000?oooooooooo00kooooo00?o0000onNfX_l000001?obhk`01?l0003onlVAoo_9TOl0
0002ojAaV004o`000?nZLiKoZW>Fo`0000GoYL?_00?o0000oo^bH_ok/V800ol000001?ok/V3o0000
oo^bH?l00004oo^bH0;o000000?onk5No`000?l000001?ok/Eh01?l0003oW5f5o`000?l00002oiEb
Z@;o00001oooool00ol0003oooooooooo`03ooooo`00?_ooool00ol0003oooooooooo`0kooooo`;o
00000oo^]YH01ol0003on/F?o`000?l0003okkRFo`000?od^Xd01Ol00002oo2cS@?o000000?oCBn<
o`000?l000000_n;GiT2o`0000Co]H2K00?o0000olF>Vol000001?o:TIT01Ol0003oeY^HomJKV?oF
ViSo000000?of9bF00Go0000on6VUOl0003ofinFo`000003omZNU@07o`000?oJWYCofYjDomZNU?l0
003oe9VEo`000002oeQN_P05o`000?nUQ[;oYHJbojF6/_l000000_nlTJT01?l0003o`IR]ol6H[Ol0
0002olfLY@07o`000?oCYJOodjFWom>UYol0003of:FQo`000002omn/XP05o`000?oW^JCoikVTonNi
Y?l000000_oZ^:001?l0003ollRSoo?8Xol00003oo_WYP;o000000Koklb_o`000?l0003o0000omom
d?l00002om6V[003o`000?nhX<3o000000Co]hRT00?o0000okJ2WOnfPYd00_nfPYd2o`0000?o[7RI
00Go0000ojihV?n^N9So[WRHo`000003ojihU`;o00001?n^MiH01Ol0003o[gRFojmhU_n_N9Ko0000
00Kooooo00?o0000ooooooooool03_ooool2o`0000Col^>l0ol000001OokbI7o0000ojAaV?nTLISo
000000?oZW>F00Co0000ojG3konU`nooYL?_1?l00003ojG3k`;o000000?onk9Po`000?ok/V000ook
/V02o`000003oo^aG_l0003o000000Conk5N00Co0000oiaMQOl0003o00000_nELZT2o`0000Oooooo
00?o0000ooooooooool00oooool003oooooo00?o0000ooooooooool0>_ooool2o`0000;ok[JF00?o
0000oo[5SoojaHl00_l000001?o_^9Ko0000o`000?oobgH4o`000003oo2cSOl0003ol;><00;o0000
00OoCBn<o`000?l0003oRenIo`000?nIJIWo000000Go]H2K0_l00003olZAV@03o`000?oKXYWo0000
00;oeY^H00Wo0000omRLU_oHW9Kof9bFo`000?oQYYGo0000om^OU_l000000ooJWYD01_l0003ofYjD
omZNU?oJWYCo0000omBIU@;o000000?oF5jno`000?nUQ[800_nUQ[801?l0003o_96YokbAZOl00002
ol6H[@04o`000?o=W:GocIbUo`0000?odjFW0_l00003omn/XP05o`000?oW^JCoikVTonNiY?l00000
0_oZ^:001?l0003ollRSoo?8Xol00002oo_WYP03o`000?nY_NSo000000;o00000_ooool4o`0000;o
^:3000?o0000okN8Y?ngR:@00_ngR:@00ol0003o]X:MokJ2W@02okJ2W@;o00000on/N9T01Ol0003o
[WRHojihV?n^N9So000000?o[WRG0_l00004ojigUP04o`000?n_N9Ko[gRFo`0001Sooooo00Co0000
of]CY?l0003ol^>l0_l00002oiEXV`;o00000onTLIP00ol0003oZW>FojYcUP02ojYcUP?o00000_n/
Li@01?l0003oYL?_ojG3konU`nl3o`000003oo^bH?l0003onk9P00Conk9P00Co0000oo^aG_l0003o
00001Ook/Eh2o`000004olV20?l0003oUG:YoiEbZ@;o00001_ooool00ol0003oooooooooo`03oooo
o`00@?ooool00ol0003oooooooooo`0iooooo`;o00000_o^]YH00ol0003on/F?o`000003o`000003
ooBjSOl0003ool]f00;o000000Col;F@o`000?o`/hgo00000_o`/h`00ol0003oCBn<o`000002o`00
00;oVFVI00?o0000okF0VoneP9/00oneP9/2o`0000?obY6I00?o0000om^RVOl000000_oFViP02Ol0
003of9bFomRLU_oHW9Ko0000on6VUOl0003ofinFo`000003omZNU@05o`000?oJWYCofYjDomZNU?l0
00000_oDVID3o`0000CoYHJb0_l00003ol6H[@03o`000?o=W:Go000000GodjFW00Go0000omn/X_oO
[:;ogjbRo`000002onNiY005o`000?odcjSo0000onZhX?l000000_ocb:<00ol0003onnNVo`000002
o`0000Oooooo00Go0000okRP`?nhX<3o^:30o`000004okN8Y003o`000?nfPYgo]X:M00;o]X:M00?o
0000ojahVOn/N9T00_n/N9T01Ol0003o[WRHojihV?n^N9So000000;o[WRG00Co0000ok9kV?nbNiSo
00000on^MiH01?l0003o[gRFojmhU_l0000Hooooo`03o`000?m[DjCoJe>T00;o00000onEJ9/00ol0
003oY76HojAaV002ojAaV003o`000?nZLiKoZW>F00;oZW>F00?o0000ojacU?n/Li@00_n/Li@4o`00
00?oYL?_0_l00005oo^bH003o`000?ok/Eko000000;o00001?ok/Eh2o`000004olV20?l0003oUG:Y
oiEbZ@;o00001_ooool00ol0003oooooooooo`03ooooo`00@Oooool2o`0003Wooooo00Ko0000onjf
U_o^]YKok[JFo`000?ojaHl4o`000003ooBjSOl0003ool]f00;o000000Col;F@o`000?o`/hgo0000
0_o`/h`01?l0003oCBn<odd_S?l00003oiUYV@03o`000?neP9_o]H2K00?o]H2K00?o0000olZAVOo:
TIT00_o:TIT01Ol0003ofj:Io`000?oFViSo000000?of9bF00Go0000on6VUOoQYYGohJJEo`000004
omZNU@05o`000?oJWYCofYjDomZNU?l000000_oDVID01Ol0003o02>_o`000?l0003oYHJb00?o0000
1?o1V:d00ol0003ocIbUo`000005om>UY`04o`000?oO[:;ogjbRo`0000?oikVT00Co0000ooC?Z?l0
003o00000_ocb:<00ol0003onnNVo`00000:ooooo`03o`000?nhX<3o^:3000;o^:3000Go0000okN8
Y?ngR:Co]hRTo`000004okJ2W@03o`000?n/N9Wo[7RI00;o[7RI00Go0000ojihV?n^N9So[WRHo`00
0002ojihU`04o`000?nbNiSo/W^Ho`0000?o[WNF00Co0000ojmhU_n_N9Ko00006Oooool01?l0003o
Je>Tof]CY?l00003oiEXV`03o`000?nTLISoY76H00?oY76H00Go0000ojYcU_nZLiKoZW>Fo`000004
ojacU0;o00001OnU`nl2o`0000Gonk9P00Go0000oo^aG_l0003onk5No`000004oo^aGP04o`000?nL
GHGo0000o`0000;oUG:Y0_l00006ooooo`03o`000?oooooooooo00?ooooo0013ooooo`03o`000?oo
oooooooo03Kooooo00Ko0000onjfU_o^]YKok[JFo`000?ojaHl2o`000005onnhU_l0003om;Z=o`00
0?oobgH00_l000001?o`]I3o0000oo2cSOl00002oo2cS004o`000?m=;hcoCBn<o`0000?oVFVI00?o
0000okF0VoneP9/00oneP9/00ol0003obY6IolZAV@02olZAV@05o`000?oKXYWo0000omJKV?l00000
0ooHW9H01Ol0003ohJJEon6VUOoQYYGo000000?ofYjE00?o0000omZNU?oJWY@00_oJWY@00ol0003o
e9VEomBIU@02o`000003o`0S[ol0003o000000;oX8bo00?o0000ol6H[Oo1V:d00oo1V:d2o`0000Co
djFW00Go0000omfc[Ol0003ogjbRo`000003onNiY003o`000?odcjSom<nX00;o000000?ollRSo`00
0?l000002oooool2o`0000?o^:3000Go0000okN8Y?ngR:Co]hRTo`000003okJ2W@;o00001?n/N9T0
1Ol0003o[WRHojihV?n^N9So000000;o[WRG00Co0000ok9kV?nbNiSo00000on^MiH01?l0003o[gRF
ojmhU_l0000Iooooo`04o`000?m[DjCoJe>To`0000CoUFRK00?o0000ojAaV?nTLIP00_nTLIP01Ol0
003oZW>FojYcU_nZLiKo000000Co[7>D00Co0000ol>7U?l0003oYL?_0ol000000onU`noo0000oo^b
H003oo^bH0;o000000?onk5No`000?ok/Eh00_l00003oo^aGP04o`000?nLGHGo0000o`0000;oUG:Y
0_l00007ooooo`03o`000?oooooooooo00;ooooo0014ooooo`03o`000?oooooooooo03Gooooo0_l0
0002onjfUPCo000000GokkRFo`000?od^Xgo0000ooo;MP02o`000004oo2eT?l0003ol;>=o`0000;o
l;><00Co0000odd_S?m=;hco00000onIJIT00ol0003o]H2KokF0V`03okF0V`03o`000?o:TIWobY6I
00;obY6I00Go0000om^RVOl0003oeY^Ho`000003omRLUP05o`000?oQYYGohJJEon6VUOl000000ooJ
WYD01?l0003ofYjDomZNU?oJWY@2o`0000;oe9VE0_l000000ol08joo0000oj2<_`02oj2<_`03o`00
0?o1V:go`IR]00?o`IR]00?o0000om>UYooCYJL00ooCYJL01Ol0003ogK>]o`000?oO[:;o000000;o
ikVT00Oo0000ooC?Z?odcjSom<nXo`000?o^lI[o000000kooooo00Go0000okRP`?nhX<3o^:30o`00
0003okN8Y004o`000?nfPYgo]X:MokJ2W@;o00001?n/N9T00ol0003o[WRHojihV002ojihV0;o0000
0onbNiP01Ol0003o[WNFojigU_n^MiKo000000;o[gRF00?o0000ooooooooool05oooool01Ol0003o
Je>Tof]CY?m[DjCo000000?oUFRK00?o0000ojAaV?nTLIP00_nTLIP01Ol0003oZW>FojYcU_nZLiKo
000000Co[7>D00Co0000ol>7U?o3QiCo00001OnU`nl03?l0003onk9Po`000?l0003oYL?_o`000?ok
/Eko0000oo^aG_l0003onk5No`0000;onk5N00Co0000oiaMQOl0003o00000_nELZT2o`0000Oooooo
00?o0000ooooooooool00_ooool004Gooooo00?o0000ooooooooool0=?ooool6o`000005onblX?l0
003okkRFo`000?od^Xd01?l000001?o`]I3o0000oo2cSOl00002oo2cS004o`000?m=;hcoCBn<o`00
00?oVFVI00?o0000okF0VoneP9/00oneP9/00ol0003obY6IolZAV@02olZAV@05o`000?oKXYWo0000
omJKV?l000000ooHW9H01Ol0003ohJJEon6VUOoQYYGo000000?ofYjE00Co0000omZNU?oJWYCofYjD
0_l00002omBIU@05o`000?oAUYKo0000o`0S[ol000000onPS;l00ol0003o`IR]ol6H[@02ol6H[@03
o`000?oCYJOodjFW00;odjFW00?o0000omfc[OoM/jd00_l00003onNiY004o`000?odcjSom<nXo`00
00;ok_6J00?o0000ooooooooool03?ooool01Ol0003o^:30okRP`?nhX<3o000000Co]hRT00Go0000
okJ2WOl0003oZ7NMo`000004ojahV@03o`000?n^N9So[WRH00;o[WRH0_l00003ok9kV007o`000?n^
MiKo[WNFojigU_l0003o[gRFo`00000Jooooo`05o`000?m[DjCoJe>Tof]CY?l000000onEJ9/00ol0
003oY76HojAaV002ojAaV005o`000?nZLiKoZW>FojYcU_l000000on/Li@00ol0003ohZNFo`000002
ol>7U004o`000?nU`nooYL?_ojG3k`?o00001?nU`nl2o`000008oo^aG_l0003onk5Noo^aG_l0003o
nk5No`000?nLGHD2o`0000;oUG:Y0_l00007ooooo`03o`000?oooooooooo00;ooooo0016ooooo`03
o`000?oooooooooo03?ooooo0_l000002Ol005Co0000o`00E?l0003ok;bPo`000?o_^9Ko0000ooBj
S@02o`000007onjiVOl0003ol;F@o`000?o`/hgo0000oo2cS002o`0000;oCBn<00Go0000oiUYVOnI
JIWoVFVIo`000004okF0V`;o00000oo:TIT01_l0003ofj:Iom^RVOl0003oeY^Ho`0000?of9bF00Go
0000on6VUOoQYYGohJJEo`000003omZNU@04o`000?oJWYCofYjDomZNU0;o00000_oDVID00ol0003o
dIJFom6FUP02o`0000?oX8bo00Oo0000ol6H[Oo1V:go`IR]o`000?o8YKKo000000;odjFW00?o0000
omfc[OoM/jd00_oM/jd01Ol0003oikVTonNiY?oW^JCo000000;om<nX00?o0000onkaV_l000004?oo
ool2o`000003okRP`?l0003o]hRT00?o]hRT0_l00003ojQgW@03o`000?n/N9Wo[7RI00;o[7RI00Co
0000ojihV?n^N9So[WRH0_l00003ok9kV007o`000?n^MiKo[WNFojigU_l0003o[gRFo`00000Joooo
o`05o`000?m[DjCoJe>Tof]CY?l000000onEJ9/00ol0003oY76HojAaV002ojAaV005o`000?nZLiKo
ZW>FojYcU_l000000on/Li@00ol0003ohZNFo`000003ol>7U0?o000000?o/WRBo`000?l000000onU
`nl3o`000008oo^aG_l0003onk5Noo^aG_l0003onk5No`000?nLGHD2o`0000?oUG:Y00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`00Aoooool2o`0003?ooooo0_l00003o`00E0;o
00000_o_^9H2o`000005ooo;M_l0003o0000oo2eT?l000000_o`/hd01?l0003ol;><o`000?l00002
odd_S005o`000?nIJIWoVFVIoiUYVOl000001?neP9/2o`0000?obY6I00Go0000om^RVOoKXYWofj:I
o`000004omRLUP05o`000?oQYYGohJJEon6VUOl000000ooJWYD01?l0003ofYjDomZNU?oJWY@2o`00
00;oe9VE00?o0000om6FU_oAUYH00_l00003oj2<_`04o`000?o1V:go`IR]o`0000;ob:Ff00Co0000
om>UYooCYJOo00001?oM/jd01?l0003oikVTonNiY?l00002ooC?Z003o`000?o^lI[o000001?ooooo
00?o0000okRP`?l000000ongR:@2o`0000?oZ7NM00?o0000ojahVOn/N9T00_n/N9T01Ol0003o[WRH
ojihV?n^N9So000000Co/W^H00?o0000ojigU_n^MiH00_n^MiH2o`0001_ooooo00Co0000of]CY?m[
DjCo00000onEJ9/00ol0003oY76HojAaV002ojAaV005o`000?nZLiKoZW>FojYcU_l000000on/Li@0
0ol0003ohZNFo`000004ol>7U003o`000?nbN9;o000000;ooooo0ol00003ojG3k`;o00000ook/Eh0
1Ol0003onk5No`000?nLGHGo000000?oUG:Y00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`00BOooool00ol0003oooooooooo`0`ooooo`;o00000_l005@02?l0003ok;bPo`000?o_
^9Ko0000ooBjSOl0003ool]f0_l000001_o`]I3o0000oo2cSOo`/hgo0000oo2cS0;o00000_m=;h`0
1Ol0003oVFVIoiUYVOnIJIWo000000Co]H2K00?o0000om6LWol000000_o:TIT01Ol0003ofj:Iom^R
VOoKXYWo000000?of9bF00Oo0000on6VUOoQYYGohJJEo`000?oa^9;o000000;ofYjE00Co0000omZN
U?oJWYCofYjD0_l00002omBIU@04o`000?oAUYKodIJFom6FUP;o00000onPS;l2o`0000?ob:Ff00?o
0000om>UYol000001?oM/jd01Ol0003okM2go`000?oW^JCo000000;om<nX0_l0000Eooooo`;o0000
00Co]hRTo`000?l0003o00001?nXMid00ol0003o[7RIojahV@02ojahV@05o`000?n^N9So[WRHojih
V?l000001?nbNiP00ol0003o[WNFojigUP02ojigUP;o00006oooool01?l0003oJe>Tof]CY?l00003
oiEXV`03o`000?nTLISoY76H00;oY76H00?o0000ojYcU_nZLiH00_nZLiH01_l0003o[7>DojacU?l0
003ohZNFo`0000Co`hND00?o0000ok9hT_l000000oooool01?l0003oYL?_ojG3konU`nl3o`0000Co
nk5N0_l000000onLGHGo0000oiEbZ@02oiEbZ@03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool004[ooooo00?o0000ooooooooool0;oooool03?l0003o001Do`00E?l005Co0000onbl
X?l0003okkRFo`000?od^Xgo0000ooo;MP;o000000Col;F@o`000?o`/hgo00000_o`/h`2o`0000;o
CBn<00Go0000oiUYVOnIJIWoVFVIo`000003okF0V`04o`000?oAW9oodIbOo`0000;obY6I00Go0000
om^RVOoKXYWofj:Io`000003omRLUP09o`000?oQYYGohJJEon6VUOl0003olKRBo`000?oJWYGo0000
00CofYjD00Co0000onZ_T_l0003o00001OoAUYH5o`0000Gob:Ff0_l00004omfc[@06o`000?o]d;Oo
0000onNiY?l0003om<nX0_l0000Gooooo`;o00000_nLMjL00ol0003oZ7NMojQgW@02ojQgW@03o`00
0?n/N9Wo[7RI00;o[7RI00Go0000ojihV?n^N9So[WRHo`000004ok9kV003o`000?n^MiKo[WNF00;o
[WNF0_l0000Kooooo`04o`000?m[DjCoJe>To`0000?oUFRK00?o0000ojAaV?nTLIP00onTLIP01Ol0
003oZW>FojYcU_nZLiKo000000;o[7>D00?o0000on:WU_l000001?o3Qi@00ol0003o/WRBo`000004
ooooo`?o00000_ooool00ol0003onk5Noo^aGP02oo^aGP;o000000?oW5f5o`000?l000000_nELZT2
o`0000Kooooo00?o0000ooooooooool00_ooool004_ooooo00?o0000ooooooooool0;_ooool02_l0
003o001Do`00E?l005Co0000onblX?l0003okkRFo`000?od^Xd2o`000006onjiVOl0003ol;F@o`00
0?o`/hgo00000_o`/h`2o`0000;oCBn<00?o0000oiUYVOnIJIT00_nIJIT01?l0003o]H2KokF0Vol0
0002om6LW`04o`000?o:TIWobY6Io`0000?ofj:I00Go0000omRLU_oHW9Kof9bFo`000003on6VU@05
o`000?oa^9;o0000omZNUOl000001?oJWY@01?l0003ojZnBo`000?l00005om6FUP05o`000?n5Vn7o
QI_QohFKhOl000001Oo8YKH00ol0003ogK>]omfc[@02omfc[@04o`000?o]d;OokM2gong@]`;o0000
00?om<nXo`000?ooool05oooool01Ol0003oW7NWoiagYonLMjOo000000CoZ7NM00?o0000ojahVOn/
N9T00_n/N9T01Ol0003o[WRHojihV?n^N9So000000Co/W^H00?o0000ojigU_n^MiH00_n^MiH00ol0
003oooooooooo`0Kooooo`04o`000?m[DjCoJe>To`0000?oUFRK00?o0000ojAaV?nTLIP00_nTLIP0
1Ol0003oZW>FojYcU_nZLiKo000000;o[7>D00?o0000on:WU_l000001?o3Qi@00ol0003o/WRBo`00
000:ooooo`Co000000?oooooo`000?nLGHD00_l00002oiEbZ@;o00001oooool00ol0003ooooooooo
o`01ooooo`00C?ooool2o`0002kooooo00Co0000o`00E?l005Co00000_o/_:001?l0003okkRFo`00
0?od^Xd2o`000006onjiVOl0003ol;F@o`000?o`/hgo00000_o`/h`3o`000003odd_S?l0003oVFVI
00?oVFVI00Co0000okF0VoneP9_o00000_oAW9l00ol0003obY6Io`000004om^RV@05o`000?oHW9Ko
f9bFomRLU_l000000ooQYYD01Ol0003olKRBo`000?oJWYGo000000?ofYjD00?o0000onZ_T_oZ[i80
0_l00005om6FUP;o00000on5Vn401?l0003ob:FfolRU]_o8YKH2o`0000CogK>]00Co0000ong@]oo]
d;OokM2g0ol0000Iooooo`05o`000?nLMjOoW7NWoiagYol000001?nXMid00ol0003o[7RIojahV@02
ojahV@03o`000?n^N9So[WRH00;o00001?nbNiP00ol0003o[WNFojigUP02ojigUP03o`000?oooooo
oooo01_ooooo00Co0000of]CY?m[DjCo00000onEJ9/00ol0003oY76HojAaV002ojAaV007o`000?nZ
LiKoZW>FojYcU_l0003o[7>Do`000003on:WUP07o`000?o3QiCo`hNDol>7U?l0003o/WRBo`00000:
ooooo`03o`000?oooooooooo00;ooooo1?l00002oiEbZ@;o00001oooool00ol0003oooooooooo`01
ooooo`00C_ooool00ol0003oooooooooo`0[ooooo`06o`000?l005Co001Do`000?o/_:3o00000_o_
^9H00ol0003om;Z=o`000002o`0000;ol;F@00?o0000oo2cSOl000000_o`/h`3o`000003odd_S?l0
003oVFVI00?oVFVI00?o0000okF0Vol000000ooAW9l00ol0003obY6Io`000003om^RV@;o00000ooH
W9H02Ol0003ohJJEon6VUOoQYYGo0000oo6hT_l0003ofYjEo`000003omZNU003o`000?oZ[i;ojZnB
00;o00001?oAUYH3o`0000?oQI_Q00Co0000olRU]_o8YKKo00000_oDalh01?l0003ogK>]omfc[Ol0
0003ong@]`;o00006oooool00ol0003oW7NWoiagY`02oiagY`05o`000?nXMigoZ7NMojQgWOl00000
1?n/N9T00ol0003o[WRHojihV002o`0000Go/W^H00Go0000ojigU_n^MiKo[WNFo`00000Mooooo`04
o`000?m[DjCoJe>To`0000?oUFRK00?o0000ojAaV?nTLIP00_nTLIP01ol0003oZW>FojYcU_nZLiKo
0000ojacU?l000000ooRYiH01ol0003o`hNDol>7U?o3QiCo0000ok9hT_l000004?ooool4o`000003
oiEbZOl0003o000000Oooooo00?o0000ooooooooool00Oooool004oooooo00?o0000ooooooooool0
:_ooool01_l0003o001Do`00E?l0003ok;bPo`0000;okkRF00?o0000ooBjSOl000000_l00002oo2e
T003o`000?o`/hgo000000;ol;><0ol000000om=;hco0000oiUYV@03oiUYV@03o`000?neP9_o0000
00?odIbO00?o0000olZAVOl000000ooKXYT00ol0003okk^Io`000002omRLUP09o`000?oQYYGohJJE
on6VUOl0003olKRBo`000?oJWYGo000000?ofYjD00?o0000onZ_T_oZ[i800_l00004om6FUP;o0000
00?ob8fFo`000?l000000_l000000oo8YKKo0000omC7cP03omC7cP03o`000?oM/jgo000000;okM2g
0ol0000Looooo`05o`000?nLMjOoW7NWoiagYol000000onXMid00ol0003o[7RIojahV@02ojahV@06
o`000?n^N9So[WRHo`000?oooooo00001?nbNiP01Ol0003o[WNFojigU_n^MiKo000001kooooo00?o
0000of]CY?l000000onEJ9/00ol0003oY76HojAaV002ojAaV007o`000?nZLiKoZW>FojYcU_l0003o
[7>Do`000003on:WUP03o`000?o3QiCo`hND00;o`hND0_l0000Aooooo`?o00000_nELZT00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo007ooooo001@ooooo`03o`000?oooooooooo02Wooooo
00?o0000o`00E?l000000_o/_:000ol0003okkRFonnhUP05o`0000;ol;F@00?o0000oo2cSOl00000
0_o`/h`3o`0000;oCBn<00Oo0000oiUYVOnIJIWoVFVIo`000?neP9_o000000?odIbO00?o0000olZA
VOl000000ooKXYT00ol0003okk^Io`000002omRLUP04o`000?oQYYGohJJEo`0000;olKRB00?o0000
omZNUOl000000ooJWY@00ol0003ojZnBonZ_TP02o`0000CodIJF0_l00004olR=UP;o00001OoDalh2
o`0000?okM2g0ol0000Looooo`05o`000?nLMjOoW7NWoiagYol000001?nXMid01ol0003o[7RIojah
VOn/N9Wo0000ojihV?l000000_ooool00ol0003o/W^Hok9kV002ok9kV005o`000?n^MiKo[WNFojig
U_l000007_ooool00ol0003oJe>To`000003oiEXV`03o`000?nTLISoY76H00;oY76H00Oo0000ojYc
U_nZLiKoZW>Fo`000?n/LiCo000000?ohZNF00?o0000ol>7U?o3Qi@00_o3Qi@2o`0001;ooooo00Go
0000ooooool0003oUG:Yo`000007ooooo`03o`000?oooooooooo007ooooo001Aooooo`;o0000:Ooo
ool00ol0003o001Do`000002onblX004o`000?o_^9Ko0000ooBjS@;o000000Cok[VIo`000?o`]I3o
00000_o`/hd00ol0003ol;><oo2cS003o`0000;oCBn<00Co0000oiUYVOnIJIWoVFVI0_l00004om6L
W`03o`000?o:TIWo000000?ofj:I00Go0000onnkVOl0003of9bFo`000003on6VU@04o`000?oa^9;o
lKRBoo6hTP;o00000ooJWY@01?l0003ojZnBonZ_T_l00005om6FUP03o`000?oY[iCo000000?ob8fF
00?o0000omfRUol000000ooDalh01ol0003oKMR^ofgH[_l0003okM2go`000?nlPYH00_l0000Loooo
o`05o`000?nLMjOoW7NWoiagYol000001?nXMid00ol0003o[7RIojahV@02ojahV@;o00000_ooool0
0ol0003o/W^Hok9kV002ok9kV004o`000?n^MiKo[WNFo`0001oooooo00?o0000of]CY?l000000onE
J9/00ol0003oY76HojAaV002ojAaV007o`000?nZLiKoZW>FojYcU_l0003o[7>Do`000003on:WUP03
o`000?o3QiCo`hND00;o`hND0_l0000Cooooo`;o000000?oUG:Yo`000?ooool01_ooool00ol0003o
ooooooooo`01ooooo`00Doooool00ol0003oooooooooo`0Vooooo`05o`000?l005Co0000onblX?l0
00000_o_^9H02?l0003om;Z=o`000?l0003ok[VIo`000?o`]I3o00000_o`/hd00ol0003ol;><o`00
0002oo2cR`04o`000?m=;hcoCBn<o`0000?oVFVI0_l00005om6LW`;o00000ooKXYT01Ol0003okk^I
o`000?oHW9Ko000000?ohJJE00Go0000oo6hT_oa^9;olKRBo`000004omZNU004o`000?oZ[i;ojZnB
o`0000GodIJF00?o0000onV_U?l000000_o8SIH00ol0003ogJ:GomfRU`02o`000003omC7c_l0003o
000000Co00000_nlPYH00ol0003oooooooooo`0Kooooo`05o`000?nLMjOoW7NWoiagYol000001?nX
Mid00ol0003o[7RIojahV@02ojahV@;o00000_ooool00ol0003o/W^Hok9kV002ok9kV004o`000?n^
MiKo[WNFo`00023ooooo00?o0000of]CY?l000000_nEJ9/00ol0003oY76HojAaV003ojAaV004o`00
0?nZLiKoZW>FojYcUP;o00000ooRYiH00ol0003o`hNDol>7U002ol>7U0;o00005?ooool00ol0003o
UG:Yo`000007ooooo`03o`000?oooooooooo007ooooo001Dooooo`03o`000?oooooooooo02Gooooo
0_l00002onblX005o`000?o_^9KokkRFo`000?od^Xd00_l000001_o^^IWo0000oo2eT?l0003ol;>=
o`0000;ol;><00Co0000oo2cRoo`/h_o00000_m=;h`01?l0003oVFVIoiUYVOnIJIT2o`0000GodIbO
00Go0000om^RVOoKXYWofj:Io`000002onnkV@03o`000?oHW9Ko000000?ohJJE00Go0000oo6hT_oa
^9;olKRBo`000003omZNU005o`000?oZ[i;ojZnBonZ_T_l000001?oAUYH01?l0003ojJnDonV_U?l0
0002olR=UP07o`000?oMXYOogJ:Go`000?noQIKo0000okn5UP02o`0000Go_8:F00?o0000oooooooo
ool06oooool01Ol0003oW7NWoiagYonLMjOo000000CoZ7NM00?o0000ojahVOn/N9T00_n/N9T2o`00
00;ooooo00?o0000ok9kV?nbNiP00_nbNiP01?l0003o[WNFojigU_l0000Pooooo`03o`000?m[DjCo
000000?oUFRK00?o0000ojAaV?nTLIP00_nTLIP01Ol0003oZW>FojYcU_nZLiKo000000CohZNF00?o
0000ol>7U?o3Qi@00_o3Qi@2o`0001Cooooo0ol00008ooooo`7o00000Oooool1ooooo`00EOooool0
0ol0003oooooooooo`0Tooooo`;o00000_o/_:001Ol0003okkRFonnhU_l0003om;Z=00?o00000_o`
]I000ol0003ol;>=o`000002oo2cS003o`000?o`/h_ol;>;00;o000000?oCBn<o`000?nIJIT00_nI
JIT00ol0003odIbOom6LW`04om6LW`05o`000?oKXYWofj:Iom^RVOl000000_o_^iT00ol0003of9bF
o`000003on6VU@05o`000?oa^9;olKRBoo6hT_l000000ooJWY@01Ol0003ojZnBonZ_T_oZ[i;o0000
00CodIJF00Co0000onV_U?oY[iCo00000_o8SIH01?l0003ogJ:GomfRUol00003okn5UP;o00001Onl
PYH00ol0003oooooooooo`0Kooooo`03o`000?nLMjOoW7NW00;oW7NW00Go0000ojQgWOnXMigoZ7NM
o`000004ojahV@05o`000?ooooooooooooooool000001?nbNiP01?l0003o[WNFojigU_l0000Qoooo
o`;o00000onEJ9/00ol0003oY76HojAaV002ojAaV005o`000?nZLiKoZW>FojYcU_l000001OoRYiH0
1?l0003o`hNDol>7U?o3Qi@2o`0001Gooooo0ol00007ooooo`7o00000Oooool1ooooo`00E_ooool0
0ol0003oooooooooo`0Sooooo`;o00000_o/_:002?l0003okkRFonnhU_l0003om;Z=o`000?o^^IWo
00000_o`]I000ol0003ol;>=o`000002oo2cS003o`000?o`/h_ol;>;00;o000000?oCBn<o`000?nI
JIT00_nIJIT00ol0003odIbOom6LW`04om6LW`05o`000?oKXYWofj:Iom^RVOl000000_o_^iT00ol0
003of9bFo`000002on6VU@03o`000?oa^9;olKRB00;olKRB00Go0000omZNU?oJWYCofYjDo`000003
onZ_TP03o`000?oAUYKodIJF00;odIJF00Co0000onV_U?oY[iCo00000_o8SIH01?l0003ogJ:GomfR
Uol00003okn5UP03o`000?oooooo000000Co_8:F00?o0000ooooooooool07?ooool01Ol0003oW7NW
oiagYonLMjOo000000?oZ7NM00?o0000ojahVOn/N9T00_n/N9T01Ol0003ooooooooooooooooo0000
00Co/W^H00Co0000ojigU_n^MiKo00008Oooool2o`0000?oUFRK00?o0000ojAaV?nTLIP00_nTLIP0
1Ol0003oZW>FojYcU_nZLiKo000000GohZNF00Co0000ol>7U?o3QiCo`hND0_l0000Fooooo`;o0000
1oooool1o`00007ooooo0Oooool005Oooooo0_l0000Sooooo`;o00000_o/_:002?l0003okkRFonnh
U_l0003om;Z=o`000?o^^IWo00000_o`]I000ol0003ol;>=o`000002oo2cS003o`000?o`/h_ol;>;
00;o000000?oCBn<o`000?nIJIT00_nIJIT00ol0003odIbOom6LW`04om6LW`05o`000?oKXYWofj:I
om^RVOl000000oo_^iT2o`0000;ohJJE00?o0000oo6hT_oa^9800_oa^9801Ol0003ofYjDomZNU?oJ
WYCo000000?ojZnB00?o0000om6FU_oAUYH00_oAUYH01?l0003ojJnDonV_U?l00002olR=UP04o`00
0?oMXYOogJ:Go`0000;o_hFF00Co0000oooooooooooo00001?nlPYH00ol0003oooooooooo`0Loooo
o`05o`000?nLMjOoW7NWoiagYol000000onXMid00ol0003o[7RIojahV@02ojahV@05o`000?oooooo
ooooooooool000001?nbNiP00ol0003o[WNFo`00000Rooooo`;o00000onEJ9/00ol0003oY76HojAa
V002ojAaV005o`000?nZLiKoZW>FojYcU_l000001OoRYiH01?l0003o`hNDol>7U?o3Qi@2o`0001Ko
oooo0_l00007ooooo`7o00000Oooool1ooooo`00FOooool00ol0003oooooooooo`0Rooooo`;o0000
0oo_^9H3o`000007onjiVOl0003ol;F@oo2eT?l0003ol;>=o`000002oo2cS005o`000?o`/h_ol;>;
o`000?l`8Y000_l00002oiUYV@;o00001OoAW9l2o`0000?ofj:I00Go0000onnkVOo_^iWokk^Io`00
0003on6VU@04o`000?oa^9;olKRBoo6hTP;o00000ooJWY@00ol0003ojZnBonZ_TP02o`0000CodIJF
00Co0000onV_U?oY[iCo00000_o8SIH01?l0003ogJ:GomfRUol00002okn5UP04o`000?oooooooooo
o`0000Co_8:F00?o0000ooooooooool07?ooool01Ol0003oW7NWoiagYonLMjOo000000?oZ7NM00Go
0000ojahVOn/N9Wo[7RIo`000004ooooo`03o`000?nbNiSo/W^H00;o/W^H00?o0000ojigU_l00000
8oooool01Ol0003oUFRKoiEXVonEJ9_o000000CoY76H00Ko0000ojYcU_nZLiKo0000ooooool00004
on:WUP03o`000?o3QiCo`hND00;o`hND00?o0000ooooooooool05Oooool00ol0003oooooooooo`05
ooooo`7o00000Oooool1ooooo`00F_ooool00ol0003oooooooooo`0Qooooo`?o000000?okkRFo`00
0?od^Xd00_l000001oo^^IWo0000oo2eT?o`]I3o0000oo2cSOl000000_o`/h`01Ol0003ol;>;o`00
0?l0003o<2:@00;o000000GoVFVIo`000?o;YkGobjNeo`000004om6LW`05o`000?oV`k;o0000om^R
VOl000001?o_^iT01Ol0003ohJJEon6VUOoQYYGo000000?olKRB00?o0000onjmW_l000000_oJWY@0
1_l0003ojZnBonZ_T_l0003ol;^Ho`0000;odIJF00Go0000onV_U?oY[iCojJnDo`000002olR=UP04
o`000?oMXYOogJ:Go`0000;o_hFF00Co0000oooooooooooo00001?nlPYH00ol0003oooooooooo`0M
ooooo`04o`000?nLMjOoW7NWo`0000CoZ7NM00?o0000ojahVOl000001_ooool01ol0003o/W^Hok9k
V?nbNiSo0000ojigU_l000008oooool2o`0000;oUFRK00?o0000ojAaV?nTLIP00_nTLIP01_l0003o
ZW>FojYcU_l0003oooooo`0000CohZNF00?o0000ol>7U?o3Qi@00_o3Qi@00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo001Kooooo`03o`000?oooooooooo
023ooooo00?o0000o`00@Ol004400_l000001ood^Xgo0000o`000?o^^IWo0000oo2eT?l000000_o`
/hd01Ol0003ol;><oo2cS?l0003ol;>;00;o000000Go<2:@o`000?l0003oVFVIo`000002ol^W]@05
o`000?oAW9oodIbOom6LWol000000_oV`k800ol0003ofj:Io`000004onnkV@05o`000?oQYYGohJJE
on6VUOl000000ooa^9801Ol0003ok[fNo`000?oJWYCo000000?ojZnB00?o0000oo2kV?l000000_oA
UYH01ol0003ojJnDonV_U?oY[iCo0000olR=U_l000000ooMXYL01?l0003o_hFFokn5U_l00002oooo
o`05o`000?nlPYKo_8:Fokb2U_l000008Oooool00ol0003oW7NWo`000004ojQgW@03o`000?n/N9Wo
000000Kooooo00?o0000ok9kV?nbNiP00_nbNiP2o`0002?ooooo0_l00002oiEXV`03o`000?nTLISo
Y76H00?oY76H0_l00002ooooo`03o`000?oRYiKohZNF00;ohZNF00?o0000ol>7U?o3Qi@00_o3Qi@0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo001Loooo
o`;o00008?ooool00ol0003o0011o`00@@04o`000005onjiVOl0003ol;F@oo2eT?l000000_o`/hd0
1Ol0003ol;><oo2cS?l0003ol;>;00?o000000?o<2:@o`000?l000000oo;YkD01?l0003odIbOom6L
Wol00003onK3/P03o`000?oKXYWo000000Cokk^I00Go0000on6VUOoQYYGohJJEo`000003oo6hTP05
o`000?o^_Iko0000omZNU?l000000ooZ[i800ol0003ol;^Ho`000002om6FUP07o`000?oY[iCojJnD
onV_U?l0003ob8fFo`000003omfRU`04o`000?noQIKo_hFFo`0000;ooooo00Go0000okb2U_nlPYKo
_8:Fo`00000Rooooo`03o`000?nLMjOo000000?oZ7NM0_l00007ooooo`03o`000?nbNiSo/W^H00;o
/W^H0_l0000Tooooo`;o00000_nEJ9/00ol0003oY76HojAaV002ojAaV0;o00000oooool00ol0003o
hZNFon:WUP02on:WUP03o`000?o3QiCo`hND00;o00006Oooool00ol0003oooooooooo`04ooooo`7o
00000Oooool005kooooo00?o0000ooooooooool07Oooool3o`0000;oYL?_0_l000001oo^^IWo0000
oo2eT?o`]I3o0000oo2cSOl000000_o`/h`00ol0003ol;>;oo2cR`03o`000003oc0RT?l0003objNe
00?objNe00Co0000om6LWooAW9oo00000ooV`k800ol0003ofj:Io`000003onnkV@;o00000_oQYYD0
1Ol0003olKRBoo6hT_oa^9;o000000;ok[fN00?o0000omZNU?l000000ooZ[i800ol0003ol;^Ho`00
0002om6FUP07o`000?oY[iCojJnDonV_U?l0003ob8fFo`000003omfRU`04o`000?noQIKo_hFFo`00
00;ooooo00Go0000okb2U_nlPYKo_8:Fo`00000Sooooo`;o000000CoZ7NMo`000?l0003o00002?oo
ool00ol0003o/W^Hok9kV002ok9kV0;o00009_ooool00ol0003oUFRKo`000004ojAaV0;o00000ooo
ool00ol0003ohZNFon:WUP02on:WUP?o00007?ooool00ol0003oooooooooo`03ooooo`7o00000Ooo
ool005oooooo00?o0000ooooooooool07?ooool02Ol0003oYL?_ojG3konU`noo0000om?8col0003o
k[VIo`000002oo2eT003o`000?o`/hgo000000;ol;><00?o0000oo2cRoo`/h/00ol000000ol`8Y3o
0000ol^W]@03ol^W]@03o`000?oAW9oo000000Coi/>b00?o0000om^RVOl000000oo_^iT01Ol0003o
i/>co`000?oQYYGo000000?olKRB00Ko0000onjmW_o^_Iko0000omZNU?l00002onZ_TP04o`000?o`
^iSol;^Ho`0000;odIJF00?o0000onV_U?oY[i@00_oY[i@2o`0000?ogJ:G00Co0000okn5U_noQIKo
00000_ooool01Ol0003o_8:Fokb2U_nlPYKo000002Cooooo0_l0000;ooooo`03o`000?nbNiSo/W^H
00;o/W^H00?o0000ooooooooool09_ooool2o`0000;oY76H0ol00004ooooo`03o`000?oRYiKohZNF
00?o00007oooool00ol0003oooooooooo`02ooooo`7o00000Oooool0063ooooo00?o0000oooooooo
ool07?ooool00ol0003oYL?_o`000002om?8c`03o`000?o^^IWo000000;ol;F@00?o0000oo2cSOl0
00000_o`/h`01_l0003ol;>;oo2cRol0003ol;>=o`0000;o<2:@00?o0000ol^W]Oo;YkD00_o;YkD2
o`0000Goi/>b00Go0000onnkVOo_^iWokk^Io`000002onK3/`03o`000?oQYYGo000000?olKRB00Ko
0000onjmW_o^_Iko0000omZNU?l00002onZ_TP04o`000?o`^iSol;^Ho`0000;odIJF00?o0000onV_
U?oY[i@00_oY[i@2o`0000?ogJ:G00?o0000okn5U_l000000oooool01Ol0003o_8:Fokb2U_nlPYKo
0000037ooooo00?o0000ok9kV?nbNiP00_nbNiP00ol0003oooooooooo`0Wooooo`?o00002?ooool2
o`0002?ooooo00Go0000ooooooooooooooooo`000001ooooo`00HOooool2o`0001cooooo0ol00002
om?8c`03o`000?o^^IWo000000;ol;F@00?o0000oo2cSOl000000_o`/h`01_l0003ol;>;oo2cRol0
003ol;>=o`0000;o<2:@00Co0000ol^W]Oo;YkGobjNe0_l00006onK3/P05o`000?o_^iWokk^Ionnk
VOl000000_oV`k<00ol0003ohJJEo`000003oo6hTP06o`000?o^_Ikok[fNo`000?oJWYCo00000_oZ
[i801_l0003ol;^Hoo2kV?l0003odIJFo`0000GojJnD0_l00003omfRU`03o`000?noQIKo000000?o
oooo00Co0000okb2U_nlPYKo0000<_ooool00ol0003o/W^Hok9kV002ok9kV003o`000?oooooooooo
05Oooooo00Go0000ooooooooooooooooo`000001ooooo`00Hoooool00ol0003oooooooooo`0Ioooo
o`03o`000?l004?o001300;o00000_o^^IT01_l0003ol;F@oo2eT?l0003ol;>=o`0000;ol;><00Ko
0000oo2cRoo`/h_o0000oo2cSOl00002oc0RT004o`000?o;YkGo0000o`0000;oYL?_00?o0000onK3
/_oV`k800_oV`k82o`0000?okk^I00Ko0000onK3/ooV`k?o0000on6VUOl00003oo6hTP04o`000?o^
_Ikok[fNonjmWP;o00000_oZ[i801_l0003ol;^Hoo2kV?l0003odIJFo`0000GojJnD00?o0000omfR
UooMXYL00ooMXYL2o`0000?ooooo00Co0000okb2U_nlPYKo0000<_ooool00ol0003o/W^Hok9kV002
ok9kV003o`000?oooooooooo05Sooooo00Co0000oooooooooooo00000Oooool006Cooooo00?o0000
ooooooooool06?ooool00ol0003o0013o`000002o`000003onjiVOl0003ol;F@00;ol;F@00?o0000
oo2cSOl000000_o`/h`00ol0003ol;>;o`000002oo2cS@03o`000?l`8Y3o000000?o00001?nU`nl0
1_l0003oi/>bo`000?l0003oYL?_o`0000;okk^I00Oo0000onK3/ooV`k?oi/>co`000?oQYYGo0000
00;olKRB00?o0000onjmW_o^_Ih00_o^_Ih01Ol0003ojZnBonZ_T_oZ[i;o000000;ol;^H00?o0000
om6FU_l000001OoY[i@00ol0003ogJ:GomfRU`03omfRU`;o00000oooool01?l0003o_8:Fokb2U_l0
000booooo`05o`000?nbNiSo/W^Hok9kV?l00000G?ooool00ol0003oooooo`000001ooooo`00IOoo
ool00ol0003oooooooooo`0Gooooo`;o00000onU`nl2o`0000;ol;F@00Co0000oo2cSOo`/hgo0000
0_o`/h`00ol0003ol;>;o`000002oo2cS@;o00001?nU`nl00ol0003oYL?_ojG3k`03o`0000CoYL?_
00?o0000onnkVOl000001?oV`k<01Ol0003olKRBoo6hT_oa^9;o000000Cok[fN00Co0000onZ_T_oZ
[i;o00001?o`^iP2o`0000GojJnD00?o0000omfRUooMXYL00ooMXYL2o`0000?ooooo00Co0000okb2
U_nlPYKo0000<oooool00ol0003o/W^Ho`00001Mooooo`03o`000?oooooooooo007o0000001Voooo
o`;o00006?ooool00ol0003oYL?_ojG3k`04o`000005oo2eT?l0003ol;>=oo2cSOl000000_o`/h`0
0ol0003ol;>;o`000003oo2cS@;o00000_nU`nl4o`0000?oYL?_00?o0000ojG3konU`nl00ol00005
onK3/`05o`000?oa^9;olKRBoo6hT_l000001?o^_Ih01?l0003ojZnBonZ_T_l00004oo2kV0;o0000
1OoY[i@00ol0003ogJ:GomfRU`03omfRU`;o00000oooool01?l0003o_8:Fokb2U_l0000cooooo`03
o`000?nbNiSo000005kooooo0Ol00001ooooo`7o0000001Xooooo`03o`000?oooooooooo01Kooooo
0_l00004ojG3k`;o000000?ol;>=o`000?o`/h`00_o`/h`00ol0003ol;>;o`000003oo2cS@04o`00
0?l008Oo0000o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?oV`k?oi/>c00Co
00000_oa^9800ol0003ok[fNonjmWP02onjmWP04o`000?oZ[i;ojZnBo`0000Col;^H00?o0000onV_
U?oY[i@00ooY[i@2o`0000GogJ:G00?o0000ooooooooool00_ooool01?l0003o_8:Fokb2U_l0000c
ooooo`;o0000H?ooool2o`000000JOooool00ol0003oooooooooo`0Gooooo`03o`000?nU`nooYL?_
00?o000000Gol;>=o`000?o`/hcol;><o`000002oo2cR`03o`000?o`/hgol;>=00Go00000_nU`nl4
o`0000?oYL?_00?o0000ojG3konU`nl01?l00004ojG3k`;o00001?o^_Ih01Ol0003oelW;o`000?oZ
[i;o000000Col;^H00?o0000onV_U?oY[i@00ooY[i@2o`0000GogJ:G00?o0000ooooooooool00ooo
ool2o`0003Cooooo00?o0000ooooooooool0G_ooool3o`000000J_ooool00ol0003oooooooooo`0F
ooooo`?o00000onU`nl2o`0000;ol;><00Co0000oo2cRoo`/h_o00000_o`/hd01?l0003ok[RIonjh
VOo^^9T3o`0000CoYL?_00?o0000ojG3konU`nl00ol00004ojG3k`03o`000?nU`nooYL?_00?o0000
0oo^_Ih01_l0003oelW;omO9bol0003ojZnBo`0000Col;^H00?o0000onV_U?oY[i@00ooY[i@00ol0
003oj<>`o`000004omfRU`03o`000?oooooooooo00?ooooo0_l0002Aooooo`Co00000oooool006_o
oooo00?o0000ooooooooool05Oooool00ol0003o0017o`000002ojG3k`Co000000Gol;><o`000?o`
/h_ol;>;o`000002oo2cS@06o`000?o^^9Wok[RIonjhVOl0003oUVNI0_l00002ojG3k`Co00000onU
`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000onjmW_l000000ooGbL/2o`0000Gol;^H00?o
0000onV_U?oY[i@00_oY[i@01?l0003oj<>`onS3/?l00004omfRU`03o`000?oooooooooo00?ooooo
0_l0002=ooooo`Co00001oooool006cooooo0_l0000Eooooo`03o`000?l004Oo000000;o00001?nU
`nl2o`000003oo2cRol0003ol;>=00;ol;>=00So0000onjhVOo^^9Wok[RIo`000?nFIiWo0000oo2c
S0;o00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl00ol00005omO9
b`03o`000?o`^iSol;^H00;ol;^H00?o0000omK9cOl000000ooY[i@01?l0003oj<>`onS3/?l00003
omfRU`03o`000?oooooooooo00Cooooo0_l00029ooooo`Co00002oooool006kooooo00?o0000oooo
ooooool04_ooool2o`0000?oYL?_00?o0000ojG3konU`nl00ol000000oo`/h_o0000oo2cS@02oo2c
S@03o`000?o^^9Wok[RI00;ok[RI0_l000000oo`/hco0000o`000002ojG3k`Co00000onU`nl00ol0
003oYL?_ojG3k`04o`0000?oYL?_00?o0000omO9booGbL/00ol00003oo2kV004o`000?oFbLgoe/W=
o`0000;ojJnD00Go0000onS3/?oX`k3oj<>`o`000003omfRU`03o`000?oooooooooo00Cooooo0_l0
0026ooooo`?o00003oooool006oooooo00?o0000ooooooooool04Oooool00ol0003oYL?_ojG3k`02
ojG3k`?o00000onU`nl2o`0000?ol;>=00?o0000onjhVOo^^9T00_o^^9T01Ol0003ol;><oo2cS?l0
003okkRF00;o00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l0
0003ojG3k`03o`000?o`^iSo000000Coe/W=00?o0000onV_U?l000000ooX`k001?l0003ogJ:GomfR
Uol00007ooooo`03o`000?oooooooooo087ooooo1?l0000Booooo`00L?ooool00ol0003ooooooooo
o`0Aooooo`06o`000?nU`noo0000o`000?nU`noo00001?nU`nl3o`000003oo2cSOl0003ok[RI00Co
k[RI00Co0000oo2cS?o`/hco00000_o_^9H00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3
konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00001?oFbLd00ol0003ojJnDo`000004onS3
/0;o00002?ooool00ol0003oooooooooo`1mooooo`Co00005_ooool0077ooooo0_l0000Booooo`;o
00000onU`nl01?l0003oYL?_o`000?l00003ojG3k`;o00001Oo^^9T01?l0003ol;><oo2cS?l00003
onnhUP?o00000oooool00ol0003oYL?_ojG3k`03o`0000CoYL?_00?o0000ojG3konU`nl00ol00004
ojG3k`03o`000?oFbLgoe/W=00?o00001OoX`k02o`0000Sooooo00?o0000ooooooooool0NOooool4
o`0001[ooooo001cooooo`03o`000?oooooooooo013ooooo0_l00002ojG3k`?o00001?nU`nl2o`00
00Gok[RI00Co0000oo2cS?o`/hco00001?o_^9H2o`0000Cooooo0ol00002ooooo`03o`000?nU`noo
YL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000onS3/?oX`k000ol00021
ooooo`Co00007_ooool007Cooooo00?o0000ooooooooool03oooool01?l0003o001;o`000?l00003
ojG3k`06o`000?nU`noo0000o`000?nU`noo00001?o^^9T2o`000003oo2cS?l0003okkRF00CokkRF
00?o0000ooooooooool01Oooool01?l0003oooooooooooooool2o`0000?ooooo00?o0000ojG3konU
`nl01?l00003ooooo`03o`000?nU`nooYL?_00Co0000P?ooool4o`0002;ooooo001eooooo`03o`00
0?oooooooooo00kooooo00Co0000o`00Bol004_o00000_nU`nl3o`0000CoYL?_00Co0000onjhVOl0
003o00000_nU`nl2o`0000GokkRF00?o0000ooooooooool01Oooool00ol0003oooooooooo`07oooo
o`;o00002?ooool2o`00083ooooo1?l0000Vooooo`00M_ooool2o`0000kooooo00?o0000o`00Bol0
00000ol00003ojG3k`03o`000?nU`nooYL?_00?o00001?nU`nl2o`0000GokkRF00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2@ooooo`?o0000:_ooool007Sooooo00?o0000ooooooooool0
2oooool2o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`04o`000?nU`noo0000o`0000;o
oooo00?o0000onnhU_o_^9H00ol00007ooooo`03o`000?oooooooooo08cooooo1?l0000]ooooo`00
NOooool00ol0003oooooooooo`0<ooooo`03o`000?nU`nooYL?_00?o00000onU`nl00ol0003oYL?_
ojG3k`03o`0000Gooooo0_l0000:ooooo`03o`000?oooooooooo08Sooooo1?l0000aooooo`00N_oo
ool00ol0003oooooooooo`0<ooooo`;o00000onU`nl00ol0003oYL?_ojG3k`03o`0001Cooooo00?o
0000ooooooooool0Q?ooool4o`0003Gooooo001kooooo`03o`000?oooooooooo00cooooo00?o0000
ojG3konU`nl01?l0000Gooooo`03o`000?oooooooooo083ooooo1?l0000iooooo`00O?ooool2o`00
00gooooo0_l0000Kooooo`03o`000?oooooooooo07cooooo1?l0000mooooo`00O_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo07Wooooo1?l00011ooooo`00Ooooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo07Kooooo0ol00015ooooo`00P?ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo07;ooooo1?l00018ooooo`00POooool2o`0002Cooooo00?o0000
ooooooooool0K_ooool4o`0004cooooo0023ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0J_ooool4o`00053ooooo0024ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0I_ooool4o`0005Cooooo0025ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
H_ooool4o`0005Sooooo0026ooooo`;o00007oooool00ol0003oooooooooo`1Nooooo`Co0000G?oo
ool008Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Kooooo`?o0000H?ooool0
08Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Gooooo`Co0000Hoooool008[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Cooooo`Co0000Ioooool008_ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`1?ooooo`Co0000Joooool008cooooo0_l0
000Iooooo`03o`000?oooooooooo04_ooooo1?l0001_ooooo`00S_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo04Oooooo1?l0001cooooo`00Soooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo04?ooooo1?l0001gooooo`00T?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo043ooooo0ol0001kooooo`00TOooool2o`0001Cooooo00?o0000ooooooooool0
??ooool4o`0007kooooo002Cooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0>?oo
ool4o`0008;ooooo002Dooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0=?ooool4
o`0008Kooooo002Eooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<?ooool4o`00
08[ooooo002Fooooo`;o00003oooool00ol0003oooooooooo`0/ooooo`Co0000S_ooool009Sooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Xooooo`Co0000T_ooool009Wooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Uooooo`?o0000U_ooool009[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`Co0000VOooool009_ooooo0_l00009oooo
o`03o`000?oooooooooo01kooooo1?l0002Mooooo`00WOooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01[ooooo1?l0002Qooooo`00W_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01Kooooo1?l0002Uooooo`00Woooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01;ooooo1?l0002Yooooo`00X?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00kooooo1?l0002]ooooo`00XOooool2o`0000?ooooo00?o0000ooooooooool02oooool3o`00
0;7ooooo002Sooooo`04o`000?ooooooooooo`0000Wooooo1?l0002dooooo`00Y?ooool00ol0003o
ooooo`000005ooooo`Co0000^?ooool00:Gooooo0_l000000ooooooo0000o`000002o`000;cooooo
002Vooooo`;o0000`?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {0, 0, 0, 0}}]
}, Open  ]],

Cell["\<\
The error is largest near the cusps in the domain, where the \
solution is expected to vary most rapidly. Of course, one could improve the \
solution by keeping more terms in the expansion. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 3", "Section",
  CellTags->"c:8"],

Cell[TextData[{
  "In this example, we consider the solution of Laplaces equation, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 \[Phi] = 0\)]],
  ", in a domain that has a concave cusp of the type discussed in relation to \
Fig. ",
  ButtonBox["6.1 (b)",
    ButtonData:>"Fig. 6.1",
    ButtonStyle->"Hyperlink"],
  ". The domain boundary is defined by the following two equations:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(z\_1\)(x, y) = \ 
        x\^2 + y\^2 - 1, \[IndentingNewLine]\(z\_2\)(x, 
          y)\  = \ \(\(y\)\(-\)\) | x |  . \)]]
}], "Text"],

Cell[TextData[{
  " The domain is shown in Cell ",
  ButtonBox["6.24",
    ButtonData:>"Cell 6.24",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(<< Calculus`;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(z[1, x_, y_]\  = \ x\^2 + y\^2 - 1;\)\), "\[IndentingNewLine]", 
    \(\(z[2, x_, y_]\  = \ \ y - Abs[x]\ ;\)\ \n\), "\[IndentingNewLine]", 
    \(\(ContourPlot[\ 
        Boole[z[1, x, y] \[LessEqual] \ \ \ 0\  && \ 
            z[2, x, y] \[LessEqual] \ \ \ 0\ ], {x, \(-1.3\), 
          1.3}, {y, \(-1.3\), 1.3}, PlotPoints \[Rule] 100];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.24"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.369822 0.5 0.369822 [
[.13018 -0.0125 -6 -9 ]
[.13018 -0.0125 6 0 ]
[.31509 -0.0125 -12 -9 ]
[.31509 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.68491 -0.0125 -9 -9 ]
[.68491 -0.0125 9 0 ]
[.86982 -0.0125 -3 -9 ]
[.86982 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .13018 -12 -4.5 ]
[-0.0125 .13018 0 4.5 ]
[-0.0125 .31509 -24 -4.5 ]
[-0.0125 .31509 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .68491 -18 -4.5 ]
[-0.0125 .68491 0 4.5 ]
[-0.0125 .86982 -6 -4.5 ]
[-0.0125 .86982 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13018 0 m
.13018 .00625 L
s
[(-1)] .13018 -0.0125 0 1 Mshowa
.31509 0 m
.31509 .00625 L
s
[(-0.5)] .31509 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.68491 0 m
.68491 .00625 L
s
[(0.5)] .68491 -0.0125 0 1 Mshowa
.86982 0 m
.86982 .00625 L
s
[(1)] .86982 -0.0125 0 1 Mshowa
.125 Mabswid
.16716 0 m
.16716 .00375 L
s
.20414 0 m
.20414 .00375 L
s
.24112 0 m
.24112 .00375 L
s
.27811 0 m
.27811 .00375 L
s
.35207 0 m
.35207 .00375 L
s
.38905 0 m
.38905 .00375 L
s
.42604 0 m
.42604 .00375 L
s
.46302 0 m
.46302 .00375 L
s
.53698 0 m
.53698 .00375 L
s
.57396 0 m
.57396 .00375 L
s
.61095 0 m
.61095 .00375 L
s
.64793 0 m
.64793 .00375 L
s
.72189 0 m
.72189 .00375 L
s
.75888 0 m
.75888 .00375 L
s
.79586 0 m
.79586 .00375 L
s
.83284 0 m
.83284 .00375 L
s
.0932 0 m
.0932 .00375 L
s
.05621 0 m
.05621 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.9068 0 m
.9068 .00375 L
s
.94379 0 m
.94379 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .13018 m
.00625 .13018 L
s
[(-1)] -0.0125 .13018 1 0 Mshowa
0 .31509 m
.00625 .31509 L
s
[(-0.5)] -0.0125 .31509 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .68491 m
.00625 .68491 L
s
[(0.5)] -0.0125 .68491 1 0 Mshowa
0 .86982 m
.00625 .86982 L
s
[(1)] -0.0125 .86982 1 0 Mshowa
.125 Mabswid
0 .16716 m
.00375 .16716 L
s
0 .20414 m
.00375 .20414 L
s
0 .24112 m
.00375 .24112 L
s
0 .27811 m
.00375 .27811 L
s
0 .35207 m
.00375 .35207 L
s
0 .38905 m
.00375 .38905 L
s
0 .42604 m
.00375 .42604 L
s
0 .46302 m
.00375 .46302 L
s
0 .53698 m
.00375 .53698 L
s
0 .57396 m
.00375 .57396 L
s
0 .61095 m
.00375 .61095 L
s
0 .64793 m
.00375 .64793 L
s
0 .72189 m
.00375 .72189 L
s
0 .75888 m
.00375 .75888 L
s
0 .79586 m
.00375 .79586 L
s
0 .83284 m
.00375 .83284 L
s
0 .0932 m
.00375 .0932 L
s
0 .05621 m
.00375 .05621 L
s
0 .01923 m
.00375 .01923 L
s
0 .9068 m
.00375 .9068 L
s
0 .94379 m
.00375 .94379 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.13018 .99375 m
.13018 1 L
s
.31509 .99375 m
.31509 1 L
s
.5 .99375 m
.5 1 L
s
.68491 .99375 m
.68491 1 L
s
.86982 .99375 m
.86982 1 L
s
.125 Mabswid
.16716 .99625 m
.16716 1 L
s
.20414 .99625 m
.20414 1 L
s
.24112 .99625 m
.24112 1 L
s
.27811 .99625 m
.27811 1 L
s
.35207 .99625 m
.35207 1 L
s
.38905 .99625 m
.38905 1 L
s
.42604 .99625 m
.42604 1 L
s
.46302 .99625 m
.46302 1 L
s
.53698 .99625 m
.53698 1 L
s
.57396 .99625 m
.57396 1 L
s
.61095 .99625 m
.61095 1 L
s
.64793 .99625 m
.64793 1 L
s
.72189 .99625 m
.72189 1 L
s
.75888 .99625 m
.75888 1 L
s
.79586 .99625 m
.79586 1 L
s
.83284 .99625 m
.83284 1 L
s
.0932 .99625 m
.0932 1 L
s
.05621 .99625 m
.05621 1 L
s
.01923 .99625 m
.01923 1 L
s
.9068 .99625 m
.9068 1 L
s
.94379 .99625 m
.94379 1 L
s
.98077 .99625 m
.98077 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .13018 m
1 .13018 L
s
.99375 .31509 m
1 .31509 L
s
.99375 .5 m
1 .5 L
s
.99375 .68491 m
1 .68491 L
s
.99375 .86982 m
1 .86982 L
s
.125 Mabswid
.99625 .16716 m
1 .16716 L
s
.99625 .20414 m
1 .20414 L
s
.99625 .24112 m
1 .24112 L
s
.99625 .27811 m
1 .27811 L
s
.99625 .35207 m
1 .35207 L
s
.99625 .38905 m
1 .38905 L
s
.99625 .42604 m
1 .42604 L
s
.99625 .46302 m
1 .46302 L
s
.99625 .53698 m
1 .53698 L
s
.99625 .57396 m
1 .57396 L
s
.99625 .61095 m
1 .61095 L
s
.99625 .64793 m
1 .64793 L
s
.99625 .72189 m
1 .72189 L
s
.99625 .75888 m
1 .75888 L
s
.99625 .79586 m
1 .79586 L
s
.99625 .83284 m
1 .83284 L
s
.99625 .0932 m
1 .0932 L
s
.99625 .05621 m
1 .05621 L
s
.99625 .01923 m
1 .01923 L
s
.99625 .9068 m
1 .9068 L
s
.99625 .94379 m
1 .94379 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.43687 .12685 m
.44658 .12685 L
.45629 .12685 L
.46601 .12685 L
.47572 .12685 L
.48543 .12685 L
.49514 .12685 L
.50486 .12685 L
.51457 .12685 L
.52428 .12685 L
.53399 .12685 L
.54371 .12685 L
.55342 .12685 L
.56313 .12685 L
.57206 .13578 L
.57284 .13657 L
.58256 .13657 L
.59227 .13657 L
.60198 .13657 L
.61091 .14549 L
.61169 .14628 L
.62141 .14628 L
.63112 .14628 L
.64005 .15521 L
.64083 .15599 L
.65054 .15599 L
.65947 .16492 L
.66026 .1657 L
.66997 .1657 L
.6789 .17463 L
.67968 .17542 L
.68939 .17542 L
.69832 .18434 L
.69911 .18513 L
.70803 .19406 L
.70882 .19484 L
.71853 .19484 L
.72746 .20377 L
.72824 .20455 L
.73717 .21348 L
.73796 .21427 L
.74688 .22319 L
.74767 .22398 L
.7566 .23291 L
.75738 .23369 L
.76631 .24262 L
.76709 .2434 L
.77602 .25233 L
.77681 .25312 L
.78573 .26204 L
.78652 .26283 L
.79545 .27176 L
.79623 .27254 L
.80516 .28147 L
.80516 .29118 L
.80594 .29197 L
.81487 .30089 L
.81566 .30168 L
.82458 .31061 L
.82458 .32032 L
.82537 .3211 L
.8343 .33003 L
.8343 .33974 L
.83508 .34053 L
.84401 .34946 L
.84401 .35917 L
.84479 .35995 L
.85372 .36888 L
.85372 .37859 L
.85372 .38831 L
.85451 .38909 L
.86343 .39802 L
.86343 .40773 L
.86343 .41744 L
.86343 .42716 L
.86422 .42794 L
.87315 .43687 L
.87315 .44658 L
.87315 .45629 L
.87315 .46601 L
.87315 .47572 L
.87315 .48543 L
.87315 .49514 L
.87315 .50486 L
.87315 .51457 L
.87315 .52428 L
.87315 .53399 L
.87315 .54371 L
.87315 .55342 L
.87315 .56313 L
.86422 .57206 L
.86343 .57284 L
.86343 .58256 L
.86343 .59227 L
.86343 .60198 L
.85451 .61091 L
.85372 .61169 L
.85372 .62141 L
.85372 .63112 L
.84479 .64005 L
.84401 .64083 L
.84401 .65054 L
.83508 .65947 L
.8343 .66026 L
.8343 .66997 L
.82537 .6789 L
.82458 .67968 L
.82458 .68939 L
.81566 .69832 L
.81487 .69911 L
.80594 .70803 L
.80516 .70882 L
.80516 .71853 L
.79623 .72746 L
.79545 .72824 L
.78652 .73717 L
.78573 .73796 L
.77681 .74688 L
.77602 .74767 L
.76709 .7566 L
.76643 .75738 L
.75738 .76631 L
.74833 .75738 L
.74767 .7566 L
.73874 .74767 L
.73796 .74688 L
.72903 .73796 L
.72824 .73717 L
.71932 .72824 L
.71853 .72746 L
.7096 .71853 L
.70882 .71775 L
.69989 .70882 L
.69911 .70803 L
.69018 .69911 L
.68939 .69832 L
.68047 .68939 L
.67968 .68861 L
.67075 .67968 L
.66997 .6789 L
.66104 .66997 L
.66026 .66918 L
.65133 .66026 L
.65054 .65947 L
.64162 .65054 L
.64083 .64976 L
.6319 .64083 L
.63112 .64005 L
.62219 .63112 L
.62141 .63033 L
.61248 .62141 L
.61169 .62062 L
.60277 .61169 L
.60198 .61091 L
.59305 .60198 L
.59227 .6012 L
.58334 .59227 L
.58256 .59148 L
.57363 .58256 L
.57284 .58177 L
.56392 .57284 L
.56313 .57206 L
.5542 .56313 L
.55342 .56235 L
.54449 .55342 L
.54371 .55263 L
.53478 .54371 L
.53399 .54292 L
.52507 .53399 L
.52428 .53321 L
.51535 .52428 L
.51457 .5235 L
.50564 .51457 L
.50486 .51378 L
.49514 .51378 L
.49436 .51457 L
.48543 .5235 L
.48465 .52428 L
.47572 .53321 L
.47493 .53399 L
.46601 .54292 L
.46522 .54371 L
.45629 .55263 L
.45551 .55342 L
.44658 .56235 L
.4458 .56313 L
.43687 .57206 L
.43608 .57284 L
.42716 .58177 L
.42637 .58256 L
.41744 .59148 L
.41666 .59227 L
.40773 .6012 L
.40695 .60198 L
.39802 .61091 L
.39723 .61169 L
.38831 .62062 L
.38752 .62141 L
.37859 .63033 L
.37781 .63112 L
.36888 .64005 L
.3681 .64083 L
.35917 .64976 L
.35838 .65054 L
.34946 .65947 L
.34867 .66026 L
.33974 .66918 L
.33896 .66997 L
.33003 .6789 L
.32925 .67968 L
.32032 .68861 L
.31953 .68939 L
.31061 .69832 L
.30982 .69911 L
.30089 .70803 L
.30011 .70882 L
.29118 .71775 L
.2904 .71853 L
.28147 .72746 L
.28068 .72824 L
.27176 .73717 L
.27097 .73796 L
.26204 .74688 L
.26126 .74767 L
.25233 .7566 L
.25167 .75738 L
.24262 .76631 L
.23357 .75738 L
.23291 .7566 L
.22398 .74767 L
.22319 .74688 L
.21427 .73796 L
.21348 .73717 L
.20455 .72824 L
.20377 .72746 L
.19484 .71853 L
.19484 .70882 L
.19406 .70803 L
.18513 .69911 L
.18434 .69832 L
.17542 .68939 L
.17542 .67968 L
.17463 .6789 L
.1657 .66997 L
.1657 .66026 L
.16492 .65947 L
.15599 .65054 L
.15599 .64083 L
.15521 .64005 L
.14628 .63112 L
.14628 .62141 L
.14628 .61169 L
.14549 .61091 L
.13657 .60198 L
.13657 .59227 L
.13657 .58256 L
.13657 .57284 L
.13578 .57206 L
.12685 .56313 L
.12685 .55342 L
.12685 .54371 L
.12685 .53399 L
.12685 .52428 L
.12685 .51457 L
.12685 .50486 L
.12685 .49514 L
.12685 .48543 L
.12685 .47572 L
.12685 .46601 L
.12685 .45629 L
.12685 .44658 L
.12685 .43687 L
.13578 .42794 L
.13657 .42716 L
.13657 .41744 L
.13657 .40773 L
.13657 .39802 L
.14549 .38909 L
.14628 .38831 L
.14628 .37859 L
.14628 .36888 L
.15521 .35995 L
.15599 .35917 L
.15599 .34946 L
.16492 .34053 L
.1657 .33974 L
.1657 .33003 L
.17463 .3211 L
.17542 .32032 L
.17542 .31061 L
.18434 .30168 L
.18513 .30089 L
.19406 .29197 L
.19484 .29118 L
.19484 .28147 L
.20377 .27254 L
.20455 .27176 L
.21348 .26283 L
.21427 .26204 L
.22319 .25312 L
.22398 .25233 L
.23291 .2434 L
.23369 .24262 L
.24262 .23369 L
.2434 .23291 L
.25233 .22398 L
.25312 .22319 L
.26204 .21427 L
.26283 .21348 L
.27176 .20455 L
.27254 .20377 L
.28147 .19484 L
.29118 .19484 L
.29197 .19406 L
.30089 .18513 L
.30168 .18434 L
.31061 .17542 L
.32032 .17542 L
.3211 .17463 L
.33003 .1657 L
.33974 .1657 L
.34053 .16492 L
.34946 .15599 L
.35917 .15599 L
.35995 .15521 L
.36888 .14628 L
.37859 .14628 L
.38831 .14628 L
.38909 .14549 L
.39802 .13657 L
.40773 .13657 L
.41744 .13657 L
.42716 .13657 L
.42794 .13578 L
F
0 g
.43687 .12685 m
.44658 .12685 L
.45629 .12685 L
.46601 .12685 L
.47572 .12685 L
.48543 .12685 L
.49514 .12685 L
.50486 .12685 L
.51457 .12685 L
.52428 .12685 L
.53399 .12685 L
.54371 .12685 L
.55342 .12685 L
.56313 .12685 L
.57206 .13578 L
.57284 .13657 L
.58256 .13657 L
.59227 .13657 L
.60198 .13657 L
.61091 .14549 L
.61169 .14628 L
.62141 .14628 L
.63112 .14628 L
.64005 .15521 L
.64083 .15599 L
.65054 .15599 L
.65947 .16492 L
.66026 .1657 L
.66997 .1657 L
.6789 .17463 L
.67968 .17542 L
.68939 .17542 L
.69832 .18434 L
.69911 .18513 L
.70803 .19406 L
.70882 .19484 L
.71853 .19484 L
.72746 .20377 L
.72824 .20455 L
.73717 .21348 L
.73796 .21427 L
.74688 .22319 L
.74767 .22398 L
.7566 .23291 L
.75738 .23369 L
.76631 .24262 L
.76709 .2434 L
.77602 .25233 L
.77681 .25312 L
.78573 .26204 L
Mistroke
.78652 .26283 L
.79545 .27176 L
.79623 .27254 L
.80516 .28147 L
.80516 .29118 L
.80594 .29197 L
.81487 .30089 L
.81566 .30168 L
.82458 .31061 L
.82458 .32032 L
.82537 .3211 L
.8343 .33003 L
.8343 .33974 L
.83508 .34053 L
.84401 .34946 L
.84401 .35917 L
.84479 .35995 L
.85372 .36888 L
.85372 .37859 L
.85372 .38831 L
.85451 .38909 L
.86343 .39802 L
.86343 .40773 L
.86343 .41744 L
.86343 .42716 L
.86422 .42794 L
.87315 .43687 L
.87315 .44658 L
.87315 .45629 L
.87315 .46601 L
.87315 .47572 L
.87315 .48543 L
.87315 .49514 L
.87315 .50486 L
.87315 .51457 L
.87315 .52428 L
.87315 .53399 L
.87315 .54371 L
.87315 .55342 L
.87315 .56313 L
.86422 .57206 L
.86343 .57284 L
.86343 .58256 L
.86343 .59227 L
.86343 .60198 L
.85451 .61091 L
.85372 .61169 L
.85372 .62141 L
.85372 .63112 L
.84479 .64005 L
Mistroke
.84401 .64083 L
.84401 .65054 L
.83508 .65947 L
.8343 .66026 L
.8343 .66997 L
.82537 .6789 L
.82458 .67968 L
.82458 .68939 L
.81566 .69832 L
.81487 .69911 L
.80594 .70803 L
.80516 .70882 L
.80516 .71853 L
.79623 .72746 L
.79545 .72824 L
.78652 .73717 L
.78573 .73796 L
.77681 .74688 L
.77602 .74767 L
.76709 .7566 L
.76643 .75738 L
.75738 .76631 L
.74833 .75738 L
.74767 .7566 L
.73874 .74767 L
.73796 .74688 L
.72903 .73796 L
.72824 .73717 L
.71932 .72824 L
.71853 .72746 L
.7096 .71853 L
.70882 .71775 L
.69989 .70882 L
.69911 .70803 L
.69018 .69911 L
.68939 .69832 L
.68047 .68939 L
.67968 .68861 L
.67075 .67968 L
.66997 .6789 L
.66104 .66997 L
.66026 .66918 L
.65133 .66026 L
.65054 .65947 L
.64162 .65054 L
.64083 .64976 L
.6319 .64083 L
.63112 .64005 L
.62219 .63112 L
.62141 .63033 L
Mistroke
.61248 .62141 L
.61169 .62062 L
.60277 .61169 L
.60198 .61091 L
.59305 .60198 L
.59227 .6012 L
.58334 .59227 L
.58256 .59148 L
.57363 .58256 L
.57284 .58177 L
.56392 .57284 L
.56313 .57206 L
.5542 .56313 L
.55342 .56235 L
.54449 .55342 L
.54371 .55263 L
.53478 .54371 L
.53399 .54292 L
.52507 .53399 L
.52428 .53321 L
.51535 .52428 L
.51457 .5235 L
.50564 .51457 L
.50486 .51378 L
.49514 .51378 L
.49436 .51457 L
.48543 .5235 L
.48465 .52428 L
.47572 .53321 L
.47493 .53399 L
.46601 .54292 L
.46522 .54371 L
.45629 .55263 L
.45551 .55342 L
.44658 .56235 L
.4458 .56313 L
.43687 .57206 L
.43608 .57284 L
.42716 .58177 L
.42637 .58256 L
.41744 .59148 L
.41666 .59227 L
.40773 .6012 L
.40695 .60198 L
.39802 .61091 L
.39723 .61169 L
.38831 .62062 L
.38752 .62141 L
.37859 .63033 L
.37781 .63112 L
Mistroke
.36888 .64005 L
.3681 .64083 L
.35917 .64976 L
.35838 .65054 L
.34946 .65947 L
.34867 .66026 L
.33974 .66918 L
.33896 .66997 L
.33003 .6789 L
.32925 .67968 L
.32032 .68861 L
.31953 .68939 L
.31061 .69832 L
.30982 .69911 L
.30089 .70803 L
.30011 .70882 L
.29118 .71775 L
.2904 .71853 L
.28147 .72746 L
.28068 .72824 L
.27176 .73717 L
.27097 .73796 L
.26204 .74688 L
.26126 .74767 L
.25233 .7566 L
.25167 .75738 L
.24262 .76631 L
.23357 .75738 L
.23291 .7566 L
.22398 .74767 L
.22319 .74688 L
.21427 .73796 L
.21348 .73717 L
.20455 .72824 L
.20377 .72746 L
.19484 .71853 L
.19484 .70882 L
.19406 .70803 L
.18513 .69911 L
.18434 .69832 L
.17542 .68939 L
.17542 .67968 L
.17463 .6789 L
.1657 .66997 L
.1657 .66026 L
.16492 .65947 L
.15599 .65054 L
.15599 .64083 L
.15521 .64005 L
.14628 .63112 L
Mistroke
.14628 .62141 L
.14628 .61169 L
.14549 .61091 L
.13657 .60198 L
.13657 .59227 L
.13657 .58256 L
.13657 .57284 L
.13578 .57206 L
.12685 .56313 L
.12685 .55342 L
.12685 .54371 L
.12685 .53399 L
.12685 .52428 L
.12685 .51457 L
.12685 .50486 L
.12685 .49514 L
.12685 .48543 L
.12685 .47572 L
.12685 .46601 L
.12685 .45629 L
.12685 .44658 L
.12685 .43687 L
.13578 .42794 L
.13657 .42716 L
.13657 .41744 L
.13657 .40773 L
.13657 .39802 L
.14549 .38909 L
.14628 .38831 L
.14628 .37859 L
.14628 .36888 L
.15521 .35995 L
.15599 .35917 L
.15599 .34946 L
.16492 .34053 L
.1657 .33974 L
.1657 .33003 L
.17463 .3211 L
.17542 .32032 L
.17542 .31061 L
.18434 .30168 L
.18513 .30089 L
.19406 .29197 L
.19484 .29118 L
.19484 .28147 L
.20377 .27254 L
.20455 .27176 L
.21348 .26283 L
.21427 .26204 L
.22319 .25312 L
Mistroke
.22398 .25233 L
.23291 .2434 L
.23369 .24262 L
.24262 .23369 L
.2434 .23291 L
.25233 .22398 L
.25312 .22319 L
.26204 .21427 L
.26283 .21348 L
.27176 .20455 L
.27254 .20377 L
.28147 .19484 L
.29118 .19484 L
.29197 .19406 L
.30089 .18513 L
.30168 .18434 L
.31061 .17542 L
.32032 .17542 L
.3211 .17463 L
.33003 .1657 L
.33974 .1657 L
.34053 .16492 L
.34946 .15599 L
.35917 .15599 L
.35995 .15521 L
.36888 .14628 L
.37859 .14628 L
.38831 .14628 L
.38909 .14549 L
.39802 .13657 L
.40773 .13657 L
.41744 .13657 L
.42716 .13657 L
.42794 .13578 L
.43687 .12685 L
Mfstroke
.2 g
.43687 .12783 m
.44658 .12783 L
.45629 .12783 L
.46601 .12783 L
.47572 .12783 L
.48543 .12783 L
.49514 .12783 L
.50486 .12783 L
.51457 .12783 L
.52428 .12783 L
.53399 .12783 L
.54371 .12783 L
.55342 .12783 L
.56313 .12783 L
.57108 .13578 L
.57284 .13755 L
.58256 .13755 L
.59227 .13755 L
.60198 .13755 L
.60993 .14549 L
.61169 .14726 L
.62141 .14726 L
.63112 .14726 L
.63907 .15521 L
.64083 .15697 L
.65054 .15697 L
.65849 .16492 L
.66026 .16668 L
.66997 .16668 L
.67792 .17463 L
.67968 .1764 L
.68939 .1764 L
.69734 .18434 L
.69911 .18611 L
.70705 .19406 L
.70882 .19582 L
.71853 .19582 L
.72648 .20377 L
.72824 .20553 L
.73619 .21348 L
.73796 .21525 L
.7459 .22319 L
.74767 .22496 L
.75562 .23291 L
.75738 .23467 L
.76533 .24262 L
.76709 .24438 L
.77504 .25233 L
.77681 .2541 L
.78475 .26204 L
.78652 .26381 L
.79447 .27176 L
.79623 .27352 L
.80418 .28147 L
.80418 .29118 L
.80594 .29295 L
.81389 .30089 L
.81566 .30266 L
.8236 .31061 L
.8236 .32032 L
.82537 .32208 L
.83332 .33003 L
.83332 .33974 L
.83508 .34151 L
.84303 .34946 L
.84303 .35917 L
.84479 .36093 L
.85274 .36888 L
.85274 .37859 L
.85274 .38831 L
.85451 .39007 L
.86245 .39802 L
.86245 .40773 L
.86245 .41744 L
.86245 .42716 L
.86422 .42892 L
.87217 .43687 L
.87217 .44658 L
.87217 .45629 L
.87217 .46601 L
.87217 .47572 L
.87217 .48543 L
.87217 .49514 L
.87217 .50486 L
.87217 .51457 L
.87217 .52428 L
.87217 .53399 L
.87217 .54371 L
.87217 .55342 L
.87217 .56313 L
.86422 .57108 L
.86245 .57284 L
.86245 .58256 L
.86245 .59227 L
.86245 .60198 L
.85451 .60993 L
.85274 .61169 L
.85274 .62141 L
.85274 .63112 L
.84479 .63907 L
.84303 .64083 L
.84303 .65054 L
.83508 .65849 L
.83332 .66026 L
.83332 .66997 L
.82537 .67792 L
.8236 .67968 L
.8236 .68939 L
.81566 .69734 L
.81389 .69911 L
.80594 .70705 L
.80418 .70882 L
.80418 .71853 L
.79623 .72648 L
.79447 .72824 L
.78652 .73619 L
.78475 .73796 L
.77681 .7459 L
.77504 .74767 L
.76709 .75562 L
.76558 .75738 L
.75738 .76533 L
.74918 .75738 L
.74767 .75562 L
.73972 .74767 L
.73796 .7459 L
.73001 .73796 L
.72824 .73619 L
.7203 .72824 L
.71853 .72648 L
.71058 .71853 L
.70882 .71677 L
.70087 .70882 L
.69911 .70705 L
.69116 .69911 L
.68939 .69734 L
.68145 .68939 L
.67968 .68763 L
.67173 .67968 L
.66997 .67792 L
.66202 .66997 L
.66026 .6682 L
.65231 .66026 L
.65054 .65849 L
.6426 .65054 L
.64083 .64878 L
.63288 .64083 L
.63112 .63907 L
.62317 .63112 L
.62141 .62935 L
.61346 .62141 L
.61169 .61964 L
.60375 .61169 L
.60198 .60993 L
.59403 .60198 L
.59227 .60022 L
.58432 .59227 L
.58256 .5905 L
.57461 .58256 L
.57284 .58079 L
.5649 .57284 L
.56313 .57108 L
.55518 .56313 L
.55342 .56137 L
.54547 .55342 L
.54371 .55165 L
.53576 .54371 L
.53399 .54194 L
.52605 .53399 L
.52428 .53223 L
.51633 .52428 L
.51457 .52252 L
.50662 .51457 L
.50486 .5128 L
.49514 .5128 L
.49338 .51457 L
.48543 .52252 L
.48367 .52428 L
.47572 .53223 L
.47395 .53399 L
.46601 .54194 L
.46424 .54371 L
.45629 .55165 L
.45453 .55342 L
.44658 .56137 L
.44482 .56313 L
.43687 .57108 L
.4351 .57284 L
.42716 .58079 L
.42539 .58256 L
.41744 .5905 L
.41568 .59227 L
.40773 .60022 L
.40597 .60198 L
.39802 .60993 L
.39625 .61169 L
.38831 .61964 L
.38654 .62141 L
.37859 .62935 L
.37683 .63112 L
.36888 .63907 L
.36712 .64083 L
.35917 .64878 L
.3574 .65054 L
.34946 .65849 L
.34769 .66026 L
.33974 .6682 L
.33798 .66997 L
.33003 .67792 L
.32827 .67968 L
.32032 .68763 L
.31855 .68939 L
.31061 .69734 L
.30884 .69911 L
.30089 .70705 L
.29913 .70882 L
.29118 .71677 L
.28942 .71853 L
.28147 .72648 L
.2797 .72824 L
.27176 .73619 L
.26999 .73796 L
.26204 .7459 L
.26028 .74767 L
.25233 .75562 L
.25082 .75738 L
.24262 .76533 L
.23442 .75738 L
.23291 .75562 L
.22496 .74767 L
.22319 .7459 L
.21525 .73796 L
.21348 .73619 L
.20553 .72824 L
.20377 .72648 L
.19582 .71853 L
.19582 .70882 L
.19406 .70705 L
.18611 .69911 L
.18434 .69734 L
.1764 .68939 L
.1764 .67968 L
.17463 .67792 L
.16668 .66997 L
.16668 .66026 L
.16492 .65849 L
.15697 .65054 L
.15697 .64083 L
.15521 .63907 L
.14726 .63112 L
.14726 .62141 L
.14726 .61169 L
.14549 .60993 L
.13755 .60198 L
.13755 .59227 L
.13755 .58256 L
.13755 .57284 L
.13578 .57108 L
.12783 .56313 L
.12783 .55342 L
.12783 .54371 L
.12783 .53399 L
.12783 .52428 L
.12783 .51457 L
.12783 .50486 L
.12783 .49514 L
.12783 .48543 L
.12783 .47572 L
.12783 .46601 L
.12783 .45629 L
.12783 .44658 L
.12783 .43687 L
.13578 .42892 L
.13755 .42716 L
.13755 .41744 L
.13755 .40773 L
.13755 .39802 L
.14549 .39007 L
.14726 .38831 L
.14726 .37859 L
.14726 .36888 L
.15521 .36093 L
.15697 .35917 L
.15697 .34946 L
.16492 .34151 L
.16668 .33974 L
.16668 .33003 L
.17463 .32208 L
.1764 .32032 L
.1764 .31061 L
.18434 .30266 L
.18611 .30089 L
.19406 .29295 L
.19582 .29118 L
.19582 .28147 L
.20377 .27352 L
.20553 .27176 L
.21348 .26381 L
.21525 .26204 L
.22319 .2541 L
.22496 .25233 L
.23291 .24438 L
.23467 .24262 L
.24262 .23467 L
.24438 .23291 L
.25233 .22496 L
.2541 .22319 L
.26204 .21525 L
.26381 .21348 L
.27176 .20553 L
.27352 .20377 L
.28147 .19582 L
.29118 .19582 L
.29295 .19406 L
.30089 .18611 L
.30266 .18434 L
.31061 .1764 L
.32032 .1764 L
.32208 .17463 L
.33003 .16668 L
.33974 .16668 L
.34151 .16492 L
.34946 .15697 L
.35917 .15697 L
.36093 .15521 L
.36888 .14726 L
.37859 .14726 L
.38831 .14726 L
.39007 .14549 L
.39802 .13755 L
.40773 .13755 L
.41744 .13755 L
.42716 .13755 L
.42892 .13578 L
F
0 g
.43687 .12783 m
.44658 .12783 L
.45629 .12783 L
.46601 .12783 L
.47572 .12783 L
.48543 .12783 L
.49514 .12783 L
.50486 .12783 L
.51457 .12783 L
.52428 .12783 L
.53399 .12783 L
.54371 .12783 L
.55342 .12783 L
.56313 .12783 L
.57108 .13578 L
.57284 .13755 L
.58256 .13755 L
.59227 .13755 L
.60198 .13755 L
.60993 .14549 L
.61169 .14726 L
.62141 .14726 L
.63112 .14726 L
.63907 .15521 L
.64083 .15697 L
.65054 .15697 L
.65849 .16492 L
.66026 .16668 L
.66997 .16668 L
.67792 .17463 L
.67968 .1764 L
.68939 .1764 L
.69734 .18434 L
.69911 .18611 L
.70705 .19406 L
.70882 .19582 L
.71853 .19582 L
.72648 .20377 L
.72824 .20553 L
.73619 .21348 L
.73796 .21525 L
.7459 .22319 L
.74767 .22496 L
.75562 .23291 L
.75738 .23467 L
.76533 .24262 L
.76709 .24438 L
.77504 .25233 L
.77681 .2541 L
.78475 .26204 L
Mistroke
.78652 .26381 L
.79447 .27176 L
.79623 .27352 L
.80418 .28147 L
.80418 .29118 L
.80594 .29295 L
.81389 .30089 L
.81566 .30266 L
.8236 .31061 L
.8236 .32032 L
.82537 .32208 L
.83332 .33003 L
.83332 .33974 L
.83508 .34151 L
.84303 .34946 L
.84303 .35917 L
.84479 .36093 L
.85274 .36888 L
.85274 .37859 L
.85274 .38831 L
.85451 .39007 L
.86245 .39802 L
.86245 .40773 L
.86245 .41744 L
.86245 .42716 L
.86422 .42892 L
.87217 .43687 L
.87217 .44658 L
.87217 .45629 L
.87217 .46601 L
.87217 .47572 L
.87217 .48543 L
.87217 .49514 L
.87217 .50486 L
.87217 .51457 L
.87217 .52428 L
.87217 .53399 L
.87217 .54371 L
.87217 .55342 L
.87217 .56313 L
.86422 .57108 L
.86245 .57284 L
.86245 .58256 L
.86245 .59227 L
.86245 .60198 L
.85451 .60993 L
.85274 .61169 L
.85274 .62141 L
.85274 .63112 L
.84479 .63907 L
Mistroke
.84303 .64083 L
.84303 .65054 L
.83508 .65849 L
.83332 .66026 L
.83332 .66997 L
.82537 .67792 L
.8236 .67968 L
.8236 .68939 L
.81566 .69734 L
.81389 .69911 L
.80594 .70705 L
.80418 .70882 L
.80418 .71853 L
.79623 .72648 L
.79447 .72824 L
.78652 .73619 L
.78475 .73796 L
.77681 .7459 L
.77504 .74767 L
.76709 .75562 L
.76558 .75738 L
.75738 .76533 L
.74918 .75738 L
.74767 .75562 L
.73972 .74767 L
.73796 .7459 L
.73001 .73796 L
.72824 .73619 L
.7203 .72824 L
.71853 .72648 L
.71058 .71853 L
.70882 .71677 L
.70087 .70882 L
.69911 .70705 L
.69116 .69911 L
.68939 .69734 L
.68145 .68939 L
.67968 .68763 L
.67173 .67968 L
.66997 .67792 L
.66202 .66997 L
.66026 .6682 L
.65231 .66026 L
.65054 .65849 L
.6426 .65054 L
.64083 .64878 L
.63288 .64083 L
.63112 .63907 L
.62317 .63112 L
.62141 .62935 L
Mistroke
.61346 .62141 L
.61169 .61964 L
.60375 .61169 L
.60198 .60993 L
.59403 .60198 L
.59227 .60022 L
.58432 .59227 L
.58256 .5905 L
.57461 .58256 L
.57284 .58079 L
.5649 .57284 L
.56313 .57108 L
.55518 .56313 L
.55342 .56137 L
.54547 .55342 L
.54371 .55165 L
.53576 .54371 L
.53399 .54194 L
.52605 .53399 L
.52428 .53223 L
.51633 .52428 L
.51457 .52252 L
.50662 .51457 L
.50486 .5128 L
.49514 .5128 L
.49338 .51457 L
.48543 .52252 L
.48367 .52428 L
.47572 .53223 L
.47395 .53399 L
.46601 .54194 L
.46424 .54371 L
.45629 .55165 L
.45453 .55342 L
.44658 .56137 L
.44482 .56313 L
.43687 .57108 L
.4351 .57284 L
.42716 .58079 L
.42539 .58256 L
.41744 .5905 L
.41568 .59227 L
.40773 .60022 L
.40597 .60198 L
.39802 .60993 L
.39625 .61169 L
.38831 .61964 L
.38654 .62141 L
.37859 .62935 L
.37683 .63112 L
Mistroke
.36888 .63907 L
.36712 .64083 L
.35917 .64878 L
.3574 .65054 L
.34946 .65849 L
.34769 .66026 L
.33974 .6682 L
.33798 .66997 L
.33003 .67792 L
.32827 .67968 L
.32032 .68763 L
.31855 .68939 L
.31061 .69734 L
.30884 .69911 L
.30089 .70705 L
.29913 .70882 L
.29118 .71677 L
.28942 .71853 L
.28147 .72648 L
.2797 .72824 L
.27176 .73619 L
.26999 .73796 L
.26204 .7459 L
.26028 .74767 L
.25233 .75562 L
.25082 .75738 L
.24262 .76533 L
.23442 .75738 L
.23291 .75562 L
.22496 .74767 L
.22319 .7459 L
.21525 .73796 L
.21348 .73619 L
.20553 .72824 L
.20377 .72648 L
.19582 .71853 L
.19582 .70882 L
.19406 .70705 L
.18611 .69911 L
.18434 .69734 L
.1764 .68939 L
.1764 .67968 L
.17463 .67792 L
.16668 .66997 L
.16668 .66026 L
.16492 .65849 L
.15697 .65054 L
.15697 .64083 L
.15521 .63907 L
.14726 .63112 L
Mistroke
.14726 .62141 L
.14726 .61169 L
.14549 .60993 L
.13755 .60198 L
.13755 .59227 L
.13755 .58256 L
.13755 .57284 L
.13578 .57108 L
.12783 .56313 L
.12783 .55342 L
.12783 .54371 L
.12783 .53399 L
.12783 .52428 L
.12783 .51457 L
.12783 .50486 L
.12783 .49514 L
.12783 .48543 L
.12783 .47572 L
.12783 .46601 L
.12783 .45629 L
.12783 .44658 L
.12783 .43687 L
.13578 .42892 L
.13755 .42716 L
.13755 .41744 L
.13755 .40773 L
.13755 .39802 L
.14549 .39007 L
.14726 .38831 L
.14726 .37859 L
.14726 .36888 L
.15521 .36093 L
.15697 .35917 L
.15697 .34946 L
.16492 .34151 L
.16668 .33974 L
.16668 .33003 L
.17463 .32208 L
.1764 .32032 L
.1764 .31061 L
.18434 .30266 L
.18611 .30089 L
.19406 .29295 L
.19582 .29118 L
.19582 .28147 L
.20377 .27352 L
.20553 .27176 L
.21348 .26381 L
.21525 .26204 L
.22319 .2541 L
Mistroke
.22496 .25233 L
.23291 .24438 L
.23467 .24262 L
.24262 .23467 L
.24438 .23291 L
.25233 .22496 L
.2541 .22319 L
.26204 .21525 L
.26381 .21348 L
.27176 .20553 L
.27352 .20377 L
.28147 .19582 L
.29118 .19582 L
.29295 .19406 L
.30089 .18611 L
.30266 .18434 L
.31061 .1764 L
.32032 .1764 L
.32208 .17463 L
.33003 .16668 L
.33974 .16668 L
.34151 .16492 L
.34946 .15697 L
.35917 .15697 L
.36093 .15521 L
.36888 .14726 L
.37859 .14726 L
.38831 .14726 L
.39007 .14549 L
.39802 .13755 L
.40773 .13755 L
.41744 .13755 L
.42716 .13755 L
.42892 .13578 L
.43687 .12783 L
Mfstroke
.3 g
.43687 .12875 m
.44658 .12875 L
.45629 .12875 L
.46601 .12875 L
.47572 .12875 L
.48543 .12875 L
.49514 .12875 L
.50486 .12875 L
.51457 .12875 L
.52428 .12875 L
.53399 .12875 L
.54371 .12875 L
.55342 .12875 L
.56313 .12875 L
.57016 .13578 L
.57284 .13846 L
.58256 .13846 L
.59227 .13846 L
.60198 .13846 L
.60901 .14549 L
.61169 .14818 L
.62141 .14818 L
.63112 .14818 L
.63815 .15521 L
.64083 .15789 L
.65054 .15789 L
.65757 .16492 L
.66026 .1676 L
.66997 .1676 L
.677 .17463 L
.67968 .17731 L
.68939 .17731 L
.69642 .18434 L
.69911 .18703 L
.70614 .19406 L
.70882 .19674 L
.71853 .19674 L
.72556 .20377 L
.72824 .20645 L
.73527 .21348 L
.73796 .21616 L
.74499 .22319 L
.74767 .22588 L
.7547 .23291 L
.75738 .23559 L
.76441 .24262 L
.76709 .2453 L
.77412 .25233 L
.77681 .25501 L
.78384 .26204 L
.78652 .26473 L
.79355 .27176 L
.79623 .27444 L
.80326 .28147 L
.80326 .29118 L
.80594 .29386 L
.81297 .30089 L
.81566 .30358 L
.82269 .31061 L
.82269 .32032 L
.82537 .323 L
.8324 .33003 L
.8324 .33974 L
.83508 .34243 L
.84211 .34946 L
.84211 .35917 L
.84479 .36185 L
.85182 .36888 L
.85182 .37859 L
.85182 .38831 L
.85451 .39099 L
.86154 .39802 L
.86154 .40773 L
.86154 .41744 L
.86154 .42716 L
.86422 .42984 L
.87125 .43687 L
.87125 .44658 L
.87125 .45629 L
.87125 .46601 L
.87125 .47572 L
.87125 .48543 L
.87125 .49514 L
.87125 .50486 L
.87125 .51457 L
.87125 .52428 L
.87125 .53399 L
.87125 .54371 L
.87125 .55342 L
.87125 .56313 L
.86422 .57016 L
.86154 .57284 L
.86154 .58256 L
.86154 .59227 L
.86154 .60198 L
.85451 .60901 L
.85182 .61169 L
.85182 .62141 L
.85182 .63112 L
.84479 .63815 L
.84211 .64083 L
.84211 .65054 L
.83508 .65757 L
.8324 .66026 L
.8324 .66997 L
.82537 .677 L
.82269 .67968 L
.82269 .68939 L
.81566 .69642 L
.81297 .69911 L
.80594 .70614 L
.80326 .70882 L
.80326 .71853 L
.79623 .72556 L
.79355 .72824 L
.78652 .73527 L
.78384 .73796 L
.77681 .74499 L
.77412 .74767 L
.76709 .7547 L
.76477 .75738 L
.75738 .76441 L
.75 .75738 L
.74767 .7547 L
.74064 .74767 L
.73796 .74499 L
.73093 .73796 L
.72824 .73527 L
.72121 .72824 L
.71853 .72556 L
.7115 .71853 L
.70882 .71585 L
.70179 .70882 L
.69911 .70614 L
.69208 .69911 L
.68939 .69642 L
.68236 .68939 L
.67968 .68671 L
.67265 .67968 L
.66997 .677 L
.66294 .66997 L
.66026 .66729 L
.65323 .66026 L
.65054 .65757 L
.64351 .65054 L
.64083 .64786 L
.6338 .64083 L
.63112 .63815 L
.62409 .63112 L
.62141 .62844 L
.61438 .62141 L
.61169 .61872 L
.60466 .61169 L
.60198 .60901 L
.59495 .60198 L
.59227 .5993 L
.58524 .59227 L
.58256 .58959 L
.57553 .58256 L
.57284 .57987 L
.56581 .57284 L
.56313 .57016 L
.5561 .56313 L
.55342 .56045 L
.54639 .55342 L
.54371 .55074 L
.53668 .54371 L
.53399 .54102 L
.52696 .53399 L
.52428 .53131 L
.51725 .52428 L
.51457 .5216 L
.50754 .51457 L
.50486 .51189 L
.49514 .51189 L
.49246 .51457 L
.48543 .5216 L
.48275 .52428 L
.47572 .53131 L
.47304 .53399 L
.46601 .54102 L
.46332 .54371 L
.45629 .55074 L
.45361 .55342 L
.44658 .56045 L
.4439 .56313 L
.43687 .57016 L
.43419 .57284 L
.42716 .57987 L
.42447 .58256 L
.41744 .58959 L
.41476 .59227 L
.40773 .5993 L
.40505 .60198 L
.39802 .60901 L
.39534 .61169 L
.38831 .61872 L
.38562 .62141 L
.37859 .62844 L
.37591 .63112 L
.36888 .63815 L
.3662 .64083 L
.35917 .64786 L
.35649 .65054 L
.34946 .65757 L
.34677 .66026 L
.33974 .66729 L
.33706 .66997 L
.33003 .677 L
.32735 .67968 L
.32032 .68671 L
.31764 .68939 L
.31061 .69642 L
.30792 .69911 L
.30089 .70614 L
.29821 .70882 L
.29118 .71585 L
.2885 .71853 L
.28147 .72556 L
.27879 .72824 L
.27176 .73527 L
.26907 .73796 L
.26204 .74499 L
.25936 .74767 L
.25233 .7547 L
.25 .75738 L
.24262 .76441 L
.23523 .75738 L
.23291 .7547 L
.22588 .74767 L
.22319 .74499 L
.21616 .73796 L
.21348 .73527 L
.20645 .72824 L
.20377 .72556 L
.19674 .71853 L
.19674 .70882 L
.19406 .70614 L
.18703 .69911 L
.18434 .69642 L
.17731 .68939 L
.17731 .67968 L
.17463 .677 L
.1676 .66997 L
.1676 .66026 L
.16492 .65757 L
.15789 .65054 L
.15789 .64083 L
.15521 .63815 L
.14818 .63112 L
.14818 .62141 L
.14818 .61169 L
.14549 .60901 L
.13846 .60198 L
.13846 .59227 L
.13846 .58256 L
.13846 .57284 L
.13578 .57016 L
.12875 .56313 L
.12875 .55342 L
.12875 .54371 L
.12875 .53399 L
.12875 .52428 L
.12875 .51457 L
.12875 .50486 L
.12875 .49514 L
.12875 .48543 L
.12875 .47572 L
.12875 .46601 L
.12875 .45629 L
.12875 .44658 L
.12875 .43687 L
.13578 .42984 L
.13846 .42716 L
.13846 .41744 L
.13846 .40773 L
.13846 .39802 L
.14549 .39099 L
.14818 .38831 L
.14818 .37859 L
.14818 .36888 L
.15521 .36185 L
.15789 .35917 L
.15789 .34946 L
.16492 .34243 L
.1676 .33974 L
.1676 .33003 L
.17463 .323 L
.17731 .32032 L
.17731 .31061 L
.18434 .30358 L
.18703 .30089 L
.19406 .29386 L
.19674 .29118 L
.19674 .28147 L
.20377 .27444 L
.20645 .27176 L
.21348 .26473 L
.21616 .26204 L
.22319 .25501 L
.22588 .25233 L
.23291 .2453 L
.23559 .24262 L
.24262 .23559 L
.2453 .23291 L
.25233 .22588 L
.25501 .22319 L
.26204 .21616 L
.26473 .21348 L
.27176 .20645 L
.27444 .20377 L
.28147 .19674 L
.29118 .19674 L
.29386 .19406 L
.30089 .18703 L
.30358 .18434 L
.31061 .17731 L
.32032 .17731 L
.323 .17463 L
.33003 .1676 L
.33974 .1676 L
.34243 .16492 L
.34946 .15789 L
.35917 .15789 L
.36185 .15521 L
.36888 .14818 L
.37859 .14818 L
.38831 .14818 L
.39099 .14549 L
.39802 .13846 L
.40773 .13846 L
.41744 .13846 L
.42716 .13846 L
.42984 .13578 L
F
0 g
.43687 .12875 m
.44658 .12875 L
.45629 .12875 L
.46601 .12875 L
.47572 .12875 L
.48543 .12875 L
.49514 .12875 L
.50486 .12875 L
.51457 .12875 L
.52428 .12875 L
.53399 .12875 L
.54371 .12875 L
.55342 .12875 L
.56313 .12875 L
.57016 .13578 L
.57284 .13846 L
.58256 .13846 L
.59227 .13846 L
.60198 .13846 L
.60901 .14549 L
.61169 .14818 L
.62141 .14818 L
.63112 .14818 L
.63815 .15521 L
.64083 .15789 L
.65054 .15789 L
.65757 .16492 L
.66026 .1676 L
.66997 .1676 L
.677 .17463 L
.67968 .17731 L
.68939 .17731 L
.69642 .18434 L
.69911 .18703 L
.70614 .19406 L
.70882 .19674 L
.71853 .19674 L
.72556 .20377 L
.72824 .20645 L
.73527 .21348 L
.73796 .21616 L
.74499 .22319 L
.74767 .22588 L
.7547 .23291 L
.75738 .23559 L
.76441 .24262 L
.76709 .2453 L
.77412 .25233 L
.77681 .25501 L
.78384 .26204 L
Mistroke
.78652 .26473 L
.79355 .27176 L
.79623 .27444 L
.80326 .28147 L
.80326 .29118 L
.80594 .29386 L
.81297 .30089 L
.81566 .30358 L
.82269 .31061 L
.82269 .32032 L
.82537 .323 L
.8324 .33003 L
.8324 .33974 L
.83508 .34243 L
.84211 .34946 L
.84211 .35917 L
.84479 .36185 L
.85182 .36888 L
.85182 .37859 L
.85182 .38831 L
.85451 .39099 L
.86154 .39802 L
.86154 .40773 L
.86154 .41744 L
.86154 .42716 L
.86422 .42984 L
.87125 .43687 L
.87125 .44658 L
.87125 .45629 L
.87125 .46601 L
.87125 .47572 L
.87125 .48543 L
.87125 .49514 L
.87125 .50486 L
.87125 .51457 L
.87125 .52428 L
.87125 .53399 L
.87125 .54371 L
.87125 .55342 L
.87125 .56313 L
.86422 .57016 L
.86154 .57284 L
.86154 .58256 L
.86154 .59227 L
.86154 .60198 L
.85451 .60901 L
.85182 .61169 L
.85182 .62141 L
.85182 .63112 L
.84479 .63815 L
Mistroke
.84211 .64083 L
.84211 .65054 L
.83508 .65757 L
.8324 .66026 L
.8324 .66997 L
.82537 .677 L
.82269 .67968 L
.82269 .68939 L
.81566 .69642 L
.81297 .69911 L
.80594 .70614 L
.80326 .70882 L
.80326 .71853 L
.79623 .72556 L
.79355 .72824 L
.78652 .73527 L
.78384 .73796 L
.77681 .74499 L
.77412 .74767 L
.76709 .7547 L
.76477 .75738 L
.75738 .76441 L
.75 .75738 L
.74767 .7547 L
.74064 .74767 L
.73796 .74499 L
.73093 .73796 L
.72824 .73527 L
.72121 .72824 L
.71853 .72556 L
.7115 .71853 L
.70882 .71585 L
.70179 .70882 L
.69911 .70614 L
.69208 .69911 L
.68939 .69642 L
.68236 .68939 L
.67968 .68671 L
.67265 .67968 L
.66997 .677 L
.66294 .66997 L
.66026 .66729 L
.65323 .66026 L
.65054 .65757 L
.64351 .65054 L
.64083 .64786 L
.6338 .64083 L
.63112 .63815 L
.62409 .63112 L
.62141 .62844 L
Mistroke
.61438 .62141 L
.61169 .61872 L
.60466 .61169 L
.60198 .60901 L
.59495 .60198 L
.59227 .5993 L
.58524 .59227 L
.58256 .58959 L
.57553 .58256 L
.57284 .57987 L
.56581 .57284 L
.56313 .57016 L
.5561 .56313 L
.55342 .56045 L
.54639 .55342 L
.54371 .55074 L
.53668 .54371 L
.53399 .54102 L
.52696 .53399 L
.52428 .53131 L
.51725 .52428 L
.51457 .5216 L
.50754 .51457 L
.50486 .51189 L
.49514 .51189 L
.49246 .51457 L
.48543 .5216 L
.48275 .52428 L
.47572 .53131 L
.47304 .53399 L
.46601 .54102 L
.46332 .54371 L
.45629 .55074 L
.45361 .55342 L
.44658 .56045 L
.4439 .56313 L
.43687 .57016 L
.43419 .57284 L
.42716 .57987 L
.42447 .58256 L
.41744 .58959 L
.41476 .59227 L
.40773 .5993 L
.40505 .60198 L
.39802 .60901 L
.39534 .61169 L
.38831 .61872 L
.38562 .62141 L
.37859 .62844 L
.37591 .63112 L
Mistroke
.36888 .63815 L
.3662 .64083 L
.35917 .64786 L
.35649 .65054 L
.34946 .65757 L
.34677 .66026 L
.33974 .66729 L
.33706 .66997 L
.33003 .677 L
.32735 .67968 L
.32032 .68671 L
.31764 .68939 L
.31061 .69642 L
.30792 .69911 L
.30089 .70614 L
.29821 .70882 L
.29118 .71585 L
.2885 .71853 L
.28147 .72556 L
.27879 .72824 L
.27176 .73527 L
.26907 .73796 L
.26204 .74499 L
.25936 .74767 L
.25233 .7547 L
.25 .75738 L
.24262 .76441 L
.23523 .75738 L
.23291 .7547 L
.22588 .74767 L
.22319 .74499 L
.21616 .73796 L
.21348 .73527 L
.20645 .72824 L
.20377 .72556 L
.19674 .71853 L
.19674 .70882 L
.19406 .70614 L
.18703 .69911 L
.18434 .69642 L
.17731 .68939 L
.17731 .67968 L
.17463 .677 L
.1676 .66997 L
.1676 .66026 L
.16492 .65757 L
.15789 .65054 L
.15789 .64083 L
.15521 .63815 L
.14818 .63112 L
Mistroke
.14818 .62141 L
.14818 .61169 L
.14549 .60901 L
.13846 .60198 L
.13846 .59227 L
.13846 .58256 L
.13846 .57284 L
.13578 .57016 L
.12875 .56313 L
.12875 .55342 L
.12875 .54371 L
.12875 .53399 L
.12875 .52428 L
.12875 .51457 L
.12875 .50486 L
.12875 .49514 L
.12875 .48543 L
.12875 .47572 L
.12875 .46601 L
.12875 .45629 L
.12875 .44658 L
.12875 .43687 L
.13578 .42984 L
.13846 .42716 L
.13846 .41744 L
.13846 .40773 L
.13846 .39802 L
.14549 .39099 L
.14818 .38831 L
.14818 .37859 L
.14818 .36888 L
.15521 .36185 L
.15789 .35917 L
.15789 .34946 L
.16492 .34243 L
.1676 .33974 L
.1676 .33003 L
.17463 .323 L
.17731 .32032 L
.17731 .31061 L
.18434 .30358 L
.18703 .30089 L
.19406 .29386 L
.19674 .29118 L
.19674 .28147 L
.20377 .27444 L
.20645 .27176 L
.21348 .26473 L
.21616 .26204 L
.22319 .25501 L
Mistroke
.22588 .25233 L
.23291 .2453 L
.23559 .24262 L
.24262 .23559 L
.2453 .23291 L
.25233 .22588 L
.25501 .22319 L
.26204 .21616 L
.26473 .21348 L
.27176 .20645 L
.27444 .20377 L
.28147 .19674 L
.29118 .19674 L
.29386 .19406 L
.30089 .18703 L
.30358 .18434 L
.31061 .17731 L
.32032 .17731 L
.323 .17463 L
.33003 .1676 L
.33974 .1676 L
.34243 .16492 L
.34946 .15789 L
.35917 .15789 L
.36185 .15521 L
.36888 .14818 L
.37859 .14818 L
.38831 .14818 L
.39099 .14549 L
.39802 .13846 L
.40773 .13846 L
.41744 .13846 L
.42716 .13846 L
.42984 .13578 L
.43687 .12875 L
Mfstroke
.4 g
.43687 .12963 m
.44658 .12963 L
.45629 .12963 L
.46601 .12963 L
.47572 .12963 L
.48543 .12963 L
.49514 .12963 L
.50486 .12963 L
.51457 .12963 L
.52428 .12963 L
.53399 .12963 L
.54371 .12963 L
.55342 .12963 L
.56313 .12963 L
.56928 .13578 L
.57284 .13935 L
.58256 .13935 L
.59227 .13935 L
.60198 .13935 L
.60813 .14549 L
.61169 .14906 L
.62141 .14906 L
.63112 .14906 L
.63727 .15521 L
.64083 .15877 L
.65054 .15877 L
.65669 .16492 L
.66026 .16848 L
.66997 .16848 L
.67612 .17463 L
.67968 .1782 L
.68939 .1782 L
.69554 .18434 L
.69911 .18791 L
.70525 .19406 L
.70882 .19762 L
.71853 .19762 L
.72468 .20377 L
.72824 .20733 L
.73439 .21348 L
.73796 .21705 L
.7441 .22319 L
.74767 .22676 L
.75382 .23291 L
.75738 .23647 L
.76353 .24262 L
.76709 .24618 L
.77324 .25233 L
.77681 .2559 L
.78295 .26204 L
.78652 .26561 L
.79267 .27176 L
.79623 .27532 L
.80238 .28147 L
.80238 .29118 L
.80594 .29475 L
.81209 .30089 L
.81566 .30446 L
.8218 .31061 L
.8218 .32032 L
.82537 .32388 L
.83152 .33003 L
.83152 .33974 L
.83508 .34331 L
.84123 .34946 L
.84123 .35917 L
.84479 .36273 L
.85094 .36888 L
.85094 .37859 L
.85094 .38831 L
.85451 .39187 L
.86065 .39802 L
.86065 .40773 L
.86065 .41744 L
.86065 .42716 L
.86422 .43072 L
.87037 .43687 L
.87037 .44658 L
.87037 .45629 L
.87037 .46601 L
.87037 .47572 L
.87037 .48543 L
.87037 .49514 L
.87037 .50486 L
.87037 .51457 L
.87037 .52428 L
.87037 .53399 L
.87037 .54371 L
.87037 .55342 L
.87037 .56313 L
.86422 .56928 L
.86065 .57284 L
.86065 .58256 L
.86065 .59227 L
.86065 .60198 L
.85451 .60813 L
.85094 .61169 L
.85094 .62141 L
.85094 .63112 L
.84479 .63727 L
.84123 .64083 L
.84123 .65054 L
.83508 .65669 L
.83152 .66026 L
.83152 .66997 L
.82537 .67612 L
.8218 .67968 L
.8218 .68939 L
.81566 .69554 L
.81209 .69911 L
.80594 .70525 L
.80238 .70882 L
.80238 .71853 L
.79623 .72468 L
.79267 .72824 L
.78652 .73439 L
.78295 .73796 L
.77681 .7441 L
.77324 .74767 L
.76709 .75382 L
.76397 .75738 L
.75738 .76353 L
.75079 .75738 L
.74767 .75382 L
.74152 .74767 L
.73796 .7441 L
.73181 .73796 L
.72824 .73439 L
.7221 .72824 L
.71853 .72468 L
.71238 .71853 L
.70882 .71497 L
.70267 .70882 L
.69911 .70525 L
.69296 .69911 L
.68939 .69554 L
.68325 .68939 L
.67968 .68583 L
.67353 .67968 L
.66997 .67612 L
.66382 .66997 L
.66026 .6664 L
.65411 .66026 L
.65054 .65669 L
.6444 .65054 L
.64083 .64698 L
.63468 .64083 L
.63112 .63727 L
.62497 .63112 L
.62141 .62755 L
.61526 .62141 L
.61169 .61784 L
.60555 .61169 L
.60198 .60813 L
.59583 .60198 L
.59227 .59842 L
.58612 .59227 L
.58256 .5887 L
.57641 .58256 L
.57284 .57899 L
.5667 .57284 L
.56313 .56928 L
.55698 .56313 L
.55342 .55957 L
.54727 .55342 L
.54371 .54985 L
.53756 .54371 L
.53399 .54014 L
.52785 .53399 L
.52428 .53043 L
.51813 .52428 L
.51457 .52072 L
.50842 .51457 L
.50486 .511 L
.49514 .511 L
.49158 .51457 L
.48543 .52072 L
.48187 .52428 L
.47572 .53043 L
.47215 .53399 L
.46601 .54014 L
.46244 .54371 L
.45629 .54985 L
.45273 .55342 L
.44658 .55957 L
.44302 .56313 L
.43687 .56928 L
.4333 .57284 L
.42716 .57899 L
.42359 .58256 L
.41744 .5887 L
.41388 .59227 L
.40773 .59842 L
.40417 .60198 L
.39802 .60813 L
.39445 .61169 L
.38831 .61784 L
.38474 .62141 L
.37859 .62755 L
.37503 .63112 L
.36888 .63727 L
.36532 .64083 L
.35917 .64698 L
.3556 .65054 L
.34946 .65669 L
.34589 .66026 L
.33974 .6664 L
.33618 .66997 L
.33003 .67612 L
.32647 .67968 L
.32032 .68583 L
.31675 .68939 L
.31061 .69554 L
.30704 .69911 L
.30089 .70525 L
.29733 .70882 L
.29118 .71497 L
.28762 .71853 L
.28147 .72468 L
.2779 .72824 L
.27176 .73439 L
.26819 .73796 L
.26204 .7441 L
.25848 .74767 L
.25233 .75382 L
.24921 .75738 L
.24262 .76353 L
.23603 .75738 L
.23291 .75382 L
.22676 .74767 L
.22319 .7441 L
.21705 .73796 L
.21348 .73439 L
.20733 .72824 L
.20377 .72468 L
.19762 .71853 L
.19762 .70882 L
.19406 .70525 L
.18791 .69911 L
.18434 .69554 L
.1782 .68939 L
.1782 .67968 L
.17463 .67612 L
.16848 .66997 L
.16848 .66026 L
.16492 .65669 L
.15877 .65054 L
.15877 .64083 L
.15521 .63727 L
.14906 .63112 L
.14906 .62141 L
.14906 .61169 L
.14549 .60813 L
.13935 .60198 L
.13935 .59227 L
.13935 .58256 L
.13935 .57284 L
.13578 .56928 L
.12963 .56313 L
.12963 .55342 L
.12963 .54371 L
.12963 .53399 L
.12963 .52428 L
.12963 .51457 L
.12963 .50486 L
.12963 .49514 L
.12963 .48543 L
.12963 .47572 L
.12963 .46601 L
.12963 .45629 L
.12963 .44658 L
.12963 .43687 L
.13578 .43072 L
.13935 .42716 L
.13935 .41744 L
.13935 .40773 L
.13935 .39802 L
.14549 .39187 L
.14906 .38831 L
.14906 .37859 L
.14906 .36888 L
.15521 .36273 L
.15877 .35917 L
.15877 .34946 L
.16492 .34331 L
.16848 .33974 L
.16848 .33003 L
.17463 .32388 L
.1782 .32032 L
.1782 .31061 L
.18434 .30446 L
.18791 .30089 L
.19406 .29475 L
.19762 .29118 L
.19762 .28147 L
.20377 .27532 L
.20733 .27176 L
.21348 .26561 L
.21705 .26204 L
.22319 .2559 L
.22676 .25233 L
.23291 .24618 L
.23647 .24262 L
.24262 .23647 L
.24618 .23291 L
.25233 .22676 L
.2559 .22319 L
.26204 .21705 L
.26561 .21348 L
.27176 .20733 L
.27532 .20377 L
.28147 .19762 L
.29118 .19762 L
.29475 .19406 L
.30089 .18791 L
.30446 .18434 L
.31061 .1782 L
.32032 .1782 L
.32388 .17463 L
.33003 .16848 L
.33974 .16848 L
.34331 .16492 L
.34946 .15877 L
.35917 .15877 L
.36273 .15521 L
.36888 .14906 L
.37859 .14906 L
.38831 .14906 L
.39187 .14549 L
.39802 .13935 L
.40773 .13935 L
.41744 .13935 L
.42716 .13935 L
.43072 .13578 L
F
0 g
.43687 .12963 m
.44658 .12963 L
.45629 .12963 L
.46601 .12963 L
.47572 .12963 L
.48543 .12963 L
.49514 .12963 L
.50486 .12963 L
.51457 .12963 L
.52428 .12963 L
.53399 .12963 L
.54371 .12963 L
.55342 .12963 L
.56313 .12963 L
.56928 .13578 L
.57284 .13935 L
.58256 .13935 L
.59227 .13935 L
.60198 .13935 L
.60813 .14549 L
.61169 .14906 L
.62141 .14906 L
.63112 .14906 L
.63727 .15521 L
.64083 .15877 L
.65054 .15877 L
.65669 .16492 L
.66026 .16848 L
.66997 .16848 L
.67612 .17463 L
.67968 .1782 L
.68939 .1782 L
.69554 .18434 L
.69911 .18791 L
.70525 .19406 L
.70882 .19762 L
.71853 .19762 L
.72468 .20377 L
.72824 .20733 L
.73439 .21348 L
.73796 .21705 L
.7441 .22319 L
.74767 .22676 L
.75382 .23291 L
.75738 .23647 L
.76353 .24262 L
.76709 .24618 L
.77324 .25233 L
.77681 .2559 L
.78295 .26204 L
Mistroke
.78652 .26561 L
.79267 .27176 L
.79623 .27532 L
.80238 .28147 L
.80238 .29118 L
.80594 .29475 L
.81209 .30089 L
.81566 .30446 L
.8218 .31061 L
.8218 .32032 L
.82537 .32388 L
.83152 .33003 L
.83152 .33974 L
.83508 .34331 L
.84123 .34946 L
.84123 .35917 L
.84479 .36273 L
.85094 .36888 L
.85094 .37859 L
.85094 .38831 L
.85451 .39187 L
.86065 .39802 L
.86065 .40773 L
.86065 .41744 L
.86065 .42716 L
.86422 .43072 L
.87037 .43687 L
.87037 .44658 L
.87037 .45629 L
.87037 .46601 L
.87037 .47572 L
.87037 .48543 L
.87037 .49514 L
.87037 .50486 L
.87037 .51457 L
.87037 .52428 L
.87037 .53399 L
.87037 .54371 L
.87037 .55342 L
.87037 .56313 L
.86422 .56928 L
.86065 .57284 L
.86065 .58256 L
.86065 .59227 L
.86065 .60198 L
.85451 .60813 L
.85094 .61169 L
.85094 .62141 L
.85094 .63112 L
.84479 .63727 L
Mistroke
.84123 .64083 L
.84123 .65054 L
.83508 .65669 L
.83152 .66026 L
.83152 .66997 L
.82537 .67612 L
.8218 .67968 L
.8218 .68939 L
.81566 .69554 L
.81209 .69911 L
.80594 .70525 L
.80238 .70882 L
.80238 .71853 L
.79623 .72468 L
.79267 .72824 L
.78652 .73439 L
.78295 .73796 L
.77681 .7441 L
.77324 .74767 L
.76709 .75382 L
.76397 .75738 L
.75738 .76353 L
.75079 .75738 L
.74767 .75382 L
.74152 .74767 L
.73796 .7441 L
.73181 .73796 L
.72824 .73439 L
.7221 .72824 L
.71853 .72468 L
.71238 .71853 L
.70882 .71497 L
.70267 .70882 L
.69911 .70525 L
.69296 .69911 L
.68939 .69554 L
.68325 .68939 L
.67968 .68583 L
.67353 .67968 L
.66997 .67612 L
.66382 .66997 L
.66026 .6664 L
.65411 .66026 L
.65054 .65669 L
.6444 .65054 L
.64083 .64698 L
.63468 .64083 L
.63112 .63727 L
.62497 .63112 L
.62141 .62755 L
Mistroke
.61526 .62141 L
.61169 .61784 L
.60555 .61169 L
.60198 .60813 L
.59583 .60198 L
.59227 .59842 L
.58612 .59227 L
.58256 .5887 L
.57641 .58256 L
.57284 .57899 L
.5667 .57284 L
.56313 .56928 L
.55698 .56313 L
.55342 .55957 L
.54727 .55342 L
.54371 .54985 L
.53756 .54371 L
.53399 .54014 L
.52785 .53399 L
.52428 .53043 L
.51813 .52428 L
.51457 .52072 L
.50842 .51457 L
.50486 .511 L
.49514 .511 L
.49158 .51457 L
.48543 .52072 L
.48187 .52428 L
.47572 .53043 L
.47215 .53399 L
.46601 .54014 L
.46244 .54371 L
.45629 .54985 L
.45273 .55342 L
.44658 .55957 L
.44302 .56313 L
.43687 .56928 L
.4333 .57284 L
.42716 .57899 L
.42359 .58256 L
.41744 .5887 L
.41388 .59227 L
.40773 .59842 L
.40417 .60198 L
.39802 .60813 L
.39445 .61169 L
.38831 .61784 L
.38474 .62141 L
.37859 .62755 L
.37503 .63112 L
Mistroke
.36888 .63727 L
.36532 .64083 L
.35917 .64698 L
.3556 .65054 L
.34946 .65669 L
.34589 .66026 L
.33974 .6664 L
.33618 .66997 L
.33003 .67612 L
.32647 .67968 L
.32032 .68583 L
.31675 .68939 L
.31061 .69554 L
.30704 .69911 L
.30089 .70525 L
.29733 .70882 L
.29118 .71497 L
.28762 .71853 L
.28147 .72468 L
.2779 .72824 L
.27176 .73439 L
.26819 .73796 L
.26204 .7441 L
.25848 .74767 L
.25233 .75382 L
.24921 .75738 L
.24262 .76353 L
.23603 .75738 L
.23291 .75382 L
.22676 .74767 L
.22319 .7441 L
.21705 .73796 L
.21348 .73439 L
.20733 .72824 L
.20377 .72468 L
.19762 .71853 L
.19762 .70882 L
.19406 .70525 L
.18791 .69911 L
.18434 .69554 L
.1782 .68939 L
.1782 .67968 L
.17463 .67612 L
.16848 .66997 L
.16848 .66026 L
.16492 .65669 L
.15877 .65054 L
.15877 .64083 L
.15521 .63727 L
.14906 .63112 L
Mistroke
.14906 .62141 L
.14906 .61169 L
.14549 .60813 L
.13935 .60198 L
.13935 .59227 L
.13935 .58256 L
.13935 .57284 L
.13578 .56928 L
.12963 .56313 L
.12963 .55342 L
.12963 .54371 L
.12963 .53399 L
.12963 .52428 L
.12963 .51457 L
.12963 .50486 L
.12963 .49514 L
.12963 .48543 L
.12963 .47572 L
.12963 .46601 L
.12963 .45629 L
.12963 .44658 L
.12963 .43687 L
.13578 .43072 L
.13935 .42716 L
.13935 .41744 L
.13935 .40773 L
.13935 .39802 L
.14549 .39187 L
.14906 .38831 L
.14906 .37859 L
.14906 .36888 L
.15521 .36273 L
.15877 .35917 L
.15877 .34946 L
.16492 .34331 L
.16848 .33974 L
.16848 .33003 L
.17463 .32388 L
.1782 .32032 L
.1782 .31061 L
.18434 .30446 L
.18791 .30089 L
.19406 .29475 L
.19762 .29118 L
.19762 .28147 L
.20377 .27532 L
.20733 .27176 L
.21348 .26561 L
.21705 .26204 L
.22319 .2559 L
Mistroke
.22676 .25233 L
.23291 .24618 L
.23647 .24262 L
.24262 .23647 L
.24618 .23291 L
.25233 .22676 L
.2559 .22319 L
.26204 .21705 L
.26561 .21348 L
.27176 .20733 L
.27532 .20377 L
.28147 .19762 L
.29118 .19762 L
.29475 .19406 L
.30089 .18791 L
.30446 .18434 L
.31061 .1782 L
.32032 .1782 L
.32388 .17463 L
.33003 .16848 L
.33974 .16848 L
.34331 .16492 L
.34946 .15877 L
.35917 .15877 L
.36273 .15521 L
.36888 .14906 L
.37859 .14906 L
.38831 .14906 L
.39187 .14549 L
.39802 .13935 L
.40773 .13935 L
.41744 .13935 L
.42716 .13935 L
.43072 .13578 L
.43687 .12963 L
Mfstroke
.5 g
.43687 .1305 m
.44658 .1305 L
.45629 .1305 L
.46601 .1305 L
.47572 .1305 L
.48543 .1305 L
.49514 .1305 L
.50486 .1305 L
.51457 .1305 L
.52428 .1305 L
.53399 .1305 L
.54371 .1305 L
.55342 .1305 L
.56313 .1305 L
.56842 .13578 L
.57284 .14021 L
.58256 .14021 L
.59227 .14021 L
.60198 .14021 L
.60727 .14549 L
.61169 .14992 L
.62141 .14992 L
.63112 .14992 L
.6364 .15521 L
.64083 .15963 L
.65054 .15963 L
.65583 .16492 L
.66026 .16935 L
.66997 .16935 L
.67525 .17463 L
.67968 .17906 L
.68939 .17906 L
.69468 .18434 L
.69911 .18877 L
.70439 .19406 L
.70882 .19848 L
.71853 .19848 L
.72382 .20377 L
.72824 .2082 L
.73353 .21348 L
.73796 .21791 L
.74324 .22319 L
.74767 .22762 L
.75295 .23291 L
.75738 .23733 L
.76267 .24262 L
.76709 .24705 L
.77238 .25233 L
.77681 .25676 L
.78209 .26204 L
.78652 .26647 L
.7918 .27176 L
.79623 .27618 L
.80152 .28147 L
.80152 .29118 L
.80594 .29561 L
.81123 .30089 L
.81566 .30532 L
.82094 .31061 L
.82094 .32032 L
.82537 .32475 L
.83065 .33003 L
.83065 .33974 L
.83508 .34417 L
.84037 .34946 L
.84037 .35917 L
.84479 .3636 L
.85008 .36888 L
.85008 .37859 L
.85008 .38831 L
.85451 .39273 L
.85979 .39802 L
.85979 .40773 L
.85979 .41744 L
.85979 .42716 L
.86422 .43158 L
.8695 .43687 L
.8695 .44658 L
.8695 .45629 L
.8695 .46601 L
.8695 .47572 L
.8695 .48543 L
.8695 .49514 L
.8695 .50486 L
.8695 .51457 L
.8695 .52428 L
.8695 .53399 L
.8695 .54371 L
.8695 .55342 L
.8695 .56313 L
.86422 .56842 L
.85979 .57284 L
.85979 .58256 L
.85979 .59227 L
.85979 .60198 L
.85451 .60727 L
.85008 .61169 L
.85008 .62141 L
.85008 .63112 L
.84479 .6364 L
.84037 .64083 L
.84037 .65054 L
.83508 .65583 L
.83065 .66026 L
.83065 .66997 L
.82537 .67525 L
.82094 .67968 L
.82094 .68939 L
.81566 .69468 L
.81123 .69911 L
.80594 .70439 L
.80152 .70882 L
.80152 .71853 L
.79623 .72382 L
.7918 .72824 L
.78652 .73353 L
.78209 .73796 L
.77681 .74324 L
.77238 .74767 L
.76709 .75295 L
.76317 .75738 L
.75738 .76267 L
.75159 .75738 L
.74767 .75295 L
.74238 .74767 L
.73796 .74324 L
.73267 .73796 L
.72824 .73353 L
.72296 .72824 L
.71853 .72382 L
.71325 .71853 L
.70882 .7141 L
.70353 .70882 L
.69911 .70439 L
.69382 .69911 L
.68939 .69468 L
.68411 .68939 L
.67968 .68497 L
.6744 .67968 L
.66997 .67525 L
.66468 .66997 L
.66026 .66554 L
.65497 .66026 L
.65054 .65583 L
.64526 .65054 L
.64083 .64612 L
.63555 .64083 L
.63112 .6364 L
.62583 .63112 L
.62141 .62669 L
.61612 .62141 L
.61169 .61698 L
.60641 .61169 L
.60198 .60727 L
.5967 .60198 L
.59227 .59755 L
.58698 .59227 L
.58256 .58784 L
.57727 .58256 L
.57284 .57813 L
.56756 .57284 L
.56313 .56842 L
.55785 .56313 L
.55342 .5587 L
.54813 .55342 L
.54371 .54899 L
.53842 .54371 L
.53399 .53928 L
.52871 .53399 L
.52428 .52957 L
.519 .52428 L
.51457 .51985 L
.50928 .51457 L
.50486 .51014 L
.49514 .51014 L
.49072 .51457 L
.48543 .51985 L
.481 .52428 L
.47572 .52957 L
.47129 .53399 L
.46601 .53928 L
.46158 .54371 L
.45629 .54899 L
.45187 .55342 L
.44658 .5587 L
.44215 .56313 L
.43687 .56842 L
.43244 .57284 L
.42716 .57813 L
.42273 .58256 L
.41744 .58784 L
.41302 .59227 L
.40773 .59755 L
.4033 .60198 L
.39802 .60727 L
.39359 .61169 L
.38831 .61698 L
.38388 .62141 L
.37859 .62669 L
.37417 .63112 L
.36888 .6364 L
.36445 .64083 L
.35917 .64612 L
.35474 .65054 L
.34946 .65583 L
.34503 .66026 L
.33974 .66554 L
.33532 .66997 L
.33003 .67525 L
.3256 .67968 L
.32032 .68497 L
.31589 .68939 L
.31061 .69468 L
.30618 .69911 L
.30089 .70439 L
.29647 .70882 L
.29118 .7141 L
.28675 .71853 L
.28147 .72382 L
.27704 .72824 L
.27176 .73353 L
.26733 .73796 L
.26204 .74324 L
.25762 .74767 L
.25233 .75295 L
.24841 .75738 L
.24262 .76267 L
.23683 .75738 L
.23291 .75295 L
.22762 .74767 L
.22319 .74324 L
.21791 .73796 L
.21348 .73353 L
.2082 .72824 L
.20377 .72382 L
.19848 .71853 L
.19848 .70882 L
.19406 .70439 L
.18877 .69911 L
.18434 .69468 L
.17906 .68939 L
.17906 .67968 L
.17463 .67525 L
.16935 .66997 L
.16935 .66026 L
.16492 .65583 L
.15963 .65054 L
.15963 .64083 L
.15521 .6364 L
.14992 .63112 L
.14992 .62141 L
.14992 .61169 L
.14549 .60727 L
.14021 .60198 L
.14021 .59227 L
.14021 .58256 L
.14021 .57284 L
.13578 .56842 L
.1305 .56313 L
.1305 .55342 L
.1305 .54371 L
.1305 .53399 L
.1305 .52428 L
.1305 .51457 L
.1305 .50486 L
.1305 .49514 L
.1305 .48543 L
.1305 .47572 L
.1305 .46601 L
.1305 .45629 L
.1305 .44658 L
.1305 .43687 L
.13578 .43158 L
.14021 .42716 L
.14021 .41744 L
.14021 .40773 L
.14021 .39802 L
.14549 .39273 L
.14992 .38831 L
.14992 .37859 L
.14992 .36888 L
.15521 .3636 L
.15963 .35917 L
.15963 .34946 L
.16492 .34417 L
.16935 .33974 L
.16935 .33003 L
.17463 .32475 L
.17906 .32032 L
.17906 .31061 L
.18434 .30532 L
.18877 .30089 L
.19406 .29561 L
.19848 .29118 L
.19848 .28147 L
.20377 .27618 L
.2082 .27176 L
.21348 .26647 L
.21791 .26204 L
.22319 .25676 L
.22762 .25233 L
.23291 .24705 L
.23733 .24262 L
.24262 .23733 L
.24705 .23291 L
.25233 .22762 L
.25676 .22319 L
.26204 .21791 L
.26647 .21348 L
.27176 .2082 L
.27618 .20377 L
.28147 .19848 L
.29118 .19848 L
.29561 .19406 L
.30089 .18877 L
.30532 .18434 L
.31061 .17906 L
.32032 .17906 L
.32475 .17463 L
.33003 .16935 L
.33974 .16935 L
.34417 .16492 L
.34946 .15963 L
.35917 .15963 L
.3636 .15521 L
.36888 .14992 L
.37859 .14992 L
.38831 .14992 L
.39273 .14549 L
.39802 .14021 L
.40773 .14021 L
.41744 .14021 L
.42716 .14021 L
.43158 .13578 L
F
0 g
.43687 .1305 m
.44658 .1305 L
.45629 .1305 L
.46601 .1305 L
.47572 .1305 L
.48543 .1305 L
.49514 .1305 L
.50486 .1305 L
.51457 .1305 L
.52428 .1305 L
.53399 .1305 L
.54371 .1305 L
.55342 .1305 L
.56313 .1305 L
.56842 .13578 L
.57284 .14021 L
.58256 .14021 L
.59227 .14021 L
.60198 .14021 L
.60727 .14549 L
.61169 .14992 L
.62141 .14992 L
.63112 .14992 L
.6364 .15521 L
.64083 .15963 L
.65054 .15963 L
.65583 .16492 L
.66026 .16935 L
.66997 .16935 L
.67525 .17463 L
.67968 .17906 L
.68939 .17906 L
.69468 .18434 L
.69911 .18877 L
.70439 .19406 L
.70882 .19848 L
.71853 .19848 L
.72382 .20377 L
.72824 .2082 L
.73353 .21348 L
.73796 .21791 L
.74324 .22319 L
.74767 .22762 L
.75295 .23291 L
.75738 .23733 L
.76267 .24262 L
.76709 .24705 L
.77238 .25233 L
.77681 .25676 L
.78209 .26204 L
Mistroke
.78652 .26647 L
.7918 .27176 L
.79623 .27618 L
.80152 .28147 L
.80152 .29118 L
.80594 .29561 L
.81123 .30089 L
.81566 .30532 L
.82094 .31061 L
.82094 .32032 L
.82537 .32475 L
.83065 .33003 L
.83065 .33974 L
.83508 .34417 L
.84037 .34946 L
.84037 .35917 L
.84479 .3636 L
.85008 .36888 L
.85008 .37859 L
.85008 .38831 L
.85451 .39273 L
.85979 .39802 L
.85979 .40773 L
.85979 .41744 L
.85979 .42716 L
.86422 .43158 L
.8695 .43687 L
.8695 .44658 L
.8695 .45629 L
.8695 .46601 L
.8695 .47572 L
.8695 .48543 L
.8695 .49514 L
.8695 .50486 L
.8695 .51457 L
.8695 .52428 L
.8695 .53399 L
.8695 .54371 L
.8695 .55342 L
.8695 .56313 L
.86422 .56842 L
.85979 .57284 L
.85979 .58256 L
.85979 .59227 L
.85979 .60198 L
.85451 .60727 L
.85008 .61169 L
.85008 .62141 L
.85008 .63112 L
.84479 .6364 L
Mistroke
.84037 .64083 L
.84037 .65054 L
.83508 .65583 L
.83065 .66026 L
.83065 .66997 L
.82537 .67525 L
.82094 .67968 L
.82094 .68939 L
.81566 .69468 L
.81123 .69911 L
.80594 .70439 L
.80152 .70882 L
.80152 .71853 L
.79623 .72382 L
.7918 .72824 L
.78652 .73353 L
.78209 .73796 L
.77681 .74324 L
.77238 .74767 L
.76709 .75295 L
.76317 .75738 L
.75738 .76267 L
.75159 .75738 L
.74767 .75295 L
.74238 .74767 L
.73796 .74324 L
.73267 .73796 L
.72824 .73353 L
.72296 .72824 L
.71853 .72382 L
.71325 .71853 L
.70882 .7141 L
.70353 .70882 L
.69911 .70439 L
.69382 .69911 L
.68939 .69468 L
.68411 .68939 L
.67968 .68497 L
.6744 .67968 L
.66997 .67525 L
.66468 .66997 L
.66026 .66554 L
.65497 .66026 L
.65054 .65583 L
.64526 .65054 L
.64083 .64612 L
.63555 .64083 L
.63112 .6364 L
.62583 .63112 L
.62141 .62669 L
Mistroke
.61612 .62141 L
.61169 .61698 L
.60641 .61169 L
.60198 .60727 L
.5967 .60198 L
.59227 .59755 L
.58698 .59227 L
.58256 .58784 L
.57727 .58256 L
.57284 .57813 L
.56756 .57284 L
.56313 .56842 L
.55785 .56313 L
.55342 .5587 L
.54813 .55342 L
.54371 .54899 L
.53842 .54371 L
.53399 .53928 L
.52871 .53399 L
.52428 .52957 L
.519 .52428 L
.51457 .51985 L
.50928 .51457 L
.50486 .51014 L
.49514 .51014 L
.49072 .51457 L
.48543 .51985 L
.481 .52428 L
.47572 .52957 L
.47129 .53399 L
.46601 .53928 L
.46158 .54371 L
.45629 .54899 L
.45187 .55342 L
.44658 .5587 L
.44215 .56313 L
.43687 .56842 L
.43244 .57284 L
.42716 .57813 L
.42273 .58256 L
.41744 .58784 L
.41302 .59227 L
.40773 .59755 L
.4033 .60198 L
.39802 .60727 L
.39359 .61169 L
.38831 .61698 L
.38388 .62141 L
.37859 .62669 L
.37417 .63112 L
Mistroke
.36888 .6364 L
.36445 .64083 L
.35917 .64612 L
.35474 .65054 L
.34946 .65583 L
.34503 .66026 L
.33974 .66554 L
.33532 .66997 L
.33003 .67525 L
.3256 .67968 L
.32032 .68497 L
.31589 .68939 L
.31061 .69468 L
.30618 .69911 L
.30089 .70439 L
.29647 .70882 L
.29118 .7141 L
.28675 .71853 L
.28147 .72382 L
.27704 .72824 L
.27176 .73353 L
.26733 .73796 L
.26204 .74324 L
.25762 .74767 L
.25233 .75295 L
.24841 .75738 L
.24262 .76267 L
.23683 .75738 L
.23291 .75295 L
.22762 .74767 L
.22319 .74324 L
.21791 .73796 L
.21348 .73353 L
.2082 .72824 L
.20377 .72382 L
.19848 .71853 L
.19848 .70882 L
.19406 .70439 L
.18877 .69911 L
.18434 .69468 L
.17906 .68939 L
.17906 .67968 L
.17463 .67525 L
.16935 .66997 L
.16935 .66026 L
.16492 .65583 L
.15963 .65054 L
.15963 .64083 L
.15521 .6364 L
.14992 .63112 L
Mistroke
.14992 .62141 L
.14992 .61169 L
.14549 .60727 L
.14021 .60198 L
.14021 .59227 L
.14021 .58256 L
.14021 .57284 L
.13578 .56842 L
.1305 .56313 L
.1305 .55342 L
.1305 .54371 L
.1305 .53399 L
.1305 .52428 L
.1305 .51457 L
.1305 .50486 L
.1305 .49514 L
.1305 .48543 L
.1305 .47572 L
.1305 .46601 L
.1305 .45629 L
.1305 .44658 L
.1305 .43687 L
.13578 .43158 L
.14021 .42716 L
.14021 .41744 L
.14021 .40773 L
.14021 .39802 L
.14549 .39273 L
.14992 .38831 L
.14992 .37859 L
.14992 .36888 L
.15521 .3636 L
.15963 .35917 L
.15963 .34946 L
.16492 .34417 L
.16935 .33974 L
.16935 .33003 L
.17463 .32475 L
.17906 .32032 L
.17906 .31061 L
.18434 .30532 L
.18877 .30089 L
.19406 .29561 L
.19848 .29118 L
.19848 .28147 L
.20377 .27618 L
.2082 .27176 L
.21348 .26647 L
.21791 .26204 L
.22319 .25676 L
Mistroke
.22762 .25233 L
.23291 .24705 L
.23733 .24262 L
.24262 .23733 L
.24705 .23291 L
.25233 .22762 L
.25676 .22319 L
.26204 .21791 L
.26647 .21348 L
.27176 .2082 L
.27618 .20377 L
.28147 .19848 L
.29118 .19848 L
.29561 .19406 L
.30089 .18877 L
.30532 .18434 L
.31061 .17906 L
.32032 .17906 L
.32475 .17463 L
.33003 .16935 L
.33974 .16935 L
.34417 .16492 L
.34946 .15963 L
.35917 .15963 L
.3636 .15521 L
.36888 .14992 L
.37859 .14992 L
.38831 .14992 L
.39273 .14549 L
.39802 .14021 L
.40773 .14021 L
.41744 .14021 L
.42716 .14021 L
.43158 .13578 L
.43687 .1305 L
Mfstroke
.6 g
.43687 .13135 m
.44658 .13135 L
.45629 .13135 L
.46601 .13135 L
.47572 .13135 L
.48543 .13135 L
.49514 .13135 L
.50486 .13135 L
.51457 .13135 L
.52428 .13135 L
.53399 .13135 L
.54371 .13135 L
.55342 .13135 L
.56313 .13135 L
.56756 .13578 L
.57284 .14107 L
.58256 .14107 L
.59227 .14107 L
.60198 .14107 L
.60641 .14549 L
.61169 .15078 L
.62141 .15078 L
.63112 .15078 L
.63555 .15521 L
.64083 .16049 L
.65054 .16049 L
.65497 .16492 L
.66026 .1702 L
.66997 .1702 L
.6744 .17463 L
.67968 .17992 L
.68939 .17992 L
.69382 .18434 L
.69911 .18963 L
.70353 .19406 L
.70882 .19934 L
.71853 .19934 L
.72296 .20377 L
.72824 .20905 L
.73267 .21348 L
.73796 .21877 L
.74238 .22319 L
.74767 .22848 L
.7521 .23291 L
.75738 .23819 L
.76181 .24262 L
.76709 .2479 L
.77152 .25233 L
.77681 .25762 L
.78123 .26204 L
.78652 .26733 L
.79095 .27176 L
.79623 .27704 L
.80066 .28147 L
.80066 .29118 L
.80594 .29647 L
.81037 .30089 L
.81566 .30618 L
.82008 .31061 L
.82008 .32032 L
.82537 .3256 L
.8298 .33003 L
.8298 .33974 L
.83508 .34503 L
.83951 .34946 L
.83951 .35917 L
.84479 .36445 L
.84922 .36888 L
.84922 .37859 L
.84922 .38831 L
.85451 .39359 L
.85893 .39802 L
.85893 .40773 L
.85893 .41744 L
.85893 .42716 L
.86422 .43244 L
.86865 .43687 L
.86865 .44658 L
.86865 .45629 L
.86865 .46601 L
.86865 .47572 L
.86865 .48543 L
.86865 .49514 L
.86865 .50486 L
.86865 .51457 L
.86865 .52428 L
.86865 .53399 L
.86865 .54371 L
.86865 .55342 L
.86865 .56313 L
.86422 .56756 L
.85893 .57284 L
.85893 .58256 L
.85893 .59227 L
.85893 .60198 L
.85451 .60641 L
.84922 .61169 L
.84922 .62141 L
.84922 .63112 L
.84479 .63555 L
.83951 .64083 L
.83951 .65054 L
.83508 .65497 L
.8298 .66026 L
.8298 .66997 L
.82537 .6744 L
.82008 .67968 L
.82008 .68939 L
.81566 .69382 L
.81037 .69911 L
.80594 .70353 L
.80066 .70882 L
.80066 .71853 L
.79623 .72296 L
.79095 .72824 L
.78652 .73267 L
.78123 .73796 L
.77681 .74238 L
.77152 .74767 L
.76709 .7521 L
.76236 .75738 L
.75738 .76181 L
.7524 .75738 L
.74767 .7521 L
.74324 .74767 L
.73796 .74238 L
.73353 .73796 L
.72824 .73267 L
.72382 .72824 L
.71853 .72296 L
.7141 .71853 L
.70882 .71325 L
.70439 .70882 L
.69911 .70353 L
.69468 .69911 L
.68939 .69382 L
.68497 .68939 L
.67968 .68411 L
.67525 .67968 L
.66997 .6744 L
.66554 .66997 L
.66026 .66468 L
.65583 .66026 L
.65054 .65497 L
.64612 .65054 L
.64083 .64526 L
.6364 .64083 L
.63112 .63555 L
.62669 .63112 L
.62141 .62583 L
.61698 .62141 L
.61169 .61612 L
.60727 .61169 L
.60198 .60641 L
.59755 .60198 L
.59227 .5967 L
.58784 .59227 L
.58256 .58698 L
.57813 .58256 L
.57284 .57727 L
.56842 .57284 L
.56313 .56756 L
.5587 .56313 L
.55342 .55785 L
.54899 .55342 L
.54371 .54813 L
.53928 .54371 L
.53399 .53842 L
.52957 .53399 L
.52428 .52871 L
.51985 .52428 L
.51457 .519 L
.51014 .51457 L
.50486 .50928 L
.49514 .50928 L
.48986 .51457 L
.48543 .519 L
.48015 .52428 L
.47572 .52871 L
.47043 .53399 L
.46601 .53842 L
.46072 .54371 L
.45629 .54813 L
.45101 .55342 L
.44658 .55785 L
.4413 .56313 L
.43687 .56756 L
.43158 .57284 L
.42716 .57727 L
.42187 .58256 L
.41744 .58698 L
.41216 .59227 L
.40773 .5967 L
.40245 .60198 L
.39802 .60641 L
.39273 .61169 L
.38831 .61612 L
.38302 .62141 L
.37859 .62583 L
.37331 .63112 L
.36888 .63555 L
.3636 .64083 L
.35917 .64526 L
.35388 .65054 L
.34946 .65497 L
.34417 .66026 L
.33974 .66468 L
.33446 .66997 L
.33003 .6744 L
.32475 .67968 L
.32032 .68411 L
.31503 .68939 L
.31061 .69382 L
.30532 .69911 L
.30089 .70353 L
.29561 .70882 L
.29118 .71325 L
.2859 .71853 L
.28147 .72296 L
.27618 .72824 L
.27176 .73267 L
.26647 .73796 L
.26204 .74238 L
.25676 .74767 L
.25233 .7521 L
.2476 .75738 L
.24262 .76181 L
.23764 .75738 L
.23291 .7521 L
.22848 .74767 L
.22319 .74238 L
.21877 .73796 L
.21348 .73267 L
.20905 .72824 L
.20377 .72296 L
.19934 .71853 L
.19934 .70882 L
.19406 .70353 L
.18963 .69911 L
.18434 .69382 L
.17992 .68939 L
.17992 .67968 L
.17463 .6744 L
.1702 .66997 L
.1702 .66026 L
.16492 .65497 L
.16049 .65054 L
.16049 .64083 L
.15521 .63555 L
.15078 .63112 L
.15078 .62141 L
.15078 .61169 L
.14549 .60641 L
.14107 .60198 L
.14107 .59227 L
.14107 .58256 L
.14107 .57284 L
.13578 .56756 L
.13135 .56313 L
.13135 .55342 L
.13135 .54371 L
.13135 .53399 L
.13135 .52428 L
.13135 .51457 L
.13135 .50486 L
.13135 .49514 L
.13135 .48543 L
.13135 .47572 L
.13135 .46601 L
.13135 .45629 L
.13135 .44658 L
.13135 .43687 L
.13578 .43244 L
.14107 .42716 L
.14107 .41744 L
.14107 .40773 L
.14107 .39802 L
.14549 .39359 L
.15078 .38831 L
.15078 .37859 L
.15078 .36888 L
.15521 .36445 L
.16049 .35917 L
.16049 .34946 L
.16492 .34503 L
.1702 .33974 L
.1702 .33003 L
.17463 .3256 L
.17992 .32032 L
.17992 .31061 L
.18434 .30618 L
.18963 .30089 L
.19406 .29647 L
.19934 .29118 L
.19934 .28147 L
.20377 .27704 L
.20905 .27176 L
.21348 .26733 L
.21877 .26204 L
.22319 .25762 L
.22848 .25233 L
.23291 .2479 L
.23819 .24262 L
.24262 .23819 L
.2479 .23291 L
.25233 .22848 L
.25762 .22319 L
.26204 .21877 L
.26733 .21348 L
.27176 .20905 L
.27704 .20377 L
.28147 .19934 L
.29118 .19934 L
.29647 .19406 L
.30089 .18963 L
.30618 .18434 L
.31061 .17992 L
.32032 .17992 L
.3256 .17463 L
.33003 .1702 L
.33974 .1702 L
.34503 .16492 L
.34946 .16049 L
.35917 .16049 L
.36445 .15521 L
.36888 .15078 L
.37859 .15078 L
.38831 .15078 L
.39359 .14549 L
.39802 .14107 L
.40773 .14107 L
.41744 .14107 L
.42716 .14107 L
.43244 .13578 L
F
0 g
.43687 .13135 m
.44658 .13135 L
.45629 .13135 L
.46601 .13135 L
.47572 .13135 L
.48543 .13135 L
.49514 .13135 L
.50486 .13135 L
.51457 .13135 L
.52428 .13135 L
.53399 .13135 L
.54371 .13135 L
.55342 .13135 L
.56313 .13135 L
.56756 .13578 L
.57284 .14107 L
.58256 .14107 L
.59227 .14107 L
.60198 .14107 L
.60641 .14549 L
.61169 .15078 L
.62141 .15078 L
.63112 .15078 L
.63555 .15521 L
.64083 .16049 L
.65054 .16049 L
.65497 .16492 L
.66026 .1702 L
.66997 .1702 L
.6744 .17463 L
.67968 .17992 L
.68939 .17992 L
.69382 .18434 L
.69911 .18963 L
.70353 .19406 L
.70882 .19934 L
.71853 .19934 L
.72296 .20377 L
.72824 .20905 L
.73267 .21348 L
.73796 .21877 L
.74238 .22319 L
.74767 .22848 L
.7521 .23291 L
.75738 .23819 L
.76181 .24262 L
.76709 .2479 L
.77152 .25233 L
.77681 .25762 L
.78123 .26204 L
Mistroke
.78652 .26733 L
.79095 .27176 L
.79623 .27704 L
.80066 .28147 L
.80066 .29118 L
.80594 .29647 L
.81037 .30089 L
.81566 .30618 L
.82008 .31061 L
.82008 .32032 L
.82537 .3256 L
.8298 .33003 L
.8298 .33974 L
.83508 .34503 L
.83951 .34946 L
.83951 .35917 L
.84479 .36445 L
.84922 .36888 L
.84922 .37859 L
.84922 .38831 L
.85451 .39359 L
.85893 .39802 L
.85893 .40773 L
.85893 .41744 L
.85893 .42716 L
.86422 .43244 L
.86865 .43687 L
.86865 .44658 L
.86865 .45629 L
.86865 .46601 L
.86865 .47572 L
.86865 .48543 L
.86865 .49514 L
.86865 .50486 L
.86865 .51457 L
.86865 .52428 L
.86865 .53399 L
.86865 .54371 L
.86865 .55342 L
.86865 .56313 L
.86422 .56756 L
.85893 .57284 L
.85893 .58256 L
.85893 .59227 L
.85893 .60198 L
.85451 .60641 L
.84922 .61169 L
.84922 .62141 L
.84922 .63112 L
.84479 .63555 L
Mistroke
.83951 .64083 L
.83951 .65054 L
.83508 .65497 L
.8298 .66026 L
.8298 .66997 L
.82537 .6744 L
.82008 .67968 L
.82008 .68939 L
.81566 .69382 L
.81037 .69911 L
.80594 .70353 L
.80066 .70882 L
.80066 .71853 L
.79623 .72296 L
.79095 .72824 L
.78652 .73267 L
.78123 .73796 L
.77681 .74238 L
.77152 .74767 L
.76709 .7521 L
.76236 .75738 L
.75738 .76181 L
.7524 .75738 L
.74767 .7521 L
.74324 .74767 L
.73796 .74238 L
.73353 .73796 L
.72824 .73267 L
.72382 .72824 L
.71853 .72296 L
.7141 .71853 L
.70882 .71325 L
.70439 .70882 L
.69911 .70353 L
.69468 .69911 L
.68939 .69382 L
.68497 .68939 L
.67968 .68411 L
.67525 .67968 L
.66997 .6744 L
.66554 .66997 L
.66026 .66468 L
.65583 .66026 L
.65054 .65497 L
.64612 .65054 L
.64083 .64526 L
.6364 .64083 L
.63112 .63555 L
.62669 .63112 L
.62141 .62583 L
Mistroke
.61698 .62141 L
.61169 .61612 L
.60727 .61169 L
.60198 .60641 L
.59755 .60198 L
.59227 .5967 L
.58784 .59227 L
.58256 .58698 L
.57813 .58256 L
.57284 .57727 L
.56842 .57284 L
.56313 .56756 L
.5587 .56313 L
.55342 .55785 L
.54899 .55342 L
.54371 .54813 L
.53928 .54371 L
.53399 .53842 L
.52957 .53399 L
.52428 .52871 L
.51985 .52428 L
.51457 .519 L
.51014 .51457 L
.50486 .50928 L
.49514 .50928 L
.48986 .51457 L
.48543 .519 L
.48015 .52428 L
.47572 .52871 L
.47043 .53399 L
.46601 .53842 L
.46072 .54371 L
.45629 .54813 L
.45101 .55342 L
.44658 .55785 L
.4413 .56313 L
.43687 .56756 L
.43158 .57284 L
.42716 .57727 L
.42187 .58256 L
.41744 .58698 L
.41216 .59227 L
.40773 .5967 L
.40245 .60198 L
.39802 .60641 L
.39273 .61169 L
.38831 .61612 L
.38302 .62141 L
.37859 .62583 L
.37331 .63112 L
Mistroke
.36888 .63555 L
.3636 .64083 L
.35917 .64526 L
.35388 .65054 L
.34946 .65497 L
.34417 .66026 L
.33974 .66468 L
.33446 .66997 L
.33003 .6744 L
.32475 .67968 L
.32032 .68411 L
.31503 .68939 L
.31061 .69382 L
.30532 .69911 L
.30089 .70353 L
.29561 .70882 L
.29118 .71325 L
.2859 .71853 L
.28147 .72296 L
.27618 .72824 L
.27176 .73267 L
.26647 .73796 L
.26204 .74238 L
.25676 .74767 L
.25233 .7521 L
.2476 .75738 L
.24262 .76181 L
.23764 .75738 L
.23291 .7521 L
.22848 .74767 L
.22319 .74238 L
.21877 .73796 L
.21348 .73267 L
.20905 .72824 L
.20377 .72296 L
.19934 .71853 L
.19934 .70882 L
.19406 .70353 L
.18963 .69911 L
.18434 .69382 L
.17992 .68939 L
.17992 .67968 L
.17463 .6744 L
.1702 .66997 L
.1702 .66026 L
.16492 .65497 L
.16049 .65054 L
.16049 .64083 L
.15521 .63555 L
.15078 .63112 L
Mistroke
.15078 .62141 L
.15078 .61169 L
.14549 .60641 L
.14107 .60198 L
.14107 .59227 L
.14107 .58256 L
.14107 .57284 L
.13578 .56756 L
.13135 .56313 L
.13135 .55342 L
.13135 .54371 L
.13135 .53399 L
.13135 .52428 L
.13135 .51457 L
.13135 .50486 L
.13135 .49514 L
.13135 .48543 L
.13135 .47572 L
.13135 .46601 L
.13135 .45629 L
.13135 .44658 L
.13135 .43687 L
.13578 .43244 L
.14107 .42716 L
.14107 .41744 L
.14107 .40773 L
.14107 .39802 L
.14549 .39359 L
.15078 .38831 L
.15078 .37859 L
.15078 .36888 L
.15521 .36445 L
.16049 .35917 L
.16049 .34946 L
.16492 .34503 L
.1702 .33974 L
.1702 .33003 L
.17463 .3256 L
.17992 .32032 L
.17992 .31061 L
.18434 .30618 L
.18963 .30089 L
.19406 .29647 L
.19934 .29118 L
.19934 .28147 L
.20377 .27704 L
.20905 .27176 L
.21348 .26733 L
.21877 .26204 L
.22319 .25762 L
Mistroke
.22848 .25233 L
.23291 .2479 L
.23819 .24262 L
.24262 .23819 L
.2479 .23291 L
.25233 .22848 L
.25762 .22319 L
.26204 .21877 L
.26733 .21348 L
.27176 .20905 L
.27704 .20377 L
.28147 .19934 L
.29118 .19934 L
.29647 .19406 L
.30089 .18963 L
.30618 .18434 L
.31061 .17992 L
.32032 .17992 L
.3256 .17463 L
.33003 .1702 L
.33974 .1702 L
.34503 .16492 L
.34946 .16049 L
.35917 .16049 L
.36445 .15521 L
.36888 .15078 L
.37859 .15078 L
.38831 .15078 L
.39359 .14549 L
.39802 .14107 L
.40773 .14107 L
.41744 .14107 L
.42716 .14107 L
.43244 .13578 L
.43687 .13135 L
Mfstroke
.7 g
.43687 .13222 m
.44658 .13222 L
.45629 .13222 L
.46601 .13222 L
.47572 .13222 L
.48543 .13222 L
.49514 .13222 L
.50486 .13222 L
.51457 .13222 L
.52428 .13222 L
.53399 .13222 L
.54371 .13222 L
.55342 .13222 L
.56313 .13222 L
.5667 .13578 L
.57284 .14193 L
.58256 .14193 L
.59227 .14193 L
.60198 .14193 L
.60555 .14549 L
.61169 .15164 L
.62141 .15164 L
.63112 .15164 L
.63468 .15521 L
.64083 .16135 L
.65054 .16135 L
.65411 .16492 L
.66026 .17107 L
.66997 .17107 L
.67353 .17463 L
.67968 .18078 L
.68939 .18078 L
.69296 .18434 L
.69911 .19049 L
.70267 .19406 L
.70882 .2002 L
.71853 .2002 L
.7221 .20377 L
.72824 .20992 L
.73181 .21348 L
.73796 .21963 L
.74152 .22319 L
.74767 .22934 L
.75123 .23291 L
.75738 .23905 L
.76095 .24262 L
.76709 .24877 L
.77066 .25233 L
.77681 .25848 L
.78037 .26204 L
.78652 .26819 L
.79008 .27176 L
.79623 .2779 L
.7998 .28147 L
.7998 .29118 L
.80594 .29733 L
.80951 .30089 L
.81566 .30704 L
.81922 .31061 L
.81922 .32032 L
.82537 .32647 L
.82893 .33003 L
.82893 .33974 L
.83508 .34589 L
.83865 .34946 L
.83865 .35917 L
.84479 .36532 L
.84836 .36888 L
.84836 .37859 L
.84836 .38831 L
.85451 .39445 L
.85807 .39802 L
.85807 .40773 L
.85807 .41744 L
.85807 .42716 L
.86422 .4333 L
.86778 .43687 L
.86778 .44658 L
.86778 .45629 L
.86778 .46601 L
.86778 .47572 L
.86778 .48543 L
.86778 .49514 L
.86778 .50486 L
.86778 .51457 L
.86778 .52428 L
.86778 .53399 L
.86778 .54371 L
.86778 .55342 L
.86778 .56313 L
.86422 .5667 L
.85807 .57284 L
.85807 .58256 L
.85807 .59227 L
.85807 .60198 L
.85451 .60555 L
.84836 .61169 L
.84836 .62141 L
.84836 .63112 L
.84479 .63468 L
.83865 .64083 L
.83865 .65054 L
.83508 .65411 L
.82893 .66026 L
.82893 .66997 L
.82537 .67353 L
.81922 .67968 L
.81922 .68939 L
.81566 .69296 L
.80951 .69911 L
.80594 .70267 L
.7998 .70882 L
.7998 .71853 L
.79623 .7221 L
.79008 .72824 L
.78652 .73181 L
.78037 .73796 L
.77681 .74152 L
.77066 .74767 L
.76709 .75123 L
.76153 .75738 L
.75738 .76095 L
.75324 .75738 L
.74767 .75123 L
.7441 .74767 L
.73796 .74152 L
.73439 .73796 L
.72824 .73181 L
.72468 .72824 L
.71853 .7221 L
.71497 .71853 L
.70882 .71238 L
.70525 .70882 L
.69911 .70267 L
.69554 .69911 L
.68939 .69296 L
.68583 .68939 L
.67968 .68325 L
.67612 .67968 L
.66997 .67353 L
.6664 .66997 L
.66026 .66382 L
.65669 .66026 L
.65054 .65411 L
.64698 .65054 L
.64083 .6444 L
.63727 .64083 L
.63112 .63468 L
.62755 .63112 L
.62141 .62497 L
.61784 .62141 L
.61169 .61526 L
.60813 .61169 L
.60198 .60555 L
.59842 .60198 L
.59227 .59583 L
.5887 .59227 L
.58256 .58612 L
.57899 .58256 L
.57284 .57641 L
.56928 .57284 L
.56313 .5667 L
.55957 .56313 L
.55342 .55698 L
.54985 .55342 L
.54371 .54727 L
.54014 .54371 L
.53399 .53756 L
.53043 .53399 L
.52428 .52785 L
.52072 .52428 L
.51457 .51813 L
.511 .51457 L
.50486 .50842 L
.49514 .50842 L
.489 .51457 L
.48543 .51813 L
.47928 .52428 L
.47572 .52785 L
.46957 .53399 L
.46601 .53756 L
.45986 .54371 L
.45629 .54727 L
.45015 .55342 L
.44658 .55698 L
.44043 .56313 L
.43687 .5667 L
.43072 .57284 L
.42716 .57641 L
.42101 .58256 L
.41744 .58612 L
.4113 .59227 L
.40773 .59583 L
.40158 .60198 L
.39802 .60555 L
.39187 .61169 L
.38831 .61526 L
.38216 .62141 L
.37859 .62497 L
.37245 .63112 L
.36888 .63468 L
.36273 .64083 L
.35917 .6444 L
.35302 .65054 L
.34946 .65411 L
.34331 .66026 L
.33974 .66382 L
.3336 .66997 L
.33003 .67353 L
.32388 .67968 L
.32032 .68325 L
.31417 .68939 L
.31061 .69296 L
.30446 .69911 L
.30089 .70267 L
.29475 .70882 L
.29118 .71238 L
.28503 .71853 L
.28147 .7221 L
.27532 .72824 L
.27176 .73181 L
.26561 .73796 L
.26204 .74152 L
.2559 .74767 L
.25233 .75123 L
.24676 .75738 L
.24262 .76095 L
.23847 .75738 L
.23291 .75123 L
.22934 .74767 L
.22319 .74152 L
.21963 .73796 L
.21348 .73181 L
.20992 .72824 L
.20377 .7221 L
.2002 .71853 L
.2002 .70882 L
.19406 .70267 L
.19049 .69911 L
.18434 .69296 L
.18078 .68939 L
.18078 .67968 L
.17463 .67353 L
.17107 .66997 L
.17107 .66026 L
.16492 .65411 L
.16135 .65054 L
.16135 .64083 L
.15521 .63468 L
.15164 .63112 L
.15164 .62141 L
.15164 .61169 L
.14549 .60555 L
.14193 .60198 L
.14193 .59227 L
.14193 .58256 L
.14193 .57284 L
.13578 .5667 L
.13222 .56313 L
.13222 .55342 L
.13222 .54371 L
.13222 .53399 L
.13222 .52428 L
.13222 .51457 L
.13222 .50486 L
.13222 .49514 L
.13222 .48543 L
.13222 .47572 L
.13222 .46601 L
.13222 .45629 L
.13222 .44658 L
.13222 .43687 L
.13578 .4333 L
.14193 .42716 L
.14193 .41744 L
.14193 .40773 L
.14193 .39802 L
.14549 .39445 L
.15164 .38831 L
.15164 .37859 L
.15164 .36888 L
.15521 .36532 L
.16135 .35917 L
.16135 .34946 L
.16492 .34589 L
.17107 .33974 L
.17107 .33003 L
.17463 .32647 L
.18078 .32032 L
.18078 .31061 L
.18434 .30704 L
.19049 .30089 L
.19406 .29733 L
.2002 .29118 L
.2002 .28147 L
.20377 .2779 L
.20992 .27176 L
.21348 .26819 L
.21963 .26204 L
.22319 .25848 L
.22934 .25233 L
.23291 .24877 L
.23905 .24262 L
.24262 .23905 L
.24877 .23291 L
.25233 .22934 L
.25848 .22319 L
.26204 .21963 L
.26819 .21348 L
.27176 .20992 L
.2779 .20377 L
.28147 .2002 L
.29118 .2002 L
.29733 .19406 L
.30089 .19049 L
.30704 .18434 L
.31061 .18078 L
.32032 .18078 L
.32647 .17463 L
.33003 .17107 L
.33974 .17107 L
.34589 .16492 L
.34946 .16135 L
.35917 .16135 L
.36532 .15521 L
.36888 .15164 L
.37859 .15164 L
.38831 .15164 L
.39445 .14549 L
.39802 .14193 L
.40773 .14193 L
.41744 .14193 L
.42716 .14193 L
.4333 .13578 L
F
0 g
.43687 .13222 m
.44658 .13222 L
.45629 .13222 L
.46601 .13222 L
.47572 .13222 L
.48543 .13222 L
.49514 .13222 L
.50486 .13222 L
.51457 .13222 L
.52428 .13222 L
.53399 .13222 L
.54371 .13222 L
.55342 .13222 L
.56313 .13222 L
.5667 .13578 L
.57284 .14193 L
.58256 .14193 L
.59227 .14193 L
.60198 .14193 L
.60555 .14549 L
.61169 .15164 L
.62141 .15164 L
.63112 .15164 L
.63468 .15521 L
.64083 .16135 L
.65054 .16135 L
.65411 .16492 L
.66026 .17107 L
.66997 .17107 L
.67353 .17463 L
.67968 .18078 L
.68939 .18078 L
.69296 .18434 L
.69911 .19049 L
.70267 .19406 L
.70882 .2002 L
.71853 .2002 L
.7221 .20377 L
.72824 .20992 L
.73181 .21348 L
.73796 .21963 L
.74152 .22319 L
.74767 .22934 L
.75123 .23291 L
.75738 .23905 L
.76095 .24262 L
.76709 .24877 L
.77066 .25233 L
.77681 .25848 L
.78037 .26204 L
Mistroke
.78652 .26819 L
.79008 .27176 L
.79623 .2779 L
.7998 .28147 L
.7998 .29118 L
.80594 .29733 L
.80951 .30089 L
.81566 .30704 L
.81922 .31061 L
.81922 .32032 L
.82537 .32647 L
.82893 .33003 L
.82893 .33974 L
.83508 .34589 L
.83865 .34946 L
.83865 .35917 L
.84479 .36532 L
.84836 .36888 L
.84836 .37859 L
.84836 .38831 L
.85451 .39445 L
.85807 .39802 L
.85807 .40773 L
.85807 .41744 L
.85807 .42716 L
.86422 .4333 L
.86778 .43687 L
.86778 .44658 L
.86778 .45629 L
.86778 .46601 L
.86778 .47572 L
.86778 .48543 L
.86778 .49514 L
.86778 .50486 L
.86778 .51457 L
.86778 .52428 L
.86778 .53399 L
.86778 .54371 L
.86778 .55342 L
.86778 .56313 L
.86422 .5667 L
.85807 .57284 L
.85807 .58256 L
.85807 .59227 L
.85807 .60198 L
.85451 .60555 L
.84836 .61169 L
.84836 .62141 L
.84836 .63112 L
.84479 .63468 L
Mistroke
.83865 .64083 L
.83865 .65054 L
.83508 .65411 L
.82893 .66026 L
.82893 .66997 L
.82537 .67353 L
.81922 .67968 L
.81922 .68939 L
.81566 .69296 L
.80951 .69911 L
.80594 .70267 L
.7998 .70882 L
.7998 .71853 L
.79623 .7221 L
.79008 .72824 L
.78652 .73181 L
.78037 .73796 L
.77681 .74152 L
.77066 .74767 L
.76709 .75123 L
.76153 .75738 L
.75738 .76095 L
.75324 .75738 L
.74767 .75123 L
.7441 .74767 L
.73796 .74152 L
.73439 .73796 L
.72824 .73181 L
.72468 .72824 L
.71853 .7221 L
.71497 .71853 L
.70882 .71238 L
.70525 .70882 L
.69911 .70267 L
.69554 .69911 L
.68939 .69296 L
.68583 .68939 L
.67968 .68325 L
.67612 .67968 L
.66997 .67353 L
.6664 .66997 L
.66026 .66382 L
.65669 .66026 L
.65054 .65411 L
.64698 .65054 L
.64083 .6444 L
.63727 .64083 L
.63112 .63468 L
.62755 .63112 L
.62141 .62497 L
Mistroke
.61784 .62141 L
.61169 .61526 L
.60813 .61169 L
.60198 .60555 L
.59842 .60198 L
.59227 .59583 L
.5887 .59227 L
.58256 .58612 L
.57899 .58256 L
.57284 .57641 L
.56928 .57284 L
.56313 .5667 L
.55957 .56313 L
.55342 .55698 L
.54985 .55342 L
.54371 .54727 L
.54014 .54371 L
.53399 .53756 L
.53043 .53399 L
.52428 .52785 L
.52072 .52428 L
.51457 .51813 L
.511 .51457 L
.50486 .50842 L
.49514 .50842 L
.489 .51457 L
.48543 .51813 L
.47928 .52428 L
.47572 .52785 L
.46957 .53399 L
.46601 .53756 L
.45986 .54371 L
.45629 .54727 L
.45015 .55342 L
.44658 .55698 L
.44043 .56313 L
.43687 .5667 L
.43072 .57284 L
.42716 .57641 L
.42101 .58256 L
.41744 .58612 L
.4113 .59227 L
.40773 .59583 L
.40158 .60198 L
.39802 .60555 L
.39187 .61169 L
.38831 .61526 L
.38216 .62141 L
.37859 .62497 L
.37245 .63112 L
Mistroke
.36888 .63468 L
.36273 .64083 L
.35917 .6444 L
.35302 .65054 L
.34946 .65411 L
.34331 .66026 L
.33974 .66382 L
.3336 .66997 L
.33003 .67353 L
.32388 .67968 L
.32032 .68325 L
.31417 .68939 L
.31061 .69296 L
.30446 .69911 L
.30089 .70267 L
.29475 .70882 L
.29118 .71238 L
.28503 .71853 L
.28147 .7221 L
.27532 .72824 L
.27176 .73181 L
.26561 .73796 L
.26204 .74152 L
.2559 .74767 L
.25233 .75123 L
.24676 .75738 L
.24262 .76095 L
.23847 .75738 L
.23291 .75123 L
.22934 .74767 L
.22319 .74152 L
.21963 .73796 L
.21348 .73181 L
.20992 .72824 L
.20377 .7221 L
.2002 .71853 L
.2002 .70882 L
.19406 .70267 L
.19049 .69911 L
.18434 .69296 L
.18078 .68939 L
.18078 .67968 L
.17463 .67353 L
.17107 .66997 L
.17107 .66026 L
.16492 .65411 L
.16135 .65054 L
.16135 .64083 L
.15521 .63468 L
.15164 .63112 L
Mistroke
.15164 .62141 L
.15164 .61169 L
.14549 .60555 L
.14193 .60198 L
.14193 .59227 L
.14193 .58256 L
.14193 .57284 L
.13578 .5667 L
.13222 .56313 L
.13222 .55342 L
.13222 .54371 L
.13222 .53399 L
.13222 .52428 L
.13222 .51457 L
.13222 .50486 L
.13222 .49514 L
.13222 .48543 L
.13222 .47572 L
.13222 .46601 L
.13222 .45629 L
.13222 .44658 L
.13222 .43687 L
.13578 .4333 L
.14193 .42716 L
.14193 .41744 L
.14193 .40773 L
.14193 .39802 L
.14549 .39445 L
.15164 .38831 L
.15164 .37859 L
.15164 .36888 L
.15521 .36532 L
.16135 .35917 L
.16135 .34946 L
.16492 .34589 L
.17107 .33974 L
.17107 .33003 L
.17463 .32647 L
.18078 .32032 L
.18078 .31061 L
.18434 .30704 L
.19049 .30089 L
.19406 .29733 L
.2002 .29118 L
.2002 .28147 L
.20377 .2779 L
.20992 .27176 L
.21348 .26819 L
.21963 .26204 L
.22319 .25848 L
Mistroke
.22934 .25233 L
.23291 .24877 L
.23905 .24262 L
.24262 .23905 L
.24877 .23291 L
.25233 .22934 L
.25848 .22319 L
.26204 .21963 L
.26819 .21348 L
.27176 .20992 L
.2779 .20377 L
.28147 .2002 L
.29118 .2002 L
.29733 .19406 L
.30089 .19049 L
.30704 .18434 L
.31061 .18078 L
.32032 .18078 L
.32647 .17463 L
.33003 .17107 L
.33974 .17107 L
.34589 .16492 L
.34946 .16135 L
.35917 .16135 L
.36532 .15521 L
.36888 .15164 L
.37859 .15164 L
.38831 .15164 L
.39445 .14549 L
.39802 .14193 L
.40773 .14193 L
.41744 .14193 L
.42716 .14193 L
.4333 .13578 L
.43687 .13222 L
Mfstroke
.8 g
.43687 .1331 m
.44658 .1331 L
.45629 .1331 L
.46601 .1331 L
.47572 .1331 L
.48543 .1331 L
.49514 .1331 L
.50486 .1331 L
.51457 .1331 L
.52428 .1331 L
.53399 .1331 L
.54371 .1331 L
.55342 .1331 L
.56313 .1331 L
.56581 .13578 L
.57284 .14281 L
.58256 .14281 L
.59227 .14281 L
.60198 .14281 L
.60466 .14549 L
.61169 .15252 L
.62141 .15252 L
.63112 .15252 L
.6338 .15521 L
.64083 .16224 L
.65054 .16224 L
.65323 .16492 L
.66026 .17195 L
.66997 .17195 L
.67265 .17463 L
.67968 .18166 L
.68939 .18166 L
.69208 .18434 L
.69911 .19137 L
.70179 .19406 L
.70882 .20109 L
.71853 .20109 L
.72121 .20377 L
.72824 .2108 L
.73093 .21348 L
.73796 .22051 L
.74064 .22319 L
.74767 .23022 L
.75035 .23291 L
.75738 .23994 L
.76006 .24262 L
.76709 .24965 L
.76978 .25233 L
.77681 .25936 L
.77949 .26204 L
.78652 .26907 L
.7892 .27176 L
.79623 .27879 L
.79891 .28147 L
.79891 .29118 L
.80594 .29821 L
.80863 .30089 L
.81566 .30792 L
.81834 .31061 L
.81834 .32032 L
.82537 .32735 L
.82805 .33003 L
.82805 .33974 L
.83508 .34677 L
.83776 .34946 L
.83776 .35917 L
.84479 .3662 L
.84748 .36888 L
.84748 .37859 L
.84748 .38831 L
.85451 .39534 L
.85719 .39802 L
.85719 .40773 L
.85719 .41744 L
.85719 .42716 L
.86422 .43419 L
.8669 .43687 L
.8669 .44658 L
.8669 .45629 L
.8669 .46601 L
.8669 .47572 L
.8669 .48543 L
.8669 .49514 L
.8669 .50486 L
.8669 .51457 L
.8669 .52428 L
.8669 .53399 L
.8669 .54371 L
.8669 .55342 L
.8669 .56313 L
.86422 .56581 L
.85719 .57284 L
.85719 .58256 L
.85719 .59227 L
.85719 .60198 L
.85451 .60466 L
.84748 .61169 L
.84748 .62141 L
.84748 .63112 L
.84479 .6338 L
.83776 .64083 L
.83776 .65054 L
.83508 .65323 L
.82805 .66026 L
.82805 .66997 L
.82537 .67265 L
.81834 .67968 L
.81834 .68939 L
.81566 .69208 L
.80863 .69911 L
.80594 .70179 L
.79891 .70882 L
.79891 .71853 L
.79623 .72121 L
.7892 .72824 L
.78652 .73093 L
.77949 .73796 L
.77681 .74064 L
.76978 .74767 L
.76709 .75035 L
.76064 .75738 L
.75738 .76006 L
.75412 .75738 L
.74767 .75035 L
.74499 .74767 L
.73796 .74064 L
.73527 .73796 L
.72824 .73093 L
.72556 .72824 L
.71853 .72121 L
.71585 .71853 L
.70882 .7115 L
.70614 .70882 L
.69911 .70179 L
.69642 .69911 L
.68939 .69208 L
.68671 .68939 L
.67968 .68236 L
.677 .67968 L
.66997 .67265 L
.66729 .66997 L
.66026 .66294 L
.65757 .66026 L
.65054 .65323 L
.64786 .65054 L
.64083 .64351 L
.63815 .64083 L
.63112 .6338 L
.62844 .63112 L
.62141 .62409 L
.61872 .62141 L
.61169 .61438 L
.60901 .61169 L
.60198 .60466 L
.5993 .60198 L
.59227 .59495 L
.58959 .59227 L
.58256 .58524 L
.57987 .58256 L
.57284 .57553 L
.57016 .57284 L
.56313 .56581 L
.56045 .56313 L
.55342 .5561 L
.55074 .55342 L
.54371 .54639 L
.54102 .54371 L
.53399 .53668 L
.53131 .53399 L
.52428 .52696 L
.5216 .52428 L
.51457 .51725 L
.51189 .51457 L
.50486 .50754 L
.49514 .50754 L
.48811 .51457 L
.48543 .51725 L
.4784 .52428 L
.47572 .52696 L
.46869 .53399 L
.46601 .53668 L
.45898 .54371 L
.45629 .54639 L
.44926 .55342 L
.44658 .5561 L
.43955 .56313 L
.43687 .56581 L
.42984 .57284 L
.42716 .57553 L
.42013 .58256 L
.41744 .58524 L
.41041 .59227 L
.40773 .59495 L
.4007 .60198 L
.39802 .60466 L
.39099 .61169 L
.38831 .61438 L
.38128 .62141 L
.37859 .62409 L
.37156 .63112 L
.36888 .6338 L
.36185 .64083 L
.35917 .64351 L
.35214 .65054 L
.34946 .65323 L
.34243 .66026 L
.33974 .66294 L
.33271 .66997 L
.33003 .67265 L
.323 .67968 L
.32032 .68236 L
.31329 .68939 L
.31061 .69208 L
.30358 .69911 L
.30089 .70179 L
.29386 .70882 L
.29118 .7115 L
.28415 .71853 L
.28147 .72121 L
.27444 .72824 L
.27176 .73093 L
.26473 .73796 L
.26204 .74064 L
.25501 .74767 L
.25233 .75035 L
.24588 .75738 L
.24262 .76006 L
.23936 .75738 L
.23291 .75035 L
.23022 .74767 L
.22319 .74064 L
.22051 .73796 L
.21348 .73093 L
.2108 .72824 L
.20377 .72121 L
.20109 .71853 L
.20109 .70882 L
.19406 .70179 L
.19137 .69911 L
.18434 .69208 L
.18166 .68939 L
.18166 .67968 L
.17463 .67265 L
.17195 .66997 L
.17195 .66026 L
.16492 .65323 L
.16224 .65054 L
.16224 .64083 L
.15521 .6338 L
.15252 .63112 L
.15252 .62141 L
.15252 .61169 L
.14549 .60466 L
.14281 .60198 L
.14281 .59227 L
.14281 .58256 L
.14281 .57284 L
.13578 .56581 L
.1331 .56313 L
.1331 .55342 L
.1331 .54371 L
.1331 .53399 L
.1331 .52428 L
.1331 .51457 L
.1331 .50486 L
.1331 .49514 L
.1331 .48543 L
.1331 .47572 L
.1331 .46601 L
.1331 .45629 L
.1331 .44658 L
.1331 .43687 L
.13578 .43419 L
.14281 .42716 L
.14281 .41744 L
.14281 .40773 L
.14281 .39802 L
.14549 .39534 L
.15252 .38831 L
.15252 .37859 L
.15252 .36888 L
.15521 .3662 L
.16224 .35917 L
.16224 .34946 L
.16492 .34677 L
.17195 .33974 L
.17195 .33003 L
.17463 .32735 L
.18166 .32032 L
.18166 .31061 L
.18434 .30792 L
.19137 .30089 L
.19406 .29821 L
.20109 .29118 L
.20109 .28147 L
.20377 .27879 L
.2108 .27176 L
.21348 .26907 L
.22051 .26204 L
.22319 .25936 L
.23022 .25233 L
.23291 .24965 L
.23994 .24262 L
.24262 .23994 L
.24965 .23291 L
.25233 .23022 L
.25936 .22319 L
.26204 .22051 L
.26907 .21348 L
.27176 .2108 L
.27879 .20377 L
.28147 .20109 L
.29118 .20109 L
.29821 .19406 L
.30089 .19137 L
.30792 .18434 L
.31061 .18166 L
.32032 .18166 L
.32735 .17463 L
.33003 .17195 L
.33974 .17195 L
.34677 .16492 L
.34946 .16224 L
.35917 .16224 L
.3662 .15521 L
.36888 .15252 L
.37859 .15252 L
.38831 .15252 L
.39534 .14549 L
.39802 .14281 L
.40773 .14281 L
.41744 .14281 L
.42716 .14281 L
.43419 .13578 L
F
0 g
.43687 .1331 m
.44658 .1331 L
.45629 .1331 L
.46601 .1331 L
.47572 .1331 L
.48543 .1331 L
.49514 .1331 L
.50486 .1331 L
.51457 .1331 L
.52428 .1331 L
.53399 .1331 L
.54371 .1331 L
.55342 .1331 L
.56313 .1331 L
.56581 .13578 L
.57284 .14281 L
.58256 .14281 L
.59227 .14281 L
.60198 .14281 L
.60466 .14549 L
.61169 .15252 L
.62141 .15252 L
.63112 .15252 L
.6338 .15521 L
.64083 .16224 L
.65054 .16224 L
.65323 .16492 L
.66026 .17195 L
.66997 .17195 L
.67265 .17463 L
.67968 .18166 L
.68939 .18166 L
.69208 .18434 L
.69911 .19137 L
.70179 .19406 L
.70882 .20109 L
.71853 .20109 L
.72121 .20377 L
.72824 .2108 L
.73093 .21348 L
.73796 .22051 L
.74064 .22319 L
.74767 .23022 L
.75035 .23291 L
.75738 .23994 L
.76006 .24262 L
.76709 .24965 L
.76978 .25233 L
.77681 .25936 L
.77949 .26204 L
Mistroke
.78652 .26907 L
.7892 .27176 L
.79623 .27879 L
.79891 .28147 L
.79891 .29118 L
.80594 .29821 L
.80863 .30089 L
.81566 .30792 L
.81834 .31061 L
.81834 .32032 L
.82537 .32735 L
.82805 .33003 L
.82805 .33974 L
.83508 .34677 L
.83776 .34946 L
.83776 .35917 L
.84479 .3662 L
.84748 .36888 L
.84748 .37859 L
.84748 .38831 L
.85451 .39534 L
.85719 .39802 L
.85719 .40773 L
.85719 .41744 L
.85719 .42716 L
.86422 .43419 L
.8669 .43687 L
.8669 .44658 L
.8669 .45629 L
.8669 .46601 L
.8669 .47572 L
.8669 .48543 L
.8669 .49514 L
.8669 .50486 L
.8669 .51457 L
.8669 .52428 L
.8669 .53399 L
.8669 .54371 L
.8669 .55342 L
.8669 .56313 L
.86422 .56581 L
.85719 .57284 L
.85719 .58256 L
.85719 .59227 L
.85719 .60198 L
.85451 .60466 L
.84748 .61169 L
.84748 .62141 L
.84748 .63112 L
.84479 .6338 L
Mistroke
.83776 .64083 L
.83776 .65054 L
.83508 .65323 L
.82805 .66026 L
.82805 .66997 L
.82537 .67265 L
.81834 .67968 L
.81834 .68939 L
.81566 .69208 L
.80863 .69911 L
.80594 .70179 L
.79891 .70882 L
.79891 .71853 L
.79623 .72121 L
.7892 .72824 L
.78652 .73093 L
.77949 .73796 L
.77681 .74064 L
.76978 .74767 L
.76709 .75035 L
.76064 .75738 L
.75738 .76006 L
.75412 .75738 L
.74767 .75035 L
.74499 .74767 L
.73796 .74064 L
.73527 .73796 L
.72824 .73093 L
.72556 .72824 L
.71853 .72121 L
.71585 .71853 L
.70882 .7115 L
.70614 .70882 L
.69911 .70179 L
.69642 .69911 L
.68939 .69208 L
.68671 .68939 L
.67968 .68236 L
.677 .67968 L
.66997 .67265 L
.66729 .66997 L
.66026 .66294 L
.65757 .66026 L
.65054 .65323 L
.64786 .65054 L
.64083 .64351 L
.63815 .64083 L
.63112 .6338 L
.62844 .63112 L
.62141 .62409 L
Mistroke
.61872 .62141 L
.61169 .61438 L
.60901 .61169 L
.60198 .60466 L
.5993 .60198 L
.59227 .59495 L
.58959 .59227 L
.58256 .58524 L
.57987 .58256 L
.57284 .57553 L
.57016 .57284 L
.56313 .56581 L
.56045 .56313 L
.55342 .5561 L
.55074 .55342 L
.54371 .54639 L
.54102 .54371 L
.53399 .53668 L
.53131 .53399 L
.52428 .52696 L
.5216 .52428 L
.51457 .51725 L
.51189 .51457 L
.50486 .50754 L
.49514 .50754 L
.48811 .51457 L
.48543 .51725 L
.4784 .52428 L
.47572 .52696 L
.46869 .53399 L
.46601 .53668 L
.45898 .54371 L
.45629 .54639 L
.44926 .55342 L
.44658 .5561 L
.43955 .56313 L
.43687 .56581 L
.42984 .57284 L
.42716 .57553 L
.42013 .58256 L
.41744 .58524 L
.41041 .59227 L
.40773 .59495 L
.4007 .60198 L
.39802 .60466 L
.39099 .61169 L
.38831 .61438 L
.38128 .62141 L
.37859 .62409 L
.37156 .63112 L
Mistroke
.36888 .6338 L
.36185 .64083 L
.35917 .64351 L
.35214 .65054 L
.34946 .65323 L
.34243 .66026 L
.33974 .66294 L
.33271 .66997 L
.33003 .67265 L
.323 .67968 L
.32032 .68236 L
.31329 .68939 L
.31061 .69208 L
.30358 .69911 L
.30089 .70179 L
.29386 .70882 L
.29118 .7115 L
.28415 .71853 L
.28147 .72121 L
.27444 .72824 L
.27176 .73093 L
.26473 .73796 L
.26204 .74064 L
.25501 .74767 L
.25233 .75035 L
.24588 .75738 L
.24262 .76006 L
.23936 .75738 L
.23291 .75035 L
.23022 .74767 L
.22319 .74064 L
.22051 .73796 L
.21348 .73093 L
.2108 .72824 L
.20377 .72121 L
.20109 .71853 L
.20109 .70882 L
.19406 .70179 L
.19137 .69911 L
.18434 .69208 L
.18166 .68939 L
.18166 .67968 L
.17463 .67265 L
.17195 .66997 L
.17195 .66026 L
.16492 .65323 L
.16224 .65054 L
.16224 .64083 L
.15521 .6338 L
.15252 .63112 L
Mistroke
.15252 .62141 L
.15252 .61169 L
.14549 .60466 L
.14281 .60198 L
.14281 .59227 L
.14281 .58256 L
.14281 .57284 L
.13578 .56581 L
.1331 .56313 L
.1331 .55342 L
.1331 .54371 L
.1331 .53399 L
.1331 .52428 L
.1331 .51457 L
.1331 .50486 L
.1331 .49514 L
.1331 .48543 L
.1331 .47572 L
.1331 .46601 L
.1331 .45629 L
.1331 .44658 L
.1331 .43687 L
.13578 .43419 L
.14281 .42716 L
.14281 .41744 L
.14281 .40773 L
.14281 .39802 L
.14549 .39534 L
.15252 .38831 L
.15252 .37859 L
.15252 .36888 L
.15521 .3662 L
.16224 .35917 L
.16224 .34946 L
.16492 .34677 L
.17195 .33974 L
.17195 .33003 L
.17463 .32735 L
.18166 .32032 L
.18166 .31061 L
.18434 .30792 L
.19137 .30089 L
.19406 .29821 L
.20109 .29118 L
.20109 .28147 L
.20377 .27879 L
.2108 .27176 L
.21348 .26907 L
.22051 .26204 L
.22319 .25936 L
Mistroke
.23022 .25233 L
.23291 .24965 L
.23994 .24262 L
.24262 .23994 L
.24965 .23291 L
.25233 .23022 L
.25936 .22319 L
.26204 .22051 L
.26907 .21348 L
.27176 .2108 L
.27879 .20377 L
.28147 .20109 L
.29118 .20109 L
.29821 .19406 L
.30089 .19137 L
.30792 .18434 L
.31061 .18166 L
.32032 .18166 L
.32735 .17463 L
.33003 .17195 L
.33974 .17195 L
.34677 .16492 L
.34946 .16224 L
.35917 .16224 L
.3662 .15521 L
.36888 .15252 L
.37859 .15252 L
.38831 .15252 L
.39534 .14549 L
.39802 .14281 L
.40773 .14281 L
.41744 .14281 L
.42716 .14281 L
.43419 .13578 L
.43687 .1331 L
Mfstroke
.9 g
.43687 .13402 m
.44658 .13402 L
.45629 .13402 L
.46601 .13402 L
.47572 .13402 L
.48543 .13402 L
.49514 .13402 L
.50486 .13402 L
.51457 .13402 L
.52428 .13402 L
.53399 .13402 L
.54371 .13402 L
.55342 .13402 L
.56313 .13402 L
.5649 .13578 L
.57284 .14373 L
.58256 .14373 L
.59227 .14373 L
.60198 .14373 L
.60375 .14549 L
.61169 .15344 L
.62141 .15344 L
.63112 .15344 L
.63288 .15521 L
.64083 .16315 L
.65054 .16315 L
.65231 .16492 L
.66026 .17287 L
.66997 .17287 L
.67173 .17463 L
.67968 .18258 L
.68939 .18258 L
.69116 .18434 L
.69911 .19229 L
.70087 .19406 L
.70882 .202 L
.71853 .202 L
.7203 .20377 L
.72824 .21172 L
.73001 .21348 L
.73796 .22143 L
.73972 .22319 L
.74767 .23114 L
.74943 .23291 L
.75738 .24085 L
.75915 .24262 L
.76709 .25057 L
.76886 .25233 L
.77681 .26028 L
.77857 .26204 L
.78652 .26999 L
.78828 .27176 L
.79623 .2797 L
.798 .28147 L
.798 .29118 L
.80594 .29913 L
.80771 .30089 L
.81566 .30884 L
.81742 .31061 L
.81742 .32032 L
.82537 .32827 L
.82713 .33003 L
.82713 .33974 L
.83508 .34769 L
.83685 .34946 L
.83685 .35917 L
.84479 .36712 L
.84656 .36888 L
.84656 .37859 L
.84656 .38831 L
.85451 .39625 L
.85627 .39802 L
.85627 .40773 L
.85627 .41744 L
.85627 .42716 L
.86422 .4351 L
.86598 .43687 L
.86598 .44658 L
.86598 .45629 L
.86598 .46601 L
.86598 .47572 L
.86598 .48543 L
.86598 .49514 L
.86598 .50486 L
.86598 .51457 L
.86598 .52428 L
.86598 .53399 L
.86598 .54371 L
.86598 .55342 L
.86598 .56313 L
.86422 .5649 L
.85627 .57284 L
.85627 .58256 L
.85627 .59227 L
.85627 .60198 L
.85451 .60375 L
.84656 .61169 L
.84656 .62141 L
.84656 .63112 L
.84479 .63288 L
.83685 .64083 L
.83685 .65054 L
.83508 .65231 L
.82713 .66026 L
.82713 .66997 L
.82537 .67173 L
.81742 .67968 L
.81742 .68939 L
.81566 .69116 L
.80771 .69911 L
.80594 .70087 L
.798 .70882 L
.798 .71853 L
.79623 .7203 L
.78828 .72824 L
.78652 .73001 L
.77857 .73796 L
.77681 .73972 L
.76886 .74767 L
.76709 .74943 L
.75966 .75738 L
.75738 .75915 L
.7551 .75738 L
.74767 .74943 L
.7459 .74767 L
.73796 .73972 L
.73619 .73796 L
.72824 .73001 L
.72648 .72824 L
.71853 .7203 L
.71677 .71853 L
.70882 .71058 L
.70705 .70882 L
.69911 .70087 L
.69734 .69911 L
.68939 .69116 L
.68763 .68939 L
.67968 .68145 L
.67792 .67968 L
.66997 .67173 L
.6682 .66997 L
.66026 .66202 L
.65849 .66026 L
.65054 .65231 L
.64878 .65054 L
.64083 .6426 L
.63907 .64083 L
.63112 .63288 L
.62935 .63112 L
.62141 .62317 L
.61964 .62141 L
.61169 .61346 L
.60993 .61169 L
.60198 .60375 L
.60022 .60198 L
.59227 .59403 L
.5905 .59227 L
.58256 .58432 L
.58079 .58256 L
.57284 .57461 L
.57108 .57284 L
.56313 .5649 L
.56137 .56313 L
.55342 .55518 L
.55165 .55342 L
.54371 .54547 L
.54194 .54371 L
.53399 .53576 L
.53223 .53399 L
.52428 .52605 L
.52252 .52428 L
.51457 .51633 L
.5128 .51457 L
.50486 .50662 L
.49514 .50662 L
.4872 .51457 L
.48543 .51633 L
.47748 .52428 L
.47572 .52605 L
.46777 .53399 L
.46601 .53576 L
.45806 .54371 L
.45629 .54547 L
.44835 .55342 L
.44658 .55518 L
.43863 .56313 L
.43687 .5649 L
.42892 .57284 L
.42716 .57461 L
.41921 .58256 L
.41744 .58432 L
.4095 .59227 L
.40773 .59403 L
.39978 .60198 L
.39802 .60375 L
.39007 .61169 L
.38831 .61346 L
.38036 .62141 L
.37859 .62317 L
.37065 .63112 L
.36888 .63288 L
.36093 .64083 L
.35917 .6426 L
.35122 .65054 L
.34946 .65231 L
.34151 .66026 L
.33974 .66202 L
.3318 .66997 L
.33003 .67173 L
.32208 .67968 L
.32032 .68145 L
.31237 .68939 L
.31061 .69116 L
.30266 .69911 L
.30089 .70087 L
.29295 .70882 L
.29118 .71058 L
.28323 .71853 L
.28147 .7203 L
.27352 .72824 L
.27176 .73001 L
.26381 .73796 L
.26204 .73972 L
.2541 .74767 L
.25233 .74943 L
.2449 .75738 L
.24262 .75915 L
.24034 .75738 L
.23291 .74943 L
.23114 .74767 L
.22319 .73972 L
.22143 .73796 L
.21348 .73001 L
.21172 .72824 L
.20377 .7203 L
.202 .71853 L
.202 .70882 L
.19406 .70087 L
.19229 .69911 L
.18434 .69116 L
.18258 .68939 L
.18258 .67968 L
.17463 .67173 L
.17287 .66997 L
.17287 .66026 L
.16492 .65231 L
.16315 .65054 L
.16315 .64083 L
.15521 .63288 L
.15344 .63112 L
.15344 .62141 L
.15344 .61169 L
.14549 .60375 L
.14373 .60198 L
.14373 .59227 L
.14373 .58256 L
.14373 .57284 L
.13578 .5649 L
.13402 .56313 L
.13402 .55342 L
.13402 .54371 L
.13402 .53399 L
.13402 .52428 L
.13402 .51457 L
.13402 .50486 L
.13402 .49514 L
.13402 .48543 L
.13402 .47572 L
.13402 .46601 L
.13402 .45629 L
.13402 .44658 L
.13402 .43687 L
.13578 .4351 L
.14373 .42716 L
.14373 .41744 L
.14373 .40773 L
.14373 .39802 L
.14549 .39625 L
.15344 .38831 L
.15344 .37859 L
.15344 .36888 L
.15521 .36712 L
.16315 .35917 L
.16315 .34946 L
.16492 .34769 L
.17287 .33974 L
.17287 .33003 L
.17463 .32827 L
.18258 .32032 L
.18258 .31061 L
.18434 .30884 L
.19229 .30089 L
.19406 .29913 L
.202 .29118 L
.202 .28147 L
.20377 .2797 L
.21172 .27176 L
.21348 .26999 L
.22143 .26204 L
.22319 .26028 L
.23114 .25233 L
.23291 .25057 L
.24085 .24262 L
.24262 .24085 L
.25057 .23291 L
.25233 .23114 L
.26028 .22319 L
.26204 .22143 L
.26999 .21348 L
.27176 .21172 L
.2797 .20377 L
.28147 .202 L
.29118 .202 L
.29913 .19406 L
.30089 .19229 L
.30884 .18434 L
.31061 .18258 L
.32032 .18258 L
.32827 .17463 L
.33003 .17287 L
.33974 .17287 L
.34769 .16492 L
.34946 .16315 L
.35917 .16315 L
.36712 .15521 L
.36888 .15344 L
.37859 .15344 L
.38831 .15344 L
.39625 .14549 L
.39802 .14373 L
.40773 .14373 L
.41744 .14373 L
.42716 .14373 L
.4351 .13578 L
F
0 g
.43687 .13402 m
.44658 .13402 L
.45629 .13402 L
.46601 .13402 L
.47572 .13402 L
.48543 .13402 L
.49514 .13402 L
.50486 .13402 L
.51457 .13402 L
.52428 .13402 L
.53399 .13402 L
.54371 .13402 L
.55342 .13402 L
.56313 .13402 L
.5649 .13578 L
.57284 .14373 L
.58256 .14373 L
.59227 .14373 L
.60198 .14373 L
.60375 .14549 L
.61169 .15344 L
.62141 .15344 L
.63112 .15344 L
.63288 .15521 L
.64083 .16315 L
.65054 .16315 L
.65231 .16492 L
.66026 .17287 L
.66997 .17287 L
.67173 .17463 L
.67968 .18258 L
.68939 .18258 L
.69116 .18434 L
.69911 .19229 L
.70087 .19406 L
.70882 .202 L
.71853 .202 L
.7203 .20377 L
.72824 .21172 L
.73001 .21348 L
.73796 .22143 L
.73972 .22319 L
.74767 .23114 L
.74943 .23291 L
.75738 .24085 L
.75915 .24262 L
.76709 .25057 L
.76886 .25233 L
.77681 .26028 L
.77857 .26204 L
Mistroke
.78652 .26999 L
.78828 .27176 L
.79623 .2797 L
.798 .28147 L
.798 .29118 L
.80594 .29913 L
.80771 .30089 L
.81566 .30884 L
.81742 .31061 L
.81742 .32032 L
.82537 .32827 L
.82713 .33003 L
.82713 .33974 L
.83508 .34769 L
.83685 .34946 L
.83685 .35917 L
.84479 .36712 L
.84656 .36888 L
.84656 .37859 L
.84656 .38831 L
.85451 .39625 L
.85627 .39802 L
.85627 .40773 L
.85627 .41744 L
.85627 .42716 L
.86422 .4351 L
.86598 .43687 L
.86598 .44658 L
.86598 .45629 L
.86598 .46601 L
.86598 .47572 L
.86598 .48543 L
.86598 .49514 L
.86598 .50486 L
.86598 .51457 L
.86598 .52428 L
.86598 .53399 L
.86598 .54371 L
.86598 .55342 L
.86598 .56313 L
.86422 .5649 L
.85627 .57284 L
.85627 .58256 L
.85627 .59227 L
.85627 .60198 L
.85451 .60375 L
.84656 .61169 L
.84656 .62141 L
.84656 .63112 L
.84479 .63288 L
Mistroke
.83685 .64083 L
.83685 .65054 L
.83508 .65231 L
.82713 .66026 L
.82713 .66997 L
.82537 .67173 L
.81742 .67968 L
.81742 .68939 L
.81566 .69116 L
.80771 .69911 L
.80594 .70087 L
.798 .70882 L
.798 .71853 L
.79623 .7203 L
.78828 .72824 L
.78652 .73001 L
.77857 .73796 L
.77681 .73972 L
.76886 .74767 L
.76709 .74943 L
.75966 .75738 L
.75738 .75915 L
.7551 .75738 L
.74767 .74943 L
.7459 .74767 L
.73796 .73972 L
.73619 .73796 L
.72824 .73001 L
.72648 .72824 L
.71853 .7203 L
.71677 .71853 L
.70882 .71058 L
.70705 .70882 L
.69911 .70087 L
.69734 .69911 L
.68939 .69116 L
.68763 .68939 L
.67968 .68145 L
.67792 .67968 L
.66997 .67173 L
.6682 .66997 L
.66026 .66202 L
.65849 .66026 L
.65054 .65231 L
.64878 .65054 L
.64083 .6426 L
.63907 .64083 L
.63112 .63288 L
.62935 .63112 L
.62141 .62317 L
Mistroke
.61964 .62141 L
.61169 .61346 L
.60993 .61169 L
.60198 .60375 L
.60022 .60198 L
.59227 .59403 L
.5905 .59227 L
.58256 .58432 L
.58079 .58256 L
.57284 .57461 L
.57108 .57284 L
.56313 .5649 L
.56137 .56313 L
.55342 .55518 L
.55165 .55342 L
.54371 .54547 L
.54194 .54371 L
.53399 .53576 L
.53223 .53399 L
.52428 .52605 L
.52252 .52428 L
.51457 .51633 L
.5128 .51457 L
.50486 .50662 L
.49514 .50662 L
.4872 .51457 L
.48543 .51633 L
.47748 .52428 L
.47572 .52605 L
.46777 .53399 L
.46601 .53576 L
.45806 .54371 L
.45629 .54547 L
.44835 .55342 L
.44658 .55518 L
.43863 .56313 L
.43687 .5649 L
.42892 .57284 L
.42716 .57461 L
.41921 .58256 L
.41744 .58432 L
.4095 .59227 L
.40773 .59403 L
.39978 .60198 L
.39802 .60375 L
.39007 .61169 L
.38831 .61346 L
.38036 .62141 L
.37859 .62317 L
.37065 .63112 L
Mistroke
.36888 .63288 L
.36093 .64083 L
.35917 .6426 L
.35122 .65054 L
.34946 .65231 L
.34151 .66026 L
.33974 .66202 L
.3318 .66997 L
.33003 .67173 L
.32208 .67968 L
.32032 .68145 L
.31237 .68939 L
.31061 .69116 L
.30266 .69911 L
.30089 .70087 L
.29295 .70882 L
.29118 .71058 L
.28323 .71853 L
.28147 .7203 L
.27352 .72824 L
.27176 .73001 L
.26381 .73796 L
.26204 .73972 L
.2541 .74767 L
.25233 .74943 L
.2449 .75738 L
.24262 .75915 L
.24034 .75738 L
.23291 .74943 L
.23114 .74767 L
.22319 .73972 L
.22143 .73796 L
.21348 .73001 L
.21172 .72824 L
.20377 .7203 L
.202 .71853 L
.202 .70882 L
.19406 .70087 L
.19229 .69911 L
.18434 .69116 L
.18258 .68939 L
.18258 .67968 L
.17463 .67173 L
.17287 .66997 L
.17287 .66026 L
.16492 .65231 L
.16315 .65054 L
.16315 .64083 L
.15521 .63288 L
.15344 .63112 L
Mistroke
.15344 .62141 L
.15344 .61169 L
.14549 .60375 L
.14373 .60198 L
.14373 .59227 L
.14373 .58256 L
.14373 .57284 L
.13578 .5649 L
.13402 .56313 L
.13402 .55342 L
.13402 .54371 L
.13402 .53399 L
.13402 .52428 L
.13402 .51457 L
.13402 .50486 L
.13402 .49514 L
.13402 .48543 L
.13402 .47572 L
.13402 .46601 L
.13402 .45629 L
.13402 .44658 L
.13402 .43687 L
.13578 .4351 L
.14373 .42716 L
.14373 .41744 L
.14373 .40773 L
.14373 .39802 L
.14549 .39625 L
.15344 .38831 L
.15344 .37859 L
.15344 .36888 L
.15521 .36712 L
.16315 .35917 L
.16315 .34946 L
.16492 .34769 L
.17287 .33974 L
.17287 .33003 L
.17463 .32827 L
.18258 .32032 L
.18258 .31061 L
.18434 .30884 L
.19229 .30089 L
.19406 .29913 L
.202 .29118 L
.202 .28147 L
.20377 .2797 L
.21172 .27176 L
.21348 .26999 L
.22143 .26204 L
.22319 .26028 L
Mistroke
.23114 .25233 L
.23291 .25057 L
.24085 .24262 L
.24262 .24085 L
.25057 .23291 L
.25233 .23114 L
.26028 .22319 L
.26204 .22143 L
.26999 .21348 L
.27176 .21172 L
.2797 .20377 L
.28147 .202 L
.29118 .202 L
.29913 .19406 L
.30089 .19229 L
.30884 .18434 L
.31061 .18258 L
.32032 .18258 L
.32827 .17463 L
.33003 .17287 L
.33974 .17287 L
.34769 .16492 L
.34946 .16315 L
.35917 .16315 L
.36712 .15521 L
.36888 .15344 L
.37859 .15344 L
.38831 .15344 L
.39625 .14549 L
.39802 .14373 L
.40773 .14373 L
.41744 .14373 L
.42716 .14373 L
.4351 .13578 L
.43687 .13402 L
Mfstroke
1 g
.43687 .135 m
.44658 .135 L
.45629 .135 L
.46601 .135 L
.47572 .135 L
.48543 .135 L
.49514 .135 L
.50486 .135 L
.51457 .135 L
.52428 .135 L
.53399 .135 L
.54371 .135 L
.55342 .135 L
.56313 .135 L
.56392 .13578 L
.57284 .14471 L
.58256 .14471 L
.59227 .14471 L
.60198 .14471 L
.60277 .14549 L
.61169 .15442 L
.62141 .15442 L
.63112 .15442 L
.6319 .15521 L
.64083 .16413 L
.65054 .16413 L
.65133 .16492 L
.66026 .17385 L
.66997 .17385 L
.67075 .17463 L
.67968 .18356 L
.68939 .18356 L
.69018 .18434 L
.69911 .19327 L
.69989 .19406 L
.70882 .20298 L
.71853 .20298 L
.71932 .20377 L
.72824 .2127 L
.72903 .21348 L
.73796 .22241 L
.73874 .22319 L
.74767 .23212 L
.74845 .23291 L
.75738 .24183 L
.75817 .24262 L
.76709 .25155 L
.76788 .25233 L
.77681 .26126 L
.77759 .26204 L
.78652 .27097 L
.7873 .27176 L
.79623 .28068 L
.79702 .28147 L
.79702 .29118 L
.80594 .30011 L
.80673 .30089 L
.81566 .30982 L
.81644 .31061 L
.81644 .32032 L
.82537 .32925 L
.82615 .33003 L
.82615 .33974 L
.83508 .34867 L
.83587 .34946 L
.83587 .35917 L
.84479 .3681 L
.84558 .36888 L
.84558 .37859 L
.84558 .38831 L
.85451 .39723 L
.85529 .39802 L
.85529 .40773 L
.85529 .41744 L
.85529 .42716 L
.86422 .43608 L
.865 .43687 L
.865 .44658 L
.865 .45629 L
.865 .46601 L
.865 .47572 L
.865 .48543 L
.865 .49514 L
.865 .50486 L
.865 .51457 L
.865 .52428 L
.865 .53399 L
.865 .54371 L
.865 .55342 L
.865 .56313 L
.86422 .56392 L
.85529 .57284 L
.85529 .58256 L
.85529 .59227 L
.85529 .60198 L
.85451 .60277 L
.84558 .61169 L
.84558 .62141 L
.84558 .63112 L
.84479 .6319 L
.83587 .64083 L
.83587 .65054 L
.83508 .65133 L
.82615 .66026 L
.82615 .66997 L
.82537 .67075 L
.81644 .67968 L
.81644 .68939 L
.81566 .69018 L
.80673 .69911 L
.80594 .69989 L
.79702 .70882 L
.79702 .71853 L
.79623 .71932 L
.7873 .72824 L
.78652 .72903 L
.77759 .73796 L
.77681 .73874 L
.76788 .74767 L
.76709 .74845 L
.75851 .75738 L
.75738 .75817 L
.75626 .75738 L
.74767 .74845 L
.74688 .74767 L
.73796 .73874 L
.73717 .73796 L
.72824 .72903 L
.72746 .72824 L
.71853 .71932 L
.71775 .71853 L
.70882 .7096 L
.70803 .70882 L
.69911 .69989 L
.69832 .69911 L
.68939 .69018 L
.68861 .68939 L
.67968 .68047 L
.6789 .67968 L
.66997 .67075 L
.66918 .66997 L
.66026 .66104 L
.65947 .66026 L
.65054 .65133 L
.64976 .65054 L
.64083 .64162 L
.64005 .64083 L
.63112 .6319 L
.63033 .63112 L
.62141 .62219 L
.62062 .62141 L
.61169 .61248 L
.61091 .61169 L
.60198 .60277 L
.6012 .60198 L
.59227 .59305 L
.59148 .59227 L
.58256 .58334 L
.58177 .58256 L
.57284 .57363 L
.57206 .57284 L
.56313 .56392 L
.56235 .56313 L
.55342 .5542 L
.55263 .55342 L
.54371 .54449 L
.54292 .54371 L
.53399 .53478 L
.53321 .53399 L
.52428 .52507 L
.5235 .52428 L
.51457 .51535 L
.51378 .51457 L
.50486 .50564 L
.49514 .50564 L
.48622 .51457 L
.48543 .51535 L
.4765 .52428 L
.47572 .52507 L
.46679 .53399 L
.46601 .53478 L
.45708 .54371 L
.45629 .54449 L
.44737 .55342 L
.44658 .5542 L
.43765 .56313 L
.43687 .56392 L
.42794 .57284 L
.42716 .57363 L
.41823 .58256 L
.41744 .58334 L
.40852 .59227 L
.40773 .59305 L
.3988 .60198 L
.39802 .60277 L
.38909 .61169 L
.38831 .61248 L
.37938 .62141 L
.37859 .62219 L
.36967 .63112 L
.36888 .6319 L
.35995 .64083 L
.35917 .64162 L
.35024 .65054 L
.34946 .65133 L
.34053 .66026 L
.33974 .66104 L
.33082 .66997 L
.33003 .67075 L
.3211 .67968 L
.32032 .68047 L
.31139 .68939 L
.31061 .69018 L
.30168 .69911 L
.30089 .69989 L
.29197 .70882 L
.29118 .7096 L
.28225 .71853 L
.28147 .71932 L
.27254 .72824 L
.27176 .72903 L
.26283 .73796 L
.26204 .73874 L
.25312 .74767 L
.25233 .74845 L
.24374 .75738 L
.24262 .75817 L
.24149 .75738 L
.23291 .74845 L
.23212 .74767 L
.22319 .73874 L
.22241 .73796 L
.21348 .72903 L
.2127 .72824 L
.20377 .71932 L
.20298 .71853 L
.20298 .70882 L
.19406 .69989 L
.19327 .69911 L
.18434 .69018 L
.18356 .68939 L
.18356 .67968 L
.17463 .67075 L
.17385 .66997 L
.17385 .66026 L
.16492 .65133 L
.16413 .65054 L
.16413 .64083 L
.15521 .6319 L
.15442 .63112 L
.15442 .62141 L
.15442 .61169 L
.14549 .60277 L
.14471 .60198 L
.14471 .59227 L
.14471 .58256 L
.14471 .57284 L
.13578 .56392 L
.135 .56313 L
.135 .55342 L
.135 .54371 L
.135 .53399 L
.135 .52428 L
.135 .51457 L
.135 .50486 L
.135 .49514 L
.135 .48543 L
.135 .47572 L
.135 .46601 L
.135 .45629 L
.135 .44658 L
.135 .43687 L
.13578 .43608 L
.14471 .42716 L
.14471 .41744 L
.14471 .40773 L
.14471 .39802 L
.14549 .39723 L
.15442 .38831 L
.15442 .37859 L
.15442 .36888 L
.15521 .3681 L
.16413 .35917 L
.16413 .34946 L
.16492 .34867 L
.17385 .33974 L
.17385 .33003 L
.17463 .32925 L
.18356 .32032 L
.18356 .31061 L
.18434 .30982 L
.19327 .30089 L
.19406 .30011 L
.20298 .29118 L
.20298 .28147 L
.20377 .28068 L
.2127 .27176 L
.21348 .27097 L
.22241 .26204 L
.22319 .26126 L
.23212 .25233 L
.23291 .25155 L
.24183 .24262 L
.24262 .24183 L
.25155 .23291 L
.25233 .23212 L
.26126 .22319 L
.26204 .22241 L
.27097 .21348 L
.27176 .2127 L
.28068 .20377 L
.28147 .20298 L
.29118 .20298 L
.30011 .19406 L
.30089 .19327 L
.30982 .18434 L
.31061 .18356 L
.32032 .18356 L
.32925 .17463 L
.33003 .17385 L
.33974 .17385 L
.34867 .16492 L
.34946 .16413 L
.35917 .16413 L
.3681 .15521 L
.36888 .15442 L
.37859 .15442 L
.38831 .15442 L
.39723 .14549 L
.39802 .14471 L
.40773 .14471 L
.41744 .14471 L
.42716 .14471 L
.43608 .13578 L
F
0 g
.43687 .135 m
.44658 .135 L
.45629 .135 L
.46601 .135 L
.47572 .135 L
.48543 .135 L
.49514 .135 L
.50486 .135 L
.51457 .135 L
.52428 .135 L
.53399 .135 L
.54371 .135 L
.55342 .135 L
.56313 .135 L
.56392 .13578 L
.57284 .14471 L
.58256 .14471 L
.59227 .14471 L
.60198 .14471 L
.60277 .14549 L
.61169 .15442 L
.62141 .15442 L
.63112 .15442 L
.6319 .15521 L
.64083 .16413 L
.65054 .16413 L
.65133 .16492 L
.66026 .17385 L
.66997 .17385 L
.67075 .17463 L
.67968 .18356 L
.68939 .18356 L
.69018 .18434 L
.69911 .19327 L
.69989 .19406 L
.70882 .20298 L
.71853 .20298 L
.71932 .20377 L
.72824 .2127 L
.72903 .21348 L
.73796 .22241 L
.73874 .22319 L
.74767 .23212 L
.74845 .23291 L
.75738 .24183 L
.75817 .24262 L
.76709 .25155 L
.76788 .25233 L
.77681 .26126 L
.77759 .26204 L
Mistroke
.78652 .27097 L
.7873 .27176 L
.79623 .28068 L
.79702 .28147 L
.79702 .29118 L
.80594 .30011 L
.80673 .30089 L
.81566 .30982 L
.81644 .31061 L
.81644 .32032 L
.82537 .32925 L
.82615 .33003 L
.82615 .33974 L
.83508 .34867 L
.83587 .34946 L
.83587 .35917 L
.84479 .3681 L
.84558 .36888 L
.84558 .37859 L
.84558 .38831 L
.85451 .39723 L
.85529 .39802 L
.85529 .40773 L
.85529 .41744 L
.85529 .42716 L
.86422 .43608 L
.865 .43687 L
.865 .44658 L
.865 .45629 L
.865 .46601 L
.865 .47572 L
.865 .48543 L
.865 .49514 L
.865 .50486 L
.865 .51457 L
.865 .52428 L
.865 .53399 L
.865 .54371 L
.865 .55342 L
.865 .56313 L
.86422 .56392 L
.85529 .57284 L
.85529 .58256 L
.85529 .59227 L
.85529 .60198 L
.85451 .60277 L
.84558 .61169 L
.84558 .62141 L
.84558 .63112 L
.84479 .6319 L
Mistroke
.83587 .64083 L
.83587 .65054 L
.83508 .65133 L
.82615 .66026 L
.82615 .66997 L
.82537 .67075 L
.81644 .67968 L
.81644 .68939 L
.81566 .69018 L
.80673 .69911 L
.80594 .69989 L
.79702 .70882 L
.79702 .71853 L
.79623 .71932 L
.7873 .72824 L
.78652 .72903 L
.77759 .73796 L
.77681 .73874 L
.76788 .74767 L
.76709 .74845 L
.75851 .75738 L
.75738 .75817 L
.75626 .75738 L
.74767 .74845 L
.74688 .74767 L
.73796 .73874 L
.73717 .73796 L
.72824 .72903 L
.72746 .72824 L
.71853 .71932 L
.71775 .71853 L
.70882 .7096 L
.70803 .70882 L
.69911 .69989 L
.69832 .69911 L
.68939 .69018 L
.68861 .68939 L
.67968 .68047 L
.6789 .67968 L
.66997 .67075 L
.66918 .66997 L
.66026 .66104 L
.65947 .66026 L
.65054 .65133 L
.64976 .65054 L
.64083 .64162 L
.64005 .64083 L
.63112 .6319 L
.63033 .63112 L
.62141 .62219 L
Mistroke
.62062 .62141 L
.61169 .61248 L
.61091 .61169 L
.60198 .60277 L
.6012 .60198 L
.59227 .59305 L
.59148 .59227 L
.58256 .58334 L
.58177 .58256 L
.57284 .57363 L
.57206 .57284 L
.56313 .56392 L
.56235 .56313 L
.55342 .5542 L
.55263 .55342 L
.54371 .54449 L
.54292 .54371 L
.53399 .53478 L
.53321 .53399 L
.52428 .52507 L
.5235 .52428 L
.51457 .51535 L
.51378 .51457 L
.50486 .50564 L
.49514 .50564 L
.48622 .51457 L
.48543 .51535 L
.4765 .52428 L
.47572 .52507 L
.46679 .53399 L
.46601 .53478 L
.45708 .54371 L
.45629 .54449 L
.44737 .55342 L
.44658 .5542 L
.43765 .56313 L
.43687 .56392 L
.42794 .57284 L
.42716 .57363 L
.41823 .58256 L
.41744 .58334 L
.40852 .59227 L
.40773 .59305 L
.3988 .60198 L
.39802 .60277 L
.38909 .61169 L
.38831 .61248 L
.37938 .62141 L
.37859 .62219 L
.36967 .63112 L
Mistroke
.36888 .6319 L
.35995 .64083 L
.35917 .64162 L
.35024 .65054 L
.34946 .65133 L
.34053 .66026 L
.33974 .66104 L
.33082 .66997 L
.33003 .67075 L
.3211 .67968 L
.32032 .68047 L
.31139 .68939 L
.31061 .69018 L
.30168 .69911 L
.30089 .69989 L
.29197 .70882 L
.29118 .7096 L
.28225 .71853 L
.28147 .71932 L
.27254 .72824 L
.27176 .72903 L
.26283 .73796 L
.26204 .73874 L
.25312 .74767 L
.25233 .74845 L
.24374 .75738 L
.24262 .75817 L
.24149 .75738 L
.23291 .74845 L
.23212 .74767 L
.22319 .73874 L
.22241 .73796 L
.21348 .72903 L
.2127 .72824 L
.20377 .71932 L
.20298 .71853 L
.20298 .70882 L
.19406 .69989 L
.19327 .69911 L
.18434 .69018 L
.18356 .68939 L
.18356 .67968 L
.17463 .67075 L
.17385 .66997 L
.17385 .66026 L
.16492 .65133 L
.16413 .65054 L
.16413 .64083 L
.15521 .6319 L
.15442 .63112 L
Mistroke
.15442 .62141 L
.15442 .61169 L
.14549 .60277 L
.14471 .60198 L
.14471 .59227 L
.14471 .58256 L
.14471 .57284 L
.13578 .56392 L
.135 .56313 L
.135 .55342 L
.135 .54371 L
.135 .53399 L
.135 .52428 L
.135 .51457 L
.135 .50486 L
.135 .49514 L
.135 .48543 L
.135 .47572 L
.135 .46601 L
.135 .45629 L
.135 .44658 L
.135 .43687 L
.13578 .43608 L
.14471 .42716 L
.14471 .41744 L
.14471 .40773 L
.14471 .39802 L
.14549 .39723 L
.15442 .38831 L
.15442 .37859 L
.15442 .36888 L
.15521 .3681 L
.16413 .35917 L
.16413 .34946 L
.16492 .34867 L
.17385 .33974 L
.17385 .33003 L
.17463 .32925 L
.18356 .32032 L
.18356 .31061 L
.18434 .30982 L
.19327 .30089 L
.19406 .30011 L
.20298 .29118 L
.20298 .28147 L
.20377 .28068 L
.2127 .27176 L
.21348 .27097 L
.22241 .26204 L
.22319 .26126 L
Mistroke
.23212 .25233 L
.23291 .25155 L
.24183 .24262 L
.24262 .24183 L
.25155 .23291 L
.25233 .23212 L
.26126 .22319 L
.26204 .22241 L
.27097 .21348 L
.27176 .2127 L
.28068 .20377 L
.28147 .20298 L
.29118 .20298 L
.30011 .19406 L
.30089 .19327 L
.30982 .18434 L
.31061 .18356 L
.32032 .18356 L
.32925 .17463 L
.33003 .17385 L
.33974 .17385 L
.34867 .16492 L
.34946 .16413 L
.35917 .16413 L
.3681 .15521 L
.36888 .15442 L
.37859 .15442 L
.38831 .15442 L
.39723 .14549 L
.39802 .14471 L
.40773 .14471 L
.41744 .14471 L
.42716 .14471 L
.43608 .13578 L
.43687 .135 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00C_ooool4o`000003oa0@4?oooooooooo02cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM02[ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0_ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@0_ooooo`Co000000?o410@ooooooooool09oooool0053ooooo
00?o0000ooooooooool0;_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo02Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0_ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0<?ooool00ol0003oooooooooo`0Y
ooooo`00AOooool6o`0000Gooooo00?o0000ooooooooool09_ooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo02Sooooo00Go410@oooooooooooooooooa0@
400_ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo02Wooooo001@ooooo`03o`000?oooooooooo02kooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo02Wooooo00Go0000ooooooooooooooooo`00000_ooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0`ooooo`03o`000?oooooooooo
02Wooooo001@ooooo`03o`000?oooooooooo02kooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`0:_ooool01Ol0003ooooooooooooooooo000002oooooo00Go
0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0<Oooool00ol0003o
ooooooooo`0Yooooo`00D?ooool00ol0003oooooooooo`0^ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`0/ooooo`05oa0@4?ooooooooooooooool@4100;oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Y
ooooo`00D?ooool00ol0003oooooooooo`0^ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`0/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Yooooo`00C_oo
ool00omEEEGoIVIVo`00000`ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0002_ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0_ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
033ooooo00?oEEEEofIVI_l00000:oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool002;oooooool00016o`00007ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00?ooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool09oooool1o`00007ooooo000Rooooo`03o`000?oooooo
oooo0?oooooo@_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo0?oooooo@_ooool1o`00
007ooooo000Rooooo`03o`000?oooooooooo0?oooooo@_ooool1o`00007ooooo000Rooooo`03o`00
0?oooooooooo0?oooooo@_ooool1o`00007ooooo000Rooooo`;o0000oooooom2ooooo`;o00000Ooo
ool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00007ooooo000Roooo
o`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`008_ooool00ol0003o
ooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool0
0oooooooo`0003Wo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0
000io`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006
ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00
007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`00
8_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Oooool002;ooooo00?o
0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooo
oooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`008_ooool2o`0000Coooooool0000io`00
00Gooooo0_l00001ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006ooooo`7o
00000Oooool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00007ooooo
000Rooooo`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`008_ooool0
0ol0003oooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Oooool002;ooooo00?o0000oooo
ooooool00oooooooo`0003Wo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?o
ooooool0000io`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000
>Ol00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_oo
ool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001
ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Oooool002;o
oooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00007ooooo000Rooooo`;o0000
1?ooooooo`0003Wo00001Oooool2o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0
000io`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006
ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00
007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`00
8_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Oooool002;ooooo00?o
0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooo
oooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03oooo
oooo0000>Ol00006ooooo`7o00000Oooool001Sooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`003ooo
ool6o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooooooo0000>Ol0
0006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01Oooool3o`0000?oooooool0000i
o`0000Cooooo0ol00001ooooo`006_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?oooooool0000io`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?oooooQol0000[ooooohKo00001_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00ooooon6o`0002goooooQOl00006ooooo`7o0000
0Oooool001Sooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`03ooooohGo0000;ooo
oon4o`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03ooooogco0000@Ooooomk
o`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03ooooog[o0000AOoooomio`00
00Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03ooooogWo0000Aooooomho`0000Ko
oooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03ooooog;o0000EOoooomao`0000Kooooo
0Ol00001ooooo`008_ooool00ol0003oooooooooo`03ooooog7o0000Eooooom`o`0000Kooooo0Ol0
0001ooooo`008_ooool00ol0003oooooooooo`03ooooog3o0000FOoooom_o`0000Kooooo0Ol00001
ooooo`008_ooool00ol0003oooooooooo`03ooooofoo0000Fooooom^o`0000Kooooo0Ol00001oooo
o`008_ooool2o`0000CoooooJol0001Sooooof[o00001Oooool2o`00007ooooo000Rooooo`03o`00
0?oooooooooo00?oooooJ_l0001UooooofWo00001_ooool1o`00007ooooo000Rooooo`03o`000?oo
oooooooo00?oooooJOl0001WooooofSo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooo
oooo00?oooooIOl0001_ooooofCo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo
00?oooooI?l0001aooooof?o00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?o
ooooHol0001cooooof;o00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo
G_l0001moooooego00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooGOl0
001ooooooeco00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooG?l00021
oooooe_o00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooFol00023oooo
oe[o00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooF_l00025oooooeWo
00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooFOl00027oooooeSo0000
1_ooool1o`00007ooooo000Rooooo`;o00001?oooomEo`0008ooooooE?l00005ooooo`;o00000Ooo
ool002;ooooo00?o0000ooooooooool00ooooomDo`00097oooooDol00006ooooo`7o00000Oooool0
02;ooooo00?o0000ooooooooool00ooooomCo`0009?oooooD_l00006ooooo`7o00000Oooool002;o
oooo00?o0000ooooooooool00ooooomCo`0009?oooooD_l00006ooooo`7o00000Oooool002;ooooo
00?o0000ooooooooool00ooooomAo`0009OoooooD?l00006ooooo`7o00000Oooool002;ooooo00?o
0000ooooooooool00ooooom@o`0009WoooooCol00006ooooo`7o00000Oooool002;ooooo00?o0000
ooooooooool00ooooom?o`0009[oooooCol00006ooooo`7o00000Oooool002;ooooo00?o0000oooo
ooooool00ooooom?o`0009_oooooC_l00006ooooo`7o00000Oooool002;ooooo00?o0000oooooooo
ool00ooooom>o`0009goooooCOl00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool0
0ooooom=o`0009ooooooC?l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooo
oom;o`000:?oooooB_l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooom:
o`000:GoooooBOl00006ooooo`7o00000Oooool002;ooooo0_l00004ooooodWo0000Yooooom8o`00
00Gooooo0_l00001ooooo`008_ooool00ol0003oooooooooo`03ooooodSo0000ZOoooom7o`0000Ko
oooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03ooooodOo0000Zooooom6o`0000Kooooo
0Ol00001ooooo`008_ooool00ol0003oooooooooo`03ooooodKo0000[Ooooom5o`0000Kooooo0Ol0
0001ooooo`008_ooool00ol0003oooooooooo`03ooooodGo0000[ooooom4o`0000Kooooo0Ol00001
ooooo`008_ooool00ol0003oooooooooo`03ooooodCo0000/Ooooom3o`0000Kooooo0Ol00001oooo
o`008_ooool00ol0003oooooooooo`03oooood?o0000/ooooom2o`0000Kooooo0Ol00001ooooo`00
8_ooool00ol0003oooooooooo`03oooood;o0000]Ooooom1o`0000Kooooo0Ol00001ooooo`008_oo
ool00ol0003oooooooooo`03oooood7o0000]ooooom0o`0000Kooooo0Ol00001ooooo`008_ooool0
0ol0003oooooooooo`03oooood3o0000^Oooooloo`0000Kooooo0Ol00001ooooo`008_ooool00ol0
003oooooooooo`03oooood3o0000^Oooooloo`0000Kooooo0Ol00001ooooo`008_ooool00ol0003o
ooooooooo`03ooooocko0000_Ooooolmo`0000Kooooo0Ol00001ooooo`008_ooool2o`0000Cooooo
?Ol0002oooooocco00001Oooool2o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo??l0
0030ooooocco00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo??l00030
ooooocco00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo??l00030oooo
occo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo??l00030ooooocco
00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo??l00031oooooc_o0000
1_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo>ol00033oooooc[o00001_oo
ool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo>_l00035ooooocWo00001_ooool1
o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo>?l00038ooooocSo00001_ooool1o`00
007ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00?ooooo=ol0003:ooooocOo00001_ooool1
o`00007ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`03ooooocKo0000c?oooolfo`0000Kooooo0Ol00001
ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo=_l0003=ooooocGo00001_ooool1o`00007ooooo0007oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`?o00000ooooolf
o`000<gooooo=Ol00004ooooo`?o00000Oooool000Oooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`03ooooocKo0000cOoo
ooleo`0000Kooooo0Ol00001ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`03ooooocGo0000coooooldo`0000Kooooo0Ol0
0001ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`03ooooocCo0000dOoooolco`0000Kooooo0Ol00001ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo00?ooooo<ol0
003Coooooc;o00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo<ol0003C
oooooc;o00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo<ol0003Coooo
oc;o00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo<ol0003Coooooc;o
00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo<ol0003Coooooc;o0000
1_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo<_l0003Eoooooc7o00001_oo
ool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo<Ol0003Goooooc3o00001_ooool1
o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo<?l0003Ioooooboo00001_ooool1o`00
007ooooo000Rooooo`;o00001?ooool`o`000=Wooooo;ol00005ooooo`;o00000Oooool002;ooooo
00?o0000ooooooooool00oooool`o`000=Wooooo;ol00006ooooo`7o00000Oooool002;ooooo00?o
0000ooooooooool00oooool`o`000=Wooooo;ol00006ooooo`7o00000Oooool002;ooooo00?o0000
ooooooooool00oooool_o`000=_ooooo;_l00006ooooo`7o00000Oooool002;ooooo00?o0000oooo
ooooool00oooool^o`000=gooooo;Ol00006ooooo`7o00000Oooool002;ooooo00?o0000oooooooo
ool00oooool]o`000=oooooo;?l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool0
0oooool]o`000=oooooo;?l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooo
ool]o`000=oooooo;?l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00oooool]
o`000=oooooo;?l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00oooool]o`00
0=oooooo;?l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00oooool]o`000=oo
oooo;?l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00oooool]o`000=oooooo
;?l00006ooooo`7o00000Oooool002;ooooo0_l00004ooooobco0000hOooool[o`0000Gooooo0_l0
0001ooooo`008_ooool00ol0003oooooooooo`03ooooob_o0000hooooolZo`0000Kooooo0Ol00001
ooooo`008_ooool00ol0003oooooooooo`03ooooob[o0000iOoooolYo`0000Kooooo0Ol00001oooo
o`008_ooool00ol0003oooooooooo`03ooooob[o0000iOoooolYo`0000Kooooo0Ol00001ooooo`00
8_ooool00ol0003oooooooooo`03ooooob[o0000iOoooolYo`0000Kooooo0Ol00001ooooo`008_oo
ool00ol0003oooooooooo`03ooooob[o0000iOoooolYo`0000Kooooo0Ol00001ooooo`008_ooool0
0ol0003oooooooooo`03ooooob[o0000iOoooolYo`0000Kooooo0Ol00001ooooo`008_ooool00ol0
003oooooooooo`03ooooob[o0000iOoooolYo`0000Kooooo0Ol00001ooooo`008_ooool00ol0003o
ooooooooo`03ooooob[o0000iOoooolYo`0000Kooooo0Ol00001ooooo`008_ooool00ol0003ooooo
ooooo`03ooooob[o0000iOoooolYo`0000Kooooo0Ol00001ooooo`008_ooool00ol0003ooooooooo
o`03ooooob[o0000iOoooolYo`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03
ooooob[o0000iOoooolYo`0000Kooooo0Ol00001ooooo`008_ooool2o`0000Cooooo:_l0003Uoooo
obWo00001Oooool2o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo:Ol0003WooooobSo
00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo:?l0003YooooobOo0000
1_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo9ol0003[ooooobKo00001_oo
ool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo9_l0003/ooooobKo00001_ooool1
o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo9_l0003/ooooobKo00001_ooool1o`00
007ooooo000Rooooo`03o`000?oooooooooo00?ooooo9_l0003/ooooobKo00001_ooool1o`00007o
oooo000Rooooo`03o`000?oooooooooo00?ooooo9_l0003/ooooobKo00001_ooool1o`00007ooooo
000Rooooo`03o`000?oooooooooo00?ooooo9_l0003/ooooobKo00001_ooool1o`00007ooooo000R
ooooo`03o`000?oooooooooo00?ooooo9_l0003/ooooobKo00001_ooool1o`00007ooooo000Roooo
o`03o`000?oooooooooo00?ooooo9_l0003/ooooobKo00001_ooool1o`00007ooooo000Rooooo`03
o`000?oooooooooo00?ooooo9_l0003/ooooobKo00001_ooool1o`00007ooooo000Rooooo`;o0000
1?oooolVo`000>cooooo9_l00005ooooo`;o00000Oooool002;ooooo00?o0000ooooooooool00ooo
oolVo`000>cooooo9_l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooolV
o`000>cooooo9_l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooolVo`00
0>cooooo9_l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooolVo`000>co
oooo9_l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooolVo`000>cooooo
9_l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooolVo`000>cooooo9_l0
0006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooolVo`000>cooooo9_l00006
ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooolVo`000>cooooo9_l00006oooo
o`7o00000Oooool001Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo
00?ooooo9_l0003/ooooobKo00001_ooool1o`00007ooooo000Gooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`03ooooobKo0000k?oooolVo`0000Kooooo0Ol00001oooo
o`005oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool00ooooolVo`00
0>cooooo9_l00006ooooo`7o00000Oooool001Oooooo00Go0000ooooooooooooooooo`000006oooo
o`?o00000ooooolVo`000>cooooo9_l00004ooooo`?o00000Oooool001Oooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo9_l0001dooooo`Go0000LooooolVo`00
00Kooooo0Ol00001ooooo`005oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooo
ooooool00ooooolVo`0007?ooooo1_l0001cooooobKo00001_ooool1o`00007ooooo000Gooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`03ooooobKo0000L_ooool8o`00
07;ooooo9_l00006ooooo`7o00000Oooool001Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooo
o`03o`000?oooooooooo00?ooooo9_l0001aooooo`[o0000LOoooolVo`0000Kooooo0Ol00001oooo
o`008_ooool00ol0003oooooooooo`03ooooobKo0000LOooool;o`00073ooooo9_l00006ooooo`7o
00000Oooool002;ooooo00?o0000ooooooooool00ooooolVo`00073ooooo3Ol0001_ooooobKo0000
1_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo9_l0001_ooooo`oo0000K_oo
oolVo`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03ooooobKo0000K_oooolA
o`0006gooooo9_l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooolVo`00
06gooooo4ol0001/ooooobKo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?o
oooo9_l0001/oooooaGo0000JooooolVo`0000Kooooo0Ol00001ooooo`008_ooool00ol0003ooooo
ooooo`03ooooobKo0000JooooolGo`0006[ooooo9_l00006ooooo`7o00000Oooool002;ooooo0_l0
0004ooooobKo0000J_oooolIo`0006Wooooo9_l00005ooooo`;o00000Oooool002;ooooo00?o0000
ooooooooool00ooooolVo`0006Wooooo6ol0001XooooobKo00001_ooool1o`00007ooooo000Roooo
o`03o`000?oooooooooo00?ooooo9_l0001Xoooooago0000IooooolVo`0000Kooooo0Ol00001oooo
o`008_ooool00ol0003oooooooooo`03ooooobKo0000IooooolOo`0006Kooooo9_l00006ooooo`7o
00000Oooool002;ooooo00?o0000ooooooooool00ooooolVo`0006Kooooo8Ol0001UooooobKo0000
1_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo9_l0001Uooooob?o0000I?oo
oolVo`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03ooooobKo0000I?oooolU
o`0006?ooooo9_l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooolVo`00
06?ooooo9ol0001RooooobKo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?o
oooo9ol0001Pooooob[o0000HOoooolVo`0000Kooooo0Ol00001ooooo`008_ooool00ol0003ooooo
ooooo`03ooooobSo0000Goooool[o`0005oooooo9ol00006ooooo`7o00000Oooool002;ooooo00?o
0000ooooooooool00ooooolYo`0005gooooo;Ol0001MooooobSo00001_ooool1o`00007ooooo000R
ooooo`03o`000?oooooooooo00?ooooo:_l0001Koooooboo0000FooooolYo`0000Kooooo0Ol00001
ooooo`008_ooool2o`0000Cooooo:_l0001Ioooooc?o0000FOoooolYo`0000Gooooo0_l00001oooo
o`008_ooool00ol0003oooooooooo`03ooooob[o0000F?ooooleo`0005Sooooo:Ol00006ooooo`7o
00000Oooool002;ooooo00?o0000ooooooooool00ooooolZo`0005Oooooo=ol0001GooooobWo0000
1_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo:_l0001GooooocOo0000Eooo
oolYo`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03ooooob[o0000E_ooooli
o`0005Kooooo:Ol00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooolZo`00
05Gooooo>ol0001EooooobWo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?o
oooo:_l0001Dooooocgo0000E?oooolYo`0000Kooooo0Ol00001ooooo`008_ooool00ol0003ooooo
ooooo`03ooooob[o0000Doooooloo`0005?ooooo:Ol00006ooooo`7o00000Oooool002;ooooo00?o
0000ooooooooool00ooooolZo`0005;ooooo@Ol0001BooooobWo00001_ooool1o`00007ooooo000R
ooooo`03o`000?oooooooooo00?ooooo:_l0001Aoooood?o0000DOoooolYo`0000Kooooo0Ol00001
ooooo`008_ooool00ol0003oooooooooo`03ooooob_o0000Cooooom5o`0004oooooo:_l00006oooo
o`7o00000Oooool002;ooooo00?o0000ooooooooool00oooool/o`0004goooooAol0001=ooooob_o
00001_ooool1o`00007ooooo000Rooooo`;o00001?ooool]o`0004_oooooBOl0001;ooooobco0000
1Oooool2o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo;Ol0001:oooood_o0000B_oo
ool/o`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03ooooobgo0000BOoooom=
o`0004Wooooo;?l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00oooool]o`00
04SoooooCol00018ooooobco00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?o
oooo;Ol00017oooooe7o0000Aoooool/o`0000Kooooo0Ol00001ooooo`008_ooool00ol0003ooooo
ooooo`03ooooobgo0000A_oooomCo`0004Kooooo;?l00006ooooo`7o00000Oooool002;ooooo00?o
0000ooooooooool00oooool]o`0004CoooooEol00014ooooobco00001_ooool1o`00007ooooo000R
ooooo`03o`000?oooooooooo00?ooooo;_l00012oooooeSo0000@oooool]o`0000Kooooo0Ol00001
ooooo`008_ooool00ol0003oooooooooo`03oooooboo0000@?oooomJo`00047ooooo;_l00006oooo
o`7o00000Oooool002;ooooo00?o0000ooooooooool00oooool`o`0003koooooG?l0000ooooooboo
00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo<?l0000noooooego0000
?_ooool_o`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03oooooc3o0000?Ooo
oomOo`0003gooooo;ol00006ooooo`7o00000Oooool002;ooooo0_l00004oooooc3o0000??oooomQ
o`0003cooooo;ol00005ooooo`;o00000Oooool002;ooooo00?o0000ooooooooool00oooool`o`00
03_oooooHol0000koooooboo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?o
oooo<Ol0000iooooofGo0000>Oooool`o`0000Kooooo0Ol00001ooooo`008_ooool00ol0003ooooo
ooooo`03oooooc;o0000=ooooomWo`0003Oooooo<Ol00006ooooo`7o00000Oooool002;ooooo00?o
0000ooooooooool00ooooolco`0003GoooooJOl0000eoooooc;o00001_ooool1o`00007ooooo000R
ooooo`03o`000?oooooooooo00?ooooo<ol0000dooooof_o0000=?oooolbo`0000Kooooo0Ol00001
ooooo`008_ooool00ol0003oooooooooo`03oooooc?o0000<ooooom]o`0003?ooooo<_l00006oooo
o`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooolco`0003;oooooKol0000boooooc;o
00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo=?l0000`ooooog7o0000
<?oooolco`0000Kooooo0Ol00001ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`03ooooocGo
0000;_oooomco`0002kooooo=?l00006ooooo`7o00000Oooool000Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00?o
oooo=_l0000/ooooogGo0000;?ooooleo`0000Kooooo0Ol00001ooooo`001oooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooocKo
0000:ooooomgo`0002_ooooo=Ol00006ooooo`7o00000Oooool000Oooooo00Go0000oooooooooooo
ooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00003ooooocKo0000:_oooomio`0002[o
oooo=Ol00004ooooo`?o00000Oooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`03ooooocKo0000:?oooomlo`00
02Sooooo=_l00006ooooo`7o00000Oooool000Oooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00ooooolgo`0002OoooooOOl0000Woooo
ocKo00001_ooool1o`00007ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo>?l0000Uooooogoo00009Ooooolgo`00
00Kooooo0Ol00001ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006oooo
o`03o`000?oooooooooo00?ooooo>Ol0000Soooooh7o00008ooooolho`0000Kooooo0Ol00001oooo
o`008_ooool00ol0003oooooooooo`03oooooc[o00008?oooon5o`0001oooooo>_l00006ooooo`7o
00000Oooool002;ooooo00?o0000ooooooooool00ooooolko`0001koooooQol0000Moooooc_o0000
1_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo??l0000LooooohWo00006ooo
oollo`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03ooooocco00007?oooon9
o`0001_ooooo??l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooollo`00
01_oooooRol0000Jooooocco00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?o
oooo??l0000Jooooohgo00006Ooooollo`0000Kooooo0Ol00001ooooo`008_ooool00ol0003ooooo
ooooo`03ooooocgo00006?oooon?o`0001Sooooo??l00006ooooo`7o00000Oooool002;ooooo0_l0
0004ooooocko00005_oooonAo`0001Kooooo?Ol00005ooooo`;o00000Oooool002;ooooo00?o0000
ooooooooool00oooooloo`0001CoooooTol0000Dooooocko00001_ooool1o`00007ooooo000Roooo
o`03o`000?oooooooooo00?ooooo@?l0000BoooooiGo00004_ooooloo`0000Kooooo0Ol00001oooo
o`008_ooool00ol0003oooooooooo`03oooood7o00004?oooonGo`00013ooooo@?l00006ooooo`7o
00000Oooool002;ooooo00?o0000ooooooooool00ooooom2o`0000koooooVOl0000>oooood7o0000
1_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo@ol0000<oooooi_o00003?oo
oom2o`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03ooooodCo00002_oooonM
o`0000[ooooo@ol00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooom5o`00
00SoooooWol00008ooooodCo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?o
ooooA_l00006oooooj7o00001_oooom5o`0000Kooooo0Ol00001ooooo`008_ooool00ol0003ooooo
ooooo`03ooooodOo00001?oooonSo`0000CoooooA_l00006ooooo`7o00000Oooool002;ooooo00?o
0000ooooooooool00ooooom8o`0000;oooooYOl00002ooooodOo00001_ooool1o`00007ooooo000R
ooooo`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`008_ooool2o`00
00Coooooool0000io`0000Gooooo0_l00001ooooo`008_ooool00ol0003oooooooooo`03oooooooo
0000>Ol00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo0000
1_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol0
0001ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Oooool0
02;ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00007ooooo000Rooooo`03
o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`008_ooool00ol0003ooooo
ooooo`03oooooooo0000>Ol00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooo
ooooo`0003Wo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000i
o`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006oooo
o`7o00000Oooool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00007o
oooo000Rooooo`;o00001?ooooooo`0003Wo00001Oooool2o`00007ooooo000Rooooo`03o`000?oo
oooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03
oooooooo0000>Ol00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00oooooooo`00
03Wo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000io`0000Ko
oooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006ooooo`7o0000
0Oooool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00007ooooo000R
ooooo`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`008_ooool00ol0
003oooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Oooool002;ooooo00?o0000oooooooo
ool00oooooooo`0003Wo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo
ool0000io`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000>Ol0
0006ooooo`7o00000Oooool002;ooooo0_l00004oooooooo0000>Ol00005ooooo`;o00000Oooool0
02;ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00007ooooo000Rooooo`03
o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`008_ooool00ol0003ooooo
ooooo`03oooooooo0000>Ol00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooo
ooooo`0003Wo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000i
o`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006oooo
o`7o00000Oooool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00007o
oooo000Rooooo`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`006?oo
ool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooooooo
o`0003Wo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooooooo`0003Wo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Go
oooo0ol00003oooooooo0000>Ol00004ooooo`?o00000Oooool001[ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooooooo0000>Ol00006
ooooo`7o00000Oooool001Sooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`03oooo
oooo0000>Ol00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo
00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000io`0000Kooooo
0Ol00001ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Ooo
ool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00007ooooo000Roooo
o`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`008_ooool00ol0003o
ooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool0
0oooooooo`0003Wo00001_ooool1o`00007ooooo000Rooooo`;o00001?ooooooo`0003Wo00001Ooo
ool2o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001
ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Oooool002;o
oooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00007ooooo000Rooooo`03o`00
0?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`008_ooool00ol0003ooooooooo
o`03oooooooo0000>Ol00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooooo
o`0003Wo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000io`00
00Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006ooooo`7o
00000Oooool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00007ooooo
000Rooooo`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`008_ooool0
0ol0003oooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Oooool002;ooooo0_l00004oooo
oooo0000>Ol00005ooooo`;o00000Oooool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo
00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000io`0000Kooooo
0Ol00001ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Ooo
ool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00007ooooo000Roooo
o`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`008_ooool00ol0003o
ooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool0
0oooooooo`0003Wo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0
000io`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006
ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00
007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`00
8_ooool2o`0000Coooooool0000io`0000Gooooo0_l00001ooooo`008_ooool00ol0003ooooooooo
o`3ooooood;ooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`3ooooood;ooooo0Ol00001
ooooo`008_ooool00ol0003oooooooooo`3ooooood;ooooo0Ol00001ooooo`008_ooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool09oooool1o`00007o
oooo000Rooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`008_ooooooo`0004Ko00000Ooo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1, -1, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "For boundary conditions,  on the edges of the cusp we take  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x = y, y) = \(\[Phi](x = \(-y\), y) = 
          1 - x\^\(\(2\)\(\ \)\) - y\^2\)\)]],
  ". This boundary condition matches continuously onto the boundary condition \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] = 0\)]],
  ",  applied to the circular part of the boundary. "
}], "Text"],

Cell[TextData[{
  "\tThis problem is analytically tractable. The solution was developed as an \
exercise in Chapter 4 [Sec. ",
  ButtonBox["4.3",
    ButtonData:>{"Chapter4.nb", "c:32"},
    ButtonStyle->"Hyperlink"],
  ", Exercise (9)] and is given below in cylindrical coordinates:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r, \[Theta])\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`lim\+\(\[Epsilon] \[Rule] \ 0\)\(\[Sum]\+\(n = 1\)\%\
\[Infinity] A\_n\ \((\[Epsilon])\)\ \(sin(\(\(n\ \[Pi]\)\/\(log(\[Epsilon])\)\
\) \(log(r)\))\) {sinh[\(\(n\ \[Pi]\)\/\(log(\[Epsilon])\)\) \((\[Theta] - \
\[Beta])\)] - \ 
                sinh[\(\(n\ \[Pi]\)\/\(log(\[Epsilon])\)\) \((\[Theta] - \
\[Beta] - \[Alpha])\)]}\)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(6.1.14)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  " runs between  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] = 3  \[Pi]/4\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\  + \ \[Alpha]\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = 3\ \[Pi]/2\)]],
  " is the opening angle of the domain. The Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  " are determined according to the equation"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(sinh(\(n\ \[Pi]\)\/\(log(\[Epsilon])\))\) \(\(A\_n\
\)(\[Epsilon])\) = \ \[Integral]\_\[Epsilon]\%1\( 
              sin(\(\(n\ \[Pi]\)\/\(log(\[Epsilon])\)\) \(Log(r)\))\) \((1 - 
                r\^2)\) \(\[DifferentialD]r\/r\)/\(\[Integral]\_\[Epsilon]\%1\
\(\( sin\^2\)(\(\(n\ \[Pi]\)\/\(log(\[Epsilon])\)\) \(log(
                        r)\))\) \[DifferentialD]r\/r\)\)]],
  "."
}], "Text"],

Cell["This analytic solution is constructed below:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(A[n_]\  = 
      Simplify[\ 
        Integrate[
            Sin[n\ Pi\ Log[r]\ /Log[\[Epsilon]]] \((1 - r\^2)\)/
                r, {r, \[Epsilon], 1}]/
          Integrate[
            Sin[n\ Pi\ Log[r]\ /Log[\[Epsilon]]]^2/r, {r, \[Epsilon], 1}], 
        n \[Element] Integers]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.25"],

Cell[BoxData[
    \(\(2\ \((\(-1\))\)\^n\ n\^2\ \[Pi]\^2\ \((\(-1\) + \[Epsilon]\^2)\) - 8\ \
\((\(-1\) + \((\(-1\))\)\^n)\)\ Log[\[Epsilon]]\^2\)\/\(n\^3\ \[Pi]\^3 + 4\ n\
\ \[Pi]\ Log[\[Epsilon]]\^2\)\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\[Epsilon]\  = \ 10. ^\(-8\); \[Alpha]\  = \ 3\ Pi/2. ; \[Beta]\  = \ 
      3  Pi/4;\[IndentingNewLine]\), "\n", 
    \(\(\[Phi][r_, \[Theta]_]\  = \ 
        Sum[A[n]\ Sin[\ 
              n\ Pi\ Log[r]/
                  Log[\[Epsilon]]]\ \((Sinh[
                    n\ Pi\ \((\[Theta] - \[Beta])\)/Log[\[Epsilon]]] + 
                  Sinh[n\ Pi\ \((\[Alpha] + \[Beta] - \[Theta])\)/
                        Log[\[Epsilon]]])\)/
              Sinh[n\ \[Pi]\ \[Alpha]/Log[\[Epsilon]]], {n, 1, 
            150}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.26"],

Cell[TextData[{
  "Along the edges of the cusp at ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] = \[Beta]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\  = \ \[Beta]\  + \ \[Alpha]\)]],
  ", this analytic solution can be seen to match the boundary condition ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\  = \ 1\  - \ r\^2\)]],
  ", as shown in Cell ",
  ButtonBox["6.27",
    ButtonData:>"Cell 6.27",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[{\[Phi][r, \[Beta]], \[Phi][r, \[Beta] + \[Alpha]], 
          1 - r^2}, {r, 0.0001, 1}, PlotRange \[Rule] All, 
        AxesLabel \[Rule] {"\<r\>", "\<\>"}, 
        PlotLabel -> "\<\[Phi] along edges of cusp\>"];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.27"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0237142 0.952476 0.014715 0.587363 [
[.21421 .00222 -9 -9 ]
[.21421 .00222 9 0 ]
[.4047 .00222 -9 -9 ]
[.4047 .00222 9 0 ]
[.5952 .00222 -9 -9 ]
[.5952 .00222 9 0 ]
[.7857 .00222 -9 -9 ]
[.7857 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 10 6 ]
[.01121 .13219 -18 -4.5 ]
[.01121 .13219 0 4.5 ]
[.01121 .24966 -18 -4.5 ]
[.01121 .24966 0 4.5 ]
[.01121 .36713 -18 -4.5 ]
[.01121 .36713 0 4.5 ]
[.01121 .48461 -18 -4.5 ]
[.01121 .48461 0 4.5 ]
[.01121 .60208 -6 -4.5 ]
[.01121 .60208 0 4.5 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21421 .01472 m
.21421 .02097 L
s
[(0.2)] .21421 .00222 0 1 Mshowa
.4047 .01472 m
.4047 .02097 L
s
[(0.4)] .4047 .00222 0 1 Mshowa
.5952 .01472 m
.5952 .02097 L
s
[(0.6)] .5952 .00222 0 1 Mshowa
.7857 .01472 m
.7857 .02097 L
s
[(0.8)] .7857 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07134 .01472 m
.07134 .01847 L
s
.11896 .01472 m
.11896 .01847 L
s
.16659 .01472 m
.16659 .01847 L
s
.26183 .01472 m
.26183 .01847 L
s
.30946 .01472 m
.30946 .01847 L
s
.35708 .01472 m
.35708 .01847 L
s
.45233 .01472 m
.45233 .01847 L
s
.49995 .01472 m
.49995 .01847 L
s
.54758 .01472 m
.54758 .01847 L
s
.64282 .01472 m
.64282 .01847 L
s
.69045 .01472 m
.69045 .01847 L
s
.73807 .01472 m
.73807 .01847 L
s
.83332 .01472 m
.83332 .01847 L
s
.88094 .01472 m
.88094 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02371 .13219 m
.02996 .13219 L
s
[(0.2)] .01121 .13219 1 0 Mshowa
.02371 .24966 m
.02996 .24966 L
s
[(0.4)] .01121 .24966 1 0 Mshowa
.02371 .36713 m
.02996 .36713 L
s
[(0.6)] .01121 .36713 1 0 Mshowa
.02371 .48461 m
.02996 .48461 L
s
[(0.8)] .01121 .48461 1 0 Mshowa
.02371 .60208 m
.02996 .60208 L
s
[(1)] .01121 .60208 1 0 Mshowa
.125 Mabswid
.02371 .04408 m
.02746 .04408 L
s
.02371 .07345 m
.02746 .07345 L
s
.02371 .10282 m
.02746 .10282 L
s
.02371 .16156 m
.02746 .16156 L
s
.02371 .19092 m
.02746 .19092 L
s
.02371 .22029 m
.02746 .22029 L
s
.02371 .27903 m
.02746 .27903 L
s
.02371 .3084 m
.02746 .3084 L
s
.02371 .33776 m
.02746 .33776 L
s
.02371 .3965 m
.02746 .3965 L
s
.02371 .42587 m
.02746 .42587 L
s
.02371 .45524 m
.02746 .45524 L
s
.02371 .51397 m
.02746 .51397 L
s
.02371 .54334 m
.02746 .54334 L
s
.02371 .57271 m
.02746 .57271 L
s
.25 Mabswid
.02371 0 m
.02371 .61803 L
s
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
75.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(along) show
111.000 13.000 moveto
(edges) show
147.000 13.000 moveto
(of) show
165.000 13.000 moveto
(cusp) show
189.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .60332 m
.06244 .60044 L
.08255 .59895 L
.08383 .5985 L
.08447 .59841 L
.08518 .59842 L
.08594 .59854 L
.08666 .59874 L
.08802 .59928 L
.0893 .5998 L
.09052 .60017 L
.09118 .60029 L
.09192 .60033 L
.0932 .60016 L
.09398 .59993 L
.09469 .59964 L
.09629 .59884 L
.09767 .5981 L
.09839 .59775 L
.09916 .59743 L
.09985 .59719 L
.10061 .59701 L
.1013 .59691 L
.10195 .59687 L
.10322 .59696 L
.10393 .59709 L
.10458 .59723 L
.10702 .59792 L
.10826 .59821 L
.10896 .59833 L
.10962 .5984 L
.11033 .59843 L
.11099 .59841 L
.11171 .59833 L
.11247 .59819 L
.11372 .59782 L
.1151 .59728 L
.11758 .59614 L
.11992 .59516 L
.12121 .59476 L
.12194 .59459 L
.12262 .59448 L
.12381 .59437 L
.12507 .59437 L
.12624 .59446 L
.1275 .59463 L
.12977 .59502 L
.13044 .59512 L
.13116 .59522 L
.13248 .59535 L
Mistroke
.13376 .59538 L
.13495 .59531 L
.13616 .59515 L
.13729 .59491 L
.13831 .59463 L
.13941 .59426 L
.14415 .59232 L
.14653 .59141 L
.14784 .59099 L
.14908 .59068 L
.15024 .59045 L
.15149 .59028 L
.15263 .59019 L
.15368 .59016 L
.15493 .59017 L
.15609 .59021 L
.15737 .59029 L
.15875 .59038 L
.16012 .59046 L
.16081 .59049 L
.16156 .59051 L
.1622 .59051 L
.16289 .5905 L
.16413 .59043 L
.16482 .59037 L
.16555 .59028 L
.16686 .59007 L
.16827 .58977 L
.16982 .58934 L
.17518 .58736 L
.17998 .58546 L
.18251 .58463 L
.18521 .58393 L
.1865 .58368 L
.18792 .58346 L
.18922 .5833 L
.19044 .58319 L
.19168 .5831 L
.19282 .58304 L
.1954 .58295 L
.19653 .58291 L
.19774 .58285 L
.19888 .58279 L
.19992 .58272 L
.20109 .58261 L
.2022 .58248 L
.20469 .58209 L
.20723 .58153 L
.20991 .58075 L
.21472 .579 L
Mistroke
.2204 .57665 L
.2256 .57465 L
.23043 .57315 L
.23502 .57211 L
.23986 .57132 L
.24515 .57059 L
.24975 .56984 L
.25464 .56876 L
.25927 .56738 L
.26345 .56585 L
.30354 .55128 L
.34211 .53634 L
.38313 .5185 L
.42264 .49956 L
.46063 .47729 L
.50108 .45563 L
.54001 .42965 L
.58139 .39949 L
.62125 .37149 L
.6596 .34145 L
.7004 .305 L
.73969 .2689 L
.77746 .23433 L
.81768 .19538 L
.85639 .15402 L
.89755 .10662 L
.9372 .05989 L
.97532 .0157 L
.97619 .01472 L
Mfstroke
.02381 .60332 m
.06244 .60044 L
.08255 .59895 L
.08383 .5985 L
.08447 .59841 L
.08518 .59842 L
.08594 .59854 L
.08666 .59874 L
.08802 .59928 L
.0893 .5998 L
.09052 .60017 L
.09118 .60029 L
.09192 .60033 L
.0932 .60016 L
.09398 .59993 L
.09469 .59964 L
.09629 .59884 L
.09767 .5981 L
.09839 .59775 L
.09916 .59743 L
.09985 .59719 L
.10061 .59701 L
.1013 .59691 L
.10195 .59687 L
.10322 .59696 L
.10393 .59709 L
.10458 .59723 L
.10702 .59792 L
.10826 .59821 L
.10896 .59833 L
.10962 .5984 L
.11033 .59843 L
.11099 .59841 L
.11171 .59833 L
.11247 .59819 L
.11372 .59782 L
.1151 .59728 L
.11758 .59614 L
.11992 .59516 L
.12121 .59476 L
.12194 .59459 L
.12262 .59448 L
.12381 .59437 L
.12507 .59437 L
.12624 .59446 L
.1275 .59463 L
.12977 .59502 L
.13044 .59512 L
.13116 .59522 L
.13248 .59535 L
Mistroke
.13376 .59538 L
.13495 .59531 L
.13616 .59515 L
.13729 .59491 L
.13831 .59463 L
.13941 .59426 L
.14415 .59232 L
.14653 .59141 L
.14784 .59099 L
.14908 .59068 L
.15024 .59045 L
.15149 .59028 L
.15263 .59019 L
.15368 .59016 L
.15493 .59017 L
.15609 .59021 L
.15737 .59029 L
.15875 .59038 L
.16012 .59046 L
.16081 .59049 L
.16156 .59051 L
.1622 .59051 L
.16289 .5905 L
.16413 .59043 L
.16482 .59037 L
.16555 .59028 L
.16686 .59007 L
.16827 .58977 L
.16982 .58934 L
.17518 .58736 L
.17998 .58546 L
.18251 .58463 L
.18521 .58393 L
.1865 .58368 L
.18792 .58346 L
.18922 .5833 L
.19044 .58319 L
.19168 .5831 L
.19282 .58304 L
.1954 .58295 L
.19653 .58291 L
.19774 .58285 L
.19888 .58279 L
.19992 .58272 L
.20109 .58261 L
.2022 .58248 L
.20469 .58209 L
.20723 .58153 L
.20991 .58075 L
.21472 .579 L
Mistroke
.2204 .57665 L
.2256 .57465 L
.23043 .57315 L
.23502 .57211 L
.23986 .57132 L
.24515 .57059 L
.24975 .56984 L
.25464 .56876 L
.25927 .56738 L
.26345 .56585 L
.30354 .55128 L
.34211 .53634 L
.38313 .5185 L
.42264 .49956 L
.46063 .47729 L
.50108 .45563 L
.54001 .42965 L
.58139 .39949 L
.62125 .37149 L
.6596 .34145 L
.7004 .305 L
.73969 .2689 L
.77746 .23433 L
.81768 .19538 L
.85639 .15402 L
.89755 .10662 L
.9372 .05989 L
.97532 .0157 L
.97619 .01472 L
Mfstroke
.02381 .60208 m
.02499 .60208 L
.02605 .60207 L
.02729 .60207 L
.02846 .60206 L
.03053 .60205 L
.03279 .60202 L
.03527 .60199 L
.0379 .60195 L
.04262 .60185 L
.04749 .60171 L
.05205 .60156 L
.06244 .60111 L
.07305 .6005 L
.08274 .59982 L
.10458 .59784 L
.12357 .59562 L
.14429 .59267 L
.18493 .58525 L
.22406 .57609 L
.26565 .56418 L
.30571 .55059 L
.34426 .53555 L
.38527 .51745 L
.42475 .49795 L
.46273 .4773 L
.50315 .45326 L
.54206 .42812 L
.58342 .39926 L
.62326 .36935 L
.66159 .33864 L
.70238 .30388 L
.74164 .26837 L
.77939 .23236 L
.8196 .19197 L
.85828 .15113 L
.89942 .10558 L
.93905 .05963 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Coooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool09?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;oooool4o`000003oa0@4?oooooooooo01gooooo001?ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00V
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<Oooool00ol0003oooooooooo`0Oooooo`00Coooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Vooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Ko
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<Oooool0
0ol0003oooooooooo`0Oooooo`00Coooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Voooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b037ooooo00?o
0000ooooooooool07oooool004oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02Gooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Oo
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09_ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00aooooo`03o`00
0?oooooooooo01oooooo001?ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Tooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Wooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Xooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@037ooooo00?o0000ooooooooool07ooo
ool004oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000aooooo`03o`000?oooooooooo01oooooo001?
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;oooool00omEEEGoIVIVo`00000Qooooo`00oooo
oomYooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooolhooooo`03oa0@4?l0003o000000?o
00002_ooool001kooooo00?o0000ooooooooool0ooooooljooooo`03o`000?oooooooooo00_ooooo
000Goooooooo0000>Ol0000;ooooo`03o`000?oooooooooo00_ooooo000Nooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00_ooooo000Nooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0=oooool2o`00
01?ooooo00?o0000oc8b<_oMgMd02oooool001kooooo00?o0000ooooooooool0oooooolTooooo`;o
00004oooool2o`000004ojVYZOlQ8B7o0000ob4Q8@Wooooo000Nooooo`03o`000?oooooooooo0?oo
oooo8oooool2o`0002?ooooo000Nooooo`03o`000?oooooooooo0?oooooo8_ooool2o`0002Cooooo
000Nooooo`03o`000?oooooooooo0?oooooo8_ooool00ol0003oooooooooo`0Sooooo`007_ooool0
0ol0003oooooooooo`3oooooob7ooooo00?o0000ooooooooool09?ooool001kooooo00?o0000oooo
ooooool0oooooolPooooo`03o`000?oooooooooo02Gooooo000Nooooo`?o0000oooooolOooooo`03
o`000?oooooooooo02Kooooo000Nooooo`03o`000?oooooooooo0?oooooo7_ooool2o`0002Sooooo
000Nooooo`03o`000?oooooooooo0?oooooo7Oooool2o`0002Wooooo000Nooooo`03o`000?oooooo
oooo0?oooooo7?ooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo0?oooooo6oooool2o`00
02_ooooo000Nooooo`03o`000?oooooooooo0?oooooo6_ooool2o`0002cooooo000Nooooo`03o`00
0?oooooooooo0?oooooo6_ooool2o`0002cooooo000Nooooo`03o`000?oooooooooo0?oooooo6Ooo
ool2o`0002gooooo000Nooooo`03o`000?oooooooooo0?oooooo6?ooool2o`0002kooooo000Noooo
o`?o0000oooooolGooooo`;o0000;oooool001kooooo00?o0000ooooooooool0oooooolFooooo`;o
0000<?ooool001kooooo00?o0000ooooooooool0oooooolFooooo`03o`000?oooooooooo02oooooo
000Nooooo`03o`000?oooooooooo0?oooooo5Oooool00ol0003oooooooooo`0`ooooo`007_ooool0
0ol0003oooooooooo`3ooooooaCooooo00?o0000ooooooooool0<Oooool001kooooo00?o0000oooo
ooooool0oooooolCooooo`03o`000?oooooooooo03;ooooo000Nooooo`03o`000?oooooooooo0?oo
oooo4_ooool00ol0003oooooooooo`0cooooo`007_ooool00ol0003oooooooooo`3ooooooa7ooooo
0_l0000eooooo`007_ooool00ol0003oooooooooo`3ooooooa3ooooo0_l0000fooooo`007_ooool0
0ol0003oooooooooo`3oooooo`oooooo0_l0000gooooo`007_ooool3o`000?oooooo3_ooool2o`00
03Sooooo000Nooooo`03o`000?oooooooooo0?oooooo3_ooool00ol0003oooooooooo`0gooooo`00
7_ooool00ol0003oooooooooo`3oooooo`gooooo0_l0000iooooo`007_ooool00ol0003ooooooooo
o`3oooooo`cooooo0_l0000jooooo`007_ooool00ol0003oooooooooo`3oooooo`_ooooo0_l0000k
ooooo`007_ooool00ol0003oooooooooo`3oooooo`[ooooo0_l0000looooo`001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool00ol0003oooooooooo`3ooooo
o`[ooooo00?o0000ooooooooool0>oooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000ooooooooool0ooooool9
ooooo`03o`000?oooooooooo03cooooo0004ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo0?oooooo2?ooool00ol0003oooooooooo`0m
ooooo`001?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3
o`000?oooooo1oooool00ol0003oooooooooo`0nooooo`001?ooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`3oooooo`Kooooo0_l00010
ooooo`001?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`3oooooo`Kooooo00?o0000ooooooooool0?oooool000Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool00ol0003ooooooooo
o`3oooooo`Gooooo00?o0000ooooooooool0@?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3oooooo`Cooooo
00?o0000ooooooooool0@Oooool001kooooo00?o0000ooooooooool0ooooool3ooooo`03o`000?oo
oooooooo04;ooooo000Nooooo`03o`000?oooooooooo0?oooooo0_ooool00ol0003oooooooooo`13
ooooo`007_ooool00ol0003oooooooooo`3oooooo`7ooooo00?o0000ooooooooool0A?ooool001ko
oooo00?o0000ooooooooool0ooooool00ol0003oooooooooo`15ooooo`007_ooool3o`000?kooooo
00?o0000ooooooooool0A_ooool001kooooo00?o0000ooooooooool0oOooool00ol0003ooooooooo
o`17ooooo`007_ooool00ol0003oooooooooo`3looooo`03o`000?oooooooooo04Sooooo000Noooo
o`03o`000?oooooooooo0?_ooooo00?o0000ooooooooool0BOooool001kooooo00?o0000oooooooo
ool0n_ooool00ol0003oooooooooo`1:ooooo`007_ooool00ol0003oooooooooo`3iooooo`03o`00
0?oooooooooo04_ooooo000Nooooo`03o`000?oooooooooo0?Sooooo00?o0000ooooooooool0C?oo
ool001kooooo00?o0000ooooooooool0moooool00ol0003oooooooooo`1=ooooo`007_ooool00ol0
003oooooooooo`3fooooo`03o`000?oooooooooo04kooooo000Nooooo`?o0000mOooool00ol0003o
ooooooooo`1?ooooo`007_ooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo053ooooo
000Nooooo`03o`000?oooooooooo0??ooooo00?o0000ooooooooool0DOooool001kooooo00?o0000
ooooooooool0l_ooool00ol0003oooooooooo`1Booooo`007_ooool00ol0003oooooooooo`3aoooo
o`03o`000?oooooooooo05?ooooo000Nooooo`03o`000?oooooooooo0?3ooooo00?o0000oooooooo
ool0E?ooool001kooooo00?o0000ooooooooool0koooool00ol0003oooooooooo`1Eooooo`007_oo
ool00ol0003oooooooooo`3^ooooo`03o`000?oooooooooo05Kooooo000Nooooo`03o`000?oooooo
oooo0>gooooo00?o0000ooooooooool0Eoooool001kooooo0ol0003/ooooo`03o`000?oooooooooo
05Sooooo000Nooooo`03o`000?oooooooooo0>_ooooo00?o0000ooooooooool0FOooool001kooooo
00?o0000ooooooooool0j_ooool00ol0003oooooooooo`1Jooooo`007_ooool00ol0003ooooooooo
o`3Yooooo`03o`000?oooooooooo05_ooooo000Nooooo`03o`000?oooooooooo0>Oooooo0_l0001N
ooooo`007_ooool00ol0003oooooooooo`3Vooooo`03o`000?oooooooooo05kooooo000Nooooo`03
o`000?oooooooooo0>Gooooo00?o0000ooooooooool0Goooool000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000oooooooo
ool0i?ooool00ol0003oooooooooo`1Pooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0hoooool00ol0003o
ooooooooo`1Qooooo`001?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00005ooooo`?o
0000h_ooool00ol0003oooooooooo`1Rooooo`001?ooool01Ol0003ooooooooooooooooo000000_o
oooo00CoA4A4omgMgOoooooo00001_ooool00ol0003oooooooooo`3Qooooo`03o`000?oooooooooo
06?ooooo0004ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00006
ooooo`03o`000?oooooooooo0>3ooooo00?o0000ooooooooool0I?ooool000Cooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo00?o0000ooooooooool0goooool0
0ol0003oooooooooo`1Uooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000001_ooool00ol0003oooooooooo`3Nooooo`03o`000?oooooooooo06Kooooo0004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05ooooo`03o`000?oooooo
oooo0=gooooo00?o0000ooooooooool0Ioooool001kooooo00?o0000ooooooooool0foooool2o`00
06[ooooo000Nooooo`03o`000?oooooooooo0=[ooooo00?o0000ooooooooool0J_ooool001kooooo
00?o0000ooooooooool0fOooool00ol0003oooooooooo`1[ooooo`007_ooool3o`000=Sooooo00?o
0000ooooooooool0K?ooool001kooooo00?o0000ooooooooool0eoooool00ol0003oooooooooo`1]
ooooo`007_ooool00ol0003oooooooooo`3Fooooo`03o`000?oooooooooo06kooooo000Nooooo`03
o`000?oooooooooo0=Gooooo00?o0000ooooooooool0Koooool001kooooo00?o0000ooooooooool0
e?ooool00ol0003oooooooooo`1`ooooo`007_ooool00ol0003oooooooooo`3Cooooo`03o`000?oo
oooooooo077ooooo000Nooooo`03o`000?oooooooooo0=;ooooo00?o0000ooooooooool0L_ooool0
01kooooo00?o0000ooooooooool0dOooool00ol0003oooooooooo`1cooooo`007_ooool00ol0003o
ooooooooo`3?ooooo`;o0000M_ooool001kooooo0ol0003>ooooo`03o`000?oooooooooo07Kooooo
000Nooooo`03o`000?oooooooooo0<gooooo00?o0000ooooooooool0Moooool001kooooo00?o0000
ooooooooool0c?ooool00ol0003oooooooooo`1hooooo`007_ooool00ol0003oooooooooo`3;oooo
o`03o`000?oooooooooo07Wooooo000Nooooo`03o`000?oooooooooo0<[ooooo00?o0000oooooooo
ool0N_ooool001kooooo00?o0000ooooooooool0bOooool00ol0003oooooooooo`1kooooo`007_oo
ool00ol0003oooooooooo`38ooooo`03o`000?oooooooooo07cooooo000Nooooo`03o`000?oooooo
oooo0<Oooooo00?o0000ooooooooool0OOooool001kooooo00?o0000ooooooooool0a_ooool00ol0
003oooooooooo`1nooooo`007_ooool00ol0003oooooooooo`35ooooo`03o`000?oooooooooo07oo
oooo000Nooooo`?o0000`oooool2o`0008;ooooo000Nooooo`03o`000?oooooooooo0<;ooooo0_l0
0023ooooo`007_ooool00ol0003oooooooooo`31ooooo`03o`000?oooooooooo08?ooooo000Noooo
o`03o`000?oooooooooo0;oooooo0_l00026ooooo`007_ooool00ol0003oooooooooo`2nooooo`;o
0000Qoooool001kooooo00?o0000ooooooooool0_Oooool00ol0003oooooooooo`27ooooo`001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<
c<`01Oooool00ol0003oooooooooo`2kooooo`;o0000R_ooool000Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Gooooo00?o0000oooo
ooooool0^_ooool2o`0008_ooooo0004ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0^Oooool00ol0003oooooooooo`2;
ooooo`001?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q
8@05ooooo`?o0000]oooool2o`0008kooooo0004ooooo`05o`000?ooooooooooooooool000002ooo
ool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0]_ooool2o`0008oooooo
0004ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`07ooooo`03o`00
0?oooooooooo0;Gooooo00?o0000ooooooooool0Soooool000Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`03omgMgOl@413oV9RH00Oooooo00?o0000ooooooooool0/oooool2o`0009;ooooo
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4105ooooo`03
o`000?oooooooooo0;;ooooo0_l0002Cooooo`007_ooool00ol0003oooooooooo`2aooooo`03o`00
0?oooooooooo09?ooooo000Nooooo`03o`000?oooooooooo0;3ooooo00?o0000ooooooooool0U?oo
ool001kooooo00?o0000ooooooooool0[_ooool2o`0009Oooooo000Nooooo`03o`000?oooooooooo
0:gooooo00?o0000ooooooooool0Uoooool001kooooo0ol0002/ooooo`03o`000?oooooooooo09So
oooo000Nooooo`03o`000?oooooooooo0:[ooooo0_l0002Kooooo`007_ooool00ol0003ooooooooo
o`2Yooooo`03o`000?oooooooooo09_ooooo000Nooooo`03o`000?oooooooooo0:Oooooo0_l0002N
ooooo`007_ooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo09kooooo000Nooooo`03
o`000?oooooooooo0:Cooooo0_l0002Qooooo`007_ooool00ol0003oooooooooo`2Sooooo`03o`00
0?oooooooooo0:7ooooo000Nooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool0X_oo
ool001kooooo00?o0000ooooooooool0X?ooool2o`000:Gooooo000Nooooo`?o0000Woooool00ol0
003oooooooooo`2Uooooo`007_ooool00ol0003oooooooooo`2Mooooo`;o0000Z?ooool001kooooo
00?o0000ooooooooool0Voooool2o`000:[ooooo000Nooooo`03o`000?oooooooooo09[ooooo0_l0
002[ooooo`007_ooool00ol0003oooooooooo`2Hooooo`;o0000[Oooool001kooooo00?o0000oooo
ooooool0U_ooool3o`000:kooooo000Nooooo`03o`000?oooooooooo09Gooooo0_l0002`ooooo`00
7_ooool00ol0003oooooooooo`2Cooooo`?o0000/Oooool001kooooo00?o0000ooooooooool0TOoo
ool3o`000;?ooooo000Nooooo`?o0000T?ooool3o`000;Cooooo000Nooooo`03o`000?oooooooooo
08kooooo0ol0002fooooo`007_ooool00ol0003oooooooooo`2=ooooo`;o0000^?ooool001kooooo
00?o0000ooooooooool0Roooool2o`000;[ooooo000Nooooo`03o`000?oooooooooo08[ooooo00?o
0000ooooooooool0^_ooool001kooooo00?o0000ooooooooool0R?ooool2o`000;gooooo000Noooo
o`03o`000?oooooooooo08Kooooo0_l0002oooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`24
ooooo`?o0000`?ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0P_ooool3o`000<;ooooo0004
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Gooooo
0ol00021ooooo`;o0000a?ooool000Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b
<_nHV9SooooooiRHV?lb<S801Oooool00ol0003oooooooooo`1oooooo`;o0000a_ooool000Cooooo
00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01Oooool00ol0
003oooooooooo`1mooooo`;o0000b?ooool000Cooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?nj^[[ooooookZj^_l@41001Oooool00ol0003oooooooooo`1kooooo`;o0000b_ooool0
00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001Ooo
ool00ol0003oooooooooo`1iooooo`?o0000boooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01Oooool00ol0003oooooooooo`1gooooo`?o0000
cOooool001kooooo00?o0000ooooooooool0MOooool3o`000<oooooo000Nooooo`03o`000?oooooo
oooo07?ooooo0ol0003Aooooo`007_ooool00ol0003oooooooooo`1aooooo`?o0000doooool001ko
oooo0ol0001_ooooo`?o0000eOooool001kooooo00?o0000ooooooooool0KOooool3o`000=Oooooo
000Nooooo`03o`000?oooooooooo06_ooooo0ol0003Iooooo`007_ooool00ol0003oooooooooo`1Y
ooooo`?o0000foooool001kooooo00?o0000ooooooooool0I_ooool3o`000=kooooo000Nooooo`03
o`000?oooooooooo06Cooooo0_l0003Qooooo`007_ooool00ol0003oooooooooo`1Qooooo`?o0000
hoooool001kooooo00?o0000ooooooooool0Goooool3o`000>Gooooo000Nooooo`03o`000?oooooo
oooo05cooooo1?l0003Wooooo`007_ooool3o`0005[ooooo0ol0003Zooooo`007_ooool00ol0003o
ooooooooo`1Hooooo`?o0000k?ooool001kooooo00?o0000ooooooooool0EOooool4o`000>kooooo
000Nooooo`03o`000?oooooooooo05?ooooo0ol0003aooooo`007_ooool00ol0003oooooooooo`1@
ooooo`Co0000loooool001kooooo00?o0000ooooooooool0COooool4o`000?Kooooo000Nooooo`03
o`000?oooooooooo04[ooooo1?l0003iooooo`007_ooool00ol0003oooooooooo`17ooooo`Co0000
o?ooool001kooooo00?o0000ooooooooool0A?ooool4o`000?oooooo000Nooooo`03o`000?oooooo
oooo03oooooo1_l0003oooooo`?ooooo000Nooooo`?o0000??ooool5o`000?oooooo1oooool001ko
oooo00?o0000ooooooooool0>?ooool6o`000?oooooo2_ooool001kooooo00?o0000ooooooooool0
<oooool6o`000?oooooo3oooool001kooooo00?o0000ooooooooool0;_ooool8o`000?oooooo4_oo
ool001kooooo00?o0000ooooooooool0:Oooool6o`000?oooooo6Oooool001kooooo00?o0000oooo
ooooool09?ooool8o`000?oooooo7?ooool001Gooooo1?l000000ol@413oooooooooo`02ooooo`03
o`000?oooooooooo01cooooo0ol000000ooooooo0000o`000003o`000?oooooo8oooool001Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Dooooo`go0000oooooolWooooo`005ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo4_l00003ooooo`;o0000oooo
ool^ooooo`005oooool00ol0003oooooooooo`04ooooo`_o0000oooooom0ooooo`005oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom8ooooo`005Oooool00omEEEGoIVIVo`000006ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00UOooool01OlQ8B7o0000o`000?m4
A4CogMgM01Sooooo00Go8B4Qo`000?l0003oA4A4omgMg@15ooooo`04oa0@4?l0003o0000o`0006So
oooo001Wooooo`03o`000?oooooooooo02kooooo00?oMgMgoc8b<_ooool06_ooool00omgMgOo<S8b
ooooo`15ooooo`03o`000?oooooooooo06Sooooo001Wooooo`03oa0@4?oMgMgooooo02oooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo06Sooooo001U
ooooo`05olc<c?l@413o0000o`000?n7QhL02_ooool01_nHV9So0000o`000?mgMgOo410@o`0000;o
oooo1Ol00003ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^0_ooool01?l@413o0000o`000?oo
ool2o`000008oa0@4?ooooook^k^oeEEEOl0003o410@olc<c?l00007ooooo`06onk^k_mEEEGo0000
o`000?m4A4Co^[Zj0_ooool03_o^k^koEEEEo`000?l0003oV9RHo`000?l@413oooooonk^k_mEEEGo
0000oa0@4?o<c<co00000_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P;ooooo00Ko410@oc8b
<_l0003o0000oa0@4?nYZJT7ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^0_ooool00ol@413o
0000o`000002o`000003oa0@4?oooooooooo00Oooooo00GoIVIVo`000?l0003oA4A4olc<c003oooo
o`09oiRHV?l0003o0000ogMgMol0003o410@ooooool@413o<S8b00;o000000?o410@ojVYZOooool0
0_ooool01_l0003oMgMgo`000?l0003oEEEEonk^kVGooooo001Uooooo`06ob4Q8On7QhOo<S8bojVY
ZOm4A4CoQhN72Oooool01Ol0003oc<c<onk^k_n7QhOo000000Gooooo00?o0000ooooooooool00ooo
ool01_mEEEGoMgMgooooooooooooMgMgoeEEE@?ooooo00Go0000ooooooooooooooooo`000002oooo
o`06oeEEEOmgMgOoooooonk^k_mEEEGo00001oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40;o
oooo00KoEEEEogMgMoooooook^k^oeEEEOl00002ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo0000
0_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo00Ko0000ojVYZOoooooooooookZj^_l0
0007ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE1?ooool00ol0003oooooooooo`09ooooo`06
ofIVI_mgMgOooooooooooon7QhOo410@0oooool01Ol0003oZJVYoooooon7QhOo000000;ooooo00Ko
0000ojVYZOoooooooooookZj^_l00003ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEEIOooool0
06Gooooo00Ko0000oooooomVIVKoQhN7omgMgOl@4109ooooo`05oa0@4?n7QhOoooooonk^k_l00000
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00?ok^k^o`000?ooool01_ooool00ol0
003oooooooooo`05ooooo`06o`000?ooooooooooooooooo^k^ko00000_ooool01_l0003ooooooooo
ooooooook^k^o`0000;ooooo00?o0000ooooooooool01_ooool01Onj^[[oQhN7ofIVI_mVIVKo410@
00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go^[Zj
ohN7QomVIVKoIVIVoa0@4003ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0Hooo
ool006Gooooo00Ko410@omgMgOmgMgOoMgMgooooool00009ooooo`03okZj^_l@413o000000;o0000
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00?ok^k^o`000?ooool01_ooool6o`00
00;ooooo00Ko0000ooooooooooooooooonk^k_l00002ooooo`06o`000?ooooooooooooooooo^k^ko
00000_ooool6o`0000;ooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h7ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Kooooo00Go0000ooooooooooooooooo`000002ooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOo
k^k^0oooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo06?ooooo001Uooooo`06ojVY
ZOm4A4CoV9RHodA4A?nHV9So410@3?ooool00oo<c<co0000ooooo`04ooooo`03o`000?oooooooooo
00?ooooo00KoEEEEogMgMoooooooooooogMgMomEEED3ooooo`05o`000?n7QhOoooooojVYZOl00000
0_ooool01_mEEEGoMgMgooooooo^k^koEEEEo`0000Oooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb
<S82ooooo`06ofIVI_mgMgOoooooonk^k_mEEEGo00000_ooool01_mEEEGoMgMgooooooo^k^koEEEE
o`0000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S82ooooo`06o`000?nj^[[oooooonk^k_mg
MgOo00001oooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@Cooooo00?o0000ooooooooool02Ooo
ool01_mVIVKoMgMgooooooooooooQhN7o`0000?ooooo00Go0000ooooooooooooooooo`000002oooo
o`06o`000?nj^[[oooooonk^k_mgMgOo00000oooool01_l0003oEEEEonk^k_ooooooMgMgofIVIVGo
oooo001Vooooo`05oiRHV?l0003o0000oa0@4?o<c<`02_ooool01?lb<S;o0000o`000?nHV9P5oooo
o`03o`000?oooooooooo00?ooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h2ooooo`03oa0@4?l0
003oMgMg00;o000000[oV9RHooooooooooook^k^oeEEEOl0003o8B4QojVYZOl0003o410@1_ooool0
1_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo00Kok^k^oeEEEOl0003o410@olc<c?l00002oooo
o`0:onk^k_mEEEGo0000ob4Q8OnYZJWo0000oa0@4?ooooook^k^oeEEE@;o000000KoA4A4onk^k_oo
ooooooooojVYZOlQ8B42o`000003oc8b<_l0003ooooo00Kooooo00Kok^k^oeEEEOl0003o0000oeEE
EOo^k^h2ooooo`03oa0@4?l0003o000000?o00002?ooool01_o^k^koIVIVo`000?l0003oA4A4o`00
00;ooooo00Co410@o`000?oooooooooo0_l00002ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o0000
0_ooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo06Cooooo001Wooooo`03okZj^_lb
<S;ooooo01Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo08gooooo001Xooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0Wooooo`03oa0@4?nj^[[ooooo08gooooo001looooo`03oa0@4?l0003o0000
02kooooo0_l0000Yooooo`04okZj^_l@413o0000oa0@48cooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.104687, -0.0829537, \
0.00422592, 0.00685281}}]
}, Open  ]],

Cell[TextData[{
  "However,  along ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\  = \ 3\ \[Pi]/2\)]],
  " (i.e. the ",
  Cell[BoxData[
      \(TraditionalForm\`\(-y\)\)]],
  " axis), the solution has a singular slope near the origin, as shown in \
Cell ",
  ButtonBox["6.28",
    ButtonData:>"Cell 6.28",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[\[Phi][r, \[Beta]\  + \ \[Alpha]/2], {r, 0.0001, 1}, 
        PlotRange \[Rule] All];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.28"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0237142 0.952476 0.0147151 0.592055 [
[.21421 .00222 -9 -9 ]
[.21421 .00222 9 0 ]
[.4047 .00222 -9 -9 ]
[.4047 .00222 9 0 ]
[.5952 .00222 -9 -9 ]
[.5952 .00222 9 0 ]
[.7857 .00222 -9 -9 ]
[.7857 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01121 .13313 -18 -4.5 ]
[.01121 .13313 0 4.5 ]
[.01121 .25154 -18 -4.5 ]
[.01121 .25154 0 4.5 ]
[.01121 .36995 -18 -4.5 ]
[.01121 .36995 0 4.5 ]
[.01121 .48836 -18 -4.5 ]
[.01121 .48836 0 4.5 ]
[.01121 .60677 -6 -4.5 ]
[.01121 .60677 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21421 .01472 m
.21421 .02097 L
s
[(0.2)] .21421 .00222 0 1 Mshowa
.4047 .01472 m
.4047 .02097 L
s
[(0.4)] .4047 .00222 0 1 Mshowa
.5952 .01472 m
.5952 .02097 L
s
[(0.6)] .5952 .00222 0 1 Mshowa
.7857 .01472 m
.7857 .02097 L
s
[(0.8)] .7857 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07134 .01472 m
.07134 .01847 L
s
.11896 .01472 m
.11896 .01847 L
s
.16659 .01472 m
.16659 .01847 L
s
.26183 .01472 m
.26183 .01847 L
s
.30946 .01472 m
.30946 .01847 L
s
.35708 .01472 m
.35708 .01847 L
s
.45233 .01472 m
.45233 .01847 L
s
.49995 .01472 m
.49995 .01847 L
s
.54758 .01472 m
.54758 .01847 L
s
.64282 .01472 m
.64282 .01847 L
s
.69045 .01472 m
.69045 .01847 L
s
.73807 .01472 m
.73807 .01847 L
s
.83332 .01472 m
.83332 .01847 L
s
.88094 .01472 m
.88094 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02371 .13313 m
.02996 .13313 L
s
[(0.2)] .01121 .13313 1 0 Mshowa
.02371 .25154 m
.02996 .25154 L
s
[(0.4)] .01121 .25154 1 0 Mshowa
.02371 .36995 m
.02996 .36995 L
s
[(0.6)] .01121 .36995 1 0 Mshowa
.02371 .48836 m
.02996 .48836 L
s
[(0.8)] .01121 .48836 1 0 Mshowa
.02371 .60677 m
.02996 .60677 L
s
[(1)] .01121 .60677 1 0 Mshowa
.125 Mabswid
.02371 .04432 m
.02746 .04432 L
s
.02371 .07392 m
.02746 .07392 L
s
.02371 .10352 m
.02746 .10352 L
s
.02371 .16273 m
.02746 .16273 L
s
.02371 .19233 m
.02746 .19233 L
s
.02371 .22193 m
.02746 .22193 L
s
.02371 .28114 m
.02746 .28114 L
s
.02371 .31074 m
.02746 .31074 L
s
.02371 .34035 m
.02746 .34035 L
s
.02371 .39955 m
.02746 .39955 L
s
.02371 .42915 m
.02746 .42915 L
s
.02371 .45876 m
.02746 .45876 L
s
.02371 .51796 m
.02746 .51796 L
s
.02371 .54756 m
.02746 .54756 L
s
.02371 .57717 m
.02746 .57717 L
s
.25 Mabswid
.02371 0 m
.02371 .61803 L
s
.5 Mabswid
.02381 .60332 m
.02605 .59115 L
.02846 .58196 L
.03279 .56871 L
.04262 .54502 L
.06244 .5081 L
.10458 .44878 L
.14603 .4026 L
.18596 .36477 L
.22437 .3327 L
.26524 .30214 L
.30459 .27549 L
.34242 .252 L
.38271 .22892 L
.42148 .20834 L
.46271 .18798 L
.50241 .16968 L
.54061 .15315 L
.58125 .13659 L
.62038 .12156 L
.66196 .10647 L
.70203 .09272 L
.74058 .08014 L
.78158 .06742 L
.82107 .05576 L
.85904 .04504 L
.89947 .03413 L
.93838 .02408 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000:oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0:oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=?ooool4o`000003oa0@4?oooooooooo00Kooooo001Aooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0:ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B40:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40=_ooool00ol0003oooooooooo`08ooooo`00DOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002_o
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000=_ooool0
0ol0003oooooooooo`08ooooo`00DOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h0:oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0[oooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03Kooooo00?o
0000ooooooooool02?ooool0057ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02[ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002go
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0:oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00fooooo`03o`00
0?oooooooooo00Sooooo001Aooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0]ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Kooooo00?o0000ooooooooool02?oo
ool0057ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000;Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000fooooo`03o`000?oooooooooo00Sooooo001A
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02_ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42_ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=?ooool00omEEEGoIVIVo`00000:ooooo`00oooo
oomYooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001?oooooool0001D
o`0000;ooooo000Kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool4o`00
00;ooooo00?o0000ooooooooool02?ooool001_ooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`0cooooo`Co00001_ooool00ol0003oooooooooo`08ooooo`006oooool00ol0003ooooo
ooooo`3ooooooc;ooooo1?l0000Eooooo`006oooool00ol0003oooooooooo`3oooooobgooooo1Ol0
000Iooooo`006oooool00ol0003oooooooooo`3oooooobSooooo1Ol0000Nooooo`006oooool00ol0
003oooooooooo`3oooooobCooooo1?l0000Sooooo`006oooool00ol0003oooooooooo`3oooooob7o
oooo0ol0000Wooooo`006oooool00ol0003oooooooooo`3ooooooakooooo0ol0000Zooooo`006ooo
ool00ol0003oooooooooo`3ooooooa_ooooo0ol0000]ooooo`006oooool3o`000?oooooo5oooool4
o`00033ooooo000Kooooo`03o`000?oooooooooo0?oooooo4_ooool5o`0003Cooooo000Kooooo`03
o`000?oooooooooo0?oooooo3_ooool4o`0003Wooooo000Kooooo`03o`000?oooooooooo0?oooooo
2_ooool4o`0003gooooo000Kooooo`03o`000?oooooooooo0?oooooo1oooool3o`00047ooooo000K
ooooo`03o`000?oooooooooo0?oooooo1?ooool3o`0004Cooooo000Kooooo`03o`000?oooooooooo
0?oooooo0Oooool3o`0004Oooooo000Kooooo`03o`000?oooooooooo0?gooooo0ol0001:ooooo`00
6oooool00ol0003oooooooooo`3jooooo`?o0000COooool001_ooooo00?o0000ooooooooool0mooo
ool3o`00053ooooo000Kooooo`?o0000m?ooool3o`0005?ooooo000Kooooo`03o`000?oooooooooo
0?7ooooo0ol0001Fooooo`006oooool00ol0003oooooooooo`3^ooooo`?o0000FOooool001_ooooo
00?o0000ooooooooool0joooool3o`0005cooooo000Kooooo`03o`000?oooooooooo0>Sooooo0ol0
001Oooooo`006oooool00ol0003oooooooooo`3Uooooo`?o0000H_ooool001_ooooo00?o0000oooo
ooooool0h_ooool3o`0006Gooooo000Kooooo`03o`000?oooooooooo0=oooooo0ol0001Xooooo`00
6oooool00ol0003oooooooooo`3Looooo`?o0000Joooool001_ooooo00?o0000ooooooooool0fOoo
ool3o`0006kooooo000Kooooo`?o0000e_ooool3o`00077ooooo000Kooooo`03o`000?oooooooooo
0=Cooooo0_l0001dooooo`006oooool00ol0003oooooooooo`3Aooooo`?o0000M_ooool001_ooooo
00?o0000ooooooooool0c_ooool3o`0007Wooooo000Kooooo`03o`000?oooooooooo0<_ooooo0ol0
001looooo`006oooool00ol0003oooooooooo`38ooooo`?o0000Ooooool001_ooooo00?o0000oooo
ooooool0a_ooool2o`0008;ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001_ooool00ol0003oooooooooo`33ooooo`?o0000Q?ooool00005ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo0<3ooooo0ol00027ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00?o0000ooooooooool0__ooool2o`0008[ooooo00001Ol0003ooooooooooooooooo
000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;_ooooo0ol0002<ooooo`0000Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0^Oooool2
o`0008oooooo00001Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`2fooooo`?o0000TOooool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0/oooool3o`0009Cooooo0000
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo0;3ooooo0ol0002Gooooo`006oooool00ol0003oooooooooo`2]ooooo`?o0000V_oo
ool001_ooooo00?o0000ooooooooool0Zoooool2o`0009gooooo000Kooooo`03o`000?oooooooooo
0:Wooooo0_l0002Oooooo`006oooool00ol0003oooooooooo`2Wooooo`;o0000XOooool001_ooooo
00?o0000ooooooooool0Y?ooool3o`000:?ooooo000Kooooo`?o0000X_ooool2o`000:Kooooo000K
ooooo`03o`000?oooooooooo0:3ooooo0_l0002Xooooo`006oooool00ol0003oooooooooo`2Noooo
o`;o0000Z_ooool001_ooooo00?o0000ooooooooool0W?ooool2o`000:cooooo000Kooooo`03o`00
0?oooooooooo09[ooooo0_l0002^ooooo`006oooool00ol0003oooooooooo`2Gooooo`?o0000/?oo
ool001_ooooo00?o0000ooooooooool0UOooool2o`000;?ooooo000Kooooo`03o`000?oooooooooo
09?ooooo0_l0002eooooo`006oooool00ol0003oooooooooo`2Aooooo`;o0000]oooool001_ooooo
00?o0000ooooooooool0Soooool2o`000;Wooooo000Kooooo`?o0000SOooool2o`000;_ooooo000K
ooooo`03o`000?oooooooooo08_ooooo0_l0002mooooo`006oooool00ol0003oooooooooo`29oooo
o`;o0000_oooool001_ooooo00?o0000ooooooooool0Qoooool2o`000<7ooooo000Kooooo`03o`00
0?oooooooooo08Gooooo0_l00033ooooo`006oooool00ol0003oooooooooo`23ooooo`;o0000aOoo
ool001_ooooo00?o0000ooooooooool0POooool2o`000<Oooooo000Kooooo`03o`000?oooooooooo
07oooooo0_l00039ooooo`006oooool00ol0003oooooooooo`1mooooo`;o0000boooool001_ooooo
00?o0000ooooooooool0O?ooool00ol0003oooooooooo`3;ooooo`006oooool3o`0007[ooooo0_l0
003>ooooo`006oooool00ol0003oooooooooo`1hooooo`;o0000d?ooool001_ooooo00?o0000oooo
ooooool0M_ooool2o`000=;ooooo000Kooooo`03o`000?oooooooooo07Cooooo0_l0003Dooooo`00
6oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo0=Cooooo000Kooooo`03o`000?oo
oooooooo077ooooo0_l0003Gooooo`006oooool00ol0003oooooooooo`1_ooooo`;o0000fOooool0
0005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04
ooooo`03o`000?oooooooooo06gooooo0_l0003Kooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06cooooo00?o0000
ooooooooool0foooool00005oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo00?o0000
ooooooooool0J_ooool2o`000=kooooo00001Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo00001oooool3o`0006Sooooo0_l0003Pooooo`0000Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0Ioooool00ol0003ooooo
ooooo`3Pooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo
00?o0000ooooooooool0IOooool2o`000>?ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`1Sooooo`;o0000iOooool00005onk^k_lb
<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo06;ooooo
00?o0000ooooooooool0iOooool001_ooooo00?o0000ooooooooool0H?ooool2o`000>Sooooo000K
ooooo`03o`000?oooooooooo05kooooo0_l0003Zooooo`006oooool00ol0003oooooooooo`1Moooo
o`03o`000?oooooooooo0>[ooooo000Kooooo`03o`000?oooooooooo05_ooooo0_l0003]ooooo`00
6oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo0>gooooo000Kooooo`?o0000F?oo
ool2o`000?3ooooo000Kooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0l?ooool0
01_ooooo00?o0000ooooooooool0EOooool2o`000??ooooo000Kooooo`03o`000?oooooooooo05Co
oooo00?o0000ooooooooool0loooool001_ooooo00?o0000ooooooooool0Doooool00ol0003ooooo
ooooo`3dooooo`006oooool00ol0003oooooooooo`1Aooooo`;o0000moooool001_ooooo00?o0000
ooooooooool0D?ooool00ol0003oooooooooo`3gooooo`006oooool00ol0003oooooooooo`1>oooo
o`;o0000n_ooool001_ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`3jooooo`00
6oooool00ol0003oooooooooo`1;ooooo`;o0000oOooool001_ooooo0ol0001:ooooo`03o`000?oo
oooooooo0?gooooo000Kooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0o_ooool0
01_ooooo00?o0000ooooooooool0Aoooool2o`000?oooooo0_ooool001_ooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`3oooooo`;ooooo000Kooooo`03o`000?oooooooooo04Cooooo
0_l0003oooooo`Gooooo000Kooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0oooo
ool5ooooo`006oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo0?oooooo1_ooool0
01_ooooo00?o0000ooooooooool0@?ooool2o`000?oooooo2Oooool001_ooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`3oooooo`Wooooo000Kooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool0ooooool:ooooo`006oooool3o`0003gooooo00?o0000ooooooooool0oooo
ool;ooooo`006oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo0?oooooo3?ooool0
01_ooooo00?o0000ooooooooool0>_ooool2o`000?oooooo3oooool001_ooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`3oooooo`oooooo000Kooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool0ooooool@ooooo`006oooool00ol0003oooooooooo`0gooooo`03o`000?oo
oooooooo0?oooooo4Oooool001_ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`3o
oooooa;ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo0?oooooo4ooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0oooooolDooooo`0000Go
410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo0?oooooo5Oooool00005o`000?ooooooooooooooool0
00002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000booooo`03o`000?oooooooooo
0?oooooo5_ooool00005o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`3ooooooaOooooo00001Ol@
413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo0?oooooo6?ooool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool0
0ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0oooooolI
ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`3ooooooa[ooooo000Kooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool0oooooolKooooo`006oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo0?oooooo7?ooool001_ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`3ooooooagooooo000Kooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
oooooolNooooo`006oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0?oooooo7ooo
ool001_ooooo0ol0000Xooooo`03o`000?oooooooooo0?oooooo8?ooool001_ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`3oooooob7ooooo000Kooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0oooooolQooooo`006oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo0?oooooo8_ooool001_ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`3oooooob?ooooo000Kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0oooooolT
ooooo`006oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0?oooooo9Oooool001_o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`3oooooobKooooo000Kooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0oooooolWooooo`006oooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo0?oooooo:?ooool001_ooooo0ol0000Oooooo`03o`000?oooooo
oooo0?oooooo:Oooool001_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`3ooooo
ob[ooooo000Kooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0ooooool[ooooo`00
6oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0?oooooo;?ooool001_ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`3oooooobgooooo000Kooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0ooooool^ooooo`006oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo0?oooooo;oooool001_ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`3ooooooboooooo000Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
ooooool`ooooo`006oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0?oooooo<Ooo
ool001_ooooo0ol0000Fooooo`03o`000?oooooooooo0?oooooo<_ooool001_ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`3ooooooc;ooooo000Kooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0oooooolcooooo`006oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo0?oooooo=?ooool001_ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`3oooooocGooooo000Kooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0oooooole
ooooo`006oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0?oooooo=_ooool00005
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0oooooolgooooo`0000GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`3oooooocSooooo00001Ol@413ooooooooooooo
oooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0oooooolhooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05oc8b
<_nHV9SooooooiRHV?lb<S801_ooool3o`0000oooooo00?o0000ooooooooool0ooooooliooooo`00
00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo0?oooooo>_ooool00005oa0@4?oooooooooooooo
ool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`3ooooooc_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0oooo
oolkooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
1_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0?oooooo??ooool001_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`3oooooocgooooo000Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0oooooolnooooo`006oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo0?oooooo?_ooool001_ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`3oooooocoooooo000Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
ooooooloooooo`006oooool3o`0000Sooooo00?o0000ooooooooool0oooooom0ooooo`006oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?oooooo@?ooool001_ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooom1ooooo`006oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001_ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3ooooood;ooooo000Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom2
ooooo`006oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@oooool001_o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood?ooooo000Kooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom4ooooo`006oooool3o`0000Cooooo00?o
0000ooooooooool0oooooom4ooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0?ooooooAOooool001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooo
odGooooo000Kooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooom6ooooo`00
6oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooA_ooool001_ooooo00Go
0000ooooooooooooooooo`00003oooooodWooooo000Kooooo`05o`000?ooooooooooooooool00000
oooooom9ooooo`006oooool01?l0003oooooooooool0003ooooood[ooooo000Kooooo`04o`000?oo
ooooooooo`000?ooooooB_ooool001_ooooo00Co0000oooooooooooo0000oooooom:ooooo`006ooo
ool3o`000?ooooooBoooool001_ooooo00?o0000ooooool00000oooooom;ooooo`006oooool00ol0
003oooooo`00003ooooood_ooooo000Kooooo`03o`000?oooooo00000?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`;o0000oooooom<ooooo`006oooool2o`000?ooooooC?ooool0
017ooooo1?l000000ol@413oooooooooo`03ooooo`;o0000oooooom<ooooo`004oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oooooooooo00Gooooo0ol0
003ooooood_ooooo000Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom;
ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooBoooool001?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Aooooo`03oeEE
EOmVIVKo000000Oooooo00?o0000ooooooooool0oooooom;ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "The singularity in ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\[Phi]/\[PartialD]r\)]],
  " is expected near the point of a cusp, as surface charge accumulates at \
such points [see Sec. ",
  ButtonBox["3.2",
    ButtonData:>{"Chapter3.nb", "c:43"},
    ButtonStyle->"Hyperlink"],
  ", Exercise (5)(b)].  This singular behavior will make it difficult to find \
a convergent numerical solution using the Galerkin method."
}], "Text"],

Cell[TextData[{
  "\tNevertheless, we will now attempt a Galerkin solution.  First, we must \
choose basis functions. These functions must be zero on the boundary. \
However, if we were to use the function ",
  Cell[BoxData[
      \(TraditionalForm\`\(z\_2\)(x, y) = \(\(y\)\(-\)\) | x | \)]],
  "  to define the basis functions via Eq. ",
  ButtonBox["(6.1.8)",
    ButtonData:>"(6.1.8)",
    ButtonStyle->"Hyperlink"],
  ",  grave problems would develop in the Galerkin method. Because gradients \
of the ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\(m\ n\)\)]],
  " are required in the solution, the result would exhibit a singularity \
along ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " and strong Gibbs phenomena throughout the domain.  "
}], "Text"],

Cell[TextData[{
  "\tWhat we need instead is a different function ",
  Cell[BoxData[
      \(TraditionalForm\`\(z\_2\)(x, y)\)]],
  " that equals zero on the domain boundary, but is not singular, except at \
",
  Cell[BoxData[
      \(TraditionalForm\`\((0, 0)\)\)]],
  ". Such functions do exist (after all, the solution of Poisson's equation \
is one such function). One simple example is"
}], "Text",
  CellTags->"i:9"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(z\_2\)(x, y)\  = \ 
        y\  - \ \@\(\((1 - a)\)\ x\^2 + a\ y\^2\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`0 < a < 1\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "It is easy to see that this function equals zero only along the lines ",
  Cell[BoxData[
      \(TraditionalForm\`y = \(\(|\)\(x\)\(|\)\)\)]],
  ", but the function is singular only at  ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\) = \((0, 0)\)\)]],
  ".  If we use this choice in the Galerkin method, we can find a convergent \
solution for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y)\)]],
  ", although the convergence is slow, as we will see. The code is given \
below. Note the use of symmetry in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " when defining the basis functions and the inner product: the solution is \
symmetric in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", so we choose basis functions that have this symmetry, and we integrate \
only over the right half of the domain."
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox[\( (*\ 
          define\ the\ curves\ that\ determine\ the\ \(\(boundary\)\(:\)\)\ *) \
\),
        FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", " ", 
      RowBox[{
        RowBox[{\(z[1, x_, y_]\  = \ x^2\  + \ y^2\  - 1;\), 
          "\[IndentingNewLine]", \(z[2, x_, y_]\  = \ \ y - 
                Sqrt[3  x^2/4\  + y^2/4]\ ;\), " ", "\[IndentingNewLine]", 
          StyleBox[\( (*\ define\ the\ charge\ density\ \ *) \),
            FontColor->RGBColor[1, 0, 0]], 
          "\[IndentingNewLine]", \(\[Rho][x_, y_]\  = \ 0;\), 
          "\[IndentingNewLine]", 
          
          StyleBox[\( (*\ 
              define\ the\ function\ u\ used\ to\ match\ inhomogeneous\ \
boundary\ conditions, \ if\ any\ *) \),
            FontColor->RGBColor[1, 0, 0]], 
          "\[IndentingNewLine]", \(u[x_, y_]\  = \ 1 - \((x^2\  + \ y^2)\);\),
           "\[IndentingNewLine]", 
          RowBox[{
            StyleBox["(*",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              FontColor->RGBColor[1, 0, 0]], 
            RowBox[{
              StyleBox["define",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[" ",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox["the",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[" ",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox["inner",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[" ",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox["product",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[" ",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox["using",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[" ",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox["Boole",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[" ",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox["notation",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[" ",
                FontColor->RGBColor[1, 0, 0]], 
              RowBox[{
                StyleBox["(",
                  FontColor->RGBColor[1, 0, 0]], 
                RowBox[{
                  StyleBox["Mathematica",
                    FontSlant->"Italic",
                    FontColor->RGBColor[1, 0, 0]], 
                  StyleBox[" ",
                    FontColor->RGBColor[1, 0, 0]], 
                  StyleBox["4.1",
                    FontColor->RGBColor[1, 0, 0]], 
                  StyleBox[" ",
                    FontColor->RGBColor[1, 0, 0]], 
                  StyleBox["only",
                    FontColor->RGBColor[1, 0, 0]]}], 
                StyleBox[")",
                  FontColor->RGBColor[1, 0, 0]]}]}], " ", 
            StyleBox["*)",
              FontColor->RGBColor[1, 0, 0]]}], 
          "\[IndentingNewLine]", \(norm[f_, g_]\  := \ 
            2  NIntegrate[
                f\ g\ Boole[
                    z[1, x, y] \[LessEqual] \ \ \ 0\  && \ 
                      z[2, x, y] \[LessEqual] \ 0], {x, 0, 
                  Infinity}, {y, \(-Infinity\), Infinity}, 
                MaxRecursion \[Rule] 10]\)}], " ", ";"}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.29"],

Cell[TextData[{
  "Numerical integration is now the fastest approach to determining the inner \
products. Even so, the equations take some time to evaluate for the chosen \
case of ",
  Cell[BoxData[
      \(TraditionalForm\`P\_x = \(P\_y = 3\)\)]],
  ".  (Each equation requires 16 two-dimensional numerical integrals to be \
evaluated, and there are 16 equations for the 16 Fourier coefficients.) The \
result is plotted in Cell ",
  ButtonBox["6.31",
    ButtonData:>"Cell 6.31",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(galerkin[3, 3, 2];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.30"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{0, 
          0}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-3.504776182717489`\)\ \
c[0, 0] + 1.6350924463673526`\ c[0, 1] - 1.0227526155716995`\ c[0, 2] + 
            0.6779166577308993`\ c[0, 3] - 0.8677105081043167`\ c[1, 0] + 
            0.2723216680602963`\ c[1, 1] - 0.14866289229494548`\ c[1, 2] + 
            0.08227982270270344`\ c[1, 3] - 0.3806724524876043`\ c[2, 0] + 
            0.09300676803096145`\ c[2, 1] - 0.04761933121550303`\ c[2, 2] + 
            0.022885110525260842`\ c[2, 3] - 0.20807846879270914`\ c[3, 0] + 
            0.04182645159569168`\ c[3, 1] - 0.020610270712650886`\ c[3, 2] + 
            0.008758208032821293`\ c[3, 3] == 2.598240282383346`\)\),
      SequenceForm[ "eq", {0, 0}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -3.5047761827174888, 
              c[ 0, 0]], 
            Times[ 1.6350924463673526, 
              c[ 0, 1]], 
            Times[ -1.0227526155716995, 
              c[ 0, 2]], 
            Times[ 0.67791665773089926, 
              c[ 0, 3]], 
            Times[ -0.86771050810431671, 
              c[ 1, 0]], 
            Times[ 0.27232166806029628, 
              c[ 1, 1]], 
            Times[ -0.14866289229494548, 
              c[ 1, 2]], 
            Times[ 0.08227982270270344, 
              c[ 1, 3]], 
            Times[ -0.38067245248760428, 
              c[ 2, 0]], 
            Times[ 0.093006768030961445, 
              c[ 2, 1]], 
            Times[ -0.047619331215503033, 
              c[ 2, 2]], 
            Times[ 0.022885110525260842, 
              c[ 2, 3]], 
            Times[ -0.20807846879270914, 
              c[ 3, 0]], 
            Times[ 0.041826451595691677, 
              c[ 3, 1]], 
            Times[ -0.020610270712650886, 
              c[ 3, 2]], 
            Times[ 0.0087582080328212925, 
              c[ 3, 3]]], 2.5982402823833461]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{0, 
          1}\[InvisibleSpace]" = "\[InvisibleSpace]\(1.6350925239061564`\ c[
                0, 0] - 1.2763198687162909`\ c[0, 1] + 
            0.8805203912687791`\ c[0, 2] - 0.6514869846919767`\ c[0, 3] + 
            0.27232166952168974`\ c[1, 0] - 0.1942256758862964`\ c[1, 1] + 
            0.10803183020642494`\ c[1, 2] - 0.07179909577063671`\ c[1, 3] + 
            0.09300676723714274`\ c[2, 0] - 0.06395972617819998`\ c[2, 1] + 
            0.03020060806200805`\ c[2, 2] - 0.01880516404465241`\ c[2, 3] + 
            0.041826451605907915`\ c[3, 0] - 0.028204153960637898`\ c[3, 1] + 
            0.011589116698569213`\ c[3, 2] - 
            0.006902689595527565`\ c[3, 3] == \(-0.889269023371542`\)\)\),
      SequenceForm[ "eq", {0, 1}, " = ", 
        Equal[ 
          Plus[ 
            Times[ 1.6350925239061564, 
              c[ 0, 0]], 
            Times[ -1.2763198687162909, 
              c[ 0, 1]], 
            Times[ 0.88052039126877912, 
              c[ 0, 2]], 
            Times[ -0.65148698469197674, 
              c[ 0, 3]], 
            Times[ 0.27232166952168974, 
              c[ 1, 0]], 
            Times[ -0.19422567588629641, 
              c[ 1, 1]], 
            Times[ 0.10803183020642494, 
              c[ 1, 2]], 
            Times[ -0.071799095770636714, 
              c[ 1, 3]], 
            Times[ 0.09300676723714274, 
              c[ 2, 0]], 
            Times[ -0.063959726178199977, 
              c[ 2, 1]], 
            Times[ 0.030200608062008048, 
              c[ 2, 2]], 
            Times[ -0.018805164044652409, 
              c[ 2, 3]], 
            Times[ 0.041826451605907915, 
              c[ 3, 0]], 
            Times[ -0.028204153960637898, 
              c[ 3, 1]], 
            Times[ 0.011589116698569213, 
              c[ 3, 2]], 
            Times[ -0.0069026895955275648, 
              c[ 3, 3]]], -0.88926902337154201]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{0, 
          2}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-1.0227526177521447`\)\
\ c[0, 0] + 0.880520394658569`\ c[0, 1] - 0.7073510935828231`\ c[0, 2] + 
            0.5575671460249609`\ c[0, 3] - 0.14866289134783212`\ c[1, 0] + 
            0.10803183570004865`\ c[1, 1] - 0.07824009300468761`\ c[1, 2] + 
            0.0541742488679077`\ c[1, 3] - 0.04761933173745078`\ c[2, 0] + 
            0.030200608308507737`\ c[2, 1] - 0.020548648043905132`\ c[2, 2] + 
            0.012764807179542589`\ c[2, 3] - 0.020610270624568165`\ c[3, 0] + 
            0.011589116724943931`\ c[3, 1] - 0.007558766448059473`\ c[3, 2] + 
            0.004258958381705501`\ c[3, 3] == 0.5366706427269019`\)\),
      SequenceForm[ "eq", {0, 2}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -1.0227526177521447, 
              c[ 0, 0]], 
            Times[ 0.88052039465856902, 
              c[ 0, 1]], 
            Times[ -0.70735109358282311, 
              c[ 0, 2]], 
            Times[ 0.55756714602496094, 
              c[ 0, 3]], 
            Times[ -0.14866289134783212, 
              c[ 1, 0]], 
            Times[ 0.10803183570004865, 
              c[ 1, 1]], 
            Times[ -0.078240093004687608, 
              c[ 1, 2]], 
            Times[ 0.054174248867907698, 
              c[ 1, 3]], 
            Times[ -0.047619331737450782, 
              c[ 2, 0]], 
            Times[ 0.030200608308507737, 
              c[ 2, 1]], 
            Times[ -0.020548648043905132, 
              c[ 2, 2]], 
            Times[ 0.012764807179542589, 
              c[ 2, 3]], 
            Times[ -0.020610270624568165, 
              c[ 3, 0]], 
            Times[ 0.011589116724943931, 
              c[ 3, 1]], 
            Times[ -0.007558766448059473, 
              c[ 3, 2]], 
            Times[ 0.0042589583817055007, 
              c[ 3, 3]]], 0.5366706427269019]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{0, 
          3}\[InvisibleSpace]" = "\[InvisibleSpace]\(0.6779166128172255`\ c[
                0, 0] - 0.651486987230687`\ c[0, 1] + 
            0.5575671438121805`\ c[0, 2] - 0.46885502305622573`\ c[0, 3] + 
            0.08227982281961926`\ c[1, 0] - 0.07179909580567413`\ c[1, 1] + 
            0.05417424806375189`\ c[1, 2] - 0.04159374943281591`\ c[1, 3] + 
            0.022885110636592723`\ c[2, 0] - 0.018805164066519962`\ c[2, 1] + 
            0.01276480722589721`\ c[2, 2] - 0.009186543336556083`\ c[2, 3] + 
            0.00875820812159103`\ c[3, 0] - 0.006902689457136344`\ c[3, 1] + 
            0.004258958350581763`\ c[3, 2] - 
            0.002919450712013513`\ c[3, 3] == \(-0.3217016765357592`\)\)\),
      SequenceForm[ "eq", {0, 3}, " = ", 
        Equal[ 
          Plus[ 
            Times[ 0.67791661281722548, 
              c[ 0, 0]], 
            Times[ -0.65148698723068699, 
              c[ 0, 1]], 
            Times[ 0.55756714381218053, 
              c[ 0, 2]], 
            Times[ -0.46885502305622573, 
              c[ 0, 3]], 
            Times[ 0.082279822819619264, 
              c[ 1, 0]], 
            Times[ -0.071799095805674132, 
              c[ 1, 1]], 
            Times[ 0.054174248063751887, 
              c[ 1, 2]], 
            Times[ -0.041593749432815907, 
              c[ 1, 3]], 
            Times[ 0.022885110636592723, 
              c[ 2, 0]], 
            Times[ -0.018805164066519962, 
              c[ 2, 1]], 
            Times[ 0.01276480722589721, 
              c[ 2, 2]], 
            Times[ -0.0091865433365560835, 
              c[ 2, 3]], 
            Times[ 0.0087582081215910306, 
              c[ 3, 0]], 
            Times[ -0.0069026894571363436, 
              c[ 3, 1]], 
            Times[ 0.0042589583505817626, 
              c[ 3, 2]], 
            Times[ -0.0029194507120135129, 
              c[ 3, 3]]], -0.32170167653575921]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{1, 
          0}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.8677105420708995`\)\
\ c[0, 0] + 0.2723216699354064`\ c[0, 1] - 0.14866289300866917`\ c[0, 2] + 
            0.08227982499502368`\ c[0, 3] - 0.5629235798971659`\ c[1, 0] + 
            0.14451078213844148`\ c[1, 1] - 0.07338332070922951`\ c[1, 2] + 
            0.03598704658806903`\ c[1, 3] - 0.33880162515399337`\ c[2, 0] + 
            0.0710884375066017`\ c[2, 1] - 0.0345581426179401`\ c[2, 2] + 
            0.014991767118211886`\ c[2, 3] - 0.21979385973125623`\ c[3, 0] + 
            0.038984932397991605`\ c[3, 1] - 0.018444191921273504`\ c[3, 2] + 
            0.0071606048950421455`\ c[3, 3] == 0.5768609331927412`\)\),
      SequenceForm[ "eq", {1, 0}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.86771054207089948, 
              c[ 0, 0]], 
            Times[ 0.27232166993540641, 
              c[ 0, 1]], 
            Times[ -0.14866289300866917, 
              c[ 0, 2]], 
            Times[ 0.082279824995023676, 
              c[ 0, 3]], 
            Times[ -0.5629235798971659, 
              c[ 1, 0]], 
            Times[ 0.14451078213844148, 
              c[ 1, 1]], 
            Times[ -0.07338332070922951, 
              c[ 1, 2]], 
            Times[ 0.035987046588069033, 
              c[ 1, 3]], 
            Times[ -0.33880162515399337, 
              c[ 2, 0]], 
            Times[ 0.071088437506601695, 
              c[ 2, 1]], 
            Times[ -0.034558142617940102, 
              c[ 2, 2]], 
            Times[ 0.014991767118211886, 
              c[ 2, 3]], 
            Times[ -0.21979385973125623, 
              c[ 3, 0]], 
            Times[ 0.038984932397991605, 
              c[ 3, 1]], 
            Times[ -0.018444191921273504, 
              c[ 3, 2]], 
            Times[ 0.0071606048950421455, 
              c[ 3, 3]]], 0.57686093319274123]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{1, 
          1}\[InvisibleSpace]" = "\[InvisibleSpace]\(0.2723216699474639`\ c[
                0, 0] - 0.19422567603462149`\ c[0, 1] + 
            0.10803183075723373`\ c[0, 2] - 0.07179909592857112`\ c[0, 3] + 
            0.14451078250586874`\ c[1, 0] - 0.08972371530836601`\ c[1, 1] + 
            0.043302543786007994`\ c[1, 2] - 0.02655350782588484`\ c[1, 3] + 
            0.07108844120781621`\ c[2, 0] - 0.04215202694811472`\ c[2, 1] + 
            0.017822675775702214`\ c[2, 2] - 0.010371493880708307`\ c[2, 3] + 
            0.038984932304503055`\ c[3, 0] - 0.022534292697344104`\ c[3, 1] + 
            0.008469415937094119`\ c[3, 2] - 
            0.004748007467892514`\ c[3, 3] == \(-0.12293283971699011`\)\)\),
      SequenceForm[ "eq", {1, 1}, " = ", 
        Equal[ 
          Plus[ 
            Times[ 0.27232166994746387, 
              c[ 0, 0]], 
            Times[ -0.19422567603462149, 
              c[ 0, 1]], 
            Times[ 0.10803183075723373, 
              c[ 0, 2]], 
            Times[ -0.071799095928571116, 
              c[ 0, 3]], 
            Times[ 0.14451078250586874, 
              c[ 1, 0]], 
            Times[ -0.089723715308366009, 
              c[ 1, 1]], 
            Times[ 0.043302543786007994, 
              c[ 1, 2]], 
            Times[ -0.02655350782588484, 
              c[ 1, 3]], 
            Times[ 0.071088441207816211, 
              c[ 2, 0]], 
            Times[ -0.042152026948114721, 
              c[ 2, 1]], 
            Times[ 0.017822675775702214, 
              c[ 2, 2]], 
            Times[ -0.010371493880708307, 
              c[ 2, 3]], 
            Times[ 0.038984932304503055, 
              c[ 3, 0]], 
            Times[ -0.022534292697344104, 
              c[ 3, 1]], 
            Times[ 0.0084694159370941186, 
              c[ 3, 2]], 
            Times[ -0.0047480074678925141, 
              c[ 3, 3]]], -0.12293283971699011]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{1, 
          2}\[InvisibleSpace]" = \
"\[InvisibleSpace]\(\(-0.14866289382341366`\)\ c[0, 0] + 
            0.10803183053481527`\ c[0, 1] - 0.07824009045658684`\ c[0, 2] + 
            0.05417424885717752`\ c[0, 3] - 0.07338333390671005`\ c[1, 0] + 
            0.04330254457040629`\ c[1, 1] - 0.028296991620815146`\ c[1, 2] + 
            0.017509189194162594`\ c[1, 3] - 0.03455814260575313`\ c[2, 0] + 
            0.017822675838733697`\ c[2, 1] - 0.011027571101483065`\ c[2, 2] + 
            0.0062006241524093075`\ c[2, 3] - 
            0.018444191962290742`\ c[3, 0] + 0.00846941594424941`\ c[3, 1] - 
            0.005046043648873608`\ c[3, 2] + 0.0025997154355896215`\ c[3, 3] == 
          0.07530758617720691`\)\),
      SequenceForm[ "eq", {1, 2}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.14866289382341366, 
              c[ 0, 0]], 
            Times[ 0.10803183053481527, 
              c[ 0, 1]], 
            Times[ -0.078240090456586836, 
              c[ 0, 2]], 
            Times[ 0.054174248857177518, 
              c[ 0, 3]], 
            Times[ -0.073383333906710049, 
              c[ 1, 0]], 
            Times[ 0.04330254457040629, 
              c[ 1, 1]], 
            Times[ -0.028296991620815146, 
              c[ 1, 2]], 
            Times[ 0.017509189194162594, 
              c[ 1, 3]], 
            Times[ -0.034558142605753128, 
              c[ 2, 0]], 
            Times[ 0.017822675838733697, 
              c[ 2, 1]], 
            Times[ -0.011027571101483065, 
              c[ 2, 2]], 
            Times[ 0.0062006241524093075, 
              c[ 2, 3]], 
            Times[ -0.018444191962290742, 
              c[ 3, 0]], 
            Times[ 0.0084694159442494105, 
              c[ 3, 1]], 
            Times[ -0.0050460436488736077, 
              c[ 3, 2]], 
            Times[ 0.0025997154355896215, 
              c[ 3, 3]]], 0.075307586177206912]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{1, 
          3}\[InvisibleSpace]" = "\[InvisibleSpace]\(0.0822798230326752`\ c[
                0, 0] - 0.07179909452960061`\ c[0, 1] + 
            0.05417424943726847`\ c[0, 2] - 0.041593749670490655`\ c[0, 3] + 
            0.035987046512237254`\ c[1, 0] - 0.0265535077025885`\ c[1, 1] + 
            0.017509189259431242`\ c[1, 2] - 0.01229485586215261`\ c[1, 3] + 
            0.014991767136997073`\ c[2, 0] - 0.0103714937827982`\ c[2, 1] + 
            0.006200624187471231`\ c[2, 2] - 0.004117199584262991`\ c[2, 3] + 
            0.0071606048363704565`\ c[3, 0] - 
            0.004748007479610691`\ c[3, 1] + 
            0.0025997145290612292`\ c[3, 2] - 
            0.0016544379323899937`\ c[3, 3] == \(-0.03552098395910542`\)\)\),
      SequenceForm[ "eq", {1, 3}, " = ", 
        Equal[ 
          Plus[ 
            Times[ 0.082279823032675198, 
              c[ 0, 0]], 
            Times[ -0.071799094529600607, 
              c[ 0, 1]], 
            Times[ 0.054174249437268472, 
              c[ 0, 2]], 
            Times[ -0.041593749670490655, 
              c[ 0, 3]], 
            Times[ 0.035987046512237254, 
              c[ 1, 0]], 
            Times[ -0.026553507702588498, 
              c[ 1, 1]], 
            Times[ 0.017509189259431242, 
              c[ 1, 2]], 
            Times[ -0.01229485586215261, 
              c[ 1, 3]], 
            Times[ 0.014991767136997073, 
              c[ 2, 0]], 
            Times[ -0.0103714937827982, 
              c[ 2, 1]], 
            Times[ 0.0062006241874712313, 
              c[ 2, 2]], 
            Times[ -0.0041171995842629906, 
              c[ 2, 3]], 
            Times[ 0.0071606048363704565, 
              c[ 3, 0]], 
            Times[ -0.0047480074796106908, 
              c[ 3, 1]], 
            Times[ 0.0025997145290612292, 
              c[ 3, 2]], 
            Times[ -0.0016544379323899937, 
              c[ 3, 3]]], -0.035520983959105419]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{2, 
          0}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.3806724459673615`\)\
\ c[0, 0] + 0.09300676820959519`\ c[0, 1] - 0.04761933191332914`\ c[0, 2] + 
            0.022885110712993165`\ c[0, 3] - 0.3388016263882182`\ c[1, 0] + 
            0.0710884345915904`\ c[1, 1] - 0.03455814220946763`\ c[1, 2] + 
            0.014991767052786471`\ c[1, 3] - 0.25016939757143913`\ c[2, 0] + 
            0.044646749743634265`\ c[2, 1] - 0.02106849883254663`\ c[2, 2] + 
            0.008206511674500603`\ c[2, 3] - 0.18436858180788676`\ c[3, 0] + 
            0.028535427759659313`\ c[3, 1] - 0.013210808856271098`\ c[3, 2] + 
            0.00465538751885035`\ c[3, 3] == 0.24517070818467906`\)\),
      SequenceForm[ "eq", {2, 0}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.38067244596736149, 
              c[ 0, 0]], 
            Times[ 0.093006768209595192, 
              c[ 0, 1]], 
            Times[ -0.047619331913329142, 
              c[ 0, 2]], 
            Times[ 0.022885110712993165, 
              c[ 0, 3]], 
            Times[ -0.3388016263882182, 
              c[ 1, 0]], 
            Times[ 0.071088434591590394, 
              c[ 1, 1]], 
            Times[ -0.034558142209467631, 
              c[ 1, 2]], 
            Times[ 0.014991767052786471, 
              c[ 1, 3]], 
            Times[ -0.25016939757143913, 
              c[ 2, 0]], 
            Times[ 0.044646749743634265, 
              c[ 2, 1]], 
            Times[ -0.02106849883254663, 
              c[ 2, 2]], 
            Times[ 0.0082065116745006026, 
              c[ 2, 3]], 
            Times[ -0.18436858180788676, 
              c[ 3, 0]], 
            Times[ 0.028535427759659313, 
              c[ 3, 1]], 
            Times[ -0.013210808856271098, 
              c[ 3, 2]], 
            Times[ 0.0046553875188503503, 
              c[ 3, 3]]], 0.24517070818467906]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{2, 
          1}\[InvisibleSpace]" = "\[InvisibleSpace]\(0.09300676858251222`\ c[
                0, 0] - 0.0639597264024068`\ c[0, 1] + 
            0.030200608600381658`\ c[0, 2] - 0.018805164200911606`\ c[0, 3] + 
            0.07108844124563478`\ c[1, 0] - 0.04215202685041512`\ c[1, 1] + 
            0.01782267577269184`\ c[1, 2] - 0.010371493866559226`\ c[1, 3] + 
            0.044646749759782216`\ c[2, 0] - 0.025158600434750822`\ c[2, 1] + 
            0.009515322740270685`\ c[2, 2] - 0.005305401140639838`\ c[2, 3] + 
            0.028535427773151597`\ c[3, 0] - 0.01563950630913856`\ c[3, 1] + 
            0.005336731470548332`\ c[3, 2] - 
            0.002885254562545731`\ c[3, 3] == \(-0.03823872062672139`\)\)\),
      SequenceForm[ "eq", {2, 1}, " = ", 
        Equal[ 
          Plus[ 
            Times[ 0.093006768582512223, 
              c[ 0, 0]], 
            Times[ -0.063959726402406797, 
              c[ 0, 1]], 
            Times[ 0.030200608600381658, 
              c[ 0, 2]], 
            Times[ -0.018805164200911606, 
              c[ 0, 3]], 
            Times[ 0.071088441245634779, 
              c[ 1, 0]], 
            Times[ -0.042152026850415122, 
              c[ 1, 1]], 
            Times[ 0.017822675772691841, 
              c[ 1, 2]], 
            Times[ -0.010371493866559226, 
              c[ 1, 3]], 
            Times[ 0.044646749759782216, 
              c[ 2, 0]], 
            Times[ -0.025158600434750822, 
              c[ 2, 1]], 
            Times[ 0.0095153227402706847, 
              c[ 2, 2]], 
            Times[ -0.0053054011406398378, 
              c[ 2, 3]], 
            Times[ 0.028535427773151597, 
              c[ 3, 0]], 
            Times[ -0.015639506309138559, 
              c[ 3, 1]], 
            Times[ 0.005336731470548332, 
              c[ 3, 2]], 
            Times[ -0.0028852545625457312, 
              c[ 3, 3]]], -0.038238720626721387]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{2, 
          2}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.047619331882800736`\
\)\ c[0, 0] + 0.030200608022089265`\ c[0, 1] - 
            0.020548648514115368`\ c[0, 2] + 0.012764807296138811`\ c[0, 3] - 
            0.03455814275408066`\ c[1, 0] + 0.017822675905215586`\ c[1, 1] - 
            0.01102757068246567`\ c[1, 2] + 0.006200624149158334`\ c[1, 3] - 
            0.02106849947853066`\ c[2, 0] + 0.009515322805536375`\ c[2, 1] - 
            0.005603437354810236`\ c[2, 2] + 0.002887019227867494`\ c[2, 3] - 
            0.013210808739043267`\ c[3, 0] + 0.005336731444395667`\ c[3, 1] - 
            0.0030386032396916883`\ c[3, 2] + 
            0.0014442877493821647`\ c[3, 3] == 0.0243875802394917`\)\),
      SequenceForm[ "eq", {2, 2}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.047619331882800736, 
              c[ 0, 0]], 
            Times[ 0.030200608022089265, 
              c[ 0, 1]], 
            Times[ -0.020548648514115368, 
              c[ 0, 2]], 
            Times[ 0.012764807296138811, 
              c[ 0, 3]], 
            Times[ -0.034558142754080659, 
              c[ 1, 0]], 
            Times[ 0.017822675905215586, 
              c[ 1, 1]], 
            Times[ -0.011027570682465669, 
              c[ 1, 2]], 
            Times[ 0.0062006241491583342, 
              c[ 1, 3]], 
            Times[ -0.02106849947853066, 
              c[ 2, 0]], 
            Times[ 0.0095153228055363751, 
              c[ 2, 1]], 
            Times[ -0.0056034373548102361, 
              c[ 2, 2]], 
            Times[ 0.0028870192278674942, 
              c[ 2, 3]], 
            Times[ -0.013210808739043267, 
              c[ 3, 0]], 
            Times[ 0.0053367314443956669, 
              c[ 3, 1]], 
            Times[ -0.0030386032396916883, 
              c[ 3, 2]], 
            Times[ 0.0014442877493821647, 
              c[ 3, 3]]], 0.0243875802394917]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{2, 
          3}\[InvisibleSpace]" = "\[InvisibleSpace]\(0.022885110580302508`\ c[
                0, 0] - 0.018805163961872734`\ c[0, 1] + 
            0.012764807483112877`\ c[0, 2] - 0.009186543489622327`\ c[0, 3] + 
            0.014991767161337587`\ c[1, 0] - 0.01037149382582035`\ c[1, 1] + 
            0.006200624176987195`\ c[1, 2] - 
            0.0041171994085293555`\ c[1, 3] + 0.00820651169220701`\ c[2, 0] - 
            0.00530540114512719`\ c[2, 1] + 0.002887019234026584`\ c[2, 2] - 
            0.0018235067209312376`\ c[2, 3] + 
            0.0046553875171790144`\ c[3, 0] - 
            0.0028852545574931075`\ c[3, 1] + 
            0.0014442877632039925`\ c[3, 2] - 
            0.0008787138625165395`\ c[3, 3] == \(-0.009321944375888791`\)\)\),
      
      SequenceForm[ "eq", {2, 3}, " = ", 
        Equal[ 
          Plus[ 
            Times[ 0.022885110580302508, 
              c[ 0, 0]], 
            Times[ -0.018805163961872734, 
              c[ 0, 1]], 
            Times[ 0.012764807483112877, 
              c[ 0, 2]], 
            Times[ -0.0091865434896223272, 
              c[ 0, 3]], 
            Times[ 0.014991767161337587, 
              c[ 1, 0]], 
            Times[ -0.01037149382582035, 
              c[ 1, 1]], 
            Times[ 0.0062006241769871949, 
              c[ 1, 2]], 
            Times[ -0.0041171994085293555, 
              c[ 1, 3]], 
            Times[ 0.0082065116922070101, 
              c[ 2, 0]], 
            Times[ -0.0053054011451271902, 
              c[ 2, 1]], 
            Times[ 0.0028870192340265839, 
              c[ 2, 2]], 
            Times[ -0.0018235067209312376, 
              c[ 2, 3]], 
            Times[ 0.0046553875171790144, 
              c[ 3, 0]], 
            Times[ -0.0028852545574931075, 
              c[ 3, 1]], 
            Times[ 0.0014442877632039925, 
              c[ 3, 2]], 
            Times[ -0.00087871386251653946, 
              c[ 3, 3]]], -0.009321944375888791]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{3, 
          0}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.2080784695867788`\)\
\ c[0, 0] + 0.041826452142622705`\ c[0, 1] - 0.02061027040146507`\ c[0, 2] + 
            0.008758208035893066`\ c[0, 3] - 0.21979380402340754`\ c[1, 0] + 
            0.03898493238881015`\ c[1, 1] - 0.01844419189747768`\ c[1, 2] + 
            0.007160604924111817`\ c[1, 3] - 0.18436858213188756`\ c[2, 0] + 
            0.028535427718901468`\ c[2, 1] - 0.013210808696861066`\ c[2, 2] + 
            0.0046553875186983295`\ c[2, 3] - 0.14856074079149387`\ c[3, 0] + 
            0.020319604058881984`\ c[3, 1] - 0.009275936052455228`\ c[3, 2] + 
            0.00298341529175595`\ c[3, 3] == 0.131630143329326`\)\),
      SequenceForm[ "eq", {3, 0}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.20807846958677881, 
              c[ 0, 0]], 
            Times[ 0.041826452142622705, 
              c[ 0, 1]], 
            Times[ -0.02061027040146507, 
              c[ 0, 2]], 
            Times[ 0.0087582080358930663, 
              c[ 0, 3]], 
            Times[ -0.21979380402340754, 
              c[ 1, 0]], 
            Times[ 0.038984932388810151, 
              c[ 1, 1]], 
            Times[ -0.018444191897477681, 
              c[ 1, 2]], 
            Times[ 0.0071606049241118167, 
              c[ 1, 3]], 
            Times[ -0.18436858213188756, 
              c[ 2, 0]], 
            Times[ 0.028535427718901468, 
              c[ 2, 1]], 
            Times[ -0.013210808696861066, 
              c[ 2, 2]], 
            Times[ 0.0046553875186983295, 
              c[ 2, 3]], 
            Times[ -0.14856074079149387, 
              c[ 3, 0]], 
            Times[ 0.020319604058881984, 
              c[ 3, 1]], 
            Times[ -0.0092759360524552279, 
              c[ 3, 2]], 
            Times[ 0.0029834152917559498, 
              c[ 3, 3]]], 0.13163014332932599]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{3, 
          1}\[InvisibleSpace]" = "\[InvisibleSpace]\(0.04182645168182704`\ c[
                0, 0] - 0.02820415492792206`\ c[0, 1] + 
            0.011589116716604685`\ c[0, 2] - 0.006902689479110434`\ c[0, 3] + 
            0.03898493234031709`\ c[1, 0] - 0.02253429260451624`\ c[1, 1] + 
            0.008469415960970391`\ c[1, 2] - 0.004748007480681842`\ c[1, 3] + 
            0.028535427737025495`\ c[2, 0] - 0.01563950627511309`\ c[2, 1] + 
            0.005336731450951263`\ c[2, 2] - 
            0.0028852545796962136`\ c[2, 3] + 
            0.020319604078195486`\ c[3, 0] - 0.010822675764026448`\ c[3, 1] + 
            0.003369868832755333`\ c[3, 2] - 
            0.0017751841310206747`\ c[3, 3] == \(-0.016170535929320773`\)\)\),
      
      SequenceForm[ "eq", {3, 1}, " = ", 
        Equal[ 
          Plus[ 
            Times[ 0.04182645168182704, 
              c[ 0, 0]], 
            Times[ -0.028204154927922061, 
              c[ 0, 1]], 
            Times[ 0.011589116716604685, 
              c[ 0, 2]], 
            Times[ -0.0069026894791104337, 
              c[ 0, 3]], 
            Times[ 0.038984932340317087, 
              c[ 1, 0]], 
            Times[ -0.02253429260451624, 
              c[ 1, 1]], 
            Times[ 0.008469415960970391, 
              c[ 1, 2]], 
            Times[ -0.0047480074806818418, 
              c[ 1, 3]], 
            Times[ 0.028535427737025495, 
              c[ 2, 0]], 
            Times[ -0.015639506275113089, 
              c[ 2, 1]], 
            Times[ 0.0053367314509512633, 
              c[ 2, 2]], 
            Times[ -0.0028852545796962136, 
              c[ 2, 3]], 
            Times[ 0.020319604078195486, 
              c[ 3, 0]], 
            Times[ -0.010822675764026448, 
              c[ 3, 1]], 
            Times[ 0.0033698688327553328, 
              c[ 3, 2]], 
            Times[ -0.0017751841310206747, 
              c[ 3, 3]]], -0.016170535929320773]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{3, 
          2}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.020610270669373022`\
\)\ c[0, 0] + 0.01158911681934974`\ c[0, 1] - 
            0.007558766410254932`\ c[0, 2] + 0.004258958388405497`\ c[0, 3] - 
            0.018444191882889812`\ c[1, 0] + 0.008469415958402414`\ c[1, 1] - 
            0.005046043688954668`\ c[1, 2] + 0.002599715430341638`\ c[1, 3] - 
            0.013210808700722231`\ c[2, 0] + 
            0.0053367314723437465`\ c[2, 1] - 
            0.0030386032160687757`\ c[2, 2] + 
            0.001444287748205167`\ c[2, 3] - 0.009275936049665331`\ c[3, 0] + 
            0.003369868821546629`\ c[3, 1] - 
            0.0018614590150906655`\ c[3, 2] + 
            0.0008208681426477635`\ c[3, 3] == 0.010733641011742517`\)\),
      SequenceForm[ "eq", {3, 2}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.020610270669373022, 
              c[ 0, 0]], 
            Times[ 0.011589116819349741, 
              c[ 0, 1]], 
            Times[ -0.0075587664102549322, 
              c[ 0, 2]], 
            Times[ 0.0042589583884054972, 
              c[ 0, 3]], 
            Times[ -0.018444191882889812, 
              c[ 1, 0]], 
            Times[ 0.008469415958402414, 
              c[ 1, 1]], 
            Times[ -0.0050460436889546677, 
              c[ 1, 2]], 
            Times[ 0.002599715430341638, 
              c[ 1, 3]], 
            Times[ -0.013210808700722231, 
              c[ 2, 0]], 
            Times[ 0.0053367314723437465, 
              c[ 2, 1]], 
            Times[ -0.0030386032160687757, 
              c[ 2, 2]], 
            Times[ 0.0014442877482051669, 
              c[ 2, 3]], 
            Times[ -0.0092759360496653311, 
              c[ 3, 0]], 
            Times[ 0.0033698688215466292, 
              c[ 3, 1]], 
            Times[ -0.0018614590150906655, 
              c[ 3, 2]], 
            Times[ 0.00082086814264776349, 
              c[ 3, 3]]], 0.010733641011742517]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{3, 
          3}\[InvisibleSpace]" = "\[InvisibleSpace]\(0.008758208053733783`\ c[
                0, 0] - 0.006902689499332309`\ c[0, 1] + 
            0.004258958339075735`\ c[0, 2] - 
            0.0029194507349737213`\ c[0, 3] + 
            0.0071606049283372275`\ c[1, 0] - 
            0.004748007462035559`\ c[1, 1] + 0.002599715390082774`\ c[1, 2] - 
            0.0016544378090879437`\ c[1, 3] + 
            0.004655387674539014`\ c[2, 0] - 0.002885254569564683`\ c[2, 1] + 
            0.0014442877470159754`\ c[2, 2] - 
            0.0008787138977880775`\ c[2, 3] + 
            0.002983415125407614`\ c[3, 0] - 0.001775184127632271`\ c[3, 1] + 
            0.0008208681744471414`\ c[3, 2] - 
            0.0004831062256722749`\ c[3, 
                3] == \(-0.0034129416600930133`\)\)\),
      SequenceForm[ "eq", {3, 3}, " = ", 
        Equal[ 
          Plus[ 
            Times[ 0.008758208053733783, 
              c[ 0, 0]], 
            Times[ -0.0069026894993323091, 
              c[ 0, 1]], 
            Times[ 0.0042589583390757347, 
              c[ 0, 2]], 
            Times[ -0.0029194507349737213, 
              c[ 0, 3]], 
            Times[ 0.0071606049283372275, 
              c[ 1, 0]], 
            Times[ -0.0047480074620355594, 
              c[ 1, 1]], 
            Times[ 0.0025997153900827741, 
              c[ 1, 2]], 
            Times[ -0.0016544378090879437, 
              c[ 1, 3]], 
            Times[ 0.0046553876745390136, 
              c[ 2, 0]], 
            Times[ -0.002885254569564683, 
              c[ 2, 1]], 
            Times[ 0.0014442877470159754, 
              c[ 2, 2]], 
            Times[ -0.00087871389778807754, 
              c[ 2, 3]], 
            Times[ 0.0029834151254076141, 
              c[ 3, 0]], 
            Times[ -0.001775184127632271, 
              c[ 3, 1]], 
            Times[ 0.0008208681744471414, 
              c[ 3, 2]], 
            Times[ -0.00048310622567227489, 
              c[ 3, 3]]], -0.0034129416600930133]],
      Editable->False]], "Print"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot3D[\((\[Phi][x, y])\)\ Boole[
            z[1, x, y] \[LessEqual] \ \ \ 0\  && \ 
              z[2, x, y] \[LessEqual] \ \ \ 0\ ], {x, \(-1.3\), 
          1.3}, {y, \(-1.3\), 1.3}, PlotPoints \[Rule] 60, 
        PlotRange \[Rule] All, Mesh \[Rule] False, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
        PlotLabel -> "\<\[Phi]\>"];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.31"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -5 0 ]
[.5 .82364 5 12 ]
[.09521 .21956 -12 -8.90049 ]
[.09521 .21956 0 .09951 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.5975 .02203 -5.10557 -9 ]
[.5975 .02203 .89443 0 ]
[.29165 .07573 -9.31117 -12 ]
[.29165 .07573 .68883 0 ]
[.74008 .05512 0 -6.20283 ]
[.74008 .05512 12 2.79717 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.95518 .38451 0 -5.89111 ]
[.95518 .38451 6 3.10889 ]
[.91861 .21225 0 -8.04169 ]
[.91861 .21225 10 3.95831 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01567 .318 -24 -2.78704 ]
[.01567 .318 0 6.21296 ]
[.00694 .37275 -18 -2.83348 ]
[.00694 .37275 0 6.16652 ]
[-0.00211 .42944 -24 -2.88175 ]
[-0.00211 .42944 0 6.11825 ]
[-0.01148 .48818 -6 -2.93196 ]
[-0.01148 .48818 0 6.06804 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.10459 .22873 m
.10928 .23332 L
s
[(-1)] .09521 .21956 1 .97789 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60504 .03277 m
.60881 .03814 L
s
[(1)] .5975 .02203 .70186 1 Mshowa
.125 Mabswid
.15056 .21073 m
.15333 .21353 L
s
.19737 .19241 m
.20009 .19525 L
s
.24504 .17374 m
.24771 .17663 L
s
.29359 .15473 m
.29622 .15766 L
s
.39347 .11562 m
.39599 .11865 L
s
.44485 .0955 m
.4473 .09858 L
s
.49721 .075 m
.4996 .07812 L
s
.5506 .05409 m
.55293 .05726 L
s
.05944 .24641 m
.06229 .24912 L
s
.66056 .01103 m
.66275 .0143 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7278 .05976 m
.72167 .06208 L
s
[(-1)] .74008 .05512 -1 .37841 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.94264 .38838 m
.93637 .39032 L
s
[(1)] .95518 .38451 -1 .30914 Mshowa
.125 Mabswid
.7527 .09784 m
.74901 .09921 L
s
.77673 .1346 m
.77303 .13594 L
s
.79994 .17011 m
.79623 .17143 L
s
.82238 .20443 m
.81866 .20572 L
s
.86507 .26972 m
.86133 .27097 L
s
.88539 .30081 m
.88165 .30203 L
s
.90507 .33092 m
.90132 .33212 L
s
.92415 .3601 m
.92039 .36128 L
s
.702 .02028 m
.69833 .02171 L
s
.96058 .41582 m
.95681 .41697 L
s
gsave
.91861 .21225 -61 -12.0417 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02794 .31333 m
.03407 .311 L
s
[(0.25)] .01567 .318 1 -0.38066 Mshowa
.01924 .36819 m
.0254 .36591 L
s
[(0.5)] .00694 .37275 1 -0.37034 Mshowa
.01024 .425 m
.01642 .42278 L
s
[(0.75)] -0.00211 .42944 1 -0.35961 Mshowa
.00091 .48386 m
.00711 .4817 L
s
[(1)] -0.01148 .48818 1 -0.34845 Mshowa
.125 Mabswid
.03468 .27079 m
.03835 .26936 L
s
.03301 .28132 m
.03668 .2799 L
s
.03133 .29192 m
.03501 .2905 L
s
.02964 .30259 m
.03332 .30118 L
s
.02622 .32415 m
.0299 .32276 L
s
.0245 .33505 m
.02818 .33366 L
s
.02276 .34602 m
.02644 .34464 L
s
.02101 .35706 m
.0247 .35569 L
s
.01747 .37939 m
.02116 .37803 L
s
.01568 .39067 m
.01938 .38932 L
s
.01388 .40203 m
.01758 .40069 L
s
.01207 .41347 m
.01577 .41213 L
s
.0084 .4366 m
.01211 .43528 L
s
.00655 .44829 m
.01026 .44697 L
s
.00469 .46006 m
.0084 .45875 L
s
.00281 .47192 m
.00652 .47062 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39995 .5989 .40512 .60371 .4138 .60111 .40865 .59628 Mtetra
.40865 .59628 .4138 .60111 .42251 .5985 .41737 .59365 Mtetra
.41737 .59365 .42251 .5985 .43124 .59588 .42613 .59102 Mtetra
.42613 .59102 .43124 .59588 .44001 .59325 .43491 .58837 Mtetra
.43491 .58837 .44001 .59325 .4488 .59061 .44372 .58572 Mtetra
.44372 .58572 .4488 .59061 .45762 .58796 .45256 .58306 Mtetra
.45256 .58306 .45762 .58796 .46647 .58531 .46142 .58039 Mtetra
.46142 .58039 .46647 .58531 .47535 .58265 .47032 .57771 Mtetra
.47032 .57771 .47535 .58265 .48425 .57997 .47925 .57502 Mtetra
.47925 .57502 .48425 .57997 .49319 .57729 .4882 .57232 Mtetra
.4882 .57232 .49319 .57729 .50216 .5746 .49719 .56961 Mtetra
.49719 .56961 .50216 .5746 .51115 .5719 .5062 .5669 Mtetra
.5062 .5669 .51115 .5719 .52017 .5692 .51524 .56418 Mtetra
.51524 .56418 .52017 .5692 .52923 .56648 .52432 .56144 Mtetra
.52432 .56144 .52923 .56648 .53831 .56376 .53342 .5587 Mtetra
.53342 .5587 .53831 .56376 .54743 .56102 .54256 .55595 Mtetra
.54256 .55595 .54743 .56102 .55657 .55828 .55172 .55319 Mtetra
.55172 .55319 .55657 .55828 .56575 .55553 .56092 .55042 Mtetra
.56092 .55042 .56575 .55553 .57495 .55276 .57014 .54764 Mtetra
.57014 .54764 .57495 .55276 .58419 .54999 .5794 .54485 Mtetra
.5794 .54485 .58419 .54999 .59345 .54721 .58869 .54206 Mtetra
.58869 .54206 .59345 .54721 .60275 .54442 .598 .53925 Mtetra
.598 .53925 .60275 .54442 .61208 .54163 .60735 .53643 Mtetra
.60735 .53643 .61208 .54163 .62144 .53882 .61673 .53361 Mtetra
.61673 .53361 .62144 .53882 .63083 .536 .62615 .53077 Mtetra
.62615 .53077 .63083 .536 .64026 .53317 .63559 .52793 Mtetra
.63559 .52793 .64026 .53317 .64971 .53034 .64507 .52507 Mtetra
.64507 .52507 .64971 .53034 .6592 .52749 .65458 .52221 Mtetra
.65458 .52221 .6592 .52749 .66872 .52463 .66412 .51934 Mtetra
.66412 .51934 .66872 .52463 .67827 .52177 .67369 .51645 Mtetra
.67369 .51645 .67827 .52177 .68785 .51889 .6833 .51356 Mtetra
.6833 .51356 .68785 .51889 .69747 .51601 .69293 .51066 Mtetra
.69293 .51066 .69747 .51601 .70711 .51312 .70261 .50775 Mtetra
.70261 .50775 .70711 .51312 .7168 .51021 .71231 .50482 Mtetra
.71231 .50482 .7168 .51021 .72651 .5073 .72205 .50189 Mtetra
.72205 .50189 .72651 .5073 .73626 .50437 .73182 .49895 Mtetra
.73182 .49895 .73626 .50437 .74604 .50144 .74162 .49599 Mtetra
.74162 .49599 .74604 .50144 .75585 .49849 .75146 .49303 Mtetra
.75146 .49303 .75585 .49849 .7657 .49554 .76133 .49006 Mtetra
.76133 .49006 .7657 .49554 .77558 .49257 .77124 .48707 Mtetra
.77124 .48707 .77558 .49257 .7855 .4896 .78118 .48408 Mtetra
.78118 .48408 .7855 .4896 .79545 .48661 .79115 .48108 Mtetra
.79115 .48108 .79545 .48661 .80544 .48362 .80116 .47806 Mtetra
.80116 .47806 .80544 .48362 .81546 .48061 .81121 .47504 Mtetra
.81121 .47504 .81546 .48061 .82551 .4776 .82129 .472 Mtetra
.82129 .472 .82551 .4776 .8356 .47457 .8314 .46895 Mtetra
.8314 .46895 .8356 .47457 .84573 .47153 .84155 .4659 Mtetra
.84155 .4659 .84573 .47153 .85588 .46848 .85174 .46283 Mtetra
.85174 .46283 .85588 .46848 .86608 .46543 .86196 .45975 Mtetra
.86196 .45975 .86608 .46543 .87631 .46236 .87222 .45666 Mtetra
.87222 .45666 .87631 .46236 .88658 .45928 .88251 .45356 Mtetra
.88251 .45356 .88658 .45928 .89688 .45619 .89284 .45045 Mtetra
.89284 .45045 .89688 .45619 .90722 .45308 .90321 .44733 Mtetra
.90321 .44733 .90722 .45308 .9176 .44997 .91361 .4442 Mtetra
.91361 .4442 .9176 .44997 .92801 .44685 .92405 .44105 Mtetra
.92405 .44105 .92801 .44685 .93846 .44371 .93452 .4379 Mtetra
.93452 .4379 .93846 .44371 .94895 .44057 .94504 .43473 Mtetra
.94504 .43473 .94895 .44057 .95947 .43741 .95559 .43155 Mtetra
.95559 .43155 .95947 .43741 .97003 .43424 .96618 .42836 Mtetra
.39475 .59406 .39995 .5989 .40865 .59628 .40347 .59142 Mtetra
.40347 .59142 .40865 .59628 .41737 .59365 .41221 .58878 Mtetra
.41221 .58878 .41737 .59365 .42613 .59102 .42098 .58613 Mtetra
.42098 .58613 .42613 .59102 .43491 .58837 .42978 .58347 Mtetra
.42978 .58347 .43491 .58837 .44372 .58572 .43861 .5808 Mtetra
.43861 .5808 .44372 .58572 .45256 .58306 .44746 .57812 Mtetra
.44746 .57812 .45256 .58306 .46142 .58039 .45635 .57543 Mtetra
.45635 .57543 .46142 .58039 .47032 .57771 .46527 .57274 Mtetra
.46527 .57274 .47032 .57771 .47925 .57502 .47421 .57003 Mtetra
.47421 .57003 .47925 .57502 .4882 .57232 .48318 .56732 Mtetra
.48318 .56732 .4882 .57232 .49719 .56961 .49219 .5646 Mtetra
.49219 .5646 .49719 .56961 .5062 .5669 .50122 .56186 Mtetra
.50122 .56186 .5062 .5669 .51524 .56418 .51028 .55912 Mtetra
.51028 .55912 .51524 .56418 .52432 .56144 .51938 .55637 Mtetra
.51938 .55637 .52432 .56144 .53342 .5587 .5285 .55361 Mtetra
.5285 .55361 .53342 .5587 .54256 .55595 .53766 .55085 Mtetra
.53766 .55085 .54256 .55595 .55172 .55319 .54684 .54807 Mtetra
.54684 .54807 .55172 .55319 .56092 .55042 .55606 .54528 Mtetra
.55606 .54528 .56092 .55042 .57014 .54764 .5653 .54249 Mtetra
.5653 .54249 .57014 .54764 .5794 .54485 .57458 .53968 Mtetra
.57458 .53968 .5794 .54485 .58869 .54206 .58389 .53687 Mtetra
.58389 .53687 .58869 .54206 .598 .53925 .59323 .53404 Mtetra
.59323 .53404 .598 .53925 .60735 .53643 .6026 .53121 Mtetra
.6026 .53121 .60735 .53643 .61673 .53361 .612 .52837 Mtetra
.612 .52837 .61673 .53361 .62615 .53077 .62143 .52551 Mtetra
.62143 .52551 .62615 .53077 .63559 .52793 .6309 .52265 Mtetra
.6309 .52265 .63559 .52793 .64507 .52507 .6404 .51978 Mtetra
.6404 .51978 .64507 .52507 .65458 .52221 .64993 .5169 Mtetra
.64993 .5169 .65458 .52221 .66412 .51934 .65949 .51401 Mtetra
.65949 .51401 .66412 .51934 .67369 .51645 .66908 .51111 Mtetra
.66908 .51111 .67369 .51645 .6833 .51356 .67871 .50819 Mtetra
.67871 .50819 .6833 .51356 .69293 .51066 .68837 .50527 Mtetra
.68837 .50527 .69293 .51066 .70261 .50775 .69807 .50234 Mtetra
.69807 .50234 .70261 .50775 .71231 .50482 .70779 .4994 Mtetra
.70779 .4994 .71231 .50482 .72205 .50189 .71756 .49645 Mtetra
.71756 .49645 .72205 .50189 .73182 .49895 .72735 .49349 Mtetra
.72735 .49349 .73182 .49895 .74162 .49599 .73718 .49052 Mtetra
.73718 .49052 .74162 .49599 .75146 .49303 .74704 .48753 Mtetra
.74704 .48753 .75146 .49303 .76133 .49006 .75694 .48454 Mtetra
.75694 .48454 .76133 .49006 .77124 .48707 .76687 .48154 Mtetra
.76687 .48154 .77124 .48707 .78118 .48408 .77683 .47853 Mtetra
.77683 .47853 .78118 .48408 .79115 .48108 .78683 .4755 Mtetra
.78683 .4755 .79115 .48108 .80116 .47806 .79686 .47247 Mtetra
.79686 .47247 .80116 .47806 .81121 .47504 .80693 .46942 Mtetra
.80693 .46942 .81121 .47504 .82129 .472 .81704 .46637 Mtetra
.81704 .46637 .82129 .472 .8314 .46895 .82718 .4633 Mtetra
.82718 .4633 .8314 .46895 .84155 .4659 .83735 .46023 Mtetra
.83735 .46023 .84155 .4659 .85174 .46283 .84756 .45714 Mtetra
.84756 .45714 .85174 .46283 .86196 .45975 .85781 .45404 Mtetra
.85781 .45404 .86196 .45975 .87222 .45666 .8681 .45093 Mtetra
.8681 .45093 .87222 .45666 .88251 .45356 .87841 .44781 Mtetra
.87841 .44781 .88251 .45356 .89284 .45045 .88877 .44468 Mtetra
.88877 .44468 .89284 .45045 .90321 .44733 .89916 .44154 Mtetra
.89916 .44154 .90321 .44733 .91361 .4442 .90959 .43838 Mtetra
.90959 .43838 .91361 .4442 .92405 .44105 .92006 .43522 Mtetra
.92006 .43522 .92405 .44105 .93452 .4379 .93056 .43204 Mtetra
.93056 .43204 .93452 .4379 .94504 .43473 .94111 .42885 Mtetra
.94111 .42885 .94504 .43473 .95559 .43155 .95168 .42565 Mtetra
.95168 .42565 .95559 .43155 .96618 .42836 .9623 .42244 Mtetra
.38952 .58919 .39475 .59406 .40347 .59142 .39825 .58654 Mtetra
.39825 .58654 .40347 .59142 .41221 .58878 .40701 .58388 Mtetra
.40701 .58388 .41221 .58878 .42098 .58613 .4158 .58121 Mtetra
.4158 .58121 .42098 .58613 .42978 .58347 .42462 .57853 Mtetra
.42462 .57853 .42978 .58347 .43861 .5808 .43347 .57585 Mtetra
.43347 .57585 .43861 .5808 .44746 .57812 .44234 .57315 Mtetra
.44234 .57315 .44746 .57812 .45635 .57543 .45125 .57045 Mtetra
.45125 .57045 .45635 .57543 .46527 .57274 .46018 .56774 Mtetra
.46018 .56774 .46527 .57274 .47421 .57003 .46914 .56501 Mtetra
.46914 .56501 .47421 .57003 .48318 .56732 .47814 .56228 Mtetra
.47814 .56228 .48318 .56732 .49219 .5646 .48716 .55955 Mtetra
.48716 .55955 .49219 .5646 .50122 .56186 .49621 .5568 Mtetra
.49621 .5568 .50122 .56186 .51028 .55912 .50529 .55404 Mtetra
.50529 .55404 .51028 .55912 .51938 .55637 .51441 .55127 Mtetra
.51441 .55127 .51938 .55637 .5285 .55361 .52355 .5485 Mtetra
.52355 .5485 .5285 .55361 .53766 .55085 .53272 .54571 Mtetra
.53272 .54571 .53766 .55085 .54684 .54807 .54193 .54292 Mtetra
.54193 .54292 .54684 .54807 .55606 .54528 .55116 .54011 Mtetra
.55116 .54011 .55606 .54528 .5653 .54249 .56043 .5373 Mtetra
.56043 .5373 .5653 .54249 .57458 .53968 .56973 .53448 Mtetra
.56973 .53448 .57458 .53968 .58389 .53687 .57906 .53165 Mtetra
.57906 .53165 .58389 .53687 .59323 .53404 .58842 .52881 Mtetra
.58842 .52881 .59323 .53404 .6026 .53121 .59781 .52595 Mtetra
.59781 .52595 .6026 .53121 .612 .52837 .60723 .52309 Mtetra
.60723 .52309 .612 .52837 .62143 .52551 .61669 .52022 Mtetra
.61669 .52022 .62143 .52551 .6309 .52265 .62618 .51734 Mtetra
.62618 .51734 .6309 .52265 .6404 .51978 .6357 .51445 Mtetra
.6357 .51445 .6404 .51978 .64993 .5169 .64525 .51155 Mtetra
.64525 .51155 .64993 .5169 .65949 .51401 .65483 .50864 Mtetra
.65483 .50864 .65949 .51401 .66908 .51111 .66445 .50572 Mtetra
.66445 .50572 .66908 .51111 .67871 .50819 .6741 .50279 Mtetra
.6741 .50279 .67871 .50819 .68837 .50527 .68378 .49985 Mtetra
.68378 .49985 .68837 .50527 .69807 .50234 .6935 .4969 Mtetra
.6935 .4969 .69807 .50234 .70779 .4994 .70325 .49394 Mtetra
.70325 .49394 .70779 .4994 .71756 .49645 .71304 .49097 Mtetra
.71304 .49097 .71756 .49645 .72735 .49349 .72285 .48799 Mtetra
.72285 .48799 .72735 .49349 .73718 .49052 .7327 .485 Mtetra
.7327 .485 .73718 .49052 .74704 .48753 .74259 .482 Mtetra
.74259 .482 .74704 .48753 .75694 .48454 .75251 .47899 Mtetra
.75251 .47899 .75694 .48454 .76687 .48154 .76246 .47597 Mtetra
.76246 .47597 .76687 .48154 .77683 .47853 .77245 .47294 Mtetra
.77245 .47294 .77683 .47853 .78683 .4755 .78248 .46989 Mtetra
.78248 .46989 .78683 .4755 .79686 .47247 .79254 .46684 Mtetra
.79254 .46684 .79686 .47247 .80693 .46942 .80263 .46377 Mtetra
.80263 .46377 .80693 .46942 .81704 .46637 .81276 .4607 Mtetra
.81276 .4607 .81704 .46637 .82718 .4633 .82293 .45761 Mtetra
.82293 .45761 .82718 .4633 .83735 .46023 .83313 .45452 Mtetra
.83313 .45452 .83735 .46023 .84756 .45714 .84336 .45141 Mtetra
.84336 .45141 .84756 .45714 .85781 .45404 .85364 .44829 Mtetra
.85364 .44829 .85781 .45404 .8681 .45093 .86395 .44516 Mtetra
.86395 .44516 .8681 .45093 .87841 .44781 .87429 .44202 Mtetra
.87429 .44202 .87841 .44781 .88877 .44468 .88468 .43887 Mtetra
.88468 .43887 .88877 .44468 .89916 .44154 .89509 .4357 Mtetra
.89509 .4357 .89916 .44154 .90959 .43838 .90555 .43253 Mtetra
.90555 .43253 .90959 .43838 .92006 .43522 .91605 .42934 Mtetra
.91605 .42934 .92006 .43522 .93056 .43204 .92658 .42615 Mtetra
.92658 .42615 .93056 .43204 .94111 .42885 .93715 .42294 Mtetra
.93715 .42294 .94111 .42885 .95168 .42565 .94775 .41972 Mtetra
.94775 .41972 .95168 .42565 .9623 .42244 .9584 .41649 Mtetra
.38426 .58429 .38952 .58919 .39825 .58654 .39301 .58162 Mtetra
.39301 .58162 .39825 .58654 .40701 .58388 .40179 .57894 Mtetra
.40179 .57894 .40701 .58388 .4158 .58121 .41059 .57626 Mtetra
.41059 .57626 .4158 .58121 .42462 .57853 .41943 .57357 Mtetra
.41943 .57357 .42462 .57853 .43347 .57585 .42829 .57086 Mtetra
.42829 .57086 .43347 .57585 .44234 .57315 .43719 .56815 Mtetra
.43719 .56815 .44234 .57315 .45125 .57045 .44611 .56543 Mtetra
.44611 .56543 .45125 .57045 .46018 .56774 .45506 .5627 Mtetra
.45506 .5627 .46018 .56774 .46914 .56501 .46404 .55997 Mtetra
.46404 .55997 .46914 .56501 .47814 .56228 .47306 .55722 Mtetra
.47306 .55722 .47814 .56228 .48716 .55955 .4821 .55446 Mtetra
.4821 .55446 .48716 .55955 .49621 .5568 .49117 .5517 Mtetra
.49117 .5517 .49621 .5568 .50529 .55404 .50027 .54893 Mtetra
.50027 .54893 .50529 .55404 .51441 .55127 .50941 .54614 Mtetra
.50941 .54614 .51441 .55127 .52355 .5485 .51857 .54335 Mtetra
.51857 .54335 .52355 .5485 .53272 .54571 .52776 .54055 Mtetra
.52776 .54055 .53272 .54571 .54193 .54292 .53699 .53773 Mtetra
.53699 .53773 .54193 .54292 .55116 .54011 .54624 .53491 Mtetra
.54624 .53491 .55116 .54011 .56043 .5373 .55553 .53208 Mtetra
.55553 .53208 .56043 .5373 .56973 .53448 .56485 .52924 Mtetra
.56485 .52924 .56973 .53448 .57906 .53165 .5742 .52639 Mtetra
.5742 .52639 .57906 .53165 .58842 .52881 .58358 .52353 Mtetra
.58358 .52353 .58842 .52881 .59781 .52595 .59299 .52067 Mtetra
.59299 .52067 .59781 .52595 .60723 .52309 .60244 .51779 Mtetra
.60244 .51779 .60723 .52309 .61669 .52022 .61191 .5149 Mtetra
.61191 .5149 .61669 .52022 .62618 .51734 .62142 .512 Mtetra
.62142 .512 .62618 .51734 .6357 .51445 .63097 .50909 Mtetra
.63097 .50909 .6357 .51445 .64525 .51155 .64054 .50617 Mtetra
.64054 .50617 .64525 .51155 .65483 .50864 .65015 .50324 Mtetra
.65015 .50324 .65483 .50864 .66445 .50572 .65979 .50031 Mtetra
.65979 .50031 .66445 .50572 .6741 .50279 .66946 .49736 Mtetra
.66946 .49736 .6741 .50279 .68378 .49985 .67917 .4944 Mtetra
.67917 .4944 .68378 .49985 .6935 .4969 .68891 .49143 Mtetra
.68891 .49143 .6935 .4969 .70325 .49394 .69868 .48845 Mtetra
.69868 .48845 .70325 .49394 .71304 .49097 .70849 .48546 Mtetra
.70849 .48546 .71304 .49097 .72285 .48799 .71833 .48246 Mtetra
.71833 .48246 .72285 .48799 .7327 .485 .7282 .47945 Mtetra
.7282 .47945 .7327 .485 .74259 .482 .73811 .47643 Mtetra
.73811 .47643 .74259 .482 .75251 .47899 .74806 .4734 Mtetra
.74806 .4734 .75251 .47899 .76246 .47597 .75804 .47036 Mtetra
.75804 .47036 .76246 .47597 .77245 .47294 .76805 .46731 Mtetra
.76805 .46731 .77245 .47294 .78248 .46989 .7781 .46425 Mtetra
.7781 .46425 .78248 .46989 .79254 .46684 .78818 .46117 Mtetra
.78818 .46117 .79254 .46684 .80263 .46377 .7983 .45809 Mtetra
.7983 .45809 .80263 .46377 .81276 .4607 .80846 .45499 Mtetra
.80846 .45499 .81276 .4607 .82293 .45761 .81865 .45189 Mtetra
.81865 .45189 .82293 .45761 .83313 .45452 .82887 .44877 Mtetra
.82887 .44877 .83313 .45452 .84336 .45141 .83914 .44564 Mtetra
.83914 .44564 .84336 .45141 .85364 .44829 .84943 .4425 Mtetra
.84943 .4425 .85364 .44829 .86395 .44516 .85977 .43935 Mtetra
.85977 .43935 .86395 .44516 .87429 .44202 .87014 .43619 Mtetra
.87014 .43619 .87429 .44202 .88468 .43887 .88055 .43302 Mtetra
.88055 .43302 .88468 .43887 .89509 .4357 .891 .42984 Mtetra
.891 .42984 .89509 .4357 .90555 .43253 .90148 .42664 Mtetra
.90148 .42664 .90555 .43253 .91605 .42934 .912 .42343 Mtetra
.912 .42343 .91605 .42934 .92658 .42615 .92256 .42021 Mtetra
.92256 .42021 .92658 .42615 .93715 .42294 .93316 .41698 Mtetra
.93316 .41698 .93715 .42294 .94775 .41972 .9438 .41374 Mtetra
.9438 .41374 .94775 .41972 .9584 .41649 .95447 .41049 Mtetra
.37896 .57936 .38426 .58429 .39301 .58162 .38773 .57667 Mtetra
.38773 .57667 .39301 .58162 .40179 .57894 .39653 .57398 Mtetra
.39653 .57398 .40179 .57894 .41059 .57626 .40535 .57128 Mtetra
.40535 .57128 .41059 .57626 .41943 .57357 .4142 .56857 Mtetra
.4142 .56857 .41943 .57357 .42829 .57086 .42309 .56585 Mtetra
.42309 .56585 .42829 .57086 .43719 .56815 .432 .56313 Mtetra
.432 .56313 .43719 .56815 .44611 .56543 .44094 .56039 Mtetra
.44094 .56039 .44611 .56543 .45506 .5627 .44991 .55764 Mtetra
.44991 .55764 .45506 .5627 .46404 .55997 .45892 .55489 Mtetra
.45892 .55489 .46404 .55997 .47306 .55722 .46795 .55213 Mtetra
.46795 .55213 .47306 .55722 .4821 .55446 .47701 .54935 Mtetra
.47701 .54935 .4821 .55446 .49117 .5517 .4861 .54657 Mtetra
.4861 .54657 .49117 .5517 .50027 .54893 .49522 .54378 Mtetra
.49522 .54378 .50027 .54893 .50941 .54614 .50437 .54098 Mtetra
.50437 .54098 .50941 .54614 .51857 .54335 .51356 .53817 Mtetra
.51356 .53817 .51857 .54335 .52776 .54055 .52277 .53535 Mtetra
.52277 .53535 .52776 .54055 .53699 .53773 .53202 .53252 Mtetra
.53202 .53252 .53699 .53773 .54624 .53491 .54129 .52968 Mtetra
.54129 .52968 .54624 .53491 .55553 .53208 .5506 .52683 Mtetra
.5506 .52683 .55553 .53208 .56485 .52924 .55994 .52397 Mtetra
.55994 .52397 .56485 .52924 .5742 .52639 .56931 .52111 Mtetra
.56931 .52111 .5742 .52639 .58358 .52353 .57871 .51823 Mtetra
.57871 .51823 .58358 .52353 .59299 .52067 .58815 .51534 Mtetra
.58815 .51534 .59299 .52067 .60244 .51779 .59761 .51245 Mtetra
.59761 .51245 .60244 .51779 .61191 .5149 .60711 .50954 Mtetra
.60711 .50954 .61191 .5149 .62142 .512 .61664 .50662 Mtetra
.61664 .50662 .62142 .512 .63097 .50909 .6262 .5037 Mtetra
.6262 .5037 .63097 .50909 .64054 .50617 .6358 .50076 Mtetra
.6358 .50076 .64054 .50617 .65015 .50324 .64543 .49781 Mtetra
.64543 .49781 .65015 .50324 .65979 .50031 .65509 .49486 Mtetra
.65509 .49486 .65979 .50031 .66946 .49736 .66479 .49189 Mtetra
.66479 .49189 .66946 .49736 .67917 .4944 .67452 .48891 Mtetra
.67452 .48891 .67917 .4944 .68891 .49143 .68428 .48592 Mtetra
.68428 .48592 .68891 .49143 .69868 .48845 .69408 .48293 Mtetra
.69408 .48293 .69868 .48845 .70849 .48546 .70391 .47992 Mtetra
.70391 .47992 .70849 .48546 .71833 .48246 .71377 .4769 Mtetra
.71377 .4769 .71833 .48246 .7282 .47945 .72367 .47387 Mtetra
.72367 .47387 .7282 .47945 .73811 .47643 .73361 .47083 Mtetra
.73361 .47083 .73811 .47643 .74806 .4734 .74357 .46778 Mtetra
.74357 .46778 .74806 .4734 .75804 .47036 .75358 .46472 Mtetra
.75358 .46472 .75804 .47036 .76805 .46731 .76362 .46165 Mtetra
.76362 .46165 .76805 .46731 .7781 .46425 .77369 .45856 Mtetra
.77369 .45856 .7781 .46425 .78818 .46117 .7838 .45547 Mtetra
.7838 .45547 .78818 .46117 .7983 .45809 .79394 .45237 Mtetra
.79394 .45237 .7983 .45809 .80846 .45499 .80412 .44925 Mtetra
.80412 .44925 .80846 .45499 .81865 .45189 .81434 .44612 Mtetra
.81434 .44612 .81865 .45189 .82887 .44877 .82459 .44299 Mtetra
.82459 .44299 .82887 .44877 .83914 .44564 .83488 .43984 Mtetra
.83488 .43984 .83914 .44564 .84943 .4425 .84521 .43668 Mtetra
.84521 .43668 .84943 .4425 .85977 .43935 .85557 .43351 Mtetra
.85557 .43351 .85977 .43935 .87014 .43619 .86597 .43033 Mtetra
.86597 .43033 .87014 .43619 .88055 .43302 .8764 .42713 Mtetra
.8764 .42713 .88055 .43302 .891 .42984 .88688 .42393 Mtetra
.88688 .42393 .891 .42984 .90148 .42664 .89739 .42071 Mtetra
.89739 .42071 .90148 .42664 .912 .42343 .90794 .41748 Mtetra
.90794 .41748 .912 .42343 .92256 .42021 .91852 .41424 Mtetra
.91852 .41424 .92256 .42021 .93316 .41698 .92915 .41099 Mtetra
.92915 .41099 .93316 .41698 .9438 .41374 .93981 .40773 Mtetra
.93981 .40773 .9438 .41374 .95447 .41049 .95051 .40445 Mtetra
.37364 .5744 .37896 .57936 .38773 .57667 .38242 .5717 Mtetra
.38242 .5717 .38773 .57667 .39653 .57398 .39123 .56899 Mtetra
.39123 .56899 .39653 .57398 .40535 .57128 .40008 .56627 Mtetra
.40008 .56627 .40535 .57128 .4142 .56857 .40895 .56355 Mtetra
.40895 .56355 .4142 .56857 .42309 .56585 .41785 .56081 Mtetra
.41785 .56081 .42309 .56585 .432 .56313 .42678 .55807 Mtetra
.42678 .55807 .432 .56313 .44094 .56039 .43574 .55531 Mtetra
.43574 .55531 .44094 .56039 .44991 .55764 .44473 .55255 Mtetra
.44473 .55255 .44991 .55764 .45892 .55489 .45375 .54978 Mtetra
.45375 .54978 .45892 .55489 .46795 .55213 .4628 .547 Mtetra
.4628 .547 .46795 .55213 .47701 .54935 .47189 .54421 Mtetra
.47189 .54421 .47701 .54935 .4861 .54657 .481 .54141 Mtetra
.481 .54141 .4861 .54657 .49522 .54378 .49014 .5386 Mtetra
.49014 .5386 .49522 .54378 .50437 .54098 .49931 .53578 Mtetra
.49931 .53578 .50437 .54098 .51356 .53817 .50851 .53296 Mtetra
.50851 .53296 .51356 .53817 .52277 .53535 .51775 .53012 Mtetra
.51775 .53012 .52277 .53535 .53202 .53252 .52701 .52727 Mtetra
.52701 .52727 .53202 .53252 .54129 .52968 .53631 .52441 Mtetra
.53631 .52441 .54129 .52968 .5506 .52683 .54564 .52155 Mtetra
.54564 .52155 .5506 .52683 .55994 .52397 .555 .51867 Mtetra
.555 .51867 .55994 .52397 .56931 .52111 .56439 .51579 Mtetra
.56439 .51579 .56931 .52111 .57871 .51823 .57381 .51289 Mtetra
.57381 .51289 .57871 .51823 .58815 .51534 .58327 .50999 Mtetra
.58327 .50999 .58815 .51534 .59761 .51245 .59276 .50707 Mtetra
.59276 .50707 .59761 .51245 .60711 .50954 .60228 .50415 Mtetra
.60228 .50415 .60711 .50954 .61664 .50662 .61183 .50121 Mtetra
.61183 .50121 .61664 .50662 .6262 .5037 .62141 .49827 Mtetra
.62141 .49827 .6262 .5037 .6358 .50076 .63103 .49531 Mtetra
.63103 .49531 .6358 .50076 .64543 .49781 .64068 .49235 Mtetra
.64068 .49235 .64543 .49781 .65509 .49486 .65037 .48937 Mtetra
.65037 .48937 .65509 .49486 .66479 .49189 .66009 .48638 Mtetra
.66009 .48638 .66479 .49189 .67452 .48891 .66984 .48339 Mtetra
.66984 .48339 .67452 .48891 .68428 .48592 .67963 .48038 Mtetra
.67963 .48038 .68428 .48592 .69408 .48293 .68945 .47736 Mtetra
.68945 .47736 .69408 .48293 .70391 .47992 .6993 .47434 Mtetra
.6993 .47434 .70391 .47992 .71377 .4769 .70919 .4713 Mtetra
.70919 .4713 .71377 .4769 .72367 .47387 .71911 .46825 Mtetra
.71911 .46825 .72367 .47387 .73361 .47083 .72907 .46519 Mtetra
.72907 .46519 .73361 .47083 .74357 .46778 .73906 .46212 Mtetra
.73906 .46212 .74357 .46778 .75358 .46472 .74909 .45904 Mtetra
.74909 .45904 .75358 .46472 .76362 .46165 .75915 .45595 Mtetra
.75915 .45595 .76362 .46165 .77369 .45856 .76925 .45284 Mtetra
.76925 .45284 .77369 .45856 .7838 .45547 .77938 .44973 Mtetra
.77938 .44973 .7838 .45547 .79394 .45237 .78955 .44661 Mtetra
.78955 .44661 .79394 .45237 .80412 .44925 .79976 .44347 Mtetra
.79976 .44347 .80412 .44925 .81434 .44612 .81 .44032 Mtetra
.81 .44032 .81434 .44612 .82459 .44299 .82028 .43717 Mtetra
.82028 .43717 .82459 .44299 .83488 .43984 .8306 .434 Mtetra
.8306 .434 .83488 .43984 .84521 .43668 .84095 .43082 Mtetra
.84095 .43082 .84521 .43668 .85557 .43351 .85134 .42762 Mtetra
.85134 .42762 .85557 .43351 .86597 .43033 .86176 .42442 Mtetra
.86176 .42442 .86597 .43033 .8764 .42713 .87223 .42121 Mtetra
.87223 .42121 .8764 .42713 .88688 .42393 .88273 .41798 Mtetra
.88273 .41798 .88688 .42393 .89739 .42071 .89327 .41474 Mtetra
.89327 .41474 .89739 .42071 .90794 .41748 .90384 .41149 Mtetra
.90384 .41149 .90794 .41748 .91852 .41424 .91446 .40823 Mtetra
.91446 .40823 .91852 .41424 .92915 .41099 .92511 .40496 Mtetra
.92511 .40496 .92915 .41099 .93981 .40773 .9358 .40167 Mtetra
.9358 .40167 .93981 .40773 .95051 .40445 .94653 .39838 Mtetra
.36828 .56941 .37364 .5744 .38242 .5717 .37708 .56669 Mtetra
.37708 .56669 .38242 .5717 .39123 .56899 .38591 .56397 Mtetra
.38591 .56397 .39123 .56899 .40008 .56627 .39477 .56123 Mtetra
.39477 .56123 .40008 .56627 .40895 .56355 .40366 .55849 Mtetra
.40366 .55849 .40895 .56355 .41785 .56081 .41258 .55574 Mtetra
.41258 .55574 .41785 .56081 .42678 .55807 .42153 .55298 Mtetra
.42153 .55298 .42678 .55807 .43574 .55531 .43051 .55021 Mtetra
.43051 .55021 .43574 .55531 .44473 .55255 .43952 .54743 Mtetra
.43952 .54743 .44473 .55255 .45375 .54978 .44856 .54464 Mtetra
.44856 .54464 .45375 .54978 .4628 .547 .45763 .54184 Mtetra
.45763 .54184 .4628 .547 .47189 .54421 .46673 .53903 Mtetra
.46673 .53903 .47189 .54421 .481 .54141 .47586 .53622 Mtetra
.47586 .53622 .481 .54141 .49014 .5386 .48502 .53339 Mtetra
.48502 .53339 .49014 .5386 .49931 .53578 .49422 .53056 Mtetra
.49422 .53056 .49931 .53578 .50851 .53296 .50344 .52771 Mtetra
.50344 .52771 .50851 .53296 .51775 .53012 .51269 .52485 Mtetra
.51269 .52485 .51775 .53012 .52701 .52727 .52198 .52199 Mtetra
.52198 .52199 .52701 .52727 .53631 .52441 .5313 .51912 Mtetra
.5313 .51912 .53631 .52441 .54564 .52155 .54064 .51623 Mtetra
.54064 .51623 .54564 .52155 .555 .51867 .55003 .51334 Mtetra
.55003 .51334 .555 .51867 .56439 .51579 .55944 .51043 Mtetra
.55944 .51043 .56439 .51579 .57381 .51289 .56888 .50752 Mtetra
.56888 .50752 .57381 .51289 .58327 .50999 .57836 .5046 Mtetra
.57836 .5046 .58327 .50999 .59276 .50707 .58787 .50166 Mtetra
.58787 .50166 .59276 .50707 .60228 .50415 .59741 .49872 Mtetra
.59741 .49872 .60228 .50415 .61183 .50121 .60699 .49577 Mtetra
.60699 .49577 .61183 .50121 .62141 .49827 .61659 .4928 Mtetra
.61659 .4928 .62141 .49827 .63103 .49531 .62623 .48983 Mtetra
.62623 .48983 .63103 .49531 .64068 .49235 .63591 .48684 Mtetra
.63591 .48684 .64068 .49235 .65037 .48937 .64562 .48385 Mtetra
.64562 .48385 .65037 .48937 .66009 .48638 .65536 .48084 Mtetra
.65536 .48084 .66009 .48638 .66984 .48339 .66513 .47783 Mtetra
.66513 .47783 .66984 .48339 .67963 .48038 .67494 .4748 Mtetra
.67494 .4748 .67963 .48038 .68945 .47736 .68479 .47177 Mtetra
.68479 .47177 .68945 .47736 .6993 .47434 .69466 .46872 Mtetra
.69466 .46872 .6993 .47434 .70919 .4713 .70458 .46566 Mtetra
.70458 .46566 .70919 .4713 .71911 .46825 .71452 .46259 Mtetra
.71452 .46259 .71911 .46825 .72907 .46519 .7245 .45951 Mtetra
.7245 .45951 .72907 .46519 .73906 .46212 .73452 .45642 Mtetra
.73452 .45642 .73906 .46212 .74909 .45904 .74457 .45332 Mtetra
.74457 .45332 .74909 .45904 .75915 .45595 .75466 .45021 Mtetra
.75466 .45021 .75915 .45595 .76925 .45284 .76478 .44709 Mtetra
.76478 .44709 .76925 .45284 .77938 .44973 .77494 .44395 Mtetra
.77494 .44395 .77938 .44973 .78955 .44661 .78514 .44081 Mtetra
.78514 .44081 .78955 .44661 .79976 .44347 .79537 .43765 Mtetra
.79537 .43765 .79976 .44347 .81 .44032 .80564 .43448 Mtetra
.80564 .43448 .81 .44032 .82028 .43717 .81594 .43131 Mtetra
.81594 .43131 .82028 .43717 .8306 .434 .82628 .42812 Mtetra
.82628 .42812 .8306 .434 .84095 .43082 .83666 .42491 Mtetra
.83666 .42491 .84095 .43082 .85134 .42762 .84708 .4217 Mtetra
.84708 .4217 .85134 .42762 .86176 .42442 .85753 .41848 Mtetra
.85753 .41848 .86176 .42442 .87223 .42121 .86802 .41524 Mtetra
.86802 .41524 .87223 .42121 .88273 .41798 .87855 .41199 Mtetra
.87855 .41199 .88273 .41798 .89327 .41474 .88912 .40873 Mtetra
.88912 .40873 .89327 .41474 .90384 .41149 .89972 .40546 Mtetra
.89972 .40546 .90384 .41149 .91446 .40823 .91036 .40218 Mtetra
.91036 .40218 .91446 .40823 .92511 .40496 .92104 .39888 Mtetra
.92104 .39888 .92511 .40496 .9358 .40167 .93176 .39558 Mtetra
.93176 .39558 .9358 .40167 .94653 .39838 .94252 .39226 Mtetra
.36288 .56439 .36828 .56941 .37708 .56669 .37171 .56165 Mtetra
.37171 .56165 .37708 .56669 .38591 .56397 .38056 .55891 Mtetra
.38056 .55891 .38591 .56397 .39477 .56123 .38944 .55616 Mtetra
.38944 .55616 .39477 .56123 .40366 .55849 .39834 .5534 Mtetra
.39834 .5534 .40366 .55849 .41258 .55574 .40728 .55063 Mtetra
.40728 .55063 .41258 .55574 .42153 .55298 .41625 .54786 Mtetra
.41625 .54786 .42153 .55298 .43051 .55021 .42525 .54507 Mtetra
.42525 .54507 .43051 .55021 .43952 .54743 .43428 .54227 Mtetra
.43428 .54227 .43952 .54743 .44856 .54464 .44334 .53947 Mtetra
.44334 .53947 .44856 .54464 .45763 .54184 .45243 .53665 Mtetra
.45243 .53665 .45763 .54184 .46673 .53903 .46155 .53383 Mtetra
.46155 .53383 .46673 .53903 .47586 .53622 .4707 .53099 Mtetra
.4707 .53099 .47586 .53622 .48502 .53339 .47988 .52815 Mtetra
.47988 .52815 .48502 .53339 .49422 .53056 .48909 .52529 Mtetra
.48909 .52529 .49422 .53056 .50344 .52771 .49833 .52243 Mtetra
.49833 .52243 .50344 .52771 .51269 .52485 .50761 .51956 Mtetra
.50761 .51956 .51269 .52485 .52198 .52199 .51691 .51668 Mtetra
.51691 .51668 .52198 .52199 .5313 .51912 .52625 .51378 Mtetra
.52625 .51378 .5313 .51912 .54064 .51623 .53562 .51088 Mtetra
.53562 .51088 .54064 .51623 .55003 .51334 .54502 .50797 Mtetra
.54502 .50797 .55003 .51334 .55944 .51043 .55446 .50505 Mtetra
.55446 .50505 .55944 .51043 .56888 .50752 .56392 .50212 Mtetra
.56392 .50212 .56888 .50752 .57836 .5046 .57342 .49917 Mtetra
.57342 .49917 .57836 .5046 .58787 .50166 .58295 .49622 Mtetra
.58295 .49622 .58787 .50166 .59741 .49872 .59251 .49326 Mtetra
.59251 .49326 .59741 .49872 .60699 .49577 .60211 .49029 Mtetra
.60211 .49029 .60699 .49577 .61659 .4928 .61174 .4873 Mtetra
.61174 .4873 .61659 .4928 .62623 .48983 .62141 .48431 Mtetra
.62141 .48431 .62623 .48983 .63591 .48684 .6311 .48131 Mtetra
.6311 .48131 .63591 .48684 .64562 .48385 .64083 .47829 Mtetra
.64083 .47829 .64562 .48385 .65536 .48084 .6506 .47527 Mtetra
.6506 .47527 .65536 .48084 .66513 .47783 .66039 .47223 Mtetra
.66039 .47223 .66513 .47783 .67494 .4748 .67023 .46919 Mtetra
.67023 .46919 .67494 .4748 .68479 .47177 .68009 .46613 Mtetra
.68009 .46613 .68479 .47177 .69466 .46872 .69 .46307 Mtetra
.69 .46307 .69466 .46872 .70458 .46566 .69993 .45999 Mtetra
.69993 .45999 .70458 .46566 .71452 .46259 .7099 .4569 Mtetra
.7099 .4569 .71452 .46259 .7245 .45951 .71991 .4538 Mtetra
.71991 .4538 .7245 .45951 .73452 .45642 .72995 .45069 Mtetra
.72995 .45069 .73452 .45642 .74457 .45332 .74003 .44757 Mtetra
.74003 .44757 .74457 .45332 .75466 .45021 .75014 .44444 Mtetra
.75014 .44444 .75466 .45021 .76478 .44709 .76029 .44129 Mtetra
.76029 .44129 .76478 .44709 .77494 .44395 .77047 .43814 Mtetra
.77047 .43814 .77494 .44395 .78514 .44081 .78069 .43497 Mtetra
.78069 .43497 .78514 .44081 .79537 .43765 .79095 .4318 Mtetra
.79095 .4318 .79537 .43765 .80564 .43448 .80124 .42861 Mtetra
.80124 .42861 .80564 .43448 .81594 .43131 .81158 .42541 Mtetra
.81158 .42541 .81594 .43131 .82628 .42812 .82194 .4222 Mtetra
.82194 .4222 .82628 .42812 .83666 .42491 .83235 .41897 Mtetra
.83235 .41897 .83666 .42491 .84708 .4217 .84279 .41574 Mtetra
.84279 .41574 .84708 .4217 .85753 .41848 .85327 .41249 Mtetra
.85327 .41249 .85753 .41848 .86802 .41524 .86379 .40924 Mtetra
.86379 .40924 .86802 .41524 .87855 .41199 .87434 .40597 Mtetra
.87434 .40597 .87855 .41199 .88912 .40873 .88494 .40268 Mtetra
.88494 .40268 .88912 .40873 .89972 .40546 .89557 .39939 Mtetra
.89557 .39939 .89972 .40546 .91036 .40218 .90624 .39609 Mtetra
.90624 .39609 .91036 .40218 .92104 .39888 .91695 .39277 Mtetra
.91695 .39277 .92104 .39888 .93176 .39558 .9277 .38944 Mtetra
.9277 .38944 .93176 .39558 .94252 .39226 .93849 .3861 Mtetra
.35746 .55933 .36288 .56439 .37171 .56165 .3663 .55659 Mtetra
.3663 .55659 .37171 .56165 .38056 .55891 .37517 .55383 Mtetra
.37517 .55383 .38056 .55891 .38944 .55616 .38406 .55106 Mtetra
.38406 .55106 .38944 .55616 .39834 .5534 .39299 .54828 Mtetra
.39299 .54828 .39834 .5534 .40728 .55063 .40195 .5455 Mtetra
.40195 .5455 .40728 .55063 .41625 .54786 .41094 .5427 Mtetra
.41094 .5427 .41625 .54786 .42525 .54507 .41995 .5399 Mtetra
.41995 .5399 .42525 .54507 .43428 .54227 .429 .53708 Mtetra
.429 .53708 .43428 .54227 .44334 .53947 .43808 .53426 Mtetra
.43808 .53426 .44334 .53947 .45243 .53665 .44719 .53143 Mtetra
.44719 .53143 .45243 .53665 .46155 .53383 .45633 .52859 Mtetra
.45633 .52859 .46155 .53383 .4707 .53099 .4655 .52573 Mtetra
.4655 .52573 .4707 .53099 .47988 .52815 .4747 .52287 Mtetra
.4747 .52287 .47988 .52815 .48909 .52529 .48393 .52 Mtetra
.48393 .52 .48909 .52529 .49833 .52243 .49319 .51712 Mtetra
.49319 .51712 .49833 .52243 .50761 .51956 .50249 .51423 Mtetra
.50249 .51423 .50761 .51956 .51691 .51668 .51182 .51133 Mtetra
.51182 .51133 .51691 .51668 .52625 .51378 .52117 .50842 Mtetra
.52117 .50842 .52625 .51378 .53562 .51088 .53056 .5055 Mtetra
.53056 .5055 .53562 .51088 .54502 .50797 .53999 .50257 Mtetra
.53999 .50257 .54502 .50797 .55446 .50505 .54944 .49963 Mtetra
.54944 .49963 .55446 .50505 .56392 .50212 .55893 .49668 Mtetra
.55893 .49668 .56392 .50212 .57342 .49917 .56845 .49372 Mtetra
.56845 .49372 .57342 .49917 .58295 .49622 .578 .49075 Mtetra
.578 .49075 .58295 .49622 .59251 .49326 .58759 .48776 Mtetra
.58759 .48776 .59251 .49326 .60211 .49029 .59721 .48477 Mtetra
.59721 .48477 .60211 .49029 .61174 .4873 .60686 .48177 Mtetra
.60686 .48177 .61174 .4873 .62141 .48431 .61654 .47876 Mtetra
.61654 .47876 .62141 .48431 .6311 .48131 .62626 .47574 Mtetra
.62626 .47574 .6311 .48131 .64083 .47829 .63602 .4727 Mtetra
.63602 .4727 .64083 .47829 .6506 .47527 .64581 .46966 Mtetra
.64581 .46966 .6506 .47527 .66039 .47223 .65563 .4666 Mtetra
.65563 .4666 .66039 .47223 .67023 .46919 .66548 .46354 Mtetra
.66548 .46354 .67023 .46919 .68009 .46613 .67537 .46046 Mtetra
.67537 .46046 .68009 .46613 .69 .46307 .6853 .45738 Mtetra
.6853 .45738 .69 .46307 .69993 .45999 .69526 .45428 Mtetra
.69526 .45428 .69993 .45999 .7099 .4569 .70525 .45117 Mtetra
.70525 .45117 .7099 .4569 .71991 .4538 .71528 .44805 Mtetra
.71528 .44805 .71991 .4538 .72995 .45069 .72535 .44492 Mtetra
.72535 .44492 .72995 .45069 .74003 .44757 .73545 .44178 Mtetra
.73545 .44178 .74003 .44757 .75014 .44444 .74559 .43862 Mtetra
.74559 .43862 .75014 .44444 .76029 .44129 .75576 .43546 Mtetra
.75576 .43546 .76029 .44129 .77047 .43814 .76597 .43229 Mtetra
.76597 .43229 .77047 .43814 .78069 .43497 .77622 .4291 Mtetra
.77622 .4291 .78069 .43497 .79095 .4318 .7865 .4259 Mtetra
.7865 .4259 .79095 .4318 .80124 .42861 .79682 .42269 Mtetra
.79682 .42269 .80124 .42861 .81158 .42541 .80718 .41947 Mtetra
.80718 .41947 .81158 .42541 .82194 .4222 .81757 .41624 Mtetra
.81757 .41624 .82194 .4222 .83235 .41897 .82801 .41299 Mtetra
.82801 .41299 .83235 .41897 .84279 .41574 .83847 .40974 Mtetra
.83847 .40974 .84279 .41574 .85327 .41249 .84898 .40647 Mtetra
.84898 .40647 .85327 .41249 .86379 .40924 .85953 .40319 Mtetra
.85953 .40319 .86379 .40924 .87434 .40597 .87011 .3999 Mtetra
.87011 .3999 .87434 .40597 .88494 .40268 .88073 .3966 Mtetra
.88073 .3966 .88494 .40268 .89557 .39939 .89139 .39328 Mtetra
.89139 .39328 .89557 .39939 .90624 .39609 .90209 .38995 Mtetra
.90209 .38995 .90624 .39609 .91695 .39277 .91283 .38661 Mtetra
.91283 .38661 .91695 .39277 .9277 .38944 .92361 .38326 Mtetra
.92361 .38326 .9277 .38944 .93849 .3861 .93443 .3799 Mtetra
.352 .55425 .35746 .55933 .3663 .55659 .36086 .55149 Mtetra
.36086 .55149 .3663 .55659 .37517 .55383 .36975 .54871 Mtetra
.36975 .54871 .37517 .55383 .38406 .55106 .37866 .54593 Mtetra
.37866 .54593 .38406 .55106 .39299 .54828 .38761 .54313 Mtetra
.38761 .54313 .39299 .54828 .40195 .5455 .39658 .54033 Mtetra
.39658 .54033 .40195 .5455 .41094 .5427 .40559 .53752 Mtetra
.40559 .53752 .41094 .5427 .41995 .5399 .41463 .5347 Mtetra
.41463 .5347 .41995 .5399 .429 .53708 .42369 .53187 Mtetra
.42369 .53187 .429 .53708 .43808 .53426 .43279 .52902 Mtetra
.43279 .52902 .43808 .53426 .44719 .53143 .44192 .52617 Mtetra
.44192 .52617 .44719 .53143 .45633 .52859 .45108 .52331 Mtetra
.45108 .52331 .45633 .52859 .4655 .52573 .46027 .52044 Mtetra
.46027 .52044 .4655 .52573 .4747 .52287 .46949 .51756 Mtetra
.46949 .51756 .4747 .52287 .48393 .52 .47874 .51468 Mtetra
.47874 .51468 .48393 .52 .49319 .51712 .48802 .51178 Mtetra
.48802 .51178 .49319 .51712 .50249 .51423 .49734 .50887 Mtetra
.49734 .50887 .50249 .51423 .51182 .51133 .50669 .50595 Mtetra
.50669 .50595 .51182 .51133 .52117 .50842 .51606 .50302 Mtetra
.51606 .50302 .52117 .50842 .53056 .5055 .52548 .50008 Mtetra
.52548 .50008 .53056 .5055 .53999 .50257 .53492 .49713 Mtetra
.53492 .49713 .53999 .50257 .54944 .49963 .5444 .49417 Mtetra
.5444 .49417 .54944 .49963 .55893 .49668 .5539 .4912 Mtetra
.5539 .4912 .55893 .49668 .56845 .49372 .56345 .48822 Mtetra
.56345 .48822 .56845 .49372 .578 .49075 .57302 .48523 Mtetra
.57302 .48523 .578 .49075 .58759 .48776 .58263 .48223 Mtetra
.58263 .48223 .58759 .48776 .59721 .48477 .59227 .47922 Mtetra
.59227 .47922 .59721 .48477 .60686 .48177 .60195 .4762 Mtetra
.60195 .4762 .60686 .48177 .61654 .47876 .61165 .47317 Mtetra
.61165 .47317 .61654 .47876 .62626 .47574 .6214 .47013 Mtetra
.6214 .47013 .62626 .47574 .63602 .4727 .63117 .46707 Mtetra
.63117 .46707 .63602 .4727 .64581 .46966 .64098 .46401 Mtetra
.64098 .46401 .64581 .46966 .65563 .4666 .65083 .46094 Mtetra
.65083 .46094 .65563 .4666 .66548 .46354 .66071 .45785 Mtetra
.66071 .45785 .66548 .46354 .67537 .46046 .67062 .45476 Mtetra
.67062 .45476 .67537 .46046 .6853 .45738 .68057 .45165 Mtetra
.68057 .45165 .6853 .45738 .69526 .45428 .69055 .44853 Mtetra
.69055 .44853 .69526 .45428 .70525 .45117 .70057 .4454 Mtetra
.70057 .4454 .70525 .45117 .71528 .44805 .71063 .44226 Mtetra
.71063 .44226 .71528 .44805 .72535 .44492 .72072 .43911 Mtetra
.72072 .43911 .72535 .44492 .73545 .44178 .73085 .43595 Mtetra
.73085 .43595 .73545 .44178 .74559 .43862 .74101 .43277 Mtetra
.74101 .43277 .74559 .43862 .75576 .43546 .75121 .42959 Mtetra
.75121 .42959 .75576 .43546 .76597 .43229 .76144 .42639 Mtetra
.76144 .42639 .76597 .43229 .77622 .4291 .77172 .42319 Mtetra
.77172 .42319 .77622 .4291 .7865 .4259 .78203 .41997 Mtetra
.78203 .41997 .7865 .4259 .79682 .42269 .79237 .41674 Mtetra
.79237 .41674 .79682 .42269 .80718 .41947 .80275 .41349 Mtetra
.80275 .41349 .80718 .41947 .81757 .41624 .81318 .41024 Mtetra
.81318 .41024 .81757 .41624 .82801 .41299 .82363 .40697 Mtetra
.82363 .40697 .82801 .41299 .83847 .40974 .83413 .4037 Mtetra
.83413 .4037 .83847 .40974 .84898 .40647 .84466 .40041 Mtetra
.84466 .40041 .84898 .40647 .85953 .40319 .85524 .3971 Mtetra
.85524 .3971 .85953 .40319 .87011 .3999 .86585 .39379 Mtetra
.86585 .39379 .87011 .3999 .88073 .3966 .8765 .39047 Mtetra
.8765 .39047 .88073 .3966 .89139 .39328 .88719 .38713 Mtetra
.88719 .38713 .89139 .39328 .90209 .38995 .89791 .38378 Mtetra
.89791 .38378 .90209 .38995 .91283 .38661 .90868 .38041 Mtetra
.90868 .38041 .91283 .38661 .92361 .38326 .91949 .37704 Mtetra
.91949 .37704 .92361 .38326 .93443 .3799 .93033 .37365 Mtetra
.34651 .54914 .352 .55425 .36086 .55149 .35539 .54636 Mtetra
.35539 .54636 .36086 .55149 .36975 .54871 .36429 .54356 Mtetra
.36429 .54356 .36975 .54871 .37866 .54593 .37322 .54076 Mtetra
.37322 .54076 .37866 .54593 .38761 .54313 .38219 .53795 Mtetra
.38219 .53795 .38761 .54313 .39658 .54033 .39118 .53513 Mtetra
.39118 .53513 .39658 .54033 .40559 .53752 .40021 .5323 Mtetra
.40021 .5323 .40559 .53752 .41463 .5347 .40926 .52946 Mtetra
.40926 .52946 .41463 .5347 .42369 .53187 .41835 .52661 Mtetra
.41835 .52661 .42369 .53187 .43279 .52902 .42747 .52375 Mtetra
.42747 .52375 .43279 .52902 .44192 .52617 .43661 .52089 Mtetra
.43661 .52089 .44192 .52617 .45108 .52331 .44579 .51801 Mtetra
.44579 .51801 .45108 .52331 .46027 .52044 .455 .51512 Mtetra
.455 .51512 .46027 .52044 .46949 .51756 .46424 .51222 Mtetra
.46424 .51222 .46949 .51756 .47874 .51468 .47351 .50932 Mtetra
.47351 .50932 .47874 .51468 .48802 .51178 .48282 .5064 Mtetra
.48282 .5064 .48802 .51178 .49734 .50887 .49216 .50347 Mtetra
.49216 .50347 .49734 .50887 .50669 .50595 .50152 .50053 Mtetra
.50152 .50053 .50669 .50595 .51606 .50302 .51092 .49759 Mtetra
.51092 .49759 .51606 .50302 .52548 .50008 .52036 .49463 Mtetra
.52036 .49463 .52548 .50008 .53492 .49713 .52982 .49166 Mtetra
.52982 .49166 .53492 .49713 .5444 .49417 .53932 .48868 Mtetra
.53932 .48868 .5444 .49417 .5539 .4912 .54885 .48569 Mtetra
.54885 .48569 .5539 .4912 .56345 .48822 .55841 .4827 Mtetra
.55841 .4827 .56345 .48822 .57302 .48523 .56801 .47969 Mtetra
.56801 .47969 .57302 .48523 .58263 .48223 .57764 .47667 Mtetra
.57764 .47667 .58263 .48223 .59227 .47922 .5873 .47364 Mtetra
.5873 .47364 .59227 .47922 .60195 .4762 .597 .4706 Mtetra
.597 .4706 .60195 .4762 .61165 .47317 .60673 .46754 Mtetra
.60673 .46754 .61165 .47317 .6214 .47013 .6165 .46448 Mtetra
.6165 .46448 .6214 .47013 .63117 .46707 .62629 .46141 Mtetra
.62629 .46141 .63117 .46707 .64098 .46401 .63613 .45833 Mtetra
.63613 .45833 .64098 .46401 .65083 .46094 .646 .45523 Mtetra
.646 .45523 .65083 .46094 .66071 .45785 .6559 .45213 Mtetra
.6559 .45213 .66071 .45785 .67062 .45476 .66584 .44901 Mtetra
.66584 .44901 .67062 .45476 .68057 .45165 .67581 .44588 Mtetra
.67581 .44588 .68057 .45165 .69055 .44853 .68582 .44275 Mtetra
.68582 .44275 .69055 .44853 .70057 .4454 .69586 .4396 Mtetra
.69586 .4396 .70057 .4454 .71063 .44226 .70594 .43644 Mtetra
.70594 .43644 .71063 .44226 .72072 .43911 .71606 .43326 Mtetra
.71606 .43326 .72072 .43911 .73085 .43595 .72621 .43008 Mtetra
.72621 .43008 .73085 .43595 .74101 .43277 .7364 .42689 Mtetra
.7364 .42689 .74101 .43277 .75121 .42959 .74662 .42368 Mtetra
.74662 .42368 .75121 .42959 .76144 .42639 .75688 .42046 Mtetra
.75688 .42046 .76144 .42639 .77172 .42319 .76718 .41723 Mtetra
.76718 .41723 .77172 .42319 .78203 .41997 .77752 .41399 Mtetra
.77752 .41399 .78203 .41997 .79237 .41674 .78789 .41074 Mtetra
.78789 .41074 .79237 .41674 .80275 .41349 .7983 .40748 Mtetra
.7983 .40748 .80275 .41349 .81318 .41024 .80875 .4042 Mtetra
.80875 .4042 .81318 .41024 .82363 .40697 .81923 .40091 Mtetra
.81923 .40091 .82363 .40697 .83413 .4037 .82976 .39761 Mtetra
.82976 .39761 .83413 .4037 .84466 .40041 .84032 .3943 Mtetra
.84032 .3943 .84466 .40041 .85524 .3971 .85092 .39098 Mtetra
.85092 .39098 .85524 .3971 .86585 .39379 .86156 .38764 Mtetra
.86156 .38764 .86585 .39379 .8765 .39047 .87224 .38429 Mtetra
.87224 .38429 .8765 .39047 .88719 .38713 .88295 .38093 Mtetra
.88295 .38093 .88719 .38713 .89791 .38378 .89371 .37756 Mtetra
.89371 .37756 .89791 .38378 .90868 .38041 .9045 .37418 Mtetra
.9045 .37418 .90868 .38041 .91949 .37704 .91534 .37078 Mtetra
.91534 .37078 .91949 .37704 .93033 .37365 .92622 .36737 Mtetra
.34098 .54399 .34651 .54914 .35539 .54636 .34988 .54119 Mtetra
.34988 .54119 .35539 .54636 .36429 .54356 .3588 .53838 Mtetra
.3588 .53838 .36429 .54356 .37322 .54076 .36775 .53557 Mtetra
.36775 .53557 .37322 .54076 .38219 .53795 .37674 .53274 Mtetra
.37674 .53274 .38219 .53795 .39118 .53513 .38575 .5299 Mtetra
.38575 .5299 .39118 .53513 .40021 .5323 .39479 .52705 Mtetra
.39479 .52705 .40021 .5323 .40926 .52946 .40387 .52419 Mtetra
.40387 .52419 .40926 .52946 .41835 .52661 .41297 .52133 Mtetra
.41297 .52133 .41835 .52661 .42747 .52375 .42211 .51845 Mtetra
.42211 .51845 .42747 .52375 .43661 .52089 .43128 .51557 Mtetra
.43128 .51557 .43661 .52089 .44579 .51801 .44047 .51267 Mtetra
.44047 .51267 .44579 .51801 .455 .51512 .4497 .50976 Mtetra
.4497 .50976 .455 .51512 .46424 .51222 .45897 .50685 Mtetra
.45897 .50685 .46424 .51222 .47351 .50932 .46826 .50392 Mtetra
.46826 .50392 .47351 .50932 .48282 .5064 .47758 .50099 Mtetra
.47758 .50099 .48282 .5064 .49216 .50347 .48694 .49804 Mtetra
.48694 .49804 .49216 .50347 .50152 .50053 .49633 .49508 Mtetra
.49633 .49508 .50152 .50053 .51092 .49759 .50575 .49212 Mtetra
.50575 .49212 .51092 .49759 .52036 .49463 .5152 .48914 Mtetra
.5152 .48914 .52036 .49463 .52982 .49166 .52469 .48615 Mtetra
.52469 .48615 .52982 .49166 .53932 .48868 .53421 .48316 Mtetra
.53421 .48316 .53932 .48868 .54885 .48569 .54376 .48015 Mtetra
.54376 .48015 .54885 .48569 .55841 .4827 .55335 .47713 Mtetra
.55335 .47713 .55841 .4827 .56801 .47969 .56296 .4741 Mtetra
.56296 .4741 .56801 .47969 .57764 .47667 .57262 .47106 Mtetra
.57262 .47106 .57764 .47667 .5873 .47364 .5823 .46801 Mtetra
.5823 .46801 .5873 .47364 .597 .4706 .59202 .46495 Mtetra
.59202 .46495 .597 .4706 .60673 .46754 .60178 .46188 Mtetra
.60178 .46188 .60673 .46754 .6165 .46448 .61156 .4588 Mtetra
.61156 .4588 .6165 .46448 .62629 .46141 .62139 .45571 Mtetra
.62139 .45571 .62629 .46141 .63613 .45833 .63124 .45261 Mtetra
.63124 .45261 .63613 .45833 .646 .45523 .64113 .44949 Mtetra
.64113 .44949 .646 .45523 .6559 .45213 .65106 .44637 Mtetra
.65106 .44637 .6559 .45213 .66584 .44901 .66102 .44323 Mtetra
.66102 .44323 .66584 .44901 .67581 .44588 .67102 .44008 Mtetra
.67102 .44008 .67581 .44588 .68582 .44275 .68105 .43692 Mtetra
.68105 .43692 .68582 .44275 .69586 .4396 .69112 .43375 Mtetra
.69112 .43375 .69586 .4396 .70594 .43644 .70123 .43057 Mtetra
.70123 .43057 .70594 .43644 .71606 .43326 .71137 .42738 Mtetra
.71137 .42738 .71606 .43326 .72621 .43008 .72154 .42417 Mtetra
.72154 .42417 .72621 .43008 .7364 .42689 .73176 .42096 Mtetra
.73176 .42096 .7364 .42689 .74662 .42368 .74201 .41773 Mtetra
.74201 .41773 .74662 .42368 .75688 .42046 .75229 .41449 Mtetra
.75229 .41449 .75688 .42046 .76718 .41723 .76262 .41124 Mtetra
.76262 .41124 .76718 .41723 .77752 .41399 .77298 .40798 Mtetra
.77298 .40798 .77752 .41399 .78789 .41074 .78338 .40471 Mtetra
.78338 .40471 .78789 .41074 .7983 .40748 .79382 .40142 Mtetra
.79382 .40142 .7983 .40748 .80875 .4042 .80429 .39812 Mtetra
.80429 .39812 .80875 .4042 .81923 .40091 .8148 .39481 Mtetra
.8148 .39481 .81923 .40091 .82976 .39761 .82535 .39149 Mtetra
.82535 .39149 .82976 .39761 .84032 .3943 .83594 .38816 Mtetra
.83594 .38816 .84032 .3943 .85092 .39098 .84657 .38481 Mtetra
.84657 .38481 .85092 .39098 .86156 .38764 .85724 .38145 Mtetra
.85724 .38145 .86156 .38764 .87224 .38429 .86794 .37808 Mtetra
.86794 .37808 .87224 .38429 .88295 .38093 .87869 .3747 Mtetra
.87869 .3747 .88295 .38093 .89371 .37756 .88947 .3713 Mtetra
.88947 .3713 .89371 .37756 .9045 .37418 .9003 .36789 Mtetra
.9003 .36789 .9045 .37418 .91534 .37078 .91116 .36447 Mtetra
.91116 .36447 .91534 .37078 .92622 .36737 .92207 .36104 Mtetra
.33542 .53882 .34098 .54399 .34988 .54119 .34434 .536 Mtetra
.34434 .536 .34988 .54119 .3588 .53838 .35328 .53317 Mtetra
.35328 .53317 .3588 .53838 .36775 .53557 .36225 .53034 Mtetra
.36225 .53034 .36775 .53557 .37674 .53274 .37125 .52749 Mtetra
.37125 .52749 .37674 .53274 .38575 .5299 .38028 .52463 Mtetra
.38028 .52463 .38575 .5299 .39479 .52705 .38935 .52177 Mtetra
.38935 .52177 .39479 .52705 .40387 .52419 .39844 .51889 Mtetra
.39844 .51889 .40387 .52419 .41297 .52133 .40756 .51601 Mtetra
.40756 .51601 .41297 .52133 .42211 .51845 .41672 .51312 Mtetra
.41672 .51312 .42211 .51845 .43128 .51557 .42591 .51021 Mtetra
.42591 .51021 .43128 .51557 .44047 .51267 .43512 .5073 Mtetra
.43512 .5073 .44047 .51267 .4497 .50976 .44437 .50437 Mtetra
.44437 .50437 .4497 .50976 .45897 .50685 .45365 .50144 Mtetra
.45365 .50144 .45897 .50685 .46826 .50392 .46297 .49849 Mtetra
.46297 .49849 .46826 .50392 .47758 .50099 .47231 .49554 Mtetra
.47231 .49554 .47758 .50099 .48694 .49804 .48169 .49257 Mtetra
.48169 .49257 .48694 .49804 .49633 .49508 .4911 .4896 Mtetra
.4911 .4896 .49633 .49508 .50575 .49212 .50054 .48661 Mtetra
.50054 .48661 .50575 .49212 .5152 .48914 .51002 .48362 Mtetra
.51002 .48362 .5152 .48914 .52469 .48615 .51952 .48061 Mtetra
.51952 .48061 .52469 .48615 .53421 .48316 .52906 .4776 Mtetra
.52906 .4776 .53421 .48316 .54376 .48015 .53864 .47457 Mtetra
.53864 .47457 .54376 .48015 .55335 .47713 .54825 .47153 Mtetra
.54825 .47153 .55335 .47713 .56296 .4741 .55789 .46848 Mtetra
.55789 .46848 .56296 .4741 .57262 .47106 .56756 .46543 Mtetra
.56756 .46543 .57262 .47106 .5823 .46801 .57727 .46236 Mtetra
.57727 .46236 .5823 .46801 .59202 .46495 .58701 .45928 Mtetra
.58701 .45928 .59202 .46495 .60178 .46188 .59679 .45619 Mtetra
.59679 .45619 .60178 .46188 .61156 .4588 .6066 .45308 Mtetra
.6066 .45308 .61156 .4588 .62139 .45571 .61645 .44997 Mtetra
.61645 .44997 .62139 .45571 .63124 .45261 .62633 .44685 Mtetra
.62633 .44685 .63124 .45261 .64113 .44949 .63624 .44371 Mtetra
.63624 .44371 .64113 .44949 .65106 .44637 .64619 .44057 Mtetra
.64619 .44057 .65106 .44637 .66102 .44323 .65618 .43741 Mtetra
.65618 .43741 .66102 .44323 .67102 .44008 .6662 .43424 Mtetra
.6662 .43424 .67102 .44008 .68105 .43692 .67626 .43106 Mtetra
.67626 .43106 .68105 .43692 .69112 .43375 .68635 .42787 Mtetra
.68635 .42787 .69112 .43375 .70123 .43057 .69648 .42467 Mtetra
.69648 .42467 .70123 .43057 .71137 .42738 .70664 .42145 Mtetra
.70664 .42145 .71137 .42738 .72154 .42417 .71685 .41823 Mtetra
.71685 .41823 .72154 .42417 .73176 .42096 .72709 .41499 Mtetra
.72709 .41499 .73176 .42096 .74201 .41773 .73736 .41174 Mtetra
.73736 .41174 .74201 .41773 .75229 .41449 .74767 .40848 Mtetra
.74767 .40848 .75229 .41449 .76262 .41124 .75802 .40521 Mtetra
.75802 .40521 .76262 .41124 .77298 .40798 .76841 .40193 Mtetra
.76841 .40193 .77298 .40798 .78338 .40471 .77884 .39863 Mtetra
.77884 .39863 .78338 .40471 .79382 .40142 .7893 .39532 Mtetra
.7893 .39532 .79382 .40142 .80429 .39812 .7998 .392 Mtetra
.7998 .392 .80429 .39812 .8148 .39481 .81034 .38867 Mtetra
.81034 .38867 .8148 .39481 .82535 .39149 .82092 .38532 Mtetra
.82092 .38532 .82535 .39149 .83594 .38816 .83154 .38197 Mtetra
.83154 .38197 .83594 .38816 .84657 .38481 .84219 .3786 Mtetra
.84219 .3786 .84657 .38481 .85724 .38145 .85289 .37522 Mtetra
.85289 .37522 .85724 .38145 .86794 .37808 .86362 .37182 Mtetra
.86362 .37182 .86794 .37808 .87869 .3747 .8744 .36842 Mtetra
.8744 .36842 .87869 .3747 .88947 .3713 .88521 .365 Mtetra
.88521 .365 .88947 .3713 .9003 .36789 .89607 .36157 Mtetra
.89607 .36157 .9003 .36789 .91116 .36447 .90696 .35812 Mtetra
.90696 .35812 .91116 .36447 .92207 .36104 .91789 .35467 Mtetra
.32983 .53361 .33542 .53882 .34434 .536 .33876 .53077 Mtetra
.33876 .53077 .34434 .536 .35328 .53317 .34772 .52793 Mtetra
.34772 .52793 .35328 .53317 .36225 .53034 .35671 .52507 Mtetra
.35671 .52507 .36225 .53034 .37125 .52749 .36573 .52221 Mtetra
.36573 .52221 .37125 .52749 .38028 .52463 .37478 .51934 Mtetra
.37478 .51934 .38028 .52463 .38935 .52177 .38386 .51645 Mtetra
.38386 .51645 .38935 .52177 .39844 .51889 .39298 .51356 Mtetra
.39298 .51356 .39844 .51889 .40756 .51601 .40212 .51066 Mtetra
.40212 .51066 .40756 .51601 .41672 .51312 .4113 .50775 Mtetra
.4113 .50775 .41672 .51312 .42591 .51021 .4205 .50482 Mtetra
.4205 .50482 .42591 .51021 .43512 .5073 .42974 .50189 Mtetra
.42974 .50189 .43512 .5073 .44437 .50437 .43901 .49895 Mtetra
.626 .73 .922 r
.43901 .49895 .44437 .50437 .45365 .50144 .44829 .49686 Mtetra
.599 .076 0 r
.44829 .49686 .45365 .50144 .46297 .49849 .45738 .50629 Mtetra
.75 .892 .493 r
.45738 .50629 .46297 .49849 .47231 .49554 .46701 .49006 Mtetra
.664 .741 .908 r
.46701 .49006 .47231 .49554 .48169 .49257 .47641 .48707 Mtetra
.47641 .48707 .48169 .49257 .4911 .4896 .48584 .48408 Mtetra
.48584 .48408 .4911 .4896 .50054 .48661 .4953 .48108 Mtetra
.4953 .48108 .50054 .48661 .51002 .48362 .5048 .47806 Mtetra
.5048 .47806 .51002 .48362 .51952 .48061 .51433 .47504 Mtetra
.51433 .47504 .51952 .48061 .52906 .4776 .52389 .472 Mtetra
.52389 .472 .52906 .4776 .53864 .47457 .53348 .46895 Mtetra
.53348 .46895 .53864 .47457 .54825 .47153 .54311 .4659 Mtetra
.54311 .4659 .54825 .47153 .55789 .46848 .55278 .46283 Mtetra
.55278 .46283 .55789 .46848 .56756 .46543 .56247 .45975 Mtetra
.56247 .45975 .56756 .46543 .57727 .46236 .5722 .45666 Mtetra
.5722 .45666 .57727 .46236 .58701 .45928 .58197 .45356 Mtetra
.58197 .45356 .58701 .45928 .59679 .45619 .59177 .45045 Mtetra
.59177 .45045 .59679 .45619 .6066 .45308 .6016 .44733 Mtetra
.6016 .44733 .6066 .45308 .61645 .44997 .61147 .4442 Mtetra
.61147 .4442 .61645 .44997 .62633 .44685 .62138 .44105 Mtetra
.62138 .44105 .62633 .44685 .63624 .44371 .63132 .4379 Mtetra
.63132 .4379 .63624 .44371 .64619 .44057 .64129 .43473 Mtetra
.64129 .43473 .64619 .44057 .65618 .43741 .6513 .43155 Mtetra
.6513 .43155 .65618 .43741 .6662 .43424 .66135 .42836 Mtetra
.66135 .42836 .6662 .43424 .67626 .43106 .67143 .42516 Mtetra
.67143 .42516 .67626 .43106 .68635 .42787 .68155 .42195 Mtetra
.68155 .42195 .68635 .42787 .69648 .42467 .6917 .41873 Mtetra
.6917 .41873 .69648 .42467 .70664 .42145 .70189 .41549 Mtetra
.70189 .41549 .70664 .42145 .71685 .41823 .71212 .41224 Mtetra
.71212 .41224 .71685 .41823 .72709 .41499 .72238 .40898 Mtetra
.72238 .40898 .72709 .41499 .73736 .41174 .73268 .40571 Mtetra
.73268 .40571 .73736 .41174 .74767 .40848 .74302 .40243 Mtetra
.74302 .40243 .74767 .40848 .75802 .40521 .7534 .39914 Mtetra
0 .155 .681 r
.7534 .39914 .75802 .40521 .76841 .40193 .76482 .40943 Mtetra
0 0 0 r
.76482 .40943 .76841 .40193 .77884 .39863 .77433 .3934 Mtetra
.696 .787 .921 r
.77433 .3934 .77884 .39863 .7893 .39532 .78476 .38918 Mtetra
.664 .741 .908 r
.78476 .38918 .7893 .39532 .7998 .392 .79528 .38584 Mtetra
.79528 .38584 .7998 .392 .81034 .38867 .80585 .38249 Mtetra
.80585 .38249 .81034 .38867 .82092 .38532 .81646 .37912 Mtetra
.81646 .37912 .82092 .38532 .83154 .38197 .8271 .37574 Mtetra
.8271 .37574 .83154 .38197 .84219 .3786 .83779 .37235 Mtetra
.83779 .37235 .84219 .3786 .85289 .37522 .84851 .36894 Mtetra
.84851 .36894 .85289 .37522 .86362 .37182 .85927 .36553 Mtetra
.85927 .36553 .86362 .37182 .8744 .36842 .87008 .3621 Mtetra
.87008 .3621 .8744 .36842 .88521 .365 .88092 .35865 Mtetra
.88092 .35865 .88521 .365 .89607 .36157 .8918 .3552 Mtetra
.8918 .3552 .89607 .36157 .90696 .35812 .90273 .35173 Mtetra
.90273 .35173 .90696 .35812 .91789 .35467 .91369 .34825 Mtetra
.3242 .52837 .32983 .53361 .33876 .53077 .33315 .52551 Mtetra
.33315 .52551 .33876 .53077 .34772 .52793 .34213 .52265 Mtetra
.34213 .52265 .34772 .52793 .35671 .52507 .35114 .51978 Mtetra
.35114 .51978 .35671 .52507 .36573 .52221 .36018 .5169 Mtetra
.36018 .5169 .36573 .52221 .37478 .51934 .36925 .51401 Mtetra
.36925 .51401 .37478 .51934 .38386 .51645 .37835 .51111 Mtetra
.37835 .51111 .38386 .51645 .39298 .51356 .38748 .50819 Mtetra
.38748 .50819 .39298 .51356 .40212 .51066 .39664 .50527 Mtetra
.39664 .50527 .40212 .51066 .4113 .50775 .40584 .50234 Mtetra
.40584 .50234 .4113 .50775 .4205 .50482 .41506 .4994 Mtetra
.41506 .4994 .4205 .50482 .42974 .50189 .42432 .49645 Mtetra
.42432 .49645 .42974 .50189 .43901 .49895 .43361 .49349 Mtetra
0 .114 .617 r
.43361 .49349 .43901 .49895 .44829 .49686 .44267 .50129 Mtetra
.734 .31 .243 r
.44267 .50129 .44829 .49686 .45738 .50629 .45178 .5107 Mtetra
.751 .332 .255 r
.45178 .5107 .45738 .50629 .46701 .49006 .46097 .52125 Mtetra
0 0 .07 r
.46097 .52125 .46701 .49006 .47641 .48707 .47109 .48154 Mtetra
.664 .741 .908 r
.47109 .48154 .47641 .48707 .48584 .48408 .48054 .47853 Mtetra
.48054 .47853 .48584 .48408 .4953 .48108 .49003 .4755 Mtetra
.49003 .4755 .4953 .48108 .5048 .47806 .49954 .47247 Mtetra
.49954 .47247 .5048 .47806 .51433 .47504 .5091 .46942 Mtetra
.5091 .46942 .51433 .47504 .52389 .472 .51868 .46637 Mtetra
.51868 .46637 .52389 .472 .53348 .46895 .5283 .4633 Mtetra
.5283 .4633 .53348 .46895 .54311 .4659 .53795 .46023 Mtetra
.53795 .46023 .54311 .4659 .55278 .46283 .54763 .45714 Mtetra
.54763 .45714 .55278 .46283 .56247 .45975 .55735 .45404 Mtetra
.55735 .45404 .56247 .45975 .5722 .45666 .56711 .45093 Mtetra
.56711 .45093 .5722 .45666 .58197 .45356 .57689 .44781 Mtetra
.57689 .44781 .58197 .45356 .59177 .45045 .58672 .44468 Mtetra
.58672 .44468 .59177 .45045 .6016 .44733 .59657 .44154 Mtetra
.59657 .44154 .6016 .44733 .61147 .4442 .60647 .43838 Mtetra
.60647 .43838 .61147 .4442 .62138 .44105 .61639 .43522 Mtetra
.61639 .43522 .62138 .44105 .63132 .4379 .62636 .43204 Mtetra
.62636 .43204 .63132 .4379 .64129 .43473 .63636 .42885 Mtetra
.63636 .42885 .64129 .43473 .6513 .43155 .64639 .42565 Mtetra
.64639 .42565 .6513 .43155 .66135 .42836 .65646 .42244 Mtetra
.65646 .42244 .66135 .42836 .67143 .42516 .66657 .41922 Mtetra
.66657 .41922 .67143 .42516 .68155 .42195 .67671 .41599 Mtetra
.67671 .41599 .68155 .42195 .6917 .41873 .68689 .41274 Mtetra
.68689 .41274 .6917 .41873 .70189 .41549 .6971 .40949 Mtetra
.6971 .40949 .70189 .41549 .71212 .41224 .70736 .40622 Mtetra
.70736 .40622 .71212 .41224 .72238 .40898 .71765 .40294 Mtetra
.71765 .40294 .72238 .40898 .73268 .40571 .72798 .39965 Mtetra
.72798 .39965 .73268 .40571 .74302 .40243 .73834 .39634 Mtetra
.883 .479 .039 r
.73834 .39634 .74302 .40243 .7534 .39914 .75136 .43063 Mtetra
.333 .096 .398 r
.75136 .43063 .7534 .39914 .76482 .40943 .76092 .41346 Mtetra
.803 .926 .548 r
.76092 .41346 .76482 .40943 .77433 .3934 .77051 .39742 Mtetra
.737 .909 .535 r
.77051 .39742 .77433 .3934 .78476 .38918 .78018 .383 Mtetra
.664 .741 .908 r
.78018 .383 .78476 .38918 .79528 .38584 .79074 .37964 Mtetra
.79074 .37964 .79528 .38584 .80585 .38249 .80133 .37626 Mtetra
.80133 .37626 .80585 .38249 .81646 .37912 .81196 .37287 Mtetra
.81196 .37287 .81646 .37912 .8271 .37574 .82264 .36947 Mtetra
.82264 .36947 .8271 .37574 .83779 .37235 .83335 .36605 Mtetra
.83335 .36605 .83779 .37235 .84851 .36894 .8441 .36262 Mtetra
.8441 .36262 .84851 .36894 .85927 .36553 .85489 .35918 Mtetra
.85489 .35918 .85927 .36553 .87008 .3621 .86572 .35573 Mtetra
.86572 .35573 .87008 .3621 .88092 .35865 .8766 .35226 Mtetra
.8766 .35226 .88092 .35865 .8918 .3552 .88751 .34879 Mtetra
.88751 .34879 .8918 .3552 .90273 .35173 .89846 .34529 Mtetra
.89846 .34529 .90273 .35173 .91369 .34825 .90946 .34179 Mtetra
.31854 .52309 .3242 .52837 .33315 .52551 .3275 .52022 Mtetra
.3275 .52022 .33315 .52551 .34213 .52265 .3365 .51734 Mtetra
.3365 .51734 .34213 .52265 .35114 .51978 .34553 .51445 Mtetra
.34553 .51445 .35114 .51978 .36018 .5169 .35459 .51155 Mtetra
.35459 .51155 .36018 .5169 .36925 .51401 .36368 .50864 Mtetra
.36368 .50864 .36925 .51401 .37835 .51111 .3728 .50572 Mtetra
.3728 .50572 .37835 .51111 .38748 .50819 .38195 .50279 Mtetra
.38195 .50279 .38748 .50819 .39664 .50527 .39113 .49985 Mtetra
.39113 .49985 .39664 .50527 .40584 .50234 .40034 .4969 Mtetra
.40034 .4969 .40584 .50234 .41506 .4994 .40959 .49394 Mtetra
.40959 .49394 .41506 .4994 .42432 .49645 .41887 .49097 Mtetra
.019 .414 .859 r
.41887 .49097 .42432 .49645 .43361 .49349 .42796 .49559 Mtetra
.723 .252 .128 r
.42796 .49559 .43361 .49349 .44267 .50129 .43702 .5038 Mtetra
.743 .289 .171 r
.43702 .5038 .44267 .50129 .45178 .5107 .44616 .5131 Mtetra
.762 .314 .186 r
.44616 .5131 .45178 .5107 .46097 .52125 .45538 .5235 Mtetra
.779 .335 .196 r
.45538 .5235 .46097 .52125 .47109 .48154 .46468 .53498 Mtetra
0 0 .186 r
.46468 .53498 .47109 .48154 .48054 .47853 .47521 .47294 Mtetra
.664 .741 .908 r
.47521 .47294 .48054 .47853 .49003 .4755 .48472 .46989 Mtetra
.48472 .46989 .49003 .4755 .49954 .47247 .49426 .46684 Mtetra
.49426 .46684 .49954 .47247 .5091 .46942 .50383 .46377 Mtetra
.50383 .46377 .5091 .46942 .51868 .46637 .51344 .4607 Mtetra
.51344 .4607 .51868 .46637 .5283 .4633 .52308 .45761 Mtetra
.52308 .45761 .5283 .4633 .53795 .46023 .53275 .45452 Mtetra
.53275 .45452 .53795 .46023 .54763 .45714 .54246 .45141 Mtetra
.54246 .45141 .54763 .45714 .55735 .45404 .5522 .44829 Mtetra
.5522 .44829 .55735 .45404 .56711 .45093 .56197 .44516 Mtetra
.56197 .44516 .56711 .45093 .57689 .44781 .57179 .44202 Mtetra
.57179 .44202 .57689 .44781 .58672 .44468 .58163 .43887 Mtetra
.58163 .43887 .58672 .44468 .59657 .44154 .59151 .4357 Mtetra
.59151 .4357 .59657 .44154 .60647 .43838 .60143 .43253 Mtetra
.60143 .43253 .60647 .43838 .61639 .43522 .61138 .42934 Mtetra
.61138 .42934 .61639 .43522 .62636 .43204 .62137 .42615 Mtetra
.62137 .42615 .62636 .43204 .63636 .42885 .63139 .42294 Mtetra
.63139 .42294 .63636 .42885 .64639 .42565 .64145 .41972 Mtetra
.64145 .41972 .64639 .42565 .65646 .42244 .65154 .41649 Mtetra
.65154 .41649 .65646 .42244 .66657 .41922 .66167 .41324 Mtetra
.66167 .41324 .66657 .41922 .67671 .41599 .67184 .40999 Mtetra
.67184 .40999 .67671 .41599 .68689 .41274 .68205 .40672 Mtetra
.68205 .40672 .68689 .41274 .6971 .40949 .69229 .40344 Mtetra
.69229 .40344 .6971 .40949 .70736 .40622 .70257 .40015 Mtetra
.70257 .40015 .70736 .40622 .71765 .40294 .71288 .39685 Mtetra
.71288 .39685 .71765 .40294 .72798 .39965 .72324 .39354 Mtetra
.941 .579 .202 r
.72324 .39354 .72798 .39965 .73834 .39634 .73755 .45057 Mtetra
.431 .204 .467 r
.73755 .45057 .73834 .39634 .75136 .43063 .74717 .43247 Mtetra
.932 .964 .67 r
.74717 .43247 .75136 .43063 .76092 .41346 .75681 .41542 Mtetra
.91 .971 .672 r
.75681 .41542 .76092 .41346 .77051 .39742 .76648 .39947 Mtetra
.883 .976 .674 r
.76648 .39947 .77051 .39742 .78018 .383 .77619 .3846 Mtetra
.795 .987 .73 r
.77619 .3846 .78018 .383 .79074 .37964 .78616 .37339 Mtetra
.664 .741 .908 r
.78616 .37339 .79074 .37964 .80133 .37626 .79678 .36999 Mtetra
.79678 .36999 .80133 .37626 .81196 .37287 .80744 .36658 Mtetra
.80744 .36658 .81196 .37287 .82264 .36947 .81814 .36315 Mtetra
.81814 .36315 .82264 .36947 .83335 .36605 .82888 .35971 Mtetra
.82888 .35971 .83335 .36605 .8441 .36262 .83966 .35626 Mtetra
.83966 .35626 .8441 .36262 .85489 .35918 .85048 .3528 Mtetra
.85048 .3528 .85489 .35918 .86572 .35573 .86134 .34932 Mtetra
.86134 .34932 .86572 .35573 .8766 .35226 .87224 .34583 Mtetra
.87224 .34583 .8766 .35226 .88751 .34879 .88319 .34233 Mtetra
.88319 .34233 .88751 .34879 .89846 .34529 .89417 .33881 Mtetra
.89417 .33881 .89846 .34529 .90946 .34179 .9052 .33528 Mtetra
.31284 .51779 .31854 .52309 .3275 .52022 .32182 .5149 Mtetra
.32182 .5149 .3275 .52022 .3365 .51734 .33084 .512 Mtetra
.33084 .512 .3365 .51734 .34553 .51445 .33988 .50909 Mtetra
.33988 .50909 .34553 .51445 .35459 .51155 .34896 .50617 Mtetra
.34896 .50617 .35459 .51155 .36368 .50864 .35807 .50324 Mtetra
.35807 .50324 .36368 .50864 .3728 .50572 .36721 .50031 Mtetra
.36721 .50031 .3728 .50572 .38195 .50279 .37638 .49736 Mtetra
.37638 .49736 .38195 .50279 .39113 .49985 .38558 .4944 Mtetra
.38558 .4944 .39113 .49985 .40034 .4969 .39482 .49143 Mtetra
.39482 .49143 .40034 .4969 .40959 .49394 .40408 .48845 Mtetra
.409 .642 .952 r
.40408 .48845 .40959 .49394 .41887 .49097 .41324 .48959 Mtetra
.648 .09 0 r
.41324 .48959 .41887 .49097 .42796 .49559 .42227 .49665 Mtetra
.72 .225 .062 r
.42227 .49665 .42796 .49559 .43702 .5038 .43136 .50473 Mtetra
.744 .258 .085 r
.43136 .50473 .43702 .5038 .44616 .5131 .44052 .51385 Mtetra
.765 .286 .102 r
.44052 .51385 .44616 .5131 .45538 .5235 .44976 .52401 Mtetra
.783 .31 .114 r
.44976 .52401 .45538 .5235 .46468 .53498 .45909 .5352 Mtetra
.798 .33 .12 r
.45909 .5352 .46468 .53498 .47521 .47294 .46851 .5474 Mtetra
0 0 .232 r
.46851 .5474 .47521 .47294 .48472 .46989 .47938 .46425 Mtetra
.664 .741 .908 r
.47938 .46425 .48472 .46989 .49426 .46684 .48894 .46117 Mtetra
.48894 .46117 .49426 .46684 .50383 .46377 .49853 .45809 Mtetra
.49853 .45809 .50383 .46377 .51344 .4607 .50816 .45499 Mtetra
.50816 .45499 .51344 .4607 .52308 .45761 .51782 .45189 Mtetra
.51782 .45189 .52308 .45761 .53275 .45452 .52752 .44877 Mtetra
.52752 .44877 .53275 .45452 .54246 .45141 .53725 .44564 Mtetra
.53725 .44564 .54246 .45141 .5522 .44829 .54701 .4425 Mtetra
.54701 .4425 .5522 .44829 .56197 .44516 .55681 .43935 Mtetra
.55681 .43935 .56197 .44516 .57179 .44202 .56664 .43619 Mtetra
.56664 .43619 .57179 .44202 .58163 .43887 .57651 .43302 Mtetra
.57651 .43302 .58163 .43887 .59151 .4357 .58642 .42984 Mtetra
.58642 .42984 .59151 .4357 .60143 .43253 .59636 .42664 Mtetra
.59636 .42664 .60143 .43253 .61138 .42934 .60633 .42343 Mtetra
.60633 .42343 .61138 .42934 .62137 .42615 .61634 .42021 Mtetra
.61634 .42021 .62137 .42615 .63139 .42294 .62639 .41698 Mtetra
.62639 .41698 .63139 .42294 .64145 .41972 .63647 .41374 Mtetra
.63647 .41374 .64145 .41972 .65154 .41649 .64659 .41049 Mtetra
.64659 .41049 .65154 .41649 .66167 .41324 .65675 .40722 Mtetra
.65675 .40722 .66167 .41324 .67184 .40999 .66694 .40395 Mtetra
.66694 .40395 .67184 .40999 .68205 .40672 .67717 .40066 Mtetra
.67717 .40066 .68205 .40672 .69229 .40344 .68744 .39736 Mtetra
.68744 .39736 .69229 .40344 .70257 .40015 .69774 .39405 Mtetra
.69774 .39405 .70257 .40015 .71288 .39685 .70808 .39072 Mtetra
.957 .614 .267 r
.70808 .39072 .71288 .39685 .72324 .39354 .7234 .46919 Mtetra
.465 .242 .49 r
.7234 .46919 .72324 .39354 .73755 .45057 .7331 .45036 Mtetra
.961 .93 .714 r
.7331 .45036 .73755 .45057 .74717 .43247 .74281 .43251 Mtetra
.954 .945 .722 r
.74281 .43251 .74717 .43247 .75681 .41542 .75253 .41568 Mtetra
.944 .959 .73 r
.75253 .41568 .75681 .41542 .76648 .39947 .76228 .39988 Mtetra
.929 .972 .739 r
.76228 .39988 .76648 .39947 .77619 .3846 .77206 .38511 Mtetra
.911 .982 .75 r
.77206 .38511 .77619 .3846 .78616 .37339 .78189 .37135 Mtetra
.804 .95 .915 r
.78189 .37135 .78616 .37339 .79678 .36999 .7922 .36368 Mtetra
.664 .741 .908 r
.7922 .36368 .79678 .36999 .80744 .36658 .80289 .36024 Mtetra
.80289 .36024 .80744 .36658 .81814 .36315 .81361 .35679 Mtetra
.81361 .35679 .81814 .36315 .82888 .35971 .82438 .35333 Mtetra
.82438 .35333 .82888 .35971 .83966 .35626 .83519 .34986 Mtetra
.83519 .34986 .83966 .35626 .85048 .3528 .84604 .34637 Mtetra
.84604 .34637 .85048 .3528 .86134 .34932 .85693 .34287 Mtetra
.85693 .34287 .86134 .34932 .87224 .34583 .86786 .33935 Mtetra
.86786 .33935 .87224 .34583 .88319 .34233 .87884 .33583 Mtetra
.87884 .33583 .88319 .34233 .89417 .33881 .88985 .33229 Mtetra
.88985 .33229 .89417 .33881 .9052 .33528 .9009 .32873 Mtetra
.3071 .51245 .31284 .51779 .32182 .5149 .31611 .50954 Mtetra
.31611 .50954 .32182 .5149 .33084 .512 .32514 .50662 Mtetra
.32514 .50662 .33084 .512 .33988 .50909 .33421 .5037 Mtetra
.33421 .5037 .33988 .50909 .34896 .50617 .3433 .50076 Mtetra
.3433 .50076 .34896 .50617 .35807 .50324 .35243 .49781 Mtetra
.35243 .49781 .35807 .50324 .36721 .50031 .36159 .49486 Mtetra
.36159 .49486 .36721 .50031 .37638 .49736 .37078 .49189 Mtetra
.37078 .49189 .37638 .49736 .38558 .4944 .38 .48891 Mtetra
.38 .48891 .38558 .4944 .39482 .49143 .38925 .48592 Mtetra
.641 .735 .917 r
.38925 .48592 .39482 .49143 .40408 .48845 .39852 .48347 Mtetra
0 .242 .716 r
.39852 .48347 .40408 .48845 .41324 .48959 .40752 .48951 Mtetra
.673 .137 0 r
.40752 .48951 .41324 .48959 .42227 .49665 .41657 .49643 Mtetra
.705 .181 0 r
.41657 .49643 .42227 .49665 .43136 .50473 .42568 .50432 Mtetra
.732 .218 0 r
.42568 .50432 .43136 .50473 .44052 .51385 .43486 .51321 Mtetra
.755 .249 .006 r
.43486 .51321 .44052 .51385 .44976 .52401 .44412 .52307 Mtetra
.773 .274 .017 r
.44412 .52307 .44976 .52401 .45909 .5352 .45346 .5339 Mtetra
.789 .295 .023 r
.45346 .5339 .45909 .5352 .46851 .5474 .46291 .5457 Mtetra
.802 .314 .025 r
.46291 .5457 .46851 .5474 .47938 .46425 .47245 .55847 Mtetra
0 0 .257 r
.47245 .55847 .47938 .46425 .48894 .46117 .48358 .45547 Mtetra
.664 .741 .908 r
.48358 .45547 .48894 .46117 .49853 .45809 .4932 .45237 Mtetra
.4932 .45237 .49853 .45809 .50816 .45499 .50285 .44925 Mtetra
.50285 .44925 .50816 .45499 .51782 .45189 .51253 .44612 Mtetra
.51253 .44612 .51782 .45189 .52752 .44877 .52225 .44299 Mtetra
.52225 .44299 .52752 .44877 .53725 .44564 .532 .43984 Mtetra
.532 .43984 .53725 .44564 .54701 .4425 .54179 .43668 Mtetra
.54179 .43668 .54701 .4425 .55681 .43935 .55161 .43351 Mtetra
.55161 .43351 .55681 .43935 .56664 .43619 .56147 .43033 Mtetra
.56147 .43033 .56664 .43619 .57651 .43302 .57136 .42713 Mtetra
.57136 .42713 .57651 .43302 .58642 .42984 .58129 .42393 Mtetra
.58129 .42393 .58642 .42984 .59636 .42664 .59125 .42071 Mtetra
.59125 .42071 .59636 .42664 .60633 .42343 .60125 .41748 Mtetra
.60125 .41748 .60633 .42343 .61634 .42021 .61128 .41424 Mtetra
.61128 .41424 .61634 .42021 .62639 .41698 .62136 .41099 Mtetra
.62136 .41099 .62639 .41698 .63647 .41374 .63146 .40773 Mtetra
.63146 .40773 .63647 .41374 .64659 .41049 .64161 .40445 Mtetra
.64161 .40445 .64659 .41049 .65675 .40722 .65179 .40117 Mtetra
.65179 .40117 .65675 .40722 .66694 .40395 .66201 .39787 Mtetra
.66201 .39787 .66694 .40395 .67717 .40066 .67226 .39456 Mtetra
.67226 .39456 .67717 .40066 .68744 .39736 .68255 .39123 Mtetra
.68255 .39123 .68744 .39736 .69774 .39405 .69288 .3879 Mtetra
.963 .631 .303 r
.69288 .3879 .69774 .39405 .70808 .39072 .70892 .48645 Mtetra
.483 .261 .501 r
.70892 .48645 .70808 .39072 .7234 .46919 .71872 .46704 Mtetra
.953 .881 .725 r
.71872 .46704 .7234 .46919 .7331 .45036 .72851 .44858 Mtetra
.953 .898 .734 r
.72851 .44858 .7331 .45036 .74281 .43251 .7383 .43107 Mtetra
.95 .914 .744 r
.7383 .43107 .74281 .43251 .75253 .41568 .7481 .41451 Mtetra
.945 .93 .755 r
.7481 .41451 .75253 .41568 .76228 .39988 .75793 .39892 Mtetra
.937 .945 .768 r
.75793 .39892 .76228 .39988 .77206 .38511 .76779 .3843 Mtetra
.925 .959 .782 r
.76779 .3843 .77206 .38511 .78189 .37135 .77769 .37065 Mtetra
.912 .97 .795 r
.77769 .37065 .78189 .37135 .7922 .36368 .78763 .35788 Mtetra
.684 .769 .916 r
.78763 .35788 .7922 .36368 .80289 .36024 .7983 .35387 Mtetra
.664 .741 .908 r
.7983 .35387 .80289 .36024 .81361 .35679 .80906 .35039 Mtetra
.80906 .35039 .81361 .35679 .82438 .35333 .81985 .34691 Mtetra
.81985 .34691 .82438 .35333 .83519 .34986 .83069 .34341 Mtetra
.83069 .34341 .83519 .34986 .84604 .34637 .84157 .3399 Mtetra
.84157 .3399 .84604 .34637 .85693 .34287 .85249 .33637 Mtetra
.85249 .33637 .85693 .34287 .86786 .33935 .86345 .33283 Mtetra
.86345 .33283 .86786 .33935 .87884 .33583 .87445 .32928 Mtetra
.87445 .32928 .87884 .33583 .88985 .33229 .8855 .32572 Mtetra
.8855 .32572 .88985 .33229 .9009 .32873 .89658 .32214 Mtetra
.30133 .50707 .3071 .51245 .31611 .50954 .31035 .50415 Mtetra
.31035 .50415 .31611 .50954 .32514 .50662 .31941 .50121 Mtetra
.31941 .50121 .32514 .50662 .33421 .5037 .32849 .49827 Mtetra
.32849 .49827 .33421 .5037 .3433 .50076 .3376 .49531 Mtetra
.3376 .49531 .3433 .50076 .35243 .49781 .34675 .49235 Mtetra
.34675 .49235 .35243 .49781 .36159 .49486 .35593 .48937 Mtetra
.35593 .48937 .36159 .49486 .37078 .49189 .36514 .48638 Mtetra
.36514 .48638 .37078 .49189 .38 .48891 .37438 .48339 Mtetra
.37438 .48339 .38 .48891 .38925 .48592 .38365 .48038 Mtetra
.308 .592 .944 r
.38365 .48038 .38925 .48592 .39852 .48347 .39276 .48251 Mtetra
.596 .024 0 r
.39276 .48251 .39852 .48347 .40752 .48951 .40178 .48838 Mtetra
.638 .078 0 r
.40178 .48838 .40752 .48951 .41657 .49643 .41085 .49513 Mtetra
.675 .127 0 r
.41085 .49513 .41657 .49643 .42568 .50432 .41998 .50281 Mtetra
.705 .168 0 r
.41998 .50281 .42568 .50432 .43486 .51321 .42918 .51142 Mtetra
.729 .2 0 r
.42918 .51142 .43486 .51321 .44412 .52307 .43846 .52093 Mtetra
.747 .226 0 r
.43846 .52093 .44412 .52307 .45346 .5339 .44782 .53134 Mtetra
.762 .248 0 r
.44782 .53134 .45346 .5339 .46291 .5457 .45728 .54266 Mtetra
.773 .266 0 r
.45728 .54266 .46291 .5457 .47245 .55847 .46683 .55492 Mtetra
.781 .282 0 r
.46683 .55492 .47245 .55847 .48358 .45547 .4765 .56812 Mtetra
0 0 .272 r
.4765 .56812 .48358 .45547 .4932 .45237 .48783 .44661 Mtetra
.664 .741 .908 r
.48783 .44661 .4932 .45237 .50285 .44925 .4975 .44347 Mtetra
.4975 .44347 .50285 .44925 .51253 .44612 .50721 .44032 Mtetra
.50721 .44032 .51253 .44612 .52225 .44299 .51695 .43717 Mtetra
.51695 .43717 .52225 .44299 .532 .43984 .52672 .434 Mtetra
.52672 .434 .532 .43984 .54179 .43668 .53653 .43082 Mtetra
.53653 .43082 .54179 .43668 .55161 .43351 .54638 .42762 Mtetra
.54638 .42762 .55161 .43351 .56147 .43033 .55626 .42442 Mtetra
.55626 .42442 .56147 .43033 .57136 .42713 .56617 .42121 Mtetra
.56617 .42121 .57136 .42713 .58129 .42393 .57612 .41798 Mtetra
.57612 .41798 .58129 .42393 .59125 .42071 .58611 .41474 Mtetra
.58611 .41474 .59125 .42071 .60125 .41748 .59613 .41149 Mtetra
.59613 .41149 .60125 .41748 .61128 .41424 .60619 .40823 Mtetra
.60619 .40823 .61128 .41424 .62136 .41099 .61629 .40496 Mtetra
.61629 .40496 .62136 .41099 .63146 .40773 .62642 .40167 Mtetra
.62642 .40167 .63146 .40773 .64161 .40445 .63659 .39838 Mtetra
.63659 .39838 .64161 .40445 .65179 .40117 .6468 .39507 Mtetra
.6468 .39507 .65179 .40117 .66201 .39787 .65704 .39175 Mtetra
.65704 .39175 .66201 .39787 .67226 .39456 .66732 .38841 Mtetra
.66732 .38841 .67226 .39456 .68255 .39123 .67764 .38507 Mtetra
.966 .642 .326 r
.67764 .38507 .68255 .39123 .69288 .3879 .69413 .50226 Mtetra
.493 .272 .507 r
.69413 .50226 .69288 .3879 .70892 .48645 .70403 .48244 Mtetra
.933 .835 .724 r
.70403 .48244 .70892 .48645 .71872 .46704 .71392 .46352 Mtetra
.936 .852 .734 r
.71392 .46352 .71872 .46704 .72851 .44858 .72379 .44551 Mtetra
.938 .868 .744 r
.72379 .44551 .72851 .44858 .7383 .43107 .73367 .4284 Mtetra
.938 .885 .755 r
.73367 .4284 .7383 .43107 .7481 .41451 .74356 .41216 Mtetra
.935 .901 .767 r
.74356 .41216 .7481 .41451 .75793 .39892 .75346 .39681 Mtetra
.93 .916 .78 r
.75346 .39681 .75793 .39892 .76779 .3843 .76339 .38238 Mtetra
.923 .929 .795 r
.76339 .38238 .76779 .3843 .77769 .37065 .77336 .36887 Mtetra
.913 .941 .81 r
.77336 .36887 .77769 .37065 .78763 .35788 .78337 .35623 Mtetra
.832 .966 .891 r
.78337 .35623 .78763 .35788 .7983 .35387 .79368 .34744 Mtetra
.664 .741 .908 r
.79368 .34744 .7983 .35387 .80906 .35039 .80447 .34395 Mtetra
.80447 .34395 .80906 .35039 .81985 .34691 .81529 .34044 Mtetra
.81529 .34044 .81985 .34691 .83069 .34341 .82616 .33691 Mtetra
.82616 .33691 .83069 .34341 .84157 .3399 .83707 .33338 Mtetra
.83707 .33338 .84157 .3399 .85249 .33637 .84802 .32983 Mtetra
.84802 .32983 .85249 .33637 .86345 .33283 .85901 .32626 Mtetra
.85901 .32626 .86345 .33283 .87445 .32928 .87004 .32269 Mtetra
.87004 .32269 .87445 .32928 .8855 .32572 .88111 .3191 Mtetra
.88111 .3191 .8855 .32572 .89658 .32214 .89223 .31549 Mtetra
.29552 .50166 .30133 .50707 .31035 .50415 .30456 .49872 Mtetra
.30456 .49872 .31035 .50415 .31941 .50121 .31364 .49577 Mtetra
.31364 .49577 .31941 .50121 .32849 .49827 .32274 .4928 Mtetra
.32274 .4928 .32849 .49827 .3376 .49531 .33187 .48983 Mtetra
.33187 .48983 .3376 .49531 .34675 .49235 .34104 .48684 Mtetra
.34104 .48684 .34675 .49235 .35593 .48937 .35024 .48385 Mtetra
.35024 .48385 .35593 .48937 .36514 .48638 .35947 .48084 Mtetra
.35947 .48084 .36514 .48638 .37438 .48339 .36873 .47783 Mtetra
.626 .731 .922 r
.36873 .47783 .37438 .48339 .38365 .48038 .37798 .47565 Mtetra
0 .327 .777 r
.37798 .47565 .38365 .48038 .39276 .48251 .38697 .48068 Mtetra
.535 0 0 r
.38697 .48068 .39276 .48251 .40178 .48838 .39602 .48637 Mtetra
.586 .012 0 r
.39602 .48637 .40178 .48838 .41085 .49513 .40511 .49293 Mtetra
.629 .066 0 r
.40511 .49293 .41085 .49513 .41998 .50281 .41426 .50038 Mtetra
.661 .109 0 r
.41426 .50038 .41998 .50281 .42918 .51142 .42348 .50868 Mtetra
.685 .141 0 r
.42348 .50868 .42918 .51142 .43846 .52093 .43278 .5178 Mtetra
.701 .166 0 r
.43278 .5178 .43846 .52093 .44782 .53134 .44215 .52773 Mtetra
.712 .187 0 r
.44215 .52773 .44782 .53134 .45728 .54266 .45163 .53851 Mtetra
.72 .204 0 r
.45163 .53851 .45728 .54266 .46683 .55492 .46119 .55018 Mtetra
.724 .219 0 r
.46119 .55018 .46683 .55492 .4765 .56812 .47087 .56277 Mtetra
.724 .231 0 r
.47087 .56277 .4765 .56812 .48783 .44661 .48066 .57628 Mtetra
0 0 .282 r
.48066 .57628 .48783 .44661 .4975 .44347 .49212 .43765 Mtetra
.664 .741 .908 r
.49212 .43765 .4975 .44347 .50721 .44032 .50185 .43448 Mtetra
.50185 .43448 .50721 .44032 .51695 .43717 .51161 .43131 Mtetra
.51161 .43131 .51695 .43717 .52672 .434 .52141 .42812 Mtetra
.52141 .42812 .52672 .434 .53653 .43082 .53124 .42491 Mtetra
.53124 .42491 .53653 .43082 .54638 .42762 .54111 .4217 Mtetra
.54111 .4217 .54638 .42762 .55626 .42442 .55101 .41848 Mtetra
.55101 .41848 .55626 .42442 .56617 .42121 .56095 .41524 Mtetra
.56095 .41524 .56617 .42121 .57612 .41798 .57093 .41199 Mtetra
.57093 .41199 .57612 .41798 .58611 .41474 .58094 .40873 Mtetra
.58094 .40873 .58611 .41474 .59613 .41149 .59099 .40546 Mtetra
.59099 .40546 .59613 .41149 .60619 .40823 .60107 .40218 Mtetra
.60107 .40218 .60619 .40823 .61629 .40496 .61119 .39888 Mtetra
.61119 .39888 .61629 .40496 .62642 .40167 .62135 .39558 Mtetra
.62135 .39558 .62642 .40167 .63659 .39838 .63154 .39226 Mtetra
.63154 .39226 .63659 .39838 .6468 .39507 .64177 .38893 Mtetra
.64177 .38893 .6468 .39507 .65704 .39175 .65204 .38558 Mtetra
.65204 .38558 .65704 .39175 .66732 .38841 .66235 .38223 Mtetra
.967 .649 .343 r
.66235 .38223 .66732 .38841 .67764 .38507 .67905 .5166 Mtetra
.499 .279 .51 r
.67905 .5166 .67764 .38507 .69413 .50226 .68906 .49646 Mtetra
.912 .795 .719 r
.68906 .49646 .69413 .50226 .70403 .48244 .69904 .47722 Mtetra
.915 .81 .728 r
.69904 .47722 .70403 .48244 .71392 .46352 .70901 .45886 Mtetra
.919 .827 .739 r
.70901 .45886 .71392 .46352 .72379 .44551 .71897 .44137 Mtetra
.922 .844 .749 r
.71897 .44137 .72379 .44551 .73367 .4284 .72894 .4247 Mtetra
.923 .86 .76 r
.72894 .4247 .73367 .4284 .74356 .41216 .7389 .40882 Mtetra
.923 .875 .772 r
.7389 .40882 .74356 .41216 .75346 .39681 .74888 .39375 Mtetra
.92 .889 .785 r
.74888 .39375 .75346 .39681 .76339 .38238 .75888 .37951 Mtetra
.914 .901 .8 r
.75888 .37951 .76339 .38238 .77336 .36887 .76891 .36617 Mtetra
.905 .913 .815 r
.76891 .36617 .77336 .36887 .78337 .35623 .77899 .35368 Mtetra
.898 .923 .828 r
.77899 .35368 .78337 .35623 .79368 .34744 .7891 .34185 Mtetra
.695 .785 .92 r
.7891 .34185 .79368 .34744 .80447 .34395 .79985 .33746 Mtetra
.664 .741 .908 r
.79985 .33746 .80447 .34395 .81529 .34044 .8107 .33392 Mtetra
.8107 .33392 .81529 .34044 .82616 .33691 .8216 .33037 Mtetra
.8216 .33037 .82616 .33691 .83707 .33338 .83253 .32681 Mtetra
.83253 .32681 .83707 .33338 .84802 .32983 .84351 .32324 Mtetra
.84351 .32324 .84802 .32983 .85901 .32626 .85453 .31965 Mtetra
.85453 .31965 .85901 .32626 .87004 .32269 .8656 .31605 Mtetra
.8656 .31605 .87004 .32269 .88111 .3191 .8767 .31243 Mtetra
.8767 .31243 .88111 .3191 .89223 .31549 .88785 .3088 Mtetra
.28968 .49622 .29552 .50166 .30456 .49872 .29874 .49326 Mtetra
.29874 .49326 .30456 .49872 .31364 .49577 .30783 .49029 Mtetra
.30783 .49029 .31364 .49577 .32274 .4928 .31695 .4873 Mtetra
.31695 .4873 .32274 .4928 .33187 .48983 .3261 .48431 Mtetra
.3261 .48431 .33187 .48983 .34104 .48684 .33529 .48131 Mtetra
.33529 .48131 .34104 .48684 .35024 .48385 .34451 .47829 Mtetra
.34451 .47829 .35024 .48385 .35947 .48084 .35375 .47527 Mtetra
.35375 .47527 .35947 .48084 .36873 .47783 .36304 .47223 Mtetra
.409 .643 .953 r
.36304 .47223 .36873 .47783 .37798 .47565 .37216 .47329 Mtetra
.41 0 0 r
.37216 .47329 .37798 .47565 .38697 .48068 .38117 .4781 Mtetra
.46 0 0 r
.38117 .4781 .38697 .48068 .39602 .48637 .39024 .4836 Mtetra
.519 0 0 r
.39024 .4836 .39602 .48637 .40511 .49293 .39935 .48995 Mtetra
.567 .001 0 r
.39935 .48995 .40511 .49293 .41426 .50038 .40852 .49715 Mtetra
.601 .044 0 r
.40852 .49715 .41426 .50038 .42348 .50868 .41776 .50513 Mtetra
.622 .074 0 r
.41776 .50513 .42348 .50868 .43278 .5178 .42707 .51383 Mtetra
.635 .096 0 r
.42707 .51383 .43278 .5178 .44215 .52773 .43647 .52326 Mtetra
.641 .114 0 r
.43647 .52326 .44215 .52773 .45163 .53851 .44595 .53345 Mtetra
.642 .129 0 r
.44595 .53345 .45163 .53851 .46119 .55018 .45553 .54446 Mtetra
.64 .143 0 r
.45553 .54446 .46119 .55018 .47087 .56277 .46522 .55636 Mtetra
.635 .154 0 r
.46522 .55636 .47087 .56277 .48066 .57628 .47501 .56918 Mtetra
.625 .162 0 r
.47501 .56918 .48066 .57628 .49212 .43765 .48493 .58291 Mtetra
0 0 .289 r
.48493 .58291 .49212 .43765 .50185 .43448 .49645 .42861 Mtetra
.664 .741 .908 r
.49645 .42861 .50185 .43448 .51161 .43131 .50624 .42541 Mtetra
.50624 .42541 .51161 .43131 .52141 .42812 .51606 .4222 Mtetra
.51606 .4222 .52141 .42812 .53124 .42491 .52592 .41897 Mtetra
.52592 .41897 .53124 .42491 .54111 .4217 .53581 .41574 Mtetra
.53581 .41574 .54111 .4217 .55101 .41848 .54573 .41249 Mtetra
.54573 .41249 .55101 .41848 .56095 .41524 .5557 .40924 Mtetra
.5557 .40924 .56095 .41524 .57093 .41199 .56569 .40597 Mtetra
.56569 .40597 .57093 .41199 .58094 .40873 .57573 .40268 Mtetra
.57573 .40268 .58094 .40873 .59099 .40546 .5858 .39939 Mtetra
.5858 .39939 .59099 .40546 .60107 .40218 .59591 .39609 Mtetra
.59591 .39609 .60107 .40218 .61119 .39888 .60605 .39277 Mtetra
.60605 .39277 .61119 .39888 .62135 .39558 .61624 .38944 Mtetra
.61624 .38944 .62135 .39558 .63154 .39226 .62645 .3861 Mtetra
.62645 .3861 .63154 .39226 .64177 .38893 .63671 .38274 Mtetra
.63671 .38274 .64177 .38893 .65204 .38558 .64701 .37938 Mtetra
.968 .654 .357 r
.64701 .37938 .65204 .38558 .66235 .38223 .66369 .52938 Mtetra
.504 .283 .512 r
.66369 .52938 .66235 .38223 .67905 .5166 .67381 .50905 Mtetra
.89 .761 .713 r
.67381 .50905 .67905 .5166 .68906 .49646 .68389 .48957 Mtetra
.895 .775 .722 r
.68389 .48957 .68906 .49646 .69904 .47722 .69396 .47099 Mtetra
.899 .79 .732 r
.69396 .47099 .69904 .47722 .70901 .45886 .70402 .45327 Mtetra
.903 .807 .742 r
.70402 .45327 .70901 .45886 .71897 .44137 .71407 .43634 Mtetra
.907 .823 .753 r
.71407 .43634 .71897 .44137 .72894 .4247 .72411 .42014 Mtetra
.909 .839 .763 r
.72411 .42014 .72894 .4247 .7389 .40882 .73415 .40465 Mtetra
.91 .853 .774 r
.73415 .40465 .7389 .40882 .74888 .39375 .7442 .38986 Mtetra
.908 .866 .786 r
.7442 .38986 .74888 .39375 .75888 .37951 .75427 .37585 Mtetra
.903 .877 .801 r
.75427 .37585 .75888 .37951 .76891 .36617 .76437 .36267 Mtetra
.896 .888 .816 r
.76437 .36267 .76891 .36617 .77899 .35368 .77452 .35034 Mtetra
.888 .898 .83 r
.77452 .35034 .77899 .35368 .7891 .34185 .7847 .3387 Mtetra
.809 .912 .91 r
.7847 .3387 .7891 .34185 .79985 .33746 .79519 .33092 Mtetra
.664 .741 .908 r
.79519 .33092 .79985 .33746 .8107 .33392 .80608 .32736 Mtetra
.80608 .32736 .8107 .33392 .8216 .33037 .817 .32379 Mtetra
.817 .32379 .8216 .33037 .83253 .32681 .82797 .3202 Mtetra
.82797 .3202 .83253 .32681 .84351 .32324 .83898 .3166 Mtetra
.83898 .3166 .84351 .32324 .85453 .31965 .85003 .31299 Mtetra
.85003 .31299 .85453 .31965 .8656 .31605 .86112 .30936 Mtetra
.86112 .30936 .8656 .31605 .8767 .31243 .87226 .30572 Mtetra
.87226 .30572 .8767 .31243 .88785 .3088 .88343 .30207 Mtetra
.2838 .49075 .28968 .49622 .29874 .49326 .29287 .48776 Mtetra
.29287 .48776 .29874 .49326 .30783 .49029 .30198 .48477 Mtetra
.30198 .48477 .30783 .49029 .31695 .4873 .31112 .48177 Mtetra
.31112 .48177 .31695 .4873 .3261 .48431 .3203 .47876 Mtetra
.3203 .47876 .3261 .48431 .33529 .48131 .3295 .47574 Mtetra
.3295 .47574 .33529 .48131 .34451 .47829 .33874 .4727 Mtetra
.33874 .4727 .34451 .47829 .35375 .47527 .34801 .46966 Mtetra
.34801 .46966 .35375 .47527 .36304 .47223 .35731 .4666 Mtetra
.118 .481 .898 r
.35731 .4666 .36304 .47223 .37216 .47329 .36632 .47028 Mtetra
0 .258 .637 r
.36632 .47028 .37216 .47329 .38117 .4781 .37536 .47486 Mtetra
.374 0 0 r
.37536 .47486 .38117 .4781 .39024 .4836 .38444 .48017 Mtetra
.441 0 0 r
.38444 .48017 .39024 .4836 .39935 .48995 .39357 .48631 Mtetra
.494 0 0 r
.39357 .48631 .39935 .48995 .40852 .49715 .40276 .49325 Mtetra
.527 0 0 r
.40276 .49325 .40852 .49715 .41776 .50513 .41201 .50089 Mtetra
.544 .002 0 r
.41201 .50089 .41776 .50513 .42707 .51383 .42134 .50917 Mtetra
.55 .02 0 r
.42134 .50917 .42707 .51383 .43647 .52326 .43075 .51807 Mtetra
.549 .033 0 r
.43075 .51807 .43647 .52326 .44595 .53345 .44026 .52763 Mtetra
.542 .045 0 r
.44026 .52763 .44595 .53345 .45553 .54446 .44985 .53793 Mtetra
.534 .057 0 r
.44985 .53793 .45553 .54446 .46522 .55636 .45955 .54907 Mtetra
0 0 .469 r
.45955 .54907 .46522 .55636 .47501 .56918 .46934 .56112 Mtetra
0 0 .474 r
.46934 .56112 .47501 .56918 .48493 .58291 .47926 .57411 Mtetra
0 0 .48 r
.47926 .57411 .48493 .58291 .49645 .42861 .4893 .58794 Mtetra
0 0 .294 r
.4893 .58794 .49645 .42861 .50624 .42541 .50083 .41947 Mtetra
.664 .741 .908 r
.50083 .41947 .50624 .42541 .51606 .4222 .51067 .41624 Mtetra
.51067 .41624 .51606 .4222 .52592 .41897 .52055 .41299 Mtetra
.52055 .41299 .52592 .41897 .53581 .41574 .53047 .40974 Mtetra
.53047 .40974 .53581 .41574 .54573 .41249 .54042 .40647 Mtetra
.54042 .40647 .54573 .41249 .5557 .40924 .5504 .40319 Mtetra
.5504 .40319 .5557 .40924 .56569 .40597 .56043 .3999 Mtetra
.56043 .3999 .56569 .40597 .57573 .40268 .57049 .3966 Mtetra
.57049 .3966 .57573 .40268 .5858 .39939 .58058 .39328 Mtetra
.58058 .39328 .5858 .39939 .59591 .39609 .59071 .38995 Mtetra
.59071 .38995 .59591 .39609 .60605 .39277 .60088 .38661 Mtetra
.60088 .38661 .60605 .39277 .61624 .38944 .61109 .38326 Mtetra
.61109 .38326 .61624 .38944 .62645 .3861 .62134 .3799 Mtetra
.62134 .3799 .62645 .3861 .63671 .38274 .63162 .37652 Mtetra
.969 .658 .368 r
.63162 .37652 .63671 .38274 .64701 .37938 .64807 .54058 Mtetra
.506 .286 .514 r
.64807 .54058 .64701 .37938 .66369 .52938 .6583 .52015 Mtetra
.871 .732 .706 r
.6583 .52015 .66369 .52938 .67381 .50905 .66849 .50053 Mtetra
.875 .744 .715 r
.66849 .50053 .67381 .50905 .68389 .48957 .67866 .48179 Mtetra
.879 .758 .725 r
.67866 .48179 .68389 .48957 .69396 .47099 .68881 .46394 Mtetra
.884 .774 .735 r
.68881 .46394 .69396 .47099 .70402 .45327 .69895 .44689 Mtetra
.889 .79 .745 r
.69895 .44689 .70402 .45327 .71407 .43634 .70908 .43056 Mtetra
.893 .806 .755 r
.70908 .43056 .71407 .43634 .72411 .42014 .7192 .41486 Mtetra
.897 .821 .765 r
.7192 .41486 .72411 .42014 .73415 .40465 .72932 .39976 Mtetra
.898 .835 .775 r
.72932 .39976 .73415 .40465 .7442 .38986 .73944 .38528 Mtetra
.896 .847 .787 r
.73944 .38528 .7442 .38986 .75427 .37585 .74958 .37149 Mtetra
.892 .857 .8 r
.74958 .37149 .75427 .37585 .76437 .36267 .75975 .35849 Mtetra
.885 .866 .815 r
.75975 .35849 .76437 .36267 .77452 .35034 .76995 .34632 Mtetra
.878 .875 .829 r
.76995 .34632 .77452 .35034 .7847 .3387 .7802 .33488 Mtetra
.866 .886 .848 r
.7802 .33488 .7847 .3387 .79519 .33092 .79051 .32434 Mtetra
.664 .741 .908 r
.79051 .32434 .79519 .33092 .80608 .32736 .80142 .32076 Mtetra
.80142 .32076 .80608 .32736 .817 .32379 .81238 .31716 Mtetra
.81238 .31716 .817 .32379 .82797 .3202 .82337 .31355 Mtetra
.82337 .31355 .82797 .3202 .83898 .3166 .83441 .30992 Mtetra
.83441 .30992 .83898 .3166 .85003 .31299 .84549 .30628 Mtetra
.84549 .30628 .85003 .31299 .86112 .30936 .85661 .30263 Mtetra
.85661 .30263 .86112 .30936 .87226 .30572 .86778 .29896 Mtetra
.86778 .29896 .87226 .30572 .88343 .30207 .87899 .29528 Mtetra
.27788 .48523 .2838 .49075 .29287 .48776 .28697 .48223 Mtetra
.28697 .48223 .29287 .48776 .30198 .48477 .2961 .47922 Mtetra
.2961 .47922 .30198 .48477 .31112 .48177 .30526 .4762 Mtetra
.30526 .4762 .31112 .48177 .3203 .47876 .31445 .47317 Mtetra
.31445 .47317 .3203 .47876 .3295 .47574 .32368 .47013 Mtetra
.32368 .47013 .3295 .47574 .33874 .4727 .33293 .46707 Mtetra
.33293 .46707 .33874 .4727 .34801 .46966 .34222 .46401 Mtetra
.579 .715 .936 r
.34222 .46401 .34801 .46966 .35731 .4666 .35145 .46269 Mtetra
0 .384 .791 r
.35145 .46269 .35731 .4666 .36632 .47028 .36045 .4667 Mtetra
0 .327 .728 r
.36045 .4667 .36632 .47028 .37536 .47486 .36951 .47105 Mtetra
0 .26 .679 r
.36951 .47105 .37536 .47486 .38444 .48017 .37862 .47615 Mtetra
0 .187 .621 r
.37862 .47615 .38444 .48017 .39357 .48631 .38776 .48208 Mtetra
0 .13 .575 r
.38776 .48208 .39357 .48631 .40276 .49325 .39697 .48875 Mtetra
.443 0 0 r
.39697 .48875 .40276 .49325 .41201 .50089 .40624 .49605 Mtetra
.455 0 0 r
.40624 .49605 .41201 .50089 .42134 .50917 .41559 .50389 Mtetra
0 .059 .546 r
.41559 .50389 .42134 .50917 .43075 .51807 .42502 .51225 Mtetra
0 .052 .556 r
.42502 .51225 .43075 .51807 .44026 .52763 .43454 .52117 Mtetra
0 .043 .565 r
.43454 .52117 .44026 .52763 .44985 .53793 .44415 .53073 Mtetra
0 .033 .57 r
.44415 .53073 .44985 .53793 .45955 .54907 .45385 .54107 Mtetra
0 .02 .571 r
.45385 .54107 .45955 .54907 .46934 .56112 .46366 .55228 Mtetra
0 .007 .569 r
.46366 .55228 .46934 .56112 .47926 .57411 .47357 .56443 Mtetra
0 0 .567 r
.47357 .56443 .47926 .57411 .4893 .58794 .48361 .57749 Mtetra
0 0 .57 r
.48361 .57749 .4893 .58794 .50083 .41947 .49377 .59132 Mtetra
0 0 .298 r
.49377 .59132 .50083 .41947 .51067 .41624 .50525 .41024 Mtetra
.664 .741 .908 r
.50525 .41024 .51067 .41624 .52055 .41299 .51516 .40697 Mtetra
.51516 .40697 .52055 .41299 .53047 .40974 .52509 .4037 Mtetra
.52509 .4037 .53047 .40974 .54042 .40647 .53507 .40041 Mtetra
.53507 .40041 .54042 .40647 .5504 .40319 .54508 .3971 Mtetra
.54508 .3971 .5504 .40319 .56043 .3999 .55513 .39379 Mtetra
.55513 .39379 .56043 .3999 .57049 .3966 .56521 .39047 Mtetra
.56521 .39047 .57049 .3966 .58058 .39328 .57533 .38713 Mtetra
.57533 .38713 .58058 .39328 .59071 .38995 .58549 .38378 Mtetra
.58549 .38378 .59071 .38995 .60088 .38661 .59568 .38041 Mtetra
.59568 .38041 .60088 .38661 .61109 .38326 .60591 .37704 Mtetra
.60591 .37704 .61109 .38326 .62134 .3799 .61618 .37365 Mtetra
.969 .661 .377 r
.61618 .37365 .62134 .3799 .63162 .37652 .63221 .55015 Mtetra
.508 .288 .514 r
.63221 .55015 .63162 .37652 .64807 .54058 .64255 .52973 Mtetra
.853 .707 .7 r
.64255 .52973 .64807 .54058 .6583 .52015 .65285 .51003 Mtetra
.857 .717 .708 r
.65285 .51003 .6583 .52015 .66849 .50053 .66311 .4912 Mtetra
.861 .73 .717 r
.66311 .4912 .66849 .50053 .67866 .48179 .67336 .47327 Mtetra
.865 .744 .728 r
.67336 .47327 .67866 .48179 .68881 .46394 .68359 .45619 Mtetra
.87 .76 .738 r
.68359 .45619 .68881 .46394 .69895 .44689 .69381 .43985 Mtetra
.876 .776 .748 r
.69381 .43985 .69895 .44689 .70908 .43056 .70402 .42413 Mtetra
.881 .792 .758 r
.70402 .42413 .70908 .43056 .7192 .41486 .71422 .40895 Mtetra
.885 .806 .767 r
.71422 .40895 .7192 .41486 .72932 .39976 .72442 .39425 Mtetra
.886 .819 .776 r
.72442 .39425 .72932 .39976 .73944 .38528 .73461 .38008 Mtetra
.886 .83 .787 r
.73461 .38008 .73944 .38528 .74958 .37149 .74481 .36652 Mtetra
.882 .839 .799 r
.74481 .36652 .74958 .37149 .75975 .35849 .75504 .3537 Mtetra
.875 .848 .814 r
.75504 .3537 .75975 .35849 .76995 .34632 .7653 .3417 Mtetra
.868 .856 .828 r
.7653 .3417 .76995 .34632 .7802 .33488 .77561 .33045 Mtetra
.866 .865 .836 r
.77561 .33045 .7802 .33488 .79051 .32434 .78594 .31953 Mtetra
.73 .833 .929 r
.78594 .31953 .79051 .32434 .80142 .32076 .79673 .3141 Mtetra
.664 .741 .908 r
.79673 .3141 .80142 .32076 .81238 .31716 .80772 .31048 Mtetra
.80772 .31048 .81238 .31716 .82337 .31355 .81874 .30684 Mtetra
.81874 .30684 .82337 .31355 .83441 .30992 .82981 .30319 Mtetra
.82981 .30319 .83441 .30992 .84549 .30628 .84092 .29953 Mtetra
.84092 .29953 .84549 .30628 .85661 .30263 .85208 .29585 Mtetra
.85208 .29585 .85661 .30263 .86778 .29896 .86327 .29216 Mtetra
.86327 .29216 .86778 .29896 .87899 .29528 .87451 .28845 Mtetra
.27192 .47969 .27788 .48523 .28697 .48223 .28103 .47667 Mtetra
.28103 .47667 .28697 .48223 .2961 .47922 .29018 .47364 Mtetra
.29018 .47364 .2961 .47922 .30526 .4762 .29936 .4706 Mtetra
.29936 .4706 .30526 .4762 .31445 .47317 .30857 .46754 Mtetra
.30857 .46754 .31445 .47317 .32368 .47013 .31782 .46448 Mtetra
.31782 .46448 .32368 .47013 .33293 .46707 .32709 .46141 Mtetra
.32709 .46141 .33293 .46707 .34222 .46401 .3364 .45833 Mtetra
.447 .662 .953 r
.3364 .45833 .34222 .46401 .35145 .46269 .34554 .45889 Mtetra
0 .409 .806 r
.34554 .45889 .35145 .46269 .36045 .4667 .35457 .46261 Mtetra
0 .384 .798 r
.35457 .46261 .36045 .4667 .36951 .47105 .36365 .46673 Mtetra
0 .315 .749 r
.36365 .46673 .36951 .47105 .37862 .47615 .37277 .47162 Mtetra
0 .244 .694 r
.37277 .47162 .37862 .47615 .38776 .48208 .38194 .47732 Mtetra
0 .19 .653 r
.38194 .47732 .38776 .48208 .39697 .48875 .39116 .48372 Mtetra
0 .157 .632 r
.39116 .48372 .39697 .48875 .40624 .49605 .40045 .49068 Mtetra
0 .142 .629 r
.40045 .49068 .40624 .49605 .41559 .50389 .40981 .49809 Mtetra
0 .137 .637 r
.40981 .49809 .41559 .50389 .42502 .51225 .41926 .5059 Mtetra
0 .134 .648 r
.41926 .5059 .42502 .51225 .43454 .52117 .4288 .51416 Mtetra
0 .129 .656 r
.4288 .51416 .43454 .52117 .44415 .53073 .43843 .52297 Mtetra
0 .119 .658 r
.43843 .52297 .44415 .53073 .45385 .54107 .44814 .53247 Mtetra
0 .105 .653 r
.44814 .53247 .45385 .54107 .46366 .55228 .45796 .54279 Mtetra
0 .088 .645 r
.45796 .54279 .46366 .55228 .47357 .56443 .46787 .55404 Mtetra
0 .073 .635 r
.46787 .55404 .47357 .56443 .48361 .57749 .4779 .56625 Mtetra
0 .064 .629 r
.4779 .56625 .48361 .57749 .49377 .59132 .48805 .57932 Mtetra
0 .066 .63 r
.48805 .57932 .49377 .59132 .50525 .41024 .49833 .593 Mtetra
0 0 .301 r
.49833 .593 .50525 .41024 .51516 .40697 .50972 .40091 Mtetra
.664 .741 .908 r
.50972 .40091 .51516 .40697 .52509 .4037 .51968 .39761 Mtetra
.51968 .39761 .52509 .4037 .53507 .40041 .52968 .3943 Mtetra
.52968 .3943 .53507 .40041 .54508 .3971 .53972 .39098 Mtetra
.53972 .39098 .54508 .3971 .55513 .39379 .54979 .38764 Mtetra
.54979 .38764 .55513 .39379 .56521 .39047 .55989 .38429 Mtetra
.55989 .38429 .56521 .39047 .57533 .38713 .57004 .38093 Mtetra
.57004 .38093 .57533 .38713 .58549 .38378 .58022 .37756 Mtetra
.58022 .37756 .58549 .38378 .59568 .38041 .59044 .37418 Mtetra
.59044 .37418 .59568 .38041 .60591 .37704 .6007 .37078 Mtetra
.969 .663 .385 r
.6007 .37078 .60591 .37704 .61618 .37365 .61614 .55803 Mtetra
.51 .288 .514 r
.61614 .55803 .61618 .37365 .63221 .55015 .62659 .53777 Mtetra
.838 .686 .694 r
.62659 .53777 .63221 .55015 .64255 .52973 .63698 .51807 Mtetra
.84 .694 .701 r
.63698 .51807 .64255 .52973 .65285 .51003 .64735 .49918 Mtetra
.843 .705 .71 r
.64735 .49918 .65285 .51003 .66311 .4912 .65768 .48122 Mtetra
.847 .718 .72 r
.65768 .48122 .66311 .4912 .67336 .47327 .66801 .46414 Mtetra
.852 .733 .731 r
.66801 .46414 .67336 .47327 .68359 .45619 .67832 .44787 Mtetra
.858 .749 .742 r
.67832 .44787 .68359 .45619 .69381 .43985 .68862 .43225 Mtetra
.863 .765 .752 r
.68862 .43225 .69381 .43985 .70402 .42413 .6989 .41716 Mtetra
.869 .78 .76 r
.6989 .41716 .70402 .42413 .71422 .40895 .70918 .40249 Mtetra
.874 .794 .768 r
.70918 .40249 .71422 .40895 .72442 .39425 .71944 .3882 Mtetra
.876 .805 .777 r
.71944 .3882 .72442 .39425 .73461 .38008 .7297 .37433 Mtetra
.876 .816 .786 r
.7297 .37433 .73461 .38008 .74481 .36652 .73996 .361 Mtetra
.872 .824 .798 r
.73996 .361 .74481 .36652 .75504 .3537 .75025 .34836 Mtetra
.865 .832 .812 r
.75025 .34836 .75504 .3537 .7653 .3417 .76058 .33654 Mtetra
.858 .839 .826 r
.76058 .33654 .7653 .3417 .77561 .33045 .77095 .32549 Mtetra
.855 .847 .835 r
.77095 .32549 .77561 .33045 .78594 .31953 .78135 .31482 Mtetra
.79 .852 .897 r
.78135 .31482 .78594 .31953 .79673 .3141 .79201 .3074 Mtetra
.664 .741 .908 r
.79201 .3074 .79673 .3141 .80772 .31048 .80302 .30376 Mtetra
.80302 .30376 .80772 .31048 .81874 .30684 .81408 .30009 Mtetra
.81408 .30009 .81874 .30684 .82981 .30319 .82518 .29642 Mtetra
.82518 .29642 .82981 .30319 .84092 .29953 .83632 .29273 Mtetra
.83632 .29273 .84092 .29953 .85208 .29585 .8475 .28902 Mtetra
.8475 .28902 .85208 .29585 .86327 .29216 .85873 .2853 Mtetra
.85873 .2853 .86327 .29216 .87451 .28845 .87 .28157 Mtetra
.26592 .4741 .27192 .47969 .28103 .47667 .27506 .47106 Mtetra
.27506 .47106 .28103 .47667 .29018 .47364 .28422 .46801 Mtetra
.28422 .46801 .29018 .47364 .29936 .4706 .29342 .46495 Mtetra
.29342 .46495 .29936 .4706 .30857 .46754 .30265 .46188 Mtetra
.30265 .46188 .30857 .46754 .31782 .46448 .31192 .4588 Mtetra
.31192 .4588 .31782 .46448 .32709 .46141 .32121 .45571 Mtetra
.32121 .45571 .32709 .46141 .3364 .45833 .33054 .45261 Mtetra
.308 .593 .945 r
.33054 .45261 .3364 .45833 .34554 .45889 .33961 .45462 Mtetra
0 .461 .861 r
.33961 .45462 .34554 .45889 .35457 .46261 .34867 .45806 Mtetra
0 .431 .847 r
.34867 .45806 .35457 .46261 .36365 .46673 .35777 .46194 Mtetra
0 .362 .802 r
.35777 .46194 .36365 .46673 .37277 .47162 .36691 .4666 Mtetra
0 .294 .753 r
.36691 .4666 .37277 .47162 .38194 .47732 .37609 .47208 Mtetra
0 .244 .717 r
.37609 .47208 .38194 .47732 .39116 .48372 .38533 .47821 Mtetra
0 .217 .701 r
.38533 .47821 .39116 .48372 .40045 .49068 .39463 .48483 Mtetra
0 .207 .701 r
.39463 .48483 .40045 .49068 .40981 .49809 .40402 .4918 Mtetra
0 .208 .711 r
.40402 .4918 .40981 .49809 .41926 .5059 .41349 .49907 Mtetra
0 .21 .722 r
.41349 .49907 .41926 .5059 .4288 .51416 .42304 .50667 Mtetra
0 .208 .728 r
.42304 .50667 .4288 .51416 .43843 .52297 .43268 .51472 Mtetra
0 .199 .726 r
.43268 .51472 .43843 .52297 .44814 .53247 .44241 .52337 Mtetra
0 .183 .717 r
.44241 .52337 .44814 .53247 .45796 .54279 .45224 .53277 Mtetra
0 .163 .703 r
.45224 .53277 .45796 .54279 .46787 .55404 .46216 .54307 Mtetra
0 .143 .687 r
.46216 .54307 .46787 .55404 .4779 .56625 .47218 .55435 Mtetra
0 .127 .674 r
.47218 .55435 .4779 .56625 .48805 .57932 .48232 .56656 Mtetra
0 .12 .666 r
.48232 .56656 .48805 .57932 .49833 .593 .49258 .57954 Mtetra
0 .126 .667 r
.49258 .57954 .49833 .593 .50972 .40091 .50298 .59294 Mtetra
0 0 .303 r
.50298 .59294 .50972 .40091 .51968 .39761 .51424 .39149 Mtetra
.664 .741 .908 r
.51424 .39149 .51968 .39761 .52968 .3943 .52426 .38816 Mtetra
.52426 .38816 .52968 .3943 .53972 .39098 .53432 .38481 Mtetra
.53432 .38481 .53972 .39098 .54979 .38764 .54441 .38145 Mtetra
.54441 .38145 .54979 .38764 .55989 .38429 .55454 .37808 Mtetra
.55454 .37808 .55989 .38429 .57004 .38093 .56471 .3747 Mtetra
.56471 .3747 .57004 .38093 .58022 .37756 .57492 .3713 Mtetra
.57492 .3713 .58022 .37756 .59044 .37418 .58516 .36789 Mtetra
.968 .665 .392 r
.58516 .36789 .59044 .37418 .6007 .37078 .59987 .5642 Mtetra
.511 .289 .514 r
.59987 .5642 .6007 .37078 .61614 .55803 .61042 .54424 Mtetra
.824 .668 .69 r
.61042 .54424 .61614 .55803 .62659 .53777 .62092 .52462 Mtetra
.826 .675 .695 r
.62092 .52462 .62659 .53777 .63698 .51807 .63137 .50573 Mtetra
.828 .684 .704 r
.63137 .50573 .63698 .51807 .64735 .49918 .6418 .48774 Mtetra
.831 .695 .713 r
.6418 .48774 .64735 .49918 .65768 .48122 .65221 .47069 Mtetra
.835 .708 .724 r
.65221 .47069 .65768 .48122 .66801 .46414 .6626 .4545 Mtetra
.84 .723 .735 r
.6626 .4545 .66801 .46414 .67832 .44787 .67299 .43904 Mtetra
.846 .738 .745 r
.67299 .43904 .67832 .44787 .68862 .43225 .68337 .42416 Mtetra
.852 .754 .755 r
.68337 .42416 .68862 .43225 .6989 .41716 .69373 .40969 Mtetra
.858 .769 .763 r
.69373 .40969 .6989 .41716 .70918 .40249 .70407 .39552 Mtetra
.863 .782 .77 r
.70407 .39552 .70918 .40249 .71944 .3882 .7144 .38163 Mtetra
.866 .793 .777 r
.7144 .38163 .71944 .3882 .7297 .37433 .72473 .36807 Mtetra
.866 .803 .786 r
.72473 .36807 .7297 .37433 .73996 .361 .73505 .35497 Mtetra
.863 .81 .797 r
.73505 .35497 .73996 .361 .75025 .34836 .7454 .34253 Mtetra
.856 .817 .81 r
.7454 .34253 .75025 .34836 .76058 .33654 .75579 .33089 Mtetra
.848 .824 .824 r
.75579 .33089 .76058 .33654 .77095 .32549 .76622 .32005 Mtetra
.845 .832 .834 r
.76622 .32005 .77095 .32549 .78135 .31482 .77668 .30962 Mtetra
.821 .84 .862 r
.77668 .30962 .78135 .31482 .79201 .3074 .78725 .30066 Mtetra
.664 .741 .908 r
.78725 .30066 .79201 .3074 .80302 .30376 .7983 .29698 Mtetra
.7983 .29698 .80302 .30376 .81408 .30009 .80938 .2933 Mtetra
.80938 .2933 .81408 .30009 .82518 .29642 .82051 .28959 Mtetra
.82051 .28959 .82518 .29642 .83632 .29273 .83169 .28588 Mtetra
.83169 .28588 .83632 .29273 .8475 .28902 .8429 .28214 Mtetra
.8429 .28214 .8475 .28902 .85873 .2853 .85416 .2784 Mtetra
.85416 .2784 .85873 .2853 .87 .28157 .86546 .27464 Mtetra
.25989 .46848 .26592 .4741 .27506 .47106 .26904 .46543 Mtetra
.26904 .46543 .27506 .47106 .28422 .46801 .27823 .46236 Mtetra
.27823 .46236 .28422 .46801 .29342 .46495 .28744 .45928 Mtetra
.28744 .45928 .29342 .46495 .30265 .46188 .29669 .45619 Mtetra
.29669 .45619 .30265 .46188 .31192 .4588 .30598 .45308 Mtetra
.30598 .45308 .31192 .4588 .32121 .45571 .31529 .44997 Mtetra
.31529 .44997 .32121 .45571 .33054 .45261 .32464 .44685 Mtetra
.184 .523 .919 r
.32464 .44685 .33054 .45261 .33961 .45462 .33366 .44993 Mtetra
.075 .501 .898 r
.33366 .44993 .33961 .45462 .34867 .45806 .34274 .45309 Mtetra
.042 .468 .882 r
.34274 .45309 .34867 .45806 .35777 .46194 .35187 .45672 Mtetra
0 .402 .841 r
.35187 .45672 .35777 .46194 .36691 .4666 .36102 .46116 Mtetra
0 .337 .798 r
.36102 .46116 .36691 .4666 .37609 .47208 .37022 .46639 Mtetra
0 .292 .768 r
.37022 .46639 .37609 .47208 .38533 .47821 .37947 .47224 Mtetra
0 .27 .755 r
.37947 .47224 .38533 .47821 .39463 .48483 .3888 .47852 Mtetra
0 .266 .758 r
.3888 .47852 .39463 .48483 .40402 .4918 .3982 .48506 Mtetra
0 .271 .768 r
.3982 .48506 .40402 .4918 .41349 .49907 .40769 .4918 Mtetra
0 .277 .778 r
.40769 .4918 .41349 .49907 .42304 .50667 .41726 .49876 Mtetra
0 .278 .781 r
.41726 .49876 .42304 .50667 .43268 .51472 .42692 .50606 Mtetra
0 .269 .776 r
.42692 .50606 .43268 .51472 .44241 .52337 .43667 .51385 Mtetra
0 .252 .763 r
.43667 .51385 .44241 .52337 .45224 .53277 .4465 .52232 Mtetra
0 .23 .745 r
.4465 .52232 .45224 .53277 .46216 .54307 .45643 .53164 Mtetra
0 .206 .726 r
.45643 .53164 .46216 .54307 .47218 .55435 .46645 .54192 Mtetra
0 .184 .708 r
.46645 .54192 .47218 .55435 .48232 .56656 .47658 .55319 Mtetra
0 .169 .694 r
.47658 .55319 .48232 .56656 .49258 .57954 .48683 .56535 Mtetra
0 .165 .687 r
.48683 .56535 .49258 .57954 .50298 .59294 .4972 .57815 Mtetra
.009 .176 .69 r
.4972 .57815 .50298 .59294 .51424 .39149 .50772 .59109 Mtetra
0 0 .305 r
.50772 .59109 .51424 .39149 .52426 .38816 .5188 .38197 Mtetra
.664 .741 .908 r
.5188 .38197 .52426 .38816 .53432 .38481 .52888 .3786 Mtetra
.52888 .3786 .53432 .38481 .54441 .38145 .539 .37522 Mtetra
.539 .37522 .54441 .38145 .55454 .37808 .54916 .37182 Mtetra
.54916 .37182 .55454 .37808 .56471 .3747 .55935 .36842 Mtetra
.55935 .36842 .56471 .3747 .57492 .3713 .56958 .365 Mtetra
.968 .666 .398 r
.56958 .365 .57492 .3713 .58516 .36789 .58343 .56863 Mtetra
.512 .289 .513 r
.58343 .56863 .58516 .36789 .59987 .5642 .59408 .54912 Mtetra
.812 .653 .686 r
.59408 .54912 .59987 .5642 .61042 .54424 .60467 .5297 Mtetra
.813 .658 .69 r
.60467 .5297 .61042 .54424 .62092 .52462 .61522 .51086 Mtetra
.814 .665 .697 r
.61522 .51086 .62092 .52462 .63137 .50573 .62573 .49286 Mtetra
.816 .674 .706 r
.62573 .49286 .63137 .50573 .6418 .48774 .63622 .47582 Mtetra
.819 .686 .717 r
.63622 .47582 .6418 .48774 .65221 .47069 .64669 .45971 Mtetra
.823 .699 .728 r
.64669 .45971 .65221 .47069 .6626 .4545 .65716 .44443 Mtetra
.828 .714 .739 r
.65716 .44443 .6626 .4545 .67299 .43904 .66762 .42979 Mtetra
.834 .729 .749 r
.66762 .42979 .67299 .43904 .68337 .42416 .67806 .41562 Mtetra
.841 .745 .758 r
.67806 .41562 .68337 .42416 .69373 .40969 .6885 .40176 Mtetra
.847 .759 .765 r
.6885 .40176 .69373 .40969 .70407 .39552 .69891 .38809 Mtetra
.853 .771 .771 r
.69891 .38809 .70407 .39552 .7144 .38163 .70931 .37459 Mtetra
.857 .782 .777 r
.70931 .37459 .7144 .38163 .72473 .36807 .71969 .36134 Mtetra
.857 .791 .785 r
.71969 .36134 .72473 .36807 .73505 .35497 .73008 .34848 Mtetra
.854 .798 .795 r
.73008 .34848 .73505 .35497 .7454 .34253 .74048 .33624 Mtetra
.847 .804 .809 r
.74048 .33624 .7454 .34253 .75579 .33089 .75093 .3248 Mtetra
.839 .811 .823 r
.75093 .3248 .75579 .33089 .76622 .32005 .76142 .31416 Mtetra
.835 .818 .833 r
.76142 .31416 .76622 .32005 .77668 .30962 .77194 .30398 Mtetra
.837 .827 .838 r
.77194 .30398 .77668 .30962 .78725 .30066 .78246 .29386 Mtetra
.664 .741 .908 r
.78246 .29386 .78725 .30066 .7983 .29698 .79354 .29016 Mtetra
.79354 .29016 .7983 .29698 .80938 .2933 .80466 .28645 Mtetra
.80466 .28645 .80938 .2933 .82051 .28959 .81582 .28272 Mtetra
.81582 .28272 .82051 .28959 .83169 .28588 .82702 .27898 Mtetra
.82702 .27898 .83169 .28588 .8429 .28214 .83826 .27522 Mtetra
.83826 .27522 .8429 .28214 .85416 .2784 .84955 .27145 Mtetra
.84955 .27145 .85416 .2784 .86546 .27464 .86089 .26766 Mtetra
.25381 .46283 .25989 .46848 .26904 .46543 .26299 .45975 Mtetra
.26299 .45975 .26904 .46543 .27823 .46236 .27219 .45666 Mtetra
.27219 .45666 .27823 .46236 .28744 .45928 .28143 .45356 Mtetra
.28143 .45356 .28744 .45928 .29669 .45619 .2907 .45045 Mtetra
.2907 .45045 .29669 .45619 .30598 .45308 .3 .44733 Mtetra
.3 .44733 .30598 .45308 .31529 .44997 .30934 .4442 Mtetra
.647 .737 .915 r
.30934 .4442 .31529 .44997 .32464 .44685 .31868 .44145 Mtetra
.107 .493 .902 r
.31868 .44145 .32464 .44685 .33366 .44993 .32769 .44485 Mtetra
.146 .531 .92 r
.32769 .44485 .33366 .44993 .34274 .45309 .33679 .44774 Mtetra
.111 .498 .904 r
.33679 .44774 .34274 .45309 .35187 .45672 .34594 .45111 Mtetra
.031 .435 .869 r
.34594 .45111 .35187 .45672 .36102 .46116 .35512 .4553 Mtetra
0 .375 .832 r
.35512 .4553 .36102 .46116 .37022 .46639 .36433 .46028 Mtetra
0 .334 .807 r
.36433 .46028 .37022 .46639 .37947 .47224 .3736 .46585 Mtetra
0 .316 .797 r
.3736 .46585 .37947 .47224 .3888 .47852 .38294 .47178 Mtetra
0 .316 .801 r
.38294 .47178 .3888 .47852 .3982 .48506 .39236 .4779 Mtetra
0 .325 .81 r
.39236 .4779 .3982 .48506 .40769 .4918 .40186 .48413 Mtetra
0 .334 .817 r
.40186 .48413 .40769 .4918 .41726 .49876 .41146 .49047 Mtetra
.031 .336 .817 r
.41146 .49047 .41726 .49876 .42692 .50606 .42114 .49703 Mtetra
.054 .328 .809 r
.42114 .49703 .42692 .50606 .43667 .51385 .4309 .50397 Mtetra
.065 .312 .795 r
.4309 .50397 .43667 .51385 .4465 .52232 .44075 .51151 Mtetra
.066 .288 .776 r
.44075 .51151 .4465 .52232 .45643 .53164 .45069 .51983 Mtetra
.06 .262 .755 r
.45069 .51983 .45643 .53164 .46645 .54192 .46071 .52907 Mtetra
.052 .236 .734 r
.46071 .52907 .46645 .54192 .47658 .55319 .47083 .53933 Mtetra
.048 .216 .716 r
.47083 .53933 .47658 .55319 .48683 .56535 .48107 .55056 Mtetra
.05 .203 .703 r
.48107 .55056 .48683 .56535 .4972 .57815 .49142 .56259 Mtetra
.064 .202 .698 r
.49142 .56259 .4972 .57815 .50772 .59109 .50191 .57509 Mtetra
.096 .219 .703 r
.50191 .57509 .50772 .59109 .5188 .38197 .51254 .58741 Mtetra
0 0 .306 r
.51254 .58741 .5188 .38197 .52888 .3786 .52341 .37235 Mtetra
.664 .741 .908 r
.52341 .37235 .52888 .3786 .539 .37522 .53355 .36894 Mtetra
.53355 .36894 .539 .37522 .54916 .37182 .54373 .36553 Mtetra
.54373 .36553 .54916 .37182 .55935 .36842 .55395 .3621 Mtetra
.967 .667 .403 r
.55395 .3621 .55935 .36842 .56958 .365 .56684 .57128 Mtetra
.512 .289 .512 r
.56684 .57128 .56958 .365 .58343 .56863 .57758 .5524 Mtetra
.8 .64 .683 r
.57758 .5524 .58343 .56863 .59408 .54912 .58827 .53327 Mtetra
.801 .643 .686 r
.58827 .53327 .59408 .54912 .60467 .5297 .5989 .51455 Mtetra
.802 .648 .692 r
.5989 .51455 .60467 .5297 .61522 .51086 .60949 .49659 Mtetra
.803 .656 .7 r
.60949 .49659 .61522 .51086 .62573 .49286 .62006 .47957 Mtetra
.805 .666 .71 r
.62006 .47957 .62573 .49286 .63622 .47582 .6306 .46352 Mtetra
.808 .678 .721 r
.6306 .46352 .63622 .47582 .64669 .45971 .64114 .44838 Mtetra
.811 .691 .732 r
.64114 .44838 .64669 .45971 .65716 .44443 .65168 .43398 Mtetra
.817 .706 .743 r
.65168 .43398 .65716 .44443 .66762 .42979 .6622 .42016 Mtetra
.823 .721 .752 r
.6622 .42016 .66762 .42979 .67806 .41562 .67272 .40669 Mtetra
.83 .736 .76 r
.67272 .40669 .67806 .41562 .6885 .40176 .68321 .39341 Mtetra
.837 .749 .766 r
.68321 .39341 .6885 .40176 .69891 .38809 .69369 .38023 Mtetra
.843 .761 .772 r
.69369 .38023 .69891 .38809 .70931 .37459 .70415 .36711 Mtetra
.847 .771 .777 r
.70415 .36711 .70931 .37459 .71969 .36134 .7146 .35416 Mtetra
.848 .78 .784 r
.7146 .35416 .71969 .36134 .73008 .34848 .72504 .34155 Mtetra
.846 .787 .794 r
.72504 .34155 .73008 .34848 .74048 .33624 .7355 .32953 Mtetra
.839 .793 .807 r
.7355 .32953 .74048 .33624 .75093 .3248 .746 .31829 Mtetra
.83 .799 .822 r
.746 .31829 .75093 .3248 .76142 .31416 .75656 .30787 Mtetra
.826 .805 .832 r
.75656 .30787 .76142 .31416 .77194 .30398 .76714 .29792 Mtetra
.838 .816 .828 r
.76714 .29792 .77194 .30398 .78246 .29386 .77768 .28744 Mtetra
.679 .762 .914 r
.77768 .28744 .78246 .29386 .79354 .29016 .78875 .28329 Mtetra
.664 .741 .908 r
.78875 .28329 .79354 .29016 .80466 .28645 .79989 .27955 Mtetra
.79989 .27955 .80466 .28645 .81582 .28272 .81108 .2758 Mtetra
.81108 .2758 .81582 .28272 .82702 .27898 .82232 .27203 Mtetra
.82232 .27203 .82702 .27898 .83826 .27522 .83359 .26824 Mtetra
.83359 .26824 .83826 .27522 .84955 .27145 .84492 .26444 Mtetra
.84492 .26444 .84955 .27145 .86089 .26766 .85628 .26063 Mtetra
.2477 .45714 .25381 .46283 .26299 .45975 .25689 .45404 Mtetra
.25689 .45404 .26299 .45975 .27219 .45666 .26612 .45093 Mtetra
.26612 .45093 .27219 .45666 .28143 .45356 .27537 .44781 Mtetra
.27537 .44781 .28143 .45356 .2907 .45045 .28466 .44468 Mtetra
.28466 .44468 .2907 .45045 .3 .44733 .29398 .44154 Mtetra
.29398 .44154 .3 .44733 .30934 .4442 .30334 .43838 Mtetra
.617 .728 .925 r
.30334 .43838 .30934 .4442 .31868 .44145 .31266 .43626 Mtetra
.117 .509 .909 r
.31266 .43626 .31868 .44145 .32769 .44485 .32169 .4394 Mtetra
.207 .554 .933 r
.32169 .4394 .32769 .44485 .33679 .44774 .33082 .44203 Mtetra
.171 .521 .918 r
.33082 .44203 .33679 .44774 .34594 .45111 .33999 .44514 Mtetra
.095 .463 .889 r
.33999 .44514 .34594 .45111 .35512 .4553 .34919 .44907 Mtetra
.026 .407 .857 r
.34919 .44907 .35512 .4553 .36433 .46028 .35842 .45377 Mtetra
0 .37 .836 r
.35842 .45377 .36433 .46028 .3736 .46585 .36771 .45904 Mtetra
0 .356 .828 r
.36771 .45904 .3736 .46585 .38294 .47178 .37706 .46463 Mtetra
.005 .358 .831 r
.37706 .46463 .38294 .47178 .39236 .4779 .3865 .47034 Mtetra
.043 .37 .838 r
.3865 .47034 .39236 .4779 .40186 .48413 .39602 .47607 Mtetra
.085 .38 .842 r
.39602 .47607 .40186 .48413 .41146 .49047 .40564 .48181 Mtetra
.12 .383 .84 r
.40564 .48181 .41146 .49047 .42114 .49703 .41534 .48766 Mtetra
.143 .377 .831 r
.41534 .48766 .42114 .49703 .4309 .50397 .42512 .49379 Mtetra
.153 .361 .816 r
.42512 .49379 .4309 .50397 .44075 .51151 .43498 .50041 Mtetra
.152 .338 .796 r
.43498 .50041 .44075 .51151 .45069 .51983 .44493 .50773 Mtetra
.143 .311 .775 r
.44493 .50773 .45069 .51983 .46071 .52907 .45496 .51592 Mtetra
.131 .284 .753 r
.45496 .51592 .46071 .52907 .47083 .53933 .46508 .52509 Mtetra
.121 .259 .733 r
.46508 .52509 .47083 .53933 .48107 .55056 .4753 .53528 Mtetra
.117 .241 .717 r
.4753 .53528 .48107 .55056 .49142 .56259 .48564 .54639 Mtetra
.12 .232 .706 r
.48564 .54639 .49142 .56259 .50191 .57509 .4961 .55821 Mtetra
.135 .234 .703 r
.4961 .55821 .50191 .57509 .51254 .58741 .50669 .5703 Mtetra
.17 .256 .711 r
.50669 .5703 .51254 .58741 .52341 .37235 .51743 .58188 Mtetra
0 0 .306 r
.51743 .58188 .52341 .37235 .53355 .36894 .52807 .36262 Mtetra
.664 .741 .908 r
.52807 .36262 .53355 .36894 .54373 .36553 .53827 .35918 Mtetra
.967 .668 .408 r
.53827 .35918 .54373 .36553 .55395 .3621 .55013 .57214 Mtetra
.513 .288 .511 r
.55013 .57214 .55395 .3621 .56684 .57128 .56095 .554 Mtetra
.79 .628 .681 r
.56095 .554 .56684 .57128 .57758 .5524 .57172 .53527 Mtetra
.79 .629 .682 r
.57172 .53527 .57758 .5524 .58827 .53327 .58243 .51677 Mtetra
.79 .633 .687 r
.58243 .51677 .58827 .53327 .5989 .51455 .5931 .49892 Mtetra
.791 .64 .694 r
.5931 .49892 .5989 .51455 .60949 .49659 .60374 .48195 Mtetra
.792 .648 .703 r
.60374 .48195 .60949 .49659 .62006 .47957 .61436 .46596 Mtetra
.794 .659 .714 r
.61436 .46596 .62006 .47957 .6306 .46352 .62496 .45092 Mtetra
.797 .671 .725 r
.62496 .45092 .6306 .46352 .64114 .44838 .63556 .43674 Mtetra
.8 .684 .736 r
.63556 .43674 .64114 .44838 .65168 .43398 .64616 .42323 Mtetra
.805 .698 .747 r
.64616 .42323 .65168 .43398 .6622 .42016 .65675 .41018 Mtetra
.812 .713 .756 r
.65675 .41018 .6622 .42016 .67272 .40669 .66732 .39738 Mtetra
.82 .727 .763 r
.66732 .39738 .67272 .40669 .68321 .39341 .67788 .38467 Mtetra
.827 .74 .768 r
.67788 .38467 .68321 .39341 .69369 .38023 .68842 .37194 Mtetra
.834 .752 .772 r
.68842 .37194 .69369 .38023 .70415 .36711 .69894 .3592 Mtetra
.839 .761 .777 r
.69894 .3592 .70415 .36711 .7146 .35416 .70944 .34655 Mtetra
.84 .769 .784 r
.70944 .34655 .7146 .35416 .72504 .34155 .71995 .3342 Mtetra
.837 .776 .794 r
.71995 .3342 .72504 .34155 .7355 .32953 .73046 .32241 Mtetra
.83 .782 .806 r
.73046 .32241 .7355 .32953 .746 .31829 .74102 .31139 Mtetra
.821 .788 .82 r
.74102 .31139 .746 .31829 .75656 .30787 .75163 .3012 Mtetra
.817 .794 .831 r
.75163 .3012 .75656 .30787 .76714 .29792 .76227 .29148 Mtetra
.83 .804 .827 r
.76227 .29148 .76714 .29792 .77768 .28744 .77287 .28121 Mtetra
.702 .779 .911 r
.77287 .28121 .77768 .28744 .78875 .28329 .78392 .27638 Mtetra
.664 .741 .908 r
.78392 .27638 .78875 .28329 .79989 .27955 .7951 .27261 Mtetra
.7951 .27261 .79989 .27955 .81108 .2758 .80632 .26883 Mtetra
.80632 .26883 .81108 .2758 .82232 .27203 .81758 .26503 Mtetra
.81758 .26503 .82232 .27203 .83359 .26824 .82889 .26122 Mtetra
.82889 .26122 .83359 .26824 .84492 .26444 .84024 .25739 Mtetra
.84024 .25739 .84492 .26444 .85628 .26063 .85164 .25355 Mtetra
.24155 .45141 .2477 .45714 .25689 .45404 .25076 .44829 Mtetra
.25076 .44829 .25689 .45404 .26612 .45093 .26 .44516 Mtetra
.26 .44516 .26612 .45093 .27537 .44781 .26928 .44202 Mtetra
.26928 .44202 .27537 .44781 .28466 .44468 .27859 .43887 Mtetra
.27859 .43887 .28466 .44468 .29398 .44154 .28793 .4357 Mtetra
.28793 .4357 .29398 .44154 .30334 .43838 .2973 .43253 Mtetra
.602 .723 .93 r
.2973 .43253 .30334 .43838 .31266 .43626 .30662 .43069 Mtetra
.174 .53 .922 r
.30662 .43069 .31266 .43626 .32169 .4394 .31568 .43362 Mtetra
.258 .57 .939 r
.31568 .43362 .32169 .4394 .33082 .44203 .32483 .436 Mtetra
.224 .541 .926 r
.32483 .436 .33082 .44203 .33999 .44514 .33402 .43883 Mtetra
.153 .487 .902 r
.33402 .43883 .33999 .44514 .34919 .44907 .34324 .44248 Mtetra
.089 .436 .875 r
.34324 .44248 .34919 .44907 .35842 .45377 .35249 .44689 Mtetra
.054 .402 .857 r
.35249 .44689 .35842 .45377 .36771 .45904 .36179 .45184 Mtetra
.052 .389 .85 r
.36179 .45184 .36771 .45904 .37706 .46463 .37117 .45708 Mtetra
.077 .394 .852 r
.37117 .45708 .37706 .46463 .3865 .47034 .38062 .46239 Mtetra
.117 .405 .856 r
.38062 .46239 .3865 .47034 .39602 .47607 .39016 .46763 Mtetra
.16 .416 .857 r
.39016 .46763 .39602 .47607 .40564 .48181 .3998 .47281 Mtetra
.195 .421 .853 r
.3998 .47281 .40564 .48181 .41534 .48766 .40952 .47799 Mtetra
.218 .416 .843 r
.40952 .47799 .41534 .48766 .42512 .49379 .41932 .48334 Mtetra
.227 .402 .828 r
.41932 .48334 .42512 .49379 .43498 .50041 .4292 .48908 Mtetra
.226 .381 .81 r
.4292 .48908 .43498 .50041 .44493 .50773 .43916 .49541 Mtetra
.216 .354 .789 r
.43916 .49541 .44493 .50773 .45496 .51592 .4492 .50253 Mtetra
.203 .327 .768 r
.4492 .50253 .45496 .51592 .46508 .52509 .45932 .5106 Mtetra
.19 .3 .748 r
.45932 .5106 .46508 .52509 .4753 .53528 .46954 .51966 Mtetra
.181 .279 .73 r
.46954 .51966 .4753 .53528 .48564 .54639 .47986 .52968 Mtetra
.179 .265 .716 r
.47986 .52968 .48564 .54639 .4961 .55821 .49029 .54053 Mtetra
.185 .258 .706 r
.49029 .54053 .4961 .55821 .50669 .5703 .50085 .55195 Mtetra
.2 .262 .703 r
.50085 .55195 .50669 .5703 .51743 .58188 .51155 .56355 Mtetra
.23 .284 .712 r
.51155 .56355 .51743 .58188 .52807 .36262 .52239 .57445 Mtetra
.537 .307 .514 r
.52239 .57445 .52807 .36262 .53827 .35918 .53332 .57118 Mtetra
.512 .287 .51 r
.53332 .57118 .53827 .35918 .55013 .57214 .54421 .5537 Mtetra
.778 .616 .679 r
.54421 .5537 .55013 .57214 .56095 .554 .55506 .53546 Mtetra
.777 .614 .678 r
.55506 .53546 .56095 .554 .57172 .53527 .56584 .51734 Mtetra
.778 .618 .682 r
.56584 .51734 .57172 .53527 .58243 .51677 .57659 .49975 Mtetra
.779 .624 .688 r
.57659 .49975 .58243 .51677 .5931 .49892 .58729 .48293 Mtetra
.78 .632 .697 r
.58729 .48293 .5931 .49892 .60374 .48195 .59797 .46704 Mtetra
.782 .641 .707 r
.59797 .46704 .60374 .48195 .61436 .46596 .60864 .45212 Mtetra
.783 .652 .718 r
.60864 .45212 .61436 .46596 .62496 .45092 .6193 .4381 Mtetra
.786 .664 .729 r
.6193 .4381 .62496 .45092 .63556 .43674 .62995 .42486 Mtetra
.789 .677 .741 r
.62995 .42486 .63556 .43674 .64616 .42323 .6406 .41219 Mtetra
.795 .691 .75 r
.6406 .41219 .64616 .42323 .65675 .41018 .65125 .39988 Mtetra
.802 .705 .759 r
.65125 .39988 .65675 .41018 .66732 .39738 .66189 .38772 Mtetra
.81 .719 .765 r
.66189 .38772 .66732 .39738 .67788 .38467 .67251 .37553 Mtetra
.818 .731 .769 r
.67251 .37553 .67788 .38467 .68842 .37194 .6831 .36325 Mtetra
.825 .742 .773 r
.6831 .36325 .68842 .37194 .69894 .3592 .69368 .35087 Mtetra
.83 .752 .777 r
.69368 .35087 .69894 .3592 .70944 .34655 .70424 .33853 Mtetra
.831 .76 .784 r
.70424 .33853 .70944 .34655 .71995 .3342 .7148 .32646 Mtetra
.829 .766 .793 r
.7148 .32646 .71995 .3342 .73046 .32241 .72537 .31492 Mtetra
.822 .772 .806 r
.72537 .31492 .73046 .32241 .74102 .31139 .73599 .30415 Mtetra
.813 .777 .82 r
.73599 .30415 .74102 .31139 .75163 .3012 .74665 .29419 Mtetra
.809 .784 .83 r
.74665 .29419 .75163 .3012 .76227 .29148 .75735 .28468 Mtetra
.822 .794 .825 r
.75735 .28468 .76227 .29148 .77287 .28121 .768 .27459 Mtetra
.711 .77 .899 r
.768 .27459 .77287 .28121 .78392 .27638 .77906 .26941 Mtetra
.664 .741 .908 r
.77906 .26941 .78392 .27638 .7951 .27261 .79026 .26561 Mtetra
.79026 .26561 .7951 .27261 .80632 .26883 .80152 .2618 Mtetra
.80152 .2618 .80632 .26883 .81758 .26503 .81281 .25798 Mtetra
.81281 .25798 .81758 .26503 .82889 .26122 .82415 .25414 Mtetra
.82415 .25414 .82889 .26122 .84024 .25739 .83554 .25028 Mtetra
.83554 .25028 .84024 .25739 .85164 .25355 .84697 .24641 Mtetra
.23536 .44564 .24155 .45141 .25076 .44829 .24459 .4425 Mtetra
.24459 .4425 .25076 .44829 .26 .44516 .25385 .43935 Mtetra
.25385 .43935 .26 .44516 .26928 .44202 .26314 .43619 Mtetra
.26314 .43619 .26928 .44202 .27859 .43887 .27247 .43302 Mtetra
.27247 .43302 .27859 .43887 .28793 .4357 .28183 .42984 Mtetra
.28183 .42984 .28793 .4357 .2973 .43253 .29123 .42664 Mtetra
.603 .723 .93 r
.29123 .42664 .2973 .43253 .30662 .43069 .30057 .42477 Mtetra
.218 .542 .927 r
.30057 .42477 .30662 .43069 .31568 .43362 .30964 .42753 Mtetra
.3 .582 .94 r
.30964 .42753 .31568 .43362 .32483 .436 .31881 .42966 Mtetra
.271 .556 .93 r
.31881 .42966 .32483 .436 .33402 .43883 .32803 .43221 Mtetra
.206 .508 .91 r
.32803 .43221 .33402 .43883 .34324 .44248 .33727 .43555 Mtetra
.147 .461 .888 r
.33727 .43555 .34324 .44248 .35249 .44689 .34654 .43965 Mtetra
.115 .43 .871 r
.34654 .43965 .35249 .44689 .36179 .45184 .35586 .44427 Mtetra
.116 .418 .864 r
.35586 .44427 .36179 .45184 .37117 .45708 .36525 .44915 Mtetra
.142 .422 .864 r
.36525 .44915 .37117 .45708 .38062 .46239 .37472 .45406 Mtetra
.181 .434 .866 r
.37472 .45406 .38062 .46239 .39016 .46763 .38429 .45885 Mtetra
.223 .445 .865 r
.38429 .45885 .39016 .46763 .3998 .47281 .39394 .46348 Mtetra
.257 .45 .859 r
.39394 .46348 .3998 .47281 .40952 .47799 .40368 .46804 Mtetra
.28 .447 .849 r
.40368 .46804 .40952 .47799 .41932 .48334 .4135 .47266 Mtetra
.29 .435 .835 r
.4135 .47266 .41932 .48334 .4292 .48908 .4234 .47755 Mtetra
.289 .416 .818 r
.4234 .47755 .4292 .48908 .43916 .49541 .43337 .48293 Mtetra
.279 .392 .799 r
.43337 .48293 .43916 .49541 .4492 .50253 .44342 .48901 Mtetra
.266 .365 .779 r
.44342 .48901 .4492 .50253 .45932 .5106 .45355 .49594 Mtetra
.252 .339 .759 r
.45355 .49594 .45932 .5106 .46954 .51966 .46376 .50381 Mtetra
.243 .317 .74 r
.46376 .50381 .46954 .51966 .47986 .52968 .47407 .51261 Mtetra
.24 .3 .725 r
.47407 .51261 .47986 .52968 .49029 .54053 .48449 .52223 Mtetra
.247 .292 .713 r
.48449 .52223 .49029 .54053 .50085 .55195 .49503 .53246 Mtetra
.265 .293 .705 r
.49503 .53246 .50085 .55195 .51155 .56355 .50569 .54295 Mtetra
.306 .312 .702 r
.50569 .54295 .51155 .56355 .52239 .57445 .51648 .55289 Mtetra
.609 .5 .705 r
.51648 .55289 .52239 .57445 .53332 .57118 .52739 .54958 Mtetra
.747 .583 .672 r
.52739 .54958 .53332 .57118 .54421 .5537 .53829 .53299 Mtetra
.757 .592 .673 r
.53829 .53299 .54421 .5537 .55506 .53546 .54915 .51579 Mtetra
.762 .6 .677 r
.54915 .51579 .55506 .53546 .56584 .51734 .55996 .49879 Mtetra
.765 .608 .683 r
.55996 .49879 .56584 .51734 .57659 .49975 .57073 .48236 Mtetra
.768 .616 .691 r
.57073 .48236 .57659 .49975 .58729 .48293 .58147 .46672 Mtetra
.769 .625 .701 r
.58147 .46672 .58729 .48293 .59797 .46704 .59219 .45197 Mtetra
.771 .635 .711 r
.59219 .45197 .59797 .46704 .60864 .45212 .6029 .43813 Mtetra
.772 .646 .723 r
.6029 .43813 .60864 .45212 .6193 .4381 .61361 .42512 Mtetra
.775 .658 .734 r
.61361 .42512 .6193 .4381 .62995 .42486 .62432 .41278 Mtetra
.779 .671 .745 r
.62432 .41278 .62995 .42486 .6406 .41219 .63502 .40092 Mtetra
.784 .685 .754 r
.63502 .40092 .6406 .41219 .65125 .39988 .64572 .3893 Mtetra
.792 .698 .761 r
.64572 .3893 .65125 .39988 .66189 .38772 .65641 .37772 Mtetra
.8 .711 .766 r
.65641 .37772 .66189 .38772 .67251 .37553 .66709 .36603 Mtetra
.809 .723 .77 r
.66709 .36603 .67251 .37553 .6831 .36325 .67774 .35416 Mtetra
.816 .733 .773 r
.67774 .35416 .6831 .36325 .69368 .35087 .68837 .34214 Mtetra
.821 .742 .777 r
.68837 .34214 .69368 .35087 .70424 .33853 .69898 .33012 Mtetra
.823 .75 .783 r
.69898 .33012 .70424 .33853 .7148 .32646 .70959 .31834 Mtetra
.82 .757 .793 r
.70959 .31834 .7148 .32646 .72537 .31492 .72022 .30708 Mtetra
.814 .763 .805 r
.72022 .30708 .72537 .31492 .73599 .30415 .73089 .29657 Mtetra
.805 .768 .819 r
.73089 .29657 .73599 .30415 .74665 .29419 .74161 .28685 Mtetra
.801 .775 .829 r
.74161 .28685 .74665 .29419 .75735 .28468 .75237 .27755 Mtetra
.816 .784 .823 r
.75237 .27755 .75735 .28468 .768 .27459 .76307 .26758 Mtetra
.709 .758 .891 r
.76307 .26758 .768 .27459 .77906 .26941 .77416 .26239 Mtetra
.664 .741 .908 r
.77416 .26239 .77906 .26941 .79026 .26561 .7854 .25857 Mtetra
.7854 .25857 .79026 .26561 .80152 .2618 .79668 .25473 Mtetra
.79668 .25473 .80152 .2618 .81281 .25798 .80801 .25088 Mtetra
.80801 .25088 .81281 .25798 .82415 .25414 .81938 .24701 Mtetra
.81938 .24701 .82415 .25414 .83554 .25028 .8308 .24313 Mtetra
.8308 .24313 .83554 .25028 .84697 .24641 .84226 .23923 Mtetra
.22912 .43984 .23536 .44564 .24459 .4425 .23837 .43668 Mtetra
.23837 .43668 .24459 .4425 .25385 .43935 .24765 .43351 Mtetra
.24765 .43351 .25385 .43935 .26314 .43619 .25697 .43033 Mtetra
.25697 .43033 .26314 .43619 .27247 .43302 .26632 .42713 Mtetra
.26632 .42713 .27247 .43302 .28183 .42984 .2757 .42393 Mtetra
.2757 .42393 .28183 .42984 .29123 .42664 .28511 .42071 Mtetra
.619 .729 .925 r
.28511 .42071 .29123 .42664 .30057 .42477 .29449 .41849 Mtetra
.251 .548 .928 r
.29449 .41849 .30057 .42477 .30964 .42753 .30358 .42113 Mtetra
.335 .59 .938 r
.30358 .42113 .30964 .42753 .31881 .42966 .31278 .42304 Mtetra
.313 .57 .93 r
.31278 .42304 .31881 .42966 .32803 .43221 .32202 .4253 Mtetra
.254 .527 .915 r
.32202 .4253 .32803 .43221 .33727 .43555 .33128 .42832 Mtetra
.2 .483 .896 r
.33128 .42832 .33727 .43555 .34654 .43965 .34057 .43208 Mtetra
.171 .454 .881 r
.34057 .43208 .34654 .43965 .35586 .44427 .34991 .43635 Mtetra
.173 .443 .873 r
.34991 .43635 .35586 .44427 .36525 .44915 .35932 .44086 Mtetra
.198 .446 .871 r
.35932 .44086 .36525 .44915 .37472 .45406 .36881 .44537 Mtetra
.236 .457 .87 r
.36881 .44537 .37472 .45406 .38429 .45885 .37839 .44972 Mtetra
.276 .467 .867 r
.37839 .44972 .38429 .45885 .39394 .46348 .38806 .45385 Mtetra
.309 .473 .861 r
.38806 .45385 .39394 .46348 .40368 .46804 .39782 .45782 Mtetra
.331 .472 .85 r
.39782 .45782 .40368 .46804 .4135 .47266 .40766 .46176 Mtetra
.342 .462 .837 r
.40766 .46176 .4135 .47266 .4234 .47755 .41758 .46587 Mtetra
.342 .446 .822 r
.41758 .46587 .4234 .47755 .43337 .48293 .42757 .47036 Mtetra
.334 .424 .805 r
.42757 .47036 .43337 .48293 .44342 .48901 .43763 .47542 Mtetra
.321 .399 .786 r
.43763 .47542 .44342 .48901 .45355 .49594 .44777 .48124 Mtetra
.309 .374 .768 r
.44777 .48124 .45355 .49594 .46376 .50381 .45799 .48788 Mtetra
.3 .353 .75 r
.45799 .48788 .46376 .50381 .47407 .51261 .46829 .49536 Mtetra
.299 .337 .733 r
.46829 .49536 .47407 .51261 .48449 .52223 .4787 .50356 Mtetra
.311 .331 .72 r
.4787 .50356 .48449 .52223 .49503 .53246 .48921 .51219 Mtetra
.343 .338 .709 r
.48921 .51219 .49503 .53246 .50569 .54295 .49984 .52063 Mtetra
.426 .378 .701 r
.49984 .52063 .50569 .54295 .51648 .55289 .5106 .52683 Mtetra
.6 .472 .678 r
.5106 .52683 .51648 .55289 .52739 .54958 .52148 .52348 Mtetra
.697 .534 .663 r
.52148 .52348 .52739 .54958 .53829 .53299 .53238 .51054 Mtetra
.732 .57 .671 r
.53238 .51054 .53829 .53299 .54915 .51579 .54324 .49532 Mtetra
.746 .587 .678 r
.54324 .49532 .54915 .51579 .55996 .49879 .55407 .47986 Mtetra
.752 .599 .686 r
.55407 .47986 .55996 .49879 .57073 .48236 .56487 .4648 Mtetra
.756 .609 .695 r
.56487 .4648 .57073 .48236 .58147 .46672 .57564 .45042 Mtetra
.759 .62 .705 r
.57564 .45042 .58147 .46672 .59219 .45197 .5864 .43684 Mtetra
.76 .63 .716 r
.5864 .43684 .59219 .45197 .6029 .43813 .59715 .42408 Mtetra
.762 .641 .728 r
.59715 .42408 .6029 .43813 .61361 .42512 .6079 .41203 Mtetra
.765 .653 .739 r
.6079 .41203 .61361 .42512 .62432 .41278 .61865 .40055 Mtetra
.769 .666 .749 r
.61865 .40055 .62432 .41278 .63502 .40092 .62941 .38942 Mtetra
.775 .679 .757 r
.62941 .38942 .63502 .40092 .64572 .3893 .64016 .37844 Mtetra
.782 .691 .764 r
.64016 .37844 .64572 .3893 .65641 .37772 .6509 .3674 Mtetra
.791 .704 .768 r
.6509 .3674 .65641 .37772 .66709 .36603 .66162 .35618 Mtetra
.8 .715 .771 r
.66162 .35618 .66709 .36603 .67774 .35416 .67232 .34471 Mtetra
.808 .725 .774 r
.67232 .34471 .67774 .35416 .68837 .34214 .68301 .33304 Mtetra
.813 .734 .777 r
.68301 .33304 .68837 .34214 .69898 .33012 .69367 .32135 Mtetra
.814 .741 .783 r
.69367 .32135 .69898 .33012 .70959 .31834 .70434 .30987 Mtetra
.812 .748 .793 r
.70434 .30987 .70959 .31834 .72022 .30708 .71503 .29891 Mtetra
.805 .754 .805 r
.71503 .29891 .72022 .30708 .73089 .29657 .72575 .28868 Mtetra
.797 .76 .819 r
.72575 .28868 .73089 .29657 .74161 .28685 .73653 .27922 Mtetra
.794 .766 .828 r
.73653 .27922 .74161 .28685 .75237 .27755 .74733 .2701 Mtetra
.81 .776 .821 r
.74733 .2701 .75237 .27755 .76307 .26758 .75808 .2602 Mtetra
.697 .744 .888 r
.75808 .2602 .76307 .26758 .77416 .26239 .76923 .25532 Mtetra
.664 .741 .908 r
.76923 .25532 .77416 .26239 .7854 .25857 .7805 .25147 Mtetra
.7805 .25147 .7854 .25857 .79668 .25473 .79181 .24761 Mtetra
.79181 .24761 .79668 .25473 .80801 .25088 .80317 .24372 Mtetra
.80317 .24372 .80801 .25088 .81938 .24701 .81457 .23983 Mtetra
.81457 .23983 .81938 .24701 .8308 .24313 .82602 .23592 Mtetra
.82602 .23592 .8308 .24313 .84226 .23923 .83752 .23199 Mtetra
.22285 .434 .22912 .43984 .23837 .43668 .23212 .43082 Mtetra
.23212 .43082 .23837 .43668 .24765 .43351 .24142 .42762 Mtetra
.24142 .42762 .24765 .43351 .25697 .43033 .25075 .42442 Mtetra
.25075 .42442 .25697 .43033 .26632 .42713 .26012 .42121 Mtetra
.26012 .42121 .26632 .42713 .2757 .42393 .26952 .41798 Mtetra
.26952 .41798 .2757 .42393 .28511 .42071 .27896 .41474 Mtetra
.648 .737 .914 r
.27896 .41474 .28511 .42071 .29449 .41849 .2884 .41187 Mtetra
.274 .549 .925 r
.2884 .41187 .29449 .41849 .30358 .42113 .29749 .41446 Mtetra
.364 .595 .935 r
.29749 .41446 .30358 .42113 .31278 .42304 .30671 .41616 Mtetra
.349 .58 .929 r
.30671 .41616 .31278 .42304 .32202 .4253 .31598 .41814 Mtetra
.298 .543 .916 r
.31598 .41814 .32202 .4253 .33128 .42832 .32527 .42081 Mtetra
.249 .503 .9 r
.32527 .42081 .33128 .42832 .34057 .43208 .33458 .4242 Mtetra
.223 .475 .887 r
.33458 .4242 .34057 .43208 .34991 .43635 .34394 .4281 Mtetra
.223 .464 .878 r
.34394 .4281 .34991 .43635 .35932 .44086 .35337 .43223 Mtetra
.247 .466 .874 r
.35337 .43223 .35932 .44086 .36881 .44537 .36288 .43635 Mtetra
.282 .475 .871 r
.36288 .43635 .36881 .44537 .37839 .44972 .37248 .44027 Mtetra
.319 .485 .866 r
.37248 .44027 .37839 .44972 .38806 .45385 .38217 .44393 Mtetra
.351 .491 .859 r
.38217 .44393 .38806 .45385 .39782 .45782 .39195 .44736 Mtetra
.373 .491 .849 r
.39195 .44736 .39782 .45782 .40766 .46176 .40181 .45068 Mtetra
.384 .484 .838 r
.40181 .45068 .40766 .46176 .41758 .46587 .41174 .45407 Mtetra
.386 .47 .824 r
.41174 .45407 .41758 .46587 .42757 .47036 .42175 .45772 Mtetra
.38 .451 .809 r
.42175 .45772 .42757 .47036 .43763 .47542 .43183 .46184 Mtetra
.37 .429 .792 r
.43183 .46184 .43763 .47542 .44777 .48124 .44198 .46657 Mtetra
.359 .406 .775 r
.44198 .46657 .44777 .48124 .45799 .48788 .4522 .472 Mtetra
.352 .387 .757 r
.4522 .472 .45799 .48788 .46829 .49536 .46251 .47813 Mtetra
.354 .372 .741 r
.46251 .47813 .46829 .49536 .4787 .50356 .4729 .4848 Mtetra
.371 .368 .727 r
.4729 .4848 .4787 .50356 .48921 .51219 .4834 .49164 Mtetra
.411 .38 .714 r
.4834 .49164 .48921 .51219 .49984 .52063 .49402 .49779 Mtetra
.491 .417 .7 r
.49402 .49779 .49984 .52063 .5106 .52683 .50475 .5011 Mtetra
.6 .473 .679 r
.50475 .5011 .5106 .52683 .52148 .52348 .51559 .4977 Mtetra
.673 .52 .669 r
.51559 .4977 .52148 .52348 .53238 .51054 .52647 .48758 Mtetra
.712 .555 .674 r
.52647 .48758 .53238 .51054 .54324 .49532 .53734 .47458 Mtetra
.73 .576 .682 r
.53734 .47458 .54324 .49532 .55407 .47986 .54818 .46085 Mtetra
.739 .591 .691 r
.54818 .46085 .55407 .47986 .56487 .4648 .559 .44726 Mtetra
.745 .603 .7 r
.559 .44726 .56487 .4648 .57564 .45042 .5698 .43417 Mtetra
.748 .615 .711 r
.5698 .43417 .57564 .45042 .5864 .43684 .5806 .42175 Mtetra
.75 .626 .722 r
.5806 .42175 .5864 .43684 .59715 .42408 .59138 .41002 Mtetra
.752 .637 .733 r
.59138 .41002 .59715 .42408 .6079 .41203 .60218 .39888 Mtetra
.755 .649 .744 r
.60218 .39888 .6079 .41203 .61865 .40055 .61297 .38819 Mtetra
.759 .661 .753 r
.61297 .38819 .61865 .40055 .62941 .38942 .62377 .37774 Mtetra
.766 .673 .76 r
.62377 .37774 .62941 .38942 .64016 .37844 .63456 .36733 Mtetra
.774 .685 .766 r
.63456 .36733 .64016 .37844 .6509 .3674 .64535 .35679 Mtetra
.783 .697 .769 r
.64535 .35679 .6509 .3674 .66162 .35618 .65612 .34599 Mtetra
.791 .707 .771 r
.65612 .34599 .66162 .35618 .67232 .34471 .66687 .3349 Mtetra
.799 .717 .774 r
.66687 .3349 .67232 .34471 .68301 .33304 .6776 .32359 Mtetra
.804 .726 .778 r
.6776 .32359 .68301 .33304 .69367 .32135 .68832 .31223 Mtetra
.806 .733 .784 r
.68832 .31223 .69367 .32135 .70434 .30987 .69904 .30109 Mtetra
.804 .74 .793 r
.69904 .30109 .70434 .30987 .71503 .29891 .70978 .29045 Mtetra
.797 .746 .806 r
.70978 .29045 .71503 .29891 .72575 .28868 .72056 .28053 Mtetra
.79 .752 .819 r
.72056 .28053 .72575 .28868 .73653 .27922 .73139 .27131 Mtetra
.788 .759 .826 r
.73139 .27131 .73653 .27922 .74733 .2701 .74224 .26235 Mtetra
.807 .769 .818 r
.74224 .26235 .74733 .2701 .75808 .2602 .75303 .25246 Mtetra
.675 .726 .888 r
.75303 .25246 .75808 .2602 .76923 .25532 .76426 .2482 Mtetra
.664 .741 .908 r
.76426 .2482 .76923 .25532 .7805 .25147 .77556 .24432 Mtetra
.77556 .24432 .7805 .25147 .79181 .24761 .78691 .24043 Mtetra
.78691 .24043 .79181 .24761 .80317 .24372 .7983 .23652 Mtetra
.7983 .23652 .80317 .24372 .81457 .23983 .80973 .2326 Mtetra
.80973 .2326 .81457 .23983 .82602 .23592 .82121 .22866 Mtetra
.82121 .22866 .82602 .23592 .83752 .23199 .83274 .2247 Mtetra
.21653 .42812 .22285 .434 .23212 .43082 .22582 .42491 Mtetra
.22582 .42491 .23212 .43082 .24142 .42762 .23514 .4217 Mtetra
.23514 .4217 .24142 .42762 .25075 .42442 .2445 .41848 Mtetra
.2445 .41848 .25075 .42442 .26012 .42121 .25388 .41524 Mtetra
.25388 .41524 .26012 .42121 .26952 .41798 .2633 .41199 Mtetra
.2633 .41199 .26952 .41798 .27896 .41474 .27276 .40873 Mtetra
.27276 .40873 .27896 .41474 .2884 .41187 .28225 .40546 Mtetra
.314 .581 .937 r
.28225 .40546 .2884 .41187 .29749 .41446 .29139 .40751 Mtetra
.386 .598 .93 r
.29139 .40751 .29749 .41446 .30671 .41616 .30063 .40905 Mtetra
.38 .589 .926 r
.30063 .40905 .30671 .41616 .31598 .41814 .30992 .41074 Mtetra
.337 .557 .916 r
.30992 .41074 .31598 .41814 .32527 .42081 .31923 .41306 Mtetra
.294 .521 .903 r
.31923 .41306 .32527 .42081 .33458 .4242 .32857 .41606 Mtetra
.269 .495 .89 r
.32857 .41606 .33458 .4242 .34394 .4281 .33796 .41956 Mtetra
.269 .482 .881 r
.33796 .41956 .34394 .4281 .35337 .43223 .34741 .4233 Mtetra
.289 .482 .875 r
.34741 .4233 .35337 .43223 .36288 .43635 .35693 .42701 Mtetra
.321 .49 .87 r
.35693 .42701 .36288 .43635 .37248 .44027 .36655 .43052 Mtetra
.355 .498 .864 r
.36655 .43052 .37248 .44027 .38217 .44393 .37626 .43374 Mtetra
.385 .505 .856 r
.37626 .43374 .38217 .44393 .39195 .44736 .38605 .43669 Mtetra
.407 .506 .847 r
.38605 .43669 .39195 .44736 .40181 .45068 .39593 .43945 Mtetra
.419 .501 .836 r
.39593 .43945 .40181 .45068 .41174 .45407 .40589 .44218 Mtetra
.423 .49 .824 r
.40589 .44218 .41174 .45407 .42175 .45772 .41592 .44507 Mtetra
.419 .474 .811 r
.41592 .44507 .42175 .45772 .43183 .46184 .42601 .4483 Mtetra
.411 .455 .796 r
.42601 .4483 .43183 .46184 .44198 .46657 .43617 .45202 Mtetra
.403 .435 .78 r
.43617 .45202 .44198 .46657 .4522 .472 .4464 .45629 Mtetra
.398 .418 .764 r
.4464 .45629 .4522 .472 .46251 .47813 .45671 .46109 Mtetra
.402 .405 .748 r
.45671 .46109 .46251 .47813 .4729 .4848 .46711 .46625 Mtetra
.421 .402 .733 r
.46711 .46625 .4729 .4848 .4834 .49164 .4776 .47132 Mtetra
.461 .413 .718 r
.4776 .47132 .4834 .49164 .49402 .49779 .48821 .47541 Mtetra
.527 .442 .703 r
.48821 .47541 .49402 .49779 .50475 .5011 .49892 .47679 Mtetra
.603 .48 .686 r
.49892 .47679 .50475 .5011 .51559 .4977 .50973 .47335 Mtetra
.66 .517 .678 r
.50973 .47335 .51559 .4977 .52647 .48758 .52059 .46508 Mtetra
.696 .547 .681 r
.52059 .46508 .52647 .48758 .53734 .47458 .53145 .45407 Mtetra
.716 .569 .688 r
.53145 .45407 .53734 .47458 .54818 .46085 .5423 .44205 Mtetra
.727 .586 .697 r
.5423 .44205 .54818 .46085 .559 .44726 .55314 .42991 Mtetra
.734 .599 .706 r
.55314 .42991 .559 .44726 .5698 .43417 .56396 .41809 Mtetra
.738 .611 .717 r
.56396 .41809 .5698 .43417 .5806 .42175 .57478 .40679 Mtetra
.74 .623 .728 r
.57478 .40679 .5806 .42175 .59138 .41002 .58561 .39602 Mtetra
.743 .634 .739 r
.58561 .39602 .59138 .41002 .60218 .39888 .59643 .38571 Mtetra
.746 .645 .749 r
.59643 .38571 .60218 .39888 .61297 .38819 .60726 .37573 Mtetra
.751 .657 .757 r
.60726 .37573 .61297 .38819 .62377 .37774 .6181 .36589 Mtetra
.757 .668 .763 r
.6181 .36589 .62377 .37774 .63456 .36733 .62893 .356 Mtetra
.765 .679 .767 r
.62893 .356 .63456 .36733 .64535 .35679 .63976 .3459 Mtetra
.775 .69 .77 r
.63976 .3459 .64535 .35679 .65612 .34599 .65057 .33549 Mtetra
.783 .7 .772 r
.65057 .33549 .65612 .34599 .66687 .3349 .66137 .32477 Mtetra
.791 .709 .774 r
.66137 .32477 .66687 .3349 .6776 .32359 .67215 .31381 Mtetra
.796 .718 .778 r
.67215 .31381 .6776 .32359 .68832 .31223 .68292 .30281 Mtetra
.798 .726 .785 r
.68292 .30281 .68832 .31223 .69904 .30109 .6937 .29202 Mtetra
.795 .733 .794 r
.6937 .29202 .69904 .30109 .70978 .29045 .70449 .28173 Mtetra
.789 .739 .807 r
.70449 .28173 .70978 .29045 .72056 .28053 .71533 .27212 Mtetra
.782 .745 .819 r
.71533 .27212 .72056 .28053 .73139 .27131 .72621 .26314 Mtetra
.783 .752 .825 r
.72621 .26314 .73139 .27131 .74224 .26235 .7371 .25431 Mtetra
.795 .759 .821 r
.7371 .25431 .74224 .26235 .75303 .25246 .74797 .24492 Mtetra
.663 .729 .898 r
.74797 .24492 .75303 .25246 .76426 .2482 .75925 .24103 Mtetra
.664 .741 .908 r
.75925 .24103 .76426 .2482 .77556 .24432 .77059 .23712 Mtetra
.77059 .23712 .77556 .24432 .78691 .24043 .78196 .2332 Mtetra
.78196 .2332 .78691 .24043 .7983 .23652 .79339 .22926 Mtetra
.79339 .22926 .7983 .23652 .80973 .2326 .80486 .22531 Mtetra
.80486 .22531 .80973 .2326 .82121 .22866 .81637 .22134 Mtetra
.81637 .22134 .82121 .22866 .83274 .2247 .82793 .21736 Mtetra
.21018 .4222 .21653 .42812 .22582 .42491 .21948 .41897 Mtetra
.21948 .41897 .22582 .42491 .23514 .4217 .22882 .41574 Mtetra
.22882 .41574 .23514 .4217 .2445 .41848 .2382 .41249 Mtetra
.2382 .41249 .2445 .41848 .25388 .41524 .2476 .40924 Mtetra
.2476 .40924 .25388 .41524 .2633 .41199 .25705 .40597 Mtetra
.25705 .40597 .2633 .41199 .27276 .40873 .26652 .40268 Mtetra
.26652 .40268 .27276 .40873 .28225 .40546 .27603 .39939 Mtetra
.404 .641 .953 r
.27603 .39939 .28225 .40546 .29139 .40751 .28526 .4003 Mtetra
.402 .598 .925 r
.28526 .4003 .29139 .40751 .30063 .40905 .29452 .40172 Mtetra
.406 .596 .922 r
.29452 .40172 .30063 .40905 .30992 .41074 .30383 .40313 Mtetra
.372 .57 .915 r
.30383 .40313 .30992 .41074 .31923 .41306 .31318 .40509 Mtetra
.334 .538 .903 r
.31318 .40509 .31923 .41306 .32857 .41606 .32254 .40769 Mtetra
.311 .512 .891 r
.32254 .40769 .32857 .41606 .33796 .41956 .33195 .41077 Mtetra
.31 .499 .881 r
.33195 .41077 .33796 .41956 .34741 .4233 .34142 .41409 Mtetra
.327 .497 .874 r
.34142 .41409 .34741 .4233 .35693 .42701 .35097 .4174 Mtetra
.355 .502 .867 r
.35097 .4174 .35693 .42701 .36655 .43052 .36061 .42051 Mtetra
.386 .51 .861 r
.36061 .42051 .36655 .43052 .37626 .43374 .37033 .42332 Mtetra
.413 .515 .853 r
.37033 .42332 .37626 .43374 .38605 .43669 .38014 .42582 Mtetra
.434 .517 .844 r
.38014 .42582 .38605 .43669 .39593 .43945 .39004 .42808 Mtetra
.447 .514 .835 r
.39004 .42808 .39593 .43945 .40589 .44218 .40001 .43023 Mtetra
.452 .506 .824 r
.40001 .43023 .40589 .44218 .41592 .44507 .41006 .43244 Mtetra
.451 .494 .812 r
.41006 .43244 .41592 .44507 .42601 .4483 .42017 .43487 Mtetra
.446 .478 .799 r
.42017 .43487 .42601 .4483 .43617 .45202 .43035 .43766 Mtetra
.44 .461 .785 r
.43035 .43766 .43617 .45202 .4464 .45629 .44059 .44085 Mtetra
.438 .446 .77 r
.44059 .44085 .4464 .45629 .45671 .46109 .45091 .44442 Mtetra
.444 .435 .755 r
.45091 .44442 .45671 .46109 .46711 .46625 .46131 .44815 Mtetra
.462 .432 .739 r
.46131 .44815 .46711 .46625 .4776 .47132 .4718 .45162 Mtetra
.498 .441 .724 r
.4718 .45162 .4776 .47132 .48821 .47541 .48239 .45402 Mtetra
.549 .462 .709 r
.48239 .45402 .48821 .47541 .49892 .47679 .49309 .45409 Mtetra
.606 .49 .695 r
.49309 .45409 .49892 .47679 .50973 .47335 .50387 .45061 Mtetra
.652 .519 .688 r
.50387 .45061 .50973 .47335 .52059 .46508 .51471 .44358 Mtetra
.684 .545 .69 r
.51471 .44358 .52059 .46508 .53145 .45407 .52557 .43419 Mtetra
.704 .566 .696 r
.52557 .43419 .53145 .45407 .5423 .44205 .53642 .4237 Mtetra
.716 .583 .704 r
.53642 .4237 .5423 .44205 .55314 .42991 .54727 .41292 Mtetra
.724 .597 .714 r
.54727 .41292 .55314 .42991 .56396 .41809 .55812 .40229 Mtetra
.728 .609 .724 r
.55812 .40229 .56396 .41809 .57478 .40679 .56896 .39201 Mtetra
.731 .62 .735 r
.56896 .39201 .57478 .40679 .58561 .39602 .57981 .38212 Mtetra
.734 .631 .745 r
.57981 .38212 .58561 .39602 .59643 .38571 .59067 .37256 Mtetra
.738 .642 .753 r
.59067 .37256 .59643 .38571 .60726 .37573 .60154 .36321 Mtetra
.743 .653 .76 r
.60154 .36321 .60726 .37573 .6181 .36589 .61241 .3539 Mtetra
.75 .664 .766 r
.61241 .3539 .6181 .36589 .62893 .356 .62328 .34446 Mtetra
.758 .674 .769 r
.62328 .34446 .62893 .356 .63976 .3459 .63414 .33476 Mtetra
.767 .684 .771 r
.63414 .33476 .63976 .3459 .65057 .33549 .645 .32472 Mtetra
.776 .694 .773 r
.645 .32472 .65057 .33549 .66137 .32477 .65584 .31435 Mtetra
.783 .703 .775 r
.65584 .31435 .66137 .32477 .67215 .31381 .66666 .30375 Mtetra
.788 .711 .779 r
.66666 .30375 .67215 .31381 .68292 .30281 .67748 .29312 Mtetra
.79 .719 .786 r
.67748 .29312 .68292 .30281 .6937 .29202 .68831 .28271 Mtetra
.787 .726 .796 r
.68831 .28271 .6937 .29202 .70449 .28173 .69916 .27278 Mtetra
.781 .733 .808 r
.69916 .27278 .70449 .28173 .71533 .27212 .71005 .26349 Mtetra
.776 .739 .82 r
.71005 .26349 .71533 .27212 .72621 .26314 .72098 .25475 Mtetra
.779 .747 .824 r
.72098 .25475 .72621 .26314 .7371 .25431 .73191 .24598 Mtetra
.77 .747 .831 r
.73191 .24598 .7371 .25431 .74797 .24492 .74289 .23772 Mtetra
.664 .741 .908 r
.74289 .23772 .74797 .24492 .75925 .24103 .75421 .2338 Mtetra
.75421 .2338 .75925 .24103 .77059 .23712 .76558 .22987 Mtetra
.76558 .22987 .77059 .23712 .78196 .2332 .77699 .22592 Mtetra
.77699 .22592 .78196 .2332 .79339 .22926 .78844 .22195 Mtetra
.78844 .22195 .79339 .22926 .80486 .22531 .79994 .21797 Mtetra
.79994 .21797 .80486 .22531 .81637 .22134 .81149 .21397 Mtetra
.81149 .21397 .81637 .22134 .82793 .21736 .82308 .20996 Mtetra
.20378 .41624 .21018 .4222 .21948 .41897 .2131 .41299 Mtetra
.2131 .41299 .21948 .41897 .22882 .41574 .22246 .40974 Mtetra
.22246 .40974 .22882 .41574 .2382 .41249 .23186 .40647 Mtetra
.23186 .40647 .2382 .41249 .2476 .40924 .24128 .40319 Mtetra
.24128 .40319 .2476 .40924 .25705 .40597 .25075 .3999 Mtetra
.25075 .3999 .25705 .40597 .26652 .40268 .26024 .3966 Mtetra
.26024 .3966 .26652 .40268 .27603 .39939 .26977 .39328 Mtetra
.51 .689 .948 r
.26977 .39328 .27603 .39939 .28526 .4003 .27912 .39284 Mtetra
.413 .596 .92 r
.27912 .39284 .28526 .4003 .29452 .40172 .28838 .39418 Mtetra
.428 .602 .918 r
.28838 .39418 .29452 .40172 .30383 .40313 .29772 .39534 Mtetra
.403 .581 .912 r
.29772 .39534 .30383 .40313 .31318 .40509 .30709 .39694 Mtetra
.371 .553 .903 r
.30709 .39694 .31318 .40509 .32254 .40769 .31649 .39912 Mtetra
.349 .529 .891 r
.31649 .39912 .32254 .40769 .33195 .41077 .32593 .40177 Mtetra
.346 .515 .881 r
.32593 .40177 .33195 .41077 .34142 .41409 .33542 .40466 Mtetra
.36 .51 .872 r
.33542 .40466 .34142 .41409 .35097 .4174 .34499 .40756 Mtetra
.384 .513 .865 r
.34499 .40756 .35097 .4174 .36061 .42051 .35464 .41028 Mtetra
.411 .519 .857 r
.35464 .41028 .36061 .42051 .37033 .42332 .36438 .4127 Mtetra
.436 .524 .85 r
.36438 .4127 .37033 .42332 .38014 .42582 .37421 .41479 Mtetra
.456 .527 .841 r
.37421 .41479 .38014 .42582 .39004 .42808 .38413 .4166 Mtetra
.47 .525 .833 r
.38413 .4166 .39004 .42808 .40001 .43023 .39412 .41824 Mtetra
.476 .52 .823 r
.39412 .41824 .40001 .43023 .41006 .43244 .40418 .41986 Mtetra
.477 .51 .813 r
.40418 .41986 .41006 .43244 .42017 .43487 .41431 .42159 Mtetra
.475 .498 .802 r
.41431 .42159 .42017 .43487 .43035 .43766 .4245 .42354 Mtetra
.472 .484 .789 r
.4245 .42354 .43035 .43766 .44059 .44085 .43476 .42576 Mtetra
.471 .471 .775 r
.43476 .42576 .44059 .44085 .45091 .44442 .44509 .42821 Mtetra
.478 .461 .761 r
.44509 .42821 .45091 .44442 .46131 .44815 .4555 .43068 Mtetra
.495 .459 .746 r
.4555 .43068 .46131 .44815 .4718 .45162 .46599 .43278 Mtetra
.525 .465 .732 r
.46599 .43278 .4718 .45162 .48239 .45402 .47658 .43385 Mtetra
.566 .48 .717 r
.47658 .43385 .48239 .45402 .49309 .45409 .48726 .43299 Mtetra
.61 .501 .706 r
.48726 .43299 .49309 .45409 .50387 .45061 .49802 .42947 Mtetra
.647 .524 .7 r
.49802 .42947 .50387 .45061 .51471 .44358 .50884 .42329 Mtetra
.675 .546 .7 r
.50884 .42329 .51471 .44358 .52557 .43419 .51969 .41517 Mtetra
.694 .566 .705 r
.51969 .41517 .52557 .43419 .53642 .4237 .53054 .40599 Mtetra
.707 .582 .713 r
.53054 .40599 .53642 .4237 .54727 .41292 .5414 .39641 Mtetra
.715 .596 .722 r
.5414 .39641 .54727 .41292 .55812 .40229 .55226 .38684 Mtetra
.72 .608 .732 r
.55226 .38684 .55812 .40229 .56896 .39201 .56313 .37747 Mtetra
.723 .619 .741 r
.56313 .37747 .56896 .39201 .57981 .38212 .57401 .36836 Mtetra
.726 .63 .75 r
.57401 .36836 .57981 .38212 .59067 .37256 .58489 .35946 Mtetra
.731 .64 .758 r
.58489 .35946 .59067 .37256 .60154 .36321 .59579 .35065 Mtetra
.736 .65 .764 r
.59579 .35065 .60154 .36321 .61241 .3539 .60669 .3418 Mtetra
.743 .66 .768 r
.60669 .3418 .61241 .3539 .62328 .34446 .61759 .33275 Mtetra
.751 .669 .771 r
.61759 .33275 .62328 .34446 .63414 .33476 .62849 .32341 Mtetra
.76 .679 .772 r
.62849 .32341 .63414 .33476 .645 .32472 .63938 .31371 Mtetra
.769 .688 .774 r
.63938 .31371 .645 .32472 .65584 .31435 .65026 .30369 Mtetra
.776 .697 .776 r
.65026 .30369 .65584 .31435 .66666 .30375 .66114 .29346 Mtetra
.78 .705 .781 r
.66114 .29346 .66666 .30375 .67748 .29312 .672 .28321 Mtetra
.781 .713 .788 r
.672 .28321 .67748 .29312 .68831 .28271 .68288 .2732 Mtetra
.779 .721 .798 r
.68288 .2732 .68831 .28271 .69916 .27278 .69379 .26365 Mtetra
.774 .728 .81 r
.69379 .26365 .69916 .27278 .71005 .26349 .70473 .25467 Mtetra
.77 .734 .82 r
.70473 .25467 .71005 .26349 .72098 .25475 .7157 .24613 Mtetra
.776 .742 .822 r
.7157 .24613 .72098 .25475 .73191 .24598 .72667 .23739 Mtetra
.739 .731 .844 r
.72667 .23739 .73191 .24598 .74289 .23772 .73778 .23048 Mtetra
.664 .741 .908 r
.73778 .23048 .74289 .23772 .75421 .2338 .74913 .22653 Mtetra
.74913 .22653 .75421 .2338 .76558 .22987 .76053 .22256 Mtetra
.76053 .22256 .76558 .22987 .77699 .22592 .77197 .21858 Mtetra
.77197 .21858 .77699 .22592 .78844 .22195 .78346 .21459 Mtetra
.78346 .21459 .78844 .22195 .79994 .21797 .79499 .21058 Mtetra
.79499 .21058 .79994 .21797 .81149 .21397 .80657 .20655 Mtetra
.80657 .20655 .81149 .21397 .82308 .20996 .8182 .2025 Mtetra
.19733 .41024 .20378 .41624 .2131 .41299 .20668 .40697 Mtetra
.20668 .40697 .2131 .41299 .22246 .40974 .21606 .4037 Mtetra
.21606 .4037 .22246 .40974 .23186 .40647 .22547 .40041 Mtetra
.22547 .40041 .23186 .40647 .24128 .40319 .23492 .3971 Mtetra
.23492 .3971 .24128 .40319 .25075 .3999 .2444 .39379 Mtetra
.2444 .39379 .25075 .3999 .26024 .3966 .25392 .39047 Mtetra
.25392 .39047 .26024 .3966 .26977 .39328 .26347 .38713 Mtetra
.604 .723 .929 r
.26347 .38713 .26977 .39328 .27912 .39284 .27295 .38511 Mtetra
.418 .591 .914 r
.27295 .38511 .27912 .39284 .28838 .39418 .28222 .38645 Mtetra
.446 .605 .914 r
.28222 .38645 .28838 .39418 .29772 .39534 .29158 .3874 Mtetra
.43 .591 .91 r
.29158 .3874 .29772 .39534 .30709 .39694 .30098 .38865 Mtetra
.403 .567 .901 r
.30098 .38865 .30709 .39694 .31649 .39912 .31041 .39041 Mtetra
.384 .544 .891 r
.31041 .39041 .31649 .39912 .32593 .40177 .31988 .39261 Mtetra
.379 .529 .88 r
.31988 .39261 .32593 .40177 .33542 .40466 .3294 .39506 Mtetra
.389 .523 .871 r
.3294 .39506 .33542 .40466 .34499 .40756 .33899 .39754 Mtetra
.409 .524 .863 r
.33899 .39754 .34499 .40756 .35464 .41028 .34866 .39987 Mtetra
.433 .528 .855 r
.34866 .39987 .35464 .41028 .36438 .4127 .35842 .40191 Mtetra
.455 .532 .847 r
.35842 .40191 .36438 .4127 .37421 .41479 .36826 .40362 Mtetra
.474 .535 .839 r
.36826 .40362 .37421 .41479 .38413 .4166 .37819 .40504 Mtetra
.488 .535 .831 r
.37819 .40504 .38413 .4166 .39412 .41824 .3882 .40624 Mtetra
.496 .531 .823 r
.3882 .40624 .39412 .41824 .40418 .41986 .39828 .40735 Mtetra
.499 .524 .814 r
.39828 .40735 .40418 .41986 .41431 .42159 .40842 .40847 Mtetra
.498 .514 .804 r
.40842 .40847 .41431 .42159 .4245 .42354 .41863 .4097 Mtetra
.498 .503 .793 r
.41863 .4097 .4245 .42354 .43476 .42576 .4289 .41108 Mtetra
.499 .493 .781 r
.4289 .41108 .43476 .42576 .44509 .42821 .43925 .41255 Mtetra
.506 .485 .768 r
.43925 .41255 .44509 .42821 .4555 .43068 .44966 .41394 Mtetra
.521 .482 .754 r
.44966 .41394 .4555 .43068 .46599 .43278 .46016 .41491 Mtetra
.546 .487 .74 r
.46016 .41491 .46599 .43278 .47658 .43385 .47075 .41493 Mtetra
.579 .498 .727 r
.47075 .41493 .47658 .43385 .48726 .43299 .48142 .4134 Mtetra
.613 .514 .717 r
.48142 .4134 .48726 .43299 .49802 .42947 .49216 .40984 Mtetra
.644 .532 .712 r
.49216 .40984 .49802 .42947 .50884 .42329 .50297 .40426 Mtetra
.669 .551 .712 r
.50297 .40426 .50884 .42329 .51969 .41517 .5138 .39711 Mtetra
.687 .568 .716 r
.5138 .39711 .51969 .41517 .53054 .40599 .52466 .389 Mtetra
.699 .583 .723 r
.52466 .389 .53054 .40599 .5414 .39641 .53553 .38045 Mtetra
.707 .597 .731 r
.53553 .38045 .5414 .39641 .55226 .38684 .5464 .37179 Mtetra
.712 .609 .74 r
.5464 .37179 .55226 .38684 .56313 .37747 .55729 .36322 Mtetra
.716 .619 .748 r
.55729 .36322 .56313 .37747 .57401 .36836 .56819 .35477 Mtetra
.72 .629 .756 r
.56819 .35477 .57401 .36836 .58489 .35946 .5791 .34642 Mtetra
.724 .639 .762 r
.5791 .34642 .58489 .35946 .59579 .35065 .59002 .33808 Mtetra
.73 .648 .767 r
.59002 .33808 .59579 .35065 .60669 .3418 .60095 .32961 Mtetra
.737 .657 .77 r
.60095 .32961 .60669 .3418 .61759 .33275 .61188 .32091 Mtetra
.745 .666 .772 r
.61188 .32091 .61759 .33275 .62849 .32341 .62281 .31189 Mtetra
.754 .674 .774 r
.62281 .31189 .62849 .32341 .63938 .31371 .63374 .30252 Mtetra
.762 .683 .775 r
.63374 .30252 .63938 .31371 .65026 .30369 .64466 .29284 Mtetra
.768 .692 .778 r
.64466 .29284 .65026 .30369 .66114 .29346 .65558 .28298 Mtetra
.772 .7 .783 r
.65558 .28298 .66114 .29346 .672 .28321 .66649 .27314 Mtetra
.773 .708 .791 r
.66649 .27314 .672 .28321 .68288 .2732 .67742 .26353 Mtetra
.771 .716 .801 r
.67742 .26353 .68288 .2732 .69379 .26365 .68838 .25435 Mtetra
.767 .723 .812 r
.68838 .25435 .69379 .26365 .70473 .25467 .69937 .24568 Mtetra
.765 .73 .82 r
.69937 .24568 .70473 .25467 .7157 .24613 .71038 .2373 Mtetra
.775 .738 .819 r
.71038 .2373 .7157 .24613 .72667 .23739 .72139 .22851 Mtetra
.698 .709 .857 r
.72139 .22851 .72667 .23739 .73778 .23048 .73264 .22317 Mtetra
.664 .741 .908 r
.73264 .22317 .73778 .23048 .74913 .22653 .74402 .2192 Mtetra
.74402 .2192 .74913 .22653 .76053 .22256 .75545 .2152 Mtetra
.75545 .2152 .76053 .22256 .77197 .21858 .76692 .21119 Mtetra
.76692 .21119 .77197 .21858 .78346 .21459 .77844 .20717 Mtetra
.77844 .20717 .78346 .21459 .79499 .21058 .79001 .20313 Mtetra
.79001 .20313 .79499 .21058 .80657 .20655 .80162 .19907 Mtetra
.80162 .19907 .80657 .20655 .8182 .2025 .81328 .19499 Mtetra
.19085 .4042 .19733 .41024 .20668 .40697 .20021 .40091 Mtetra
.20021 .40091 .20668 .40697 .21606 .4037 .20961 .39761 Mtetra
.20961 .39761 .21606 .4037 .22547 .40041 .21905 .3943 Mtetra
.21905 .3943 .22547 .40041 .23492 .3971 .22851 .39098 Mtetra
.22851 .39098 .23492 .3971 .2444 .39379 .23802 .38764 Mtetra
.23802 .38764 .2444 .39379 .25392 .39047 .24755 .38429 Mtetra
.24755 .38429 .25392 .39047 .26347 .38713 .25713 .38093 Mtetra
.25713 .38093 .26347 .38713 .27295 .38511 .26673 .37756 Mtetra
.438 .608 .92 r
.26673 .37756 .27295 .38511 .28222 .38645 .27604 .37852 Mtetra
.458 .606 .91 r
.27604 .37852 .28222 .38645 .29158 .3874 .28541 .37932 Mtetra
.452 .599 .907 r
.28541 .37932 .29158 .3874 .30098 .38865 .29484 .38025 Mtetra
.432 .58 .9 r
.29484 .38025 .30098 .38865 .31041 .39041 .3043 .3816 Mtetra
.415 .559 .89 r
.3043 .3816 .31041 .39041 .31988 .39261 .3138 .38334 Mtetra
.409 .544 .88 r
.3138 .38334 .31988 .39261 .3294 .39506 .32335 .38534 Mtetra
.416 .536 .87 r
.32335 .38534 .3294 .39506 .33899 .39754 .33296 .3874 Mtetra
.431 .534 .861 r
.33296 .3874 .33899 .39754 .34866 .39987 .34266 .38932 Mtetra
.451 .536 .852 r
.34266 .38932 .34866 .39987 .35842 .40191 .35243 .391 Mtetra
.472 .539 .845 r
.35243 .391 .35842 .40191 .36826 .40362 .36229 .39237 Mtetra
.489 .542 .837 r
.36229 .39237 .36826 .40362 .37819 .40504 .37224 .39344 Mtetra
.502 .542 .83 r
.37224 .39344 .37819 .40504 .3882 .40624 .38226 .39426 Mtetra
.511 .54 .823 r
.38226 .39426 .3882 .40624 .39828 .40735 .39235 .39493 Mtetra
.516 .536 .815 r
.39235 .39493 .39828 .40735 .40842 .40847 .40251 .39553 Mtetra
.518 .529 .806 r
.40251 .39553 .40842 .40847 .41863 .4097 .41273 .39615 Mtetra
.519 .52 .797 r
.41273 .39615 .41863 .4097 .4289 .41108 .42302 .39682 Mtetra
.522 .512 .786 r
.42302 .39682 .4289 .41108 .43925 .41255 .43338 .39747 Mtetra
.529 .506 .774 r
.43338 .39747 .43925 .41255 .44966 .41394 .44381 .39796 Mtetra
.543 .503 .762 r
.44381 .39796 .44966 .41394 .46016 .41491 .45431 .39801 Mtetra
.563 .506 .75 r
.45431 .39801 .46016 .41491 .47075 .41493 .4649 .39724 Mtetra
.59 .515 .738 r
.4649 .39724 .47075 .41493 .48142 .4134 .47556 .3952 Mtetra
.617 .527 .729 r
.47556 .3952 .48142 .4134 .49216 .40984 .4863 .39161 Mtetra
.643 .542 .725 r
.4863 .39161 .49216 .40984 .50297 .40426 .49709 .38646 Mtetra
.664 .558 .724 r
.49709 .38646 .50297 .40426 .5138 .39711 .50792 .38005 Mtetra
.68 .573 .727 r
.50792 .38005 .5138 .39711 .52466 .389 .51877 .37279 Mtetra
.692 .587 .733 r
.51877 .37279 .52466 .389 .53553 .38045 .52965 .36507 Mtetra
.7 .599 .74 r
.52965 .36507 .53553 .38045 .5464 .37179 .54053 .35718 Mtetra
.706 .61 .748 r
.54053 .35718 .5464 .37179 .55729 .36322 .55144 .34926 Mtetra
.71 .62 .755 r
.55144 .34926 .55729 .36322 .56819 .35477 .56235 .34137 Mtetra
.714 .63 .761 r
.56235 .34137 .56819 .35477 .5791 .34642 .57328 .33348 Mtetra
.719 .638 .767 r
.57328 .33348 .5791 .34642 .59002 .33808 .58423 .32551 Mtetra
.725 .646 .77 r
.58423 .32551 .59002 .33808 .60095 .32961 .59518 .31738 Mtetra
.732 .655 .773 r
.59518 .31738 .60095 .32961 .61188 .32091 .60614 .30897 Mtetra
.74 .663 .774 r
.60614 .30897 .61188 .32091 .62281 .31189 .61711 .30025 Mtetra
.748 .671 .775 r
.61711 .30025 .62281 .31189 .63374 .30252 .62807 .29119 Mtetra
.756 .679 .777 r
.62807 .29119 .63374 .30252 .64466 .29284 .63903 .28186 Mtetra
.761 .688 .781 r
.63903 .28186 .64466 .29284 .65558 .28298 .64998 .27238 Mtetra
.765 .696 .786 r
.64998 .27238 .65558 .28298 .66649 .27314 .66095 .26294 Mtetra
.766 .704 .794 r
.66095 .26294 .66649 .27314 .67742 .26353 .67193 .25374 Mtetra
.764 .712 .804 r
.67193 .25374 .67742 .26353 .68838 .25435 .68293 .24493 Mtetra
.761 .72 .814 r
.68293 .24493 .68838 .25435 .69937 .24568 .69397 .23654 Mtetra
.761 .727 .82 r
.69397 .23654 .69937 .24568 .71038 .2373 .70503 .22827 Mtetra
.766 .731 .821 r
.70503 .22827 .71038 .2373 .72139 .22851 .71608 .21981 Mtetra
.66 .699 .875 r
.71608 .21981 .72139 .22851 .73264 .22317 .72745 .21582 Mtetra
.664 .741 .908 r
.72745 .21582 .73264 .22317 .74402 .2192 .73887 .21181 Mtetra
.73887 .21181 .74402 .2192 .75545 .2152 .75033 .20779 Mtetra
.75033 .20779 .75545 .2152 .76692 .21119 .76183 .20375 Mtetra
.76183 .20375 .76692 .21119 .77844 .20717 .77338 .19969 Mtetra
.77338 .19969 .77844 .20717 .79001 .20313 .78498 .19562 Mtetra
.78498 .19562 .79001 .20313 .80162 .19907 .79663 .19153 Mtetra
.79663 .19153 .80162 .19907 .81328 .19499 .80832 .18743 Mtetra
.18432 .39812 .19085 .4042 .20021 .40091 .1937 .39481 Mtetra
.1937 .39481 .20021 .40091 .20961 .39761 .20312 .39149 Mtetra
.20312 .39149 .20961 .39761 .21905 .3943 .21258 .38816 Mtetra
.21258 .38816 .21905 .3943 .22851 .39098 .22206 .38481 Mtetra
.22206 .38481 .22851 .39098 .23802 .38764 .23159 .38145 Mtetra
.23159 .38145 .23802 .38764 .24755 .38429 .24114 .37808 Mtetra
.24114 .37808 .24755 .38429 .25713 .38093 .25074 .3747 Mtetra
.25074 .3747 .25713 .38093 .26673 .37756 .26037 .3713 Mtetra
.537 .699 .944 r
.26037 .3713 .26673 .37756 .27604 .37852 .26983 .3704 Mtetra
.466 .605 .905 r
.26983 .3704 .27604 .37852 .28541 .37932 .27922 .37111 Mtetra
.47 .605 .903 r
.27922 .37111 .28541 .37932 .29484 .38025 .28867 .37176 Mtetra
.457 .591 .898 r
.28867 .37176 .29484 .38025 .3043 .3816 .29816 .37271 Mtetra
.442 .572 .889 r
.29816 .37271 .3043 .3816 .3138 .38334 .30769 .37402 Mtetra
.436 .557 .879 r
.30769 .37402 .3138 .38334 .32335 .38534 .31727 .37556 Mtetra
.44 .548 .869 r
.31727 .37556 .32335 .38534 .33296 .3874 .32691 .37718 Mtetra
.452 .544 .86 r
.32691 .37718 .33296 .3874 .34266 .38932 .33663 .37871 Mtetra
.468 .544 .851 r
.33663 .37871 .34266 .38932 .35243 .391 .34642 .38003 Mtetra
.486 .546 .843 r
.34642 .38003 .35243 .391 .36229 .39237 .3563 .38107 Mtetra
.501 .548 .836 r
.3563 .38107 .36229 .39237 .37224 .39344 .36625 .38182 Mtetra
.514 .549 .83 r
.36625 .38182 .37224 .39344 .38226 .39426 .37629 .38231 Mtetra
.523 .548 .823 r
.37629 .38231 .38226 .39426 .39235 .39493 .38639 .38261 Mtetra
.529 .546 .816 r
.38639 .38261 .39235 .39493 .40251 .39553 .39657 .38279 Mtetra
.533 .541 .809 r
.39657 .38279 .40251 .39553 .41273 .39615 .40681 .38291 Mtetra
.536 .535 .801 r
.40681 .38291 .41273 .39615 .42302 .39682 .41711 .38298 Mtetra
.54 .529 .792 r
.41711 .38298 .42302 .39682 .43338 .39747 .42748 .38296 Mtetra
.547 .524 .781 r
.42748 .38296 .43338 .39747 .44381 .39796 .43792 .38273 Mtetra
.56 .522 .77 r
.43792 .38273 .44381 .39796 .45431 .39801 .44843 .38206 Mtetra
.577 .524 .759 r
.44843 .38206 .45431 .39801 .4649 .39724 .45902 .38067 Mtetra
.599 .531 .749 r
.45902 .38067 .4649 .39724 .47556 .3952 .46968 .37826 Mtetra
.622 .54 .742 r
.46968 .37826 .47556 .3952 .4863 .39161 .48041 .37463 Mtetra
.643 .553 .737 r
.48041 .37463 .4863 .39161 .49709 .38646 .49119 .36979 Mtetra
.661 .566 .737 r
.49119 .36979 .49709 .38646 .50792 .38005 .50202 .36392 Mtetra
.676 .579 .739 r
.50202 .36392 .50792 .38005 .51877 .37279 .51287 .35732 Mtetra
.687 .592 .744 r
.51287 .35732 .51877 .37279 .52965 .36507 .52375 .35027 Mtetra
.695 .603 .75 r
.52375 .35027 .52965 .36507 .54053 .35718 .53465 .34299 Mtetra
.7 .613 .756 r
.53465 .34299 .54053 .35718 .55144 .34926 .54557 .3356 Mtetra
.705 .622 .762 r
.54557 .3356 .55144 .34926 .56235 .34137 .5565 .32816 Mtetra
.71 .631 .767 r
.5565 .32816 .56235 .34137 .57328 .33348 .56745 .32064 Mtetra
.715 .638 .771 r
.56745 .32064 .57328 .33348 .58423 .32551 .57842 .31299 Mtetra
.721 .646 .773 r
.57842 .31299 .58423 .32551 .59518 .31738 .5894 .30512 Mtetra
.728 .653 .775 r
.5894 .30512 .59518 .31738 .60614 .30897 .60038 .29699 Mtetra
.735 .661 .776 r
.60038 .29699 .60614 .30897 .61711 .30025 .61137 .28853 Mtetra
.743 .668 .778 r
.61137 .28853 .61711 .30025 .62807 .29119 .62237 .27978 Mtetra
.75 .676 .78 r
.62237 .27978 .62807 .29119 .63903 .28186 .63336 .27079 Mtetra
.755 .685 .784 r
.63336 .27079 .63903 .28186 .64998 .27238 .64436 .2617 Mtetra
.758 .693 .79 r
.64436 .2617 .64998 .27238 .66095 .26294 .65537 .25267 Mtetra
.758 .702 .798 r
.65537 .25267 .66095 .26294 .67193 .25374 .6664 .24387 Mtetra
.757 .709 .807 r
.6664 .24387 .67193 .25374 .68293 .24493 .67745 .23542 Mtetra
.755 .717 .816 r
.67745 .23542 .68293 .24493 .69397 .23654 .68853 .22725 Mtetra
.759 .724 .82 r
.68853 .22725 .69397 .23654 .70503 .22827 .69962 .21902 Mtetra
.725 .713 .839 r
.69962 .21902 .70503 .22827 .71608 .21981 .71083 .21243 Mtetra
.664 .741 .908 r
.71083 .21243 .71608 .21981 .72745 .21582 .72223 .20841 Mtetra
.72223 .20841 .72745 .21582 .73887 .21181 .73367 .20437 Mtetra
.73367 .20437 .73887 .21181 .75033 .20779 .74517 .20032 Mtetra
.74517 .20032 .75033 .20779 .76183 .20375 .7567 .19625 Mtetra
.7567 .19625 .76183 .20375 .77338 .19969 .76829 .19216 Mtetra
.76829 .19216 .77338 .19969 .78498 .19562 .77992 .18806 Mtetra
.77992 .18806 .78498 .19562 .79663 .19153 .7916 .18394 Mtetra
.7916 .18394 .79663 .19153 .80832 .18743 .80333 .17981 Mtetra
.17775 .392 .18432 .39812 .1937 .39481 .18715 .38867 Mtetra
.18715 .38867 .1937 .39481 .20312 .39149 .19659 .38532 Mtetra
.19659 .38532 .20312 .39149 .21258 .38816 .20606 .38197 Mtetra
.20606 .38197 .21258 .38816 .22206 .38481 .21557 .3786 Mtetra
.21557 .3786 .22206 .38481 .23159 .38145 .22511 .37522 Mtetra
.22511 .37522 .23159 .38145 .24114 .37808 .23469 .37182 Mtetra
.23469 .37182 .24114 .37808 .25074 .3747 .24431 .36842 Mtetra
.24431 .36842 .25074 .3747 .26037 .3713 .25396 .365 Mtetra
.643 .736 .916 r
.25396 .365 .26037 .3713 .26983 .3704 .2636 .36206 Mtetra
.468 .6 .901 r
.2636 .36206 .26983 .3704 .27922 .37111 .27299 .36276 Mtetra
.484 .609 .9 r
.27299 .36276 .27922 .37111 .28867 .37176 .28247 .3632 Mtetra
.477 .6 .896 r
.28247 .3632 .28867 .37176 .29816 .37271 .29199 .3638 Mtetra
.466 .585 .889 r
.29199 .3638 .29816 .37271 .30769 .37402 .30155 .36467 Mtetra
.46 .571 .879 r
.30155 .36467 .30769 .37402 .31727 .37556 .31116 .36576 Mtetra
.462 .56 .869 r
.31116 .36576 .31727 .37556 .32691 .37718 .32083 .36695 Mtetra
.471 .555 .86 r
.32083 .36695 .32691 .37718 .33663 .37871 .33057 .36808 Mtetra
.483 .553 .851 r
.33057 .36808 .33663 .37871 .34642 .38003 .34038 .36905 Mtetra
.498 .553 .843 r
.34038 .36905 .34642 .38003 .3563 .38107 .35028 .36978 Mtetra
.512 .555 .836 r
.35028 .36978 .3563 .38107 .36625 .38182 .36025 .37023 Mtetra
.524 .556 .83 r
.36025 .37023 .36625 .38182 .37629 .38231 .37029 .37043 Mtetra
.533 .556 .824 r
.37029 .37043 .37629 .38231 .38639 .38261 .38041 .37042 Mtetra
.54 .554 .818 r
.38041 .37042 .38639 .38261 .39657 .38279 .3906 .37025 Mtetra
.545 .551 .812 r
.3906 .37025 .39657 .38279 .40681 .38291 .40085 .36996 Mtetra
.549 .547 .805 r
.40085 .36996 .40681 .38291 .41711 .38298 .41117 .36955 Mtetra
.554 .543 .797 r
.41117 .36955 .41711 .38298 .42748 .38296 .42155 .369 Mtetra
.562 .54 .788 r
.42155 .369 .42748 .38296 .43792 .38273 .432 .36819 Mtetra
.573 .539 .779 r
.432 .36819 .43792 .38273 .44843 .38206 .44252 .36696 Mtetra
.589 .541 .769 r
.44252 .36696 .44843 .38206 .45902 .38067 .45311 .3651 Mtetra
.606 .546 .761 r
.45311 .3651 .45902 .38067 .46968 .37826 .46378 .36241 Mtetra
.625 .554 .754 r
.46378 .36241 .46968 .37826 .48041 .37463 .4745 .35875 Mtetra
.644 .564 .75 r
.4745 .35875 .48041 .37463 .49119 .36979 .48528 .35412 Mtetra
.66 .575 .749 r
.48528 .35412 .49119 .36979 .50202 .36392 .4961 .34865 Mtetra
.673 .586 .751 r
.4961 .34865 .50202 .36392 .51287 .35732 .50696 .34255 Mtetra
.683 .597 .754 r
.50696 .34255 .51287 .35732 .52375 .35027 .51784 .33601 Mtetra
.69 .608 .759 r
.51784 .33601 .52375 .35027 .53465 .34299 .52875 .32921 Mtetra
.696 .617 .763 r
.52875 .32921 .53465 .34299 .54557 .3356 .53968 .32224 Mtetra
.702 .625 .768 r
.53968 .32224 .54557 .3356 .5565 .32816 .55063 .31515 Mtetra
.706 .632 .772 r
.55063 .31515 .5565 .32816 .56745 .32064 .5616 .30792 Mtetra
.712 .639 .775 r
.5616 .30792 .56745 .32064 .57842 .31299 .57259 .30052 Mtetra
.718 .646 .776 r
.57259 .30052 .57842 .31299 .5894 .30512 .58359 .29289 Mtetra
.724 .653 .778 r
.58359 .29289 .5894 .30512 .60038 .29699 .5946 .28499 Mtetra
.731 .66 .779 r
.5946 .28499 .60038 .29699 .61137 .28853 .60562 .2768 Mtetra
.738 .667 .781 r
.60562 .2768 .61137 .28853 .62237 .27978 .61664 .26835 Mtetra
.744 .675 .783 r
.61664 .26835 .62237 .27978 .63336 .27079 .62767 .25971 Mtetra
.748 .683 .788 r
.62767 .25971 .63336 .27079 .64436 .2617 .63871 .25101 Mtetra
.751 .691 .794 r
.63871 .25101 .64436 .2617 .65537 .25267 .64977 .24238 Mtetra
.752 .7 .802 r
.64977 .24238 .65537 .25267 .6664 .24387 .66084 .23396 Mtetra
.751 .707 .811 r
.66084 .23396 .6664 .24387 .67745 .23542 .67194 .22582 Mtetra
.751 .715 .818 r
.67194 .22582 .67745 .23542 .68853 .22725 .68306 .21782 Mtetra
.758 .722 .818 r
.68306 .21782 .68853 .22725 .69962 .21902 .69418 .20954 Mtetra
.672 .687 .856 r
.69418 .20954 .69962 .21902 .71083 .21243 .70553 .20499 Mtetra
.664 .741 .908 r
.70553 .20499 .71083 .21243 .72223 .20841 .71697 .20094 Mtetra
.71697 .20094 .72223 .20841 .73367 .20437 .72844 .19688 Mtetra
.72844 .19688 .73367 .20437 .74517 .20032 .73997 .19279 Mtetra
.73997 .19279 .74517 .20032 .7567 .19625 .75154 .18869 Mtetra
.75154 .18869 .7567 .19625 .76829 .19216 .76316 .18458 Mtetra
.76316 .18458 .76829 .19216 .77992 .18806 .77482 .18044 Mtetra
.77482 .18044 .77992 .18806 .7916 .18394 .78654 .17629 Mtetra
.78654 .17629 .7916 .18394 .80333 .17981 .7983 .17213 Mtetra
.17113 .38584 .17775 .392 .18715 .38867 .18055 .38249 Mtetra
.18055 .38249 .18715 .38867 .19659 .38532 .19001 .37912 Mtetra
.19001 .37912 .19659 .38532 .20606 .38197 .19951 .37574 Mtetra
.19951 .37574 .20606 .38197 .21557 .3786 .20903 .37235 Mtetra
.20903 .37235 .21557 .3786 .22511 .37522 .2186 .36894 Mtetra
.2186 .36894 .22511 .37522 .23469 .37182 .2282 .36553 Mtetra
.2282 .36553 .23469 .37182 .24431 .36842 .23783 .3621 Mtetra
.23783 .3621 .24431 .36842 .25396 .365 .2475 .35865 Mtetra
.2475 .35865 .25396 .365 .2636 .36206 .25721 .3552 Mtetra
.544 .684 .93 r
.25721 .3552 .2636 .36206 .27299 .36276 .26674 .35425 Mtetra
.492 .609 .897 r
.26674 .35425 .27299 .36276 .28247 .3632 .27623 .35456 Mtetra
.494 .607 .894 r
.27623 .35456 .28247 .3632 .29199 .3638 .28578 .35486 Mtetra
.487 .596 .888 r
.28578 .35486 .29199 .3638 .30155 .36467 .29538 .35534 Mtetra
.482 .583 .879 r
.29538 .35534 .30155 .36467 .31116 .36576 .30502 .356 Mtetra
.482 .573 .87 r
.30502 .356 .31116 .36576 .32083 .36695 .31472 .35676 Mtetra
.488 .566 .861 r
.31472 .35676 .32083 .36695 .33057 .36808 .32448 .3575 Mtetra
.498 .562 .852 r
.32448 .3575 .33057 .36808 .34038 .36905 .33432 .35811 Mtetra
.509 .561 .844 r
.33432 .35811 .34038 .36905 .35028 .36978 .34423 .35852 Mtetra
.521 .561 .837 r
.34423 .35852 .35028 .36978 .36025 .37023 .35421 .3587 Mtetra
.532 .562 .831 r
.35421 .3587 .36025 .37023 .37029 .37043 .36427 .35864 Mtetra
.541 .562 .826 r
.36427 .35864 .37029 .37043 .38041 .37042 .3744 .35837 Mtetra
.548 .562 .82 r
.3744 .35837 .38041 .37042 .3906 .37025 .3846 .3579 Mtetra
.554 .56 .815 r
.3846 .3579 .3906 .37025 .40085 .36996 .39486 .35728 Mtetra
.56 .558 .809 r
.39486 .35728 .40085 .36996 .41117 .36955 .40519 .3565 Mtetra
.566 .556 .802 r
.40519 .3565 .41117 .36955 .42155 .369 .41559 .35552 Mtetra
.574 .554 .795 r
.41559 .35552 .42155 .369 .432 .36819 .42605 .35426 Mtetra
.584 .554 .787 r
.42605 .35426 .432 .36819 .44252 .36696 .43658 .3526 Mtetra
.598 .556 .779 r
.43658 .3526 .44252 .36696 .45311 .3651 .44718 .35039 Mtetra
.613 .56 .771 r
.44718 .35039 .45311 .3651 .46378 .36241 .45784 .34749 Mtetra
.629 .567 .765 r
.45784 .34749 .46378 .36241 .4745 .35875 .46857 .3438 Mtetra
.645 .575 .762 r
.46857 .3438 .4745 .35875 .48528 .35412 .47934 .33932 Mtetra
.659 .584 .76 r
.47934 .33932 .48528 .35412 .4961 .34865 .49017 .33413 Mtetra
.67 .594 .761 r
.49017 .33413 .4961 .34865 .50696 .34255 .50103 .32839 Mtetra
.68 .604 .764 r
.50103 .32839 .50696 .34255 .51784 .33601 .51192 .32224 Mtetra
.687 .613 .767 r
.51192 .32224 .51784 .33601 .52875 .32921 .52284 .3158 Mtetra
.694 .621 .771 r
.52284 .3158 .52875 .32921 .53968 .32224 .53378 .30915 Mtetra
.699 .628 .774 r
.53378 .30915 .53968 .32224 .55063 .31515 .54474 .30233 Mtetra
.704 .634 .776 r
.54474 .30233 .55063 .31515 .5616 .30792 .55573 .29534 Mtetra
.709 .641 .778 r
.55573 .29534 .5616 .30792 .57259 .30052 .56674 .28815 Mtetra
.715 .647 .78 r
.56674 .28815 .57259 .30052 .58359 .29289 .57776 .28072 Mtetra
.721 .653 .781 r
.57776 .28072 .58359 .29289 .5946 .28499 .58879 .27304 Mtetra
.727 .659 .782 r
.58879 .27304 .5946 .28499 .60562 .2768 .59984 .26511 Mtetra
.733 .666 .784 r
.59984 .26511 .60562 .2768 .61664 .26835 .6109 .25696 Mtetra
.739 .674 .788 r
.6109 .25696 .61664 .26835 .62767 .25971 .62196 .24867 Mtetra
.743 .682 .793 r
.62196 .24867 .62767 .25971 .63871 .25101 .63304 .24034 Mtetra
.745 .69 .799 r
.63304 .24034 .63871 .25101 .64977 .24238 .64413 .2321 Mtetra
.746 .699 .807 r
.64413 .2321 .64977 .24238 .66084 .23396 .65525 .22402 Mtetra
.746 .706 .814 r
.65525 .22402 .66084 .23396 .67194 .22582 .66639 .21613 Mtetra
.749 .713 .819 r
.66639 .21613 .67194 .22582 .68306 .21782 .67754 .20821 Mtetra
.723 .706 .834 r
.67754 .20821 .68306 .21782 .69418 .20954 .68878 .20157 Mtetra
.663 .725 .896 r
.68878 .20157 .69418 .20954 .70553 .20499 .7002 .1975 Mtetra
.664 .741 .908 r
.7002 .1975 .70553 .20499 .71697 .20094 .71167 .19342 Mtetra
.71167 .19342 .71697 .20094 .72844 .19688 .72318 .18932 Mtetra
.72318 .18932 .72844 .19688 .73997 .19279 .73473 .18521 Mtetra
.73473 .18521 .73997 .19279 .75154 .18869 .74634 .18108 Mtetra
.74634 .18108 .75154 .18869 .76316 .18458 .75799 .17693 Mtetra
.75799 .17693 .76316 .18458 .77482 .18044 .76969 .17277 Mtetra
.76969 .17277 .77482 .18044 .78654 .17629 .78143 .16859 Mtetra
.78143 .16859 .78654 .17629 .7983 .17213 .79323 .16439 Mtetra
.16447 .37964 .17113 .38584 .18055 .38249 .17391 .37626 Mtetra
.17391 .37626 .18055 .38249 .19001 .37912 .18339 .37287 Mtetra
.18339 .37287 .19001 .37912 .19951 .37574 .1929 .36947 Mtetra
.1929 .36947 .19951 .37574 .20903 .37235 .20245 .36605 Mtetra
.20245 .36605 .20903 .37235 .2186 .36894 .21204 .36262 Mtetra
.21204 .36262 .2186 .36894 .2282 .36553 .22166 .35918 Mtetra
.22166 .35918 .2282 .36553 .23783 .3621 .23131 .35573 Mtetra
.23131 .35573 .23783 .3621 .2475 .35865 .241 .35226 Mtetra
.241 .35226 .2475 .35865 .25721 .3552 .25073 .34879 Mtetra
.654 .739 .912 r
.25073 .34879 .25721 .3552 .26674 .35425 .26047 .34555 Mtetra
.494 .606 .893 r
.26047 .34555 .26674 .35425 .27623 .35456 .26997 .34581 Mtetra
.505 .611 .891 r
.26997 .34581 .27623 .35456 .28578 .35486 .27954 .34589 Mtetra
.504 .605 .887 r
.27954 .34589 .28578 .35486 .29538 .35534 .28916 .34604 Mtetra
.501 .595 .88 r
.28916 .34604 .29538 .35534 .30502 .356 .29884 .3463 Mtetra
.501 .585 .871 r
.29884 .3463 .30502 .356 .31472 .35676 .30857 .34665 Mtetra
.504 .577 .862 r
.30857 .34665 .31472 .35676 .32448 .3575 .31836 .347 Mtetra
.511 .572 .853 r
.31836 .347 .32448 .3575 .33432 .35811 .32821 .34726 Mtetra
.52 .57 .846 r
.32821 .34726 .33432 .35811 .34423 .35852 .33814 .34736 Mtetra
.53 .569 .839 r
.33814 .34736 .34423 .35852 .35421 .3587 .34814 .34727 Mtetra
.539 .569 .833 r
.34814 .34727 .35421 .3587 .36427 .35864 .35821 .34696 Mtetra
.548 .569 .828 r
.35821 .34696 .36427 .35864 .3744 .35837 .36836 .34645 Mtetra
.555 .569 .823 r
.36836 .34645 .3744 .35837 .3846 .3579 .37857 .34574 Mtetra
.561 .568 .818 r
.37857 .34574 .3846 .3579 .39486 .35728 .38884 .34485 Mtetra
.568 .567 .813 r
.38884 .34485 .39486 .35728 .40519 .3565 .39918 .34376 Mtetra
.575 .567 .807 r
.39918 .34376 .40519 .3565 .41559 .35552 .40959 .34246 Mtetra
.583 .566 .801 r
.40959 .34246 .41559 .35552 .42605 .35426 .42006 .34086 Mtetra
.593 .567 .794 r
.42006 .34086 .42605 .35426 .43658 .3526 .4306 .33888 Mtetra
.605 .569 .787 r
.4306 .33888 .43658 .3526 .44718 .35039 .44121 .3364 Mtetra
.618 .573 .781 r
.44121 .3364 .44718 .35039 .45784 .34749 .45187 .33333 Mtetra
.632 .578 .776 r
.45187 .33333 .45784 .34749 .46857 .3438 .4626 .32961 Mtetra
.646 .586 .772 r
.4626 .32961 .46857 .3438 .47934 .33932 .47338 .32523 Mtetra
.658 .594 .771 r
.47338 .32523 .47934 .33932 .49017 .33413 .48421 .32025 Mtetra
.669 .602 .771 r
.48421 .32025 .49017 .33413 .50103 .32839 .49507 .31476 Mtetra
.678 .61 .772 r
.49507 .31476 .50103 .32839 .51192 .32224 .50597 .30889 Mtetra
.685 .618 .775 r
.50597 .30889 .51192 .32224 .52284 .3158 .5169 .30272 Mtetra
.691 .625 .777 r
.5169 .30272 .52284 .3158 .53378 .30915 .52786 .29631 Mtetra
.697 .631 .779 r
.52786 .29631 .53378 .30915 .54474 .30233 .53884 .2897 Mtetra
.702 .637 .781 r
.53884 .2897 .54474 .30233 .55573 .29534 .54984 .28289 Mtetra
.707 .642 .782 r
.54984 .28289 .55573 .29534 .56674 .28815 .56086 .27588 Mtetra
.712 .648 .784 r
.56086 .27588 .56674 .28815 .57776 .28072 .57191 .26864 Mtetra
.718 .654 .785 r
.57191 .26864 .57776 .28072 .58879 .27304 .58296 .26118 Mtetra
.724 .66 .786 r
.58296 .26118 .58879 .27304 .59984 .26511 .59404 .2535 Mtetra
.729 .667 .789 r
.59404 .2535 .59984 .26511 .6109 .25696 .60512 .24565 Mtetra
.733 .674 .793 r
.60512 .24565 .6109 .25696 .62196 .24867 .61622 .2377 Mtetra
.737 .682 .798 r
.61622 .2377 .62196 .24867 .63304 .24034 .62734 .22973 Mtetra
.739 .69 .804 r
.62734 .22973 .63304 .24034 .64413 .2321 .63847 .22184 Mtetra
.74 .698 .811 r
.63847 .22184 .64413 .2321 .65525 .22402 .64963 .21406 Mtetra
.742 .705 .817 r
.64963 .21406 .65525 .22402 .66639 .21613 .6608 .20632 Mtetra
.748 .712 .818 r
.6608 .20632 .66639 .21613 .67754 .20821 .67199 .19839 Mtetra
.663 .677 .853 r
.67199 .19839 .67754 .20821 .68878 .20157 .68338 .19405 Mtetra
.664 .741 .908 r
.68338 .19405 .68878 .20157 .7002 .1975 .69483 .18996 Mtetra
.69483 .18996 .7002 .1975 .71167 .19342 .70632 .18584 Mtetra
.70632 .18584 .71167 .19342 .72318 .18932 .71787 .18172 Mtetra
.71787 .18172 .72318 .18932 .73473 .18521 .72946 .17757 Mtetra
.72946 .17757 .73473 .18521 .74634 .18108 .74109 .17341 Mtetra
.74109 .17341 .74634 .18108 .75799 .17693 .75278 .16923 Mtetra
.75278 .16923 .75799 .17693 .76969 .17277 .76451 .16504 Mtetra
.76451 .16504 .76969 .17277 .78143 .16859 .77629 .16082 Mtetra
.77629 .16082 .78143 .16859 .79323 .16439 .78812 .15659 Mtetra
.15776 .37339 .16447 .37964 .17391 .37626 .16722 .36999 Mtetra
.16722 .36999 .17391 .37626 .18339 .37287 .17672 .36658 Mtetra
.17672 .36658 .18339 .37287 .1929 .36947 .18626 .36315 Mtetra
.18626 .36315 .1929 .36947 .20245 .36605 .19583 .35971 Mtetra
.19583 .35971 .20245 .36605 .21204 .36262 .20543 .35626 Mtetra
.20543 .35626 .21204 .36262 .22166 .35918 .21507 .3528 Mtetra
.21507 .3528 .22166 .35918 .23131 .35573 .22475 .34932 Mtetra
.22475 .34932 .23131 .35573 .241 .35226 .23446 .34583 Mtetra
.23446 .34583 .241 .35226 .25073 .34879 .24421 .34233 Mtetra
.24421 .34233 .25073 .34879 .26047 .34555 .25399 .33881 Mtetra
.591 .71 .926 r
.25399 .33881 .26047 .34555 .26997 .34581 .26368 .33691 Mtetra
.511 .61 .888 r
.26368 .33691 .26997 .34581 .27954 .34589 .27326 .33688 Mtetra
.516 .61 .885 r
.27326 .33688 .27954 .34589 .28916 .34604 .28291 .33676 Mtetra
.516 .604 .88 r
.28291 .33676 .28916 .34604 .29884 .3463 .29262 .33668 Mtetra
.517 .596 .872 r
.29262 .33668 .29884 .3463 .30857 .34665 .30238 .33665 Mtetra
.519 .588 .864 r
.30238 .33665 .30857 .34665 .31836 .347 .31219 .33662 Mtetra
.524 .583 .856 r
.31219 .33662 .31836 .347 .32821 .34726 .32207 .33654 Mtetra
.531 .579 .848 r
.32207 .33654 .32821 .34726 .33814 .34736 .33202 .33633 Mtetra
.539 .577 .841 r
.33202 .33633 .33814 .34736 .34814 .34727 .34204 .33597 Mtetra
.547 .576 .835 r
.34204 .33597 .34814 .34727 .35821 .34696 .35212 .33542 Mtetra
.554 .576 .83 r
.35212 .33542 .35821 .34696 .36836 .34645 .36228 .33469 Mtetra
.561 .576 .826 r
.36228 .33469 .36836 .34645 .37857 .34574 .3725 .33376 Mtetra
.568 .575 .821 r
.3725 .33376 .37857 .34574 .38884 .34485 .38279 .33264 Mtetra
.574 .575 .816 r
.38279 .33264 .38884 .34485 .39918 .34376 .39314 .33131 Mtetra
.581 .575 .811 r
.39314 .33131 .39918 .34376 .40959 .34246 .40356 .32974 Mtetra
.59 .576 .806 r
.40356 .32974 .40959 .34246 .42006 .34086 .41404 .32788 Mtetra
.599 .577 .8 r
.41404 .32788 .42006 .34086 .4306 .33888 .42459 .32566 Mtetra
.61 .58 .795 r
.42459 .32566 .4306 .33888 .44121 .3364 .4352 .32298 Mtetra
.622 .584 .789 r
.4352 .32298 .44121 .3364 .45187 .33333 .44588 .31979 Mtetra
.635 .589 .785 r
.44588 .31979 .45187 .33333 .4626 .32961 .45661 .31603 Mtetra
.647 .595 .782 r
.45661 .31603 .4626 .32961 .47338 .32523 .46739 .31171 Mtetra
.658 .602 .78 r
.46739 .31171 .47338 .32523 .48421 .32025 .47822 .30686 Mtetra
.668 .609 .779 r
.47822 .30686 .48421 .32025 .49507 .31476 .4891 .30156 Mtetra
.677 .616 .78 r
.4891 .30156 .49507 .31476 .50597 .30889 .5 .29589 Mtetra
.684 .623 .781 r
.5 .29589 .50597 .30889 .5169 .30272 .51094 .28991 Mtetra
.69 .629 .783 r
.51094 .28991 .5169 .30272 .52786 .29631 .52191 .28369 Mtetra
.695 .634 .784 r
.52191 .28369 .52786 .29631 .53884 .2897 .53291 .27725 Mtetra
.7 .639 .785 r
.53291 .27725 .53884 .2897 .54984 .28289 .54393 .2706 Mtetra
.705 .645 .786 r
.54393 .2706 .54984 .28289 .56086 .27588 .55497 .26375 Mtetra
.71 .65 .788 r
.55497 .26375 .56086 .27588 .57191 .26864 .56603 .25669 Mtetra
.715 .655 .789 r
.56603 .25669 .57191 .26864 .58296 .26118 .57711 .24944 Mtetra
.72 .661 .791 r
.57711 .24944 .58296 .26118 .59404 .2535 .58821 .24202 Mtetra
.725 .668 .794 r
.58821 .24202 .59404 .2535 .60512 .24565 .59933 .23447 Mtetra
.729 .675 .798 r
.59933 .23447 .60512 .24565 .61622 .2377 .61046 .22684 Mtetra
.732 .683 .803 r
.61046 .22684 .61622 .2377 .62734 .22973 .62161 .2192 Mtetra
.734 .691 .809 r
.62161 .2192 .62734 .22973 .63847 .22184 .63278 .2116 Mtetra
.737 .698 .815 r
.63278 .2116 .63847 .22184 .64963 .21406 .64398 .20402 Mtetra
.74 .705 .817 r
.64398 .20402 .64963 .21406 .6608 .20632 .65518 .19635 Mtetra
.699 .69 .838 r
.65518 .19635 .6608 .20632 .67199 .19839 .6665 .19059 Mtetra
.663 .733 .902 r
.6665 .19059 .67199 .19839 .68338 .19405 .67793 .18648 Mtetra
.664 .741 .908 r
.67793 .18648 .68338 .19405 .69483 .18996 .68942 .18235 Mtetra
.68942 .18235 .69483 .18996 .70632 .18584 .70094 .17821 Mtetra
.70094 .17821 .70632 .18584 .71787 .18172 .71252 .17405 Mtetra
.71252 .17405 .71787 .18172 .72946 .17757 .72414 .16988 Mtetra
.72414 .16988 .72946 .17757 .74109 .17341 .73581 .16568 Mtetra
.73581 .16568 .74109 .17341 .75278 .16923 .74753 .16147 Mtetra
.74753 .16147 .75278 .16923 .76451 .16504 .75929 .15724 Mtetra
.75929 .15724 .76451 .16504 .77629 .16082 .77111 .153 Mtetra
.77111 .153 .77629 .16082 .78812 .15659 .78297 .14874 Mtetra
.15101 .3671 .15776 .37339 .16722 .36999 .16049 .36368 Mtetra
.16049 .36368 .16722 .36999 .17672 .36658 .17001 .36024 Mtetra
.17001 .36024 .17672 .36658 .18626 .36315 .17956 .35679 Mtetra
.17956 .35679 .18626 .36315 .19583 .35971 .18915 .35333 Mtetra
.18915 .35333 .19583 .35971 .20543 .35626 .19878 .34986 Mtetra
.19878 .34986 .20543 .35626 .21507 .3528 .20844 .34637 Mtetra
.20844 .34637 .21507 .3528 .22475 .34932 .21814 .34287 Mtetra
.21814 .34287 .22475 .34932 .23446 .34583 .22787 .33935 Mtetra
.22787 .33935 .23446 .34583 .24421 .34233 .23764 .33583 Mtetra
.23764 .33583 .24421 .34233 .25399 .33881 .24745 .33229 Mtetra
.24745 .33229 .25399 .33881 .26368 .33691 .25729 .32873 Mtetra
.553 .651 .9 r
.25729 .32873 .26368 .33691 .27326 .33688 .26696 .32775 Mtetra
.524 .612 .883 r
.26696 .32775 .27326 .33688 .28291 .33676 .27663 .32747 Mtetra
.528 .61 .879 r
.27663 .32747 .28291 .33676 .29262 .33668 .28635 .32713 Mtetra
.53 .605 .873 r
.28635 .32713 .29262 .33668 .30238 .33665 .29614 .32677 Mtetra
.533 .599 .866 r
.29614 .32677 .30238 .33665 .31219 .33662 .30599 .32639 Mtetra
.537 .593 .858 r
.30599 .32639 .31219 .33662 .32207 .33654 .31589 .32597 Mtetra
.542 .589 .851 r
.31589 .32597 .32207 .33654 .33202 .33633 .32586 .32546 Mtetra
.548 .586 .844 r
.32586 .32546 .33202 .33633 .34204 .33597 .3359 .32482 Mtetra
.554 .584 .838 r
.3359 .32482 .34204 .33597 .35212 .33542 .346 .32403 Mtetra
.56 .583 .833 r
.346 .32403 .35212 .33542 .36228 .33469 .35617 .32307 Mtetra
.567 .582 .828 r
.35617 .32307 .36228 .33469 .3725 .33376 .3664 .32194 Mtetra
.573 .582 .824 r
.3664 .32194 .3725 .33376 .38279 .33264 .3767 .32062 Mtetra
.58 .582 .82 r
.3767 .32062 .38279 .33264 .39314 .33131 .38707 .31908 Mtetra
.587 .583 .815 r
.38707 .31908 .39314 .33131 .40356 .32974 .39749 .3173 Mtetra
.595 .584 .811 r
.39749 .3173 .40356 .32974 .41404 .32788 .40799 .31524 Mtetra
.604 .586 .806 r
.40799 .31524 .41404 .32788 .42459 .32566 .41855 .31282 Mtetra
.615 .589 .801 r
.41855 .31282 .42459 .32566 .4352 .32298 .42917 .30999 Mtetra
.626 .592 .796 r
.42917 .30999 .4352 .32298 .44588 .31979 .43985 .30669 Mtetra
.637 .597 .792 r
.43985 .30669 .44588 .31979 .45661 .31603 .45059 .3029 Mtetra
.648 .602 .789 r
.45059 .3029 .45661 .31603 .46739 .31171 .46138 .29862 Mtetra
.658 .608 .787 r
.46138 .29862 .46739 .31171 .47822 .30686 .47221 .29386 Mtetra
.668 .615 .786 r
.47221 .29386 .47822 .30686 .4891 .30156 .48309 .28869 Mtetra
.676 .621 .786 r
.48309 .28869 .4891 .30156 .5 .29589 .49401 .28316 Mtetra
.682 .627 .787 r
.49401 .28316 .5 .29589 .51094 .28991 .50496 .27734 Mtetra
.688 .632 .788 r
.50496 .27734 .51094 .28991 .52191 .28369 .51594 .27126 Mtetra
.694 .637 .789 r
.51594 .27126 .52191 .28369 .53291 .27725 .52695 .26496 Mtetra
.698 .642 .79 r
.52695 .26496 .53291 .27725 .54393 .2706 .53799 .25846 Mtetra
.703 .647 .791 r
.53799 .25846 .54393 .2706 .55497 .26375 .54905 .25177 Mtetra
.708 .652 .792 r
.54905 .25177 .55497 .26375 .56603 .25669 .56013 .2449 Mtetra
.712 .658 .794 r
.56013 .2449 .56603 .25669 .57711 .24944 .57124 .23786 Mtetra
.717 .664 .796 r
.57124 .23786 .57711 .24944 .58821 .24202 .58236 .23069 Mtetra
.721 .67 .8 r
.58236 .23069 .58821 .24202 .59933 .23447 .59351 .22342 Mtetra
.724 .677 .804 r
.59351 .22342 .59933 .23447 .61046 .22684 .60467 .21609 Mtetra
.728 .685 .809 r
.60467 .21609 .61046 .22684 .62161 .2192 .61586 .20872 Mtetra
.731 .692 .813 r
.61586 .20872 .62161 .2192 .63278 .2116 .62706 .20134 Mtetra
.734 .698 .816 r
.62706 .20134 .63278 .2116 .64398 .20402 .63829 .19386 Mtetra
.72 .695 .826 r
.63829 .19386 .64398 .20402 .65518 .19635 .64956 .18711 Mtetra
.659 .692 .87 r
.64956 .18711 .65518 .19635 .6665 .19059 .66098 .18299 Mtetra
.664 .741 .908 r
.66098 .18299 .6665 .19059 .67793 .18648 .67245 .17885 Mtetra
.67245 .17885 .67793 .18648 .68942 .18235 .68396 .17469 Mtetra
.68396 .17469 .68942 .18235 .70094 .17821 .69552 .17052 Mtetra
.69552 .17052 .70094 .17821 .71252 .17405 .70713 .16633 Mtetra
.70713 .16633 .71252 .17405 .72414 .16988 .71878 .16212 Mtetra
.71878 .16212 .72414 .16988 .73581 .16568 .73049 .1579 Mtetra
.73049 .1579 .73581 .16568 .74753 .16147 .74224 .15365 Mtetra
.74224 .15365 .74753 .16147 .75929 .15724 .75404 .14939 Mtetra
.75404 .14939 .75929 .15724 .77111 .153 .76589 .14512 Mtetra
.76589 .14512 .77111 .153 .78297 .14874 .77778 .14082 Mtetra
.14421 .36077 .15101 .3671 .16049 .36368 .15371 .35733 Mtetra
.15371 .35733 .16049 .36368 .17001 .36024 .16325 .35387 Mtetra
.16325 .35387 .17001 .36024 .17956 .35679 .17282 .35039 Mtetra
.17282 .35039 .17956 .35679 .18915 .35333 .18243 .34691 Mtetra
.18243 .34691 .18915 .35333 .19878 .34986 .19208 .34341 Mtetra
.19208 .34341 .19878 .34986 .20844 .34637 .20176 .3399 Mtetra
.20176 .3399 .20844 .34637 .21814 .34287 .21148 .33637 Mtetra
.21148 .33637 .21814 .34287 .22787 .33935 .22124 .33283 Mtetra
.22124 .33283 .22787 .33935 .23764 .33583 .23103 .32928 Mtetra
.23103 .32928 .23764 .33583 .24745 .33229 .24086 .32572 Mtetra
.24086 .32572 .24745 .33229 .25729 .32873 .25072 .32214 Mtetra
.25072 .32214 .25729 .32873 .26696 .32775 .26062 .31854 Mtetra
.531 .615 .881 r
.26062 .31854 .26696 .32775 .27663 .32747 .27031 .31809 Mtetra
.535 .613 .877 r
.27031 .31809 .27663 .32747 .28635 .32713 .28006 .31758 Mtetra
.54 .612 .873 r
.28006 .31758 .28635 .32713 .29614 .32677 .28987 .31697 Mtetra
.544 .608 .867 r
.28987 .31697 .29614 .32677 .30599 .32639 .29974 .3163 Mtetra
.548 .603 .861 r
.29974 .3163 .30599 .32639 .31589 .32597 .30967 .31557 Mtetra
.552 .599 .854 r
.30967 .31557 .31589 .32597 .32586 .32546 .31966 .31475 Mtetra
.557 .595 .847 r
.31966 .31475 .32586 .32546 .3359 .32482 .32972 .31384 Mtetra
.562 .592 .841 r
.32972 .31384 .3359 .32482 .346 .32403 .33984 .3128 Mtetra
.567 .59 .836 r
.33984 .3128 .346 .32403 .35617 .32307 .35002 .31162 Mtetra
.573 .589 .831 r
.35002 .31162 .35617 .32307 .3664 .32194 .36027 .31028 Mtetra
.578 .589 .827 r
.36027 .31028 .3664 .32194 .3767 .32062 .37058 .30876 Mtetra
.585 .589 .823 r
.37058 .30876 .3767 .32062 .38707 .31908 .38096 .30704 Mtetra
.592 .59 .818 r
.38096 .30704 .38707 .31908 .39749 .3173 .3914 .30507 Mtetra
.6 .591 .814 r
.3914 .30507 .39749 .3173 .40799 .31524 .4019 .30283 Mtetra
.609 .593 .81 r
.4019 .30283 .40799 .31524 .41855 .31282 .41247 .30025 Mtetra
.618 .595 .805 r
.41247 .30025 .41855 .31282 .42917 .30999 .4231 .29729 Mtetra
.628 .599 .801 r
.4231 .29729 .42917 .30999 .43985 .30669 .43379 .29392 Mtetra
.639 .603 .798 r
.43379 .29392 .43985 .30669 .45059 .3029 .44453 .29009 Mtetra
.649 .608 .795 r
.44453 .29009 .45059 .3029 .46138 .29862 .45533 .28583 Mtetra
.658 .614 .793 r
.45533 .28583 .46138 .29862 .47221 .29386 .46618 .28114 Mtetra
.667 .619 .792 r
.46618 .28114 .47221 .29386 .48309 .28869 .47706 .27606 Mtetra
.674 .625 .791 r
.47706 .27606 .48309 .28869 .49401 .28316 .48799 .27064 Mtetra
.681 .63 .791 r
.48799 .27064 .49401 .28316 .50496 .27734 .49895 .26494 Mtetra
.687 .635 .792 r
.49895 .26494 .50496 .27734 .51594 .27126 .50995 .25899 Mtetra
.692 .64 .793 r
.50995 .25899 .51594 .27126 .52695 .26496 .52098 .25283 Mtetra
.697 .645 .794 r
.52098 .25283 .52695 .26496 .53799 .25846 .53203 .24647 Mtetra
.701 .649 .795 r
.53203 .24647 .53799 .25846 .54905 .25177 .54311 .23995 Mtetra
.705 .654 .797 r
.54311 .23995 .54905 .25177 .56013 .2449 .55421 .23327 Mtetra
.709 .66 .799 r
.55421 .23327 .56013 .2449 .57124 .23786 .56534 .22645 Mtetra
.713 .666 .802 r
.56534 .22645 .57124 .23786 .58236 .23069 .57649 .21953 Mtetra
.717 .673 .805 r
.57649 .21953 .58236 .23069 .59351 .22342 .58766 .21251 Mtetra
.721 .679 .809 r
.58766 .21251 .59351 .22342 .60467 .21609 .59886 .20542 Mtetra
.724 .686 .813 r
.59886 .20542 .60467 .21609 .61586 .20872 .61007 .19825 Mtetra
.728 .692 .815 r
.61007 .19825 .61586 .20872 .62706 .20134 .62131 .19097 Mtetra
.731 .696 .817 r
.62131 .19097 .62706 .20134 .63829 .19386 .63257 .18362 Mtetra
.654 .667 .85 r
.63257 .18362 .63829 .19386 .64956 .18711 .64397 .17949 Mtetra
.664 .741 .908 r
.64397 .17949 .64956 .18711 .66098 .18299 .65542 .17533 Mtetra
.65542 .17533 .66098 .18299 .67245 .17885 .66692 .17116 Mtetra
.66692 .17116 .67245 .17885 .68396 .17469 .67847 .16697 Mtetra
.67847 .16697 .68396 .17469 .69552 .17052 .69006 .16277 Mtetra
.69006 .16277 .69552 .17052 .70713 .16633 .7017 .15855 Mtetra
.7017 .15855 .70713 .16633 .71878 .16212 .71339 .15431 Mtetra
.71339 .15431 .71878 .16212 .73049 .1579 .72512 .15005 Mtetra
.72512 .15005 .73049 .1579 .74224 .15365 .73691 .14577 Mtetra
.73691 .14577 .74224 .15365 .75404 .14939 .74874 .14148 Mtetra
.74874 .14148 .75404 .14939 .76589 .14512 .76063 .13717 Mtetra
.76063 .13717 .76589 .14512 .77778 .14082 .77256 .13284 Mtetra
.13736 .3544 .14421 .36077 .15371 .35733 .14689 .35093 Mtetra
.14689 .35093 .15371 .35733 .16325 .35387 .15644 .34744 Mtetra
.15644 .34744 .16325 .35387 .17282 .35039 .16604 .34395 Mtetra
.16604 .34395 .17282 .35039 .18243 .34691 .17567 .34044 Mtetra
.17567 .34044 .18243 .34691 .19208 .34341 .18534 .33691 Mtetra
.18534 .33691 .19208 .34341 .20176 .3399 .19504 .33338 Mtetra
.19504 .33338 .20176 .3399 .21148 .33637 .20478 .32983 Mtetra
.20478 .32983 .21148 .33637 .22124 .33283 .21455 .32626 Mtetra
.21455 .32626 .22124 .33283 .23103 .32928 .22437 .32269 Mtetra
.22437 .32269 .23103 .32928 .24086 .32572 .23422 .3191 Mtetra
.23422 .3191 .24086 .32572 .25072 .32214 .24411 .31549 Mtetra
.24411 .31549 .25072 .32214 .26062 .31854 .25403 .31188 Mtetra
.654 .739 .912 r
.25403 .31188 .26062 .31854 .27031 .31809 .26397 .30849 Mtetra
.536 .608 .873 r
.26397 .30849 .27031 .31809 .28006 .31758 .27373 .30795 Mtetra
.546 .613 .871 r
.27373 .30795 .28006 .31758 .28987 .31697 .28355 .30719 Mtetra
.552 .613 .867 r
.28355 .30719 .28987 .31697 .29974 .3163 .29345 .3063 Mtetra
.557 .611 .862 r
.29345 .3063 .29974 .3163 .30967 .31557 .3034 .3053 Mtetra
.561 .607 .856 r
.3034 .3053 .30967 .31557 .31966 .31475 .31342 .30421 Mtetra
.565 .604 .85 r
.31342 .30421 .31966 .31475 .32972 .31384 .32349 .30303 Mtetra
.57 .601 .845 r
.32349 .30303 .32972 .31384 .33984 .3128 .33363 .30174 Mtetra
.574 .598 .839 r
.33363 .30174 .33984 .3128 .35002 .31162 .34383 .30032 Mtetra
.579 .596 .834 r
.34383 .30032 .35002 .31162 .36027 .31028 .3541 .29877 Mtetra
.584 .595 .83 r
.3541 .29877 .36027 .31028 .37058 .30876 .36442 .29705 Mtetra
.59 .595 .825 r
.36442 .29705 .37058 .30876 .38096 .30704 .37481 .29513 Mtetra
.596 .595 .821 r
.37481 .29513 .38096 .30704 .3914 .30507 .38527 .29299 Mtetra
.604 .596 .817 r
.38527 .29299 .3914 .30507 .4019 .30283 .39578 .29058 Mtetra
.612 .598 .813 r
.39578 .29058 .4019 .30283 .41247 .30025 .40636 .28787 Mtetra
.621 .601 .809 r
.40636 .28787 .41247 .30025 .4231 .29729 .417 .2848 Mtetra
.63 .604 .805 r
.417 .2848 .4231 .29729 .43379 .29392 .4277 .28135 Mtetra
.64 .608 .802 r
.4277 .28135 .43379 .29392 .44453 .29009 .43845 .27749 Mtetra
.649 .612 .799 r
.43845 .27749 .44453 .29009 .45533 .28583 .44926 .27324 Mtetra
.658 .617 .797 r
.44926 .27324 .45533 .28583 .46618 .28114 .46011 .26859 Mtetra
.666 .622 .796 r
.46011 .26859 .46618 .28114 .47706 .27606 .47101 .26359 Mtetra
.673 .627 .795 r
.47101 .26359 .47706 .27606 .48799 .27064 .48195 .25828 Mtetra
.679 .632 .795 r
.48195 .25828 .48799 .27064 .49895 .26494 .49292 .25269 Mtetra
.685 .637 .796 r
.49292 .25269 .49895 .26494 .50995 .25899 .50393 .24686 Mtetra
.69 .642 .797 r
.50393 .24686 .50995 .25899 .52098 .25283 .51497 .24084 Mtetra
.694 .647 .798 r
.51497 .24084 .52098 .25283 .53203 .24647 .52604 .23464 Mtetra
.698 .652 .8 r
.52604 .23464 .53203 .24647 .54311 .23995 .53714 .22829 Mtetra
.702 .657 .802 r
.53714 .22829 .54311 .23995 .55421 .23327 .54826 .2218 Mtetra
.706 .663 .804 r
.54826 .2218 .55421 .23327 .56534 .22645 .55942 .2152 Mtetra
.71 .669 .807 r
.55942 .2152 .56534 .22645 .57649 .21953 .57059 .20849 Mtetra
.714 .675 .81 r
.57059 .20849 .57649 .21953 .58766 .21251 .58179 .20168 Mtetra
.718 .681 .813 r
.58179 .20168 .58766 .21251 .59886 .20542 .59301 .19476 Mtetra
.723 .687 .815 r
.59301 .19476 .59886 .20542 .61007 .19825 .60426 .18768 Mtetra
.728 .691 .815 r
.60426 .18768 .61007 .19825 .62131 .19097 .61552 .18037 Mtetra
.66 .662 .841 r
.61552 .18037 .62131 .19097 .63257 .18362 .6269 .17597 Mtetra
.664 .741 .908 r
.6269 .17597 .63257 .18362 .64397 .17949 .63834 .1718 Mtetra
.63834 .1718 .64397 .17949 .65542 .17533 .64982 .16762 Mtetra
.64982 .16762 .65542 .17533 .66692 .17116 .66135 .16342 Mtetra
.66135 .16342 .66692 .17116 .67847 .16697 .67293 .1592 Mtetra
.67293 .1592 .67847 .16697 .69006 .16277 .68455 .15496 Mtetra
.68455 .15496 .69006 .16277 .7017 .15855 .69623 .15071 Mtetra
.69623 .15071 .7017 .15855 .71339 .15431 .70795 .14643 Mtetra
.70795 .14643 .71339 .15431 .72512 .15005 .71972 .14214 Mtetra
.71972 .14214 .72512 .15005 .73691 .14577 .73154 .13784 Mtetra
.73154 .13784 .73691 .14577 .74874 .14148 .74341 .13351 Mtetra
.74341 .13351 .74874 .14148 .76063 .13717 .75532 .12917 Mtetra
.75532 .12917 .76063 .13717 .77256 .13284 .76729 .1248 Mtetra
.13047 .34798 .13736 .3544 .14689 .35093 .14001 .34449 Mtetra
.14001 .34449 .14689 .35093 .15644 .34744 .14959 .34098 Mtetra
.14959 .34098 .15644 .34744 .16604 .34395 .15921 .33746 Mtetra
.15921 .33746 .16604 .34395 .17567 .34044 .16886 .33392 Mtetra
.16886 .33392 .17567 .34044 .18534 .33691 .17854 .33037 Mtetra
.17854 .33037 .18534 .33691 .19504 .33338 .18827 .32681 Mtetra
.18827 .32681 .19504 .33338 .20478 .32983 .19803 .32324 Mtetra
.19803 .32324 .20478 .32983 .21455 .32626 .20783 .31965 Mtetra
.20783 .31965 .21455 .32626 .22437 .32269 .21766 .31605 Mtetra
.21766 .31605 .22437 .32269 .23422 .3191 .22753 .31243 Mtetra
.22753 .31243 .23422 .3191 .24411 .31549 .23744 .3088 Mtetra
.23744 .3088 .24411 .31549 .25403 .31188 .24739 .30516 Mtetra
.24739 .30516 .25403 .31188 .26397 .30849 .25738 .3015 Mtetra
.654 .731 .906 r
.25738 .3015 .26397 .30849 .27373 .30795 .26738 .29808 Mtetra
.546 .608 .867 r
.26738 .29808 .27373 .30795 .28355 .30719 .27721 .29731 Mtetra
.556 .614 .866 r
.27721 .29731 .28355 .30719 .29345 .3063 .28712 .2963 Mtetra
.563 .615 .862 r
.28712 .2963 .29345 .3063 .3034 .3053 .29709 .29512 Mtetra
.569 .614 .858 r
.29709 .29512 .3034 .3053 .31342 .30421 .30713 .2938 Mtetra
.573 .611 .853 r
.30713 .2938 .31342 .30421 .32349 .30303 .31723 .29237 Mtetra
.577 .609 .847 r
.31723 .29237 .32349 .30303 .33363 .30174 .32739 .29083 Mtetra
.581 .606 .842 r
.32739 .29083 .33363 .30174 .34383 .30032 .33761 .28917 Mtetra
.586 .603 .837 r
.33761 .28917 .34383 .30032 .3541 .29877 .34789 .28738 Mtetra
.59 .602 .832 r
.34789 .28738 .3541 .29877 .36442 .29705 .35823 .28545 Mtetra
.595 .601 .827 r
.35823 .28545 .36442 .29705 .37481 .29513 .36864 .28334 Mtetra
.601 .601 .823 r
.36864 .28334 .37481 .29513 .38527 .29299 .3791 .28102 Mtetra
.608 .601 .819 r
.3791 .28102 .38527 .29299 .39578 .29058 .38963 .27845 Mtetra
.615 .603 .815 r
.38963 .27845 .39578 .29058 .40636 .28787 .40022 .2756 Mtetra
.624 .605 .811 r
.40022 .2756 .40636 .28787 .417 .2848 .41087 .27243 Mtetra
.632 .608 .807 r
.41087 .27243 .417 .2848 .4277 .28135 .42158 .2689 Mtetra
.641 .611 .804 r
.42158 .2689 .4277 .28135 .43845 .27749 .43234 .26502 Mtetra
.649 .615 .802 r
.43234 .26502 .43845 .27749 .44926 .27324 .44315 .26076 Mtetra
.657 .62 .8 r
.44315 .26076 .44926 .27324 .46011 .26859 .45402 .25616 Mtetra
.665 .624 .799 r
.45402 .25616 .46011 .26859 .47101 .26359 .46492 .25123 Mtetra
.671 .629 .799 r
.46492 .25123 .47101 .26359 .48195 .25828 .47587 .24602 Mtetra
.677 .634 .799 r
.47587 .24602 .48195 .25828 .49292 .25269 .48686 .24054 Mtetra
.683 .639 .8 r
.48686 .24054 .49292 .25269 .50393 .24686 .49788 .23485 Mtetra
.687 .644 .801 r
.49788 .23485 .50393 .24686 .51497 .24084 .50894 .22898 Mtetra
.692 .649 .802 r
.50894 .22898 .51497 .24084 .52604 .23464 .52003 .22295 Mtetra
.696 .654 .804 r
.52003 .22295 .52604 .23464 .53714 .22829 .53114 .21678 Mtetra
.7 .659 .807 r
.53114 .21678 .53714 .22829 .54826 .2218 .54229 .21049 Mtetra
.703 .665 .809 r
.54229 .21049 .54826 .2218 .55942 .2152 .55346 .20408 Mtetra
.707 .671 .812 r
.55346 .20408 .55942 .2152 .57059 .20849 .56466 .19754 Mtetra
.712 .676 .814 r
.56466 .19754 .57059 .20849 .58179 .20168 .57589 .19086 Mtetra
.717 .682 .815 r
.57589 .19086 .58179 .20168 .59301 .19476 .58714 .18399 Mtetra
.723 .686 .814 r
.58714 .18399 .59301 .19476 .60426 .18768 .5984 .17686 Mtetra
.658 .658 .838 r
.5984 .17686 .60426 .18768 .61552 .18037 .60977 .17245 Mtetra
.663 .734 .902 r
.60977 .17245 .61552 .18037 .6269 .17597 .62119 .16826 Mtetra
.664 .741 .908 r
.62119 .16826 .6269 .17597 .63834 .1718 .63266 .16406 Mtetra
.63266 .16406 .63834 .1718 .64982 .16762 .64418 .15985 Mtetra
.64418 .15985 .64982 .16762 .66135 .16342 .65574 .15561 Mtetra
.65574 .15561 .66135 .16342 .67293 .1592 .66735 .15136 Mtetra
.66735 .15136 .67293 .1592 .68455 .15496 .67901 .14709 Mtetra
.67901 .14709 .68455 .15496 .69623 .15071 .69071 .1428 Mtetra
.69071 .1428 .69623 .15071 .70795 .14643 .70247 .1385 Mtetra
.70247 .1385 .70795 .14643 .71972 .14214 .71427 .13418 Mtetra
.71427 .13418 .71972 .14214 .73154 .13784 .72613 .12984 Mtetra
.72613 .12984 .73154 .13784 .74341 .13351 .73803 .12548 Mtetra
.73803 .12548 .74341 .13351 .75532 .12917 .74998 .1211 Mtetra
.74998 .1211 .75532 .12917 .76729 .1248 .76198 .1167 Mtetra
.12353 .34152 .13047 .34798 .14001 .34449 .13309 .338 Mtetra
.13309 .338 .14001 .34449 .14959 .34098 .14269 .33447 Mtetra
.14269 .33447 .14959 .34098 .15921 .33746 .15233 .33092 Mtetra
.15233 .33092 .15921 .33746 .16886 .33392 .162 .32736 Mtetra
.162 .32736 .16886 .33392 .17854 .33037 .17171 .32379 Mtetra
.17171 .32379 .17854 .33037 .18827 .32681 .18145 .3202 Mtetra
.18145 .3202 .18827 .32681 .19803 .32324 .19123 .3166 Mtetra
.19123 .3166 .19803 .32324 .20783 .31965 .20105 .31299 Mtetra
.20105 .31299 .20783 .31965 .21766 .31605 .21091 .30936 Mtetra
.21091 .30936 .21766 .31605 .22753 .31243 .2208 .30572 Mtetra
.2208 .30572 .22753 .31243 .23744 .3088 .23073 .30207 Mtetra
.23073 .30207 .23744 .3088 .24739 .30516 .2407 .2984 Mtetra
.2407 .2984 .24739 .30516 .25738 .3015 .25071 .29472 Mtetra
.25071 .29472 .25738 .3015 .26738 .29808 .26076 .29102 Mtetra
.663 .734 .902 r
.26076 .29102 .26738 .29808 .27721 .29731 .27085 .28731 Mtetra
.56 .614 .863 r
.27085 .28731 .27721 .29731 .28712 .2963 .28077 .28617 Mtetra
.566 .614 .86 r
.28077 .28617 .28712 .2963 .29709 .29512 .29075 .28491 Mtetra
.574 .617 .857 r
.29075 .28491 .29709 .29512 .30713 .2938 .30081 .28344 Mtetra
.58 .617 .853 r
.30081 .28344 .30713 .2938 .31723 .29237 .31093 .2818 Mtetra
.584 .615 .849 r
.31093 .2818 .31723 .29237 .32739 .29083 .32111 .28004 Mtetra
.589 .613 .844 r
.32111 .28004 .32739 .29083 .33761 .28917 .33135 .27814 Mtetra
.592 .61 .839 r
.33135 .27814 .33761 .28917 .34789 .28738 .34165 .27613 Mtetra
.597 .608 .834 r
.34165 .27613 .34789 .28738 .35823 .28545 .35201 .27397 Mtetra
.601 .607 .829 r
.35201 .27397 .35823 .28545 .36864 .28334 .36243 .27165 Mtetra
.606 .606 .825 r
.36243 .27165 .36864 .28334 .3791 .28102 .37291 .26914 Mtetra
.612 .606 .82 r
.37291 .26914 .3791 .28102 .38963 .27845 .38345 .2664 Mtetra
.619 .607 .816 r
.38345 .2664 .38963 .27845 .40022 .2756 .39405 .26341 Mtetra
.626 .608 .813 r
.39405 .26341 .40022 .2756 .41087 .27243 .40471 .26013 Mtetra
.634 .61 .809 r
.40471 .26013 .41087 .27243 .42158 .2689 .41543 .25653 Mtetra
.641 .614 .806 r
.41543 .25653 .42158 .2689 .43234 .26502 .4262 .25261 Mtetra
.649 .617 .804 r
.4262 .25261 .43234 .26502 .44315 .26076 .43702 .24837 Mtetra
.656 .621 .803 r
.43702 .24837 .44315 .26076 .45402 .25616 .4479 .24381 Mtetra
.663 .626 .802 r
.4479 .24381 .45402 .25616 .46492 .25123 .45881 .23896 Mtetra
.669 .63 .802 r
.45881 .23896 .46492 .25123 .47587 .24602 .46977 .23384 Mtetra
.675 .635 .802 r
.46977 .23384 .47587 .24602 .48686 .24054 .48077 .2285 Mtetra
.68 .64 .803 r
.48077 .2285 .48686 .24054 .49788 .23485 .49181 .22296 Mtetra
.684 .645 .805 r
.49181 .22296 .49788 .23485 .50894 .22898 .50288 .21725 Mtetra
.689 .65 .807 r
.50288 .21725 .50894 .22898 .52003 .22295 .51398 .21139 Mtetra
.693 .656 .809 r
.51398 .21139 .52003 .22295 .53114 .21678 .52512 .20539 Mtetra
.697 .661 .811 r
.52512 .20539 .53114 .21678 .54229 .21049 .53629 .19927 Mtetra
.701 .667 .813 r
.53629 .19927 .54229 .21049 .55346 .20408 .54748 .193 Mtetra
.706 .672 .815 r
.54748 .193 .55346 .20408 .56466 .19754 .5587 .18655 Mtetra
.711 .677 .815 r
.5587 .18655 .56466 .19754 .57589 .19086 .56995 .17989 Mtetra
.714 .679 .814 r
.56995 .17989 .57589 .19086 .58714 .18399 .58123 .17309 Mtetra
.651 .653 .839 r
.58123 .17309 .58714 .18399 .5984 .17686 .59259 .16891 Mtetra
.663 .734 .902 r
.59259 .16891 .5984 .17686 .60977 .17245 .60399 .16471 Mtetra
.664 .741 .908 r
.60399 .16471 .60977 .17245 .62119 .16826 .61544 .1605 Mtetra
.61544 .1605 .62119 .16826 .63266 .16406 .62694 .15627 Mtetra
.62694 .15627 .63266 .16406 .64418 .15985 .63849 .15202 Mtetra
.63849 .15202 .64418 .15985 .65574 .15561 .65009 .14775 Mtetra
.65009 .14775 .65574 .15561 .66735 .15136 .66173 .14347 Mtetra
.66173 .14347 .66735 .15136 .67901 .14709 .67342 .13916 Mtetra
.67342 .13916 .67901 .14709 .69071 .1428 .68516 .13484 Mtetra
.68516 .13484 .69071 .1428 .70247 .1385 .69695 .1305 Mtetra
.69695 .1305 .70247 .1385 .71427 .13418 .70879 .12615 Mtetra
.70879 .12615 .71427 .13418 .72613 .12984 .72067 .12177 Mtetra
.72067 .12177 .72613 .12984 .73803 .12548 .73261 .11738 Mtetra
.73261 .11738 .73803 .12548 .74998 .1211 .7446 .11297 Mtetra
.7446 .11297 .74998 .1211 .76198 .1167 .75663 .10854 Mtetra
.11654 .33501 .12353 .34152 .13309 .338 .12612 .33147 Mtetra
.12612 .33147 .13309 .338 .14269 .33447 .13574 .32791 Mtetra
.13574 .32791 .14269 .33447 .15233 .33092 .1454 .32434 Mtetra
.1454 .32434 .15233 .33092 .162 .32736 .15509 .32076 Mtetra
.15509 .32076 .162 .32736 .17171 .32379 .16482 .31716 Mtetra
.16482 .31716 .17171 .32379 .18145 .3202 .17459 .31355 Mtetra
.17459 .31355 .18145 .3202 .19123 .3166 .18439 .30992 Mtetra
.18439 .30992 .19123 .3166 .20105 .31299 .19423 .30628 Mtetra
.19423 .30628 .20105 .31299 .21091 .30936 .20411 .30263 Mtetra
.20411 .30263 .21091 .30936 .2208 .30572 .21402 .29896 Mtetra
.21402 .29896 .2208 .30572 .23073 .30207 .22398 .29528 Mtetra
.22398 .29528 .23073 .30207 .2407 .2984 .23397 .29159 Mtetra
.23397 .29159 .2407 .2984 .25071 .29472 .244 .28788 Mtetra
.244 .28788 .25071 .29472 .26076 .29102 .25407 .28416 Mtetra
.25407 .28416 .26076 .29102 .27085 .28731 .26418 .28042 Mtetra
.26418 .28042 .27085 .28731 .28077 .28617 .27433 .27667 Mtetra
.599 .645 .868 r
.27433 .27667 .28077 .28617 .29075 .28491 .28439 .27451 Mtetra
.574 .614 .854 r
.28439 .27451 .29075 .28491 .30081 .28344 .29445 .27301 Mtetra
.583 .618 .852 r
.29445 .27301 .30081 .28344 .31093 .2818 .30459 .27126 Mtetra
.59 .619 .849 r
.30459 .27126 .31093 .2818 .32111 .28004 .31478 .26931 Mtetra
.595 .618 .845 r
.31478 .26931 .32111 .28004 .33135 .27814 .32504 .26722 Mtetra
.599 .617 .84 r
.32504 .26722 .33135 .27814 .34165 .27613 .33537 .26498 Mtetra
.603 .615 .836 r
.33537 .26498 .34165 .27613 .35201 .27397 .34574 .2626 Mtetra
.607 .613 .831 r
.34574 .2626 .35201 .27397 .36243 .27165 .35618 .26006 Mtetra
.612 .611 .826 r
.35618 .26006 .36243 .27165 .37291 .26914 .36668 .25735 Mtetra
.617 .611 .822 r
.36668 .25735 .37291 .26914 .38345 .2664 .37724 .25444 Mtetra
.622 .611 .818 r
.37724 .25444 .38345 .2664 .39405 .26341 .38785 .25129 Mtetra
.629 .612 .814 r
.38785 .25129 .39405 .26341 .40471 .26013 .39852 .2479 Mtetra
.635 .613 .811 r
.39852 .2479 .40471 .26013 .41543 .25653 .40925 .24423 Mtetra
.642 .616 .808 r
.40925 .24423 .41543 .25653 .4262 .25261 .42003 .24028 Mtetra
.649 .619 .806 r
.42003 .24028 .4262 .25261 .43702 .24837 .43086 .23604 Mtetra
.655 .623 .805 r
.43086 .23604 .43702 .24837 .4479 .24381 .44175 .23153 Mtetra
.661 .627 .805 r
.44175 .23153 .4479 .24381 .45881 .23896 .45267 .22676 Mtetra
.667 .631 .805 r
.45267 .22676 .45881 .23896 .46977 .23384 .46364 .22176 Mtetra
.672 .636 .806 r
.46364 .22176 .46977 .23384 .48077 .2285 .47466 .21655 Mtetra
.677 .641 .807 r
.47466 .21655 .48077 .2285 .49181 .22296 .4857 .21117 Mtetra
.681 .647 .809 r
.4857 .21117 .49181 .22296 .50288 .21725 .49679 .20562 Mtetra
.686 .652 .811 r
.49679 .20562 .50288 .21725 .51398 .21139 .50791 .19992 Mtetra
.69 .657 .813 r
.50791 .19992 .51398 .21139 .52512 .20539 .51906 .19407 Mtetra
.694 .663 .814 r
.51906 .19407 .52512 .20539 .53629 .19927 .53025 .18806 Mtetra
.7 .667 .815 r
.53025 .18806 .53629 .19927 .54748 .193 .54147 .18184 Mtetra
.705 .672 .814 r
.54147 .18184 .54748 .193 .5587 .18655 .55271 .17537 Mtetra
.691 .665 .82 r
.55271 .17537 .5587 .18655 .56995 .17989 .56399 .16955 Mtetra
.654 .668 .851 r
.56399 .16955 .56995 .17989 .58123 .17309 .57534 .16536 Mtetra
.664 .741 .908 r
.57534 .16536 .58123 .17309 .59259 .16891 .58673 .16115 Mtetra
.58673 .16115 .59259 .16891 .60399 .16471 .59817 .15692 Mtetra
.59817 .15692 .60399 .16471 .61544 .1605 .60965 .15267 Mtetra
.60965 .15267 .61544 .1605 .62694 .15627 .62118 .14841 Mtetra
.62118 .14841 .62694 .15627 .63849 .15202 .63276 .14413 Mtetra
.63276 .14413 .63849 .15202 .65009 .14775 .64439 .13983 Mtetra
.64439 .13983 .65009 .14775 .66173 .14347 .65606 .13551 Mtetra
.65606 .13551 .66173 .14347 .67342 .13916 .66779 .13117 Mtetra
.66779 .13117 .67342 .13916 .68516 .13484 .67956 .12682 Mtetra
.67956 .12682 .68516 .13484 .69695 .1305 .69138 .12245 Mtetra
.69138 .12245 .69695 .1305 .70879 .12615 .70325 .11806 Mtetra
.70325 .11806 .70879 .12615 .72067 .12177 .71518 .11365 Mtetra
.71518 .11365 .72067 .12177 .73261 .11738 .72715 .10922 Mtetra
.72715 .10922 .73261 .11738 .7446 .11297 .73917 .10478 Mtetra
.73917 .10478 .7446 .11297 .75663 .10854 .75124 .10031 Mtetra
.1095 .32846 .11654 .33501 .12612 .33147 .11911 .32489 Mtetra
.11911 .32489 .12612 .33147 .13574 .32791 .12875 .32131 Mtetra
.12875 .32131 .13574 .32791 .1454 .32434 .13842 .31771 Mtetra
.13842 .31771 .1454 .32434 .15509 .32076 .14813 .3141 Mtetra
.14813 .3141 .15509 .32076 .16482 .31716 .15789 .31048 Mtetra
.15789 .31048 .16482 .31716 .17459 .31355 .16767 .30684 Mtetra
.16767 .30684 .17459 .31355 .18439 .30992 .1775 .30319 Mtetra
.1775 .30319 .18439 .30992 .19423 .30628 .18736 .29953 Mtetra
.18736 .29953 .19423 .30628 .20411 .30263 .19726 .29585 Mtetra
.19726 .29585 .20411 .30263 .21402 .29896 .2072 .29216 Mtetra
.2072 .29216 .21402 .29896 .22398 .29528 .21717 .28845 Mtetra
.21717 .28845 .22398 .29528 .23397 .29159 .22719 .28473 Mtetra
.22719 .28473 .23397 .29159 .244 .28788 .23724 .28099 Mtetra
.23724 .28099 .244 .28788 .25407 .28416 .24733 .27724 Mtetra
.24733 .27724 .25407 .28416 .26418 .28042 .25747 .27348 Mtetra
.25747 .27348 .26418 .28042 .27433 .27667 .26764 .2697 Mtetra
.26764 .2697 .27433 .27667 .28439 .27451 .27785 .26591 Mtetra
.65 .691 .874 r
.27785 .26591 .28439 .27451 .29445 .27301 .28808 .26234 Mtetra
.581 .613 .849 r
.28808 .26234 .29445 .27301 .30459 .27126 .29822 .2606 Mtetra
.591 .619 .848 r
.29822 .2606 .30459 .27126 .31478 .26931 .30843 .25858 Mtetra
.599 .621 .845 r
.30843 .25858 .31478 .26931 .32504 .26722 .31871 .25634 Mtetra
.604 .621 .841 r
.31871 .25634 .32504 .26722 .33537 .26498 .32905 .25392 Mtetra
.609 .62 .837 r
.32905 .25392 .33537 .26498 .34574 .2626 .33944 .25134 Mtetra
.613 .619 .833 r
.33944 .25134 .34574 .2626 .35618 .26006 .3499 .24859 Mtetra
.617 .617 .828 r
.3499 .24859 .35618 .26006 .36668 .25735 .36042 .24568 Mtetra
.622 .616 .824 r
.36042 .24568 .36668 .25735 .37724 .25444 .37099 .24259 Mtetra
.626 .616 .82 r
.37099 .24259 .37724 .25444 .38785 .25129 .38162 .2393 Mtetra
.632 .616 .816 r
.38162 .2393 .38785 .25129 .39852 .2479 .3923 .23578 Mtetra
.637 .617 .813 r
.3923 .23578 .39852 .2479 .40925 .24423 .40304 .23204 Mtetra
.643 .619 .811 r
.40304 .23204 .40925 .24423 .42003 .24028 .41383 .22806 Mtetra
.648 .622 .809 r
.41383 .22806 .42003 .24028 .43086 .23604 .42468 .22383 Mtetra
.654 .625 .808 r
.42468 .22383 .43086 .23604 .44175 .23153 .43557 .21937 Mtetra
.659 .629 .808 r
.43557 .21937 .44175 .23153 .45267 .22676 .4465 .21469 Mtetra
.664 .633 .809 r
.4465 .21469 .45267 .22676 .46364 .22176 .45748 .2098 Mtetra
.669 .638 .81 r
.45748 .2098 .46364 .22176 .47466 .21655 .46851 .20473 Mtetra
.674 .643 .811 r
.46851 .20473 .47466 .21655 .4857 .21117 .47957 .19949 Mtetra
.679 .648 .813 r
.47957 .19949 .4857 .21117 .49679 .20562 .49067 .19408 Mtetra
.683 .654 .814 r
.49067 .19408 .49679 .20562 .50791 .19992 .50181 .1885 Mtetra
.688 .659 .816 r
.50181 .1885 .50791 .19992 .51906 .19407 .51298 .18273 Mtetra
.694 .663 .815 r
.51298 .18273 .51906 .19407 .53025 .18806 .52419 .17673 Mtetra
.7 .667 .814 r
.52419 .17673 .53025 .18806 .54147 .18184 .53542 .17044 Mtetra
.655 .646 .829 r
.53542 .17044 .54147 .18184 .55271 .17537 .5467 .16601 Mtetra
.658 .693 .871 r
.5467 .16601 .55271 .17537 .56399 .16955 .55803 .1618 Mtetra
.664 .741 .908 r
.55803 .1618 .56399 .16955 .57534 .16536 .56941 .15757 Mtetra
.56941 .15757 .57534 .16536 .58673 .16115 .58083 .15333 Mtetra
.58083 .15333 .58673 .16115 .59817 .15692 .59229 .14906 Mtetra
.59229 .14906 .59817 .15692 .60965 .15267 .60381 .14479 Mtetra
.60381 .14479 .60965 .15267 .62118 .14841 .61537 .14049 Mtetra
.61537 .14049 .62118 .14841 .63276 .14413 .62699 .13617 Mtetra
.62699 .13617 .63276 .14413 .64439 .13983 .63865 .13184 Mtetra
.63865 .13184 .64439 .13983 .65606 .13551 .65035 .12749 Mtetra
.65035 .12749 .65606 .13551 .66779 .13117 .66211 .12312 Mtetra
.66211 .12312 .66779 .13117 .67956 .12682 .67392 .11873 Mtetra
.67392 .11873 .67956 .12682 .69138 .12245 .68578 .11433 Mtetra
.68578 .11433 .69138 .12245 .70325 .11806 .69768 .10991 Mtetra
.69768 .10991 .70325 .11806 .71518 .11365 .70964 .10546 Mtetra
.70964 .10546 .71518 .11365 .72715 .10922 .72164 .101 Mtetra
.72164 .101 .72715 .10922 .73917 .10478 .7337 .09652 Mtetra
.7337 .09652 .73917 .10478 .75124 .10031 .74581 .09202 Mtetra
.10242 .32186 .1095 .32846 .11911 .32489 .11204 .31827 Mtetra
.11204 .31827 .11911 .32489 .12875 .32131 .1217 .31466 Mtetra
.1217 .31466 .12875 .32131 .13842 .31771 .1314 .31104 Mtetra
.1314 .31104 .13842 .31771 .14813 .3141 .14113 .3074 Mtetra
.14113 .3074 .14813 .3141 .15789 .31048 .1509 .30376 Mtetra
.1509 .30376 .15789 .31048 .16767 .30684 .16071 .30009 Mtetra
.16071 .30009 .16767 .30684 .1775 .30319 .17056 .29642 Mtetra
.17056 .29642 .1775 .30319 .18736 .29953 .18044 .29273 Mtetra
.18044 .29273 .18736 .29953 .19726 .29585 .19036 .28902 Mtetra
.19036 .28902 .19726 .29585 .2072 .29216 .20032 .2853 Mtetra
.20032 .2853 .2072 .29216 .21717 .28845 .21032 .28157 Mtetra
.21032 .28157 .21717 .28845 .22719 .28473 .22036 .27782 Mtetra
.22036 .27782 .22719 .28473 .23724 .28099 .23043 .27406 Mtetra
.23043 .27406 .23724 .28099 .24733 .27724 .24055 .27028 Mtetra
.24055 .27028 .24733 .27724 .25747 .27348 .2507 .26649 Mtetra
.2507 .26649 .25747 .27348 .26764 .2697 .2609 .26268 Mtetra
.2609 .26268 .26764 .2697 .27785 .26591 .27113 .25886 Mtetra
.27113 .25886 .27785 .26591 .28808 .26234 .28141 .25503 Mtetra
.663 .734 .902 r
.28141 .25503 .28808 .26234 .29822 .2606 .29172 .25117 Mtetra
.642 .67 .861 r
.29172 .25117 .29822 .2606 .30843 .25858 .30205 .24772 Mtetra
.598 .619 .844 r
.30205 .24772 .30843 .25858 .31871 .25634 .31233 .24546 Mtetra
.606 .623 .842 r
.31233 .24546 .31871 .25634 .32905 .25392 .32269 .24293 Mtetra
.613 .625 .839 r
.32269 .24293 .32905 .25392 .33944 .25134 .3331 .2402 Mtetra
.618 .625 .835 r
.3331 .2402 .33944 .25134 .3499 .24859 .34358 .23729 Mtetra
.622 .624 .831 r
.34358 .23729 .3499 .24859 .36042 .24568 .35411 .2342 Mtetra
.626 .623 .827 r
.35411 .2342 .36042 .24568 .37099 .24259 .3647 .23094 Mtetra
.631 .622 .824 r
.3647 .23094 .37099 .24259 .38162 .2393 .37534 .2275 Mtetra
.635 .622 .82 r
.37534 .2275 .38162 .2393 .3923 .23578 .38604 .22388 Mtetra
.639 .623 .818 r
.38604 .22388 .3923 .23578 .40304 .23204 .39679 .22006 Mtetra
.644 .624 .815 r
.39679 .22006 .40304 .23204 .41383 .22806 .4076 .21604 Mtetra
.649 .626 .814 r
.4076 .21604 .41383 .22806 .42468 .22383 .41845 .21182 Mtetra
.653 .629 .813 r
.41845 .21182 .42468 .22383 .43557 .21937 .42935 .20741 Mtetra
.658 .633 .813 r
.42935 .20741 .43557 .21937 .4465 .21469 .4403 .20281 Mtetra
.663 .637 .814 r
.4403 .20281 .4465 .21469 .45748 .2098 .45129 .19803 Mtetra
.667 .642 .815 r
.45129 .19803 .45748 .2098 .46851 .20473 .46233 .19307 Mtetra
.672 .646 .816 r
.46233 .19307 .46851 .20473 .47957 .19949 .4734 .18793 Mtetra
.677 .651 .817 r
.4734 .18793 .47957 .19949 .49067 .19408 .48452 .18261 Mtetra
.682 .656 .817 r
.48452 .18261 .49067 .19408 .50181 .1885 .49567 .17707 Mtetra
.689 .66 .816 r
.49567 .17707 .50181 .1885 .51298 .18273 .50686 .17126 Mtetra
.659 .646 .826 r
.50686 .17126 .51298 .18273 .52419 .17673 .51809 .16665 Mtetra
.655 .675 .857 r
.51809 .16665 .52419 .17673 .53542 .17044 .52935 .16244 Mtetra
.663 .734 .902 r
.52935 .16244 .53542 .17044 .5467 .16601 .54066 .15822 Mtetra
.664 .741 .908 r
.54066 .15822 .5467 .16601 .55803 .1618 .55202 .15398 Mtetra
.55202 .15398 .55803 .1618 .56941 .15757 .56343 .14972 Mtetra
.56343 .14972 .56941 .15757 .58083 .15333 .57488 .14544 Mtetra
.57488 .14544 .58083 .15333 .59229 .14906 .58638 .14115 Mtetra
.58638 .14115 .59229 .14906 .60381 .14479 .59793 .13684 Mtetra
.59793 .13684 .60381 .14479 .61537 .14049 .60952 .13251 Mtetra
.60952 .13251 .61537 .14049 .62699 .13617 .62117 .12816 Mtetra
.62117 .12816 .62699 .13617 .63865 .13184 .63286 .1238 Mtetra
.63286 .1238 .63865 .13184 .65035 .12749 .6446 .11941 Mtetra
.6446 .11941 .65035 .12749 .66211 .12312 .65639 .11501 Mtetra
.65639 .11501 .66211 .12312 .67392 .11873 .66823 .11059 Mtetra
.66823 .11059 .67392 .11873 .68578 .11433 .68012 .10615 Mtetra
.68012 .10615 .68578 .11433 .69768 .10991 .69206 .10169 Mtetra
.69206 .10169 .69768 .10991 .70964 .10546 .70406 .09721 Mtetra
.70406 .09721 .70964 .10546 .72164 .101 .7161 .09271 Mtetra
.7161 .09271 .72164 .101 .7337 .09652 .72819 .0882 Mtetra
.72819 .0882 .7337 .09652 .74581 .09202 .74034 .08366 Mtetra
.09528 .31522 .10242 .32186 .11204 .31827 .10492 .3116 Mtetra
.10492 .3116 .11204 .31827 .1217 .31466 .1146 .30796 Mtetra
.1146 .30796 .1217 .31466 .1314 .31104 .12432 .30432 Mtetra
.12432 .30432 .1314 .31104 .14113 .3074 .13408 .30066 Mtetra
.13408 .30066 .14113 .3074 .1509 .30376 .14387 .29698 Mtetra
.14387 .29698 .1509 .30376 .16071 .30009 .1537 .2933 Mtetra
.1537 .2933 .16071 .30009 .17056 .29642 .16357 .28959 Mtetra
.16357 .28959 .17056 .29642 .18044 .29273 .17347 .28588 Mtetra
.17347 .28588 .18044 .29273 .19036 .28902 .18341 .28214 Mtetra
.18341 .28214 .19036 .28902 .20032 .2853 .1934 .2784 Mtetra
.1934 .2784 .20032 .2853 .21032 .28157 .20342 .27464 Mtetra
.20342 .27464 .21032 .28157 .22036 .27782 .21348 .27086 Mtetra
.21348 .27086 .22036 .27782 .23043 .27406 .22358 .26707 Mtetra
.22358 .26707 .23043 .27406 .24055 .27028 .23372 .26327 Mtetra
.23372 .26327 .24055 .27028 .2507 .26649 .24389 .25945 Mtetra
.24389 .25945 .2507 .26649 .2609 .26268 .25411 .25562 Mtetra
.25411 .25562 .2609 .26268 .27113 .25886 .26437 .25177 Mtetra
.26437 .25177 .27113 .25886 .28141 .25503 .27467 .2479 Mtetra
.27467 .2479 .28141 .25503 .29172 .25117 .28501 .24402 Mtetra
.28501 .24402 .29172 .25117 .30205 .24772 .29539 .24013 Mtetra
.663 .728 .898 r
.29539 .24013 .30205 .24772 .31233 .24546 .30581 .23622 Mtetra
.656 .683 .863 r
.30581 .23622 .31233 .24546 .32269 .24293 .31627 .23229 Mtetra
.624 .638 .844 r
.31627 .23229 .32269 .24293 .3331 .2402 .32672 .22922 Mtetra
.62 .63 .839 r
.32672 .22922 .3331 .2402 .34358 .23729 .33721 .22621 Mtetra
.626 .631 .836 r
.33721 .22621 .34358 .23729 .35411 .2342 .34776 .223 Mtetra
.63 .631 .833 r
.34776 .223 .35411 .2342 .3647 .23094 .35836 .21961 Mtetra
.635 .631 .83 r
.35836 .21961 .3647 .23094 .37534 .2275 .36902 .21606 Mtetra
.638 .631 .827 r
.36902 .21606 .37534 .2275 .38604 .22388 .37974 .21233 Mtetra
.642 .632 .825 r
.37974 .21233 .38604 .22388 .39679 .22006 .3905 .20845 Mtetra
.646 .633 .823 r
.3905 .20845 .39679 .22006 .4076 .21604 .40132 .2044 Mtetra
.65 .635 .822 r
.40132 .2044 .4076 .21604 .41845 .21182 .41218 .20018 Mtetra
.654 .637 .821 r
.41218 .20018 .41845 .21182 .42935 .20741 .4231 .1958 Mtetra
.658 .64 .821 r
.4231 .1958 .42935 .20741 .4403 .20281 .43405 .19125 Mtetra
.663 .644 .821 r
.43405 .19125 .4403 .20281 .45129 .19803 .44506 .18654 Mtetra
.667 .648 .821 r
.44506 .18654 .45129 .19803 .46233 .19307 .45611 .18163 Mtetra
.672 .652 .821 r
.45611 .18163 .46233 .19307 .4734 .18793 .4672 .17653 Mtetra
.671 .652 .823 r
.4672 .17653 .4734 .18793 .48452 .18261 .47833 .17148 Mtetra
.65 .649 .836 r
.47833 .17148 .48452 .18261 .49567 .17707 .48949 .1673 Mtetra
.656 .683 .863 r
.48949 .1673 .49567 .17707 .50686 .17126 .50069 .16309 Mtetra
.663 .728 .898 r
.50069 .16309 .50686 .17126 .51809 .16665 .51194 .15887 Mtetra
.664 .741 .908 r
.51194 .15887 .51809 .16665 .52935 .16244 .52324 .15463 Mtetra
.52324 .15463 .52935 .16244 .54066 .15822 .53458 .15038 Mtetra
.53458 .15038 .54066 .15822 .55202 .15398 .54597 .1461 Mtetra
.54597 .1461 .55202 .15398 .56343 .14972 .5574 .14181 Mtetra
.5574 .14181 .56343 .14972 .57488 .14544 .56889 .1375 Mtetra
.56889 .1375 .57488 .14544 .58638 .14115 .58042 .13318 Mtetra
.58042 .13318 .58638 .14115 .59793 .13684 .592 .12883 Mtetra
.592 .12883 .59793 .13684 .60952 .13251 .60363 .12447 Mtetra
.60363 .12447 .60952 .13251 .62117 .12816 .6153 .12009 Mtetra
.6153 .12009 .62117 .12816 .63286 .1238 .62703 .11569 Mtetra
.62703 .11569 .63286 .1238 .6446 .11941 .6388 .11127 Mtetra
.6388 .11127 .6446 .11941 .65639 .11501 .65063 .10683 Mtetra
.65063 .10683 .65639 .11501 .66823 .11059 .6625 .10238 Mtetra
.6625 .10238 .66823 .11059 .68012 .10615 .67443 .0979 Mtetra
.67443 .0979 .68012 .10615 .69206 .10169 .6864 .09341 Mtetra
.6864 .09341 .69206 .10169 .70406 .09721 .69843 .08889 Mtetra
.69843 .08889 .70406 .09721 .7161 .09271 .71051 .08436 Mtetra
.71051 .08436 .7161 .09271 .72819 .0882 .72264 .07981 Mtetra
.72264 .07981 .72819 .0882 .74034 .08366 .73482 .07524 Mtetra
.08809 .30852 .09528 .31522 .10492 .3116 .09776 .30488 Mtetra
.09776 .30488 .10492 .3116 .1146 .30796 .10746 .30122 Mtetra
.10746 .30122 .1146 .30796 .12432 .30432 .1172 .29755 Mtetra
.1172 .29755 .12432 .30432 .13408 .30066 .12697 .29386 Mtetra
.12697 .29386 .13408 .30066 .14387 .29698 .13679 .29016 Mtetra
.13679 .29016 .14387 .29698 .1537 .2933 .14664 .28645 Mtetra
.14664 .28645 .1537 .2933 .16357 .28959 .15653 .28272 Mtetra
.15653 .28272 .16357 .28959 .17347 .28588 .16645 .27898 Mtetra
.16645 .27898 .17347 .28588 .18341 .28214 .17642 .27522 Mtetra
.17642 .27522 .18341 .28214 .1934 .2784 .18642 .27145 Mtetra
.18642 .27145 .1934 .2784 .20342 .27464 .19647 .26766 Mtetra
.19647 .26766 .20342 .27464 .21348 .27086 .20655 .26386 Mtetra
.20655 .26386 .21348 .27086 .22358 .26707 .21667 .26004 Mtetra
.21667 .26004 .22358 .26707 .23372 .26327 .22683 .25621 Mtetra
.22683 .25621 .23372 .26327 .24389 .25945 .23703 .25236 Mtetra
.23703 .25236 .24389 .25945 .25411 .25562 .24728 .2485 Mtetra
.24728 .2485 .25411 .25562 .26437 .25177 .25756 .24462 Mtetra
.25756 .24462 .26437 .25177 .27467 .2479 .26788 .24073 Mtetra
.26788 .24073 .27467 .2479 .28501 .24402 .27824 .23682 Mtetra
.27824 .23682 .28501 .24402 .29539 .24013 .28865 .2329 Mtetra
.28865 .2329 .29539 .24013 .30581 .23622 .29909 .22896 Mtetra
.29909 .22896 .30581 .23622 .31627 .23229 .30958 .225 Mtetra
.30958 .225 .31627 .23229 .32672 .22922 .32011 .22103 Mtetra
.661 .715 .888 r
.32011 .22103 .32672 .22922 .33721 .22621 .33068 .21705 Mtetra
.657 .689 .868 r
.33068 .21705 .33721 .22621 .34776 .223 .34129 .21305 Mtetra
.654 .669 .852 r
.34129 .21305 .34776 .223 .35836 .21961 .35195 .20903 Mtetra
.646 .653 .842 r
.35195 .20903 .35836 .21961 .36902 .21606 .36264 .20516 Mtetra
.642 .645 .838 r
.36264 .20516 .36902 .21606 .37974 .21233 .37337 .20137 Mtetra
.646 .646 .836 r
.37337 .20137 .37974 .21233 .3905 .20845 .38415 .19744 Mtetra
.649 .647 .835 r
.38415 .19744 .3905 .20845 .40132 .2044 .39498 .19335 Mtetra
.653 .649 .833 r
.39498 .19335 .40132 .2044 .41218 .20018 .40586 .18912 Mtetra
.657 .651 .833 r
.40586 .18912 .41218 .20018 .4231 .1958 .41679 .18474 Mtetra
.654 .65 .834 r
.41679 .18474 .4231 .1958 .43405 .19125 .42775 .18044 Mtetra
.651 .655 .841 r
.42775 .18044 .43405 .19125 .44506 .18654 .43876 .17629 Mtetra
.654 .669 .852 r
.43876 .17629 .44506 .18654 .45611 .18163 .44981 .17213 Mtetra
.657 .689 .868 r
.44981 .17213 .45611 .18163 .4672 .17653 .46091 .16794 Mtetra
.661 .715 .888 r
.46091 .16794 .4672 .17653 .47833 .17148 .47205 .16374 Mtetra
.664 .741 .908 r
.47205 .16374 .47833 .17148 .48949 .1673 .48323 .15952 Mtetra
.48323 .15952 .48949 .1673 .50069 .16309 .49447 .15529 Mtetra
.49447 .15529 .50069 .16309 .51194 .15887 .50575 .15103 Mtetra
.50575 .15103 .51194 .15887 .52324 .15463 .51707 .14676 Mtetra
.51707 .14676 .52324 .15463 .53458 .15038 .52845 .14247 Mtetra
.52845 .14247 .53458 .15038 .54597 .1461 .53987 .13817 Mtetra
.53987 .13817 .54597 .1461 .5574 .14181 .55133 .13384 Mtetra
.55133 .13384 .5574 .14181 .56889 .1375 .56285 .1295 Mtetra
.56285 .1295 .56889 .1375 .58042 .13318 .57441 .12514 Mtetra
.57441 .12514 .58042 .13318 .592 .12883 .58602 .12076 Mtetra
.58602 .12076 .592 .12883 .60363 .12447 .59769 .11636 Mtetra
.59769 .11636 .60363 .12447 .6153 .12009 .60939 .11195 Mtetra
.60939 .11195 .6153 .12009 .62703 .11569 .62115 .10752 Mtetra
.62115 .10752 .62703 .11569 .6388 .11127 .63296 .10306 Mtetra
.63296 .10306 .6388 .11127 .65063 .10683 .64482 .09859 Mtetra
.64482 .09859 .65063 .10683 .6625 .10238 .65673 .0941 Mtetra
.65673 .0941 .6625 .10238 .67443 .0979 .66869 .08959 Mtetra
.66869 .08959 .67443 .0979 .6864 .09341 .6807 .08506 Mtetra
.6807 .08506 .6864 .09341 .69843 .08889 .69276 .08051 Mtetra
.69276 .08051 .69843 .08889 .71051 .08436 .70487 .07595 Mtetra
.70487 .07595 .71051 .08436 .72264 .07981 .71704 .07136 Mtetra
.71704 .07136 .72264 .07981 .73482 .07524 .72926 .06675 Mtetra
.08086 .30179 .08809 .30852 .09776 .30488 .09054 .29812 Mtetra
.09054 .29812 .09776 .30488 .10746 .30122 .10026 .29443 Mtetra
.10026 .29443 .10746 .30122 .1172 .29755 .11002 .29073 Mtetra
.11002 .29073 .1172 .29755 .12697 .29386 .11982 .28702 Mtetra
.11982 .28702 .12697 .29386 .13679 .29016 .12965 .28329 Mtetra
.12965 .28329 .13679 .29016 .14664 .28645 .13952 .27955 Mtetra
.13952 .27955 .14664 .28645 .15653 .28272 .14943 .2758 Mtetra
.14943 .2758 .15653 .28272 .16645 .27898 .15938 .27203 Mtetra
.15938 .27203 .16645 .27898 .17642 .27522 .16937 .26824 Mtetra
.16937 .26824 .17642 .27522 .18642 .27145 .1794 .26444 Mtetra
.1794 .26444 .18642 .27145 .19647 .26766 .18946 .26063 Mtetra
.18946 .26063 .19647 .26766 .20655 .26386 .19957 .2568 Mtetra
.19957 .2568 .20655 .26386 .21667 .26004 .20971 .25295 Mtetra
.20971 .25295 .21667 .26004 .22683 .25621 .2199 .24909 Mtetra
.2199 .24909 .22683 .25621 .23703 .25236 .23012 .24522 Mtetra
.23012 .24522 .23703 .25236 .24728 .2485 .24039 .24133 Mtetra
.24039 .24133 .24728 .2485 .25756 .24462 .2507 .23742 Mtetra
.2507 .23742 .25756 .24462 .26788 .24073 .26104 .2335 Mtetra
.26104 .2335 .26788 .24073 .27824 .23682 .27143 .22957 Mtetra
.27143 .22957 .27824 .23682 .28865 .2329 .28186 .22561 Mtetra
.28186 .22561 .28865 .2329 .29909 .22896 .29233 .22165 Mtetra
.29233 .22165 .29909 .22896 .30958 .225 .30284 .21766 Mtetra
.30284 .21766 .30958 .225 .32011 .22103 .3134 .21366 Mtetra
.3134 .21366 .32011 .22103 .33068 .21705 .32399 .20965 Mtetra
.32399 .20965 .33068 .21705 .34129 .21305 .33463 .20562 Mtetra
.33463 .20562 .34129 .21305 .35195 .20903 .34531 .20157 Mtetra
.34531 .20157 .35195 .20903 .36264 .20516 .35604 .1975 Mtetra
.663 .736 .904 r
.35604 .1975 .36264 .20516 .37337 .20137 .36681 .19342 Mtetra
.662 .728 .898 r
.36681 .19342 .37337 .20137 .38415 .19744 .37762 .18932 Mtetra
.662 .724 .895 r
.37762 .18932 .38415 .19744 .39498 .19335 .38848 .18521 Mtetra
.38848 .18521 .39498 .19335 .40586 .18912 .39938 .18108 Mtetra
.662 .728 .898 r
.39938 .18108 .40586 .18912 .41679 .18474 .41032 .17693 Mtetra
.663 .736 .904 r
.41032 .17693 .41679 .18474 .42775 .18044 .42131 .17277 Mtetra
.664 .741 .908 r
.42131 .17277 .42775 .18044 .43876 .17629 .43234 .16859 Mtetra
.43234 .16859 .43876 .17629 .44981 .17213 .44342 .16439 Mtetra
.44342 .16439 .44981 .17213 .46091 .16794 .45455 .16017 Mtetra
.45455 .16017 .46091 .16794 .47205 .16374 .46572 .15594 Mtetra
.46572 .15594 .47205 .16374 .48323 .15952 .47693 .15169 Mtetra
.47693 .15169 .48323 .15952 .49447 .15529 .4882 .14742 Mtetra
.4882 .14742 .49447 .15529 .50575 .15103 .49951 .14313 Mtetra
.49951 .14313 .50575 .15103 .51707 .14676 .51086 .13883 Mtetra
.51086 .13883 .51707 .14676 .52845 .14247 .52227 .13451 Mtetra
.52227 .13451 .52845 .14247 .53987 .13817 .53372 .13017 Mtetra
.53372 .13017 .53987 .13817 .55133 .13384 .54522 .12581 Mtetra
.54522 .12581 .55133 .13384 .56285 .1295 .55676 .12144 Mtetra
.55676 .12144 .56285 .1295 .57441 .12514 .56836 .11704 Mtetra
.56836 .11704 .57441 .12514 .58602 .12076 .58 .11263 Mtetra
.58 .11263 .58602 .12076 .59769 .11636 .5917 .1082 Mtetra
.5917 .1082 .59769 .11636 .60939 .11195 .60344 .10375 Mtetra
.60344 .10375 .60939 .11195 .62115 .10752 .61523 .09928 Mtetra
.61523 .09928 .62115 .10752 .63296 .10306 .62707 .09479 Mtetra
.62707 .09479 .63296 .10306 .64482 .09859 .63897 .09029 Mtetra
.63897 .09029 .64482 .09859 .65673 .0941 .65091 .08576 Mtetra
.65091 .08576 .65673 .0941 .66869 .08959 .6629 .08121 Mtetra
.6629 .08121 .66869 .08959 .6807 .08506 .67495 .07665 Mtetra
.67495 .07665 .6807 .08506 .69276 .08051 .68705 .07207 Mtetra
.68705 .07207 .69276 .08051 .70487 .07595 .69919 .06746 Mtetra
.69919 .06746 .70487 .07595 .71704 .07136 .7114 .06284 Mtetra
.7114 .06284 .71704 .07136 .72926 .06675 .72365 .05819 Mtetra
.07357 .295 .08086 .30179 .09054 .29812 .08327 .2913 Mtetra
.08327 .2913 .09054 .29812 .10026 .29443 .09301 .28759 Mtetra
.09301 .28759 .10026 .29443 .11002 .29073 .10279 .28387 Mtetra
.10279 .28387 .11002 .29073 .11982 .28702 .11261 .28013 Mtetra
.11261 .28013 .11982 .28702 .12965 .28329 .12247 .27638 Mtetra
.12247 .27638 .12965 .28329 .13952 .27955 .13236 .27261 Mtetra
.13236 .27261 .13952 .27955 .14943 .2758 .14229 .26883 Mtetra
.14229 .26883 .14943 .2758 .15938 .27203 .15226 .26503 Mtetra
.15226 .26503 .15938 .27203 .16937 .26824 .16227 .26122 Mtetra
.16227 .26122 .16937 .26824 .1794 .26444 .17232 .25739 Mtetra
.17232 .25739 .1794 .26444 .18946 .26063 .18241 .25355 Mtetra
.18241 .25355 .18946 .26063 .19957 .2568 .19254 .24969 Mtetra
.19254 .24969 .19957 .2568 .20971 .25295 .20271 .24582 Mtetra
.20271 .24582 .20971 .25295 .2199 .24909 .21292 .24193 Mtetra
.21292 .24193 .2199 .24909 .23012 .24522 .22316 .23803 Mtetra
.22316 .23803 .23012 .24522 .24039 .24133 .23345 .23411 Mtetra
.23345 .23411 .24039 .24133 .2507 .23742 .24378 .23017 Mtetra
.24378 .23017 .2507 .23742 .26104 .2335 .25415 .22622 Mtetra
.25415 .22622 .26104 .2335 .27143 .22957 .26457 .22226 Mtetra
.26457 .22226 .27143 .22957 .28186 .22561 .27502 .21828 Mtetra
.27502 .21828 .28186 .22561 .29233 .22165 .28552 .21428 Mtetra
.28552 .21428 .29233 .22165 .30284 .21766 .29605 .21027 Mtetra
.29605 .21027 .30284 .21766 .3134 .21366 .30663 .20624 Mtetra
.30663 .20624 .3134 .21366 .32399 .20965 .31726 .20219 Mtetra
.31726 .20219 .32399 .20965 .33463 .20562 .32792 .19813 Mtetra
.32792 .19813 .33463 .20562 .34531 .20157 .33863 .19405 Mtetra
.33863 .19405 .34531 .20157 .35604 .1975 .34938 .18996 Mtetra
.34938 .18996 .35604 .1975 .36681 .19342 .36018 .18584 Mtetra
.36018 .18584 .36681 .19342 .37762 .18932 .37102 .18172 Mtetra
.37102 .18172 .37762 .18932 .38848 .18521 .3819 .17757 Mtetra
.3819 .17757 .38848 .18521 .39938 .18108 .39283 .17341 Mtetra
.39283 .17341 .39938 .18108 .41032 .17693 .4038 .16923 Mtetra
.4038 .16923 .41032 .17693 .42131 .17277 .41482 .16504 Mtetra
.41482 .16504 .42131 .17277 .43234 .16859 .42588 .16082 Mtetra
.42588 .16082 .43234 .16859 .44342 .16439 .43699 .15659 Mtetra
.43699 .15659 .44342 .16439 .45455 .16017 .44814 .15234 Mtetra
.44814 .15234 .45455 .16017 .46572 .15594 .45934 .14808 Mtetra
.45934 .14808 .46572 .15594 .47693 .15169 .47059 .1438 Mtetra
.47059 .1438 .47693 .15169 .4882 .14742 .48188 .13949 Mtetra
.48188 .13949 .4882 .14742 .49951 .14313 .49322 .13518 Mtetra
.49322 .13518 .49951 .14313 .51086 .13883 .50461 .13084 Mtetra
.50461 .13084 .51086 .13883 .52227 .13451 .51604 .12648 Mtetra
.51604 .12648 .52227 .13451 .53372 .13017 .52752 .12211 Mtetra
.52752 .12211 .53372 .13017 .54522 .12581 .53905 .11772 Mtetra
.53905 .11772 .54522 .12581 .55676 .12144 .55063 .11331 Mtetra
.55063 .11331 .55676 .12144 .56836 .11704 .56226 .10888 Mtetra
.56226 .10888 .56836 .11704 .58 .11263 .57394 .10443 Mtetra
.57394 .10443 .58 .11263 .5917 .1082 .58566 .09997 Mtetra
.58566 .09997 .5917 .1082 .60344 .10375 .59744 .09548 Mtetra
.59744 .09548 .60344 .10375 .61523 .09928 .60926 .09098 Mtetra
.60926 .09098 .61523 .09928 .62707 .09479 .62114 .08646 Mtetra
.62114 .08646 .62707 .09479 .63897 .09029 .63307 .08191 Mtetra
.63307 .08191 .63897 .09029 .65091 .08576 .64504 .07735 Mtetra
.64504 .07735 .65091 .08576 .6629 .08121 .65707 .07277 Mtetra
.65707 .07277 .6629 .08121 .67495 .07665 .66915 .06817 Mtetra
.66915 .06817 .67495 .07665 .68705 .07207 .68129 .06355 Mtetra
.68129 .06355 .68705 .07207 .69919 .06746 .69347 .05891 Mtetra
.69347 .05891 .69919 .06746 .7114 .06284 .70571 .05425 Mtetra
.70571 .05425 .7114 .06284 .72365 .05819 .718 .04957 Mtetra
.06623 .28816 .07357 .295 .08327 .2913 .07595 .28444 Mtetra
.07595 .28444 .08327 .2913 .09301 .28759 .08572 .28071 Mtetra
.08572 .28071 .09301 .28759 .10279 .28387 .09552 .27695 Mtetra
.09552 .27695 .10279 .28387 .11261 .28013 .10535 .27319 Mtetra
.10535 .27319 .11261 .28013 .12247 .27638 .11523 .26941 Mtetra
.11523 .26941 .12247 .27638 .13236 .27261 .12515 .26561 Mtetra
.12515 .26561 .13236 .27261 .14229 .26883 .1351 .2618 Mtetra
.1351 .2618 .14229 .26883 .15226 .26503 .14509 .25798 Mtetra
.14509 .25798 .15226 .26503 .16227 .26122 .15513 .25414 Mtetra
.15513 .25414 .16227 .26122 .17232 .25739 .1652 .25028 Mtetra
.1652 .25028 .17232 .25739 .18241 .25355 .17531 .24641 Mtetra
.17531 .24641 .18241 .25355 .19254 .24969 .18546 .24253 Mtetra
.18546 .24253 .19254 .24969 .20271 .24582 .19565 .23863 Mtetra
.19565 .23863 .20271 .24582 .21292 .24193 .20588 .23471 Mtetra
.20588 .23471 .21292 .24193 .22316 .23803 .21615 .23078 Mtetra
.21615 .23078 .22316 .23803 .23345 .23411 .22647 .22683 Mtetra
.22647 .22683 .23345 .23411 .24378 .23017 .23682 .22287 Mtetra
.23682 .22287 .24378 .23017 .25415 .22622 .24722 .21889 Mtetra
.24722 .21889 .25415 .22622 .26457 .22226 .25765 .2149 Mtetra
.25765 .2149 .26457 .22226 .27502 .21828 .26813 .21088 Mtetra
.26813 .21088 .27502 .21828 .28552 .21428 .27865 .20686 Mtetra
.27865 .20686 .28552 .21428 .29605 .21027 .28921 .20281 Mtetra
.28921 .20281 .29605 .21027 .30663 .20624 .29982 .19876 Mtetra
.29982 .19876 .30663 .20624 .31726 .20219 .31047 .19468 Mtetra
.31047 .19468 .31726 .20219 .32792 .19813 .32116 .19059 Mtetra
.32116 .19059 .32792 .19813 .33863 .19405 .33189 .18648 Mtetra
.33189 .18648 .33863 .19405 .34938 .18996 .34267 .18235 Mtetra
.34267 .18235 .34938 .18996 .36018 .18584 .35349 .17821 Mtetra
.35349 .17821 .36018 .18584 .37102 .18172 .36436 .17405 Mtetra
.36436 .17405 .37102 .18172 .3819 .17757 .37527 .16988 Mtetra
.37527 .16988 .3819 .17757 .39283 .17341 .38623 .16568 Mtetra
.38623 .16568 .39283 .17341 .4038 .16923 .39723 .16147 Mtetra
.39723 .16147 .4038 .16923 .41482 .16504 .40827 .15724 Mtetra
.40827 .15724 .41482 .16504 .42588 .16082 .41936 .153 Mtetra
.41936 .153 .42588 .16082 .43699 .15659 .4305 .14874 Mtetra
.4305 .14874 .43699 .15659 .44814 .15234 .44168 .14446 Mtetra
.44168 .14446 .44814 .15234 .45934 .14808 .45291 .14016 Mtetra
.45291 .14016 .45934 .14808 .47059 .1438 .46419 .13584 Mtetra
.46419 .13584 .47059 .1438 .48188 .13949 .47551 .13151 Mtetra
.47551 .13151 .48188 .13949 .49322 .13518 .48688 .12716 Mtetra
.48688 .12716 .49322 .13518 .50461 .13084 .4983 .12279 Mtetra
.4983 .12279 .50461 .13084 .51604 .12648 .50977 .1184 Mtetra
.50977 .1184 .51604 .12648 .52752 .12211 .52128 .11399 Mtetra
.52128 .11399 .52752 .12211 .53905 .11772 .53284 .10956 Mtetra
.53284 .10956 .53905 .11772 .55063 .11331 .54445 .10512 Mtetra
.54445 .10512 .55063 .11331 .56226 .10888 .55611 .10066 Mtetra
.55611 .10066 .56226 .10888 .57394 .10443 .56782 .09618 Mtetra
.56782 .09618 .57394 .10443 .58566 .09997 .57958 .09167 Mtetra
.57958 .09167 .58566 .09997 .59744 .09548 .59139 .08715 Mtetra
.59139 .08715 .59744 .09548 .60926 .09098 .60325 .08261 Mtetra
.60325 .08261 .60926 .09098 .62114 .08646 .61516 .07806 Mtetra
.61516 .07806 .62114 .08646 .63307 .08191 .62712 .07348 Mtetra
.62712 .07348 .63307 .08191 .64504 .07735 .63913 .06888 Mtetra
.63913 .06888 .64504 .07735 .65707 .07277 .6512 .06426 Mtetra
.6512 .06426 .65707 .07277 .66915 .06817 .66331 .05963 Mtetra
.66331 .05963 .66915 .06817 .68129 .06355 .67548 .05497 Mtetra
.67548 .05497 .68129 .06355 .69347 .05891 .6877 .05029 Mtetra
.6877 .05029 .69347 .05891 .70571 .05425 .69997 .04559 Mtetra
.69997 .04559 .70571 .05425 .718 .04957 .7123 .04087 Mtetra
.05883 .28128 .06623 .28816 .07595 .28444 .06858 .27753 Mtetra
.06858 .27753 .07595 .28444 .08572 .28071 .07836 .27377 Mtetra
.07836 .27377 .08572 .28071 .09552 .27695 .08818 .26999 Mtetra
.08818 .26999 .09552 .27695 .10535 .27319 .09804 .2662 Mtetra
.09804 .2662 .10535 .27319 .11523 .26941 .10794 .26239 Mtetra
.10794 .26239 .11523 .26941 .12515 .26561 .11788 .25857 Mtetra
.11788 .25857 .12515 .26561 .1351 .2618 .12786 .25473 Mtetra
.12786 .25473 .1351 .2618 .14509 .25798 .13787 .25088 Mtetra
.13787 .25088 .14509 .25798 .15513 .25414 .14792 .24701 Mtetra
.14792 .24701 .15513 .25414 .1652 .25028 .15802 .24313 Mtetra
.15802 .24313 .1652 .25028 .17531 .24641 .16815 .23923 Mtetra
.16815 .23923 .17531 .24641 .18546 .24253 .17833 .23531 Mtetra
.17833 .23531 .18546 .24253 .19565 .23863 .18854 .23139 Mtetra
.18854 .23139 .19565 .23863 .20588 .23471 .1988 .22744 Mtetra
.1988 .22744 .20588 .23471 .21615 .23078 .20909 .22348 Mtetra
.20909 .22348 .21615 .23078 .22647 .22683 .21943 .2195 Mtetra
.21943 .2195 .22647 .22683 .23682 .22287 .22981 .21551 Mtetra
.22981 .21551 .23682 .22287 .24722 .21889 .24023 .2115 Mtetra
.24023 .2115 .24722 .21889 .25765 .2149 .25069 .20748 Mtetra
.25069 .20748 .25765 .2149 .26813 .21088 .26119 .20344 Mtetra
.26119 .20344 .26813 .21088 .27865 .20686 .27174 .19938 Mtetra
.27174 .19938 .27865 .20686 .28921 .20281 .28232 .19531 Mtetra
.28232 .19531 .28921 .20281 .29982 .19876 .29296 .19122 Mtetra
.29296 .19122 .29982 .19876 .31047 .19468 .30363 .18711 Mtetra
.30363 .18711 .31047 .19468 .32116 .19059 .31435 .18299 Mtetra
.31435 .18299 .32116 .19059 .33189 .18648 .32511 .17885 Mtetra
.32511 .17885 .33189 .18648 .34267 .18235 .33591 .17469 Mtetra
.33591 .17469 .34267 .18235 .35349 .17821 .34676 .17052 Mtetra
.34676 .17052 .35349 .17821 .36436 .17405 .35766 .16633 Mtetra
.35766 .16633 .36436 .17405 .37527 .16988 .36859 .16212 Mtetra
.36859 .16212 .37527 .16988 .38623 .16568 .37958 .1579 Mtetra
.37958 .1579 .38623 .16568 .39723 .16147 .39061 .15365 Mtetra
.39061 .15365 .39723 .16147 .40827 .15724 .40168 .14939 Mtetra
.40168 .14939 .40827 .15724 .41936 .153 .4128 .14512 Mtetra
.4128 .14512 .41936 .153 .4305 .14874 .42397 .14082 Mtetra
.42397 .14082 .4305 .14874 .44168 .14446 .43518 .13651 Mtetra
.43518 .13651 .44168 .14446 .45291 .14016 .44644 .13218 Mtetra
.44644 .13218 .45291 .14016 .46419 .13584 .45774 .12783 Mtetra
.45774 .12783 .46419 .13584 .47551 .13151 .4691 .12346 Mtetra
.4691 .12346 .47551 .13151 .48688 .12716 .4805 .11907 Mtetra
.4805 .11907 .48688 .12716 .4983 .12279 .49194 .11467 Mtetra
.49194 .11467 .4983 .12279 .50977 .1184 .50344 .11025 Mtetra
.50344 .11025 .50977 .1184 .52128 .11399 .51499 .1058 Mtetra
.51499 .1058 .52128 .11399 .53284 .10956 .52658 .10134 Mtetra
.52658 .10134 .53284 .10956 .54445 .10512 .53822 .09687 Mtetra
.53822 .09687 .54445 .10512 .55611 .10066 .54992 .09237 Mtetra
.54992 .09237 .55611 .10066 .56782 .09618 .56166 .08785 Mtetra
.56166 .08785 .56782 .09618 .57958 .09167 .57345 .08331 Mtetra
.57345 .08331 .57958 .09167 .59139 .08715 .58529 .07876 Mtetra
.58529 .07876 .59139 .08715 .60325 .08261 .59719 .07418 Mtetra
.59719 .07418 .60325 .08261 .61516 .07806 .60913 .06959 Mtetra
.60913 .06959 .61516 .07806 .62712 .07348 .62113 .06497 Mtetra
.62113 .06497 .62712 .07348 .63913 .06888 .63317 .06034 Mtetra
.63317 .06034 .63913 .06888 .6512 .06426 .64527 .05569 Mtetra
.64527 .05569 .6512 .06426 .66331 .05963 .65742 .05101 Mtetra
.65742 .05101 .66331 .05963 .67548 .05497 .66963 .04632 Mtetra
.66963 .04632 .67548 .05497 .6877 .05029 .68188 .0416 Mtetra
.68188 .0416 .6877 .05029 .69997 .04559 .69419 .03687 Mtetra
.69419 .03687 .69997 .04559 .7123 .04087 .70656 .03211 Mtetra
.05139 .27435 .05883 .28128 .06858 .27753 .06115 .27057 Mtetra
.06115 .27057 .06858 .27753 .07836 .27377 .07096 .26678 Mtetra
.07096 .26678 .07836 .27377 .08818 .26999 .0808 .26298 Mtetra
.0808 .26298 .08818 .26999 .09804 .2662 .09068 .25916 Mtetra
.09068 .25916 .09804 .2662 .10794 .26239 .1006 .25532 Mtetra
.1006 .25532 .10794 .26239 .11788 .25857 .11056 .25147 Mtetra
.11056 .25147 .11788 .25857 .12786 .25473 .12056 .24761 Mtetra
.12056 .24761 .12786 .25473 .13787 .25088 .13059 .24372 Mtetra
.13059 .24372 .13787 .25088 .14792 .24701 .14067 .23983 Mtetra
.14067 .23983 .14792 .24701 .15802 .24313 .15079 .23592 Mtetra
.15079 .23592 .15802 .24313 .16815 .23923 .16094 .23199 Mtetra
.16094 .23199 .16815 .23923 .17833 .23531 .17114 .22805 Mtetra
.17114 .22805 .17833 .23531 .18854 .23139 .18138 .22409 Mtetra
.18138 .22409 .18854 .23139 .1988 .22744 .19166 .22012 Mtetra
.19166 .22012 .1988 .22744 .20909 .22348 .20198 .21613 Mtetra
.20198 .21613 .20909 .22348 .21943 .2195 .21234 .21212 Mtetra
.21234 .21212 .21943 .2195 .22981 .21551 .22274 .2081 Mtetra
.22274 .2081 .22981 .21551 .24023 .2115 .23318 .20406 Mtetra
.23318 .20406 .24023 .2115 .25069 .20748 .24367 .20001 Mtetra
.24367 .20001 .25069 .20748 .26119 .20344 .2542 .19594 Mtetra
.2542 .19594 .26119 .20344 .27174 .19938 .26477 .19185 Mtetra
.26477 .19185 .27174 .19938 .28232 .19531 .27538 .18774 Mtetra
.27538 .18774 .28232 .19531 .29296 .19122 .28604 .18362 Mtetra
.28604 .18362 .29296 .19122 .30363 .18711 .29674 .17949 Mtetra
.29674 .17949 .30363 .18711 .31435 .18299 .30748 .17533 Mtetra
.30748 .17533 .31435 .18299 .32511 .17885 .31827 .17116 Mtetra
.31827 .17116 .32511 .17885 .33591 .17469 .3291 .16697 Mtetra
.3291 .16697 .33591 .17469 .34676 .17052 .33998 .16277 Mtetra
.33998 .16277 .34676 .17052 .35766 .16633 .3509 .15855 Mtetra
.3509 .15855 .35766 .16633 .36859 .16212 .36187 .15431 Mtetra
.36187 .15431 .36859 .16212 .37958 .1579 .37288 .15005 Mtetra
.37288 .15005 .37958 .1579 .39061 .15365 .38393 .14577 Mtetra
.38393 .14577 .39061 .15365 .40168 .14939 .39504 .14148 Mtetra
.39504 .14148 .40168 .14939 .4128 .14512 .40619 .13717 Mtetra
.40619 .13717 .4128 .14512 .42397 .14082 .41738 .13284 Mtetra
.41738 .13284 .42397 .14082 .43518 .13651 .42862 .1285 Mtetra
.42862 .1285 .43518 .13651 .44644 .13218 .43991 .12413 Mtetra
.43991 .12413 .44644 .13218 .45774 .12783 .45125 .11975 Mtetra
.45125 .11975 .45774 .12783 .4691 .12346 .46263 .11535 Mtetra
.46263 .11535 .4691 .12346 .4805 .11907 .47406 .11093 Mtetra
.47406 .11093 .4805 .11907 .49194 .11467 .48554 .10649 Mtetra
.48554 .10649 .49194 .11467 .50344 .11025 .49707 .10203 Mtetra
.49707 .10203 .50344 .11025 .51499 .1058 .50865 .09756 Mtetra
.50865 .09756 .51499 .1058 .52658 .10134 .52027 .09306 Mtetra
.52027 .09306 .52658 .10134 .53822 .09687 .53195 .08855 Mtetra
.53195 .08855 .53822 .09687 .54992 .09237 .54367 .08401 Mtetra
.54367 .08401 .54992 .09237 .56166 .08785 .55545 .07946 Mtetra
.55545 .07946 .56166 .08785 .57345 .08331 .56727 .07489 Mtetra
.56727 .07489 .57345 .08331 .58529 .07876 .57915 .0703 Mtetra
.57915 .0703 .58529 .07876 .59719 .07418 .59108 .06569 Mtetra
.59108 .06569 .59719 .07418 .60913 .06959 .60305 .06105 Mtetra
.60305 .06105 .60913 .06959 .62113 .06497 .61508 .0564 Mtetra
.61508 .0564 .62113 .06497 .63317 .06034 .62717 .05173 Mtetra
.62717 .05173 .63317 .06034 .64527 .05569 .6393 .04704 Mtetra
.6393 .04704 .64527 .05569 .65742 .05101 .65149 .04233 Mtetra
.65149 .04233 .65742 .05101 .66963 .04632 .66373 .0376 Mtetra
.66373 .0376 .66963 .04632 .68188 .0416 .67602 .03284 Mtetra
.67602 .03284 .68188 .0416 .69419 .03687 .68837 .02807 Mtetra
.68837 .02807 .69419 .03687 .70656 .03211 .70077 .02327 Mtetra
.04389 .26737 .05139 .27435 .06115 .27057 .05368 .26356 Mtetra
.05368 .26356 .06115 .27057 .07096 .26678 .0635 .25975 Mtetra
.0635 .25975 .07096 .26678 .0808 .26298 .07336 .25591 Mtetra
.07336 .25591 .0808 .26298 .09068 .25916 .08327 .25206 Mtetra
.08327 .25206 .09068 .25916 .1006 .25532 .09321 .2482 Mtetra
.09321 .2482 .1006 .25532 .11056 .25147 .10319 .24432 Mtetra
.10319 .24432 .11056 .25147 .12056 .24761 .11321 .24043 Mtetra
.11321 .24043 .12056 .24761 .13059 .24372 .12327 .23652 Mtetra
.12327 .23652 .13059 .24372 .14067 .23983 .13337 .2326 Mtetra
.13337 .2326 .14067 .23983 .15079 .23592 .1435 .22866 Mtetra
.1435 .22866 .15079 .23592 .16094 .23199 .15368 .2247 Mtetra
.15368 .2247 .16094 .23199 .17114 .22805 .1639 .22073 Mtetra
.1639 .22073 .17114 .22805 .18138 .22409 .17416 .21674 Mtetra
.17416 .21674 .18138 .22409 .19166 .22012 .18447 .21274 Mtetra
.18447 .21274 .19166 .22012 .20198 .21613 .19481 .20872 Mtetra
.19481 .20872 .20198 .21613 .21234 .21212 .20519 .20468 Mtetra
.20519 .20468 .21234 .21212 .22274 .2081 .21562 .20063 Mtetra
.21562 .20063 .22274 .2081 .23318 .20406 .22609 .19656 Mtetra
.22609 .19656 .23318 .20406 .24367 .20001 .2366 .19248 Mtetra
.2366 .19248 .24367 .20001 .2542 .19594 .24715 .18838 Mtetra
.24715 .18838 .2542 .19594 .26477 .19185 .25775 .18426 Mtetra
.25775 .18426 .26477 .19185 .27538 .18774 .26839 .18012 Mtetra
.26839 .18012 .27538 .18774 .28604 .18362 .27907 .17597 Mtetra
.27907 .17597 .28604 .18362 .29674 .17949 .2898 .1718 Mtetra
.2898 .1718 .29674 .17949 .30748 .17533 .30057 .16762 Mtetra
.30057 .16762 .30748 .17533 .31827 .17116 .31138 .16342 Mtetra
.31138 .16342 .31827 .17116 .3291 .16697 .32224 .1592 Mtetra
.32224 .1592 .3291 .16697 .33998 .16277 .33314 .15496 Mtetra
.33314 .15496 .33998 .16277 .3509 .15855 .34409 .15071 Mtetra
.34409 .15071 .3509 .15855 .36187 .15431 .35509 .14643 Mtetra
.35509 .14643 .36187 .15431 .37288 .15005 .36613 .14214 Mtetra
.36613 .14214 .37288 .15005 .38393 .14577 .37721 .13784 Mtetra
.37721 .13784 .38393 .14577 .39504 .14148 .38834 .13351 Mtetra
.38834 .13351 .39504 .14148 .40619 .13717 .39952 .12917 Mtetra
.39952 .12917 .40619 .13717 .41738 .13284 .41074 .1248 Mtetra
.41074 .1248 .41738 .13284 .42862 .1285 .42202 .12042 Mtetra
.42202 .12042 .42862 .1285 .43991 .12413 .43333 .11603 Mtetra
.43333 .11603 .43991 .12413 .45125 .11975 .4447 .11161 Mtetra
.4447 .11161 .45125 .11975 .46263 .11535 .45611 .10717 Mtetra
.45611 .10717 .46263 .11535 .47406 .11093 .46758 .10272 Mtetra
.46758 .10272 .47406 .11093 .48554 .10649 .47909 .09825 Mtetra
.47909 .09825 .48554 .10649 .49707 .10203 .49065 .09375 Mtetra
.49065 .09375 .49707 .10203 .50865 .09756 .50225 .08924 Mtetra
.50225 .08924 .50865 .09756 .52027 .09306 .51391 .08471 Mtetra
.51391 .08471 .52027 .09306 .53195 .08855 .52562 .08016 Mtetra
.52562 .08016 .53195 .08855 .54367 .08401 .53738 .07559 Mtetra
.53738 .07559 .54367 .08401 .55545 .07946 .54919 .071 Mtetra
.54919 .071 .55545 .07946 .56727 .07489 .56104 .0664 Mtetra
.56104 .0664 .56727 .07489 .57915 .0703 .57295 .06177 Mtetra
.57295 .06177 .57915 .0703 .59108 .06569 .58492 .05712 Mtetra
.58492 .05712 .59108 .06569 .60305 .06105 .59693 .05245 Mtetra
.59693 .05245 .60305 .06105 .61508 .0564 .60899 .04776 Mtetra
.60899 .04776 .61508 .0564 .62717 .05173 .62111 .04305 Mtetra
.62111 .04305 .62717 .05173 .6393 .04704 .63328 .03833 Mtetra
.63328 .03833 .6393 .04704 .65149 .04233 .6455 .03358 Mtetra
.6455 .03358 .65149 .04233 .66373 .0376 .65778 .0288 Mtetra
.65778 .0288 .66373 .0376 .67602 .03284 .67011 .02401 Mtetra
.67011 .02401 .67602 .03284 .68837 .02807 .68249 .0192 Mtetra
.68249 .0192 .68837 .02807 .70077 .02327 .69493 .01437 Mtetra
.03634 .26033 .04389 .26737 .05368 .26356 .04614 .2565 Mtetra
.04614 .2565 .05368 .26356 .0635 .25975 .05599 .25266 Mtetra
.05599 .25266 .0635 .25975 .07336 .25591 .06587 .2488 Mtetra
.06587 .2488 .07336 .25591 .08327 .25206 .0758 .24492 Mtetra
.0758 .24492 .08327 .25206 .09321 .2482 .08576 .24103 Mtetra
.08576 .24103 .09321 .2482 .10319 .24432 .09576 .23712 Mtetra
.09576 .23712 .10319 .24432 .11321 .24043 .1058 .2332 Mtetra
.1058 .2332 .11321 .24043 .12327 .23652 .11588 .22926 Mtetra
.11588 .22926 .12327 .23652 .13337 .2326 .12601 .22531 Mtetra
.12601 .22531 .13337 .2326 .1435 .22866 .13617 .22134 Mtetra
.13617 .22134 .1435 .22866 .15368 .2247 .14637 .21736 Mtetra
.14637 .21736 .15368 .2247 .1639 .22073 .15661 .21335 Mtetra
.15661 .21335 .1639 .22073 .17416 .21674 .1669 .20934 Mtetra
.1669 .20934 .17416 .21674 .18447 .21274 .17722 .2053 Mtetra
.17722 .2053 .18447 .21274 .19481 .20872 .18759 .20126 Mtetra
.18759 .20126 .19481 .20872 .20519 .20468 .198 .19719 Mtetra
.198 .19719 .20519 .20468 .21562 .20063 .20845 .19311 Mtetra
.20845 .19311 .21562 .20063 .22609 .19656 .21894 .18901 Mtetra
.21894 .18901 .22609 .19656 .2366 .19248 .22948 .18489 Mtetra
.22948 .18489 .2366 .19248 .24715 .18838 .24006 .18076 Mtetra
.24006 .18076 .24715 .18838 .25775 .18426 .25068 .17661 Mtetra
.25068 .17661 .25775 .18426 .26839 .18012 .26134 .17245 Mtetra
.26134 .17245 .26839 .18012 .27907 .17597 .27205 .16826 Mtetra
.27205 .16826 .27907 .17597 .2898 .1718 .2828 .16406 Mtetra
.2828 .16406 .2898 .1718 .30057 .16762 .2936 .15985 Mtetra
.2936 .15985 .30057 .16762 .31138 .16342 .30444 .15561 Mtetra
.30444 .15561 .31138 .16342 .32224 .1592 .31533 .15136 Mtetra
.31533 .15136 .32224 .1592 .33314 .15496 .32626 .14709 Mtetra
.32626 .14709 .33314 .15496 .34409 .15071 .33723 .1428 Mtetra
.33723 .1428 .34409 .15071 .35509 .14643 .34826 .1385 Mtetra
.34826 .1385 .35509 .14643 .36613 .14214 .35932 .13418 Mtetra
.35932 .13418 .36613 .14214 .37721 .13784 .37044 .12984 Mtetra
.37044 .12984 .37721 .13784 .38834 .13351 .3816 .12548 Mtetra
.3816 .12548 .38834 .13351 .39952 .12917 .3928 .1211 Mtetra
.3928 .1211 .39952 .12917 .41074 .1248 .40406 .1167 Mtetra
.40406 .1167 .41074 .1248 .42202 .12042 .41536 .11229 Mtetra
.41536 .11229 .42202 .12042 .43333 .11603 .42671 .10786 Mtetra
.42671 .10786 .43333 .11603 .4447 .11161 .4381 .10341 Mtetra
.4381 .10341 .4447 .11161 .45611 .10717 .44955 .09894 Mtetra
.44955 .09894 .45611 .10717 .46758 .10272 .46104 .09445 Mtetra
.46104 .09445 .46758 .10272 .47909 .09825 .47258 .08994 Mtetra
.47258 .08994 .47909 .09825 .49065 .09375 .48417 .08541 Mtetra
.48417 .08541 .49065 .09375 .50225 .08924 .49581 .08086 Mtetra
.49581 .08086 .50225 .08924 .51391 .08471 .5075 .0763 Mtetra
.5075 .0763 .51391 .08471 .52562 .08016 .51924 .07171 Mtetra
.51924 .07171 .52562 .08016 .53738 .07559 .53103 .06711 Mtetra
.53103 .06711 .53738 .07559 .54919 .071 .54288 .06248 Mtetra
.54288 .06248 .54919 .071 .56104 .0664 .55477 .05784 Mtetra
.55477 .05784 .56104 .0664 .57295 .06177 .56671 .05317 Mtetra
.56671 .05317 .57295 .06177 .58492 .05712 .57871 .04849 Mtetra
.57871 .04849 .58492 .05712 .59693 .05245 .59075 .04378 Mtetra
.59075 .04378 .59693 .05245 .60899 .04776 .60285 .03905 Mtetra
.60285 .03905 .60899 .04776 .62111 .04305 .61501 .03431 Mtetra
.61501 .03431 .62111 .04305 .63328 .03833 .62721 .02954 Mtetra
.62721 .02954 .63328 .03833 .6455 .03358 .63947 .02475 Mtetra
.63947 .02475 .6455 .03358 .65778 .0288 .65178 .01994 Mtetra
.65178 .01994 .65778 .0288 .67011 .02401 .66415 .01511 Mtetra
.66415 .01511 .67011 .02401 .68249 .0192 .67657 .01026 Mtetra
.67657 .01026 .68249 .0192 .69493 .01437 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.10459 .22873 m
.10928 .23332 L
s
[(-1)] .09521 .21956 1 .97789 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60504 .03277 m
.60881 .03814 L
s
[(1)] .5975 .02203 .70186 1 Mshowa
.125 Mabswid
.15056 .21073 m
.15333 .21353 L
s
.19737 .19241 m
.20009 .19525 L
s
.24504 .17374 m
.24771 .17663 L
s
.29359 .15473 m
.29622 .15766 L
s
.39347 .11562 m
.39599 .11865 L
s
.44485 .0955 m
.4473 .09858 L
s
.49721 .075 m
.4996 .07812 L
s
.5506 .05409 m
.55293 .05726 L
s
.05944 .24641 m
.06229 .24912 L
s
.66056 .01103 m
.66275 .0143 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00g_ooool4o`000003oa0@4?oooooooooo08?ooooo
003Pooooo`03o`000?oooooooooo01cooooo0_l0001Wooooo`00h?ooool00ol0003oooooooooo`0I
ooooo`?o000000?oooooo`000?ooool0I_ooool00>3ooooo00?o0000ooooooooool05oooool2o`00
00Cooooo0_l0001Vooooo`00h?ooool00ol0003oooooooooo`0Dooooo`?o00001Oooool01?nY_NSo
0000ooooool0001Uooooo`00h?ooool00ol0003oooooooooo`0Booooo`?o00001Oooool3ojVmj003
o`000?oooooo000006Gooooo003Pooooo`03o`000?oooooooooo00oooooo0ol00003ooooo`03o`00
0?ooooooZKgX00GoZKgX00Co0000ojVmj?oooooo0000I?ooool00=kooooo00?oEEEEofIVI_l00000
3_ooool3o`0000Gooooo2OnY_NP01Ol0003oZKgXoooooooooooo000006?ooooo003]ooooo`;o0000
1_ooool;ojVmj003o`000?nY_NSoZKgX00?o0000H_ooool00>[ooooo0ol00005ooooo`koZKgX00Ko
0000ojVmj?nY_NSoZKgXooooool0001Rooooo`00j?ooool2o`0000Gooooo4_nY_NP00ol0003oZKgX
ojVmj002ooooo`03o`000?oooooooooo05oooooo003Uooooo`?o00001OoooolDojVmj006o`000?nY
_NSoZKgXojVmj?oooooo0000HOooool00>?ooooo0ol00005oooooaKoZKgX00?o0000ojVmj?nY_NP0
0_nY_NP00ooooooo0000ooooo`1Oooooo`00h?ooool3o`0000;ooooo00Co0000oooooooooooooooo
6?nY_NP00ol0003oZKgXojVmj002ojVmj0;ooooo00?o0000ooooooooool0GOooool00=kooooo0_l0
0006ooooo`03o`000?nY_NSoZKgX01SoZKgX00?o0000ojVmj?nY_NP00onY_NP00ooooooo0000oooo
o`0Aooooo`Co000000?o410@ooooooooool0A_ooool00=_ooooo0ol00005oooooakoZKgX00?o0000
ojVmj?nY_NP01?nY_NP00ooooooo0000ooooo`0Booooo`03o`000?oooooooooo04Sooooo001foooo
o`;o00000_ooool2o`0005gooooo0_l00006ooooob3oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ooo
oooo0000ooooo`07ooooo`Ko00001Oooool00ol0003oooooooooo`18ooooo`00M_ooool01_o^k^ko
8B4QohN7Qonj^[[o0000omgMgE[ooooo0ol00005ooooob?oZKgX00?o0000ojVmj?nY_NP01OnY_NP0
0ooooooo0000ooooo`0Aooooo`03o`000?oooooooooo04Sooooo001gooooo`04omgMgOl0003o410@
olc<c5Sooooo0ol00005ooooobKoZKgX00?o0000ojVmj?nY_NP01_nY_NP00ooooooo0000ooooo`0@
ooooo`03o`000?oooooooooo04Sooooo001gooooo`04onk^k_lQ8B7o410@onk^kUKooooo0ol00005
ooooobSoZKgX00?o0000ojVmj?nY_NP01onY_NP00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo04Sooooo001gooooo`04ob4Q8OmgMgOoMgMgoc8b<U?ooooo0ol00003ooooo`03o`000?oooooo
ZKgX02[oZKgX00?o0000ojVmj?nY_NP02?nY_NP00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo04Sooooo001fooooo`;o00000_ooool2o`00053ooooo0_l00005ooooobkoZKgX00?o0000ojVm
j?nY_NP02?nY_NP2o`0000gooooo00?oEEEEofIVI_l00000B_ooool00<Wooooo0ol00005oooooc3o
ZKgX00?o0000ojVmj?nY_NP02OnY_NP00ol0003oooooooooo`1Hooooo`00aoooool2o`0000Kooooo
<_nY_NP00ol0003oZKgXojVmj00:ojVmj003o`000?oooooooooo05Oooooo0034ooooo`?o00001Ooo
ooleojVmj003o`000?nY_NSoZKgX00[oZKgX00?oooooo`000?ooool0Eoooool00<;ooooo0_l00006
ooooocOoZKgX00?o0000ojVmj?nY_NP02onY_NP00ol0003oooooooooo`1Fooooo`00_oooool3o`00
00Gooooo>onY_NP00ol0003oZKgXojVmj00:ojVmj003ooooool0003ooooo05Kooooo002looooo`?o
00000oooool00ol0003oooooojVmj00mojVmj003o`000?nY_NSoZKgX00[oZKgX0_ooool00ol0003o
ooooooooo`1Dooooo`00^_ooool2o`0000Kooooo@?nY_NP00ol0003oZKgXojVmj00;ojVmj003oooo
ool0003ooooo05Gooooo002gooooo`?o00001Ooooom3ojVmj003o`000?nY_NSoZKgX00coZKgX00?o
ooooo`000?ooool0E?ooool00;Gooooo0_l00005ooooodKoZKgX00?o0000ojVmj?nY_NP03?nY_NP2
ooooo`03o`000?oooooooooo05;ooooo002booooo`?o00001Ooooom8ojVmj003o`000?nY_NSoZKgX
00goZKgX00?oooooo`000?ooool0Doooool00;3ooooo0_l00006oooood[oZKgX00?o0000ojVmj?nY
_NP03_nY_NP00ooooooo0000ooooo`1Booooo`00[Oooool4o`0000CoooooCOnY_NP00ol0003oZKgX
ojVmj00?ojVmj003ooooool0003ooooo057ooooo0026ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
8?ooool2o`0000Cooooo00?o0000oooooonY_NP0C_nY_NP00ol0003oZKgXojVmj00@ojVmj003o`00
0?oooooooooo053ooooo0026ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07Oooool3o`0000Gooooo
D_nY_NP00ol0003oZKgXojVmj00@ojVmj003ooooool0003ooooo053ooooo0026ooooo`05oa0@4?oo
ooooooooooooool@41006oooool2o`0000GoooooEOnY_NP00ol0003oZKgXojVmj00AojVmj003oooo
ool0003ooooo04oooooo0026ooooo`05o`000?ooooooooooooooool000006?ooool3o`0000Gooooo
EonY_NP00ol0003oZKgXojVmj00BojVmj003o`000?oooooooooo04kooooo0026ooooo`05o`000?oo
ooooooooooooool000005Oooool3o`0000KoooooFOnY_NP00ol0003oZKgXojVmj00BojVmj003oooo
ool0003ooooo04kooooo0026ooooo`05oa0@4?ooooooooooooooool@41004oooool2o`0000Kooooo
G?nY_NP00ol0003oZKgXojVmj00CojVmj003o`000?oooooooooo04gooooo0026ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL04?ooool3o`0000;ooooo00Co0000ooooooooooooooooG_nY_NP00ol0003o
ZKgXojVmj00CojVmj003ooooool0003ooooo04gooooo0026ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03_ooool2o`0000KoooooHOnY_NP00ol0003oZKgXojVmj00DojVmj003ooooool0003ooooo04co
oooo002Fooooo`?o00001OoooomUojVmj003o`000?nY_NSoZKgX01CoZKgX00?o0000ooooooooool0
Boooool009Cooooo0_l00006ooooofOoZKgX00?o0000ojVmj?nY_NP05?nY_NP00ooooooo0000oooo
o`1;ooooo`00TOooool3o`0000KoooooJOnY_NP00ol0003oZKgXojVmj00EojVmj003ooooool0003o
oooo04[ooooo002?ooooo`;o00001Ooooom]ojVmj003o`000?nY_NSoZKgX01KoZKgX00?o0000oooo
ooooool0BOooool008cooooo1?l00003ooooog3oZKgX00?o0000ojVmj?nY_NP05_nY_NP2o`0004[o
oooo002:ooooo`;o00001?ooool00ol0003oooooojVmj01`ojVmj003o`000?nY_NSoZKgX01OoZKgX
00?oooooo`000?ooool0B?ooool008Oooooo0ol00005ooooogCoZKgX00?o0000ojVmj?nY_NP06?nY
_NP00ol0003oooooooooo`17ooooo`00Q?ooool3o`0000GoooooMonY_NP00ol0003oZKgXojVmj00H
ojVmj003ooooool0003ooooo04Oooooo0022ooooo`;o00001_oooomiojVmj003o`000?nY_NSoZKgX
01WoZKgX00?oooooo`000?ooool0A_ooool007oooooo0ol00006ooooog_oZKgX00?o0000ojVmj?nY
_NP06OnY_NP00ooooooo0000ooooo`16ooooo`00OOooool3o`0000CoooooOonY_NP00ol0003oZKgX
ojVmj00JojVmj003ooooool0003ooooo04Gooooo001jooooo`?o00000_ooool00ol0003oooooojVm
j021ojVmj003o`000?nY_NSoZKgX01_oZKgX00?oooooo`000?ooool0A?ooool007Sooooo0_l00006
ooooodGoZKgX00?oZK[UojVmj?nY_NP01onY_NP00onY^nKoZKgXojVmj00aojVmj003o`000?nY_NSo
ZKgX01coZKgX00?o0000ooooooooool0@oooool007Gooooo0ol00005ooooodOoZKgX0onY^^D6ojVm
j0CoZK_V0onY_NP00onX/MkoZKgXojVmj00/ojVmj003o`000?nY_NSoZKgX01goZKgX00?o0000oooo
ooooool0@_ooool007?ooooo0_l00005ooooockoZKgX00?oZKOSojVmj?nY_NP01_nY_NP2ojN^g0Go
ZK[U0_nY_NP3ojN/f`GoZK_V00CoZKgXojRag_nX/MkoZ;7N3OnY_NP00onY^nKoZKgXojVmj00MojVm
j003o`000?nY_NSoZKgX01goZKgX00?oooooo`000?ooool0@_ooool0073ooooo0ol00006ooooocco
ZKgX00?oZ;3NojVghonY]n<00_nY]n<4ojVmj003ojJVe_nW[]coYjkL00?oYjkL0onY^^D00onXYM?o
YjcKojN/f`04ojN/f`;oZK_V0_nWYM@5ojRagP;oZKgX0onWZmT6ojVmj0?oZK_V7_nY_NP00ol0003o
ZKgXojVmj00NojVmj0;o0000@_ooool006kooooo0_l00006ooooocgoZKgX1?nX/=h4ojVgh`03ojVm
j?nVY]KoYZKF00;oYZKF1OnW[]`01?nY^^GoZ:GCojRUdonXYM<4ojN/f`03ok>Zd?nWYMCoYjGD00?o
YjGD0onX/Mh00on`Z]7oYj_IojN[f@04ojN[f@;oZKgX0onVYmH4ojVkiP;oZKgX0onY^nHHojVmj003
o`000?nY_NSoZKgX01koZKgX0_l00012ooooo`00Joooool3o`0000;ooooo00?o0000oooooonY_NP0
=?nY_NP2ojVli`OoZKgX0_nWZmX6ojR`gP;oZKOS00?oZjKBojJVe_nVY]H01?nVY]H2ojN^g0;o/:S@
1OnXYM<00onW[=_o/j[@ok>Zd002ok>Zd0GoYjGD00CoZ;7Nok2ZdOn`Z]7o/:[A1?nWZmT00onf[M3o
YZOFojJWeP04ojJWeP;oZK_V00?oZ:SFojVki_nY^nH01?nY^nHHojVmj003o`000?nY_NSoZKgX01ko
ZKgX00?oooooo`000?ooool0@?ooool006Sooooo0ol00004ooooocGoZKgX00?oZK[UojVlionY_>L0
0onY_>L3ojVmj003ojJWeonWZm[oYj_J00?oYj_J1?nX/=h00on/Y];oZjKBoj^VdP02oj^VdPCoYZKF
00?o[ZOAok2Xd?n`Z=000on`Z=03ojRUd`03ok6Yd?ncZ]3o/j[@00?o/j[@1?nWYM@00ond[=3o/:[A
ok2Zd@03ok2Zd@03ojN[fOnf[M3o]Zg@00;o]Zg@1?nVYmH00oni[m3oZ:SFojRXeP02ojRXePCoZK_V
00?oZ:WGojVmj?nY_NP05_nY_NP00ol0003oZKgXojVmj00OojVmj003o`000?oooooooooo03oooooo
001Vooooo`;o00001_ooooldojVmj0CoZK[U1OnY_>L01?nY_NSoYZOGojJWeonVYmL5ojN[fP03ojR`
g_n/Y];o[:KB00;o[:KB1?n[Y]800onVY]Ko[ZOAojjWd@02ojjWd@Go/:S@00CoZ:GCok6Yd?naZM3o
/JW@1OncZ]000onWYMCo]:c@okB/d002okB/d0Co/:[A1Onf[M03ojJWeP?o^Jo@1?nXZ=H00onY^nKo
Z:WGojRYe`02ojRYe`CoZKgX00?oYj[IojVmj?nY_NP04?nY_NP00ol0003oZKgXojVmj00OojVmj003
ooooool0003ooooo03oooooo001Sooooo`?o00001_ooooldojVmj0;oZKWU1OnY^^D2ojVli`;oYjKE
1?nVYmL4ojN[fP03ojZUd_n/Y];o[:KB00?o[:KB0on[Y]800on]Y]7o[ZOAojjWd@03ojjWd@Go/:S@
1?naZM05ok>Zd0Go]:c@0on`Z]47okJ]d003ojJWe_ni[m3o^Jo@00;o^Jo@0onXZ=H00onj/=3oZ:WG
ojRYe`04ojRYe`03ojVmj?nWZ]WoYj[I00;oYj[I0onY_NP00onX/MkoZKgXojVmj00;ojVmj003o`00
0?nY_NSoZKgX023oZKgX00?o0000ooooooooool0?_ooool0067ooooo0_l00005ooooocCoZKgX1onY
^ND2ojVji@;oZ:KE1OnWY]D4ojJWe`03ojN[f_nZYM;oZZGB00;oZZGB1On/Y]801?n[Y];o[JKAojfV
dOn]Y]45ojjWd@Go/:S@1?naZM05ok>Zd0Go]:c@00?o/:[AokJ]d?nf[M001Onf[M000ong[]3o^Jo@
okV_d004okV_d004ojRXe_nj/=3o^[3@okZ`d0CoZ:WG00?o^k;AojNZfOnWZ]T00onWZ]T00onY_NSo
Z;7NojRagP02ojRagPcoZKgX00?o0000ojVmj?nY_NP08OnY_NP00ol0003oooooooooo`0Sooooo`?o
000000?o410@ooooooooool05?ooool005kooooo0ol00004ooooocCoZKgX00?oZK[UojViiOnY^ND0
1_nY^ND00onWY]GoZ:KEojRVe@03ojRVe@GoYjKE0_nVYmL00onYY=;oZZGBojZUdP03ojZUdPCo[:KB
00?o[:G@ojfVdOn]Y]400_n]Y]44ojjWd@03ojjWd?n`Z=3o/:S@00?o/:S@1?naZM05ok>Zd0Go]:c@
1_nf[M04okN^d0Go^Jo@1Onj/=000onXZMOo^k;Aok^bd@02ok^bd@?oYj[I00?o^;7CojRag_nX/Mh0
1?nX/Mh2ojVmj0?oZK_V1_nY_NP00ol0003oZKgXojVmj00QojVmj003ooooool0003ooooo02Gooooo
00?o410@okZj^_ooool05Oooool003Oooooo1?l000000ol@413oooooooooo`0Nooooo`;o000000?o
ooooo`000?l000000oooooldojVmj0?oZK[U1_nY^ND3ojNVe@CoZ:KE1?nWY]D00onXXm;oZJCBojVT
dP02ojVTdPGoZZGB00?o[:KBojbUd?n/YM000_n/YM04ojfVd@03ojjWdOn^Ym3o[ZO@00;o[ZO@1On`
Z=04ok6Yd0Go/j[@1Ond[=04okJ]d0Ko]jk@1Oni[m03okZ`d003okZad?nk/]7o^k;A00Co^k;A00Co
Yj[IokRadonh/M?o^;7C1?nX/Mh2ok:`ePGoZK_V1OnY_NP00ol0003oZKgXojVmj00RojVmj003o`00
0?oooooooooo02Cooooo00?oV9RHoc8b<_ooool05Oooool003Wooooo00?o0000ooooooooool07Ooo
ool3o`0000Gooooo=?nY_NP3ojVli`CoZK[U0_nY^ND2ojJUe@GoYjKE1?nXY]D00onWY]GoZ:?BojRS
dP02ojRSdPCoZJCB0_nZYM82ojZTd0Go[:G@0on]Y]400on]YM3o[ZO@ojjWd003ojjWd0Go/:S@1?na
ZM05ok>Zd0Ko]:c@1?nf[M05okN^d0Go^Jo@00?o^[3@okZad?nj/M000_nj/M04ok^bd@03ok^bd?nh
/M?o^;7C00?o^;7C00?oZ;7Nok:`e_nb/=H00onb/=H2ojVkiP;oZJgJ1OnY_NP00ol0003oZKgXojVm
j00RojVmj003ooooool0003ooooo02Cooooo00?ogMgMo`000?nj^[X05Oooool002kooooo1_l00005
ooooo`03o`000?oooooooooo01_ooooo0_l00005ooooocGoZKgX1_nY_>L2ojVji@03ojFUe_nVYMGo
YZGE00?oYZGE1OnWY]D2ojRVe@03ojNSd_nXXm;oZ:?B00?oZ:?B0onYY=800onYXm3oZZC@ojZTd003
ojZTd0Go[:G@00Co[JKAojfUd?n]YM3o[JG@1On^Ym05ok2Xd0Co/JW@1OncZ]04okB/d003okB[conf
[M3o]Zg@00;o]Zg@1_ng[]04okV_d0Ko^[7@00?o^k;Aok^bd?nk/]000_nk/]03okRad`03okfddOnb
/=Ko/[3F00?o/[3F00?o_kKAojV]f_nY[MX00onY[MX3ojVmj003ojViiOl0003oZKgX02CoZKgX00?o
ooooo`000?ooool08oooool00omEEEGoMgMgodA4A00Eooooo`00>Oooool00ol0003oooooooooo`0H
ooooo`?o00001?ooooliojVmj0CoZKcW00?oY:GFojFUe_nUYMH00_nUYMH5ojJUe@;oYjKE0_nVX]84
ojNSdPGoZ:?B00CoZJCBojVSd?nYXm3oZJ?@1?nZY=04ojbUd003ojbTcon]YM3o[JG@00;o[JG@1?n^
Ym000on_Y/oo/:S@ok2Xd003ok2Xd0?o/JW@00?o/ZW?ok>Zd?ncZ]001?ncZ]000ond[=3o]:_?okB[
c`02okB[c`Co]Zg@1Ong[]05okV_d0Co^[7@00?o^k7@ok^bd?nk/]001?nk/]001?nh/M?o_KCAokfd
dOnm]=43ok:`eP?o_kKA1?nY[MX01OnY_NSoZKWUojViiOnY^NGo000002KoZKgX0_l0000Rooooo`05
omgMgOl@413oooooob4Q8OoMgMd05?ooool003Wooooo00?o0000ooooooooool05Oooool3o`0000Go
oooo??nY_NP00onY_>OoY:GFojBUeP02ojBUeP?oYJGF1?nVYMD00onUX];oYZ;BojJRdP03ojJRdPCo
Yj?B0_nXXm82ojRRd0CoZJ?@1OnZY=000on/YM3o[:C?ojbTc`02ojbTc`Co[JG@00?o[ZO@ojnVcon_
Y/l00_n_Y/l5ok2Xd004ok6Yd?nbZLoo/ZW?ok:Yc`Co/j[@00?o/j[?okB[condZll00ondZll3okJ]
d003okJ/cong[]3o]jk@00Co]jk@1?ni[m03okZad0?o^k7@1?nk/]000onl/]3o_KCAokfdd@03okfd
d@03ok:`e_no]]7o_kKA00;o_kKA0onY[MX2okVde@?oZKWU00?o0000ojViiOnY_NP09?nY_NP2o`00
02;ooooo00GoIVIVohN7QoooooooV9RHoeEEE@0Dooooo`00>Oooool00ol0003oooooooooo`0Coooo
o`;o00001_oooolmojVmj003ojFWeonTYMKoY:GF00?oY:GF1?nUYMH00onVYMGoYJ;BojFRdP02ojFR
dPCoYZ;B0onWXm800onWXM3oZ:;@ojRRd003ojRRd0CoZJ?@0_nZY=02oj^Sc`Go[:C?0on]YM000on^
YLoo[jK?ojnVc`03ojnVc`Co/:S@00?o/JO?ok:YconbZLl00onbZLl00oncZ]3o/j[?ok>Zc`02ok>Z
c`Go]:_?00Co]Zg@okJ/conf[<oo]Zc?1?ng[]000onh[Loo^Jo@okV_d003okV_d003okZad?nk/M3o
^k7@00;o^k7@0onk/]02okbbd0Go_KCA1_no]]400onY[M[o^KCEokVde@02okVde@;oZKWU00?o0000
ojb_fon/[m/09OnY_NP00ooooooo0000ooooo`0Oooooo`03onk^k_l0003ok^k^00;ooooo00?o0000
omgMgOooool04_ooool003Wooooo00?o0000ooooooooool04?ooool3o`000003ooooool0003o0000
00;ooooo??nY_NP2ojN[fPCoYJOG1OnTYMH2ojFUeP03ojBQdonUX];oYJ;B00?oYJ;B1OnVX]801?nW
Xm;oYj7@ojNQd?nWXM04ojRRd0?oZJ?@00?oZJ;?oj^Scon[Xll00on[Xll5ojbTc`04ojfUd?n^YLoo
[ZG?ojjUc`Go[jK?00?o/:S@ok6WconaYll00_naYll4ok:Yc`Go/j[?1?ndZll00oneZlko]Zc?okJ/
c`03okJ/c`03okN^d?nh[Loo^:g?00;o^:g?0oni[m000onj[loo^k7@ok^ad004ok^ad003ok^bd?nl
/]3o_;;@00;o_;;@1Onm]=45oknfd@Co^KCE00Co`[SAojb_fon/[m_o00000on/[m/TojVmj003oooo
ool0003ooooo01oooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Aooooo`00
=oooool00omEEEGoIVIVo`00000@ooooo`;o00001OoooollojVmj003ojR`g_nWZm[oYj_J00?oYj_J
1?nUYmL2ojBUeP;oXj7C1?nTXM<5ojFRdP;oYZ;B0_nVX=04ojNQd0GoZ:;@00CoZJ?@ojVRconYX/oo
ZJ;?1On[Xll2ojbTc`;o[JC>1?n^YLl4ojnVc`03ok2Vc_naYloo/JO?00?o/JO?0onbZLl2ok>XcPGo
/j[?00?o]:_?okF[c_neZlh00_neZlh3okJ/c`03okN/c_nh[Loo^:g?00Co^:g?00Co^Jo@okZ_conj
[loo^Zo?1?nk/M000onk/<oo_;;@okbbd003okbbd0Ko_KCA1Ono]]42okVde@?o`[SA00Go[:oKo`00
0?n/[m_o[:oKokVfeP0UojVmj003ooooool0003ooooo03Sooooo0017ooooo`?o00001OoooolmojVm
j0?oZ;3N1OnWZmX2ojFWe`03oj:Qe?nSXM?oXj7C00?oXj7C0onTXM<4ojFRdP03ojBOd?nVX=3oYZ3@
00?oYZ3@1?nWXM02ojRRd0;oZ:7>1?nYX/l4oj^Sc`03ojbRc_n]Y<ko[JC>00?o[JC>1?n^YLl00on_
Y/oo/:K>ok2VcP02ok2VcPGo/JO?00Co/ZW?ok>Xc_ncZ<ko/jS>1?ncZ/l00ondZLgo]J_>okF[cP03
okF[cP03okJ/cong[<ko]jc>00;o]jc>1?nh[Ll00oni[Lgo^Zo?okZ_c`03okZ_c`03ok^ad?nk/<oo
^k3?00;o^k3?0onl/]000onm//oo_KCAokfdd@03okfdd@03okjdd?no]]7o_kKA00?o_kKA00?o^KCE
ol:hdOo2^=400oo2^=400ol0003o^KKFokVfeP02okVfeP?oZKgX00?oZ;;OojVmj?nY_NP07onY_NP0
0ooooooo0000ooooo`07ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool004Gooooo0_l00006
oooooccoZKgX0_nY]n<4ojR`gPCoYj_J00?oXJ7Eoj:Qe?nRXM@00_nRXM@4oj>Qd`CoY:7C00?oYJ;B
ojBOd?nTWm000_nTWm04ojJPd0?oYj7@00?oYio>ojRQc_nXXLh00onXXLh4ojVRc`03oj^Scon/X/ko
[:;>00;o[:;>1?n]Y<h3ojjUc`03ojnUc_n`Y/ko/:K>00?o/:K>1?naYll00onbYlgo/jS>ok>XcP03
ok>XcP03ok>ZcondZLgo]:W=00;o]:W=1?neZlh5okN/cP?o^:g?0oni[Ld4okZ_c`Ko^k3?00Co_;;@
okfbconm//oo_K;?0onm]=43okjdd0?o_kKA00?o`;OAol:hdOo2^=400oo2^=400oo2^M7o0000okVf
eP03okVfeP03ojVmj?nX/]ooZ;;O00;oZ;;O8OnY_NP00ol0003oooooooooo`06ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0:oooool004;ooooo0ol00005ooooocgoZKgX1OnY]n<4ojR`gP03ojN[f_nQ
XMGoXJ7E00;oXJ7E0onRXM@5oj>Qd`;oY:7C00?oXioAojBOd?nTWm000onTWm05ojJPd004ojNQd?nW
WlkoYio>ojNOcPCoZ:7>0onYX/l00onZXLko[:;>ojbRcP03ojbRcPGo[JC>00Co[ZG?ojnUc_n_YLko
[jG>1On`Y/h00onaYloo/ZO=ok:Wc@02ok:Wc@?o/jS>00?o/jS=okBYcOndZLd00ondZLd3okF[cP;o
]Z[=1Ong[<h00onh[Loo^Jg=okV]c@02okV]c@?o^Zo?0_nk[/d4ok^`c`03okf`cOnm//oo_K;?00?o
_K;?00?o_KCAokjdd?nn]=000onn]=001?no]]7o`;OAol2gdOo0]m43ol:hd@?o`[WA00?o0000okVf
e_ni]]H00_o4^m85ojRbgb7oZKgX00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo
410@02_ooooo0010ooooo`;o00001Ooooom1ojVmj0GoZKOS0_nX/=h00onPXMKoXJ7Eoj6Qe@03oj6Q
e@CoXZ7D0_nSXM<2oj:Od@CoXioA1OnTWm02ojJPd0;oYIo?1?nWWlh5ojRQcP04ojVRconZXLkoZZ7>
ojZQcPGo[:;>0_n]Y<h2ojjSc@Co[jG>1?n`Y/h00onaY/go/ZO=ok:Wc@04ok:Wc@04ok>Xc_ncZ<go
/jS=ok>Xc@Go]:W=00Co]J_>okJZcOnfZ/go]Z[=1?ng[<h00onhZlco^Jg=okV]c@04okV]c@04okZ_
conk[/go^jk=ok^^c@?o^k3?0onm/<d4okfbc`Go_[C@00?o`;C?ol2gdOo0]m400oo0]m400oo2^=7o
`[WAol:id@02ol:id@03o`000?ni]]Koa;_B00?oa;_B0_nX/]l2ok:efb7oZKgX00?oooooo`000?oo
ool01Oooool01Ol0003ooooooooooooooooo000002_ooooo000mooooo`?o000000?oooooo`000?oo
ool00_oooom4ojVmj0;oZKOS0_nNXMH4oj2QePGoXJ7E0_nRXM@00onQWm;oXYoAoj:Od@03oj:Od@Co
XioA0onTWm000onTW/ooYIo?ojFOc`03ojFOc`CoYio>0_nXXLh2ojVPcPCoZZ7>1?n/X/h00on/X/go
[Z?=ojjSc@03ojjSc@Co[jG>00?o/:K>ok6VcOnaY/d00_naY/d4ok:Wc@03ok:Vc?ncZ<go/jS=00;o
/jS=1?ndZLd00oneZ<co]Z[=okJZc@03okJZc@03okN/c_nhZlco^:_<00;o^:_<1?ni[Ld00onj[<co
^jk=ok^^c@03ok^^c@03ok^`conm/<go_K3=00;o_K3=0onm//l2okjbcP?o_[C@0oo0]<l4ol2gd@Go
`[WA00?o0000olBkd_o4^m800_o4^m800oo6_=7o/[GKok:ef`03ok:efb7oZKgX00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000002_ooooo000kooooo`;o00001Oooool00ol0003o
ZKgXojVmj013ojVmj0;oWj?H1?nNXMH4oj2QeP;oXJ7E0_nPWm<4oj6OdPCoXYoA1OnSWm401?nTWm3o
Y9k?ojBNconTW/l4ojFOc`CoYio>1OnYX<h4ojZQcP03ojbRc_n/X/go[:;=00;o[:;=1On^Xld2ojnU
cP03ojnTcOnaY/go/JK=00Co/JK=00?o/ZO=ok:Vc?nbY/`00_nbY/`4ok>Xc@03okBYcOneZ<co]JS<
00;o]JS<0onfZ/d00ongZL_o^:_<okR[c004okR[c003okV]cOnj[<co^Zc<00;o^Zc<0onk[/d00onl
[/co_K3=okf`c@04okf`c@03okfbconn//ko_[;>00;o_[;>00?o_[C@ol2dcoo0]<l00_o0]<l3ol2g
d@;o`KO@0oo2^M400oo2^]7o0000ol:jd@02olBkdP?oa[cA0onb]M/2okfkf23oZKgX00?oooooo`00
0?ooool01?ooool01Ol@413ooooooooooooooooo410@02_ooooo000hooooo`?o00001Ooooom5ojVm
j003ojN^g?nOXmSoWj?H00?oWj?H1?nNXMH2oj2QeP03oinOe?nPWm?oX9oC00?oX9oC0onQWm85oj:O
d@;oXioA0_nSWM04ojBNc`GoYIo?1?nWWlh4ojVPcP?oZZ7>00?oZj7=ojbRcOn/X/d00on/X/d4ojjS
c@03ojjSc?n_Y<go[jC=00;o[jC=1?naY/d00onaYLco/ZK<ok:Vc003ok:Vc0?o/jS=00?o]:O<okFX
c?neZ<`01?neZ<`01?nfZ/go]jW;okNYbongZL/4okR[c003okV[bonj[<co^Zc<00Co^Zc<00Co^jk=
okb^c?nl[/co_:k<1?nm/<d00onn/<co_[;>okjbcP03okjbcPKo`;C?00?o`;OAol6gd?o1]m000_o1
]m001_o2^M7o`[[Aol:jdOl0003o`[[AolBkdPGoa[cA00?o/[GKokfkf?nm^mP00_nm^mPPojVmj0;o
00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo000eooooo`?o00001?oooom5ojVmj0;o
ZK[U1?nW[]`5oinSf0;oWZ7F00?oWYoEoinOe?nOWm@00_nOWm@4oj2Od`CoXIoB0_nRWm42oj6Md0Go
Xig@1?nTW/l2ojFOc`;oYYk>1?nWWlh5ojVPcP04ojZQc_n[XLgoZj7=oj^Qc@Go[:;=00?o[Z?=ojjS
c?n^Xl`00_n^Xl`4ojnTc@03ok6VcOnaYLco/JG<00;o/JG<1OnbY/`01?ncZ<go]:O<okBWc?ndYl`4
okFXc003okJXbongZL_o]jW;00;o]jW;0onhZl`3okV[b`Co^Zc<00?o^jc;okb^c?nl[/`00onl[/`0
0onm/<go_[3<okj`c002okj`c0?o_[;>0_o0/ld4ol2dc`03ol6ec_o1]m3o`KO@00;o`KO@00Ko`[S@
ol:jdOo2^]7o`[[Ao`000?o2^]45olJld@03olJmd_nm^mSo_K_H00;o_K_H00?oaKoDojVmj?nY_NP0
7onY_NP00ol0003oooooooooo`02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool003?ooooo
0_l00004ooooodKoZKgX1OnY^^D4ojN^g0;oWj?H0_nLWmH4oijOe@CoWioD1?nPWm<2oj6OdP03oj2M
dOnQWM3oXIg@00?oXIg@1?nSWM03ojBNc`03ojBMc_nVW/koYYk>00?oYYk>1?nWWlh2ojVPcP;oZJ3=
1?n[XLd4ojbRc@03ojfRc?n^Xlco[Z?<00?o[Z?<0on_Y<d00on`Y<co/JG<ok6Uc003ok6Uc0Co/ZK<
00?o/jK;okBWc?ndYl`00_ndYl`3okFXc0?o]ZS;1?ngZL/00onhZlco^J_;okV[b`02okV[b`?o^Zc<
0_nk[</4okb^c003okj^bonn/<co_[3<00Co_[3<00?o_[;>ol2ccOo0/ld00_o0/ld00oo0]<oo`KG>
ol6ecP02ol6ecP;o`KO@0oo2^=02ol:jd@03o`000?o3^]7o`k[A00?oa[cA0oo6_M82okfkf0?oaKoD
0onY_NP00onY^^GoZKgXojVmj00JojVmj003ooooool0003ooooo03;ooooo000`ooooo`?o00001Ooo
oom8ojVmj0GoZK[U0_nW[]`00onKWmOoW9oFoibOeP03oibOeP?oWYoE1OnOWm@2oj2Od`03oinMd_nP
WM7oX9gA00;oX9gA1?nQWM05oj>Md004ojBNconTWLkoY9g>ojBMcPCoYYk>0onWWlh00onWW/goZJ3=
ojVPc@03ojVPc@CoZj7=00?o[:;=ojfRc?n]X/`00_n]X/`5ojjSc004ojnTcOn`Y<co/:C<ok2Tc0Go
/JG<00Co/ZK<ok>VboncY/_o/jK;1OndYl`00oneZ<co]ZS;okJXb`02okJXb`?o]jW;00?o^:W:okV[
boniZl/01?niZl/00onj[<co^jc;ok^/b`02ok^/b`;o_:k<0onn[//4okj`c003ol2`boo0/lgo`;?=
00;o`;?=00?o`[?<ol6ec_o1]Lh00oo1]Lh00oo1]m3o`[S@ol:hd003ol:hd0;o00000oo3^]400oo6
_=7oa[gBolJmdP02olJmdP03okfkf?o5_mCoaKoD00?oaKoD00CoZKgXojVjiOnY^^GoZK[U7?nY_NP0
0ooooooo0000ooooo`0aooooo`00;_ooool2o`0000?ooooo00?o0000ooooooooool0BonY_NP2ojVj
i@;oVIkH1?nKWmL4oibOePCoWYoE0_nOWm@2oifMd`CoWigB1?nPWM44oj6Md0;oXig@0_nRW<l4ojBM
cPGoYYk>00CoYio>ojNNcOnWW/goYik=1?nYX<d3oj^Qc@03oj^Qc?n]X/co[J;<00?o[J;<1?n^Xl`0
0on_Xl_o/:C<ok2Tc002ok2Tc0Co/JG<00?o/ZG;ok>VboncY//00oncY//3okBWc003okFVb_nfZ<_o
]ZS;00Co]ZS;00Co]jW;okRYb_nhZL[o^:W:1?niZl/00onjZ/Wo^jc;ok^/b`03ok^/b`03okb^c?nn
[/_o_Zk;00;o_Zk;0onn/<`3ol2`b`;o`;?=0oo2/l`4ol6ecP?o`[S@0ol000000oo3^]7o0000ol>j
d@02ol>jd@Goa[gB1Oo5_m@00oo;`];oZK[UojVji@03ojVjiA_oZKgX00?oooooo`000?ooool0<Ooo
ool002_ooooo0ol00005ooooodgoZKgX00?oY:_LoiVNf?nIW]P00onIW]P3oi^Oe`GoW9oF0_nNWmD0
0onLW]GoWIgCoifMd`03oifMd`?oWigB1OnPWM42oj6Md003oj6Ld?nRW<ooXYc?00?oXYc?1?nTWLh2
ojJNcP;oYYg=1?nWW/d5ojVPc@04oj^QcOn[XLcoZj7<oj^Qc0Go[J;<00?o[Z?<ojnSbon_Xl/00_n_
Xl/4ok2Tc003ok6Uc?nbYL_o/ZG;00;o/ZG;1?ncY//00ondYlco]JK:okFVbP02okFVbPCo]ZS;00?o
]jO9okRYb_nhZLX00_nhZLX3okV[b`?o^Z[91?nk[</6okj^b`03okj`c?o0/<_o`;3;00;o`;3;00?o
`;?=ol:cc?o2/l`00_o2/l`3ol6ecP05ol>fcOl0003o0000o`000?o2^=000oo4^Ll00oo3^]7o0000
ol>jd@02olFkd@?oa[gB0_o7_m83olFoe0?obl;B0_nY^^D3ojbiha_oZKgX00?oooooo`000?ooool0
<?ooool002[ooooo0_l00004ooooodgoZKgX00?oZK_VojB[g?nTZm`00_nTZm`5oiVNf0?oVioG0_nL
WmH2oi^NePCoW9kE1?nMWM<4oinMdP;oX9gA0_nOW=44oj6Ld0CoXYc?1?nTWLh5ojJMc@CoYik=0_nY
X<d2ojZOc0CoZj7<1?n]X/`00on]XL_o[j?;ojnSb`03ojnSb`?o/:C<00?o/J?;ok:UbonbYL/00onb
YL/3ok>Vb`03ok>Ub_neY/[o]JK:00?o]JK:0onfZ</3okNWb@Co^:W:00?o^J_;okZZbOnjZ/T00_nj
Z/T3ok^/b`;o_Jc91?nn[//00ono[/Wo`;3;ol2`b`03ol2`b`Ko`[?<0ol00002ol>fc@03ol:hd?o4
^Looa;W?00?oa;W?00?o`k[Ao`000?o5^m400_o5^m400oo6_M;oakoBolNodP02olNodP03olFoe?o;
`];obl;B00;obl;B1_n/^N<KojVmj003o`000?oooooooooo02oooooo000Zooooo`?o000000?ooooo
ojVmj?nY_NP0C?nY_NP3ojVkiPCoY:_L1?nIW]P3oiZNe`GoVikF0onLW]D5oifMd`;oWigB00?oWIcB
oinLdOnOW=400onOW=43oj6Ld0GoXYc?1?nTWLh4ojJMc@?oYik=00?oZ9k<ojZOc?nZWl`00onZWl`4
oj^Qc003ojfRc?n]XL_o[J7;00;o[J7;1On_Xl/01?n`Y<co/J?;ok6SbonaXl/5ok:Ub`04ok>Vbonc
YL[o/jG:ok>UbPGo]JK:00?o]ZS;okNWbOngYlT00_ngYlT3okRYbP03okVXbOnjZ/Wo^Z[900Co^Z[9
00Co^jc;okf/bOnm[<Wo_Jc90onn[//3okn^b@?o`;3;0_o2/LX2ol:cc0?o00001Oo3]/d5olBic`06
olJjcoo5^m7oaK_Ao`000?o5^m7oa[gA1Oo7_m801?o8`=?obl;Bol_2d_o;`]82olk4d@Co[;WS00?o
/[kSojVmj?nY_NP06OnY_NP00ooooooo0000ooooo`0_ooooo`00:_ooool00ol0003oooooojVmj01@
ojVmj0?oZK_V0_nTZm`00onGW]WoVIkHoiVNf003oiVNf0?oVYkG1?nKW]H4oibNe@;oWIgC0_nLW=<4
oifLdPCoWicA1?nQW=04oj:Lc`CoY9g>1OnVWLd01?nWW/goZ9k<ojRNc?nXW/`4ojZOc0?oZj7<00?o
[:3;ojfQbon]XL/00on]XL/4ojnSb`03ojnRb_naXl_o/J?;00;o/J?;1?nbYL/00onbY<[o/jG:ok>U
bP02ok>UbPCo]JK:00?o]JK9okNWbOngYlT01?ngYlT01?nhZL[o^JS9okVXbOniZ<T4okZZb@03ok^Z
b?nm[<Wo_Jc900?o_Jc900?o_Zk;okn^bOno[/T00ono[/T00oo0/<_o`[7:ol:abP03o`000004ol:c
c?o4]<_oa;C;olBdb`?o`kK=0_o5]ld3olBic`?oa[[?00?oaK_Ao`000?o6_M400_o6_M43olNodP?o
b<3C00?obl;Bolk4dOo>a=400_o>a=400on/^N?o/[kSok:nh`02ok:nha_oZKgX00?oooooo`000?oo
ool0;_ooool001oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?ooooooZKgX04oo
ZKgX00CoY[3OoiBLfOnDW=WoU9cI1?nGW]T4oiVNf0CoVYkG1?nKW]H2oibNe@03oi^Le?nLW=?oW9cC
00?oW9cC0onMW=85oinLd@;oXIc@00?oX9_@oj:LconRW<l00onRW<l4ojBMcPCoYYg=1?nXW/`5ojZO
c004oj^Qc?n/X<_o[:3;ojbPb`Go[J7;00?o[j?;ojnRb_n_X/X00_n_X/X4ok6Sb`03ok:UbonbY<[o
/ZC:00;o/ZC:1?ncYLX00oneY/[o]JK9okFVb@02okFVb@Co]jO900?o]jO8okVXbOniZ<T00oniZ<T0
0onjZ/Wo^j[8ok^Zb002ok^Zb0?o_Jc900?o_Zc8okn^bOno[/T00ono[/T01?o1[lSo0000o`000?l0
0002ol:abP03ol:cc?o4]<_oa;C;00?oa;C;00?o`kK=olFgcOo5]ld00_o5]ld00oo4^Looa[[?olJj
c`02olJjc`03olFkdOo6_M7o000000?oa[gA00GoakoBolS0doo8`=?ob<3ColW2d`05olk4d@05olo6
d_nb_^?o/[kSok:nhone`^@07?nY_NP00ol0003oooooooooo`0]ooooo`007oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo00Co0000ooooooooooooooooCOnY_NP4ojJ`g`?oU9cI1?nGW]T4oiVN
f0;oVYkG00?oVIgGoiZMe_nJWMH00_nJWMH4oi^Le0CoW9cC1?nMW=82oinLd@;oWY_@1?nPVm04oj:L
c`?oY9g>00?oY9c=ojJMcOnVWLd00onVWLd3ojRNc0CoZYo<00?oZYo;ojbPbon/X</00_n/X</4ojfQ
b`03ojjQb_n_X/[o[j;:00?o[j;:0onaXl/00onaXlWo/ZC:ok:TbP03ok:TbP?o/jG:00?o]:G9okFV
bOneY/T00oneY/T3okNWb@;o]jO81?niZ<T00onjZ<So^j[8ok^Zb004ok^Zb004okf/bOnn[<So_Zc8
okj/b0;o_jk90ol000000oo1[lSo`[7:ol:abP02ol:abPGoa;C;00?oaKG:olFgcOo5]ld00_o5]ld0
0oo7^<coa[[?olJjc`03olJjc`?oa[gA00?o0000olJmdOo8_]400oo8`=<3olW2d`?oc/CA0oo?a]80
1?nb_^?o]L;TokG2i?ne`^@LojVmj003o`000?oooooooooo02cooooo000Oooooo`05oa0@4?oooooo
ooooooooool@41001Oooool3o`0000;oooooCOnY_NP3ojJ`g`CoU9cI1?nGW]T2oiVNf003oiRNf?nI
WMOoVIgG00;oVIgG1?nJWMH3oi^Le0GoW9cC0_nMW=800onLVm7oWY_@oijKd003oijKd0?oX9_@1OnR
W<l01?nTWLkoY9c=ojBLcOnTW<d4ojJMc@CoZ9k<00?oZYo<ojZObonZWl/00_nZWl/4ojbPb`03ojfQ
bon^XL[o[Z7:00;o[Z7:1On_X/X01?naXl_o/J?9ok6SbOnaXlT5ok:TbP04ok>Ub_ndYLWo]:G9okBU
b@Go]JK900?o]jO9okNWb?ngYlP00_ngYlP2okVXb@?o^ZS81?nkZ/P01?nlZ/Oo_Zc8okj/b?nn[<P3
o`0000Co`Jo80oo2/LX2ol>bb@?oa;C;0oo5]LX2olFgc@?oakS<0oo6^/l2olNkcP;oa[gA00Go0000
olRndOo8_]7ob;kAolS0d`05olW2d`05olk4dOo?a];oclKBolo6d_o@b=801One`^@KojVmj0;o0000
;Oooool001oooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00?ooooo
COnY_NP3ojJ`g`;oU9cI00?oUIkJoiNNfOnGW]T00_nGW]T4oiRNf0?oVIgG1OnJWMH3oi^Le0;oW9cC
0_nKVm<4oibKd@CoWY_@1?nPVm02oj:Lc`;oXI_>1?nTW<d5ojJMc@;oZ9k<00?oZ9g<ojZObonZWl/0
0onZWl/3ojbPb`03ojbOb_n^XL[o[Z7:00?o[Z7:1?n_X/X00on`XLWo/J?9ok6Sb@02ok6Sb@Co/ZC:
00?o/j?8okBUbOndYLT00_ndYLT4okFVb@03okJUb?ngYlSo]jO800?o]jO800?o^JS9okZXb?njZ<P0
0_njZ<P3ok^Zb0?o_:[70_l00002okj/b0Ko`Jo800?o`[7:ol>bbOo3//T00_o3//T00oo4]<_oaKG:
olFebP02olFebP03olFgcOo7^<coakS<00?oakS<00?oa[[?olNkc_o7^lh00_o7^lh00oo6_M7ob;kA
o`000002olRnd@GobL;C00CoblCColo6d_o?a];oclKB0oo@b=82okG2i0?o]/GV6onY_NP00ol0003o
ooooooooo`0[ooooo`007oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooooooo
ool01?oooom:ojVmj0;oVJGN0onBWMX4oiFNfPCoUikI0onHW]P4oiVMe`;oVYgF0_nHVmD3oiVKe0Go
Vi_C0onLVm45oijKd0;oX9_@00?oWi[?oj6Kc_nQVlh00onQVlh4ojBLc@;oYYg=0_nVW<`4ojRMc0Go
ZYo;00Co[:3;ojbOb_n/Wl[o[9o:1On^XLX00on_X/[o/:79ok2Qb@02ok2Qb@Co/J?900?o/ZC:ok>S
b?ncXlP00_ncXlP4okBUb@03okFVbOnfYLSo]ZG800;o]ZG80ongYlP00onhYlOo^ZS8okZXb004okZX
b003ok^Zb?nlZ/Oo000000;o00000onn[<P2okn]a`Co`Jo800?o`[37ol>bbOo3//T00_o3//T00oo5
/lSoaKG:olFebP03olFebPGoakS<00?obKW;olNkc_o7^lh00_o7^lh2olVmcP;ob;kA00?o0000ol[0
dOo:`=400oo9`]<3ol_4d`03olo6d_o@b=;od<SB00;od<SB1_nfaNHJojVmj003ooooool0003ooooo
02_ooooo000Oooooo`05oa0@4?ooooooooooooooool@41001Oooool2o`0000KoooooAonY_NP5oiVU
gP?oTYgJ0onEW]X5oiNNf@?oV9kH0_nIWML00onGW=KoV9_EoiRKe@03oiRKe@?oVI_D1?nKVm<4oibK
d@;oWY_@0_nMV]04oinJc`CoXI_>0onTW<d00onSVlgoYYc<ojJLc003ojJLc0?oZ9g<1?nZWl/00onZ
W/[o[9o:ojbObP02ojbObPCo[Z7:00?o[Z39ok2QbOn`XLT00on`XLT3ok6Sb@03ok6Rb?ncXlSo/j?8
00?o/j?80ondYLT00ondY<So]ZG8okJUb004okJUb004okNWb?nhYlOo^:O7okRWa`Co^ZS80ol00004
okbZa`04okj/b?no[LOo_jg7okn]a`?o`Jo80oo2/<L2ol>bb@?oaK?80oo5]LX2olNfb@?oakS<0oo9
^L/2olNkcPCobKg>00?ob;kAol[0dOl000000_o:`=400oo9`]?oblCCol_4d`02ol_4d`God<SB00?o
d/_CokK5i_nfaNH00_nfaNH00oncanWoZKgXojVmj00IojVmj003ooooool0003ooooo02[ooooo000O
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`06ooooodOoZKgX1?nI
YMh4oi:MfP?oUIkJ0_nGW]T2oiFMf@?oUYcH1?nGW=H4oiRKe@CoVI_D1?nKVm<2oibKd@03oi^IdOnM
V]3oWI[@00?oWI[@0onOV/l5oj6KcP04ojBLcOnSVlgoXi_=oj>Kc@CoYYc<1?nXWL`00onZWl_oZYk:
ojZNbP02ojZNbPCo[9o:00?o[Z7:ojjPbOn^X<T00_n^X<T5ok2Qb@04ok6SbOnaX/So/J;8ok6Rb0Go
/j?800Co]:G9okBTb?ndY<So]:C81?nfYLP00ongYLOo^:O7okRWa`02okRWa`04okZXb?l0003o0000
o`0000;o^jS71?nlZ/L00onnZlOo_jg7okn]a`03okn]a`03ol6_b?o2/<Oo`[3700;o`[3700?o`k;9
olFcb?o5/lP00oo5/lP00oo5]L[oakK9olNfb@02olNfb@03olNhc?o9^L_obKW;00;obKW;00?oak_>
olVmc_o9_Lh00oo9_Lh2ol[0d@03o`000?o:`=7oc<;A00GoblCC00CocLKDom38d_o@b=;od<SB0ooB
bm<00onfaNKo/lOYok?7j@02ok?7jA_oZKgX00?o0000ooooooooool0:Oooool001oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo00OoooooAonY_NP4oiVUgP;oTYgJ00Co
TYgKoiBMf_nDWM[oU9gJ1OnEWMT3oiJLf0?oUicF1OnHVmD2oiVKe003oiRIdonIVM;oVIWB00;oVIWB
1?nKVM44oifJd0CoWi[?0_nQVlh2oj6JcPCoXi_=1OnVW<`2ojRMc003ojRMbonZW/[oZYk:00?oZYk:
0on/WlX00on]W/Wo[Z39ojjPb@03ojjPb@Co/:7900?o/:78ok6Rb?naX/P00_naX/P4ok>Sb003ok>S
aondY<So]:C800;o]:C80onfYLP3okNUa`05okRWaol0003o0000o`000?njZ<P01?nkZ<L3okbZa`;o
_Z_71?no[LL00oo1[LKo`[37ol:`a`03ol:`a`KoaK?81Oo7]/T5olVib`GobKg>0_o<_/h2ol[0d@03
o`000?o<`]7oc<;A00?oblCC0oo=a]@01?o@b=;od/_Com;;dooBbm<2omC=d`?o/lOY00?o[L?YojVm
j?nY_NP06OnY_NP00ooooooo0000ooooo`0Yooooo`00:?ooool00ol0003oooooooooo`09ooooodGo
ZKgX00?oSigLoi2Mg?n@WM`00_n@WM`4oi:Mf`?oU9gJ1?nEWMT4oiJLf0?oUicF0_nHVmD2oiNJe0Co
V9WC1?nIVM83oi^Id@GoWI[@0_nOV/l00onNVLooXI[>oj6JcP03oj6JcP?oXi_=1?nVW<`00onVVl_o
Z9g;ojRMb`02ojRMb`GoZYk:00Co[9o:ojfNbOn]W/Wo[Ik91?n^X<T3ok2Qb@;o/:781OnaX/P00onc
XlSo/j?7ok>Sa`02ok>Sa`Co]:C800?o]ZG8okNUaongYLL00ol00002okRWa`03okVWaonkZ<Oo^jS7
00Co^jS700?o_:[7okj[aonnZlL00_nnZlL2okn]a`?o`Jg60oo2/<L2olBaa`CoaK?80_o7]<L4olNf
b@04olZhbOo9^L_obKW;olVib`;obk_;0oo9_Lh3olbncP04ol[0dOo<`]7oc<;Ao`0000;oc<;A00Go
blCColg6e?o=a]CocLKDolo8e003om;;d`Coe<gC00Co/lOYojg3jOn]`nWo[L?Y6onY_NP00ooooooo
0000ooooo`0Xooooo`00:?ooool3o`0000[ooooo@OnY_NP00onY^nKoSigLohnMg002ohnMg0CoT9gL
0onBWM/4oiBMfPCoUIgI0_nFW=P01?nDVmOoUY[FoiJJe_nFV]H5oiNJe0?oV9WC1?nIVM84oi^Id@;o
WI[@0_nLVM04oijIc`CoXI[>1?nSVld00onVW<coYY_;ojJKb`02ojJKb`?oZ9g;1?nZW/X00on[WLWo
[Ik9ojfNb@02ojfNb@Go[Z3900?o/:79ok2Qb?n`XLP00_n`XLP3ok6Rb003ok:QaoncXlOo/j?700?o
/j?70ondY<P01?neY<Oo0000o`000?l00003okNUa`04okRWaoniYlOo^JO7okVWa`Co^jS700?o_:W6
okj[aonnZlL00onnZlL00ono[LOo`Jg6ol6]aP03ol6]aP04ol:`aoo4/LOoa;77olBaa`?oaK?80oo7
]<L3olNfb@?ob[S900?obKW;ol^kboo;^l/00_o;^l/00oo9_Lkoc;k>olbncP02olbncPCoc<;A00?o
0000olk4dOo=a]@00_o=a]@3olo8e003om;;dooDcM?oe<gC00;oe<gC00?oe]3Cojg3jOn]`nT00on]
`nTKojVmj003o`000?oooooooooo02Oooooo000Xooooo`03o`000?oooooooooo00_ooooo?onY_NP3
ojVkiP?oSigL1On@WM`3oi:Mf`;oU9gJ00?oTYcJoi>Kf?nCVmP00_nCVmP4oiBKe`?oUY[F1?nGV]@4
oiRId`CoVIWB0_nKVM400onJV=7oW9W@oibId003oibId0?oWYW?1OnQV/h2oj>Kc@03oj>Jc?nVVl_o
YY_;00?oYY_;1?nXWL/00onZW/[oZig9oj^Mb@02oj^Mb@Co[Ik90_n^X<T2ojnOa`Go/:780_naX/P3
ok:Qa`Go/j?70ol000000oneY<Oo]jG7okNUa`02okNUa`03okNUa_niYlOo^JO700;o^JO70onkZ<L3
okbYaPCo_Z_71_o1[LH5olBaa`03olFcb?o7]<OoakC700?oakC700?oakK9olZhbOo:^<T00_o:^<T5
ol^kb`04olfmboo<_/koc;k>olbncP;oc/7>0oo<`]401?l0003oc/CAolk4dOo=a]@4olo8e004om7;
e?oDcM?oe<gComC=d`?oe]3C0_n]`nTNojVmj003o`000?oooooooooo02Kooooo000Xooooo`03o`00
0?oooooooooo00gooooo?_nY_NP3ojVkiP?oSigL1?n@WM`3oi6Mf`CoTYcJ1?nCVmP3oiBKe`CoUY[F
1?nGV]@2oiRId`03oiNHdonHV=;oV9SB00;oV9SB1?nJV=44oibId0CoWYW?0_nQV/h2oj2Ic@CoXi[<
1OnVVl/2ojRMb`03ojRKbOn[WLWoZig900?oZig90on]W/T00on]WLOo[io7ojnOa`03ojnOa`Co/:78
00?o/J;8ok:QaonbXLL00_nbXLL2ok>Sa`?o00001?neY<L3okNUa`?o]jG61?niYlL00onkZ<Oo_:W6
okbYaP02okbYaP?o_Z_70_noZlH4ol6]aP;o`jk61?o4/LL5olNda`03olVfaoo:^<Wob[S900;ob[S9
0_o<^LP3ol^kb`?ocKg;00?oc;k>olk1c_o>`Lh00_o>`Lh01_o<`]7oc/CAolk4dOl0003oc/CAom36
d@?oclSD0ooAbm@00ooDcM?oe]3ComK@d`02omK@d`03omKCe_nY_NSoZKgX01goZKgX00?oooooo`00
0?ooool09_ooool002Sooooo0_l0000?oooooccoZKgX00CoYk_Woh^KgOn;VmgoRi_M1?n>WMd4oi2M
g0?oTIgK0onBW=X5oi>Kf0?oU9_G0_nFV]H00onDV=GoUISDoiFHe002oiFHe0CoUiSC1?nHV=83oiZH
d@GoW9W@0_nNVLl00onNV<koX9W=oj2Ic@03oj2Ic@?oXi[<1?nVVl/00onUV/WoZ9_9ojRKb@02ojRK
b@GoZig900Co[Ik9ojfMaon]WLOo[Ig71?n_WlL3ok2Qb003ok2Oa_nbXLOo/Z7700?o/Z770_l00000
1?ncXlOo]:;6okBRa_ndX/H4okFTa`03okNUaongYLKo]jG600;o]jG61?niYlL6okbYaP04okj[aono
ZlKo_j_6okn[aP?o`Jg60oo3[/H3olBaa`;oa[;60oo7]<L3olVfa`;ob[S91?o<^LP00oo;^l_ocKg;
olfmb`02olfmb`Goc/7>00God<?>olk4dOo>a=7oc/CAo`000002om36d@03olo8e?oAbmCodL_D00;o
dL_D00CodlkDomK@dooFd=?oe]3C0ooFdmHOojVmj0;o00009_ooool002Sooooo00?o0000oooooooo
ool03_ooooljojVmj0CoYk_W0on;Vmd4ohjMg@?oT9gL1?nAWM/3oi:LfP;oTi_H0_nAVMP3oi:IePCo
U9SE1?nEV=@3oiNHd`GoV9SB0onJV=42oibId0;oViO?1?nNV<h4oj2Ic@CoXi[<00?oYY_;ojFJbOnU
V/T00_nUV/T3ojRKb@CoZig900?oZi_7ojfMaon]WLL00_n]WLL5ojnOa`05ok2Qb?n`WlKo/9o6ok2O
a_nbXLL00ol000000onbXLOo/j?7okBRaP03okBRaP?o]JC700?o]Z?6okNUa_ngYLH00ongYLH3okVW
a`;o^ZO61?nlZLH00onmZLKo_j_6okn[aP03okn[aP03ol6]a_o3[/Ko`jk600?o`jk600?oa;77olJb
a_o6//H00_o6//H00oo7]<OobKK7olVfa`02olVfa`03olZhbOo<^LSoc;W800?oc;W81?o=_L/2olno
b`?oc/7>0oo@`lh01_o>a=7od<KAom36dOl0003od<KAom;9d@?odL_D0ooCc]@01OoFd=?oe]?FomKC
e_oFdmKod]OL01ooZKgX00?oooooo`000?ooool09Oooool002Oooooo00?o0000ooooooooool04?oo
ooljojVmj0CoYk_W0on;Vmd4ohjMg@?oT9gL0_nAWM/01?n?Vm_oT9[Ioi2JfOn@V]T5oi6If0?oTYWF
0onDV=D4oiFHe0CoUiSC0_nHV=82oiNGd@?oVIO@1OnKUll3oijHcPGoX9W=0_nSV/`00onSV<[oYI[9
ojFJb@03ojFJb@CoZ9_900?oZig9oj^Kaon[VlL00_n[VlL3ojfMa`Co[io700?o[ik6ok2Oa_n`WlH0
0ol00003ok:Qa`03ok:Pa_ndX/Ko]:;600Co]:;600Co]JC7okJSa_nfXlKo]Z?61OngYLH01?niYlOo
^ZO6okZWa_njYlH3okbYaP?o_JW61?noZlH5ol>^aP03olB`a_o6//Koa[;600?oa[;61Oo9]/L5olbi
b0;oc[_80_o=_L/4olnob`03olk1c_o@`lkod<?>00;od<?>0oo@a]401Ol0003od/WAom;9dOoBbM7o
dL_D00?odlkD00CoeM7EomKCe_oFdmKoe]?F0ooBem`OojVmj003ooooool0003ooooo02Cooooo000W
ooooo`?o00004OooooljojVmj0;oYk_W00CoRI_Ooh^Lg_n;W=koRicN1?n=W=d3ohjLg0CoSi_K0on@
V]T4oi6If0?oTYWF1?nDV=D4oiFHe0;oUiSC00?oUIKBoiNGdOnGUm400onGUm43oiVGd0CoViO?1?nN
V<h2oj2Ic@;oX9O;1?nSV<X4ojFJb@?oZ9_900?oZ9[7oj^Kaon[VlL00on[VlL4ojfMa`03ojnOaon_
W/Ko[ik600?o00000on`WlH00onbXLOo/Z36ok:PaP02ok:PaPCo]:;600?o]:75okJSa_nfXlH00_nf
XlH4okNUaP03okRUaOnjYlKo^ZO600?o^ZO600?o_:W6okfYa_nmZLH00_nmZLH3okn[aP;o`Jc60oo3
[/H3olB`aPCoa[;600Cob;?6olVfaoo9]/OobKK70_o;]lL3olbib0?oc[_800?ocKg;olnoboo?_l/0
0oo?_l/4om33cP;od/G>0_o@a]401?oBbM7o0000om;9dOoBbM43om?>e0?oeM7E00?oe]?Fom;Gg?oB
em`00_oBem`00oo:f^GoZKgXojVmj00MojVmj003o`000?oooooooooo02?ooooo000Wooooo`03o`00
0?oooooooooo01;ooooo>?nY_NP00onW_NWoRI_OohVKg`02ohVKg`?oRicN1?n=W=d3ohjLg0?oSi_K
1?n@V]T4oi6If0?oTYWF0_nDV=D00onBU]CoTiKCoi>Fd`02oi>Fd`CoUIKB1?nGUm43oiVGd0GoViO?
0_nNV<h00onMU/goX9O;oj2Gb`03oj2Gb`?oXiS:1OnUV/T01?nXVlWoZ9[7ojRJaonXV/L4oj^Ka`?o
[Ig700Co[Ic5o`000?l0003o00000_n_W/H3ok2OaP03ok6NaOnbX<Ko/Z3600?o/Z360ondX/H2okBQ
a@Go]Z?600?o]jG6okRUaOnhYLD00_nhYLD4okZWaPKo_JW600?o_j_6ol6/a_o1[<H00_o1[<H00oo3
[/Koa;36olB`aP02olB`aP?oa[;60oo8/lH00oo9]/OobkO7ol^ga`02ol^ga`03olbib?o>^lSoc[_8
00;oc[_81Oo?_l/2om71b`;od<?>0ooBaLh01Oo@a]7od/WAom;9dOoBbM7o000000;oe<cB00?odlkD
omGAeOoEdMD00_oEdMD01?oHe=God]OLom;Gg?oBem`3ol[JiAkoZKgX00?oooooo`000?ooool08ooo
ool002Oooooo00?o0000ooooooooool04ooooolfojVmj0?oYkgY0on9Vml4oh^LgPCoSIcM0on>W=`3
ohnKf`;oT9[I00?oSYSHohnGeon?UmL00_n?UmL3oi6GePCoTYKD1?nCU]<3oiFFdPCoUiOA1?nIUm02
oi^Gc`;oVYK>1?nMU/d4oj2Gb`CoXiS:0_nUV/T2ojFHb0CoZ9[71On[VlL3o`000003ojfLaOn_W/Ko
[ik600?o[ik600Co/9o6ok6NaOnaW/Go/Ik51OnbX<H00ondX/Ko]:75okBQa@02okBQa@?o]Z?600?o
]j?5okRUaOnhYLD00onhYLD3okZWaP;o^jO51?nmZLH00onnZ/Go`Jc6ol6/aP03ol6/aPKoa;3600?o
a[;6olRca_o8/lH00_o8/lH5ol^ga`Goc[_800Cod;g8olnoboo?_l_ocko;0ooA`L/00oo@`lkod/G>
om;5cP02om;5cP05omC8c_oBbM7od/WAom;9dOl000000_oDc=801?oFcm;oeM7EomGAeOoEdMD3omSD
e@05om;Gg?o:f^Gob][Uol[JiOnjeNd07onY_NP00ooooooo0000ooooo`0Rooooo`001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool05OooooleojVmj0?oYkgY0on9Vml2oh^LgP03ohZLgon;
VmgoRi_M00;oRi_M0on<V]`3ohfIfPCoSYSH1?n?UmL3oi6GeP?oTYKD1?nCU]<4oiFFdPCoUiOA0_nI
Um000onHULooVYK>oiZFcP03oiZFcP?oWIK=1OnPUl/2oj>HbP03oj:Fb?nUV<SoYIS800?oYIS81?nX
V/L01?n[VlOo0000o`000?l00004ojfLa@Co[ik600?o[ic4ok6NaOnaW/D00_naW/D4ok:PaP03ok>O
a?ndXLGo]:7500?o]:750_nfXlH3okNSa@Go^:G500Co^ZO6ok^WaOnkYlGo^jO50onmZLH3okjZa@Co
`Jc600?o`Zg5olB`a_o4/<H00_o4/<H00oo6/LGob;?6olRcaP02olRcaP;ob[G61?o;]lL01?o=^LOo
c[_8oljkb?o>^lP3om2mb003olnobooA`L_odL7;00;odL7;00Coe<C;om;5c_oBaLkod/G>0ooDb<h0
1OoBbM7oe<cBomC<d_l0003oe<cB00;oe/oB00CoeM7EomSDeOoHe=Gof=CE0_oJf=D00oo:f^Go^]G]
ok[Ek@02ok[EkAooZKgX00?o0000ooooooooool08Oooool000Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_oo
ool01?ooool2o`0001Oooooo=?nY_NP3ohNMh@?oR9cP1?n:W=l4oh^Kg@?oS9[L0on=VMX3ohjHf0Co
SiOG1?nAUmH3oi:Fe0CoTiKC0_nEU]800onDU=7oUYG@oiJEd002oiJEd0CoV9G?1?nJU/h4oifFc@;o
X9O;0_nOULT4oj:Fb0CoYIS80_nXV/L3o`0000CoZi[51?n]W<D00on_W/Ko[ic4ojnLa002ojnLa0Co
/Ik500?o/Z36ok>Oa?ncWl@00_ncWl@4okBQa@03okJSa_ngXlGo]j?500;o]j?51?nhYLD00oniYLGo
^jO5ok^Wa@03ok^Wa@03okfYa_nnZ/Go_Z[500;o_Z[50oo1[<H2ol:]a@?oa;360oo6/LD2olRcaP?o
b[G60oo;]lL3olfia`03oljkb?o@_LSod;g800;od;g81OoA`L/2omC4b`03om;5c_oDb<koe<S>00;o
e<S>00Goe/_>omC<d_oDc=;oe<cBo`000002omK?dP?of=CE0ooJf=D00ooMgMKo^]G]ok[Ek@02ok[E
kB3oZKgX00?o0000ooooooooool08?ooool000Cooooo00Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00_ooool2o`0001Wooooo=?nY_NP3ohNM
h@?oR9cP0on:W=l5oh^Kg@?oS9[L0on=VMX3ohjHf0CoSiOG0_nAUmH01?n?UMGoTICCoi6DdonAU=<4
oi:DdPCoU9CA1?nFUM03oiREc`GoVYK>0_nMU/d00onLU<_oWiG9oinEb@03oinEb@?oXYK80onUV<P3
o`0000?oZ9S51?n[V/D3ojfLa@03ojjJ`on_W<Co[ic400?o[ic40onaW/D00onbWL?o/io4ok>Oa003
ok>Oa0?o]:7500?o]J74okNSaOngXlD01?ngXlD01?nhYLGo^JG5okVUaOniYLD4ok^Wa@03okbXaOnn
Z/Go_Z[500Co_Z[500?o`Jc6ol:]aOo2[LD00_o2[LD00oo4/<Koa[75olJaa@02olJaa@03olRca_o:
]LKob[G600?ob[G600?obkO7olfiaoo=^LL00_o=^LL5om2mb004om:ob?oA`L_odL7;om71b`?oe<C;
1OoDb<h2omK;cP04omC<d_oFcm;oe/oBo`0000;ofM;B00?of=CEom[HeOoJf=D00_oJf=D2omgMeP;o
^]G]8OnY_NP00ol0003oooooooooo`0Pooooo`001?ooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01Wo
oooo=?nY_NP3ohNMh@?oR9cP0on:W=l2oh^Kg@;oR9WM0on9Um/3ohZFf@?oS9KH1?n=UMH4ohnEe@?o
TICC1?nBU=83oiBDd@CoUYG@1?nHULl2oiZFcP;oVI?<1?nLU</4oinEb@?oXYK800GoYIS8o`000?l0
003oYIS8ojFFa@04ojRHa@GoZi[500Co[Ic5ojjJ`on^V/?o[Y[31On_W<@01?naW/Go/Yg3ok:M`onb
WL<5ok>Oa004okBQaOneXLCo]J74okFQa0Co]j?500?o^:?4okVUaOniYLD00oniYLD2ok^Wa@?o_:S5
1?nnZ/D00oo0ZlGo`Zg5ol:]a@02ol:]a@03olB_aOo6/LGoa[7500?oa[751Oo:]LH00oo<]lKocKW7
olfia`02olfia`;od;_60oo@_LP3om:ob003om71booDa<_oe<C;00;oe<C;00Coe/K;omC8c_oDb<ko
e<S>0ooFblh3omK?dP04o`000?oId];ofM;Bom_Fd`?of]SE0_oMgMH00ooMh]WoZKgXojVmj00RojVm
j003o`000?oooooooooo01oooooo0004ooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0J
oooooc3oZKgX0on=Y^H3ohJLhP?oQicQ0on7V]l5ohRIg@?oRIOK0on:U]T3ohbFf0CoSIGF0on?UMD3
oi6Dd`CoTYCB1?nDU=44oiJEd0;oV9G?00?oUi?>oiVCc?nITl`00onITl`3oibDb`CoWiG900GoXYK8
o`000?l0003o0000ojFHb004ojFFa@?oZ9S51?n[V/D00on[V<;o[Y[3ojjJ``02ojjJ``Co[ic400?o
/9_2ok:M`onbWL<00_nbWL<4ok>Oa003okBO`oneXLCo]J7400;o]J740ongXlD3okRSa0Co^JG500?o
^jO5okbXaOnlZ<D00_nlZ<D3okjZa@?o`:_50_o2[LD3olB_a@?oa[750_o8/lD3olZeaP?oc;O60_o=
^LL4om2kaP04om2mb?oB_lSod[o8om:ob0;oe<;80ooDa</3omK6b`04omC8c_oFblkoe/_>omK;cP;o
f<g?00Goe/oBomWBd_oId];o0000omWBdP02om_Fd`03om[HeOoMgMKogMgF00?ogN;I8onY_NP2o`00
023ooooo0004ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Kooooo0_l0000Loooooc3oZKgX0on=Y^H3ohJLhP?oQicQ0on7V]l4ohRI
g@?oRIOK0on:U]T3ohbFf0GoSIGF0on?UMD3oi6Dd`CoTYCB0_nDU=400onBTm3oU9??oiBCc`02oiBC
c`CoUi?>1?nITl`3oibDb`;oWiG90ol00002oj:Fb003oj6Ca_nUU/GoYIK500?oYIK51?nXV<D00on[
V/GoZiS2oj^H`P02oj^H`P?o[Y[30on_W<@3ok2K`P?o/Yg30oncWl@3okBO``Co]J7400?o]j?5okRS
a?nhXl@00_nhXl@3okVUa@03okZUa?nlZ<Go_:S500Co_:S500?o_Z[5ol2[aOo0ZlD00_o0ZlD00oo2
[LGoa:o5olB_a@03olB_a@03olJaaOo8/lGob;?500;ob;?500?ob[G6olbga_o<]lH00_o<]lH00oo=
^LOod;_6om2kaP03om2kaP?od[o81?oD`/P01OoDa<_oe/K;omK6booFa/_of<W;00?oe/_>0ooHcLl0
1OoKdLoofM;BomWBd_oId];o000000;ofmKC00?og]_ComgMe_oMh]T00ooMh]T00oo?jNSoZKgXojVm
j00QojVmj003o`000?oooooooooo01kooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0MooooobooZKgX0on=Y^H3ohJLhP?oQicQ0on7V]l4ohRIg@?oRIOK0on:U]T3ohbFf0;oSIGF
0_n<TmD3ohfCe0?oSi?C1?nATm84oi:Cd0CoU9??0onGTlh4oiVCc0;oW9C;0ol000000onOULWoWY;7
oijBa`04oj6CaPCoYIK50onXV<D00onXUL;oZiS2oj^H`P03oj^H`PCo[Y[300?o[ic4ok2K`_n`Vl80
0_n`Vl84ok:M``03ok>Oa?ndWl?o]9o300;o]9o30oneXL@00onfXL;o^:?4okRSa004okRSa004okVU
aOnjYLCo^ZG4okZUa0Co_:S500?o_ZS4ol2[aOo0ZlD00oo0ZlD6olB_a@Gob;?51Oo<]lH5om2kaP;o
d[g600?od[o8omC2b?oD`/P00ooD`/P3omK6b`?of<W;00?oe/_>omS=cooHcLl00_oHcLl2om_Ac`04
omWBd_oKe]?ofmKCo`0000;og]_C00Coh=oDomgRfOoMh]WogN;I0oo?jNPRojVmj003ooooool0003o
oooo01kooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l00005ooooo`03o`000?oooooooooo01kooooo;OnY_NP01?nG]NgoPYcSoh:L
hon2W><3ohBLhP?oQ9[Q1?n4V=l3ohBFg@?oQYGK0on7U=T3ohVCe`GoS9?E0on=Tm@3ohnCd`CoTI?B
0onBTm04oiBCc`CoUi?>0_nITl`3o`000003oibDbonJTLWoWY;700CoWY;70onQTlH5ojFFa@04ojRH
aOnXUL;oZ9G2ojRE`PCoZiS20on^V/<00on^V<7o/9_2ok2K`P03ok2K`P?o/Yg300?o/ic1okBO`ond
Wl<01?ndWl<01?neXLCo]Z72okJQ`_nfXL84okRSa003okVS`onjYLCo^ZG400;o^ZG40onlZ<D3okjX
a0?o`:_50_o2[<@4olB_a@;oa[351?o8/lD00oo:]<Goc;O6olbgaP02olbgaP04oljia_o@^lKod;_6
om2kaP?od[g61OoD`/P2omO4b003omK6booHbL_of<W;00;of<W;00Cof/c;omS=cooHcLoof<g?0ooK
dLl3om_Fd`03o`000?oNfm?og]_C00;oh=oD00GogN;IoloYj?o?jNSocnWXok78j`0SojVmj003oooo
ool0003ooooo01gooooo000Vooooo`;o00007oooool/ojVmj0?oUkG]0on2W><3ohBLhP?oQ9[Q1?n4
V=l3ohBFg@?oQYGK0on7U=T3ohVCe`CoS9?E0on=Tm@3ohnCd`CoTI?B1?nBTm04oiBCc`;oUi?>0ol0
0002oiNAb`CoVY791?nNT/L4oj6CaP;oYIK50_nUTl<4ojRE`PGoZiS200Co[Y[3ojjH`On^V<7o[YS1
1On`Vl801?nbWL?o/ic1ok>L`OncW<44okBO``03okFN`OnfXL;o]Z7200;o]Z720onhXl@3okVS``Co
^ZG400?o_:S5okjXa?nnZ<@00onnZ<@01?o0ZlGo`Zc4ol:/a?o2[<@3olB_a@?oa[350oo8/lD2olZd
a@?oc;O60oo>^LH00oo@^lKod[g6om:maP02om:maP04omC0a_oD`/Soe<;8omC2b0?oelC81OoHbL/2
om[<b`03omS=cooKdLoofm7?00;ofm7?00GogMC?om_FdooNfm?og]_Co`000002on3Oe0;ohnGD00?o
cnWXok78jonab>/00_nab>/SojVmj003o`000?oooooooooo01cooooo000Uooooo`;o00008Oooool/
ojVmj0?oUkG]0on2W><3ohBLhP?oQ9[Q1?n4V=l3ohBFg@?oQYGK0on7U=T3ohVCe`CoS9?E0on=Tm@3
ohnCd`CoTI?B0_nBTm001?nATM3oTi7>oi>Ac_nCTLh3o`0000;oUI3=1?nGTL/3oiZAb@GoWY;70_nQ
TlH00onQTL?oYI?3ojFC``03ojFC``?oZ9G21?n[V<800on/U/3o[YS1ojjH`@02ojjH`@Co/9_200?o
/IZook>L`OncW<400_ncW<43okBO``?o]Ik11?nfXL800onhXlCo^J?3okVS``02okVS``?o^ZG400?o
_:K3okjXa?nnZ<@01?nnZ<@5ol:/a003olB_aOo6/<Goa[3500?oa[3500?ob;?5olZdaOo:]<D00_o:
]<D00oo<]lKoc[W6oljiaP02oljiaPCod[g60ooD`<H00ooD`/SoelC8omO4b002omO4b004omW7b?oH
bL_of<W;omS9b`?of/c;00Cog<o<om_AcooKdLoofm7?0_oMe<l2omoId003omkKdooPgmCo000000?o
hnGD0_oUk=<2ok78jbCoZKgX00?oooooo`000?ooool07?ooool002Gooooo00?o0000ooooooooool0
8OoooolZojVmj004ojNmjOmnVnCoOY_TogjKi0?oPIcT0on1V^<3oh2Hh@CoP9GN0on1Tm`3oh:BfP?o
QI7H0on7TMH4ohVAe@?oS97C0on>TM84ohnAd@?oTI7@0ol00002oi>AcP?oUI3=1?nGTL/4oiZAb@;o
WY;70_nLSlD4oj6A``CoYI?31?nXUL800on[V<;o[9K0ojbF`002ojbF`0Co[YS100?o/9_2ok6J_ona
V[l00_naV[l4ok>L`@03okBO`oneW/7o]Ik100;o]Ik11?nfXL86okVS``04okZUa?nlY/?o_:K3okbV
``Co_ZS40_noZL@4ol:/a0Goa[3500?ob;;4olZdaOo:]<D00_o:]<D00oo<]lGoc[W6oljiaP03olji
aP03om2kaOoB_LKod[g600Coe<361?oGa<P3omW7b003omS9booJc<_of/c;00;of/c;0_oLcl`00ooK
dLoogMC?omgDc`03omoId005on;Md?oPgmCohnGDo`000?oSiM@00_oUk=<00ooDmnCoZKgXojVmj00U
ojVmj003ooooool0003ooooo01_ooooo000Uooooo`03o`000?oooooooooo02;ooooo:?nY_NP3ojNm
j@?oOY_T0on1W>@3oh6Jh`?oP9SQ1?n0UMh3oh6Cg0?oPY;J0on5TMP3ohNAePCoRI7E0on<TM<3ohjA
dP?oSi7A0ol000000onATM3oTi7>oi>AcP02oi>AcP?oUI3=1OnGTL/2oiZAb@03oiV>aonLSlGoW8o5
00;oW8o51?nQTL<4ojFC``?oZ9G200?oZ9>oojbF`?n/U/000on/U/04ojjH`@Go/IZo1?ncW<45okFN
`@?o]Z720_nhXL44okVS``03ok^S`_nlY/?o_:K300;o_:K30onnZ<@3oknYa0?o`Zc40_o3[L@3olJ`
a@?ob;;40_o:]<D3olbga@?oc[W60oo@^lD00ooB_LKoe<36omC0aP02omC0aP03omK2a_oGa<SoelC8
00CofLO800Cofl[8om[<booJc<_of/c;0ooLcl`00ooOd/cogMC?omoId003omoId004on;Md?oUhm3o
iN?@o`0000;oiNcC0ooDmn@WojVmj003o`000?oooooooooo01[ooooo000Uooooo`;o00009?oooolX
ojVmj0?oYkgY0omnVn@3oh6Li0?oPI[S0on0V>44oh2EgP;oPI?L0on2T]X3ohFAf0?oQi7F1?n9TMD3
ohbAd`?oSY7B00CoSi7Ao`000?l0003oSi7A1?nATM04oi>AcP?oUI3=0_nGTL/2oiF=b@CoVHk71?nL
SlD3oj6A``GoYI?300CoZ9G2ojRC_onXTkooZ9>o1?n/U/03ojjH`@;o[iNn1?naV[l3ok>L`@;o]9bo
1OneW/401?nfXL;o^:71okRQ`OnhXL43okVS``?o^j?21?nlY/<00onnZ<Co_jW4oknYa003oknYa003
ol:/a?o3[LCo`jg400;o`jg400?oa[35olRba?o8//@00_o8//@00oo:]<Goc;O5olbga@03olbga@03
oljia_o@^lGod;_500;od;_500Codkg5omC0a_oD`<Koe<360ooF`/H01?oGa<SofLO8omW7b?oIalP3
om_:b004om[<booLclcog<o<omc?c0;ogm;<00CohMK<omoId?oOfM3ogmW@0_oRgM02onGSd003onOY
d?l0003oe?OT00?oe?OT:?nY_NP00ol0003oooooooooo`0Iooooo`009Oooool00ol0003ooooooooo
o`0UooooobOoZKgX0on;[nh2ogfKi@?oOY_T0omlV><3og^Eh@CoNi;N0omlT=`3oh:BfP?oQI7H0on7
TMH4ohVAe@?oS97C0ol00004ohnAd@;oTI7@00?oShk?oi2>cOn@S/d00_n@S/d3oi:=b`CoUHg91?nI
S/L4oib?a@CoXI730_nUTl<2ojB@_`CoZ9>o1On/U/001?n^V<7o[iNnojnG__n_Ukh5ok6J_`04ok>L
`OndW;oo]9bookBL_`Co]Ik100?o]ijookRQ`OnhXL400onhXL400oniXl?o^j?2ok^S`P02ok^S`PCo
_:K31OnoZL@00oo1Zl?o`jg4ol>]a003ol>]a0Gob;;41_o<]lD4om2ka@?odkg500?oe<36omK2a_oF
`/H00_oF`/H3omW7b0Cofl[80ooLcl`3omoBc0;ohMK<00?ogmW@on;Md?oRgM000ooUhm000ooWjM3o
jO3?o`000002omCgi0;o[lCZ9onY_NP00ooooooo0000ooooo`0Iooooo`009Oooool00ol0003ooooo
ooooo`0VooooobOoZKgX0on;[nh2ogfKi@?oOY_T0omlV><3og^Eh@CoNi;N0_mlT=`3ogn?fP?oPXoH
0on5SmH4ohR?e0?o00000on<Sm44ohf?d0CoShk?1?n@S/d3oi:=b`CoUHg90onIS/L4oib?a@;oXI73
0_nOSL44ojB@_`CoZ9>o1?n/U/000on]U;go[iNnojnG_P02ojnG_PCo/IZo00?o/iVmokBL_ondW;l0
0_ndW;l3okFN`@?o]ijo1?nhXL45ok^S`P?o_:K30_nnYl83oknYa0?o`J_31?o3[L@00oo6[lCob;;4
olRba002olRba003olZda?o<]lGoc;O500;oc;O50_o?^LD2om2ka@Codkg51?oF`/H2omS5aP03omW7
b?oKb/Sofl[800;ofl[80_oMcLT01?oLclcogm;<omoBc?oOd/`3on7Fc003onCKc?oRgM3oiN?@00;o
iN?@0_oWjM000ooYl<oo0000ojo4jP04ojo4jROoZKgX0_l0000Iooooo`009?ooool01?l0003ooooo
o`000?l0000WooooobGoZKgX00CoY;cZogNIi_mgVNKoMiWV0omkVnH3ogjKi0?oO9SS0omkUN43og^B
gP?oO93L0omoSmX3oh:?f0?oQHoF0ol000001?n8SmCoRXoCohZ?don:Sm<3ohb?d@CoSHo@0on?S/l4
oi2>c@?oTXg;1?nESLT4oiV>a`;oW8o500?oVh_2oin=`OnOSL400onOSL44ojB@_`CoZ9>o00?o[9K0
ojfD_On]U;d00_n]U;d4ojnG_P03ok6J_oncVKgo/iVm00;o/iVm1?ndW;l00oneW/7o]ijookNN_`02
okNN_`?o^:710_niXKl5ok^S`P03okbV`onnYl;o_ZO200;o_ZO200?o_jW4ol6[`oo1Zl<00_o1Zl<3
ol>]a0;oaZo40oo8//@2olZda0?oc;O50oo?^LD00oo@^lGodkg5om>ma@02om>ma@;oeL350_oF`/H3
omS5aP04om_8a_oKb/Sofl[8om_:b0?ogLg900?oh=39omoBc?oOd/`00ooQe/`2onCKc003onOPcOoU
hm3oiN?@00;oinW@0ooYl<l00ol0003o[lCZojo4jP0YojVmj003ooooool0003ooooo01Sooooo000T
ooooo`;o0000:_oooolSojVmj0?oY;cZ0omgVNH3og^KiP;oNYWU0omgUN<3ogFBh@?oMXoN00CoNi;N
ogb@g?mlT=coO93L0omoSmX2oh:?f0?o00001?n8Sm@3ohZ?d`?oS8oA1?n=Sm03ohn>c`GoT8k=0onB
SL/3oiF=b@;oVHk70_nFR/@4oi^;`PCoWhg11?nTT;l3ojRC_`03ojV@_?n]U;go[IBm00?o[IBm1?n_
Ukh5ok>I_@?o]9bo00?o]Y^mokNN_ongW[l01?ngW[l01?nhXL7o^J6ookVQ_oniXKl4ok^S`P03okbT
`?nnYl;o_ZO200?o_ZO21_o1Zl<00oo3[LCoaZo4olJ_a002olJ_a003olRba?o:]<Cob[C400;ob[C4
00?oc;O5olniaOo?^LD00_o?^LD01?oA^lCodkg5om>maOoC_LD3omG0a@03omK2a_oHaLKof<G600;o
f<G60_oKb<H00ooKb/SogLg9omg=b@02omg=b@;oh=3900?ogm;<on7Fc?oQe/`00ooTfl`2onOPc@03
onGSd?oWjM3ojO3?00;ojO3?00?ojOS;olgcj_l00000:onY_NP00ooooooo0000ooooo`0Gooooo`00
9?ooool00ol0003oooooooooo`0Zooooob?oZKgX0onT_>X3ogNIiP?oNi_V0_mjVND3ogNEh`?oMI;Q
0omfSmh3ogR>g0;oNhgI0ol000001?moSMOoQHoFohF?e_n5SmH4ohR?e0?oRXoC0on<Sm44ohf?d0?o
Shk?0_n@S/d2ohf;c0?oSh[90onBRLL5oiJ:a0?oVh_21?nOSL44ojB@_`03ojRC_onYT;coZI2l00;o
ZI2l1?n]U;d3ojnG_P;o/IJk1OncVKd01?ndW;oo]Y^mokJK_OnfVkd4okNN_`03okVN_OniXKoo^J6o
00;o^J6o0onkXl83okbT`0Co_ZO200?o`:S1ol6[`oo1Zl<00_o1Zl<00oo4[<;oaZo4olJ_a003olJ_
a0Gob[C41Oo?^LD2om6ka003om>maOoE`<GoeL3500;oeL3500Coel;5omS5a_oHaLKof<G60ooKb<H0
1?oMblKogLg9omg=bOoMcLT3on3@b@03on;DbOoQe/coi=_<00;oi=_<0ooWh<d01OoYi/cok>g;onc]
booYl<oojOS;00?ocO?Z00?o0000ojVmj?nY_NP0:OnY_NP00ol0003oooooooooo`08ooooo`Co0000
00?o410@ooooooooool01oooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0:ooooolSojVmj0;o
RK;a0omgV^L3ogRJi`?oM9OU0omgUN<2ogFBh@CoMXoN00CoN8kLo`000?l0003o00000_mkSMT2ogn=
e`?oPhkF1?n6S]@3ohR>dP?oRXgA1?n;SLl3ohb<cPGoSH_<0on?R/T3oi:9a`CoUX[40onKRl85oin=
`@;oY92o00?oY8flojV@_?nYT;`00onYT;`5ojfD_@04ojnG__naU[_o/IJkok6F^`Co/iVm00?o]9Rk
okJK_OnfVkd00_nfVkd3okNN_`?o^Ijm1?niXKl00onkXl;o_:C0okbT`002okbT`0?o_ZO20_o0Z<43
ol6[``;oa:c21?o6[l@2olR```?ob[C40_o<]/@3olnia@?odK_41OoE`<D2omO2a@03omS5a_oKb<Ko
flS600;oflS60_oMblH01?oMcLWoh=39on3@bOoPd<T2on;Db@03onGHbOoTflcoi=_<00?oin3=0_oY
i/`2onc]b`06onceb?oYnkoocO?Zolgcj_nY_NSo0000;?nY_NP00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01?ooool2o`0002gooooo8onY_NP2ohVbl@?oMi[W0omhV^L2ogBGi@?o
LI;S0om_S^401?mfSmko0000o`000?l00002ogR>g0?oNhgI0omoSML3oh>>ePCoQXkD0on8S]83ohZ=
d@CoRhg?0on<S<h4ohf;c0?oSh[90onBRLL4oiJ:a0CoVh_20onOSL400onOR[goY8flojB=_002ojB=
_0CoZI2l1?n]U;d00on^T[[o/IJkok6F^`02ok6F^`?o/iVm0ondV;/4okJK_@03okNN_oniW[go^Ijm
00;o^Ijm1?niXKl6okbT`003okjW`_o0Z<7o`:S100;o`:S100?o`J_3olB/`_o4[<800_o4[<82olJ_
a0Cob;3300?ob[C4olbfa?o<]/@00_o<]/@00oo?^LGodK_4om6ka002om6ka004om>ma?oE`<GoeL35
omG0a@?oel;51?oKb<H3omg;aP?oh=390ooRe<T2onGHb@03onCKc?oWh<goin3=00;ojNK<0oo/kL/0
0oo/mLSojO^ool_l^P03ojVmj003o`000?nY_NSoZKgX02WoZKgX00?oooooo`000?ooool02Oooool0
0ol0003oooooooooo`09ooooo`002Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0]ooooob;oZKgX0om`Vn/3ogNJi`?oN9[W0_mdUnD3
og6Bh`03ofn>hOl0003o000000?oL8cN0omcRm`3og^=f@?oOhgG0_n3S]H4ohJ>e0?oR8kB0on:SM44
oh^=c`?oS8c>1?n=Rl`3ohn:b@?oTXW71OnFR/@3oi^;`P03oin=`OnOR[goWhZm00;oWhZm0onTSK`5
ojV@_004ojfD_On^T[[o[Y:jojjB^PGo/IJk00?o/iVmokBH^ondV;/00_ndV;/4okJK_@Go^Ijm0oni
XKl2ok^Q_PCo_:C000?o_ZFool2X`Oo0Z<400oo0Z<45olB/`P03olJ_a?o8/<?ob;3300?ob;331Oo<
]/@4om6ka0?odkg400?oeL35omO2aOoG`/D00_oG`/D00ooJaLGoflS6om_8aP04omg;aP03on3>a_oP
d<Woh]C900;oh]C90ooUf<T01?oXgLWoin3=onWVc?oYi/`3onc]b`03onceb?oYnkoojO^o00;obobj
0onY_NP00ol0003oZKgXojVmj00YojVmj003o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2Oooool000Wooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0;_oooolRojVmj0?oL9_[0_meVnP3og>Ij0?oKYCV0ol00002ofn>h@CoL8cN
0_mcRm`3ogN;f@?oO8_G0on0S=H4ohJ>e0?oR8kB0on:SM44oh^=c`?oS8c>1?n=Rl`3ohn:b@?oTXW7
0_nFR/@2oi>6`P?oVHNo1OnOR[d3ojB=_0CoZI2l00?oZHjiojjB^_n^T[X00on^T[X3ok6F^`03ok:E
^OndV;_o]9Rk00?o]9Rk0onfVkd2okRK^`Go^Ijm00Co^J6ook^Q__nkXKko^j6n0onlY<02okjU_`Co
`:S10_o2ZL04olB/`PGob;3300?ob[;2olbfa?o<]/@00_o<]/@2olnh``;odK_41?oC_L@4omO2a@?o
f/G500CoflS6omg;a_oMblKogL_60_oPc/H00ooRdLKoh]C9on;Db@04onGHb@04onSMbOo[hlSojn?8
onWVc0;ok>g;00Cok?G8onWk_ooYnkoobobj1_nY_NP00ol0003oZKgXojVmj00XojVmj003ooooool0
003ooooo00Sooooo00?o0000ooooooooool02Oooool000Wooooo00Go0000ooooooooooooooooo`00
000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0`ooooob;oZKgX
0om`Vn/2ogFKj0;oLiWX0ol00003ofZ?h`?oJ8_Q0om`S=h3og>;g0?oMh_I0omlRmL2oh2<ePCoPhcD
0on5S=83ohN;d0CoR8[?0on9R<d4ohZ7bP?oS8K70on?QLD5oi>6`P?oVHNo1?nOR[d4ojB=_003ojV@
_?nYS[WoZHji00;oZHji1?n^T[X2ok6F^`?o/YFi1OndV;/01?nfVkgo^9^kokRK^onhVk/4okVN_@03
ok^N_?nkXKko^j6n00?o^j6n00?o_:C0okjU_onnYKl00_nnYKl2ol2X`@?o`ZW00oo4[<82olJ]`@?o
b;330oo://82olbfa0CockS300CodK_4om>ma?oC_LCodkg40_oF_l@2omO2a@Cof/G50ooMblH3on3>
aP;oh]7600Coh]C9onGHbOoUf<WoiMS90_oXgLT2on_Sb006onkZaoo/kL_ok?G8onceb?oYnkoo_>R8
1onY_NP00ol0003oZKgXojVmj00YojVmj003ooooool0003ooooo00Oooooo00?o0000ooooooooool0
2Oooool000Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo
0ol0000boooooakoZKgX0onJ^Nd2of^Gj@04og:JjOl0003o0000o`0000;oLiWX0_m^U>H3ofZ?h`;o
J8_Q0omZRMh01?m`S=koLh_Log>;g?mcRm`2ogN;f@?oO8_G0on0S=H4oh><e0?oQHcB0on7Rm04ohR:
c`?oRHS=0on:QlX4ohb6a`?oShG51?nCQ/83oiV7_`GoWhZm0_nTSK`00onTR[WoZHjiojV>^@03ojV>
^@Co[Y:j00?o/IJkok:E^OnbUKT00_nbUKT4okBH^`03okNH^?nhVk_o^9^k00;o^9^k0oniW[d2ok^N
_0Co^j6n00?o_Z:mokjU_onnYKl00onnYKl00oo0Z<7o`ZW0ol:Y`003ol:Y`003olB/`_o6[L7oaZg1
00;oaZg100?ob;33olZb`_o://800_o://800oo<]/CockS3olnh``03olnh``?odkg41?oF_l@01?oG
`/Gof/G5om[5aOoJaLD2omc8a@04omg;a_oPc/Koh<k6on3>aP?oh]760_oUeLH00ooUf<Woj=g9onSM
b@03on_Sb005onkZaoo_lLCoko74ongh_OoRnJ`00_nlj8P7ojVmj003o`000?nY_NSoZKgX02WoZKgX
0_l00007ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03?ooooo7_nY_NP2oiZik@?o0000
0ombV^T2ofjGj0?oIi7V0omZSn<2ofR;h@?oJXWN0om^R=`3og>9fP?oO8_G0_n0S=H4oh><e0?oQHcB
0on7Rm04ohR:c`?oRHS=1?n:QlX3ohb6a`?oShG51?nCQ/83oiV7_`GoWhZm00CoY8flojB:^OnTR[Wo
Y8Zi1?nYS[T4ojjB^PGo/YFi0ondV;/2okNH^0Go^9^k00?o^Ijmok^N_?nkW[`00_nkW[`2ok^Q_P?o
_Z:m1?nnYKl6ol:Y`0GoaZg11Oo://85olnh``;odK[300?odkg4omJoa?oF_l@00ooF_l@3om[5a@?o
g<S500?ogl_4on3>a_oPc/H01?oRdLH2onGEaP;oj=g90oo[hlP2onkZa`;oko7400CokORmokcXR?nb
bN_o//W[2?nY_NP00ol0003oZKgXojVmj00YojVmj003o`000?oooooooooo00?ooooo00?oEEEEofIV
I_l000002oooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0
003oooooooooo`0doooooacoZKgX0ol000001?n2/?;oJIS[ofVHjomYV>/3og:Jj@;oKYOX0omWTNH2
of:;i0?oHHOQ0omZRMh3ofj8g0;oLhWJ0omhRMP3ogf:ePCoPhcD0on5S=83ohN;d0CoR8[?0_n9R<d4
ohZ7bP?oS8K70on?QLD5oi>6`P?oVHNo0_nOR[d2oif6^PCoY8Zi1OnYS[T2ojjB^P;o[i6g1OnbUKT0
0ondV;_o]iRhokNH^002okNH^0?o^9^k00?o^Y^iok^N_?nkW[`00onkW[`00onkXKko_Z:mokjR_@02
okjR_@?o_ZFo0_o1Y[h4ol:Y`0;oa:Zo1?o6[L400oo8[l7ob[;2olZb`P02olZb`P04olfd`_o?^<?o
ckS3olnh``?odK[31OoF_l@2omS2``03om[5aOoLb<Gog<S500;og<S50_oObl@01?oPc/Koh]76on;A
a_oRdLH3onGEaP04onSJa_oXgLWojn?8on_Sb0;ok^[70_o_lL@00oo]n;go0000ok;9j`03ok;9j`Oo
ZKgX00?o0000ojVmj?nY_NP0:OnY_NP00ol0003oooooooooo`0Aooooo`008oooool00ol0003ooooo
ooooo`0eoooooaSoZKgX0ol00003ojVmj0;oP[3b0omYV>/2offJj`?oIiCY0omWTNH2of:;i0;oHHOQ
0omSQMh3ofj8g0?oLhWJ0omhRMP2ogf:ePCoP8[D0on2R]83ohB9d0CoQ8O>0on4QL`3ohZ7bPCoS8K7
0on?QLD4oi>6`P;oVHNo00?oUh>loif6^_nMQ[X00onMQ[X3ojB:^@GoZHji00Co[Y:jojnA]on_TKOo
[i6g1OnbUKT5okNH^0;o^9^k0onjVkT4ok^N_0Ko_Z:m00Co_ZFool6V__o1Y[ko`JJn0oo2ZL03olBZ
_`?oaZg10_o8[l43olZb`P?ocKC200?ockS3om6j`ooA^/<00_oA^/<01?oD_<;oe[o4omJoa?oF_l@3
omS2``04om_4`ooLb<Gog<S5omc8a@?ogl_400?oh/k4on;Aa_oRdLH00ooUeLH2onSJaP;ok=o500Ko
jn?8onkZaoo_lLCoko74ongh_OoRnJ`2o`0000;o//W[2OnY_NP00ol0003oZKgXojVmj00YojVmj003
o`000?oooooooooo013ooooo000Sooooo`;o0000=ooooolDojVmj0?o00001onY_NP2ofNTl`?oJIS[
0_m]V^/3ofNDj@;oGXgW0omIQn@2of67h@;oHhGN0omXQ]`01?m^R=coLhWJog>9f_mcRMX2ogR9f0?o
OH[F1?n0R]@3oh::dP?oQ8W@1?n4Qlh2ohB5c0?oQH?91?n7PLH3oh^0``CoT86o1?nGPk`4oif6^PCo
Y8Zi0onYS[T00on[SKKo[i6gojnA]`02ojnA]`Co/YFi0_ndU;H4okNH^003okRK^onjVkWo^Y^i00;o
^Y^i1?nkW[`00onmWk[o_Z:mokjR_@03okjR_@Go`JJn00?o`ZW0olBZ_oo4Z[l00oo4Z[l00oo6[L7o
b:o1olR_`@02olR_`@03olZb`_o=]<;ocKC200;ocKC21?oA^/<3omBl`P03omJoa?oH`/?of<;300;o
f<;30_oKa<<00ooLb<Gogl_4omo;a002omo;a0;oh/k400?oh]76onGEa_oUeLH00ooXf/H2oncOa@06
onoVa?oak/7oko74oo7e^_oXn:co00003_nY_NP00ol0003oZKgXojVmj00XojVmj003ooooool0003o
oooo013ooooo000Rooooo`03o`000?oooooooooo03Sooooo4?nY_NP3o`0000_oZKgX0_mWY?<2ofJI
k0?oIiS/0omWU>T2oej=i`;oFHOT0omHPn42of>5gP?oJ8KL0om^QmX3ogB8f0?oOH[F0on0R]@3oh::
dP?oQ8W@1?n4Qlh3ohB5c0?oQH?91?n7PLH3oh^0``CoT86o0onGPk`4oif6^PCoY8Zi00?oZHjioj^=
]_n[SKH00_n[SKH4ojnA]`;o/YFi0ondU;H4okNH^0Go^Y^i0onkW[`2okfO^PCo_Z:m0_o0Xk/4ol6V
_PKoa:Zo1Oo8[l45olfd`P03olnf`OoA^/?odK[300Coe;c21?oH`/<3om_4``Cogl_40ooRc/@00ooU
d/?oiMG6onSJaP02onSJaP?ok=o500GoknK4oo7^`OoamK[olOFjonSh[00@ojVmj003o`000?nY_NSo
ZKgX02SoZKgX00?o0000ooooooooool03oooool002;ooooo00?o0000ooooooooool0>Oooool=ojVm
j0;o00003_nY_NP3oe2Dk`;oIYW/0omWV>`2oenAjP?oEHWW0_mIQn@2oeR3h@?oG8;O0omXQ]`3ofj7
fP;oM8SH0omiR=H3ogb8e004oh2:e?n2R];oPX[Boh::dP?oQ8W@0on4Qlh3ohB5c0?oQH?91?n7PLH3
oh^0``CoT86o0onGPk`5oif6^P;oY8Zi00?oY8Rfoj^=]_n[SKH00on[SKH4ojnA]`03ok:E^OndU;Ko
]9Bf00;o]9Bf1?ngV;P00oniV;Ko^Y^iokZK^@03okZK^@04ok^N_?nmWk[o_InjokfO^P?o_Z:m0oo0
Xk/4ol6V_P03ol>W_Oo4Z[ooa:Zo00;oa:Zo0_o7Zkh4olR_`@04ol^`_oo=]<;ocKC2olfd`P?ockK1
00?odK[3omBl`_oD_<800_oD_<800ooG_/;of<;3omS2``04om_4``03omk7`_oOblCogl_400Coh/k4
00CoiM;3onSF`ooXf/Koj=[60oo/glD01Oo_i/ColNk1oo7^`OoamK[oj?R/017oZKgX00?o0000ojVm
j?nY_NP0:OnY_NP00ol0003oooooooooo`0>ooooo`008_ooool00ol0003oooooooooo`0jooooo`Wo
ZKgX0ol0000AojVmj0?oD9C_0_mRVNh3ofNHk0;oGi7Z0_mERNL3odn3i0;oF8?Q0_mLP]l3of:3g@03
ofR6g?m^Qm[oKXOJ00?oM8SH0omiR=H3ogb8e0?oOXOB0omoQ]03ogn3c@04ohB7c_n4QLcoQ8G<ohB5
c0;oQH?91?n7PLH3oh^0``CoT86o1?nGPk`4oif6^P04ojB:^OnTR;KoY8RfojB8]PCoZhff1?n_TKL6
okBD]P;o]iRh0_niV;H5okZK^@Go_Inj00?o_Z:mol2S^oo0Xk/00_o0Xk/3ol6V_P;o`jNm0oo4Z[l3
olN[_P?ob:o10oo;/;l00oo=]<;ockK1olnf`@02olnf`@Coe;c20ooG_/801?oH`/?oflC3om_4`ooK
a<<3omk7`P04omo;a?oRc/Coh/k4on;>a0;oiM;30_oXe/<01?oXf/Kok=o5oncOaOo_i/@2oo7^`@;o
lOFj00?ocNf<ojVmj?nY_NP04?nY_NP00ol0003oZKgXojVmj00YojVmj003o`000?oooooooooo00go
oooo000Rooooo`;o0000??ooool5ojVmj0?o00005OnY_NP3oe2Dk`;oHYW^0_mQU^d3oeJ>jP;oEHWW
0_m?Pn@3odmoh@;oG8;O0omRPmd3ofV4f`;oM8SH0omiR=H4ogb8e0?oOXOB0omoQ]03ogn3c@?oOh3;
0omoO/L4ohN1aP?oRh331?n@PKl3oiN3_0;oWHJj0_nLPkL4ojB8]PGoZhff0_n_TKL2ok6@]0Go]9Bf
00Co]iRhokVH]_niV;Ko^IRf1?njVkT2okbL]`Co_Inj1_o0Xk/00oo1Y[ko`jNmol>W_@02ol>W_@03
olBZ_oo7Zkkoaj^n00?oaj^n00?ob:o1ol^`_oo;/;l00_o;/;l5olnf`@03om:h`?oD_<;oe;c200Co
ekk200?of/71om_4`ooKa<<01?oNal83on;>a0;oiM;30ooXe/<01Oo/g<;ok=o5onoVa?o_i/ColNk1
00;olOFj00?oj?R/ojVmj?nY_NP04_nY_NP00ol0003oZKgXojVmj00XojVmj003o`000?oooooooooo
00gooooo000Rooooo`03o`000?oooooooooo03cooooo00CoZKgXo`000?l0003o00005_nY_NP3ojFl
j@;oAXc/0omMV>l2of6Fk@?oEXkZ0_m;QNL2odn3i0;oCgoQ0omCOml3of:3g@;oJHCK0om_Q]T3ogV8
eP?oO8SD0omnQm83ogn6d0CoOh?=0omoP</2ogmna`CoPGc40on5Nl44oi21_`;oUh>l00?oU7njoib3
]onLPkL00onLPkL3ojB8]PGoZhff00Co[i6gok6@]?naT;Co/I2d1?ndU;H00ongUKCo^IRfokVH]P03
okVH]P;o^Y^i0onlW;L4okfO^P03oknP^?o0Xk_o`:>k00?o`:>k1Oo3Ykd6olN[_PCobk2o0_o>/[l3
olnf`@?od[S000?oe;c2omNn`_oG_/800_oG_/82om[1`@03om_4`ooNal;og/O200;og/O200CohL[2
on;>a?oUd/?oiM;31?oXe/<01Oo/g<;ol>;1oo3R`OocjKkolNk100;olOFj5_nY_NP00ol0003oZKgX
ojVmj00XojVmj0;o00003Oooool002;ooooo00?o0000ooooooooool0>_ooool3o`0001[oZKgX0onU
_>T2odJ<k0?oGIS_0_mIU>d3oeJ>jP04od^5iom4O^?oA7kSodAnh`;oCgoQ0_mCOml3oeZ0g@03of:3
gOmYQ=_oJHCK00;oKhKI0omdQ]L3ogR6e@04ogb8e?mnQm;oOXOBogj7dP;oOhK@1?moPld3ogn0b`?o
Ogk71?n1O<@2ohEk`@CoRgbm1?nDOkX4oib3]`CoY8Rf0on[SKH00on/Rk?o/I2dok6@]002ok6@]0?o
]9Bf0ongUK@4okVH]P03okZK^OnlW;Oo_9bg00;o_9bg0onmWkX2oknP^0Co`:>k0_o3Y;X4ol>W_@03
olJX^oo7Zkkoaj^n00;oaj^n0_o9[Kd2ol^`_`Coc[:o00?ockK1om:h`?oB^<000_oB^<04omNn`P?o
f/711?oNal82on7:`P;oi<k100CoiM;3onSF`ooXe/?oj=K30_o/g<82oo3R`@04oo?Y__odlKSom?6h
onkfZaKoZKgX00?o0000ojVmj?nY_NP0:?nY_NP00ooooooo0000ooooo`0<ooooo`008_ooool3o`00
03Oooooo0ol00004oooooa[oZKgX0onN^^`2od2<k@?oGIS_0_mIU>d2odb;jP;o?h3V0_m4O^<3odAk
h@;oDgoO0omJP=d3of:2g0;oKhKI0omdQ]L3ogR6e@?oNHGB0omjP]04ogn3c@;oOh3;0omoO/L4oh5l
a0?oQG_11?n;O;d3oiAo^PCoW8>g1?nTR;H00on[SKKo[8^cojb;/`02ojb;/`Co/I2d00?o]9BfokNE
]?ngUK@00_ngUK@4okVH]PKo_9bg00Co_InjoknP^?noX;So_j2h0oo0Xk/3ol>T^P?o`jNm0_o6Z;/3
olN[_P?obJfm00?obk2ooljb_oo>/[l00oo>/[l4om:h`0;oeKZo0_oG_/84om[1`@03omc3`?oNal;o
g/O200?ohL[20_oTc/400ooXd/3oj=K3onSF``02oncL`P;ol>;10_ocjKh2ooCa^1SoZKgX00?o0000
ojVmj?nY_NP0:?nY_NP00ol0003oooooooooo`0;ooooo`008Oooool2o`0003Kooooo0ol00008oooo
oa[oZKgX0onN^^`2od2<k@?oEIO`0_m@TNh2odb;jP;o?h3V0_m4O^<2odAkh@;oBG_O1?mJP=d2of:2
g0?oJH?J0_mdQ]L4ogR6e@?oNHGB0_mjP]04ogUoc@?oN7_90_moO/L4oh5la0?oQG_11?n;O;d3oiAo
^PGoW8>g0_nTR;H00onUQ[?o[8^cojb;/`03ojb;/`Co/I2d1OngUK@3okVH]P;o^iVd1OnlW;L5oknP
^003ol2S^oo3Y;[o`jBj00?o`jBj00?o`jNmolJX^oo6Z;/00_o6Z;/00oo7ZkkobJfmolV]_@02olV]
_@Koc[:o00?odKBnom:h`?oB^<001?oE^[l01?oG_/;of/71om[1`OoJ`L42omc3`004omk7`_oQb/;o
hL[2on7:`P?oi<k10_oXd/000ooXe/?ok=c2oo3R`@02oo3R`@04oo?Y__odlKSom?6honkfZaWoZKgX
00?o0000ojVmj?nY_NP09onY_NP00ooooooo0000ooooo`0;ooooo`0000Co<S8bo`000?lb<S;ok^k^
1Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Co
oooo00?o0000ooooooooool0<_ooool3o`0000cooooo6_nY_NP3oiZikP;o=h[]0omEUo02oe2AkP;o
@HKZ0_loP>H2ocUih`;oA7_Q0_m9Nml3oeZ0g@?oHX;L0_mYPmX3ofn4f0?oN8KE0omiQM83ogZ2d0?o
NGo=0omhNlT3ogQhaPCoPGc40_n5Nl44oh]l_@CoU7nj1?nLPkL00onTR;KoYHJcojF6/`05ojb;/`Co
/I2d00?o]92bokNE]?ngUK@00ongUK@01?niV;Ko^iVdok^I]?nkVK@4okbL]`;o_iff1?noX;P6ol>T
^PGoaZRk1Oo9[Kd00oo<[kcoc[:ooljb_`02oljb_`;odKBn00?od[S0omFj_ooE^[l00ooE^[l3om[1
`@?og<?000?oh<Joon7:`_oQb/800ooTc/43onSB`005oncH_oo/g<;ol>;1oo3R`OocjKh00_odlKP0
0oo^mZ_oZKgXojVmj00IojVmj003o`000?nY_NSoZKgX02OoZKgX0_l0000;ooooo`0000CoV9RHoooo
oonHV9SoMgMg1Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo02oooooo0ol0000@oooooa[oZKgX0onJ^Nh2ocN:k@?oC9C`0_m5S^h2
od66jP;o<g_U00Go>GWSocUfh?liM^3o>GKPodUkg`03oe9mgP03oeZ0gOmRP]coHX;L00?oJH?J0_m_
Q=P3og:3e@04ogR6eOmiQM;oNHGBogV5dP;oNX;@1?miOld3ogQkb@;oN7S60omjM/801?n1O<CoQG_1
ohEk`On5Nl44oh]l_@?oU7nj0_nLPkL2oib0]0CoYHJc1On/Rk<2ok6@]0;o]92b1OngUK@4ok^I]0?o
_9bg0onoWKH4oknP^003ol:Q]oo3Y;[o`jBj00;o`jBj0_o5YKT4olJX^`04olVY^_o9[KgobJfmolV]
_@;oc:nl0oo>/[l3om6d_PGoeKZo0_oH_;h00ooJ`L7og<?0omc3`002omc3`0;oh<Jo00CohL[2onC>
`OoTc/7oi<k10ooXd/001_o/f;ool=jnoo3N__o`h/7olnVnooCa^0;ok_J[6onY_NP00ol0003oZKgX
ojVmj00XojVmj003o`000?oooooooooo00Wooooo0003ooooo`03oa0@4?oooooooooo00_ooooo00?o
ZJVYoeEEEOooool02?ooool00ol0003oooooooooo`02ooooo`;o0000;_ooool2o`0001Cooooo6_nY
_NP3oiZikP;o;8O/0om<U?02odF>kP;o=8;X00?o<g_Uob]dhOl[M>400_liM^02ocmgg`?oDWgN0omJ
Omd2ofV3fP?oKhCH0ombPmD3og>1dP?oLgk?0omiOld3ogQkb@?oN7S60omjM/83ogie_P?oQWNk00Co
RgbmoiAo^_nDOk[oT7Zg1?nLP;@4ojF6/`Go[8^c00Co/I2dokB@/_ndT;;o]92b1?ngUK@2okZF/PCo
^iVd00?o_9bgoknM]_noWKH00_noWKH3oknP^0;o`Z6g0oo3Y;X3olFU^@?oaZRk0_o9ZKX2olV]_@Co
c:nl00?oc[:oom6d__oA];h00_oA];h01?oC][goeKZoomFj_ooE^[l3omRl_PCog<?00ooPa[l00ooS
b[koi<k1onC>`@03onSB`0;ok=Ro0_o`g[h00oociK_om^jfojVmj00NojVmj003o`000?nY_NSoZKgX
02OoZKgX00?o0000ooooooooool02Oooool000?ooooo00?o0000ooooooooool03?ooool00olQ8B7o
ooooooooo`06ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0:_ooool3o`0001Oo
oooo6_nY_NP3oiZikP;o;8O/0om2TO02ocV:k@03ocB2j?lUM^?o9GKS00;o:gCQ0_liM^02ocmgg`?o
DWgN0_mJOmd3of:1f`;oKhCH0ombPmD4og>1dP;oLgk?0ombN/`3ogQkb@?oN7S61?mjM/82ogie_PCo
QWNk0on@N[L5oib0]0?oYHJc1?n/Rk<00on_Rk3o]92bokB@/P03okB@/P;o]iFd0onjU[84ok^I]0Ko
_iff00?o_j2hol:Q]oo2XKL00_o2XKL00oo3Y;[oaJFiolFU^@03olFU^@03olJX^oo9ZK[obJVj00;o
bJVj00?obJfmolb__?o<[k`00_o<[k`4om6d_P?odkJm00?oeKZoomRl__oH_;h00_oH_;h00ooK_kgo
g<?0omc3`004on36_`;ohlZn00?oi<k1onSB`?oXd/000_o/f;l3oo3N_P03oo?U^oofk[KoZKgX01oo
ZKgX00?o0000ojVmj?nY_NP09OnY_NP00ooooooo0000ooooo`0:ooooo`000oooool00ol0003ooooo
ooooo`0<ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03
o`000?oooooooooo02Oooooo0ol0000Koooooa[oZKgX1?nM^^`01?lMP^So@Y7`od:Al?m2TO02ocV:
k@03obMli_lUM^?o9GKS00;o:gCQ0_l/LMl01?loMmooB7WNodQig_m8NMh3oeYog@;oHX7K0omXPMP3
og:3e@?oLh7B0omcO/l2og9jc0?oL7K800?oN7_9ogQha_mhN<H01?mjM/83ogie_PCoQWNk0on@N[L4
oib0]0CoYHJc0_n/Rk<3ojn;/0Co]92b00?o]iFdokZF/_njU[800_njU[84ok^I]003okjJ/onoWKKo
_iff00?o_iff1Oo2XKL6olFU^@GobJVj1Oo<[k`00oo?/;_odKBnom6d_P04om>f_@Cof;bn0ooK_kd0
1?oL`l3oh<Joon36_ooPa[l3on?:_P03onO>_OoXd/3ok=Ro00;ok=Ro0_o`g[h00oociK_om^jfojVm
j00PojVmj003o`000?nY_NSoZKgX02;oZKgX1Oooool00ol0003oooooooooo`08ooooo`000oooool0
0ol@413oooooooooo`0<ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Uooooo`?o00007ooooolJojVmj0;oWK[/0_nU_>X2oa]niP;o=8g^0_l[QN/0
0olWO>Ko9GKSobEfh`02oae^gP03obaagolbL]ko<W;N00;oB7WN0omAO=d00omJOmgoHX7Kof:1f`02
ofR1f0?oJh3F1?mcPM82og=nc`?oLW[<0om`M/P3og1ba@?oNWK20omnMKh4ohIg^`?oT7Zg1?nLP;@4
ojF6/`03ojb;/on_Rk3o[h^`00;o[h^`1?ndT;86okZF/P;o^iVd0_nnV[<4oknM]P;o`Yjd1?o2XKL0
0oo5X[KoaJFiolFU^@03olFU^@CobJVj0_o<ZkT3olb__0?ock2k00?odKBnom>f_OoC][d00_oC][d0
0ooG^Kcof;bnomRl_P04om^o_@03omk2_?oPa[ooh<Jo00CohlZn00Coiljmon_C_Oo/f;ook=Ro0_o`
g[h2oo?U^`03ooK^]_nY_NSoZKgX023oZKgX00?o0000ojVmj?nY_NP07OnY_NP9ooooo`03o`000?oo
oooooooo00Sooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05oa0@4?oooooooooooooooolb<S80
1?ooool00ol0003oooooooooo`05ooooo`?o00008_ooool3o`0002?ooooo6_nY_NP4ojFljP;o6gkV
0_lUQn/2ob^5j`04oaQfholFKmoo5VoOoae^gP;o7F_M0_lbL]h2odQigP?oDGcM0omIOM/2ofR1f0;o
Jh3F1?m/OM82of]ic`?oLW[<1?m`M/P2og1ba@?oLFo100?oNWK2ogie__mnMKh01?n6Mk/3oi1j]`Go
W82d0_nUQ[<00onVQ;3o[h^`ojn;/003ojn;/0Co]92b1_njU[801?nkVKCo_YZcokjJ/onnV[<3oknM
]P?o`Yjd0oo2XKL2olFR]PCoaJFi0_o8Y[L2olVY^P?oc:^i0_o<[k`4oln`^`CodkJm0ooG^K`00ooH
_;kofknmom^o_@02om^o_@;og/:l00Coh<Joon?:__oSb[kohlZn0_oWc[d2on_C_@05oncH_oo`g[ko
l=jnoo?U^oofk[H09?nY_NP00ol0003oZKgXojVmj00IojVmj0cooooo00?o0000ooooooooool02?oo
ool00004oc8b<_l0003o<S8bonk^kP_ooooo1Ol00004ooooo`Co00001?ooool00ol0003ooooooooo
o`0Oooooo`?o00009ooooolJojVmj0;oYKcZ0_nY_NP2obn5j`;o9HO[0_lLOnL01?lHM^?o5VoOoaI_
gol=I]/2oae[g@;o<W;N0_llM=h3oe5lg@;oFGgK0omOOMT2of^0ePCoK7gB0_m[NLl2og9jc0CoL7K8
0om`L/D3og5_`@;oMVjm00?oOWFnohIg^on6Mk/00_n6Mk/3oi1j]`CoW82d00?oYHJcojJ4/?nVQ;00
1_n_Rk02okB@/P;o]i6`1OnjU[85okjJ/`03oknM]_o2W[Co`Yjd00;o`Yjd0_o2XKL3olFR]P?oaJFi
0oo8Y[L00oo9ZK[oc:^iolb[^@03olb[^@03olb__?o?/;_ock2k00;ock2k00Cod[:jom>f_OoC][go
dkJm0ooG^K`4om^o_@?og/:l0ooSb[h2onO>_@?ojm>m00GokmZkoo3N__ociK_olnFkooK^]P0UojVm
j003o`000?nY_NSoZKgX01CoZKgX4?ooool00ol0003oooooooooo`08ooooo`008?ooool00ol0003o
ooooooooo`0Looooo`?o0000:ooooolNojVmj0;o;hG[0_lCP>D2oaaoi`04o`M_g_l6J=_o1VSKo`eV
f`;o7F_M0_lTK=d01OllM=koAWOModIggOm6MmgoDGcM00;oFGgK0_mOOMT3of9keP?oK7gB0_m[NLl3
ofUdb`?oL7K80om`L/D4og5_`@;oMVjm1?n6Mk/3oi1j]`;oW82d0_nKOK44ojJ4/0Go[h^`00Co]92b
okNA/?ngTK3o]i6`1OnjU[800onmUk3o_YZcokjJ/`02okjJ/`Ko`Yjd00?o`Z6golFR]_o5X[H00_o5
X[H00oo5YKWob:JgolRV]`02olRV]`Koc:^i1?o?/;/2om:b^P;odkJm1?oG^K`00ooJ^k_ofknmom^o
_@04omk2_003on;6_?oSb[koiljm00;oiljm0oo[dkd00oo_f[_oln6ioo?Q^@0WojVmj003o`000?nY
_NSoZKgX017oZKgX4oooool00ol0003oooooooooo`08ooooo`008?ooool00ol0003oooooooooo`0I
ooooo`?o0000<OoooolLojVmj0;oCYOa0_lCP>D2o`Ygh@04o`M_g_l6J=_o1VSKo`1NeP;o3F?I00?o
96cMobi_gOl^Kmd00om6Mmd2odmig0?oGggI0_mRNmH2of9hdP04ofamd_m[NLooJgW?of]ic`;oJGC;
0omWKlL00om`M/SoL7;5og1ba@04og5_`@;oMVjm1?moL;T3ohaf]@CoVgfa1?nVQ;05ojn;/0Co]i6`
1?njU[82okfG/0Co_YZc00?o`I^aol:N]?o2W[@00oo2W[@5olFR]PGob:Jg00?objRfolb[^Oo<ZkT0
0oo<ZkT00oo>[KSock2koln`^`04om:b^P04om>f_OoG^KcoekVlomNi_0?of[^k00Cofknmomk2_?oN
`[cog/:l0_oRa[`00ooVb[_oiljmonO>_@03on_C_@;okmZk0_ochKTXojVmj003o`000?nY_NSoZKgX
00goZKgX5_ooool00ol0003oooooooooo`08ooooo`008?ooool2o`0001Oooooo0ol0000eoooooaco
ZKgX0om>Uo401?l0M]co2WOQo`YghOl0I]L2o`1Oe004o`1Ne_l=HmWo4fCJoa=TfP;o;VoM0om6Mmd2
odmig0;oGggI0omRNmH3of9hdP;oJgW?0omYM</3ofM_a`;oIF_300CoL7;5og5_`OmaKl7oLFo10omf
K[d3ogm`^@?oS7Je1OnKOK43ojJ4/0Co[h^`00?o/Xb^okNA/?ngTK000ongTK02okZF/P?o_IN`0onn
V[<2ol6K/@Go`Yjd00?oa9ncolFR]_o5X[H00_o5X[H01?o8Y;Cob:JgolRV]oo8Y[L2ol^X]PCoc:^i
0oo>[KP00oo?/;_od[:jom:b^P02om:b^PCoekVl0ooJ^k/3omk2_0?oh/Jl0_oVb[/01OoWc[gojm>m
on_C_Oo[dkgokmZk00;oln6i:_nY_NP00ol0003oZKgXojVmj008ojVmj1[ooooo00?o0000oooooooo
ool02?ooool001oooooo00?o0000ooooooooool05Oooool2o`0003Wooooo7?nY_NP4og:Yl`03o`1X
c_l0K]So06KG00;o05oD00Go05G>o`1KdolCI=[o4fCJobi_g@03ocUag@03odIggOm?NMcoE7SI00;o
E7SI0_mRNmH3of9hdP?oHG??0_mYM</4ofM_a`;oIF_31?maKl42ogI^_@?oOg2i1?n<M[D4oi]m/@Co
YXB`0_n_Rk03ok:<[PCo]i6`00?o^YJbokfG/?nmUk000onmUk001?nnV[?o`I^aol6K/Oo1Vk44ol:N
]0;oa9nc0oo5X[H2olRT]0;ob:Jg0oo;Z;H3olb[^@CocZfh1OoB/[X00ooE]KWoekVlomNi_004omZk
^`03omfn^_oN`[cog/:l00;oh/Jl0ooVb[/00ooZck[ojm>mon_C_@02onoJ^`;oln6i:onY_NP00ol0
003oZKgXojVmj004ojVmj1kooooo00?o0000ooooooooool01oooool001oooooo00?o0000oooooooo
ool04_ooool3o`0003cooooo7?nY_NP2og:Yl`;oU;O_00?o06;:o`1Rc?l0G<d00_l0E/`00ol0ELko
05_Coa=TfP02oaeWf`?o>G7M0_m1Lm/2oeAhf@?oEgKF0omRN=82of5cc`;oGVg:1?mWKlL2ofE[``?o
IVNo00?oLFo1ogI^_OmfK[d01?moL;T3ohaf]@CoVgfa1?nVQ;000on_Rk3o/Xb^ok:<[P02ok:<[PCo
]i6`1_nmUk000onnV[?o`I^aol6K/@02ol6K/@;o`Yjd0oo4Wk<2olFR]PCob:Bd00?ob:Jgol^X]_o;
Z;H00_o;Z;H00oo<ZkWocZfholj]^003olj]^0Cod[:j0ooE]KT01?oG^Kcof[^komZk^ooJ^k/2omfn
^P04omk2_?oRa[coh/Jlon;6_0?oi/Zk0_oZckX01?o[dkgokmZkoo?Q^OochKT/ojVmj004o`000?nY
_NSoZKgXojVmj27ooooo00?o0000ooooooooool01oooool001oooooo00?o0000ooooooooool03ooo
ool3o`00043ooooo6onY_NP5oiBgk`03o`1Rb_l0H/co05c=00;o05K<00?o04[4o`1@c?l1Fm@00_lM
Im/2ocUag@?o@G?K0_mDN=T2oeMfeP;oEg;B00CoHWSBof5ccomQLlooHG??0_mNKLX3ofM_a`?oIF_3
0omVIkl2of]V^`04ogI^_OmoL;WoOg2iogm`^@?oS7Je1?nKOK44ojJ4/0Go/Xb^1?ngTK000onjTjko
_IN`okfG/003okfG/0Go`I^a00?o`YjdolBO/oo4Wk<00oo4Wk<00oo5X[Kob:BdolRT]002olRT]0Go
bjRf1Oo>[KP2om6_]`;od[:j1?oE]KT3omZk^`?ogKjj00?ohL:ion;6_?oRa[`00ooVb[/3on[?^P04
onkE^Oo_f[_oln6ioo?Q^BcoZKgX00?oooooo`000?ooool08_ooool00ol0003oooooooooo`07oooo
o`007oooool2o`0000gooooo0ol00013oooooacoZKgX0_nD]nl3ojVmj009oaikiOl0Dk[o05>jo`1@
_ol0Bl3o04[4o`1@c?l1FmCo7FOK00;o:6[K00?o>G7Mod5cfom1Lm/00_m7L]T3oeMfeP?oEg;B0_mQ
Lll2oei]bP?oFfO600?oIfo7ofE[`omUJl<00omVIkl3of]V^`?oOg2i0on<M[D5oi]m/@;oYXB`00?o
Z8B]ok:<[_nbS:h01?nbS:h2okNA/0;o^Y>^1OnmUk000oo0VJoo`I^aol6K/@02ol6K/@Koa9nc1Oo8
Y;@00oo:YK?objRfol^X]P02ol^X]P04oljZ]Oo>[KSocZfholj]^0?odJng00?od[:jomFe^OoE]KT0
0ooE]KT00ooH]kSof[^komZk^`03omfn^P;ohL:i00Coh/JlonK:^ooVb[_oi/Zk0ooZckX00oo^eKWo
ZKgXojVmj00ZojVmj0Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`07ooooo`00
7oooool00ol0003oooooooooo`09ooooo`?o0000AooooolQojVmj0;oJ:Cc00Oo04:So`0n/Ol0?[7o
03jgo`15`Ol0D<go2ekF00;o:6[K0om1Lm/2odMbf@;oEgKF0omGL]83oeE/cP;oGVg:0omKIlH2oeYS
`@?oIVNo0om[I[/3ogIY]`CoS7Je1?nKOK401?nVQ;3oZ8B]ojR4[OnXQ:d5ok:<[P04okNA/?njTjko
^Y>^okZC[PCo_IN`0_o0VJl4ol6K/@03olBM/?o4Wk?oa9nc00?oa9nc1?o8Y;@2olZU/`?objRf0_o>
Z[D3olj]^0?odJng1OoE]KT2omRg^004omZk^ooM_[[ogKjjomfn^P?ohL:i00?oiLJhonK:^ooVb[/0
0ooZckX2onkE^BWoZKgX2?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Oooooo
000Oooooo`03o`000?oooooooooo00Kooooo0ol0001;ooooob7oZKgX0_mXY?<02?nP^nco03jao`0n
/Ol0?[Oo04G1o`1@cOl;G]Ko:6[K0olaJmX00om1Lm_oAg;IodY_e@02odY_e@;oEg;B0omEK<h2oe9V
b@CoFfO60_mJHl43ofIW_`;oJfJk0omfJKL3ohIa/`03ohaf]OnKOK7oVgfa00;oVWZ_1?nXQ:d5ok:<
[PGo^Y>^0_nmUk03ol2I[`?o`I^a0_o4WK04olBO/`;oaj6b0_o8Y;@3olZU/`;objRf1?o>Z[D00oo>
[KSodJngom6_]`02om6_]`04omBa]_oE]KWoeKFiomFe^@?of;Nh1?oM_[X3on72^@;oiLJh00?oi/Zk
on[?^_oZckX00_o^eKTVojVmj0gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`07
ooooo`007oooool3o`0000?ooooo0ol0001?ooooob7oZKgX1?nP^n`2o`0`Y`04o`14`_l0Dloo05??
oaEQe`?o<F_J0_lgJ]L2odY_e@;oBF[A00CoEg;BoeE/c_mEK<koEFc>0_mBI/T3oe]WaP;oFV?10_mJ
Gkd01?mVIkooJfJkof]V^om[I[/2ogIY]`CoQW6c1?nJNZl4ojR4[@Co/Xb^00?o]Xj/okZC[_njTjh0
0onjTjh00onmUk3o`9V_ol2I[`03ol2I[`04ol6K/Oo4WK3oa9f`olBM/0?oa9nc0oo7XK82olRT]0Co
bZFc00?objRfoljZ]Oo>Z[D00_o>Z[D4om6_]`?oe;6f00?oeKFiomRg^?oH]kP00_oH]kP00ooL^[Oo
gKjjomfn^P03on72^@?oiLJh0ooZckX2onkE^B?oZKgX4Oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00Oooooo000Nooooo`;o00000_ooool3o`0005?ooooo8OnY_NP2oj2kk0;oZKgX
0_l0<:L01?l0A<;o05??o`1CcolEHML3oc5[fP;o=f[G0_m:KmD2odUZd@?oEFc>0_mBI/T2odmOa004
oe]Wa_mJHl7oFV?1oeYS`@;oFUnm0om[I[/3ogIY]`?oQW6c1?nJNZl5ojR4[@;o/Xb^0onfSZ`4okZC
[PKo`9V_00?o`I^aolBM/?o4WK000_o4WK000oo4Wk?oaj6bolNQ/P02olNQ/P03olRT]?o:YK?obZFc
00?obZFc1Oo>Z[D00oo@[;CodJngom6_]`04omBa]PCof;Nh0ooL^[L01?oM_[[ohL:ion72^OoQ`[T3
onG6^004onW;^?oZck[ok]FionkE^B7oZKgX5Oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00Kooooo000Dooooo`Co000000?o410@ooooooooool00oooool4o`0005Oooooo9OnY_NP0
1?m>Uo7o032Wo`14`_l0Dll2o`1Ed@;o7V;G00Co<F_JocMZeoljI]?o>VKC0_m9J]42odMTc004oeE/
c_mBI/WoDVK9oe9Vb@;oCeo400?oFfO6oeYS`OmJHl400_mJGkd2oeiN^P04of]V^omfJKOoMVVgogIY
]`CoQW6c0onJNZl5ojR4[@03ok:<[_nfSZco]Xj/00;o]Xj/1?njTjh00onnUZgo`9V_ol2I[`03ol2I
[`Goa9f`1Oo7XK86olZU/`04olfW/oo>Z[GocZZeoljZ]@?od:bd00?odJngomBa]_oD/KH00_oD/KH0
1?oG];Gof;NhomRg^?oH]kP3ombj]`03omnn]ooQ`[WohL:i00?oiLJh0_oYbkP2ojVmj003onkE^OnY
_NSoZKgX01_oZKgX6Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo000F
ooooo`03o`000?oooooooooo00Gooooo0_l0001KooooobCoZKgX0_nT_>X01?l0::7o04G4o`1EdOl0
EM42oaiRe`;o963D0_ljI]<2odUZd@?oAfC<0_mBI/T3odmOa0;oFV?10_mJGkd3oeiN^P03of]V^omf
JKOoMVVg00CoQW6c1?nJNZl4ojR4[@Go]Xj/0onjTjh2okjF[@Go`9V_1Oo4WK000oo7Wk3oaj6bolNQ
/P02olNQ/P03olZS/Oo:YK?obZFc00;obZFc0_o=Yk<2oljZ]@Cod:bd1?oD/KH2omNd]@;of;Nh1?oL
^[L2omnn]`03on72^OoUa[SoiLJh00?ojL^h7OnY_NPMooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool01_ooool001Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1I
ooooobCoZKgX0_nT_>X01Oma003o04G4o`1EdOl7E]7o7V;G00?o963D00?o>VKCocUQcoliHLl00om7
I<`2odAMa`?oCeo40_m<F[l00omJHl7oFUnmoeYO_@03oeiN^P;oMVVg1?n6LK<4oiYj[`?oZ8B]00?o
[8F[okJ>[?nfSZ`01?nfSZ`01?njTjko_YJ]okjF[OnnUZd4ol2I[`;o`i^^0oo4WK02olNO/0?oaj6b
0_o:Xk43olZU/`CocJNc00?ocZZeom2/]?o@[;@00_o@[;@01?oC[kCoe;6fomBa]_oD/KH3omNd]@04
omRg^?oL^[Oog;Zgombj]`?ogkjg0ooUa[P2onW;^1_oZKgX8Oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00Kooooo000Fooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0FOoooolVojVmj005og400?l0=KKo04K7o`MFdOlNH]L00_lTH=@01?lWG=3o>VKCocUQcoliHLl3
odMTc0;oA5g70_m?Gl@3odaJ_`;oFUnm0omNG[X2ofUQ]P04ogIY]on6LK?oQW6cohIa/`CoVWZ_0_nX
Q:d3ojb5Z`Go]Xj/00?o^Y>^okjF[OnnUZd00_nnUZd2ol2I[`?o`i^^0_o4WK03olNO/0;oaj6b1?o:
Xk400oo:YK?ocJNcolfW/`03olfW/`Cod:bd0_oC[k@2omBa]PCoekBe1?oL^[L3omnn]`03on?2]_oU
a[SojL^h00;ojL^h6?nY_NPUooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01_oo
ool001Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1IooooobKoZKgX00CoM000
o`0e]_l0A/Oo1eKA0olTH=@00olWG=3o>F7?ocUQc`02ocMJb@04odMTc?m4GLOoA5g7od1F`P;oCeo4
0_m<F[l00om<E[_oFUnmoeiN^P03oeiN^P;oJF6f1?n6LK<3oiYj[`03ojR4[On/QJ_o[8F[00;o[8F[
1OnfSZ`5okjF[@03ol2I[oo3Vjko`i^^00;o`i^^00?oa9f`olNO/?o7Wk000oo7Wk000oo7XK;obZ>a
olZS/@02olZS/@KocJNc0oo@[;@4om>_]003omBa]_oG];GoekBe00;oekBe00?ofkNeombj]ooL^[L0
0ooO_[L2on?2]P03ojVmj?oYbkSojL^h01GoZKgX:Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo00Kooooo000Fooooo`03o`000?oooooooooo00[ooooo0_l0001JooooobKoZKgX00Ko
M000o`0SXol0AlOo04O7o`eCcolTH=@2obMLd0;o>F7?0olgF/T2odAMa`03od1F`_m?GlCoC5Zo00;o
C5Zo00?oC5JkoeYO_OmNG[X00_mNG[X2ofUQ]P?oOFZc00CoQW6coiYj[onJNZooVGV]1On/QJ/5okJ>
[0Go_YJ]1Oo3Vjh6olNO/0GobZ>a00?ocJFaolfW/oo=Yk<00_o=Yk<2om2Z/P;od:bd1?oC[k@4omNd
]@?ofkNe00?og;Zgomnn]ooO_[L00ooS`[H2ojVmj003onW;^?nY_NSoZKgX013oZKgX;Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00Kooooo000Fooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0F?oooolWojVmj003o`0SXol0AlOo04O700;o3E??00?o9ec@obIFbolV
E//00olgF/T01?lcDlCoA5g7od1F`_m0E/83odaJ_`;oC5Jk0omNG[X2ofUQ]PCoOFZc0onINJd5ojb5
Z`Co]Xj/00?o^i6[okjF[OnnUZd00onnUZd00oo3VJgo`i^^ol>K[P02ol>K[P03olNN[_o7Wk3oain`
00?oain`00CobZ:_olZS/Oo:Xk7obZ>a0_o=YK43olfW/`?od:Zb00?od:bdom>_]?oC[k@00ooC[k@0
1?oG/K?oekBeomNd]OoG];D3om^g]@?ogkjg0_oS`[HCojVmj37ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`05ooooo`005?ooool00omEEEGoIVIVo`00000?ooooo`03o`000?oooooo
oooo05Sooooo9onY_NP01?l08ZGo04O7o`14a_l0A<H2oa1?b`;o9UK;0olgF/T00olcDlCo@5K2od1F
`P02ociA_@03odaJ_om<E[_oC5Jk00;oCeBh0_mNG[X2ofUQ]P?oOFZc1?nINJd5ojb5Z`;o]Xj/0onk
TJ/3okjF[@;o`iV]0oo3Vjh2olNN[PCoain`0_o:XZl3olZS/@;ocJFa0oo=Yk<3om2Z/PGodjnd0_oG
/K<2omNd]@CofkNe00?og[^domnn]ooS`[H00_oS`[H@ojVmj3Gooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`05ooooo`009oooool00ol0003oooooooooo`1HooooobOoZKgX00Co02:U
o`0e^_l0A<Ko04C60_l@Cl/01?lVE/_o94o6obA?a_lgF/T2oc=Ca0;o@5K20_lnDKd00om<F[ooC5Jk
odaF^`03odmD^0;oJF6f1?mmJ[<3oiUi[@Go[8F[00?o]Xj/ok^AZonkTJ/00_nkTJ/2okjF[@?o`iV]
0oo3Vjh2olNN[P?oain`0oo:XZl2olZS/@CocJFa00?ocJNcom2Z/_o@Z[800_o@Z[801?oC[;7odjnd
om>_]?oC[k@4omNa/`04omNd]OoK]kGofkNeom^g]@;og[^d0ooS`[H>ojVmj3Sooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`05ooooo`00:?ooool2o`0005Wooooo9onY_NP01ol08ZGo
03Fjo`14a_l0A<Ko44o;oa19a_lVE//00_lTClH2oc=Ca003oc1<_om0E/;o?U6m00;o?U6m0_m<E[/3
odmD^003oeMF]OmYHKKoOFZc00?oOFZc0onINJd5ojb5Z`Go^i6[0_nnUZd4ol>I[@03ol>K[_o7WZko
aij^00;oaij^0_o7Wk04olZR[`03olZS/Oo=YK7ocJFa00;ocJFa1?o@Z[82om>//@?odjnd1?oG/K<3
om^g]@?og[^d00?oZKgXon?2]_oS`[H02_nY_NPmooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool01Oooool002[ooooo00?o0000ooooooooool0F?oooolVojVmj006oh`50?l0<[Wo04C6
o`10`ol@Cl_o44W60olTClH2oc=Ca006oc1<_olnDKgo?U6mociA_OlmC;WoC5Jk0om?E;P2oeMF]@04
ofUQ]_mmJ[?oOFZcogeZ/`?oVGV]1?n/QJ/00onbR:Wo^i6[ok^AZ`03ok^AZ`03okjF[Oo3VJgo`iV]
00?o`iV]00?o`i^^olNN[_o7WZh00_o7WZh00oo7Wk3obZ:_olZR[`03olZR[`GocJFa00Cod:R`om2Z
/_o@Z[;od:Zb0ooC[;400ooC[kCoek6comNa/`03omNa/`03omZd/ooK]kGofkNe00;og[^d0onY_NP0
0ooS`[KoZKgXojVmj005ojVmj47ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`05
ooooo`00:oooool00ol0003oooooooooo`1HooooobKoZKgX00Co00f>o`0b^Ol0A<Ko04330_l@BLH2
obA?aP04ob58`?lcDlCo<4booc1<_`?o?U6m00?o?DbiodaF^om?E;P00_m?E;P2oeMF]@?oOFZc1?nI
NJd2ojb5Z`?o/XRY1?nkTJ/6ol>I[@Goaij^1_o:XZl01?o=Y:oocJFaolfU/Oo=YK42om2X/0;od:Zb
1?oC[;45omNa/`;of[Bc00CofkNeomjk]?oN^kCog[^d2?nY_NQ4ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool01Oooool002cooooo00?o0000ooooooooool0F?oooolVojVmj007o`0Q
Yol0<[Wo0433o`10`ol@BLKo3d?1obA?aP02ob58`0;o<4bo0_l^AkX00olnDKgo?Dbioce<^@03odmD
^0;oEeJe0_m]H;<2ogeZ/`?oVGV]00?o[8F[ok:8ZOnbR:T00_nbR:T4ok^AZ`03ol6G[?o3VJgo`iV]
00?o`iV]00?oaYf]olNN[_o7WZh00_o7WZh00oo:XJkobZ:_olZR[`02olZR[`;ocJB_0oo=YK42om2X
/0;od:Zb1?oC[;401?oF[k7oek6comNa/ooG/K<3omZd/`?og[^d1_nY_NQ8ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool01?ooool002gooooo00?o0000ooooooooool0F?oooolVojVm
j007o`0NZ?l0;[Oo02jgo`0j__l@BLKo3d?1obA?aP02ob58`0;o<4bo0_l^AkX2oce<^@;o?dZf00?o
CeBhoeMF]OmGE[D01?m]H;<2oiUi[@03oiUh[OnbR:Wo/XRY00?o/XRY0onkTJ/2ol6G[0Co`iV]0_o6
WJd3olNN[P;obZ6^0oo:XZl3olfT[`;ocJFa1?o@Z;001?o@Z[;odjbaom>//OoC[;42omJ_/@?oek6c
0ooJ];<00onY_NSog[^domjk]003ojVmj4cooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`04ooooo`00;_ooool2o`0005Wooooo9_nY_NP01?l07ZSo02jgo`0^]ol0>[h2o`m3`@;o8DS0
00?o7T:koc1<_ol^AkX00_l^AkX2oce<^@;o?dZf00?oCeBhoeMF]OmGE[D00om]H;<3oiUh[@Ko/XRY
00Co^i6[ol6G[?o1Ujco`IN/0oo3VJd3olJM[@?oaij^0_o:XJh3olZR[`CocJB_00?ocJFaom2X/?o@
Z;000_o@Z;04om>//@?oeZna00Coek6comZd/ooJ];?of[Bc0onY_NP00ooN^kCoooooooooo`1>oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool0033ooooo00?o0000oooooooo
ool0E_oooolWojVmj005o`0NZ?l0;[Oo02jgo`0j__l?@l400_l=?;/00olQB<3o7T:kobi7^P02obi7
^P;o?Dbi0oloB[H2oeMF]@?oKF2c1?nIN:d5ok:8Z@03ok^AZoo1Ujco`IN/00;o`IN/0_o3VJd4olJM
[@03olNN[_o:XJkobZ6^00;obZ6^00?obZ:_olfT[oo=Y:l00oo=Y:l5om2X/003om:[/?oC[;7odjba
00CoeZna1?oJ];=Dooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool0037o
oooo00?o0000ooooooooool0E_oooolWojVmj005o`0JYol0;[Oo03Zno`0d^Ol?@l400_l=?;/2oai2
^`?o;TNj00Co?Dbiocm:]_loB[Ko?dZf0_mGE[D4ofeP/`?oVGR]1OnbR:T5ol6G[003ol>I[Oo6WJgo
aYf]00?oaYf]00?oaij^olZQ[_o:XJh00_o:XJh6olfT[`04olnW[oo@Z;3od:R`om2X/0;odZ^`0_oC
[;44omJ_/@03oooooooJ];?of[Bc05Kooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`04ooooo`00<_ooool00ol0003oooooooooo`1GooooobKoZKgX00Co01ZWo`0^]ol0>[ko03Bi0ol=
?;/01_lN@[_o7Cfgobi7^_l^Ak[o;D>goce<^@;o?dZf00?o@d^doeMF]Om]H;<00om]H;<3oiUh[@Go
/XRY1Oo1Uj`6olJM[@GobZ6^00?oc:>^olfT[oo=Y:l00_o=Y:l2olnW[`?od:R`0ooBZk001?oC[;7o
eZnaomJ_/OoF[k42ooooo`;of[BcEoooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00Cooooo000cooooo`;o0000F?oooolUojVmj003o`08TOl06ZOo02Vc00;o03Bi0_l=?;/2oai2^`04
oadm]ol^Ak[o;D>gobe3]`?o?dZf00?o@d^doeMF]Om]H;<00_m]H;<3oiUh[@Co/XRY0_noUJ`4ol6G
[003olNM[Oo6WJgoaYf]00?oaYf]00CobZ2^olZQ[_o:XJkobZ6^0_o<Xjh4olfT[`;ocjN_0_o@Z;04
om:[/0CoeZna0oooool00ooJ];?oooooooooo`1Fooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool01?ooool003Gooooo00?o0000ooooooooool0E_oooolUojVmj0;o01ZW00?o02Vco`0d
^Ol0;kD00_l=?;/01_lN@[_o7Cfgoadm]ol^Ak[o;D>gobm2]0;o?dZf0_m3Bk@3ofeP/`?oVGR]0onb
R:T3oknE[0?o`IN/0_o7WJd4olJM[@;obZ2^0oo:XJh2olbS[P?ocJB_1?o?Yjl00oo@Z;3odZ^`om:[
/002om:[/003oooooooF[k7oeZna05gooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`03ooooo`00=_ooool00ol0003oooooooooo`1FooooobGoZKgX00Oo01ZWo`0FYOl09:oo03Bio`0_
]Ol=?;_o33Ng00?o7Cfg0_l]@kL01?l_@[Co?dZfod=;]?m3Bk@2odi?/`03ofeP/onIN:goVGR]00;o
VGR]0_nbR:T3oknE[0?o`IN/0_o7WJd3olJM[@?obZ2^0_o:XJh4olbS[P03olfT[oo?YjoocjN_00?o
cjN_1?oBZk02ooooo`;oeZnaG_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?o
oooo000gooooo`03o`000?oooooooooo05Kooooo9OnY_NP00ol06ZOo01JUo`0T[`02o`0_]@;o33Ng
0_lM?KL2obe3]`;o;d:d00?o?dZfod=;]?m3Bk@00_m>Ck<01Om]H;?oVGR]oiUh[OnIN:go/XRY00Go
_iF/00?o`IN/olNM[Oo7WJd00_o7WJd2olJM[@CobZ2^00?obZ6^olbS[_o<Xjh00_o<Xjh00oo=Y:oo
cjN_olnW[`03olnW[`CodZ^`0oooool00ooF[k7oooooooooo`1Mooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool00oooool003Sooooo0_l0001Hooooob?oZKgX00Co00FBo`0FYOl05ZGo
02B_0_l0;kD01Ol<=kOo33>coadm]olM?KOo;D>g00?o;d:d0_m3Bk@3odi?/`;oVGR]00?oVgndoknE
[?noUJ`01?noUJ`00oo1Ujcoaif]olNM[@02olNM[@03olJM[Oo:X:kobZ2^00?obZ2^00?obZ6^olbS
[_o<Xjh00_o<Xjh5olnW[`;ooooo0_oBZk1Uooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool00oooool003[ooooo00?o0000ooooooooool0E_oooolSojVmj005o`01TOl05ZGo02B_o`0P
[?l0;kD00_l<=kL01?l<<k?o7Cfgoahk]?l]@kL2obm2]003oc=3/om3BkCoCTnc00;oCTnc0onKOk@6
oknE[0Goaif]1_o:X:h5olbS[P03ooooooo?YjoocjN_00;ocjN_0_ooool00ooBZk3oooooooooo`1T
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool003_ooooo00?o0000oooo
ooooool0E_oooolSojVmj006o`01TOl05ZGo02B_o`0P[?l0;kGo33Ng0_l<<k<2oahk]0?o;d:d00Co
<d>cod=;]?m>Ck?oCTnc1?nKOk@5oknE[003ojVmj?o7WJgoaif]00;oaif]00?oZKgXolZP[_o:X:h0
0oo:X:h01?ooooooc:>^olbS[_o<Xjh2ooooo`?ocjN_0oooool00ooBZk3oooooooooo`1Uooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool003cooooo00?o0000ooooooooool0
EOoooolTojVmj005o`01TOl04Z;o022/o`0P[?l0:k400ol<<k<01?lN>kCo8S^cobm2]?l_@[@2oc=3
/`?oCTnc0onKOk@4oknE[0;oZKgX0oo7WJd2ooooo`CobZ2^0_ooool3olbS[P;ooooo0_o?Yjm]oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool003gooooo0_l0001FooooobCo
ZKgX00Go006Ao`0BX_l08:co022/o`0[/@02o``c/`;o7S^d00Go8S^cobm2]?lc@k?o<d>cocY8]P02
odi?/`?oVgnd0onoUJ`3ooooo`?oaif]0_ooool3olZP[P?ooooo0_o<Xjh4ooooo`03olnW[ooooooo
oooo06_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`00?oooool00ol0
003oooooooooo`1Eooooob?oZKgX00Co01:Ro`0P[?l08:co02^a0_l<<k<01Ol@<k;o7S^dob8k/olR
>k?o;d:d00;o<d>c00?o>TRfodi?/onKOk@00onKOk@2oknE[0Cooooo00?oaif]ooooooooool00_oo
ool2olZP[PCooooo00?oc:>^ooooooooool0LOooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00;ooooo0010ooooo`03o`000?oooooooooo05Gooooo8_nY_NP01Ol007Wo01:Ro`0P[?l0
7Z[o02^a00;o33>c00Co43>bob8k/olR>k?o8S^c0_lc@k<00oljB;Koooooodi?/`03oi]o]003oknE
[?oooooooooo00?ooooo00?oaif]ooooooooool00_ooool00oo:X:koooooooooo`1hooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool00_ooool0047ooooo00?o0000ooooooooool0EOoo
oolRojVmj006o`00NOl04:7o022/o`0NZ_l0:Zoo33>c0_l@<k82ob8k/`03ob]1]_lc@k?o>TRf00;o
oooo0_nKOkB8ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool004;ooooo
00?o0000ooooooooool0EOoooolRojVmj003o`00TOl08:co01jZ00;o02Z_0_l@<k82ob8k/`03ob]1
]_oooooo<d>c08cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`00@ooo
ool2o`0005Kooooo8OnY_NP01_l007Wo012Qo`0NZ_l07Z[o02Z_o`8]/0;o43>b0_lR>k>?ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool004Gooooo00?o0000ooooooooool0
E?oooolPojVmj0;ooooo00So012Qo`0NZ_l0:Zoo02Z_o`8]/?l@<k;o63Rcob8k/i3ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`01ooooo`00A_ooool00ol0003oooooooooo`1Doooo
oaWoZKgX2Oooool01_l04:7o01jZo`0Z[ol2;K3ooooooaPh/i;ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`01ooooo`00Aoooool00ol0003oooooooooo`1DoooooaGoZKgX3_ooool0
0ol08:[o0Rf`ooooo`2Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00Oooool0
04Sooooo0_l0001Foooooa7oZKgXYoooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
007ooooo001:ooooo`03o`000?oooooooooo05Cooooo3OnY_NR[ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00Oooool004_ooooo00?o0000ooooooooool0E?ooool9ojVmj:kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00C?ooool00ol0003ooooooooo
o`1Cooooo`KoZKgX/_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo007ooooo001=
ooooo`;o0000E?ooool2ojVmj;Kooooo00?o0000ooooooooool01oooool1o`00007ooooo0Oooool0
04oooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`2fooooo`03o`000?oooooooooo
00Kooooo0Ol00001ooooo`7ooooo001@ooooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool0]_ooool00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00DOooool00ol0003ooooo
ooooo`1?ooooo`03o`000?oooooooooo0;Oooooo00?o0000ooooooooool01Oooool1o`00007ooooo
0Oooool005;ooooo0_l0001?ooooo`03o`000?oooooooooo0;Sooooo00?o0000ooooooooool01?oo
ool1o`00007ooooo0Oooool005Cooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`2i
ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo001Eooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool0^Oooool00ol0003oooooooooo`03ooooo`7o00000Oooool1oooo
o`00E_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool00oooool1o`00007ooooo001Gooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0
^oooool00ol0003oooooooooo`02ooooo`7o00000Oooool005Sooooo0_l00019ooooo`03o`000?oo
oooooooo0;cooooo00Go0000ooooooooooooooooo`000001ooooo`00F_ooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo0;cooooo00Go0000ooooooooooooooooo`000001ooooo`00Fooo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo0;gooooo00Co0000oooooooooooo0000
0Oooool005cooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`2nooooo`03o`000?oo
oooo0000007ooooo001Mooooo`;o0000A?ooool00ol0003oooooooooo`2nooooo`03o`000?oooooo
0000007ooooo001Oooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0_oooool1o`00
007ooooo0Ol00000063ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`30ooooo`;o
0000001Qooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0`?ooool3o`000000H_oo
ool2o`0003kooooo00?o0000ooooooooool0_?ooool4o`0000?ooooo001Tooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^?ooool4o`0000Oooooo001Uooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool0]Oooool3o`0000_ooooo001Vooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool0/Oooool4o`0000kooooo001Wooooo`;o0000>Oooool00ol0003ooooo
ooooo`2]ooooo`Co00004_ooool006Wooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`2Yooooo`Co00005_ooool006[ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2U
ooooo`Co00006_ooool006_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2Roooo
o`?o00007_ooool006cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`2Nooooo`Co
00008Oooool006gooooo0_l0000cooooo`03o`000?oooooooooo09[ooooo1?l0000Uooooo`00Kooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo09Kooooo1?l0000Yooooo`00L?ooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo09;ooooo1?l0000]ooooo`00LOooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo08oooooo0ol0000aooooo`00L_ooool2o`0002ko
oooo00?o0000ooooooooool0Roooool4o`0003Cooooo001dooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool0Qoooool4o`0003Sooooo001eooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0Poooool4o`0003cooooo001fooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0Ooooool4o`00043ooooo001gooooo`;o0000:Oooool00ol0003oooooooooo`1loooo
o`?o0000A?ooool007Wooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1hooooo`Co
0000Aoooool007[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1dooooo`Co0000
Boooool007_ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1`ooooo`Co0000Cooo
ool007cooooo0_l0000Tooooo`03o`000?oooooooooo06cooooo1?l0001Cooooo`00O_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo06Wooooo0ol0001Gooooo`00Ooooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo06Gooooo1?l0001Jooooo`00P?ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo067ooooo1?l0001Nooooo`00POooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo05gooooo1?l0001Rooooo`00P_ooool2o`0001kooooo00?o0000
ooooooooool0FOooool4o`0006Kooooo0024ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool0EOooool4o`0006[ooooo0025ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0D_ooool3o`0006kooooo0026ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
C_ooool4o`00077ooooo0027ooooo`;o00006Oooool00ol0003oooooooooo`1:ooooo`Co0000MOoo
ool008Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`16ooooo`Co0000NOooool0
08[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`12ooooo`Co0000OOooool008_o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0oooooo`?o0000POooool008cooooo
0_l0000Cooooo`03o`000?oooooooooo03cooooo1?l00024ooooo`00S_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo03Sooooo1?l00028ooooo`00Soooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo03Cooooo1?l0002<ooooo`00T?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo033ooooo1?l0002@ooooo`00TOooool2o`0000kooooo00?o0000oooooooo
ool0;Oooool3o`0009Cooooo002Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
:Oooool4o`0009Oooooo002Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09Ooo
ool4o`0009_ooooo002Eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool4
o`0009oooooo002Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool4o`00
0:?ooooo002Gooooo`;o00002?ooool00ol0003oooooooooo`0Jooooo`?o0000Yoooool009Wooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`Co0000Z_ooool009[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`Co0000[_ooool009_ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000/_ooool009cooooo0_l00003oooo
o`03o`000?oooooooooo00[ooooo1?l0002fooooo`00W_ooool01?l0003oooooooooool00009oooo
o`?o0000^_ooool009oooooo00?o0000ooooool000001Oooool4o`000;gooooo002Pooooo`;o0000
00?oooooo`000?l000000_l00031ooooo`00XOooool2o`000<Gooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0032ooooo`03o`000?oooooo
oooo0:?ooooo0032ooooo`03oa0@4?oMgMgooooo0:?ooooo0030ooooo`05olc<c?l@413o0000o`00
0?n7QhL0Xoooool00<3ooooo00Ko8B4QohN7Qolb<S;oZJVYodA4A?n7QhNRooooo`00`?ooool01_l0
003oooooofIVI_n7QhOogMgMoa0@4:;ooooo0030ooooo`06oa0@4?oMgMgoMgMgogMgMooooooo0000
X_ooool00<3ooooo00KoZJVYodA4A?nHV9SoA4A4oiRHV?l@412Rooooo`00`Oooool01OnHV9So0000
o`000?l@413oc<c<0:;ooooo0032ooooo`03okZj^_lb<S;ooooo0:?ooooo0033ooooo`03o`000?oo
oooooooo0:;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {0, 0, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "The solution is apparently well behaved throughout the domain of interest. \
 However, closer examination shows that it is not particularly accurate near \
the origin. In Fig. ",
  ButtonBox["6.2",
    ButtonData:>"Fig. 6.2",
    ButtonStyle->"Hyperlink"],
  ", we compare the Galerkin solution  to the exact solution found previously \
along the line ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] = 3  \[Pi]/2\)]],
  ", for the  cases ",
  Cell[BoxData[
      \(TraditionalForm\`P\_x = \(P\_y = 1\), 3, 5\)]],
  ". "
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 10 6 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
81.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
93.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.000 13.000 moveto
(\\220) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
123.000 13.000 moveto
(L) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
.5 Mabswid
[ .008 .02 ] 0 setdash
.02381 .60332 m
.06244 .54932 L
.10458 .49445 L
.14415 .44691 L
.18221 .40487 L
.22272 .36406 L
.26171 .32849 L
.30316 .29448 L
.34309 .26514 L
.3815 .23983 L
.42237 .21567 L
.46172 .19478 L
.49955 .17653 L
.53984 .15875 L
.57861 .14289 L
.61984 .12706 L
.65954 .11253 L
.69774 .09902 L
.73838 .08499 L
.77751 .07176 L
.81909 .05805 L
.85916 .04536 L
.89771 .0339 L
.93871 .02298 L
.97619 .01472 L
s
1 0 0 r
[ .05 .05 ] 0 setdash
.02381 .60332 m
.06244 .55935 L
.10458 .51235 L
.14415 .46952 L
.18221 .42985 L
.22272 .38955 L
.26171 .35287 L
.30316 .31637 L
.34309 .28376 L
.3815 .25484 L
.42237 .22675 L
.46172 .20228 L
.49955 .18109 L
.53984 .16091 L
.57861 .14366 L
.61984 .12741 L
.65954 .11352 L
.69774 .10148 L
.73838 .08971 L
.77751 .07897 L
.81909 .06766 L
.85916 .05632 L
.89771 .04442 L
.93871 .03004 L
.97619 .01472 L
s
0 g
[ ] 0 setdash
.02476 .59454 m
.0294 .57581 L
.03373 .56318 L
.04355 .54015 L
.06336 .50388 L
.10545 .4453 L
.14441 .40207 L
.18581 .36292 L
.2257 .32986 L
.26408 .30133 L
.3049 .27381 L
.34421 .24959 L
.38201 .22809 L
.42226 .20684 L
.46099 .18781 L
.50217 .1689 L
.54184 .15184 L
.58 .13639 L
.6206 .12087 L
.65969 .10675 L
.70123 .09254 L
.74126 .07956 L
.77977 .06767 L
.82073 .05562 L
.86018 .04456 L
.89812 .03438 L
.9385 .024 L
.97619 .01472 L
s
0 0 1 r
[ .05 .05 .01 .05 ] 0 setdash
.02381 .60332 m
.06244 .54262 L
.10458 .48231 L
.14415 .43181 L
.18221 .38887 L
.22272 .34886 L
.26171 .3153 L
.30316 .28414 L
.34309 .25771 L
.3815 .23487 L
.42237 .21269 L
.46172 .1929 L
.49955 .17497 L
.53984 .15686 L
.57861 .1403 L
.61984 .12362 L
.65954 .10849 L
.69774 .09484 L
.73838 .08127 L
.77751 .06907 L
.81909 .05685 L
.85916 .04557 L
.89771 .035 L
.93871 .02407 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00F_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0;Oooool4o`000003oa0@4?oooooooooo01So
oooo001Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00Tooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool09?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40;oooool00ol0003oooooooooo`0Jooooo`00F_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002Gooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000;oooool00ol0003oooooooooo`0Jooooo`00F_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo00009_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0Uooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b02oooooo00?o0000ooooooooool06_ooool005[ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`09Oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00_ooooo`03o`000?oooooooooo01[ooooo001Jooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000Vooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@02oooooo00?o0000
ooooooooool06_ooool005[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41009?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
9_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000_ooooo`03o`000?oooooo
oooo01[ooooo001Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;Oooool00omEEEGoIVIVo`00
000Looooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0ooooool`ooooo`03oa0@4?l0003o000000?o
00001Oooool002_ooooo00?o0000ooooooooool0oooooolbooooo`03o`000?oooooooooo00Kooooo
000[ooooo`03o`000?oooooooooo0?oooooo<_ooool00ol0003oooooooooo`06ooooo`009?oooooo
o`0002Ko00000ol00?l7o`0000cooooo00?o0000ooooooooool01_ooool002_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`03ooooo`03o`3o0?l00?oo003o00?o003o00?oo`00oooo
ool000004oooool00ol0003o<S8bomgMg@06ooooo`00:oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo02cooooo0ol00?l00ol0003oo`00ool00004ooooo`03o`000?oooooooooo013o
oooo0_l000001?nYZJWo8B4Qo`000?lQ8B44ooooo`00:oooool00ol0003oooooooooo`3oooooo`ko
oooo0_l0o`000ooooooo0000o`000002o`0000;oo`009?ooool002_ooooo00?o0000ooooooooool0
ooooool=ooooo`Co000000?oooooool00?oo00009oooool002_ooooo00?o0000ooooooooool0oooo
ool9ooooo`Co00001?ooool00ooo003oooooooooo`0Wooooo`00:oooool00ol0003oooooooooo`3o
ooooo`Cooooo0_l00?l3o`0003;ooooo000[ooooo`03o`000?oooooooooo0?oooooo0Oooool01?l0
003o003oo`00ool0000fooooo`00:oooool00ol0003oooooooooo`3looooo`Co0000>_ooool002_o
oooo0_l0003iooooo`Co000000?o0?l0ooooooooool0>oooool002_ooooo00?o0000ooooooooool0
m?ooool4o`0000Sooooo0ooo000gooooo`00:oooool00ol0003oooooooooo`3`ooooo`;o00000_l0
0?l00ol0o`3oooooooooo`05ooooo`Coo`00>_ooool002_ooooo00?o0000ooooooooool0kOooool2
o`0000?o003o1oooool3ool003kooooo000[ooooo`03o`000?oooooooooo0>[ooooo0_l00003o`00
o`Oooooo0ooo0011ooooo`00:oooool00ol0003oooooooooo`3Wooooo`Go003o00?o0?l0oooooooo
ool01Oooool2ool004Cooooo000[ooooo`03o`000?oooooooooo0>Cooooo0ol00?mCooooo`00:ooo
ool00ol0003oooooooooo`3Pooooo`Co00000_l0o`1Dooooo`00:oooool00ol0003oooooooooo`3L
ooooo`Co0000F_ooool002_ooooo0_l0003Iooooo`Co00000_l0o`05ooooo`?oo`00E?ooool002_o
oooo00?o0000ooooooooool0eOooool3o`0000?ooooo00Co0?l0oooooooooooooooo1?oo001Goooo
o`00:oooool00ol0003oooooooooo`3Booooo`;o00000ol00?l4ooooo`Coo`00Foooool002_ooooo
00?o0000ooooooooool0coooool3o`000004ooooool00?oo0?l0o`3o00;ooooo0ooo001Oooooo`00
:oooool00ol0003oooooooooo`3<ooooo`?o00001?ooool00ol0o`3oooooooooo`02ool006;ooooo
000[ooooo`03o`000?oooooooooo0<Wooooo0ol0001^ooooo`00:oooool00ol0003oooooooooo`36
ooooo`?o00000oooool2o`3o06cooooo000[ooooo`03o`000?oooooooooo0<Cooooo0_l00005oooo
o`03o`3o0?oooooooooo06cooooo000[ooooo`03o`000?oooooooooo0<;ooooo0ol00?l2ooooo`;o
o`00LOooool002_ooooo0_l00030ooooo`?o003o00?oooooo`3o0?oo00000_oo001cooooo`00:ooo
ool00ol0003oooooooooo`2looooo`?o003o0_ooool3ool007Kooooo000[ooooo`03o`000?oooooo
oooo0;Wooooo0ol00?l00ol0003o0?l0ool00002ool007Wooooo000[ooooo`03o`000?oooooooooo
0;Oooooo0_l00?l00ol0003oooooo`3o0002ool007cooooo000[ooooo`03o`000?oooooooooo0;Co
oooo0_l000001?l00?ooooooooooooooool2ool007kooooo000[ooooo`03o`000?oooooooooo0;7o
oooo0ol00002o`3o08Cooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo1Ol00006ooooo`03o`000?oooooooooo0:kooooo0ol00002ooooo`03o`3o0?oooooooooo08Co
oooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A006ooooo`03o`000?oooooooooo0:_ooooo0ol0002<ooooo`004?ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`000:Wooooo0_l00002oooo
o`;o0?l0Roooool0013ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
00Kooooo00?o0000ooooooooool0Y_ooool3o`000004oooooooo003oo`00o`3o08gooooo000@oooo
o`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo
oooo0:Cooooo0_l000001?oooooo003oo`00oooo002@ooooo`004?ooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Qooooo`?o000000Co
ooooo`00ool00?ooo`00T_ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`2Nooooo`?o00000_ooool00ol0o`3o
o`00ool0002Dooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c006ooooo`03o`000?oooooooooo09_ooooo0ol00003ooooo`?oo`00U_ooool002_o
oooo00?o0000ooooooooool0VOooool2o`0000?ooooo0ooo002Iooooo`00:oooool00ol0003ooooo
ooooo`2Fooooo`?o00000oooool00ol0o`3oo`00o`3o002Kooooo`00:oooool00ol0003ooooooooo
o`2Dooooo`;o0000Y?ooool002_ooooo0_l0002Cooooo`;o00000_ooool2o`00oj;ooooo000[oooo
o`03o`000?oooooooooo08oooooo0ol000001Ooooooo003oo`00ool00?oo0?l00:?ooooo000[oooo
o`03o`000?oooooooooo08gooooo0_l00002ooooo`;o003o00?oooooo`3o0?ooool0Y?ooool002_o
oooo00?o0000ooooooooool0Roooool2o`000004ooooool00?oo003oo`00ojWooooo000[ooooo`03
o`000?oooooooooo08Wooooo0_l000001?oooooo003oo`00ool0o`2[ooooo`00:oooool00ol0003o
ooooooooo`26ooooo`?o00000_ooool01?l00?oo0?l0o`3o0?ooool2ool00:Wooooo000[ooooo`03
o`000?oooooooooo08Cooooo0_l00004ooooo`03o`00ooooooooo`0000;oo`00Zoooool002_ooooo
00?o0000ooooooooool0P_ooool2o`0000Kooooo0_oo002^ooooo`00:oooool00ol0003ooooooooo
o`20ooooo`;o00001?ooool2o`3o0003oooooooo003ooooo0:oooooo000[ooooo`;o0000Ooooool2
o`0000Cooooo0_l0o`000oooooooo`00ool0002aooooo`00:oooool00ol0003oooooooooo`1loooo
o`;o00001oooool2ool00;?ooooo000[ooooo`03o`000?oooooooooo07_ooooo00?o0000oooooooo
ool01_ooool00ooo003oooooooooo`2cooooo`00:oooool00ol0003oooooooooo`1iooooo`;o0000
0oooool2o`3o00?ooooo00?oo`00ooooooooool0]?ooool002_ooooo00?o0000ooooooooool0Mooo
ool2o`0000;ooooo0_l00?l00ol0o`3oooooooooo`2jooooo`00:oooool00ol0003oooooooooo`1e
ooooo`;o00000_ooool2o`00okoooooo000[ooooo`03o`000?oooooooooo07?ooooo0_l00035oooo
o`00:oooool00ol0003oooooooooo`1aooooo`;o00001?ooool2o`3o0<7ooooo000[ooooo`03o`00
0?oooooooooo06oooooo0_l00004ooooo`;o0?l0`oooool002_ooooo0_l0001^ooooo`;o0000booo
ool002_ooooo00?o0000ooooooooool0Joooool2o`000<gooooo000[ooooo`03o`000?oooooooooo
06Wooooo0_l00004ooooo`;o0?l01?ooool2ool00<?ooooo000[ooooo`03o`000?oooooooooo06Oo
oooo0_l00002ooooo`;o003o00?oooooo`3o0?ooool01?ooool00ooo003oooooooooo`33ooooo`00
:oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooo003o00;o003o1oooool2ool00<Kooooo
000[ooooo`03o`000?oooooooooo06Cooooo0_l000000ooooooo003oooooo`07ooooo`;oo`00b?oo
ool002_ooooo00?o0000ooooooooool0H_ooool2o`000003ooooool00?oo003o00;ooooo00?o0?l0
ooooooooool00oooool00ooo003oooooooooo`38ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`1Q
ooooo`04o`000?ooooooooooo`00o`?ooooo00?o0?l0ooooooooool00_ooool2ool00<_ooooo000@
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Oooooo`;o00000_ooool01Ol00?oooooooooooooooooo0?l000?ooooo
0_oo003=ooooo`004?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000
GOooool2o`0000;ooooo0_l00?l7ooooo`03ool00?oooooooooo0<gooooo000@ooooo`05o`000?oo
ooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo05_o
oooo0_l00003ooooo`03o`00oooooooooooo00Kooooo00?oo`00ooooooooool0c_ooool0013ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool0F_ooool00ol0003oooooooooo`02ooooo`04o`00oooooooo0?l0o`3o00Kooooo00?oo`00
ooooooooool0c_ooool0013ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0F?ooool2o`0000Kooooo00?o0?l0ooooooooool0eoooool0
013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000
ooooooooool0E_ooool2o`000>;ooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0h_ooool0
02_ooooo00?o0000ooooooooool0Doooool2o`000>Gooooo000[ooooo`03o`000?oooooooooo057o
oooo0_l00007ooooo`;o0?l0g_ooool002_ooooo00?o0000ooooooooool0D?ooool00ol0003ooooo
ooooo`06ooooo`03o`3o0?oooooooooo0=kooooo000[ooooo`;o0000Coooool2o`000>[ooooo000[
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`3U
ooooo`00:oooool00ol0003oooooooooo`1;ooooo`;o00001?ooool00ol00?ooooooooooo`08oooo
o`;oo`00g?ooool002_ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`03ooooo`03
o`00oooooooooooo00;o0?l01_ooool00ooo003oooooooooo`3Looooo`00:oooool00ol0003ooooo
ooooo`18ooooo`;o00002?ooool00ol0o`3oooooooooo`05ooooo`03ool00?oooooooooo0=gooooo
000[ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool03oooool00ooo003ooooooooo
o`3Nooooo`00:oooool00ol0003oooooooooo`15ooooo`;o00004?ooool2ool00>7ooooo000[oooo
o`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`3Qoooo
o`00:oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Oooooo00?o0?l0oooooooo
ool01Oooool00ooo003oooooooooo`3Rooooo`00:oooool2o`0004;ooooo0_l00009ooooo`03o`3o
0?oooooooooo00Gooooo00?oo`00ooooooooool0hoooool002_ooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0>Cooooo000[ooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool03oooool2ool00>Oooooo000[ooooo`03o`000?oooooooooo
03gooooo0_l00004ooooo`;o003omOooool002_ooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`03ooooo`03o`00oooooooooooo00;ooooo00?o0?l0ooooooooool0l?ooool002_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00;ooooo
00?o0?l0ooooooooool0lOooool002_ooooo00?o0000ooooooooool0>Oooool2o`0000Gooooo00?o
003oooooooooool00_ooool00ol0o`3oooooooooo`3booooo`00:oooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo00?ooooo0_l00?ojooooo`00:oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00?ooooo00?o003oooooooooool0n_ooool002_ooooo0_l0000gooooo`03
o`000?oooooooooo00?ooooo00?o003oooooooooool0noooool002_ooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o0?l0ooooooooool0
m_ooool002_ooooo00?o0000ooooooooool0<oooool2o`0000Gooooo00?o003oooooooooool00ooo
ool00ol0o`3oooooooooo`3gooooo`00:oooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo00Cooooo00?o003oooooooooool00oooool00ol0o`3oooooooooo`04ooooo`03ool00?oooooo
oooo0?7ooooo000[ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01?ooool00ol0
0?ooooooooooo`0:ooooo`03ool00?oooooooooo0?;ooooo000[ooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`3cooooo`004?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool0m?ooool0013o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`08ooooo`;o0?l01oooool0
0ooo003oooooooooo`3eooooo`004?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02Ooo
ool00ol0o`3oooooooooo`05ooooo`03ool00?oooooooooo0?Kooooo000@ooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000/ooooo`03o`00
0?oooooooooo017ooooo00?oo`00ooooooooool0moooool0013ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo017ooooo00?oo`00ooooooooool0n?ooool0013ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0Aooooo`03ool00?oooooooooo0?Wooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool04Oooool00ooo003oooooooooo`3jooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
00Wooooo00?o0?l0ooooooooool01Oooool00ooo003oooooooooo`3kooooo`00:oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool00_ooool00ol0o`3o
ooooooooo`05ooooo`03ool00?oooooooooo0?cooooo000[ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool01?ooool00ol00?ooooooooooo`3oooooo`_ooooo000[ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`3oooooo`_ooooo000[
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`3o
ooooo`cooooo000[ooooo`;o00009?ooool00ol0003oooooooooo`3ooooooaGooooo000[ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool02Oooool00ol0o`3oooooooooo`3oooooo`[o
oooo000[ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02?ooool00ol0o`3ooooo
ooooo`3oooooo`_ooooo000[ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0oooo
oolGooooo`00:oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0?oooooo6?ooool0
02_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`3ooooooaWooooo000[ooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`3oooooo`So
oooo000[ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02Oooool00ol0o`3ooooo
ooooo`03ooooo`03ool00?oooooooooo0?oooooo2Oooool002_ooooo0_l0000Mooooo`03o`000?oo
oooooooo00Wooooo00?o0?l0ooooooooool00oooool00ooo003oooooooooo`3oooooo`[ooooo000[
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02Oooool00ol0o`3oooooooooo`03
ooooo`03ool00?oooooooooo0?oooooo2oooool002_ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`05ooooo`03o`00oooooooooooo00Sooooo00?oo`00ooooooooool0ooooool;oooo
o`00:oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Kooooo00?o003ooooooooo
ool01oooool00ooo003oooooooooo`3oooooo`cooooo000[ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03ool00?oooooooooo0?oooooo
3Oooool002_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`06ooooo`04o`00oooo
ooooooooo`3o00Kooooo00?oo`00ooooooooool0ooooool>ooooo`00:oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo00Kooooo00Go003oooooooooooooooooo`3o0005ooooo`03ool0
0?oooooooooo0?oooooo3oooool002_ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`05ooooo`03o`00oooooooooooo00;o0?l01Oooool00ooo003oooooooooo`3ooooooa3ooooo000[
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`07
ooooo`03ool00?oooooooooo0?oooooo4Oooool002_ooooo0_l0000Eooooo`03o`000?oooooooooo
00Kooooo00?o003oooooooooool01_ooool00ooo003oooooooooo`3ooooooa;ooooo000[ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`3ooooooaco
oooo000[ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool00ol00?oooooo
ooooo`3ooooooagooooo000[ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01Ooo
ool01?l00?ooooooooooool0o`3ooooooagooooo000[ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool01Oooool01?l00?ooooooooooool0o`3ooooooakooooo000[ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`3oooooob3ooooo000[
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0oooooolXooooo`004?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0?oooooo:Oooool0013ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`3oooooob[ooooo000@ooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000>ooooo`03
o`000?oooooooooo00Oooooo00?o0?l0ooooooooool0oooooolPooooo`004?ooool01Ol0003ooooo
oooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool01oooool00ol0o`3oooooooooo`3oooooob7ooooo000@ooooo`05
o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`3o0?oooooooooo00;ooooo00?oo`00
ooooooooool0oooooolMooooo`004?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@
okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ooo003oooooooooo`3ooooooagooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0<ooooo`03ool00?oooooooooo0?oooooo7_ooool0013ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00cooooo00?oo`00ooooooooool0oooooolOooooo`00:oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0oooooolPooooo`00:ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00Go0?l0oooooooooooooooo
ool0003oooooob?ooooo000[ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?oo
ool01?l00?ooooooooooool0o`03ooooo`03ool00?oooooooooo0?oooooo8_ooool002_ooooo0_l0
0009ooooo`03o`000?oooooooooo00Cooooo00?o003oooooool0o`000oooool00ooo003ooooooooo
o`3oooooob?ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool0
0ol00?ooooooooooo`03ooooo`03ool00?oooooooooo0?oooooo9?ooool002_ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?oo`00oooo
ooooool0oooooolUooooo`00:oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wo
oooo00?oo`00ooooooooool0oooooolVooooo`00:oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00Co0?l0ooooooooooooo`00oooooolYooooo`00:oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0?l0ooooooooool0ooooool[ooooo`00:ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0?l0ooooooooool0oooo
ool/ooooo`00:oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo=?ooool0
02_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooocGooooo000[ooooo`;o
00001?ooool00ol0003oooooooooo`3oooooocGooooo000[ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0oooooolfooooo`00:oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0?l0ooooooooool0ooooool`ooooo`00:oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0?l0ooooooooool0ooooool`ooooo`00:oooool01Ol0003ooooooooooooo
oooo000000Gooooo00?o0?l0ooooooooool0oooooolaooooo`00:oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o003oooooooooool0oooooolcooooo`00:oooool01?l0003oooooooooool0
0004ooooo`03o`00ooooooooo`000?oooooo<oooool002_ooooo00Co0000oooooooooooo00000ooo
ool01?l00?oooooooooooooo003ooooooc?ooooo000[ooooo`03o`000?oooooo000000?ooooo00Co
003oooooooooooooo`00ooooooldooooo`00:oooool3o`0000?ooooo00?o003oo`3o0?oo0000oooo
ooleooooo`00:oooool00ol0003oooooo`000002ooooo`03o`00ool0o`3oo`000?oooooo=_ooool0
02_ooooo00?o0000ooooool000000_ooool00ol00?ooo`00ooooo`3oooooocKooooo000[ooooo`06
o`000?oooooo0000ooooool00?ooo`00oooooolhooooo`00:oooool2o`000004ooooool00?oooooo
ool00?oooooo>?ooool002_ooooo0_l000000ooooooo003oool0003oooooocWooooo000Qooooo`Co
000000?o410@ooooooooool00oooool2o`000003o`00oooo003ooooo0?oooooo>Oooool002?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooo`00o`3ooooooc_ooooo000Sooooo`03o`000?oo
oooooooo00Gooooo00?o0000o`00ooooool0oooooolkooooo`008oooool00ol0003oooooooooo`05
ooooo`03o`00ool0003o00000?oooooo>oooool002?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooooc_ooooo000Sooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolkooooo`008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
>oooool0027ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3ooooooc_ooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0005
ooooo`03o`000?oooooooooo00Oooooo00?oMgMgofIVI_ooool02Oooool00ol0003o^[Zjooooo`0`
ooooo`03ofIVI_mgMgOooooo0?oooooo6?ooool000Gooooo00?o410@omgMgOooool01_ooool00ooM
gMgo410@onk^kP0:ooooo`;o<S8b8oooool00olQ8B7ogMgMooooo`0;ooooo`03onk^k_l@413ogMgM
0?oooooo6?ooool000?ooooo00Goc<c<oa0@4?l0003o0000ohN7Q`06ooooo`04oeEEEOnHV9Sooooo
oa0@40Go00001?ooool00on7QhOo0000okZj^P03ooooo`06onk^k_lb<S;o0000o`000?mEEEGok^k^
2Oooool01OnHV9So410@o`000?lb<S;oc<c<00;ooooo00?oEEEEojVYZOooool00_ooool01_nj^[[o
A4A4ooooooooooooV9RHoeEEE@Gooooo1Ol00003ooooo`03ohN7QomVIVKooooo0?oooooo5oooool0
00?ooooo00Ko8B4QohN7Qolb<S;oZJVYodA4A?n7QhL5ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool00oo<c<co0000oa0@4003ooooo`08oeEEEOmgMgOoooooonk^k_n7QhOo
8B4Qonk^k_ooool6o`000006ooooool@413o^[ZjoooooomgMgOo<S8b0oooool01_mEEEGoV9RHoooo
oooooooo410@okZj^P?ooooo00?o0000omgMgOooool00oooool01OnHV9So8B4Qonk^k_ooooooA4A4
00?ooooo00?ok^k^o`000?ooool0oooooolGooooo`000oooool01_l0003oooooofIVI_n7QhOogMgM
oa0@40Gooooo00?o<S8booooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00;ooooo00?oQhN7ogMgMoooool02oooool00ol0003oooooooooo`02ooooo`04oa0@4?oMgMgo
ooooo`0000Cooooo0_mgMgL5ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool0oooo
oolFooooo`000oooool01_l@413ogMgMogMgMomgMgOoooooo`0000Gooooo00?o<S8booooooooool0
0_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o8B4Qooooool00000
1Ol00004ooooo`03ojVYZOl@413ooooo00?ooooo00CoQhN7ofIVI_oooooo00001?ooool00oo^k^ko
410@onk^kP05ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00?o0000ooooooooool0oooooolFooooo`00
0oooool01_nYZJWoA4A4oiRHV?m4A4CoV9RHoa0@40Gooooo00?o0000onk^k_ooool00_ooool00ol0
003o<S8bomgMg@0;ooooo`03ob4Q8Ol0003o000000Co00002_ooool00ol@413o0000okZj^P04oooo
o`04omgMgOl@413oooooo`0000Gooooo00?oEEEEoiRHV?ooool01Oooool00omgMgOoIVIVooooo`02
ooooo`03onk^k_l0003ooooo0?oooooo5oooool000Cooooo00GoV9RHo`000?l0003o410@olc<c005
ooooo`04oeEEEOmgMgOoooooooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q2Oooool00onHV9SoQhN7
ooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o^[Zjob4Q8Oooool00_ooool7o`0000?ooooo
00?ogMgMoa0@4?ooool01_ooool01_l0003oooooooooooooooooMgMgoeEEEOoooooo6?ooool000Go
oooo00?o^[Zjoc8b<_ooool01_ooool00ooMgMgo410@onk^kP0Aooooo`06oc8b<_n7QhOok^k^oooo
oon7QhOo<S8b2?ooool01Ol@413oV9RHoooooonj^[[o000000kooooo00WoEEEEoiRHV?oooooooooo
o`000?nj^[[ooooooiRHV?l@41000_ooool00oo^k^ko410@omgMg@3ooooooaSooooo0006ooooo`03
o`000?oooooooooo00Kooooo00?oMgMgofIVI_ooool04?ooool01_o^k^koMgMgo`000?l0003o<S8b
olc<c0Sooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0>ooooo`09okZj^_m4A4CooooooooooonHV9So
410@o`000?lQ8B7oc<c<00;ooooo00?oIVIVogMgMoooool0oooooolHooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{73.5625, 302.938}, {198.5, 57.1875}} -> {-0.552137, \
0.4152, 0.0043491, 0.007037}}],

Cell[TextData[{
  "Fig. 6.2 Potential along ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] = 3  \[Pi]/2\)]],
  "for exact solution (solid) and Galerkin solutions with ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(P\_x\), "=", 
            RowBox[{\(P\_y\), "=", 
              StyleBox[\(1\ \((dashed)\)\),
                FontColor->RGBColor[1, 0, 0]]}]}], ",", 
          StyleBox[\(3\ \((dotted)\)\),
            FontColor->RGBColor[0, 1, 0]], ",", 
          StyleBox[\(5\ \((dot - dashed)\)\),
            FontColor->RGBColor[0, 0, 1]]}], TraditionalForm]]],
  ". "
}], "Caption",
  CellTags->"Fig. 6.2"],

Cell[TextData[{
  "\tThe solid curve is the analytic  solution, and the dashed, dotted, and \
dot-dashed curves are Galerkin solutions in order of increasing accuracy. The \
 Galerkin solutions do not converge very rapidly near the origin,  because of \
the singularity in the radial electric field caused by the cusp point. This \
can be seen directly in the  plot (Fig. ",
  ButtonBox["6.3",
    ButtonData:>"Fig. 6.3",
    ButtonStyle->"Hyperlink"],
  ")  of the radial electric field along the same line, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] = 3\ \[Pi]/2\)]],
  ":"
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.187867 0.10856 [
[.21429 .17537 -9 -9 ]
[.21429 .17537 9 0 ]
[.40476 .17537 -9 -9 ]
[.40476 .17537 9 0 ]
[.59524 .17537 -9 -9 ]
[.59524 .17537 9 0 ]
[.78571 .17537 -9 -9 ]
[.78571 .17537 9 0 ]
[.97619 .17537 -3 -9 ]
[.97619 .17537 3 0 ]
[1.025 .18787 0 -6 ]
[1.025 .18787 10 6 ]
[.01131 .07931 -12 -4.5 ]
[.01131 .07931 0 4.5 ]
[.01131 .29643 -6 -4.5 ]
[.01131 .29643 0 4.5 ]
[.01131 .40499 -6 -4.5 ]
[.01131 .40499 0 4.5 ]
[.01131 .51355 -6 -4.5 ]
[.01131 .51355 0 4.5 ]
[.02381 .64303 -37.625 0 ]
[.02381 .64303 37.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .18787 m
.21429 .19412 L
s
[(0.2)] .21429 .17537 0 1 Mshowa
.40476 .18787 m
.40476 .19412 L
s
[(0.4)] .40476 .17537 0 1 Mshowa
.59524 .18787 m
.59524 .19412 L
s
[(0.6)] .59524 .17537 0 1 Mshowa
.78571 .18787 m
.78571 .19412 L
s
[(0.8)] .78571 .17537 0 1 Mshowa
.97619 .18787 m
.97619 .19412 L
s
[(1)] .97619 .17537 0 1 Mshowa
.125 Mabswid
.07143 .18787 m
.07143 .19162 L
s
.11905 .18787 m
.11905 .19162 L
s
.16667 .18787 m
.16667 .19162 L
s
.2619 .18787 m
.2619 .19162 L
s
.30952 .18787 m
.30952 .19162 L
s
.35714 .18787 m
.35714 .19162 L
s
.45238 .18787 m
.45238 .19162 L
s
.5 .18787 m
.5 .19162 L
s
.54762 .18787 m
.54762 .19162 L
s
.64286 .18787 m
.64286 .19162 L
s
.69048 .18787 m
.69048 .19162 L
s
.7381 .18787 m
.7381 .19162 L
s
.83333 .18787 m
.83333 .19162 L
s
.88095 .18787 m
.88095 .19162 L
s
.92857 .18787 m
.92857 .19162 L
s
.25 Mabswid
0 .18787 m
1 .18787 L
s
gsave
1.025 .18787 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07931 m
.03006 .07931 L
s
[(-1)] .01131 .07931 1 0 Mshowa
.02381 .29643 m
.03006 .29643 L
s
[(1)] .01131 .29643 1 0 Mshowa
.02381 .40499 m
.03006 .40499 L
s
[(2)] .01131 .40499 1 0 Mshowa
.02381 .51355 m
.03006 .51355 L
s
[(3)] .01131 .51355 1 0 Mshowa
.125 Mabswid
.02381 .10102 m
.02756 .10102 L
s
.02381 .12273 m
.02756 .12273 L
s
.02381 .14444 m
.02756 .14444 L
s
.02381 .16615 m
.02756 .16615 L
s
.02381 .20958 m
.02756 .20958 L
s
.02381 .23129 m
.02756 .23129 L
s
.02381 .253 m
.02756 .253 L
s
.02381 .27472 m
.02756 .27472 L
s
.02381 .31814 m
.02756 .31814 L
s
.02381 .33985 m
.02756 .33985 L
s
.02381 .36156 m
.02756 .36156 L
s
.02381 .38328 m
.02756 .38328 L
s
.02381 .4267 m
.02756 .4267 L
s
.02381 .44841 m
.02756 .44841 L
s
.02381 .47012 m
.02756 .47012 L
s
.02381 .49184 m
.02756 .49184 L
s
.02381 .53526 m
.02756 .53526 L
s
.02381 .55697 m
.02756 .55697 L
s
.02381 .57868 m
.02756 .57868 L
s
.02381 .6004 m
.02756 .6004 L
s
.02381 .05759 m
.02756 .05759 L
s
.02381 .03588 m
.02756 .03588 L
s
.02381 .01417 m
.02756 .01417 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -98.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
74.250 13.000 moveto
(H) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
86.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
92.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
98.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
104.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(\\220) show
122.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
128.250 13.000 moveto
(L) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ .05 .05 ] 0 setdash
.02381 .389 m
.04262 .38787 L
.06244 .38619 L
.08255 .38401 L
.10458 .3811 L
.14509 .37447 L
.18408 .36672 L
.22553 .35723 L
.26546 .34713 L
.30387 .33673 L
.34474 .32518 L
.38409 .3138 L
.42192 .30283 L
.46221 .29136 L
.50098 .28072 L
.54221 .2701 L
.58192 .26077 L
.62011 .25285 L
.66075 .24578 L
.69988 .24052 L
.7213 .23837 L
.7311 .23757 L
.74147 .23686 L
.75104 .23632 L
.75611 .23608 L
.76154 .23587 L
.76654 .2357 L
.7711 .23559 L
.77329 .23554 L
.77568 .2355 L
.77794 .23547 L
.78002 .23544 L
.78113 .23543 L
.78235 .23542 L
.78357 .23542 L
.78486 .23541 L
.786 .23541 L
.78722 .23541 L
.78837 .23541 L
.78942 .23541 L
.79006 .23541 L
.79075 .23542 L
.79198 .23543 L
.7933 .23544 L
.79475 .23545 L
.79736 .23549 L
.79979 .23553 L
.80508 .23565 L
.80992 .2358 L
.8208 .23627 L
Mistroke
.83067 .23685 L
.83982 .23753 L
.86056 .2396 L
.88112 .24237 L
.89974 .24555 L
.93986 .25461 L
.97619 .26561 L
Mfstroke
0 1 0 r
[ .008 .02 ] 0 setdash
.02381 .44105 m
.06244 .4255 L
.10458 .40756 L
.14415 .39024 L
.18221 .37357 L
.22272 .35619 L
.26171 .34014 L
.30316 .32411 L
.34309 .30991 L
.3815 .29759 L
.42237 .28604 L
.46172 .27652 L
.49955 .26885 L
.53984 .26226 L
.57861 .25735 L
.59832 .25535 L
.61984 .25351 L
.65954 .25093 L
.67922 .24997 L
.70019 .24912 L
.74177 .24775 L
.78184 .24644 L
.82039 .24473 L
.84033 .24351 L
.86139 .24185 L
.89936 .2376 L
.91887 .23463 L
.93979 .23072 L
.97619 .22178 L
s
0 0 1 r
[ .05 .05 .01 .05 ] 0 setdash
.02381 .47413 m
.06244 .45272 L
.10458 .42542 L
.14415 .39866 L
.18221 .37373 L
.22272 .34948 L
.26171 .32917 L
.30316 .31128 L
.34309 .29761 L
.3815 .28745 L
.42237 .27931 L
.46172 .27341 L
.49955 .26891 L
.53984 .26479 L
.57861 .26101 L
.61984 .25688 L
.65954 .25269 L
.69774 .24859 L
.73838 .24443 L
.77751 .24097 L
.79749 .23952 L
.81909 .23823 L
.83996 .23725 L
.85916 .23656 L
.87958 .23597 L
.89865 .23544 L
.91697 .23481 L
.92725 .23432 L
.93662 .23376 L
.94646 .23301 L
.95557 .23211 L
.96557 .23086 L
.97619 .22916 L
s
0 g
[ ] 0 setdash
.02499 0 m
.02499 .61803 L
s
.03665 .61803 m
.03756 .60715 L
.04262 .5635 L
.04755 .53349 L
.05285 .50901 L
.06244 .47654 L
.07373 .44932 L
.08445 .42973 L
.10458 .4024 L
.12439 .38259 L
.14277 .36802 L
.1819 .34444 L
.22348 .32606 L
.26355 .3123 L
.3021 .3015 L
.34311 .29189 L
.38259 .28403 L
.42056 .27745 L
.46099 .27132 L
.4999 .2661 L
.54126 .26115 L
.5811 .25689 L
.61943 .25318 L
.66022 .2496 L
.69948 .24645 L
.73723 .24368 L
.77744 .24096 L
.81612 .23855 L
.85726 .23618 L
.89689 .23407 L
.935 .23218 L
.97556 .23031 L
.97619 .23028 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00;oooool00ol0003oooooooooo`3oooooocOooooo000_ooooo`03o`00
0?oooooooooo0?oooooo=oooool002oooooo00?o0000ooooooooool0oooooolgooooo`00;oooool0
0ol0003oooooooooo`3oooooocOooooo000_ooooo`;o0000oooooolhooooo`00;oooool00ol0003o
ooooooooo`3oooooocOooooo000_ooooo`03o`000?oooooooooo0?oooooo=oooool002oooooo00?o
0000ooooooooool0oooooolgooooo`00;oooool00ol0003oooooooooo`3oooooocOooooo000_oooo
o`03o`000?oooooooooo0?oooooo=oooool002oooooo00?o0000ooooooooool0oooooolgooooo`00
;oooool2o`000?oooooo>?ooool002oooooo00?o0000ooooooooool0oooooolgooooo`00;oooool0
0ol0003oooooooooo`3oooooocOooooo000_ooooo`03o`000?oooooooooo0?oooooo=oooool002oo
oooo00?o0000ooooooooool0oooooolgooooo`00;oooool00ol0003oooooooooo`3oooooocOooooo
000_ooooo`;o0000oooooolhooooo`00;oooool00ol0003oooooooooo`3oooooocOooooo000_oooo
o`03o`000?oooooooooo0?oooooo=oooool002oooooo00?o0000ooooooooool0oooooolgooooo`00
9Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolgooooo`009ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=oooool001cooooo1_l00005
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolgooooo`009oooool00ol0
003oooooooooo`05ooooo`;o0000oooooolhooooo`009oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo=oooool002Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3oooooocOooooo000Wooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooo
oolgooooo`009Oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0?oooooo=oooool0
02oooooo00?o0000ooooooooool0oooooolgooooo`00;oooool2o`000?oooooo>?ooool002oooooo
00?o0000ooooooooool0oooooolgooooo`00;oooool00ol0003oooooooooo`3oooooocOooooo000_
ooooo`03o`000?oooooooooo0?oooooo=oooool002oooooo00?o0000ooooooooool0oooooolgoooo
o`00;oooool00ol0003oooooooooo`3oooooocOooooo000_ooooo`03o`000?oooooooooo0?oooooo
=oooool002oooooo0_l0003oooooocSooooo000_ooooo`03o`000?oooooooooo0?oooooo=oooool0
02oooooo00?o0000ooooooooool0oooooolgooooo`00;oooool00ol0003oooooooooo`3oooooocOo
oooo000_ooooo`03o`000?oooooooooo0?oooooo=oooool002oooooo00?o0000ooooooooool0oooo
oolgooooo`00;oooool2o`000?oooooo>?ooool002oooooo00?o0000ooooooooool0:oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00008oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool08_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`09?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0;Oooool4
o`000003oa0@4?oooooooooo01Sooooo000_ooooo`03o`000?oooooooooo02_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A402?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Sooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0Toooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q
8@0_ooooo`03o`000?oooooooooo01[ooooo000_ooooo`03o`000?oooooooooo02_ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02Cooooo00Go410@oooooooooooooooo
oa0@400;ooooo`Go00009?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooo
ooooooooo`00000Tooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000002oooooo00?o0000ooooooooool06_ooool002oooooo00?o0000ooooooooool0:oooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h08oooool01Ol0003ooooooooo
oooooooo000000_ooooo00CoA4A4omgMgOoooooo00009Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Tooooo`05o`000?ooooooooooooooool000002ooo
ool01Olb<S;oV9RHoooooonHV9So<S8b02oooooo00?o0000ooooooooool06_ooool002oooooo00?o
0000ooooooooool0:oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00009Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Tooooo`05o`000?oo
ooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<02oooooo00?o0000oooooooo
ool06_ooool002oooooo00?o0000ooooooooool0:oooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool08Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<
c?l000009Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool09_ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400_ooooo`03o`00
0?oooooooooo01[ooooo000_ooooo`;o0000;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@400Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^
k^koA4A4o`00000Uooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00V
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000002oooooo
00?o0000ooooooooool06_ooool002oooooo00?o0000ooooooooool0:oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Sooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03Oooool00omgMgOo0000ooooo`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool0
1?o<c<coA4A4o`000?l@410Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@
o`000?l@413oZJVY02gooooo00?oEEEEofIVI_l000007?ooool002oooooo00?o0000ooooooooool0
oooooolgooooo`00;oooool00ol0003oooooooooo`3oooooocOooooo000_ooooo`03o`000?oooooo
oooo0?oooooo;?ooool00ol@413o0000o`000003o`0000Gooooo000_ooooo`03o`000?oooooooooo
0?oooooo;_ooool00ol0003oooooooooo`06ooooo`009oooooooo`0002ko00002oooool00ol0003o
ooooooooo`06ooooo`00;oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`00;oooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool04Oooool00ol0003o<S8bomgM
g@06ooooo`00;oooool00ol0003oooooooooo`3oooooobgooooo0_l000001?nYZJWo8B4Qo`000?lQ
8B44ooooo`00;oooool00ol0003oooooooooo`3oooooocOooooo000_ooooo`03o`000?oooooooooo
0?oooooo=oooool002oooooo00?o0000ooooooooool0oooooolgooooo`00;oooool2o`000?oooooo
>?ooool002oooooo00?o0000ooooooooool0oooooolgooooo`00;oooool00ol0003oooooooooo`3o
ooooocOooooo000_ooooo`03o`000?oooooooooo0?oooooo6Oooool2o`3o01cooooo000_ooooo`03
o`000?oooooooooo0?oooooo6?ooool00ol0o`3oooooooooo`0Looooo`00;oooool00ol0003ooooo
ooooo`3ooooooa;ooooo0_l0o`0Sooooo`00;oooool2o`000?oooooo4Oooool2o`3o00;ooooo1ol0
000Looooo`00;oooool00ol0003oooooooooo`3loooooaOo00000_l00?lQooooo`00;oooool00ol0
003oooooooooo`3:ooooo`[oo`003_ooool2ool001So00000_l00?l2ooooo`;o0?l01Oooool00ol0
o`3oooooooooo`0/ooooo`00;oooool00ol0003oooooooooo`34ooooo`Koo`003_ooool<o`0000?o
003o3Oooool2ool00004ooooool0o`3o0?l0o`3o00Gooooo00?o0?l0ooooooooool0=?ooool002oo
oooo00?o0000ooooooooool0cOooool;o`0000oooooo0_l0o`05ooooo`?o0?l01Oooool00ol0o`3o
ooooooooo`0mooooo`00;oooool00ol0003oooooooooo`31ooooo`co00000_l00?l00ol0o`3ooooo
ooooo`03ooooo`?o0?l01Oooool4o`3o00Gooooo00?o0?l0ooooooooool06oooool4ool002kooooo
000_ooooo`03o`000?oooooooooo0;?ooooo0_oo000<o`0000?ooooo1?l0o`10ooooo`Goo`00:Ooo
ool002oooooo0_l0002Zooooo`co00002?l00?m@ooooo`Coo`009Oooool002oooooo00?o0000oooo
ooooool0WOooool<o`0000;oo`000_ooool8o`00oecooooo0_oo000Sooooo`00;oooool00ol0003o
ooooooooo`2Dooooo`Wo000000?o0?l0ooooooooool0Loooool00ooo003oooooooooo`0Pooooo`00
;oooool00ol0003oooooooooo`2>ooooo`Ko000000?o0?l0ooooooooool01?ooool4o`00oiOooooo
000_ooooo`03o`000?oooooooooo08Gooooo2Ol0002Xooooo`00;oooool00ol0003oooooooooo`1l
ooooo`Wo000000?oooooo`00ool00?l01?l00?l:ooooo`?oo`00WOooool002oooooo0_l0001goooo
o`Ko000000?oooooo`00ool00?l01ol00?l;ooooo`Goo`00X?ooool002oooooo00?o0000oooooooo
ool0L?ooool6o`0001Oooooo1?oo002Uooooo`00;oooool00ol0003oooooooooo`1[ooooo`Go0000
2_ooool3o`3o00kooooo0_oo002Yooooo`00;oooool00ol0003oooooooooo`1Uooooo`Ko000000?o
ooooo`00ool00?l00_l00?lJooooo`03ool00?oooooooooo0:Wooooo000Uooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooooooo`1Oooooo`Ko00003?ooool4o`3o0<7ooooo000Woooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0F_ooool5o`000=Oooooo000Wooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0E_ooool4o`00017ooooo0_l0o`39ooooo`00
9oooool00ol0003oooooooooo`05ooooo`;o0000Doooool4o`0000Gooooo0ol00?l;ooooo`;o0?l0
3_ooool3ool00;[ooooo000Wooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Cooo
ool3o`0000Kooooo0ol00?l8ooooo`;o0?l04Oooool3ool00;gooooo000Wooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0C?ooool3o`0000Kooooo0ol00?l9ooooo`;o0?l03oooool4
ool00<3ooooo000Wooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0BOooool3o`00
00Kooooo0ol00?lJooooo`?oo`00a?ooool002Gooooo00?oEEEEofIVI_l000001oooool00ol0003o
ooooooooo`16ooooo`?o00001oooool2o`00o`Wooooo0_l0o`0@ooooo`;oo`00aoooool002oooooo
00?o0000ooooooooool0@oooool3o`0000Wooooo00?o003oooooooooool01oooool2o`3o0=_ooooo
000_ooooo`;o0000@Oooool3o`000??ooooo000_ooooo`03o`000?oooooooooo03gooooo0ol0000C
ooooo`;o0?l0hOooool002oooooo00?o0000ooooooooool0>_ooool3o`0001Cooooo0_l0o`08oooo
o`Goo`00e_ooool002oooooo00?o0000ooooooooool0=oooool3o`0001kooooo0ooo003Kooooo`00
;oooool00ol0003oooooooooo`0dooooo`?o00005?ooool2o`3o00Sooooo0ooo003Nooooo`00;ooo
ool00ol0003oooooooooo`0booooo`;o00003?ooool2o`00o`Sooooo00?o0?l0ooooooooool01Ooo
ool3ool00>7ooooo000_ooooo`03o`000?oooooooooo033ooooo0_l0000=ooooo`03o`00oooooooo
oooo00kooooo0_oo003Tooooo`00;oooool2o`0002kooooo0ol0000Cooooo`;o0?l0lOooool002oo
oooo00?o0000ooooooooool0:oooool2o`0001Gooooo00?o0?l0ooooooooool0lOooool002oooooo
00?o0000ooooooooool0:Oooool2o`000?oooooo3?ooool002oooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0@ooooo`;o0?l00oooool3ool00??ooooo000_ooooo`03o`000?oooooo
oooo02Kooooo0_l0000Booooo`03o`3o0?oo003oo`0000?oo`00m_ooool002oooooo00?o0000oooo
ooooool09?ooool2o`00013ooooo1Ooo003kooooo`00;oooool2o`0002Cooooo00?o0000oooooooo
ool03Oooool00ooo003o0?l0o`3o003oooooo`7ooooo000_ooooo`03o`000?oooooooooo027ooooo
0_l0000>ooooo`;o003o00?o0?l0ooooooooool0ooooool1ooooo`00;oooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00cooooo0_l00?ooooooo`Kooooo000_ooooo`03o`000?oooooo
oooo01oooooo00Co0000oooooooooooooooo0ooo0007ooooo`;o003oooooool8ooooo`00;oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oo003oo`0000;oo`002?ooool2o`00oooooooo2_ooool0
02oooooo00?o0000ooooooooool06Oooool4ool00003o`000?oooooooooo00Wooooo0_l00?oooooo
o`cooooo000_ooooo`03o`000?oooooooooo01Kooooo0ooo0003ooooo`03o`000?oooooooooo00Wo
oooo00?o003oooooooooool0ooooool<ooooo`00;oooool2o`0001cooooo00?o0000ooooooooool0
1_ooool2o`3o00;o003oooooool?ooooo`00;oooool00ol0003oo`00ool00008ool001;ooooo00?o
0000ooooooooool01_ooool00ol0o`3oooooo`00o`3ooooooa7ooooo000_ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0oooooolKooooo`00;oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00;ooooo0_l0o`3ooooooaSooooo000Tooooo`Go00001_ooool00ol0003o
ooooooooo`0Gooooo`04o`000?ooooooooooooooo`;o0?l0oooooolJooooo`009?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`3ooooo
oakooooo000Uooooo`03oiRHV?lQ8B7ok^k^00Oooooo0_l0000Fooooo`03o`000?oooooooooo0?oo
oooo7oooool002Kooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0Dooooo`03o`3o
0?l0003o0?l00?oooooo8?ooool002Oooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo0?oooooo8?ooool002Sooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0?oooooo8Oooool002Cooooo00Go0000okZj
^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo00gooooo0_l0o`03ooooo`03o`000?oooooo
oooo00?ooooo0_l00?oooooooagooooo000Tooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`0<ooooo`03o`3o0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol00?ooooooooooo`3ooooooagooooo000_ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool00_ooool00ol00?ooooooooooo`3ooooooakooooo000_ooooo`;o00001_ooool2o`3o00Wo
oooo00?o0000ooooooooool0oooooolTooooo`00;oooool00ol0003oooooooooo`04ooooo`03o`3o
0?oooooooooo00Sooooo00?o0000ooooooooool0oooooolUooooo`00;oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo0?oooooo9Oooool002oooooo00?o0000o`3o0?l0o`003_ooool0
0ol0003oooooooooo`3oooooobKooooo000_ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0oooooolWooooo`00;oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0?oo
oooo9oooool002oooooo0_l0000=ooooo`03o`000?oooooooooo0?oooooo:?ooool002oooooo00?o
0000ooooooooool02Oooool2o`00o`03o`000?oooooooooo0?oooooo:Oooool002oooooo00?o0000
ooooooooool01oooool2o`00o`;ooooo00?o0000ooooooooool0oooooolYooooo`00;oooool00ol0
003oooooooooo`05ooooo`;o003o0oooool00ol0003oooooooooo`3oooooob[ooooo000_ooooo`03
o`000?oooooooooo00?ooooo0_l00?l5ooooo`03o`000?oooooooooo0?oooooo:_ooool002oooooo
00?o0000ooooooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
:_ooool002oooooo00?o0000ooooooooool00_l00?l7ooooo`03o`000?oooooooooo0?oooooo:ooo
ool002oooooo00?o0000o`00ool00?l02Oooool00ol0003oooooooooo`3oooooob_ooooo000_oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0ooooool[ooooo`00;oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo0?oooooo;?ooool002oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`3oooooobcooooo000_ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0ooooool]ooooo`00;oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo;Oooool002oooooo0_l00008ooooo`03o`000?oooooooooo0?oooooo;Oooool002oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooobkooooo000_ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0ooooool^ooooo`00;oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?oooooo;_ooool002Cooooo00GoV9RHoa0@4?l0003o<S8bolc<
c006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0ooooool_ooooo`009?ooool0
1Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`3ooooooboooooo000Xooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooooboooooo000Wooooo`03ojVYZOl@413ooooo00Gooooo0_l00006oooo
o`03o`000?oooooooooo0?oooooo;oooool002Kooooo00?o410@o`000?nj^[X01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?oooooo;oooool002Oooooo00?o^[Zjob4Q8Oooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo;oooool002Cooooo00Go
410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
ooooool`ooooo`009?ooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3ooooooc3ooooo000_ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0ooooool`ooooo`00;oooool2o`0000Gooooo00?o0000ooooooooool0ooooool`
ooooo`00;oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo<?ooool002oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooooc3ooooo000_ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0oooooolaooooo`00;oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0?oooooo<Oooool002oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`3ooooooc7ooooo000_ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooolaooooo`00;oooool2o`0000Cooooo00?o0000ooooooooool0oooooolaooooo`00
;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo<_ooool002oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`3ooooooc;ooooo000_ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0oooooolbooooo`00;oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo0?oooooo<_ooool002oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`3ooooooc;ooooo000_ooooo`;o00000oooool00ol0003oooooooooo`3ooooooc;ooooo
000_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooolbooooo`00;oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo<_ooool002oooooo00Go0000oooo
ooooooooooooo`00003oooooocGooooo000_ooooo`05o`000?ooooooooooooooool00000oooooole
ooooo`00;oooool01Ol0003ooooooooooooooooo00000?oooooo=Oooool002oooooo00Go0000oooo
ooooooooooooo`00003oooooocGooooo000_ooooo`;o00000_ooool00ol0003oooooooooo`3ooooo
oc?ooooo000_ooooo`05o`000?ooooooooooooooool00000ooooooleooooo`00;oooool01Ol0003o
oooooooooooooooo00000?oooooo=Oooool002oooooo00Go0000ooooooooooooooooo`00003ooooo
ocGooooo000_ooooo`04o`000?ooooooooooo`000?oooooo=_ooool002oooooo00Co0000oooooooo
oooo0000oooooolfooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`002_ooool3o`0000Sooooo00?oMgMgofIVI_ooool02Oooool00ol0003o^[Zjooooo`0aoooo
o`03ofIVI_mgMgOooooo0?oooooo4Oooool000_ooooo00?o0000ooooooooool01_ooool00ooMgMgo
410@onk^kP0:ooooo`;o<S8b9?ooool00olQ8B7ogMgMooooo`0;ooooo`03onk^k_l@413ogMgM0?oo
oooo4Oooool000;ooooo1_l00003ooooo`03o`000?oooooooooo00Kooooo00GoEEEEoiRHV?oooooo
oooooa0@4005o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01_o^k^ko<S8bo`000?l0003oEEEE
onk^kPWooooo00SoV9RHoa0@4?l0003o<S8bolc<c?ooooooEEEEojVYZ@?ooooo00?o^[ZjodA4A?oo
ool00_ooool00onHV9SoEEEEooooo`03ooooo`Go00001?ooool00on7QhOoIVIVooooo`3ooooooa3o
oooo0003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooo`000?l00006oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@4004oooo
o`07oeEEEOmgMgOoooooonk^k_n7QhOo8B4Qonk^kP06o`0000;ooooo00Go410@okZj^_ooooooMgMg
oc8b<P02ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj1?ooool00ol0003ogMgMooooo`02oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01?ooool00oo^k^ko0000ooooo`3ooooooa3ooooo0003oooo
o`05o`000?ooooooooooooooool@41003?ooool00olb<S;oooooooooo`03ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00_ooool00on7QhOoMgMgooooo`0;ooooo`08o`000?oooooo
ooooooooool@413ogMgMooooool00005ooooo`;oMgMg1?ooool00onHV9So8B4Qonk^kP06ooooo`03
o`000?oooooooooo0?oooooo3oooool000?ooooo00?o0000ooooool@41003_ooool00olb<S;ooooo
ooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00olQ8B7o0000
o`000004o`0000Gooooo00?oZJVYoa0@4?ooool00_ooool01?n7QhOoIVIVooooool00005ooooo`03
onk^k_l@413ok^k^00Cooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`3oooooo`oo
oooo0003ooooo`?o00003_ooool00ol0003ok^k^ooooo`03ooooo`03o`000?lb<S;ogMgM00_ooooo
00?o8B4Qo`000?l000001?l0000:ooooo`03oa0@4?l0003o^[Zj00?ooooo00CogMgMoa0@4?oooooo
00001_ooool00omEEEGoV9RHooooo`04ooooo`03ogMgMomVIVKooooo00?ooooo00?ok^k^o`000?oo
ool0ooooool@ooooo`000oooool01Ol0003ooooooa0@4?oooooo410@00cooooo00?oEEEEogMgMooo
ool00_ooool2o`000004ojVYZOlQ8B7o0000ob4Q8@Wooooo00?oV9RHohN7Qoooool00oooool00ol0
003oooooooooo`09ooooo`04okZj^_lQ8B7oooooooooo`Oo00001?ooool00ooMgMgo410@ooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?oMgMgoeEEEOooool0ooooool@ooooo`000oooool01Ol0
003ooooooooooooooooo000000cooooo00?ogMgMoa0@4?o^k^h04_ooool01_lb<S;oQhN7onk^k_oo
ooooQhN7oc8b<PSooooo00Go410@oiRHV?oooooo^[Zjo`00000>ooooo`08oeEEEOnHV9Soooooo`00
0?nj^[[ooooooiRHV?l@4103ooooo`03onk^k_l@413ogMgM0?oooooo4Oooool000;ooooo1_l0000=
ooooo`03ogMgMomVIVKooooo017ooooo00Kok^k^ogMgMol0003o0000oc8b<_o<c<`8ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT03_ooool02?nj^[[oA4A4oooooonHV9So410@o`000?lQ8B7oc<c<0ooo
ool00omVIVKoMgMgooooo`3ooooooa7ooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{73.5625, 302.938}, {198.5, 57.1875}} -> {-0.569741, \
0.813124, 0.00439685, 0.0385729}}],

Cell[TextData[{
  "Fig. 6.3 Radial electric field along ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] = 3  \[Pi]/2\)]],
  "for exact solution (solid) and Galerkin solutions with ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(P\_x\), "=", 
            RowBox[{\(P\_y\), "=", 
              StyleBox[\(1\ \((dashed)\)\),
                FontColor->RGBColor[1, 0, 0]]}]}], ",", 
          StyleBox[\(3\ \((dotted)\)\),
            FontColor->RGBColor[0, 1, 0]], ",", 
          StyleBox[\(5\ \((dot - dashed)\)\),
            FontColor->RGBColor[0, 0, 1]]}], TraditionalForm]]],
  "."
}], "Caption",
  CellTags->"Fig. 6.3"],

Cell[TextData[{
  "As might be expected, our Galerkin solution fails to capture the singular \
behavior near the origin, although it is reasonably accurate for ",
  Cell[BoxData[
      \(TraditionalForm\`r \[GreaterTilde] 0.5\)]],
  ". Many more terms are needed to roughly approximate the singularity, but \
calculation of the required inner products is computationally intensive.  In \
general, numerical solutions near singularities are problematic in any \
numerical method. However, the Galerkin method in particular is best suited \
to problems with smoothly varying solutions, unless the required inner \
products are easy to evaluate."
}], "Text"],

Cell[TextData[{
  "\tIn Sec. ",
  ButtonBox["6.2",
    ButtonData:>"c:24",
    ButtonStyle->"Hyperlink"],
  ", we will observe that grid methods can do a somewhat better job in \
resolving solutions near singularities, if the grid is chosen to be \
sufficiently fine.  "
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["6.1.3 Time-Dependent Problems", "Subsubtitle",
  CellTags->{"i:11", "c:9"}],

Cell[CellGroupData[{

Cell["The Heat Equation", "Section",
  CellTags->"c:10"],

Cell[TextData[{
  "The Galerkin method can also be used in the solution of PDEs with time \
dependence. As a simple example, we will use it to solve the heat equation in \
one dimension on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ x \[LessEqual] \ b\)]],
  ","
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\/\[PartialD]t\) \(T(x, 
            t)\) = \[Chi] \(\[PartialD]\^2\/\[PartialD]x\^2\) \(T(x, t)\) + 
          S(x, t)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(6.1.15)"],

Cell["subject to mixed boundary conditions ", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`T(0, t) = \(T\_1\)(
        t), \[IndentingNewLine]\(\[PartialD]T\/\[PartialD]x\) \((b, t)\) = 
      0, \)]]], "NumberedEquation",
  CellTags->"(6.1.16)"],

Cell["and the initial condition", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`T(x, 0) = \(T\_o\)(x)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.17)"],

Cell["We write the solution in the usual manner as ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`T(x, 
          t) = \[Sum]\_\(n = 0\)\%M\(\( c\_n\)(t)\)\ \(\(v\_n\)(x)\) + 
          u(x, t)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(6.1.18)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`u(x, t)\)]],
  "is any smooth function that satisfies the boundary conditions. For this \
problem, the choice"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(u(x, t)\)\(\ \)\(=\)\(\ \)\(\(T\_1\)(
          t)\)\(\ \)\)\)]],
  " "
}], "NumberedEquation",
  CellTags->"(6.1.19)"],

Cell["works well.", "Text"],

Cell[TextData[{
  "\t The basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_n\)(x)\)]],
  " are any set of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " functions that form a complete set  as ",
  Cell[BoxData[
      \(TraditionalForm\`M \[Rule] \ \[Infinity]\)]],
  ", and that satisfy homogeneous mixed boundary conditions of the same type \
as specified in the problem. In this case, this implies homogeneous Dirichlet \
conditions  on one end, and homogeneous ",
  "von Neumann ",
  " conditions on the other:"
}], "Text",
  CellTags->"i:12"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_n\)(
          0) = \(\(\[PartialD]v\_n\/\[PartialD]x\) \((b)\) = 0\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "For example, we could choose these functions to be eigenmodes of the \
operator ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2\/\[PartialD]x\^2\)]],
  ", and then we would have the usual eigenmode expansion, as discussed \
previously in Secs. ",
  ButtonBox["3.1.4",
    ButtonData:>{"Chapter3.nb", "c:17"},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["4.2.2",
    ButtonData:>{"Chapter4.nb", "c:17"},
    ButtonStyle->"Hyperlink"],
  ".  Here, however, we will choose some other set. For instance, one simple \
choice is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(v\_n\)(
          x)\  = \ \ x\^n\ \((1 - \(n\/\(n + 1\)\) x\/b)\), \ \ n = 1, 
      2,  ... , M\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.20)"],

Cell[TextData[{
  "Some of these functions are in Cell ",
  ButtonBox["6.32",
    ButtonData:>"Cell 6.32",
    ButtonStyle->"Hyperlink"],
  ", assuming ",
  Cell[BoxData[
      \(TraditionalForm\`b = 2\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(v[n_, x_]\  = \ \ \ x^n \((1 - n \((x/b)\)\/\(n + 1\))\);\)\), "\n", 
    \(b = 2; \ 
    Plot[Evaluate[Table[v[n, x], {n, 1, 4}]], {x, 0, b}];\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.32"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.183939 [
[.2619 .00222 -9 -9 ]
[.2619 .00222 9 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .10668 -18 -4.5 ]
[.01131 .10668 0 4.5 ]
[.01131 .19865 -6 -4.5 ]
[.01131 .19865 0 4.5 ]
[.01131 .29062 -18 -4.5 ]
[.01131 .29062 0 4.5 ]
[.01131 .38259 -6 -4.5 ]
[.01131 .38259 0 4.5 ]
[.01131 .47456 -18 -4.5 ]
[.01131 .47456 0 4.5 ]
[.01131 .56653 -6 -4.5 ]
[.01131 .56653 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(0.5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(1.5)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10668 m
.03006 .10668 L
s
[(0.5)] .01131 .10668 1 0 Mshowa
.02381 .19865 m
.03006 .19865 L
s
[(1)] .01131 .19865 1 0 Mshowa
.02381 .29062 m
.03006 .29062 L
s
[(1.5)] .01131 .29062 1 0 Mshowa
.02381 .38259 m
.03006 .38259 L
s
[(2)] .01131 .38259 1 0 Mshowa
.02381 .47456 m
.03006 .47456 L
s
[(2.5)] .01131 .47456 1 0 Mshowa
.02381 .56653 m
.03006 .56653 L
s
[(3)] .01131 .56653 1 0 Mshowa
.125 Mabswid
.02381 .03311 m
.02756 .03311 L
s
.02381 .0515 m
.02756 .0515 L
s
.02381 .0699 m
.02756 .0699 L
s
.02381 .08829 m
.02756 .08829 L
s
.02381 .12508 m
.02756 .12508 L
s
.02381 .14347 m
.02756 .14347 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .18026 m
.02756 .18026 L
s
.02381 .21705 m
.02756 .21705 L
s
.02381 .23544 m
.02756 .23544 L
s
.02381 .25384 m
.02756 .25384 L
s
.02381 .27223 m
.02756 .27223 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .32741 m
.02756 .32741 L
s
.02381 .3458 m
.02756 .3458 L
s
.02381 .3642 m
.02756 .3642 L
s
.02381 .40099 m
.02756 .40099 L
s
.02381 .41938 m
.02756 .41938 L
s
.02381 .43777 m
.02756 .43777 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .49296 m
.02756 .49296 L
s
.02381 .51135 m
.02756 .51135 L
s
.02381 .52974 m
.02756 .52974 L
s
.02381 .54814 m
.02756 .54814 L
s
.02381 .58493 m
.02756 .58493 L
s
.02381 .60332 m
.02756 .60332 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .02934 L
.10458 .04459 L
.14415 .05826 L
.18221 .07081 L
.22272 .08352 L
.26171 .09513 L
.30316 .10679 L
.34309 .11737 L
.3815 .12693 L
.42237 .13645 L
.46172 .14498 L
.49955 .15258 L
.53984 .16004 L
.57861 .1666 L
.61984 .1729 L
.65954 .17832 L
.69774 .18293 L
.73838 .18719 L
.77751 .19065 L
.81909 .19365 L
.85916 .19588 L
.87754 .19668 L
.89771 .1974 L
.91765 .19796 L
.92854 .19819 L
.93871 .19837 L
.94354 .19844 L
.94878 .1985 L
.95341 .19855 L
.95832 .19859 L
.96273 .19862 L
.96524 .19863 L
.9676 .19864 L
.96976 .19865 L
.97173 .19865 L
.97277 .19865 L
.97391 .19865 L
.97509 .19865 L
.97619 .19865 L
s
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01475 L
.03279 .01478 L
.03527 .01482 L
.0379 .01487 L
.04262 .015 L
.05205 .01535 L
.06244 .01589 L
.07293 .0166 L
.0842 .01755 L
.10458 .01971 L
.1458 .02576 L
.18551 .03352 L
.22371 .04259 L
.26435 .05375 L
.30348 .06574 L
.34506 .07961 L
.38513 .09383 L
.42368 .10811 L
.46468 .12372 L
.50417 .13895 L
.54214 .15358 L
.58257 .16891 L
.62148 .18325 L
.66284 .19779 L
.70268 .2109 L
.74101 .22249 L
.78179 .23348 L
.82106 .24257 L
.85881 .24971 L
.87978 .25294 L
.89901 .2554 L
.91786 .25732 L
.92745 .25811 L
.9377 .2588 L
.94804 .25934 L
.95744 .25969 L
.96198 .2598 L
.96436 .25985 L
.96689 .2599 L
.9691 .25993 L
.97027 .25994 L
.97153 .25995 L
.97269 .25996 L
.97374 .25996 L
.9748 .25997 L
Mistroke
.97581 .25997 L
.97619 .25997 L
Mfstroke
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03746 .01472 L
.03884 .01472 L
.04016 .01472 L
.04262 .01473 L
.045 .01473 L
.04753 .01474 L
.0521 .01475 L
.05752 .01478 L
.06244 .01481 L
.06787 .01486 L
.07287 .01491 L
.08414 .01507 L
.09408 .01527 L
.10458 .01556 L
.11406 .01588 L
.12422 .0163 L
.14255 .0173 L
.16379 .01887 L
.18391 .02082 L
.22224 .02595 L
.26302 .03364 L
.30229 .04344 L
.34004 .05517 L
.38024 .0702 L
.41893 .0871 L
.46007 .10756 L
.4997 .1295 L
.5378 .1524 L
.57837 .17836 L
.61741 .20446 L
.65891 .23284 L
.69889 .26018 L
.73736 .28583 L
.77828 .31162 L
.81768 .33417 L
.85557 .35288 L
.87664 .36171 L
.89591 .36861 L
.91605 .37451 L
Mistroke
.93473 .37865 L
.94394 .38017 L
.95375 .38141 L
.95936 .38192 L
.96211 .38212 L
.96464 .38227 L
.9669 .38238 L
.96937 .38248 L
.97066 .38252 L
.97186 .38255 L
.97313 .38257 L
.97384 .38258 L
.97449 .38259 L
.97531 .38259 L
.97619 .38259 L
Mfstroke
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03638 .01472 L
.03746 .01472 L
.03873 .01472 L
.04011 .01472 L
.04141 .01472 L
.04262 .01472 L
.04521 .01472 L
.04765 .01472 L
.04984 .01472 L
.05221 .01472 L
.05481 .01472 L
.05754 .01472 L
.06244 .01472 L
.06507 .01473 L
.06746 .01473 L
.07283 .01473 L
.07781 .01474 L
.08253 .01476 L
.08802 .01477 L
.09309 .01479 L
.09862 .01482 L
.10458 .01486 L
.11421 .01494 L
.12324 .01504 L
.13399 .01519 L
.14385 .01538 L
.16277 .01589 L
.17349 .01629 L
.18347 .01673 L
.20393 .01791 L
.22252 .01936 L
.2417 .0213 L
.2625 .024 L
.28198 .02716 L
.30342 .03144 L
.34282 .04184 L
.38316 .05636 L
.42198 .07456 L
.46326 .09888 L
Mistroke
.50302 .12743 L
.54127 .15971 L
.58196 .19912 L
.62115 .24163 L
.66278 .29096 L
.7029 .34152 L
.7415 .39163 L
.78256 .44468 L
.8221 .4933 L
.86012 .53532 L
.88131 .55569 L
.9006 .57178 L
.91927 .5847 L
.92911 .59031 L
.93956 .59526 L
.94861 .59866 L
.95342 .60011 L
.9586 .60138 L
.96334 .60228 L
.96541 .60258 L
.96768 .60286 L
.96983 .60306 L
.97183 .6032 L
.97293 .60325 L
.97394 .60329 L
.9751 .60331 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00H03oool01@3^k^h0<c<c0000000c<c<0k^k^00D0
oooo0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd0A03oool400000003014A4@3oool0oooo
0480oooo100000000`0A4A40oooo0?ooo`020?ooo`808R8R1@3oool01@14A4@000000000000c<c<0
gMgM04<0oooo1@0000080?ooo`00H03oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R88
0?ooo`0307MgM`0c<c<0oooo04D0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`04
0?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`120?ooo`0509VIV@0R8R80k^k^0?ooo`14A4@0203o
ool00600oooo00D04A4A0?ooo`3oool0oooo014A4@0@0?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0480oooo00<0
VIVI028R8P3^k^h02@3oool00600oooo00D000000?ooo`3oool0oooo0000000?0?ooo`0307MgM`0c
<c<0oooo04D0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0>0?ooo`0307MgM`0c
<c<0oooo04@0oooo00<0VIVI028R8P3^k^h0203oool00600oooo00D000000?ooo`3oool0oooo0000
000<0?ooo`050000000R8R80000003<c<`3<c<`0AP3oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo00/0oooo00D00000028R8P000000<c<c0<c<c0160?ooo`0307MgM`1VIVH0oooo00L0
oooo001P0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`000000oooo0?ooo`180?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo00H0oooo001P0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0303oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`150?ooo`050000002k^k/0oooo09VIV@0A4A40203oool00600oooo00D0k^k^03<c<`00
0000<c<c0>k^kP0<0?ooo`@00000A@3oool205EEE@030000003oool0oooo04@0oooo0P1EEED00`00
0000oooo0?ooo`0;0?ooo`@00000A03oool01@2IVIT04A4A0000000R8R80c<c<00P0oooo000J0?oo
o`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00
6P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03o
ool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`004P3ooooo000005L00000000J0?ooo`03
0000003oool00000008000002`3oool:000000L0oooo00<000000?ooo`3oool00`3oool>00000003
0?ooo`0000000000010000002@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`006P3oool00`000000oooo
0?ooo`020?ooo`<000004P3oool7000001@0oooo1P00000=0?ooo`L000000P3oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`070?ooo`006P3oool00`000000oooo0?ooo`050?ooo`8000005`3oool7000001<0oooo1`00
000=0?ooo`L00000n03oool001X0oooo00<000000?ooo`3oool01`3oool3000001/0oooo1P00000D
0?ooo`L000003@3oool500000?<0oooo000J0?ooo`030000003oool0oooo00X0oooo0`00000N0?oo
o`L00000503oool7000000/0oooo0`00003`0?ooo`006P3oool3000000d0oooo0`00000R0?ooo`D0
00005P3oool5000000T0oooo1000003/0?ooo`006P3oool00`000000oooo0?ooo`0@0?ooo`<00000
903oool5000001H0oooo0`00000:0?ooo`D00000i`3oool001X0oooo00<000000?ooo`3oool04`3o
ool3000002H0oooo1000000E0?ooo`<00000303oool500000>80oooo000J0?ooo`030000003oool0
oooo01H0oooo0`00000W0?ooo`@00000503oool3000000h0oooo0`00003O0?ooo`006P3oool00`00
0000oooo0?ooo`0I0?ooo`800000:@3oool3000001@0oooo1000000=0?ooo`<00000g03oool001X0
oooo00<000000?ooo`3oool06`3oool3000002T0oooo1000000D0?ooo`<000003@3oool300000=T0
oooo000J0?ooo`<000007P3oool3000002X0oooo0`00000D0?ooo`<000003@3oool300000=H0oooo
000J0?ooo`030000003oool0oooo0240oooo0P00000[0?ooo`@000004`3oool3000000d0oooo0`00
003C0?ooo`006P3oool00`000000oooo0?ooo`0S0?ooo`<00000;03oool3000001<0oooo0`00000=
0?ooo`800000d@3oool001X0oooo00<000000?ooo`3oool09P3oool3000002`0oooo0`00000C0?oo
o`<00000303oool200000<l0oooo000J0?ooo`030000003oool0oooo02T0oooo0`00000/0?ooo`<0
00004`3oool3000000/0oooo0P00003=0?ooo`006P3oool00`000000oooo0?ooo`0/0?ooo`<00000
;03oool400000180oooo0`00000:0?ooo`<00000bP3oool001X0oooo00<000000?ooo`3oool0;`3o
ool3000002d0oooo0`00000B0?ooo`<000002P3oool200000<P0oooo000J0?ooo`<00000<P3oool4
000002`0oooo0`00000B0?ooo`8000002P3oool200000<H0oooo000J0?ooo`030000003oool0oooo
03H0oooo0`00000/0?ooo`<000004@3oool2000000X0oooo0P0000340?ooo`006P3oool00`000000
oooo0?ooo`0i0?ooo`@00000:`3oool300000100oooo0P00000:0?ooo`030000003oool0oooo0<40
oooo000J0?ooo`030000003oool0oooo03d0oooo0`00000[0?ooo`800000403oool3000000P0oooo
0P0000310?ooo`006P3oool00`000000oooo0?ooo`100?ooo`@00000:@3oool300000100oooo0P00
00080?ooo`030000003oool0oooo0;h0oooo000J0?ooo`030000003oool0oooo04@0oooo0`00000Y
0?ooo`<000003`3oool2000000L0oooo0P00002n0?ooo`006P3oool3000004L0oooo0`00000Y0?oo
o`8000003`3oool2000000L0oooo0P00002l0?ooo`006P3oool00`000000oooo0?ooo`1:0?ooo`<0
0000:03oool3000000h0oooo0`0000060?ooo`030000003oool0oooo0;T0oooo000J0?ooo`030000
003oool0oooo04d0oooo1000000W0?ooo`8000003`3oool2000000D0oooo0P00002i0?ooo`006P3o
ool00`000000oooo0?ooo`1A0?ooo`<000009P3oool3000000h0oooo0P0000050?ooo`030000003o
ool0oooo0;H0oooo0000100c<c<0000003<c<`3^k^h50?ooo`808R8R1@3oool01@14A4@000000000
000c<c<0gMgM00D0oooo00<000000?ooo`3oool0E03oool4000002D0oooo0`00000=0?ooo`<00000
0`3oool200000;H0oooo0000102IVIT0oooo09VIV@1gMgL50?ooo`808R8R203oool00`1gMgL0<c<c
0?ooo`040?ooo`030000003oool0oooo05P0oooo0`00000U0?ooo`8000003P3oool2000000<0oooo
00<000000?ooo`3oool0/`3oool000<0oooo00<04A4A0?ooo`3oool03P3oool00`000000oooo0?oo
o`030?ooo`<00000F`3oool4000002<0oooo0`00000=0?ooo`8000000P3oool200000;<0oooo0003
0?ooo`030000003oool0oooo00d0oooo00<0MgMg03<c<`3oool0103oool00`000000oooo0?ooo`1O
0?ooo`<000008`3oool2000000d0oooo00D000000?ooo`3oool0oooo0000002b0?ooo`000`3oool0
0`000000oooo0?ooo`0:0?ooo`050000000R8R80000003<c<`3<c<`01@3oool00`000000oooo0?oo
o`1R0?ooo`@000008@3oool3000000/0oooo0P0000020?ooo`800000/03oool000<0oooo00<04A4A
0?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo06H0oooo0`00000Q
0?ooo`<000002P3oool200000080oooo00<000000?ooo`3oool0[@3oool0000409VIV@3oool0VIVI
07MgM``0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1Y0?ooo`@00000803oool3
000000T0oooo00@000000?ooo`3oool00000[P3oool0000403<c<`000000<c<c0>k^kP`0oooo1000
00060?ooo`030000003oool0oooo06d0oooo1@00000N0?ooo`<000001`3oool2000000030?ooo`00
000000000:`0oooo000J0?ooo`<00000LP3oool4000001d0oooo0P0000070?ooo`80000000<0oooo
0000003oool0ZP3oool001X0oooo00<000000?ooo`3oool0MP3oool4000001/0oooo0`0000060?oo
o`040000003oool0000000000:T0oooo000J0?ooo`030000003oool0oooo07X0oooo1@00000I0?oo
o`<00000103oool2000000030?ooo`000000oooo0:L0oooo000J0?ooo`030000003oool0oooo07l0
oooo1@00000G0?ooo`<000000`3oool00`000000oooo0000002W0?ooo`006P3oool00`000000oooo
0?ooo`240?ooo`@000005P3oool3000000040?ooo`000000000000000:H0oooo000J0?ooo`030000
003oool0oooo08P0oooo1@00000D0?ooo`80000000<0oooo000000000000Y@3oool001X0oooo00<0
00000?ooo`3oool0S@3oool400000180oooo1@00002S0?ooo`006P3oool300000940oooo1000000A
0?ooo`<00000XP3oool001X0oooo00<000000?ooo`3oool0U@3oool5000000l0oooo0P00002P0?oo
o`006P3oool00`000000oooo0?ooo`2J0?ooo`@00000303oool4000009d0oooo000J0?ooo`030000
003oool0oooo09h0oooo1P0000070?ooo`D00000V`3oool001X0oooo00<000000?ooo`3oool0Y03o
ool7000000050?ooo`000000oooo0000003oool00`00002H0?ooo`006P3oool00`000000oooo0?oo
o`2[0?ooo`H000000P3oool3000009D0oooo000J0?ooo`<00000[P3oool00`000000oooo00000004
000000030?ooo`000000000009<0oooo000J0?ooo`030000003oool0oooo0:l0oooo00<000000?oo
o`3oool00P0000000`3oool000000000000400000900oooo000J0?ooo`030000003oool0oooo0;00
oooo00@000000?ooo`3oool0oooo0P0000030?ooo`H00000S03oool001X0oooo00<000000?ooo`3o
ool0/@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo2@0000250?ooo`00
6P3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo0080oooo0P0000070?ooo`<00000
0`3oool7000007h0oooo000J0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`070?ooo`<000001`3oool7000007L0oooo000J0?ooo`<00000]03oool0
0`000000oooo0?ooo`030?ooo`8000002P3oool3000000/0oooo2P00001]0?ooo`006P3oool00`00
0000oooo0?ooo`2e0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool20000
01<0oooo2@00001T0?ooo`006P3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo00@0
oooo0P00000<0?ooo`<000006@3oool7000005d0oooo000J0?ooo`030000003oool0oooo0;L0oooo
00<000000?ooo`3oool01@3oool2000000d0oooo0`00000M0?ooo`X00000D`3oool00100oooo1000
00000`0A4A40oooo0?ooo`030?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0=0?ooo`<00000903oool>000004D0oooo000B0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`060?ooo`800000403oool3
000002l0oooo3P00000g0?ooo`004P3oool00`000000oooo0?ooo`050?ooo`<00000^P3oool00`00
0000oooo0?ooo`070?ooo`8000004@3oool2000003/0oooo;P0000090?ooo`004P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0@0?ooo`<00000K`3oool00180oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`2l0?ooo`030000003oool0oooo00P0oooo0P00000C0?ooo`<00000K03oool00180oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool04`3oool2000006X0oooo000B0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0_P3oool00`000000oooo0?ooo`090?ooo`8000005@3oool3000006L0oooo000@0?oo
o`80EEEE00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool05@3oool3000006@0oooo000J0?ooo`030000003oool0oooo0<00
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0G0?ooo`<00000H@3oool001X0oooo
0`0000310?ooo`030000003oool0oooo00X0oooo0P00000J0?ooo`<00000GP3oool001X0oooo00<0
00000?ooo`3oool0`P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01X0oooo0`00
001K0?ooo`006P3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo00/0oooo0P00000M
0?ooo`@00000E`3oool001X0oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo01h0oooo1@00001B0?ooo`006P3oool00`000000oooo0?ooo`350?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool08P3oool5000004d0oooo000J0?ooo`030000
003oool0oooo0<H0oooo00<000000?ooo`3oool0303oool2000002L0oooo100000190?ooo`006P3o
ool300000<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0X0?ooo`D00000A03o
ool001X0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0=0?ooo`800000;@3oool5
000003l0oooo000J0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0_0?ooo`@00000>`3oool001X0oooo00<000000?ooo`3oool0b@3oool00`000000
oooo0?ooo`0?0?ooo`800000<`3oool4000003L0oooo000J0?ooo`030000003oool0oooo0<X0oooo
00<000000?ooo`3oool0403oool2000003D0oooo1000000c0?ooo`006P3oool00`000000oooo0?oo
o`3;0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0=P3oool6000002d0oooo000J
0?ooo`<00000c03oool00`000000oooo0?ooo`0A0?ooo`800000?03oool7000002H0oooo000J0?oo
o`030000003oool0oooo0<d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`100?oo
o``000006P3oool001X0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0B0?ooo`80
0000C03ooolA000000T0oooo000J0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`1S0?ooo`006P3oool00`000000oooo0?ooo`3?0?ooo`030000003o
ool0oooo01@0oooo0P00001S0?ooo`006P3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0H03oool001X0oooo00<000000?ooo`3oool0d@3oool00`00
0000oooo0?ooo`0E0?ooo`800000H03oool001X0oooo0`00003B0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0G@3oool001X0oooo00<000000?ooo`3oool0dP3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo05`0oooo000J0?ooo`030000003oool0oooo0=<0oooo00<0
00000?ooo`3oool05`3oool2000005`0oooo000400000003014A4@3oool0oooo0080oooo0P0R8R85
0?ooo`0504A4A0000000000003<c<`3MgMd01@3oool00`000000oooo0?ooo`3D0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0F@3oool00080oooo00<000000?ooo`3oool0103oool2
028R8PP0oooo00<0MgMg03<c<`3oool0103oool00`000000oooo0?ooo`3E0?ooo`030000003oool0
oooo01P0oooo0P00001I0?ooo`000P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
05H0oooo00020?ooo`030000003oool0oooo00h0oooo00<0MgMg03<c<`3oool0103oool300000=L0
oooo00<000000?ooo`3oool06@3oool2000005H0oooo00020?ooo`030000003oool0oooo00/0oooo
00D00000028R8P000000<c<c0<c<c0050?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`1C0?ooo`000P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`0K0?ooo`800000
D`3oool00080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0=T0oooo00<000000?ooo`3oool0703oool200000540oooo000205EEE@030000003oool0
oooo00/0oooo100000060?ooo`030000003oool0oooo0=X0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`1>0?ooo`006P3oool00`000000oooo0?ooo`3J0?ooo`030000003oool0oooo
01h0oooo0P00001>0?ooo`006P3oool300000=/0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`1;0?ooo`006P3oool00`000000oooo0?ooo`3L0?ooo`030000003oool0oooo01l0oooo
0P00001;0?ooo`006P3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0B03oool001X0oooo00<000000?ooo`3oool0gP3oool00`000000oooo0?ooo`0P
0?ooo`800000B03oool001X0oooo00<000000?ooo`3oool0gP3oool00`000000oooo0?ooo`0R0?oo
o`800000AP3oool001X0oooo00<000000?ooo`3oool0g`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo04<0oooo000J0?ooo`<00000h03oool00`000000oooo0?ooo`0S0?ooo`800000
@`3oool001X0oooo00<000000?ooo`3oool0h@3oool00`000000oooo0?ooo`0T0?ooo`800000@@3o
ool001X0oooo00<000000?ooo`3oool0h@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo03h0oooo000J0?ooo`030000003oool0oooo0>80oooo00<000000?ooo`3oool09P3oool20000
03h0oooo000J0?ooo`030000003oool0oooo0><0oooo00<000000?ooo`3oool09`3oool2000003`0
oooo000J0?ooo`030000003oool0oooo0>@0oooo00<000000?ooo`3oool0:03oool2000003X0oooo
000J0?ooo`030000003oool0oooo0>@0oooo00<000000?ooo`3oool0:P3oool3000003L0oooo000J
0?ooo`<00000i@3oool00`000000oooo0?ooo`0/0?ooo`800000=@3oool001X0oooo00<000000?oo
o`3oool0iP3oool00`000000oooo0?ooo`0]0?ooo`800000<`3oool001X0oooo00<000000?ooo`3o
ool0i`3oool00`000000oooo0?ooo`0^0?ooo`800000<@3oool001X0oooo00<000000?ooo`3oool0
j03oool00`000000oooo0?ooo`0_0?ooo`<00000;P3oool001X0oooo00<000000?ooo`3oool0j@3o
ool00`000000oooo0?ooo`0a0?ooo`<00000:`3oool001X0oooo00<000000?ooo`3oool0j@3oool0
0`000000oooo0?ooo`0d0?ooo`<00000:03oool001X0oooo0`00003Z0?ooo`030000003oool0oooo
03H0oooo0`00000U0?ooo`006P3oool00`000000oooo0?ooo`3[0?ooo`030000003oool0oooo03P0
oooo0`00000R0?ooo`006P3oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo03X0oooo
0`00000O0?ooo`006P3oool00`000000oooo0?ooo`3]0?ooo`030000003oool0oooo03`0oooo1000
000K0?ooo`003`3oool5000000H0oooo00<000000?ooo`3oool0k@3oool00`000000oooo0?ooo`10
0?ooo`<00000603oool000l0oooo00D0VIVI028R8P3^k^h0oooo04A4A0060?ooo`030000003oool0
oooo0>h0oooo00<000000?ooo`3oool0@P3oool600000180oooo000@0?ooo`0309VIV@0R8R80k^k^
00L0oooo0`00003_0?ooo`030000003oool0oooo04L0oooo2@0000090?ooo`004@3oool00`2IVIT0
8R8R0>k^kP060?ooo`030000003oool0oooo0?00oooo00<000000?ooo`3oool0F03oool00180oooo
00<0MgMg06IVIP3oool01@3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo05L0oooo
000C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0lP3oool00`000000oooo0?oo
o`1F0?ooo`003`3oool01@000000^k^k0?ooo`2IVIT04A4A00H0oooo00<000000?ooo`3oool0lP3o
ool00`000000oooo0?ooo`1F0?ooo`003`3oool01@2IVIT04A4A0000000R8R80c<c<00H0oooo00<0
00000?ooo`3oool0l`3oool00`000000oooo0?ooo`1E0?ooo`006P3oool300000?@0oooo00<00000
0?ooo`3oool0E03oool001X0oooo00<000000?ooo`3oool0m@3oool00`000000oooo0?ooo`1C0?oo
o`006P3oool00`000000oooo0?ooo`3e0?ooo`030000003oool0oooo05<0oooo000J0?ooo`030000
003oool0oooo0?H0oooo00<000000?ooo`3oool0DP3oool001X0oooo00<000000?ooo`3oool0m`3o
ool00`000000oooo0?ooo`1A0?ooo`006P3oool00`000000oooo0?ooo`3g0?ooo`030000003oool0
oooo0540oooo000J0?ooo`030000003oool0oooo0?P0oooo00<000000?ooo`3oool0D03oool001X0
oooo0`00003i0?ooo`030000003oool0oooo04l0oooo000J0?ooo`030000003oool0oooo0?X0oooo
00<000000?ooo`3oool0CP3oool001X0oooo00<000000?ooo`3oool0nP3oool00`000000oooo0?oo
o`1>0?ooo`006P3oool00`000000oooo0?ooo`3k0?ooo`030000003oool0oooo04d0oooo000J0?oo
o`030000003oool0oooo0?`0oooo00<000000?ooo`3oool0C03oool001X0oooo00<000000?ooo`3o
ool0o03oool00`000000oooo0?ooo`1<0?ooo`006P3oool300000?d0oooo00<000000?ooo`3oool0
B`3oool001X0oooo00<000000?ooo`3oool0oP3oool00`000000oooo0?ooo`1:0?ooo`006P3oool0
0`000000oooo0?ooo`3o0?ooo`030000003oool0oooo04T0oooo000J0?ooo`030000003oool0oooo
0?l0oooo00<000000?ooo`3oool0B@3oool001X0oooo00<000000?ooo`3oool0o`3oool10?ooo`03
0000003oool0oooo04P0oooo000J0?ooo`030000003oool0oooo0?l0oooo0P3oool00`000000oooo
0?ooo`170?ooo`006P3oool300000?l0oooo0`3oool00`000000oooo0?ooo`160?ooo`006P3oool0
0`000000oooo0?ooo`3o0?ooo`@0oooo00<000000?ooo`3oool0A@3oool001X0oooo00<000000?oo
o`3oool0o`3oool50?ooo`030000003oool0oooo04@0oooo000J0?ooo`030000003oool0oooo0?l0
oooo1@3oool00`000000oooo0?ooo`140?ooo`00100000050?ooo`808R8R1@3oool01@14A4@00000
0000000c<c<0gMgM00D0oooo00<000000?ooo`3oool0o`3oool60?ooo`030000003oool0oooo04<0
oooo0000100R8R80k^k^0?ooo`14A4@50?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`040?ooo`03
0000003oool0oooo0?l0oooo1`3oool00`000000oooo0?ooo`120?ooo`0000<0VIVI028R8P3^k^h0
4@3oool00`000000oooo0?ooo`030?ooo`<00000o`3oool80?ooo`030000003oool0oooo0440oooo
0000103oool0VIVI028R8P3^k^h?0?ooo`0307MgM`0c<c<0oooo00@0oooo00<000000?ooo`3oool0
o`3oool90?ooo`030000003oool0oooo0400oooo00020?ooo`0307MgM`1VIVH0oooo00/0oooo00D0
0000028R8P000000<c<c0<c<c0050?ooo`030000003oool0oooo0?l0oooo2@3oool00`000000oooo
0?ooo`100?ooo`000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo03l0oooo0000102k^k/0oooo09VIV@0A
4A4<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3oool;0?ooo`030000003o
ool0oooo03h0oooo0000100A4A400000028R8P3<c<`<0?ooo`@000001P3oool00`000000oooo0?oo
o`3o0?ooo``0oooo00<000000?ooo`3oool0?@3oool001X0oooo00<000000?ooo`3oool0o`3oool=
0?ooo`030000003oool0oooo03`0oooo000J0?ooo`<00000o`3oool>0?ooo`030000003oool0oooo
03/0oooo000J0?ooo`030000003oool0oooo0?l0oooo3P3oool00`000000oooo0?ooo`0k0?ooo`00
6P3oool00`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?ooo`3oool0>P3oool001X0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo03T0oooo000J0?ooo`030000003oool0
oooo0?l0oooo4@3oool00`000000oooo0?ooo`0h0?ooo`006P3oool00`000000oooo0?ooo`3o0?oo
oa80oooo00<000000?ooo`3oool0=`3oool001X0oooo0`00003o0?oooa<0oooo00<000000?ooo`3o
ool0=P3oool001X0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`030000003oool0oooo03D0oooo
000J0?ooo`030000003oool0oooo0?l0oooo5@3oool00`000000oooo0?ooo`0d0?ooo`006P3oool0
0`000000oooo0?ooo`3o0?oooaH0oooo00<000000?ooo`3oool0<`3oool001X0oooo00<000000?oo
o`3oool0o`3ooolG0?ooo`030000003oool0oooo0380oooo000J0?ooo`030000003oool0oooo0?l0
oooo603oool00`000000oooo0?ooo`0a0?ooo`006P3oool300000?l0oooo6@3oool00`000000oooo
0?ooo`0`0?ooo`006P3oool00`000000oooo0?ooo`3o0?oooaX0oooo00<000000?ooo`3oool0;`3o
ool001X0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`030000003oool0oooo02h0oooo000J0?oo
o`030000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`0]0?ooo`006P3oool00`000000
oooo0?ooo`3o0?oooad0oooo00<000000?ooo`3oool0;03oool001X0oooo00<000000?ooo`3oool0
o`3ooolN0?ooo`030000003oool0oooo02/0oooo000J0?ooo`<00000o`3ooolO0?ooo`030000003o
ool0oooo02X0oooo000J0?ooo`030000003oool0oooo0?l0oooo803oool00`000000oooo0?ooo`0Y
0?ooo`006P3oool00`000000oooo0?ooo`3o0?ooob40oooo00<000000?ooo`3oool0:03oool001X0
oooo00<000000?ooo`3oool0o`3ooolR0?ooo`800000:03oool000l0oooo00D0VIVI014A4@000000
<c<c0<c<c0060?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`0U0?ooo`00
3`3oool01@0A4A40^k^k0?ooo`1gMgL0<c<c00H0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`80
00009@3oool001<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooobL0oooo
00<000000?ooo`3oool08P3oool00180oooo00<0ZZZZ014A4@3oool01@3oool300000?l0oooo:03o
ool00`000000oooo0?ooo`0Q0?ooo`004@3oool00`0A4A4000000;^k^`060?ooo`030000003oool0
oooo0?l0oooo:@3oool200000240oooo000B0?ooo`030;^k^`0R8R80oooo00D0oooo00<000000?oo
o`3oool0o`3oool[0?ooo`030000003oool0oooo01h0oooo000?0?ooo`05014A4@2IVIT0oooo0;^k
^`0000001P3oool00`000000oooo0?ooo`3o0?ooob`0oooo00<000000?ooo`3oool07@3oool000l0
oooo00D0ZZZZ014A4@0000004A4A0:ZZZP060?ooo`030000003oool0oooo0?l0oooo;@3oool00`00
0000oooo0?ooo`0L0?ooo`006P3oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3o
ool06`3oool001X0oooo0`00003o0?ooobl0oooo0P00000K0?ooo`006P3oool00`000000oooo0?oo
o`3o0?oooc40oooo00<000000?ooo`3oool0603oool001X0oooo00<000000?ooo`3oool0o`3ooolb
0?ooo`<000005`3oool001X0oooo00<000000?ooo`3oool0o`3ooole0?ooo`<00000503oool001X0
oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo0140oooo000J0?ooo`030000
003oool0oooo0?l0oooo>@3oool300000100oooo000J0?ooo`<00000o`3oooll0?ooo`L000002@3o
ool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oo
od`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0
o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}]
}, Open  ]],

Cell["\<\
 \tNext, we choose an inner product. We will make the  simple \
choice\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\)\  = \ \[Integral]\_0\%b\( f\^*\) g\ \[DifferentialD]x\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.21)"],

Cell[TextData[{
  "\tThe Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_n\)(t)\)]],
  " in Eq. ",
  ButtonBox["(6.1.18)",
    ButtonData:>"(6.1.18)",
    ButtonStyle->"Hyperlink"],
  " must now be determined. To do so, we first substitute Eq. ",
  ButtonBox["(6.1.18)",
    ButtonData:>"(6.1.18)",
    ButtonStyle->"Hyperlink"],
  " into Eq. ",
  ButtonBox["(6.1.15)",
    ButtonData:>"(6.1.15)",
    ButtonStyle->"Hyperlink"],
  ", obtaining"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(n = 1\)\%M\(\[PartialD]\/\[PartialD]t\) \(\
\(c\_n\)(t)\)\ \(\(v\_n\)(
              x)\) = \(\(\[Chi] \(\[Sum]\_\(n = 1\)\%M\(\( c\_n\)(
                  t)\)\ \(\[PartialD]\^2\/\[PartialD]x\^2\) \(\(v\_n\)(
                  x)\)\)\)\(\ \)\(+\)\(\(S\&_\)(x, t)\)\(\ \)\)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(6.1.22)"],

Cell[TextData[{
  "where the modified source function ",
  Cell[BoxData[
      \(TraditionalForm\`\(S\&_\)(x, t)\)]],
  " is "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(S\&_\)(x, t) = 
      S(x, t)\  + \ \[Chi]\ \(\[PartialD]\^2\/\[PartialD]x\^2\) \(u(x, 
            t)\) - \(\[PartialD]\/\[PartialD]t\) \(u(x, 
            t)\)\)]]], "NumberedEquation",
  CellTags->"(6.1.23)"],

Cell[TextData[{
  "Now, we take an inner product of Eq. ",
  ButtonBox["(6.1.22)",
    ButtonData:>"(6.1.22)",
    ButtonStyle->"Hyperlink"],
  " with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_m\)(x)\)]],
  ", yielding"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(n = 1\)\%M\((v\_m, 
              v\_n)\) \(\[PartialD]\/\[PartialD]t\) \(\(c\_n\)(
              t)\)\  = \[Sum]\_\(n = 1\)\%M\(\( c\_n\)(
                t)\)\ \((v\_m, \[Chi] \(\[PartialD]\^2\/\[PartialD]x\^2\) 
                  v\_n)\) + \((v\_m, S\&_)\)\)]],
  ",     ",
  Cell[BoxData[
      \(TraditionalForm\`m = 1, 2,  ... , M\)]]
}], "NumberedEquation",
  CellTags->"(6.1.24)"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(6.1.24)",
    ButtonData:>"(6.1.24)",
    ButtonStyle->"Hyperlink"],
  " provides a set of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " coupled ODE's for the time variation of the Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_n\)(t)\)]],
  ". One can solve these ODEs either analytically or numerically (using ",
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "). The initial conditions on the ODEs are determined by Eq. ",
  ButtonBox["(6.1.17)",
    ButtonData:>"(6.1.17)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(n = 1\)\%M\(\( c\_n\)(0)\)\ \(\(v\_n\)(
                x)\) + u(x, 0) = \(T\_o\)(x)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.25)"],

Cell[TextData[{
  "Taking an inner product of this equation with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_m\)(x)\)]],
  ", we obtain a set of coupled equations for the ",
  "initial-value",
  "s of the Fourier coefficients:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(n = 1\)\%M\(\( c\_n\)(0)\)\ \((v\_m, 
              v\_n)\) = \ \((v\_m, T\_o - u(x, 0))\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`m = 1, 2,  ... , M\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.26)"],

Cell[TextData[{
  " These ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " equations",
  ",",
  " together with the ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " ODEs given by Eq. ",
  ButtonBox["(6.1.24)",
    ButtonData:>"(6.1.24)",
    ButtonStyle->"Hyperlink"],
  ", are sufficient to specify ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_n\)(t)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tThe following ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " commands solve this problem on the time interval ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ t \[LessEqual] \ \[Tau]\)]],
  ". We will use ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to numerically determine the solutions to Eqs. ",
  ButtonBox["(6.1.24)",
    ButtonData:>"(6.1.24)",
    ButtonStyle->"Hyperlink"],
  ", subject to the initial conditions of Eq. ",
  ButtonBox["(6.1.26)",
    ButtonData:>"(6.1.26)",
    ButtonStyle->"Hyperlink"],
  ".  The Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_n\)(t)\)]],
  " are referred to as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["c",
              FontSlant->"Plain"], "[", 
            StyleBox["n",
              FontSlant->"Plain"], "]"}], "[", 
          StyleBox["t",
            FontSlant->"Plain"], "]"}], TraditionalForm]],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This notation is equivalent to ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["c",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["n",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["t",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  StyleBox[", ",
    FontWeight->"Bold"],
  "and it works in ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", whereas the notation ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["c",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["n",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["t",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  StyleBox[" ",
    FontWeight->"Bold"],
  " will not. This is because ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " interprets that as an instruction to solve a PDE for the function of two \
variables ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["c",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["n",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["t",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ". (Recall that the same issue arose when we performed molecular dynamics \
simulations in Chapter ",
  ButtonBox["1",
    ButtonData:>{"Chapter1.nb", "c:27"},
    ButtonStyle->"Hyperlink"],
  ".) "
}], "Text"],

Cell[TextData[{
  "\tSince this is a numerical solution to the problem, we must choose \
specific forms for the initial and boundary conditions explicitly, and we \
must also choose a numerical value for the thermal diffusivity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\)]],
  " and the size of the interval, ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  ". Below, we make these choices keeping ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(M\)\(=\)\(8\)\(\ \)\)\)]],
  "terms in the series expansion of the solution, and solving over a time \
interval of ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < \[Tau] = 15\)]],
  ":"
}], "Text"],

Cell[BoxData[{
    \(T0[x_]\  = \ 1; \ T1[t_]\  = 1 + \ Sin[t]; \ 
    S[x_, t_]\  = \ 0;\n\), "\[IndentingNewLine]", 
    \(\[Chi] = 1/8; \ b = 2; \ M = 8\ ; \ \[Tau] = 15. ;\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.33"],

Cell["\<\
The temperature on the left side of the slab oscillates in time, \
and on the right the temperature gradient is zero.  \
\>", "Text"],

Cell[TextData[{
  "\tTo construct the Galerkin solution to this problem, we first define the \
function ",
  Cell[BoxData[
      \(TraditionalForm\`u(x, t)\)]],
  ", according to Eq. ",
  ButtonBox["(6.1.19)",
    ButtonData:>"(6.1.19)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(u[x_, t_]\  = \ T1[t];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.34"],

Cell[TextData[{
  "We then define the inner product, as in Eq. ",
  ButtonBox["(6.1.21)",
    ButtonData:>"(6.1.21)",
    ButtonStyle->"Hyperlink"],
  ". In this case, we will assume that the functions to be integrated are \
sufficiently straightforward that the integrals can be done analytically \
using ",
  StyleBox["Integrate",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(\(norm[f_, g_]\)\(\ \)\(:=\)\(\ \)\(Integrate[
        f\ g, {x, 0, b}]\)\(\ \)\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.35"],

Cell[TextData[{
  "It is also useful to define the spatial operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^ = \[Chi]\ \
\[PartialD]\^2\(\(/\)\(\[PartialD]x\^2\)\)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(L[f_]\  := \ \[Chi]\ D[f, {x, 2}]\ ;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.36"],

Cell[TextData[{
  "Next, we define the projection of the operator onto the functions, ",
  Cell[BoxData[
      \(TraditionalForm\`L\_\(m\ n\) = \((v\_m, \(L\&^\) v\_n)\)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(Lmat[m_, n_]\  := \ norm[v[m, x], \ L[v[n, x]]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.37"],

Cell[TextData[{
  "We then define the inner product  of the functions with each other, ",
  Cell[BoxData[
      \(TraditionalForm\`\((v\_m, v\_n)\)\)]],
  " .  Here we use symmetry of the inner product with respect to the \
interchange of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " in order to reduce the number of integrations needed. Also, we use the \
double-equal-sign notation to store previously determined values of the inner \
product without redoing the integration:"
}], "Text"],

Cell[BoxData[{
    \(\(nm[n_, m_]\  := \ \((nm[n, m]\  = \ norm[v[m, x], v[n, x]]\ )\) /; 
          n \[GreaterEqual] \ m\ \ ;\)\), "\n", 
    \(nm[n_, m_]\  := \ 
      nm[m, n]\  /; \ \(\(n\)\(<\)\(m\)\(\ \ \)\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.38"],

Cell[TextData[{
  "Next, we define the projection of the source function ",
  Cell[BoxData[
      \(TraditionalForm\`\(S\&_\)(x, t)\)]],
  "onto the ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_m\)(x)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(Svec[m_]\  := \ 
        norm[v[m, x], \ 
          S[x, t] - D[u[x, t], t]\  + \ L[u[x, t]]];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.39"],

Cell["\<\
We are ready to specify the differential equations for the Fourier \
coefficients: \
\>", "Text"],

Cell[BoxData[
    \(\(eq[m_]\  := \(eq[m]\  = \ 
          Sum[nm[m, n]\ D[\(c[n]\)[t], t], {n, 1, M}]\  \[Equal] \ 
            Sum[Lmat[m, n]\ \(c[n]\)[t], {n, 1, M}]\  + \ 
              Svec[m]\);\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.40"],

Cell["It is useful to print out the equations as a check:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Do[Print["\<eq[\>", m, "\<]= \>", eq[m]], {m, 1, M}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.41"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "0", 
        "\[InvisibleSpace]", "\<\"]= \"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{
            RowBox[{\(16\/15\), " ", 
              RowBox[{
                SuperscriptBox[\(c[0]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(52\/45\), " ", 
              RowBox[{
                SuperscriptBox[\(c[1]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(152\/105\), " ", 
              RowBox[{
                SuperscriptBox[\(c[2]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(208\/105\), " ", 
              RowBox[{
                SuperscriptBox[\(c[3]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(544\/189\), " ", 
              RowBox[{
                SuperscriptBox[\(c[4]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(1376\/315\), " ", 
              RowBox[{
                SuperscriptBox[\(c[5]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(3392\/495\), " ", 
              RowBox[{
                SuperscriptBox[\(c[6]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            FractionBox[
              RowBox[{"16384", " ", 
                RowBox[{
                  SuperscriptBox[\(c[7]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "1485"]}], 
          "==", \(\(-\(\(4\ Cos[t]\)\/3\)\) - 1\/12\ \(c[0]\)[t] - 
            1\/12\ \(c[1]\)[t] - 1\/10\ \(c[2]\)[t] - 2\/15\ \(c[3]\)[t] - 
            4\/21\ \(c[4]\)[t] - 2\/7\ \(c[5]\)[t] - 4\/9\ \(c[6]\)[t] - 
            32\/45\ \(c[7]\)[t]\)}]}],
      SequenceForm[ "eq[", 0, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 16, 15], 
              Derivative[ 1][ 
                c[ 0]][ t]], 
            Times[ 
              Rational[ 52, 45], 
              Derivative[ 1][ 
                c[ 1]][ t]], 
            Times[ 
              Rational[ 152, 105], 
              Derivative[ 1][ 
                c[ 2]][ t]], 
            Times[ 
              Rational[ 208, 105], 
              Derivative[ 1][ 
                c[ 3]][ t]], 
            Times[ 
              Rational[ 544, 189], 
              Derivative[ 1][ 
                c[ 4]][ t]], 
            Times[ 
              Rational[ 1376, 315], 
              Derivative[ 1][ 
                c[ 5]][ t]], 
            Times[ 
              Rational[ 3392, 495], 
              Derivative[ 1][ 
                c[ 6]][ t]], 
            Times[ 
              Rational[ 16384, 1485], 
              Derivative[ 1][ 
                c[ 7]][ t]]], 
          Plus[ 
            Times[ 
              Rational[ -4, 3], 
              Cos[ t]], 
            Times[ 
              Rational[ -1, 12], 
              c[ 0][ t]], 
            Times[ 
              Rational[ -1, 12], 
              c[ 1][ t]], 
            Times[ 
              Rational[ -1, 10], 
              c[ 2][ t]], 
            Times[ 
              Rational[ -2, 15], 
              c[ 3][ t]], 
            Times[ 
              Rational[ -4, 21], 
              c[ 4][ t]], 
            Times[ 
              Rational[ -2, 7], 
              c[ 5][ t]], 
            Times[ 
              Rational[ -4, 9], 
              c[ 6][ t]], 
            Times[ 
              Rational[ -32, 45], 
              c[ 7][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "1", 
        "\[InvisibleSpace]", "\<\"]= \"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{
            RowBox[{\(52\/45\), " ", 
              RowBox[{
                SuperscriptBox[\(c[0]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(416\/315\), " ", 
              RowBox[{
                SuperscriptBox[\(c[1]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(12\/7\), " ", 
              RowBox[{
                SuperscriptBox[\(c[2]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(2272\/945\), " ", 
              RowBox[{
                SuperscriptBox[\(c[3]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(32\/9\), " ", 
              RowBox[{
                SuperscriptBox[\(c[4]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            FractionBox[
              RowBox[{"18944", " ", 
                RowBox[{
                  SuperscriptBox[\(c[5]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "3465"], "+",
             
            RowBox[{\(4288\/495\), " ", 
              RowBox[{
                SuperscriptBox[\(c[6]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            FractionBox[
              RowBox[{"54272", " ", 
                RowBox[{
                  SuperscriptBox[\(c[7]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "3861"]}], 
          "==", \(\(-\(\(4\ Cos[t]\)\/3\)\) - 1\/12\ \(c[0]\)[t] - 
            2\/15\ \(c[1]\)[t] - 1\/5\ \(c[2]\)[t] - 32\/105\ \(c[3]\)[t] - 
            10\/21\ \(c[4]\)[t] - 16\/21\ \(c[5]\)[t] - 56\/45\ \(c[6]\)[t] - 
            1024\/495\ \(c[7]\)[t]\)}]}],
      SequenceForm[ "eq[", 1, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 52, 45], 
              Derivative[ 1][ 
                c[ 0]][ t]], 
            Times[ 
              Rational[ 416, 315], 
              Derivative[ 1][ 
                c[ 1]][ t]], 
            Times[ 
              Rational[ 12, 7], 
              Derivative[ 1][ 
                c[ 2]][ t]], 
            Times[ 
              Rational[ 2272, 945], 
              Derivative[ 1][ 
                c[ 3]][ t]], 
            Times[ 
              Rational[ 32, 9], 
              Derivative[ 1][ 
                c[ 4]][ t]], 
            Times[ 
              Rational[ 18944, 3465], 
              Derivative[ 1][ 
                c[ 5]][ t]], 
            Times[ 
              Rational[ 4288, 495], 
              Derivative[ 1][ 
                c[ 6]][ t]], 
            Times[ 
              Rational[ 54272, 3861], 
              Derivative[ 1][ 
                c[ 7]][ t]]], 
          Plus[ 
            Times[ 
              Rational[ -4, 3], 
              Cos[ t]], 
            Times[ 
              Rational[ -1, 12], 
              c[ 0][ t]], 
            Times[ 
              Rational[ -2, 15], 
              c[ 1][ t]], 
            Times[ 
              Rational[ -1, 5], 
              c[ 2][ t]], 
            Times[ 
              Rational[ -32, 105], 
              c[ 3][ t]], 
            Times[ 
              Rational[ -10, 21], 
              c[ 4][ t]], 
            Times[ 
              Rational[ -16, 21], 
              c[ 5][ t]], 
            Times[ 
              Rational[ -56, 45], 
              c[ 6][ t]], 
            Times[ 
              Rational[ -1024, 495], 
              c[ 7][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "2", 
        "\[InvisibleSpace]", "\<\"]= \"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{
            RowBox[{\(152\/105\), " ", 
              RowBox[{
                SuperscriptBox[\(c[0]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(12\/7\), " ", 
              RowBox[{
                SuperscriptBox[\(c[1]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(16\/7\), " ", 
              RowBox[{
                SuperscriptBox[\(c[2]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(736\/225\), " ", 
              RowBox[{
                SuperscriptBox[\(c[3]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(2432\/495\), " ", 
              RowBox[{
                SuperscriptBox[\(c[4]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(2944\/385\), " ", 
              RowBox[{
                SuperscriptBox[\(c[5]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(5248\/429\), " ", 
              RowBox[{
                SuperscriptBox[\(c[6]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(16384\/819\), " ", 
              RowBox[{
                SuperscriptBox[\(c[7]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}]}], 
          "==", \(\(-\(\(8\ Cos[t]\)\/5\)\) - 1\/10\ \(c[0]\)[t] - 
            1\/5\ \(c[1]\)[t] - 12\/35\ \(c[2]\)[t] - 4\/7\ \(c[3]\)[t] - 
            20\/21\ \(c[4]\)[t] - 8\/5\ \(c[5]\)[t] - 448\/165\ \(c[6]\)[t] - 
            256\/55\ \(c[7]\)[t]\)}]}],
      SequenceForm[ "eq[", 2, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 152, 105], 
              Derivative[ 1][ 
                c[ 0]][ t]], 
            Times[ 
              Rational[ 12, 7], 
              Derivative[ 1][ 
                c[ 1]][ t]], 
            Times[ 
              Rational[ 16, 7], 
              Derivative[ 1][ 
                c[ 2]][ t]], 
            Times[ 
              Rational[ 736, 225], 
              Derivative[ 1][ 
                c[ 3]][ t]], 
            Times[ 
              Rational[ 2432, 495], 
              Derivative[ 1][ 
                c[ 4]][ t]], 
            Times[ 
              Rational[ 2944, 385], 
              Derivative[ 1][ 
                c[ 5]][ t]], 
            Times[ 
              Rational[ 5248, 429], 
              Derivative[ 1][ 
                c[ 6]][ t]], 
            Times[ 
              Rational[ 16384, 819], 
              Derivative[ 1][ 
                c[ 7]][ t]]], 
          Plus[ 
            Times[ 
              Rational[ -8, 5], 
              Cos[ t]], 
            Times[ 
              Rational[ -1, 10], 
              c[ 0][ t]], 
            Times[ 
              Rational[ -1, 5], 
              c[ 1][ t]], 
            Times[ 
              Rational[ -12, 35], 
              c[ 2][ t]], 
            Times[ 
              Rational[ -4, 7], 
              c[ 3][ t]], 
            Times[ 
              Rational[ -20, 21], 
              c[ 4][ t]], 
            Times[ 
              Rational[ -8, 5], 
              c[ 5][ t]], 
            Times[ 
              Rational[ -448, 165], 
              c[ 6][ t]], 
            Times[ 
              Rational[ -256, 55], 
              c[ 7][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "3", 
        "\[InvisibleSpace]", "\<\"]= \"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{
            RowBox[{\(208\/105\), " ", 
              RowBox[{
                SuperscriptBox[\(c[0]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(2272\/945\), " ", 
              RowBox[{
                SuperscriptBox[\(c[1]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(736\/225\), " ", 
              RowBox[{
                SuperscriptBox[\(c[2]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            FractionBox[
              RowBox[{"11776", " ", 
                RowBox[{
                  SuperscriptBox[\(c[3]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "2475"], "+",
             
            RowBox[{\(3584\/495\), " ", 
              RowBox[{
                SuperscriptBox[\(c[4]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            FractionBox[
              RowBox[{"171008", " ", 
                RowBox[{
                  SuperscriptBox[\(c[5]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "15015"], 
            "+", 
            RowBox[{\(3584\/195\), " ", 
              RowBox[{
                SuperscriptBox[\(c[6]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            FractionBox[
              RowBox[{"1859584", " ", 
                RowBox[{
                  SuperscriptBox[\(c[7]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "61425"]}], 
          "==", \(\(-\(\(32\ Cos[t]\)\/15\)\) - 2\/15\ \(c[0]\)[t] - 
            32\/105\ \(c[1]\)[t] - 4\/7\ \(c[2]\)[t] - 64\/63\ \(c[3]\)[t] - 
            16\/9\ \(c[4]\)[t] - 512\/165\ \(c[5]\)[t] - 
            896\/165\ \(c[6]\)[t] - 4096\/429\ \(c[7]\)[t]\)}]}],
      SequenceForm[ "eq[", 3, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 208, 105], 
              Derivative[ 1][ 
                c[ 0]][ t]], 
            Times[ 
              Rational[ 2272, 945], 
              Derivative[ 1][ 
                c[ 1]][ t]], 
            Times[ 
              Rational[ 736, 225], 
              Derivative[ 1][ 
                c[ 2]][ t]], 
            Times[ 
              Rational[ 11776, 2475], 
              Derivative[ 1][ 
                c[ 3]][ t]], 
            Times[ 
              Rational[ 3584, 495], 
              Derivative[ 1][ 
                c[ 4]][ t]], 
            Times[ 
              Rational[ 171008, 15015], 
              Derivative[ 1][ 
                c[ 5]][ t]], 
            Times[ 
              Rational[ 3584, 195], 
              Derivative[ 1][ 
                c[ 6]][ t]], 
            Times[ 
              Rational[ 1859584, 61425], 
              Derivative[ 1][ 
                c[ 7]][ t]]], 
          Plus[ 
            Times[ 
              Rational[ -32, 15], 
              Cos[ t]], 
            Times[ 
              Rational[ -2, 15], 
              c[ 0][ t]], 
            Times[ 
              Rational[ -32, 105], 
              c[ 1][ t]], 
            Times[ 
              Rational[ -4, 7], 
              c[ 2][ t]], 
            Times[ 
              Rational[ -64, 63], 
              c[ 3][ t]], 
            Times[ 
              Rational[ -16, 9], 
              c[ 4][ t]], 
            Times[ 
              Rational[ -512, 165], 
              c[ 5][ t]], 
            Times[ 
              Rational[ -896, 165], 
              c[ 6][ t]], 
            Times[ 
              Rational[ -4096, 429], 
              c[ 7][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "4", 
        "\[InvisibleSpace]", "\<\"]= \"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{
            RowBox[{\(544\/189\), " ", 
              RowBox[{
                SuperscriptBox[\(c[0]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(32\/9\), " ", 
              RowBox[{
                SuperscriptBox[\(c[1]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(2432\/495\), " ", 
              RowBox[{
                SuperscriptBox[\(c[2]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(3584\/495\), " ", 
              RowBox[{
                SuperscriptBox[\(c[3]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            FractionBox[
              RowBox[{"14336", " ", 
                RowBox[{
                  SuperscriptBox[\(c[4]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "1287"], "+",
             
            RowBox[{\(11264\/637\), " ", 
              RowBox[{
                SuperscriptBox[\(c[5]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(23552\/819\), " ", 
              RowBox[{
                SuperscriptBox[\(c[6]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(45056\/945\), " ", 
              RowBox[{
                SuperscriptBox[\(c[7]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}]}], 
          "==", \(\(-\(\(64\ Cos[t]\)\/21\)\) - 4\/21\ \(c[0]\)[t] - 
            10\/21\ \(c[1]\)[t] - 20\/21\ \(c[2]\)[t] - 16\/9\ \(c[3]\)[t] - 
            320\/99\ \(c[4]\)[t] - 64\/11\ \(c[5]\)[t] - 
            4480\/429\ \(c[6]\)[t] - 5120\/273\ \(c[7]\)[t]\)}]}],
      SequenceForm[ "eq[", 4, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 544, 189], 
              Derivative[ 1][ 
                c[ 0]][ t]], 
            Times[ 
              Rational[ 32, 9], 
              Derivative[ 1][ 
                c[ 1]][ t]], 
            Times[ 
              Rational[ 2432, 495], 
              Derivative[ 1][ 
                c[ 2]][ t]], 
            Times[ 
              Rational[ 3584, 495], 
              Derivative[ 1][ 
                c[ 3]][ t]], 
            Times[ 
              Rational[ 14336, 1287], 
              Derivative[ 1][ 
                c[ 4]][ t]], 
            Times[ 
              Rational[ 11264, 637], 
              Derivative[ 1][ 
                c[ 5]][ t]], 
            Times[ 
              Rational[ 23552, 819], 
              Derivative[ 1][ 
                c[ 6]][ t]], 
            Times[ 
              Rational[ 45056, 945], 
              Derivative[ 1][ 
                c[ 7]][ t]]], 
          Plus[ 
            Times[ 
              Rational[ -64, 21], 
              Cos[ t]], 
            Times[ 
              Rational[ -4, 21], 
              c[ 0][ t]], 
            Times[ 
              Rational[ -10, 21], 
              c[ 1][ t]], 
            Times[ 
              Rational[ -20, 21], 
              c[ 2][ t]], 
            Times[ 
              Rational[ -16, 9], 
              c[ 3][ t]], 
            Times[ 
              Rational[ -320, 99], 
              c[ 4][ t]], 
            Times[ 
              Rational[ -64, 11], 
              c[ 5][ t]], 
            Times[ 
              Rational[ -4480, 429], 
              c[ 6][ t]], 
            Times[ 
              Rational[ -5120, 273], 
              c[ 7][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "5", 
        "\[InvisibleSpace]", "\<\"]= \"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{
            RowBox[{\(1376\/315\), " ", 
              RowBox[{
                SuperscriptBox[\(c[0]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            FractionBox[
              RowBox[{"18944", " ", 
                RowBox[{
                  SuperscriptBox[\(c[1]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "3465"], "+",
             
            RowBox[{\(2944\/385\), " ", 
              RowBox[{
                SuperscriptBox[\(c[2]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            FractionBox[
              RowBox[{"171008", " ", 
                RowBox[{
                  SuperscriptBox[\(c[3]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "15015"], 
            "+", 
            RowBox[{\(11264\/637\), " ", 
              RowBox[{
                SuperscriptBox[\(c[4]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            FractionBox[
              RowBox[{"90112", " ", 
                RowBox[{
                  SuperscriptBox[\(c[5]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "3185"], "+",
             
            RowBox[{\(4864\/105\), " ", 
              RowBox[{
                SuperscriptBox[\(c[6]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            FractionBox[
              RowBox[{"413696", " ", 
                RowBox[{
                  SuperscriptBox[\(c[7]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "5355"]}], 
          "==", \(\(-\(\(32\ Cos[t]\)\/7\)\) - 2\/7\ \(c[0]\)[t] - 
            16\/21\ \(c[1]\)[t] - 8\/5\ \(c[2]\)[t] - 512\/165\ \(c[3]\)[t] - 
            64\/11\ \(c[4]\)[t] - 1536\/143\ \(c[5]\)[t] - 
            256\/13\ \(c[6]\)[t] - 16384\/455\ \(c[7]\)[t]\)}]}],
      SequenceForm[ "eq[", 5, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 1376, 315], 
              Derivative[ 1][ 
                c[ 0]][ t]], 
            Times[ 
              Rational[ 18944, 3465], 
              Derivative[ 1][ 
                c[ 1]][ t]], 
            Times[ 
              Rational[ 2944, 385], 
              Derivative[ 1][ 
                c[ 2]][ t]], 
            Times[ 
              Rational[ 171008, 15015], 
              Derivative[ 1][ 
                c[ 3]][ t]], 
            Times[ 
              Rational[ 11264, 637], 
              Derivative[ 1][ 
                c[ 4]][ t]], 
            Times[ 
              Rational[ 90112, 3185], 
              Derivative[ 1][ 
                c[ 5]][ t]], 
            Times[ 
              Rational[ 4864, 105], 
              Derivative[ 1][ 
                c[ 6]][ t]], 
            Times[ 
              Rational[ 413696, 5355], 
              Derivative[ 1][ 
                c[ 7]][ t]]], 
          Plus[ 
            Times[ 
              Rational[ -32, 7], 
              Cos[ t]], 
            Times[ 
              Rational[ -2, 7], 
              c[ 0][ t]], 
            Times[ 
              Rational[ -16, 21], 
              c[ 1][ t]], 
            Times[ 
              Rational[ -8, 5], 
              c[ 2][ t]], 
            Times[ 
              Rational[ -512, 165], 
              c[ 3][ t]], 
            Times[ 
              Rational[ -64, 11], 
              c[ 4][ t]], 
            Times[ 
              Rational[ -1536, 143], 
              c[ 5][ t]], 
            Times[ 
              Rational[ -256, 13], 
              c[ 6][ t]], 
            Times[ 
              Rational[ -16384, 455], 
              c[ 7][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "6", 
        "\[InvisibleSpace]", "\<\"]= \"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{
            RowBox[{\(3392\/495\), " ", 
              RowBox[{
                SuperscriptBox[\(c[0]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(4288\/495\), " ", 
              RowBox[{
                SuperscriptBox[\(c[1]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(5248\/429\), " ", 
              RowBox[{
                SuperscriptBox[\(c[2]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(3584\/195\), " ", 
              RowBox[{
                SuperscriptBox[\(c[3]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(23552\/819\), " ", 
              RowBox[{
                SuperscriptBox[\(c[4]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(4864\/105\), " ", 
              RowBox[{
                SuperscriptBox[\(c[5]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(19456\/255\), " ", 
              RowBox[{
                SuperscriptBox[\(c[6]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            FractionBox[
              RowBox[{"176128", " ", 
                RowBox[{
                  SuperscriptBox[\(c[7]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "1377"]}], 
          "==", \(\(-\(\(64\ Cos[t]\)\/9\)\) - 4\/9\ \(c[0]\)[t] - 
            56\/45\ \(c[1]\)[t] - 448\/165\ \(c[2]\)[t] - 
            896\/165\ \(c[3]\)[t] - 4480\/429\ \(c[4]\)[t] - 
            256\/13\ \(c[5]\)[t] - 7168\/195\ \(c[6]\)[t] - 
            1024\/15\ \(c[7]\)[t]\)}]}],
      SequenceForm[ "eq[", 6, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 3392, 495], 
              Derivative[ 1][ 
                c[ 0]][ t]], 
            Times[ 
              Rational[ 4288, 495], 
              Derivative[ 1][ 
                c[ 1]][ t]], 
            Times[ 
              Rational[ 5248, 429], 
              Derivative[ 1][ 
                c[ 2]][ t]], 
            Times[ 
              Rational[ 3584, 195], 
              Derivative[ 1][ 
                c[ 3]][ t]], 
            Times[ 
              Rational[ 23552, 819], 
              Derivative[ 1][ 
                c[ 4]][ t]], 
            Times[ 
              Rational[ 4864, 105], 
              Derivative[ 1][ 
                c[ 5]][ t]], 
            Times[ 
              Rational[ 19456, 255], 
              Derivative[ 1][ 
                c[ 6]][ t]], 
            Times[ 
              Rational[ 176128, 1377], 
              Derivative[ 1][ 
                c[ 7]][ t]]], 
          Plus[ 
            Times[ 
              Rational[ -64, 9], 
              Cos[ t]], 
            Times[ 
              Rational[ -4, 9], 
              c[ 0][ t]], 
            Times[ 
              Rational[ -56, 45], 
              c[ 1][ t]], 
            Times[ 
              Rational[ -448, 165], 
              c[ 2][ t]], 
            Times[ 
              Rational[ -896, 165], 
              c[ 3][ t]], 
            Times[ 
              Rational[ -4480, 429], 
              c[ 4][ t]], 
            Times[ 
              Rational[ -256, 13], 
              c[ 5][ t]], 
            Times[ 
              Rational[ -7168, 195], 
              c[ 6][ t]], 
            Times[ 
              Rational[ -1024, 15], 
              c[ 7][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "7", 
        "\[InvisibleSpace]", "\<\"]= \"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{
            FractionBox[
              RowBox[{"16384", " ", 
                RowBox[{
                  SuperscriptBox[\(c[0]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "1485"], "+",
             
            FractionBox[
              RowBox[{"54272", " ", 
                RowBox[{
                  SuperscriptBox[\(c[1]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "3861"], "+",
             
            RowBox[{\(16384\/819\), " ", 
              RowBox[{
                SuperscriptBox[\(c[2]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            FractionBox[
              RowBox[{"1859584", " ", 
                RowBox[{
                  SuperscriptBox[\(c[3]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "61425"], 
            "+", 
            RowBox[{\(45056\/945\), " ", 
              RowBox[{
                SuperscriptBox[\(c[4]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            FractionBox[
              RowBox[{"413696", " ", 
                RowBox[{
                  SuperscriptBox[\(c[5]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "5355"], "+",
             
            FractionBox[
              RowBox[{"176128", " ", 
                RowBox[{
                  SuperscriptBox[\(c[6]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "1377"], "+",
             
            FractionBox[
              RowBox[{"5636096", " ", 
                RowBox[{
                  SuperscriptBox[\(c[7]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "26163"]}], 
          "==", \(\(-\(\(512\ Cos[t]\)\/45\)\) - 32\/45\ \(c[0]\)[t] - 
            1024\/495\ \(c[1]\)[t] - 256\/55\ \(c[2]\)[t] - 
            4096\/429\ \(c[3]\)[t] - 5120\/273\ \(c[4]\)[t] - 
            16384\/455\ \(c[5]\)[t] - 1024\/15\ \(c[6]\)[t] - 
            32768\/255\ \(c[7]\)[t]\)}]}],
      SequenceForm[ "eq[", 7, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 16384, 1485], 
              Derivative[ 1][ 
                c[ 0]][ t]], 
            Times[ 
              Rational[ 54272, 3861], 
              Derivative[ 1][ 
                c[ 1]][ t]], 
            Times[ 
              Rational[ 16384, 819], 
              Derivative[ 1][ 
                c[ 2]][ t]], 
            Times[ 
              Rational[ 1859584, 61425], 
              Derivative[ 1][ 
                c[ 3]][ t]], 
            Times[ 
              Rational[ 45056, 945], 
              Derivative[ 1][ 
                c[ 4]][ t]], 
            Times[ 
              Rational[ 413696, 5355], 
              Derivative[ 1][ 
                c[ 5]][ t]], 
            Times[ 
              Rational[ 176128, 1377], 
              Derivative[ 1][ 
                c[ 6]][ t]], 
            Times[ 
              Rational[ 5636096, 26163], 
              Derivative[ 1][ 
                c[ 7]][ t]]], 
          Plus[ 
            Times[ 
              Rational[ -512, 45], 
              Cos[ t]], 
            Times[ 
              Rational[ -32, 45], 
              c[ 0][ t]], 
            Times[ 
              Rational[ -1024, 495], 
              c[ 1][ t]], 
            Times[ 
              Rational[ -256, 55], 
              c[ 2][ t]], 
            Times[ 
              Rational[ -4096, 429], 
              c[ 3][ t]], 
            Times[ 
              Rational[ -5120, 273], 
              c[ 4][ t]], 
            Times[ 
              Rational[ -16384, 455], 
              c[ 5][ t]], 
            Times[ 
              Rational[ -1024, 15], 
              c[ 6][ t]], 
            Times[ 
              Rational[ -32768, 255], 
              c[ 7][ t]]]]],
      Editable->False]], "Print"]
}, Closed]],

Cell[TextData[{
  "The initial conditions on the Fourier coefficients are specified according \
to Eq. ",
  ButtonBox["(6.1.26)",
    ButtonData:>"(6.1.26)",
    ButtonStyle->"Hyperlink"],
  ". We print these out as well:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ic[m_]\  := \ \(ic[m]\  = \ 
          Sum[nm[m, n]\ \(c[n]\)[0], {n, 1, M}]\  \[Equal] \ 
            norm[v[m, x], T0[x] - u[x, 0]]\);\)\n\), "\[IndentingNewLine]", 
    \(\(Do[Print["\<ic[\>", m, "\<]= \>", ic[m]], {m, 1, M}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.42"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]0\[InvisibleSpace]"]= "\
\[InvisibleSpace]\(16\/15\ \(c[0]\)[0] + 52\/45\ \(c[1]\)[0] + 
            152\/105\ \(c[2]\)[0] + 208\/105\ \(c[3]\)[0] + 
            544\/189\ \(c[4]\)[0] + 1376\/315\ \(c[5]\)[0] + 
            3392\/495\ \(c[6]\)[0] + \(16384\ \(c[7]\)[0]\)\/1485 == 0\)\),
      SequenceForm[ "ic[", 0, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 16, 15], 
              c[ 0][ 0]], 
            Times[ 
              Rational[ 52, 45], 
              c[ 1][ 0]], 
            Times[ 
              Rational[ 152, 105], 
              c[ 2][ 0]], 
            Times[ 
              Rational[ 208, 105], 
              c[ 3][ 0]], 
            Times[ 
              Rational[ 544, 189], 
              c[ 4][ 0]], 
            Times[ 
              Rational[ 1376, 315], 
              c[ 5][ 0]], 
            Times[ 
              Rational[ 3392, 495], 
              c[ 6][ 0]], 
            Times[ 
              Rational[ 16384, 1485], 
              c[ 7][ 0]]], 0]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]1\[InvisibleSpace]"]= "\
\[InvisibleSpace]\(52\/45\ \(c[0]\)[0] + 416\/315\ \(c[1]\)[0] + 
            12\/7\ \(c[2]\)[0] + 2272\/945\ \(c[3]\)[0] + 
            32\/9\ \(c[4]\)[0] + \(18944\ \(c[5]\)[0]\)\/3465 + 
            4288\/495\ \(c[6]\)[0] + \(54272\ \(c[7]\)[0]\)\/3861 == 0\)\),
      SequenceForm[ "ic[", 1, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 52, 45], 
              c[ 0][ 0]], 
            Times[ 
              Rational[ 416, 315], 
              c[ 1][ 0]], 
            Times[ 
              Rational[ 12, 7], 
              c[ 2][ 0]], 
            Times[ 
              Rational[ 2272, 945], 
              c[ 3][ 0]], 
            Times[ 
              Rational[ 32, 9], 
              c[ 4][ 0]], 
            Times[ 
              Rational[ 18944, 3465], 
              c[ 5][ 0]], 
            Times[ 
              Rational[ 4288, 495], 
              c[ 6][ 0]], 
            Times[ 
              Rational[ 54272, 3861], 
              c[ 7][ 0]]], 0]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]2\[InvisibleSpace]"]= "\
\[InvisibleSpace]\(152\/105\ \(c[0]\)[0] + 12\/7\ \(c[1]\)[0] + 
            16\/7\ \(c[2]\)[0] + 736\/225\ \(c[3]\)[0] + 
            2432\/495\ \(c[4]\)[0] + 2944\/385\ \(c[5]\)[0] + 
            5248\/429\ \(c[6]\)[0] + 16384\/819\ \(c[7]\)[0] == 0\)\),
      SequenceForm[ "ic[", 2, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 152, 105], 
              c[ 0][ 0]], 
            Times[ 
              Rational[ 12, 7], 
              c[ 1][ 0]], 
            Times[ 
              Rational[ 16, 7], 
              c[ 2][ 0]], 
            Times[ 
              Rational[ 736, 225], 
              c[ 3][ 0]], 
            Times[ 
              Rational[ 2432, 495], 
              c[ 4][ 0]], 
            Times[ 
              Rational[ 2944, 385], 
              c[ 5][ 0]], 
            Times[ 
              Rational[ 5248, 429], 
              c[ 6][ 0]], 
            Times[ 
              Rational[ 16384, 819], 
              c[ 7][ 0]]], 0]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]3\[InvisibleSpace]"]= "\
\[InvisibleSpace]\(208\/105\ \(c[0]\)[0] + 2272\/945\ \(c[1]\)[0] + 
            736\/225\ \(c[2]\)[0] + \(11776\ \(c[3]\)[0]\)\/2475 + 
            3584\/495\ \(c[4]\)[0] + \(171008\ \(c[5]\)[0]\)\/15015 + 
            3584\/195\ \(c[6]\)[0] + \(1859584\ \(c[7]\)[0]\)\/61425 == 0\)\),
      
      SequenceForm[ "ic[", 3, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 208, 105], 
              c[ 0][ 0]], 
            Times[ 
              Rational[ 2272, 945], 
              c[ 1][ 0]], 
            Times[ 
              Rational[ 736, 225], 
              c[ 2][ 0]], 
            Times[ 
              Rational[ 11776, 2475], 
              c[ 3][ 0]], 
            Times[ 
              Rational[ 3584, 495], 
              c[ 4][ 0]], 
            Times[ 
              Rational[ 171008, 15015], 
              c[ 5][ 0]], 
            Times[ 
              Rational[ 3584, 195], 
              c[ 6][ 0]], 
            Times[ 
              Rational[ 1859584, 61425], 
              c[ 7][ 0]]], 0]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]4\[InvisibleSpace]"]= "\
\[InvisibleSpace]\(544\/189\ \(c[0]\)[0] + 32\/9\ \(c[1]\)[0] + 
            2432\/495\ \(c[2]\)[0] + 
            3584\/495\ \(c[3]\)[0] + \(14336\ \(c[4]\)[0]\)\/1287 + 
            11264\/637\ \(c[5]\)[0] + 23552\/819\ \(c[6]\)[0] + 
            45056\/945\ \(c[7]\)[0] == 0\)\),
      SequenceForm[ "ic[", 4, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 544, 189], 
              c[ 0][ 0]], 
            Times[ 
              Rational[ 32, 9], 
              c[ 1][ 0]], 
            Times[ 
              Rational[ 2432, 495], 
              c[ 2][ 0]], 
            Times[ 
              Rational[ 3584, 495], 
              c[ 3][ 0]], 
            Times[ 
              Rational[ 14336, 1287], 
              c[ 4][ 0]], 
            Times[ 
              Rational[ 11264, 637], 
              c[ 5][ 0]], 
            Times[ 
              Rational[ 23552, 819], 
              c[ 6][ 0]], 
            Times[ 
              Rational[ 45056, 945], 
              c[ 7][ 0]]], 0]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]5\[InvisibleSpace]"]= "\
\[InvisibleSpace]\(1376\/315\ \(c[0]\)[0] + \(18944\ \(c[1]\)[0]\)\/3465 + 
            2944\/385\ \(c[2]\)[0] + \(171008\ \(c[3]\)[0]\)\/15015 + 
            11264\/637\ \(c[4]\)[0] + \(90112\ \(c[5]\)[0]\)\/3185 + 
            4864\/105\ \(c[6]\)[0] + \(413696\ \(c[7]\)[0]\)\/5355 == 0\)\),
      SequenceForm[ "ic[", 5, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 1376, 315], 
              c[ 0][ 0]], 
            Times[ 
              Rational[ 18944, 3465], 
              c[ 1][ 0]], 
            Times[ 
              Rational[ 2944, 385], 
              c[ 2][ 0]], 
            Times[ 
              Rational[ 171008, 15015], 
              c[ 3][ 0]], 
            Times[ 
              Rational[ 11264, 637], 
              c[ 4][ 0]], 
            Times[ 
              Rational[ 90112, 3185], 
              c[ 5][ 0]], 
            Times[ 
              Rational[ 4864, 105], 
              c[ 6][ 0]], 
            Times[ 
              Rational[ 413696, 5355], 
              c[ 7][ 0]]], 0]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]6\[InvisibleSpace]"]= "\
\[InvisibleSpace]\(3392\/495\ \(c[0]\)[0] + 4288\/495\ \(c[1]\)[0] + 
            5248\/429\ \(c[2]\)[0] + 3584\/195\ \(c[3]\)[0] + 
            23552\/819\ \(c[4]\)[0] + 4864\/105\ \(c[5]\)[0] + 
            19456\/255\ \(c[6]\)[0] + \(176128\ \(c[7]\)[0]\)\/1377 == 0\)\),
      SequenceForm[ "ic[", 6, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 3392, 495], 
              c[ 0][ 0]], 
            Times[ 
              Rational[ 4288, 495], 
              c[ 1][ 0]], 
            Times[ 
              Rational[ 5248, 429], 
              c[ 2][ 0]], 
            Times[ 
              Rational[ 3584, 195], 
              c[ 3][ 0]], 
            Times[ 
              Rational[ 23552, 819], 
              c[ 4][ 0]], 
            Times[ 
              Rational[ 4864, 105], 
              c[ 5][ 0]], 
            Times[ 
              Rational[ 19456, 255], 
              c[ 6][ 0]], 
            Times[ 
              Rational[ 176128, 1377], 
              c[ 7][ 0]]], 0]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]7\[InvisibleSpace]"]= "\
\[InvisibleSpace]\(\(16384\ \(c[0]\)[0]\)\/1485 + \(54272\ \
\(c[1]\)[0]\)\/3861 + 
            16384\/819\ \(c[2]\)[0] + \(1859584\ \(c[3]\)[0]\)\/61425 + 
            45056\/945\ \(c[4]\)[
                0] + \(413696\ \(c[5]\)[0]\)\/5355 + \(176128\ \
\(c[6]\)[0]\)\/1377 + \(5636096\ \(c[7]\)[0]\)\/26163 == 0\)\),
      SequenceForm[ "ic[", 7, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 16384, 1485], 
              c[ 0][ 0]], 
            Times[ 
              Rational[ 54272, 3861], 
              c[ 1][ 0]], 
            Times[ 
              Rational[ 16384, 819], 
              c[ 2][ 0]], 
            Times[ 
              Rational[ 1859584, 61425], 
              c[ 3][ 0]], 
            Times[ 
              Rational[ 45056, 945], 
              c[ 4][ 0]], 
            Times[ 
              Rational[ 413696, 5355], 
              c[ 5][ 0]], 
            Times[ 
              Rational[ 176128, 1377], 
              c[ 6][ 0]], 
            Times[ 
              Rational[ 5636096, 26163], 
              c[ 7][ 0]]], 0]],
      Editable->False]], "Print"]
}, Closed]],

Cell[TextData[{
  "In order to use ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to determine the solution to the coupled ODEs, we must make a list of the \
equations and initial conditions:"
}], "Text"],

Cell[BoxData[
    \(\(eqns\  = \ 
        Join[Table[eq[m], {m, 1, M}], Table[ic[m], {m, 1, M}]];\)\)], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 6.43"],

Cell["\<\
Also, we create a list of the variables for which we are solving:\
\
\>", "Text"],

Cell[BoxData[
    \(\(vars\  = \ Table[\(c[m]\)[t], {m, 1, M}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.44"],

Cell[TextData[{
  "Finally, we solve the equations over a time ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Tau]\)\(\ \)\)\)]],
  " and define the solution:"
}], "Text"],

Cell[BoxData[{
    \(\(\(coefficients\  = \ \(NDSolve[eqns, vars, {t, 0, \[Tau]}, 
            MaxSteps \[Rule] 5000]\)[\([1]\)];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(T[x_, t_]\  = \ 
        u[x, t]\  + \ 
          Evaluate[Sum[\(c[n]\)[t]\ v[n, x], {n, 1, M}]];\)\), "\n", 
    \(\(T[x_, t_]\  = \ T[x, t] /. coefficients;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.45"],

Cell[TextData[{
  "Cell ",
  ButtonBox["6.46",
    ButtonData:>"Cell 6.46",
    ButtonStyle->"Hyperlink"],
  " displays our solution."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        Plot[T[x, t], {x, 0, b}, PlotRange \[Rule] {{0, 2}, {0, 2}}, 
          AxesLabel \[Rule] {"\<x\>", "\<\>"}, 
          PlotLabel \[Rule] "\<T[x,t], t=\>" <> ToString[t]], {t, 0, 
          15,  .5}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.46"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.04057 .30902 L
.08481 .30902 L
.12636 .30902 L
.16632 .30902 L
.20885 .30902 L
.2498 .30902 L
.29331 .30902 L
.33524 .30902 L
.37557 .30902 L
.41848 .30902 L
.4598 .30902 L
.49953 .30902 L
.54183 .30902 L
.58254 .30902 L
.62583 .30902 L
.66752 .30902 L
.70762 .30902 L
.7503 .30902 L
.79139 .30902 L
.83505 .30902 L
.87712 .30902 L
.9176 .30902 L
.96065 .30902 L
1 .30902 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00>@3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?oo
o`D00000103oool01@14A4@000000000000c<c<0gMgM00`0oooo00D0k^k^03<c<`000000<c<c0>k^
kP050?ooo`808R8R1@3oool01@14A4@000000000000c<c<0gMgM00`0oooo00D0k^k^03<c<`000000
<c<c0>k^kP050?ooo`808R8R1P3oool00`000000k^k^0?ooo`040?ooo`0504A4A0000000000003<c
<`3MgMd05@3oool400000003014A4@3oool0oooo01<0oooo100000000`0A4A40oooo0?ooo`020?oo
o`808R8R103oool5000000@0oooo00D0A4A4000000000000<c<c0=gMg@0=0?ooo`@0000000<04A4A
0?ooo`3oool00P3oool2028R8PD0oooo00D0A4A4000000000000<c<c0=gMg@0=0?ooo`@0000000<0
4A4A0?ooo`3oool00P3oool2028R8PH0oooo00<000000>k^kP3oool0103oool01@14A4@000000000
000c<c<0gMgM01@0oooo1@00000D0?ooo`00>@3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo
0P0R8R840?ooo`0509VIV@0R8R80k^k^0?ooo`14A4@01`3oool00`1gMgL0<c<c0?ooo`0;0?ooo`05
07MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PP0oooo00<0MgMg03<c<`3oool02`3oool01@1g
MgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R860?ooo`0305EEE@2ZZZX0oooo00L0oooo00<0MgMg
03<c<`3oool05P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo0P0R8R84
0?ooo`0509VIV@0R8R80k^k^0?ooo`14A4@01`3oool00`1gMgL0<c<c0?ooo`0>0?ooo`030000003o
ool0oooo00@0oooo0P0R8R880?ooo`0307MgM`0c<c<0oooo00h0oooo00<000000?ooo`3oool0103o
ool2028R8PH0oooo00<0EEEE0:ZZZP3oool01`3oool00`1gMgL0<c<c0?ooo`0C0?ooo`0509VIV@0R
8R80k^k^0?ooo`14A4@0503oool003T0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`0309VI
V@0R8R80k^k^00T0oooo00<000000?ooo`3oool02P3oool01@0A4A40oooo0?ooo`3oool04A4A0100
oooo00<000000?ooo`3oool02P3oool01@0A4A40oooo0?ooo`3oool04A4A00d0oooo00<0ZZZZ05EE
E@3oool0203oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool02`3oool00`2IVIT08R8R0>k^kP090?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<0ZZZZ05EE
E@3oool0203oool00`000000oooo0?ooo`0C0?ooo`0309VIV@0R8R80k^k^01D0oooo000i0?ooo`05
0000003oool0oooo0?ooo`0000003@3oool00`2IVIT08R8R0>k^kP070?ooo`0307MgM`0c<c<0oooo
00/0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`0307MgM`0c<c<0oooo00/0oooo00D00000
0?ooo`3oool0oooo0000000>0?ooo`03014A4@3oool0oooo00H0oooo00<0MgMg03<c<`3oool05P3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00`0oooo00<0VIVI028R8P3^k^h01`3o
ool00`1gMgL0<c<c0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<0MgMg03<c<`3oool03P3o
ool00`000000oooo0?ooo`0=0?ooo`03014A4@3oool0oooo00H0oooo00<0MgMg03<c<`3oool05@3o
ool00`2IVIT08R8R0>k^kP0D0?ooo`00>@3oool01@000000oooo0?ooo`3oool0000000h0oooo00<0
MgMg06IVIP3oool00`3oool01@0000008R8R0000000c<c<0c<c<00`0oooo00D000000?ooo`3oool0
oooo0000000<0?ooo`050000000R8R80000003<c<`3<c<`0303oool01@000000oooo0?ooo`3oool0
000000h0oooo00<0EEEE0<c<c03oool00`3oool01@0000008R8R0000000c<c<0c<c<01L0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0=0?ooo`0307MgM`1VIVH0oooo00<0oooo00D0
0000028R8P000000<c<c0<c<c00?0?ooo`030000003oool0oooo00/0oooo00D00000028R8P000000
<c<c0<c<c00?0?ooo`030000003oool0oooo00d0oooo00<0EEEE0<c<c03oool00`3oool01@000000
8R8R0000000c<c<0c<c<01L0oooo00<0MgMg06IVIP3oool04`3oool003T0oooo00D04A4A0?ooo`3o
ool0oooo014A4@0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool01@0A
4A40oooo0?ooo`3oool04A4A00`0oooo00<000000?ooo`3oool03P3oool01@0A4A40oooo0?ooo`3o
ool04A4A00h0oooo00<0ZZZZ07MgM`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00d0oooo00<0ZZZZ07MgM`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo0180oooo000i0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL02`3oool01@000000^k^k0?oo
o`2IVIT04A4A00@0oooo00<000000?ooo`3oool03P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0
oooo00<000000?ooo`3oool03P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00D04A4A0?oo
o`3oool0oooo03<c<`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0:0?ooo`050000002k^k/0oooo09VIV@0A4A40103oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0:0?ooo`05014A4@3oool0oooo0?ooo`0c<c<0103oool00`000000oooo0?ooo`0F0?ooo`050000
002k^k/0oooo09VIV@0A4A40503oool003T0oooo00D0k^k^03<c<`000000<c<c0>k^kP0;0?ooo`05
09VIV@0A4A400000028R8P3<c<`0103oool4000000d0oooo00D0k^k^03<c<`000000<c<c0>k^kP0<
0?ooo`@000003@3oool01@3^k^h0<c<c0000000c<c<0k^k^00/0oooo1@0000040?ooo`@000005P3o
ool205EEE@030000003oool0oooo01D0oooo0P1EEED00`000000oooo0?ooo`0:0?ooo`0509VIV@0A
4A400000028R8P3<c<`0103oool4000000h0oooo0P1EEED00`000000oooo0?ooo`0;0?ooo`@00000
3P3oool205EEE@030000003oool0oooo00X0oooo1@0000040?ooo`@000005@3oool01@2IVIT04A4A
0000000R8R80c<c<01@0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?oooeh0oooo0P000002
0?ooo`8000001@3oool00?l0ooooGP3oool01P3^k^h08R8R08R8R03<c<`000000<c<c0D0oooo003o
0?oooel0oooo00@0gMgM000000000000c<c<1P3oool00280ooooo`00000b000000/0oooo00@0k^k^
028R8P000000k^k^1P3oool00280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`08
0?ooo`050>k^kP0R8R80MgMg07MgM`0c<c<01P3oool00280oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo0P0000020?ooo`8000001@3oool0
0280oooo00<000000?ooo`3oool0o`3ooom40?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0
oooo000R0?ooo`800000o`3ooom50?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0oooo000R
0?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo00<000000?ooo`3oool0o`3ooom40?oo
o`008P3oool00`000000oooo0?ooo`3o0?oood@0oooo000R0?ooo`800000o`3ooom50?ooo`008P3o
ool00`000000oooo0?ooo`3o0?oood@0oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool0
0280oooo00<000000?ooo`3oool0o`3ooom40?ooo`008P3oool200000?l0ooooA@3oool00280oooo
00<000000?ooo`3oool0o`3ooom40?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0oooo000R
0?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo00<000000?ooo`3oool0o`3ooom40?oo
o`008P3oool200000?l0ooooA@3oool00280oooo00<000000?ooo`3oool0o`3ooom40?ooo`0000@0
<c<c0000000c<c<0k^k^1@3oool2028R8P@0oooo1@0000040?ooo`0504A4A0000000000003<c<`3M
gMd01@3oool00`000000oooo0?ooo`3o0?oood@0oooo0000102IVIT0oooo09VIV@1gMgL50?ooo`80
8R8R103oool01@2IVIT08R8R0>k^kP3oool0A4A400L0oooo00<0MgMg03<c<`3oool0103oool00`00
0000oooo0?ooo`3o0?oood@0oooo00030?ooo`03014A4@3oool0oooo00X0oooo00<0VIVI028R8P3^
k^h02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0ooooA03oool000<0oooo
00<000000?ooo`3oool02`3oool00`2IVIT08R8R0>k^kP070?ooo`0307MgM`0c<c<0oooo00@0oooo
0`00003o0?oood@0oooo00030?ooo`030000003oool0oooo00`0oooo00<0MgMg06IVIP3oool00`3o
ool01@0000008R8R0000000c<c<0c<c<00D0oooo00<000000?ooo`3oool0o`3ooom40?ooo`000`3o
ool00`0A4A40oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`3o0?oood@0oooo0000102IVIT0oooo09VIV@1gMgL;0?ooo`050000002k
^k/0oooo09VIV@0A4A40103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0oooo
A03oool0000403<c<`000000<c<c0>k^kP/0oooo00D0VIVI014A4@0000008R8R0<c<c0040?ooo`@0
00001P3oool200000?l0ooooA@3oool00280oooo00<000000?ooo`3oool0o`3ooom40?ooo`008P3o
ool00`000000oooo0?ooo`3o0?oood@0oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool0
0280oooo00<000000?ooo`3oool0o`3ooom40?ooo`008P3oool200000?l0ooooA@3oool00280oooo
00<000000?ooo`3oool0o`3ooom40?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0oooo000R
0?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo00<000000?ooo`3oool0o`3ooom40?oo
o`008P3oool200000?l0ooooA@3oool00280oooo00<000000?ooo`3oool0o`3ooom40?ooo`008P3o
ool00`000000oooo0?ooo`3o0?oood@0oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool0
0280oooo0P00003o0?ooodD0oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo
00<000000?ooo`3oool0o`3ooom40?ooo`001`3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo
0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd01@3oool00`000000oooo0?ooo`3o0?oood@0
oooo00070?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PP0oooo00<0MgMg03<c<`3o
ool0103oool00`000000oooo0?ooo`3o0?oood@0oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A
4A40403oool00`000000oooo0?ooo`030?ooo`<00000o`3ooom40?ooo`001`3oool01@000000oooo
0?ooo`3oool0000000l0oooo00<0MgMg03<c<`3oool0103oool00`000000oooo0?ooo`3o0?oood@0
oooo00070?ooo`050000003oool0oooo0?ooo`000000303oool01@0000008R8R0000000c<c<0c<c<
00D0oooo00<000000?ooo`3oool0o`3ooom40?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A
00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oood@0oooo00070?ooo`05
07MgM`2IVIT0oooo09VIV@1gMgL0303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0?l0ooooA03oool000L0oooo00D0k^k^03<c<`000000<c<c0>k^kP0<0?ooo`@000001P3oool20000
0?l0ooooA@3oool00280oooo00<000000?ooo`3oool0o`3ooom40?ooo`008P3oool00`000000oooo
0?ooo`3o0?oood@0oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo0P00003o
0?ooodD0oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo00<000000?ooo`3o
ool0o`3ooom40?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0oooo000R0?ooo`030000003o
ool0oooo0?l0ooooA03oool00280oooo0P00003o0?ooodD0oooo000R0?ooo`030000003oool0oooo
0?l0ooooA03oool00280oooo00<000000?ooo`3oool0o`3ooom40?ooo`008P3oool00`000000oooo
0?ooo`3o0?oood@0oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo0P00003o
0?ooodD0oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool0000403<c<`000000<c<c0>k^
kPD0oooo0P0R8R860?ooo`030000003^k^h0oooo00@0oooo00D0A4A4000000000000<c<c0=gMg@05
0?ooo`030000003oool0oooo0?l0ooooA03oool0000409VIV@3oool0VIVI07MgM`D0oooo0P0R8R86
0?ooo`0305EEE@2ZZZX0oooo00L0oooo00<0MgMg03<c<`3oool0103oool00`000000oooo0?ooo`3o
0?oood@0oooo00030?ooo`03014A4@3oool0oooo00/0oooo00<0ZZZZ05EEE@3oool0203oool00`00
0000oooo0?ooo`030?ooo`<00000o`3ooom40?ooo`000`3oool00`000000oooo0?ooo`0<0?ooo`03
014A4@3oool0oooo00H0oooo00<0MgMg03<c<`3oool0103oool00`000000oooo0?ooo`3o0?oood@0
oooo00030?ooo`030000003oool0oooo00`0oooo00<0EEEE0<c<c03oool00`3oool01@0000008R8R
0000000c<c<0c<c<00D0oooo00<000000?ooo`3oool0o`3ooom40?ooo`000`3oool00`0A4A40oooo
0?ooo`0<0?ooo`030:ZZZP1gMgL0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`3o0?oood@0oooo0000102IVIT0oooo09VIV@1gMgL;0?ooo`05014A4@3oool0oooo0?ooo`0c
<c<0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooA03oool0000403<c
<`000000<c<c0>k^kP/0oooo1@0000040?ooo`@000001P3oool200000?l0ooooA@3oool00280oooo
00<000000?ooo`3oool0o`3ooom40?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0oooo000R
0?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo00<000000?ooo`3oool0o`3ooom40?oo
o`008P3oool200000?l0ooooA@3oool00280oooo00<000000?ooo`3oool0o`3ooom40?ooo`008P3o
ool00`000000oooo0?ooo`3o0?oood@0oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool0
0280oooo00<000000?ooo`3oool0o`3ooom40?ooo`008P3oool200000?l0ooooA@3oool00280oooo
00<000000?ooo`3oool0o`3ooom40?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0oooo000R
0?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo0P00003o0?ooodD0oooo000R0?ooo`03
0000003oool0oooo0?l0ooooA03oool001P0oooo100000000`0A4A40oooo0?ooo`030?ooo`030000
003oool0oooo0?l0ooooA03oool001X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`3o0?oood@0oooo000J0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooom4
0?ooo`006P3oool00`000000oooo0?ooo`050?ooool00000<P00000E0?ooo`006P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooA03oool001X0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`3o0?oood@0oooo000J0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0o`3ooom40?ooo`00603oool205EEE@030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0o`3ooom40?ooo`008P3oool200000?l0ooooA@3oool00280oooo00<000000?ooo`3o
ool0o`3ooom40?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0oooo000R0?ooo`030000003o
ool0oooo0?l0ooooA03oool00280oooo0P00003o0?ooodD0oooo000R0?ooo`030000003oool0oooo
0?l0ooooA03oool00280oooo00<000000?ooo`3oool0o`3ooom40?ooo`008P3oool00`000000oooo
0?ooo`3o0?oood@0oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo0P00003o
0?ooodD0oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo00<000000?ooo`3o
ool0o`3ooom40?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0oooo000R0?ooo`030000003o
ool0oooo0?l0ooooA03oool00280oooo0P00003o0?ooodD0oooo000R0?ooo`030000003oool0oooo
0?l0ooooA03oool000@0000000<04A4A0?ooo`3oool00P3oool2028R8P@0oooo1@0000040?ooo`05
04A4A0000000000003<c<`3MgMd01@3oool00`000000oooo0?ooo`3o0?oood@0oooo00020?ooo`03
0000003oool0oooo00@0oooo0P0R8R840?ooo`0509VIV@0R8R80k^k^0?ooo`14A4@01`3oool00`1g
MgL0<c<c0?ooo`040?ooo`030000003oool0oooo0?l0ooooA03oool00080oooo00<000000?ooo`3o
ool02`3oool00`2IVIT08R8R0>k^kP090?ooo`030000003oool0oooo00<0oooo0`00003o0?oood@0
oooo00020?ooo`030000003oool0oooo00`0oooo00<0VIVI028R8P3^k^h01`3oool00`1gMgL0<c<c
0?ooo`040?ooo`030000003oool0oooo0?l0ooooA03oool00080oooo00<000000?ooo`3oool03@3o
ool00`1gMgL0IVIV0?ooo`030?ooo`050000000R8R80000003<c<`3<c<`01@3oool00`000000oooo
0?ooo`3o0?oood@0oooo00020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooA03oool00080oooo00<00000
0?ooo`3oool02P3oool01@000000^k^k0?ooo`2IVIT04A4A00@0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`3o0?oood@0oooo000205EEE@030000003oool0oooo00X0oooo00D0VIVI
014A4@0000008R8R0<c<c0040?ooo`@000001P3oool200000?l0ooooA@3oool00280oooo00<00000
0?ooo`3oool0o`3ooom40?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0oooo000R0?ooo`03
0000003oool0oooo0?l0ooooA03oool00280oooo00<000000?ooo`3oool0o`3ooom40?ooo`008P3o
ool200000?l0ooooA@3oool00280oooo00<000000?ooo`3oool0o`3ooom40?ooo`008P3oool00`00
0000oooo0?ooo`3o0?oood@0oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo
0P00003o0?ooodD0oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo00<00000
0?ooo`3oool0o`3ooom40?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0oooo000R0?ooo`03
0000003oool0oooo0?l0ooooA03oool00280oooo0P00003o0?ooodD0oooo000R0?ooo`030000003o
ool0oooo0?l0ooooA03oool000P0oooo100000000`0A4A40oooo0?ooo`020?ooo`808R8R1@3oool0
1@14A4@000000000000c<c<0gMgM00D0oooo00<000000?ooo`3oool0o`3ooom40?ooo`002P3oool0
0`000000oooo0?ooo`040?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`040?ooo`030000003oool0
oooo0?l0ooooA03oool000X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0?l0ooooA03oool000X0oooo00<000000?ooo`3oool03P3oool00`1gMgL0
<c<c0?ooo`040?ooo`<00000o`3ooom40?ooo`002P3oool00`000000oooo0?ooo`0;0?ooo`050000
000R8R80000003<c<`3<c<`01@3oool00`000000oooo0?ooo`3o0?oood@0oooo000:0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oood@0oooo
000:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`3o0?oood@0oooo00080?ooo`80EEEE00<000000?ooo`3oool02`3oool4000000H0oooo00<00000
0?ooo`3oool0o`3ooom40?ooo`008P3oool200000?l0ooooA@3oool00280oooo00<000000?ooo`3o
ool0o`3ooom40?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0oooo000R0?ooo`030000003o
ool0oooo0?l0ooooA03oool00280oooo0P00003o0?ooodD0oooo000R0?ooo`030000003oool0oooo
0?l0ooooA03oool00280oooo00<000000?ooo`3oool0o`3ooom40?ooo`008P3oool00`000000oooo
0?ooo`3o0?oood@0oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo0P00003o
0?ooodD0oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo00<000000?ooo`3o
ool0o`3ooom40?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0oooo000R0?ooo`030000003o
ool0oooo0?l0ooooA03oool00280oooo0P00003o0?ooodD0oooo000R0?ooo`030000003oool0oooo
0?l0ooooA03oool000@0000000<04A4A0?ooo`3oool00P3oool2028R8PH0oooo00<000000>k^kP3o
ool0103oool01@14A4@000000000000c<c<0gMgM00D0oooo00<000000?ooo`3oool0o`3ooom40?oo
o`000P3oool00`000000oooo0?ooo`040?ooo`808R8R1P3oool00`1EEED0ZZZZ0?ooo`070?ooo`03
07MgM`0c<c<0oooo00@0oooo00<000000?ooo`3oool0o`3ooom40?ooo`000P3oool00`000000oooo
0?ooo`0<0?ooo`030:ZZZP1EEED0oooo00P0oooo00<000000?ooo`3oool00`3oool300000?l0oooo
A03oool00080oooo00<000000?ooo`3oool03@3oool00`0A4A40oooo0?ooo`060?ooo`0307MgM`0c
<c<0oooo00@0oooo00<000000?ooo`3oool0o`3ooom40?ooo`000P3oool00`000000oooo0?ooo`0=
0?ooo`0305EEE@3<c<`0oooo00<0oooo00D00000028R8P000000<c<c0<c<c0050?ooo`030000003o
ool0oooo0?l0ooooA03oool00080oooo00<000000?ooo`3oool03@3oool00`2ZZZX0MgMg0?ooo`03
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooom40?ooo`000P3oool00`00
0000oooo0?ooo`0:0?ooo`05014A4@3oool0oooo0?ooo`0c<c<0103oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0?l0ooooA03oool00080EEEE00<000000?ooo`3oool02P3oool50000
00@0oooo100000060?ooo`800000o`3ooom50?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0
oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo00<000000?ooo`3oool0o`3o
oom40?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0oooo000R0?ooo`800000o`3ooom50?oo
o`008P3oool00`000000oooo0?ooo`3o0?oood@0oooo000R0?ooo`030000003oool0oooo0?l0oooo
A03oool00280oooo00<000000?ooo`3oool0o`3ooom40?ooo`008P3oool200000?l0ooooA@3oool0
0280oooo00<000000?ooo`3oool0o`3ooom40?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0
oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo00<000000?ooo`3oool0o`3o
oom40?ooo`008P3oool200000?l0ooooA@3oool00280oooo00<000000?ooo`3oool0o`3ooom40?oo
o`005`3oool5000000H0oooo00<000000?ooo`3oool0o`3ooom40?ooo`005`3oool01@2IVIT08R8R
0>k^kP3oool0A4A400H0oooo00<000000?ooo`3oool0o`3ooom40?ooo`00603oool00`2IVIT08R8R
0>k^kP070?ooo`030000003oool0oooo0?l0ooooA03oool001T0oooo00<0VIVI028R8P3^k^h01P3o
ool300000?l0ooooA03oool001X0oooo00<0MgMg06IVIP3oool0o`3ooom<0?ooo`006`3oool00`00
0000oooo0?ooo`3o0?oood/0oooo000G0?ooo`050000002k^k/0oooo09VIV@0A4A40o`3ooom=0?oo
o`005`3oool01@2IVIT04A4A0000000R8R80c<c<0?l0ooooC@3oool00?l0ooooJ@3oool009`0oooo
0P00000;0?ooo`03014A4@2k^k/0oooo00`0oooo0P0000060?ooo`03014A4@2k^k/0oooo0:D0oooo
002L0?ooo`030000003oool0oooo00X0oooo0P0c<c<>0?ooo`030000003oool0oooo00@0oooo0P0c
<c>V0?ooo`00TP3oool01@0A4A4000000000000000004A4A00D0oooo00<000000?ooo`3oool00P3o
ool200000080oooo0P0000020?ooo`0308R8R0000000ZZZZ00D0oooo00D0VIVI000000000000A4A4
0;^k^`030?ooo`030000003oool0oooo00@0oooo00<0R8R80000002ZZZX0303oool01@2IVIT00000
00000014A4@0^k^k00T0oooo00D0k^k^03<c<`000000<c<c0>k^kP260?ooo`00U03oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00H0k^k^028R8P28R8P0c<c<0000003<c<`2
0?ooo`030<c<c00000004A4A00D0oooo00D04A4A0;^k^`3^k^h0MgMg014A4@030?ooo`030000003o
ool0oooo00@0oooo00<0c<c<0000000A4A40303oool01P0A4A40^k^k0>k^kP1gMgL04A4A0?ooo`H0
00000P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg08H0oooo002D0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00`3oool0103MgMd000000000003<c<`;0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0;0?ooo`05014A4@3oool0oooo
0?ooo`0A4A40QP3oool009@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?oo
o`040>k^kP0R8R8000000>k^kP/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00<0oooo1P0000020?ooo`050000003oool0oooo0?ooo`000000QP3o
ool009@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`050>k^kP0R8R80
MgMg07MgM`0c<c<02`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool02`3oool01@000000oooo0?ooo`3oool0000008H0oooo002A0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`800000
0P3oool2000000P0oooo00<04A4A0000000000000`0000040?ooo`030000003oool0oooo0140oooo
00<04A4A0000000000000`00000:0?ooo`05014A4@3oool0oooo0?ooo`0A4A40QP3oool00940oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00/0
oooo00D0MgMg09VIV@3oool0VIVI07MgM`260?ooo`00T@3oool7000000@0oooo0P00000C0?ooo`03
0000003oool0oooo00@0oooo0P00000E0?ooo`030000003oool0oooo00/0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP260?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .45717 m
.04057 .41109 L
.06168 .39203 L
.08481 .37455 L
.12636 .35069 L
.14691 .34189 L
.16889 .33426 L
.18976 .32847 L
.21241 .32352 L
.23421 .31982 L
.25434 .31717 L
.274 .31516 L
.29566 .31346 L
.31604 .31227 L
.33796 .31131 L
.36015 .31061 L
.38124 .31013 L
.40204 .30979 L
.42135 .30956 L
.44289 .30938 L
.46243 .30926 L
.48264 .30918 L
.49403 .30914 L
.5045 .30912 L
.52427 .30908 L
.53549 .30906 L
.54596 .30905 L
.55694 .30904 L
.56733 .30904 L
.57667 .30903 L
.5819 .30903 L
.58682 .30903 L
.59197 .30903 L
.59669 .30903 L
.60193 .30903 L
.60486 .30903 L
.60758 .30903 L
.61027 .30903 L
.61271 .30903 L
.61543 .30903 L
.61692 .30903 L
.61833 .30903 L
.6197 .30903 L
.62039 .30903 L
.62115 .30903 L
.6225 .30903 L
.62375 .30903 L
.62452 .30903 L
.62524 .30903 L
.62659 .30903 L
Mistroke
.62735 .30903 L
.62805 .30903 L
.62964 .30903 L
.63243 .30903 L
.63499 .30903 L
.64076 .30903 L
.65123 .30903 L
.66067 .30903 L
.66587 .30903 L
.67078 .30903 L
.67335 .30903 L
.67471 .30903 L
.67614 .30903 L
.67735 .30903 L
.67868 .30903 L
.67989 .30903 L
.68103 .30903 L
.6822 .30903 L
.68343 .30903 L
.68448 .30903 L
.68563 .30903 L
.68687 .30903 L
.6882 .30903 L
.69059 .30903 L
.6934 .30903 L
.69644 .30903 L
.70197 .30903 L
.70735 .30903 L
.7123 .30903 L
.7225 .30903 L
.73204 .30902 L
.75372 .30902 L
.79454 .30901 L
.80521 .30901 L
.81084 .30901 L
.81682 .30901 L
.82203 .30901 L
.8248 .30901 L
.82779 .30901 L
.83052 .30901 L
.83302 .30901 L
.83542 .30901 L
.83662 .30901 L
.83794 .30901 L
.83932 .30901 L
.8406 .30901 L
.84126 .30901 L
.842 .30901 L
.84276 .30901 L
.84348 .30901 L
Mistroke
.8448 .30901 L
.846 .30901 L
.84871 .30901 L
.85111 .30901 L
.85373 .30901 L
.85851 .30901 L
.86403 .30901 L
.86991 .30901 L
.8805 .30901 L
.90148 .30902 L
.91252 .30902 L
.92418 .30902 L
.92923 .30902 L
.93463 .30902 L
.93774 .30902 L
.94057 .30902 L
.94193 .30902 L
.94341 .30902 L
.9448 .30902 L
.9461 .30902 L
.94727 .30902 L
.94852 .30902 L
.9492 .30902 L
.94991 .30902 L
.95119 .30902 L
.95252 .30902 L
.95376 .30902 L
.95513 .30902 L
.95658 .30902 L
.95919 .30902 L
.96166 .30902 L
.96627 .30902 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
00<000Ioo`8000Aoo`D000Aoo`@000Ioo`03001oogoo0?moodAoo`000goo00<007ooOol00goo0P00
1Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007ooOol02goo
00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0<Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03001oogoo00eoo`03001oogoo009oo`@0
00Ioo`03001oogoo0?moodAoo`000goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol0ogooA7oo0003Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol01goo
00<007ooOol0ogooA7oo0003000=Ool30005Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`0027oo0`001Woo0P00
1Goo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol0
0goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000047oo00<007ooOol00goo0`00ogooA7oo
0007Ool01@00Oomoogoo000047oo00<007ooOol00goo00<007ooOol0ogooA7oo0007Ool01@00Oomo
ogoo000037oo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol0
1goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol01goo00<007ooOol0
ogooA7oo0008Ool3000=Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol0
0`00Oomoo`3oOom4Ool000<000Ioo`8000Ioo`03001oogoo00Aoo`@000Ioo`03001oogoo0?moodAo
o`000goo00<007ooOol00goo0P001Woo00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogoo
A7oo0003Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03
001oogoo00aoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007oo
Ool037oo00<007ooOol00goo10001Woo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0=Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000=oo`03001oogoo00Uoo`05001oogoo
Ool00004Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000<000aoo`D000Aoo`@000Ioo`800?mo
odEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`0067oo1@001Goo00<0
07ooOol0ogooA7oo000JOol00`00Oomoo`05Ool00`00Oomoo`3oOom4Ool001Yoo`03001oogoo00Eo
o`03001oogoo0?moodAoo`006Woo00<007ooOol01Goo0`00Igooa`005Goo000JOol00`00Oomoo`05
Ool00`00Oomoo`1DOolC003LOol001Yoo`03001oogoo00Eoo`03001oogoo04Moo`d00>moo`006Woo
00<007ooOol01Goo00<007ooOol0@Goo1P00o7oo000HOol30007Ool00`00Oomoo`0lOol5003oOol3
Ool0029oo`8003Yoo`<00?moo`Qoo`008Woo00<007ooOol0=Goo1000ogoo2goo000ROol00`00Oomo
o`0bOol3003oOol?Ool0029oo`03001oogoo02moo`<00?mooa9oo`008Woo0P00;Goo0`00ogoo5Goo
000ROol00`00Oomoo`0YOol3003oOolHOol0029oo`03001oogoo02Ioo`<00?mooa]oo`008Woo00<0
07ooOol097oo0P00ogoo7Woo000ROol00`00Oomoo`0ROol2003oOolPOol0029oo`80025oo`800?mo
ob9oo`008Woo00<007ooOol07goo00<007ooOol0ogoo8Woo000ROol00`00Oomoo`0MOol2003oOolU
Ool0029oo`03001oogoo01]oo`800?moobMoo`008Woo00<007ooOol06Woo00<007ooOol0ogoo9goo
000ROol2000IOol2003oOolZOol0029oo`03001oogoo01Ioo`800?moobaoo`001@0017oo0P0017oo
1@0017oo10001Woo00<007ooOol05Goo00<007ooOol0ogoo;7oo0002Ool00`00Oomoo`04Ool20005
Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol04goo0P00ogoo;goo0002Ool00`00Oomo
o`0<Ool00`00Oomoo`08Ool00`00Oomoo`03Ool3000BOol00`00Oomoo`3oOol_Ool0009oo`03001o
ogoo00eoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo015oo`03001oogoo0?mooc1oo`00
0Woo00<007ooOol03Woo00<007ooOol00Woo10001Woo00<007ooOol03goo0P00ogoo<goo0002Ool0
0`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0>Ool00`00Oomoo`3oOolc
Ool0009oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00Oomoo`07Ool00`00Oomoo`0=Ool0
0`00Oomoo`3oOoldOol000<000eoo`<000Eoo`@000Ioo`8000eoo`03001oogoo0?moocEoo`008Woo
00<007ooOol02goo00<007ooOol0ogoo=Woo000ROol00`00Oomoo`0:Ool00`00Oomoo`3oOolgOol0
029oo`03001oogoo00Uoo`03001oogoo0?moocQoo`008Woo00<007ooOol02Goo00<007ooOol0ogoo
>7oo000ROol20009Ool00`00Oomoo`3oOoliOol0029oo`03001oogoo00Moo`03001oogoo0?moocYo
o`008Woo00<007ooOol01Woo00<007ooOol0ogoo>goo000ROol00`00Oomoo`05Ool00`00Oomoo`3o
OollOol0029oo`8000Eoo`03001oogoo0?mooceoo`008Woo00<007ooOol00goo00<007ooOol0ogoo
?Woo000ROol00`00Oomoo`03Ool00`00Oomoo`3oOolnOol0029oo`03001oogoo009oo`03001oogoo
0?moocmoo`008Woo00D007ooOomoo`000?mood9oo`008Woo0P0000=oo`00Ool0ogoo@Woo000ROol0
0`00Ool0003oOom4Ool000Qoo`D000Aoo`8000Eoo`@000Ioo`800?moodEoo`002Woo00<007ooOol0
17oo0P002Goo00<007ooOol00goo00<007ooOol0ogooA7oo000:Ool00`00Oomoo`0?Ool00`00Oomo
o`03Ool00`00Oomoo`3oOom4Ool000Yoo`03001oogoo00moo`03001oogoo00=oo`<00?moodAoo`00
2Woo00<007ooOol02goo10001Woo00<007ooOol0ogooA7oo000:Ool00`00Oomoo`0;Ool00`00Oomo
o`07Ool00`00Oomoo`3oOom4Ool000Yoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo0?mo
odAoo`0027oo0`003Goo10001Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001o
ogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?mo
odEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool000D000Aoo`8000Ioo`03001oogoo00Aoo`@0
00Ioo`03001oogoo0?moodAoo`000Woo00<007ooOol017oo0P001Woo00<007ooOol027oo00<007oo
Ool00goo00<007ooOol0ogooA7oo0002Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`03
Ool3003oOom4Ool0009oo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo
0?moodAoo`000Woo00<007ooOol03Goo00<007ooOol00goo10001Woo00<007ooOol0ogooA7oo0002
Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool0009oo`03
001oogoo00Yoo`05001oogooOol00004Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000<000ao
o`D000Aoo`@000Ioo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4
Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029o
o`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029o
o`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001o
ogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`005goo1@001Woo00<007ooOol0ogooA7oo000HOol01000Oomoo`001Woo00<007ooOol0ogoo
A7oo000IOol00`00Oomoo`06Ool00`00Oomoo`3oOom4Ool001Yoo`03001oogoo00Eoo`<00?moodAo
o`006goo00<007ooOol0ogooBgoo000KOol00`00Oomoo`3oOom;Ool001Moo`05001oogooOol0003o
Oom=Ool001Qoo`<00?moodioo`00ogooJGoo002EOol2000;Ool00`00Oomoo`0<Ool20005Ool00`00
Oomoo`2]Ool009Eoo`03001oogoo00Yoo`8000ioo`03001oogoo00=oo`800:ioo`00RWoo1@001Woo
00@007ooOomoo`80009oo`8000Aoo`03001oogoo00Aoo`<000Eoo`03001oogoo00Aoo`03001oogoo
00aoo`<000]oo`<000Ioo`8000Eoo`@007ioo`00S7oo00<007ooOol01Woo00<007ooOol00Woo00@0
07ooOol000Eoo`8000Aoo`05001oogooOol00004Ool00`00Oomoo`04Ool2000<Ool01@00Oomoogoo
00000Woo1P0000=oo`00Ool00Woo00<007ooOol00goo0P002Goo00<007ooOol0Ngoo002<Ool00`00
Oomoo`06Ool00`00Oomoo`03Ool2000<Ool00`00Oomoo`06Ool00`00Oomoo`0BOol00`00Oomoo`0;
Ool01@00Oomoogoo000047oo00<007ooOol0Ngoo002<Ool00`00Oomoo`06Ool00`00Oomoo`03Ool2
000<Ool00`00Oomoo`06Ool00`00Oomoo`0BOol00`00Oomoo`04Ool600000goo001oo`02Ool00`00
Oomoo`0>Ool00`00Oomoo`1kOol008aoo`03001oogoo00Ioo`03001oogoo009oo`04001oogoo000;
Ool00`00Oomoo`06Ool00`00Oomoo`0BOol00`00Oomoo`0;Ool01@00Oomoogoo000037oo1000OWoo
0029Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOomoo`80009oo`8000Qoo`H000Eoo`03
001oogoo011oo`H000Yoo`05001oogooOol0000<Ool00`00Oomoo`1oOol008Uoo`04001oogoo0002
Ool00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`06Ool00`00Oomoo`0BOol00`00Oomoo`0;
Ool01@00Oomoogoo000037oo00<007ooOol0Ogoo0029Ool70005Ool2000BOol00`00Oomoo`05Ool2
000DOol00`00Oomoo`0<Ool3000=Ool4001nOol00?moofUoo`00ogooJGoo003oOomYOol00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .56905 m
.04057 .51348 L
.08481 .46292 L
.12636 .42448 L
.16632 .39497 L
.20885 .37052 L
.2498 .35269 L
.29331 .33871 L
.33524 .32906 L
.37557 .32248 L
.3964 .31989 L
.41848 .31764 L
.45821 .31461 L
.47859 .31346 L
.50051 .31247 L
.52121 .31172 L
.5438 .31107 L
.56542 .31059 L
.58549 .31024 L
.60704 .30994 L
.62658 .30973 L
.64679 .30956 L
.66865 .30942 L
.68958 .30931 L
.7117 .30923 L
.73232 .30918 L
.75157 .30914 L
.77294 .30911 L
.79243 .30909 L
.81247 .30907 L
.83426 .30905 L
.85503 .30904 L
.87708 .30903 L
.88692 .30903 L
.89753 .30903 L
.90747 .30902 L
.91672 .30902 L
.92677 .30902 L
.93209 .30902 L
.93504 .30902 L
.93777 .30902 L
.94063 .30902 L
.94214 .30902 L
.94374 .30902 L
.94512 .30902 L
.94642 .30902 L
.94716 .30902 L
.94784 .30902 L
.94863 .30902 L
.94937 .30902 L
Mistroke
.95064 .30902 L
.95199 .30902 L
.95327 .30902 L
.95442 .30902 L
.95725 .30902 L
.95992 .30902 L
.96477 .30902 L
.97008 .30902 L
.98081 .30902 L
.9856 .30902 L
.98824 .30902 L
.99074 .30902 L
.99306 .30902 L
.99429 .30902 L
.99559 .30902 L
.99668 .30902 L
.99788 .30902 L
.99897 .30902 L
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
00<000Ioo`8000Aoo`D000Aoo`@000Ioo`03001oogoo0?moodAoo`000goo00<007ooOol00goo0P00
1Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007ooOol02goo
00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0<Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03001oogoo00eoo`03001oogoo009oo`@0
00Ioo`03001oogoo0?moodAoo`000goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol0ogooA7oo0003Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol01goo
00<007ooOol0ogooA7oo0003000=Ool30005Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`0027oo0`001Woo0P00
1Goo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol0
0goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000047oo00<007ooOol00goo0`00ogooA7oo
0007Ool01@00Oomoogoo000047oo00<007ooOol00goo00<007ooOol0ogooA7oo0007Ool01@00Oomo
ogoo000037oo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol0
1goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol01goo00<007ooOol0
ogooA7oo0008Ool3000=Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol0
0`00Oomoo`3oOom4Ool000<000Ioo`8000Ioo`03001oogoo00Aoo`@000Ioo`03001oogoo0?moodAo
o`000goo00<007ooOol00goo0P001Woo00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogoo
A7oo0003Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03
001oogoo00aoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007oo
Ool037oo00<007ooOol00goo10001Woo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0=Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000=oo`03001oogoo00Uoo`05001oogoo
Ool00004Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000<000aoo`D000Aoo`@000Ioo`800?mo
odEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`0067oo1@001Goo00<0
07ooOol0ogooA7oo000JOol00`00Oomoo`05Ool00`00Oomoo`3oOom4Ool001Yoo`03001oogoo00Eo
o`03001oogoo0?moodAoo`006Woo00<007ooOol01Goo0`00YWooR0005Goo000JOol00`00Oomoo`05
Ool00`00Oomoo`2;OolK002MOol001Yoo`03001oogoo00Eoo`03001oogoo089oo`T00;Qoo`006Woo
00<007ooOol01Goo00<007ooOol0LWoo4000`Goo000HOol30007Ool00`00Oomoo`1/Ool6003AOol0
029oo`8006Moo`H00=Moo`008Woo00<007ooOol0HGoo1@00gGoo000ROol00`00Oomoo`1LOol5003R
Ool0029oo`03001oogoo05Qoo`@00>Moo`008Woo0P00EGoo1000jgoo000ROol00`00Oomoo`1AOol3
003_Ool0029oo`03001oogoo04ioo`<00?9oo`008Woo00<007ooOol0Bgoo0`00mGoo000ROol00`00
Oomoo`18Ool3003hOol0029oo`8004Moo`800?]oo`008Woo00<007ooOol0A7oo0P00oGoo000ROol0
0`00Oomoo`12Ool2003oOol0029oo`03001oogoo041oo`800?moo`9oo`008Woo00<007ooOol0?Woo
0P00ogoo17oo000ROol2000mOol2003oOol6Ool0029oo`03001oogoo03Yoo`800?moo`Qoo`001@00
17oo0P0017oo1@0017oo10001Woo00<007ooOol0>7oo0P00ogoo2Woo0002Ool00`00Oomoo`04Ool2
0005Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0=Woo0P00ogoo37oo0002Ool00`00
Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`03Ool3000eOol00`00Oomoo`3oOol<Ool0009oo`03
001oogoo00eoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo03=oo`800?moo`moo`000Woo
00<007ooOol03Woo00<007ooOol00Woo10001Woo00<007ooOol0<Goo0P00ogoo4Goo0002Ool00`00
Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0_Ool2003oOolCOol0009oo`03
001oogoo00Yoo`05001oogooOol00004Ool00`00Oomoo`07Ool00`00Oomoo`0^Ool00`00Oomoo`3o
OolCOol000<000eoo`<000Eoo`@000Ioo`8002eoo`800?mooaIoo`008Woo00<007ooOol0:goo00<0
07ooOol0ogoo5Woo000ROol00`00Oomoo`0YOol2003oOolIOol0029oo`03001oogoo02Qoo`03001o
ogoo0?mooaUoo`008Woo00<007ooOol09goo00<007ooOol0ogoo6Woo000ROol2000VOol2003oOolM
Ool0029oo`03001oogoo02Aoo`03001oogoo0?mooaeoo`008Woo00<007ooOol08goo00<007ooOol0
ogoo7Woo000ROol00`00Oomoo`0ROol00`00Oomoo`3oOolOOol0029oo`80029oo`03001oogoo0?mo
ob1oo`008Woo00<007ooOol087oo00<007ooOol0ogoo8Goo000ROol00`00Oomoo`0OOol00`00Oomo
o`3oOolROol0029oo`03001oogoo01ioo`03001oogoo0?moob=oo`008Woo00<007ooOol07Goo00<0
07ooOol0ogoo97oo000ROol2000MOol00`00Oomoo`3oOolUOol0029oo`03001oogoo01]oo`03001o
ogoo0?moobIoo`0027oo1@0017oo0P001Goo10001Woo00<007ooOol06Woo00<007ooOol0ogoo9goo
000:Ool00`00Oomoo`04Ool20009Ool00`00Oomoo`03Ool00`00Oomoo`0IOol00`00Oomoo`3oOolX
Ool000Yoo`03001oogoo00moo`03001oogoo00=oo`03001oogoo01Qoo`03001oogoo0?moobUoo`00
2Woo00<007ooOol03goo00<007ooOol00goo0`005goo00<007ooOol0ogoo:Woo000:Ool00`00Oomo
o`0;Ool40006Ool00`00Oomoo`0GOol00`00Oomoo`3oOolZOol000Yoo`03001oogoo00]oo`03001o
ogoo00Moo`03001oogoo01Ioo`03001oogoo0?moob]oo`002Woo00<007ooOol02goo00<007ooOol0
1goo00<007ooOol05Goo00<007ooOol0ogoo;7oo0008Ool3000=Ool40006Ool00`00Oomoo`0DOol0
0`00Oomoo`3oOol]Ool0029oo`8001Aoo`03001oogoo0?moobioo`008Woo00<007ooOol04Woo00<0
07ooOol0ogoo;goo000ROol00`00Oomoo`0AOol00`00Oomoo`3oOol`Ool0029oo`03001oogoo011o
o`03001oogoo0?mooc5oo`008Woo0P0047oo00<007ooOol0ogoo<Woo000ROol00`00Oomoo`0>Ool0
0`00Oomoo`3oOolcOol0029oo`03001oogoo00eoo`03001oogoo0?moocAoo`008Woo00<007ooOol0
37oo00<007ooOol0ogoo=Goo000ROol00`00Oomoo`0;Ool00`00Oomoo`3oOolfOol0029oo`8000]o
o`03001oogoo0?moocMoo`008Woo00<007ooOol02Goo00<007ooOol0ogoo>7oo000ROol00`00Oomo
o`09Ool00`00Oomoo`3oOolhOol0029oo`03001oogoo00Qoo`03001oogoo0?moocUoo`008Woo00<0
07ooOol01goo00<007ooOol0ogoo>Woo000ROol20008Ool00`00Oomoo`3oOoljOol0029oo`03001o
ogoo00Ioo`03001oogoo0?mooc]oo`001@0017oo0P001Woo00<007ooOol017oo10001Woo00<007oo
Ool01Goo00<007ooOol0ogoo?7oo0002Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00
Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`3oOolmOol0009oo`03001oogoo00eoo`03001oogoo
00Moo`03001oogoo00=oo`<000Aoo`03001oogoo0?mooceoo`000Woo00<007ooOol03Goo00<007oo
Ool01goo00<007ooOol00goo00<007ooOol00goo00<007ooOol0ogoo?Woo0002Ool00`00Oomoo`0=
Ool00`00Oomoo`03Ool40006Ool00`00Oomoo`02Ool00`00Oomoo`3oOoloOol0009oo`03001oogoo
00ioo`03001oogoo009oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo0?moocmoo`000Woo
00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo00Moo`05001oogooOol0003oOom2Ool0
00<000aoo`D000Aoo`@000Ioo`800003Ool007oo0?mood9oo`008Woo00<007oo0000ogooA7oo000R
Ool00`00Ool0003oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0
029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03
001oogoo0?moodAoo`005goo1@001Woo00<007ooOol0ogooA7oo000HOol01000Oomoo`001Woo00<0
07ooOol0ogooA7oo000IOol00`00Oomoo`06Ool00`00Oomoo`3oOom4Ool001Yoo`03001oogoo00Eo
o`<00?moodAoo`006goo00<007ooOol0ogooBgoo000KOol00`00Oomoo`3oOom;Ool001Moo`05001o
ogooOol0003oOom=Ool001Qoo`<00?moodioo`00ogooJGoo002HOol2000;Ool00`00Oomoo`0<Ool2
0006Ool00`00Oomoo`2YOol009Qoo`03001oogoo00Yoo`8000ioo`03001oogoo00Aoo`800:Yoo`00
SWoo1@001Goo00<007ooOol00Woo0P000Woo0P000goo00<007ooOol01Goo0`0017oo00<007ooOol0
1Goo00<007ooOol037oo0`002goo1@0017oo0P00Pgoo002@Ool00`00Oomoo`05Ool00`00Oomoo`03
Ool01000Oomoo`0017oo0P001Goo00D007ooOomoo`0000=oo`03001oogoo00Eoo`8000aoo`06001o
ogooOol007oo1P001Goo00<007ooOol017oo0P00Pgoo002@Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool2000<Ool00`00Oomoo`05Ool00`00Oomoo`0COol00`00Oomoo`0>Ool00`00Oomoo`29Ool0091o
o`03001oogoo00Eoo`03001oogoo00Aoo`8000aoo`03001oogoo00Eoo`03001oogoo01=oo`03001o
ogoo00=oo`H000Eoo`03001oogoo08Uoo`00T7oo00<007ooOol01Goo00<007ooOol00goo00@007oo
Ool000]oo`03001oogoo00Eoo`03001oogoo01=oo`03001oogoo00ioo`03001oogoo08Uoo`00SGoo
00@007ooOol0009oo`03001oogoo009oo`03001oogoo009oo`80009oo`8000Qoo`H000Aoo`03001o
ogoo015oo`H000eoo`03001oogoo08Uoo`00SGoo00@007ooOol0009oo`03001oogoo009oo`03001o
ogoo019oo`03001oogoo00Eoo`03001oogoo01=oo`03001oogoo00ioo`03001oogoo08Uoo`00SGoo
1`0017oo0P004goo00<007ooOol017oo0P005Goo00<007ooOol037oo0`00Rgoo003oOomYOol00?mo
ofUoo`00ogooJGoo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .61726 m
.04057 .57108 L
.08481 .52409 L
.12636 .48442 L
.16632 .45091 L
.20885 .42039 L
.2498 .39585 L
.29331 .37458 L
.33524 .35824 L
.37557 .34584 L
.41848 .33564 L
.4598 .3282 L
.49953 .32282 L
.54183 .3186 L
.58254 .31566 L
.60324 .3145 L
.62583 .31344 L
.66752 .31196 L
.68818 .31141 L
.7102 .31093 L
.73117 .31056 L
.75386 .31023 L
.79593 .30979 L
.81687 .30963 L
.83898 .3095 L
.85984 .3094 L
.87885 .30933 L
.89934 .30926 L
.9213 .30922 L
.94134 .30918 L
.95266 .30917 L
.96314 .30916 L
.96749 .30916 L
.97217 .30916 L
.97623 .30916 L
.98066 .30915 L
.98557 .30915 L
.98825 .30915 L
.99075 .30915 L
.99309 .30915 L
.99522 .30915 L
.9964 .30915 L
.99768 .30915 L
.99889 .30915 L
1 .30915 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
00<000Ioo`8000Aoo`D000Aoo`@000Ioo`03001oogoo0?moodAoo`000goo00<007ooOol00goo0P00
1Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007ooOol02goo
00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0<Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03001oogoo00eoo`03001oogoo009oo`@0
00Ioo`03001oogoo0?moodAoo`000goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol0ogooA7oo0003Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol01goo
00<007ooOol0ogooA7oo0003000=Ool30005Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`0027oo0`001Woo0P00
1Goo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol0
0goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000047oo00<007ooOol00goo0`00ogooA7oo
0007Ool01@00Oomoogoo000047oo00<007ooOol00goo00<007ooOol0ogooA7oo0007Ool01@00Oomo
ogoo000037oo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol0
1goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol01goo00<007ooOol0
ogooA7oo0008Ool3000=Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol0
0`00Oomoo`3oOom4Ool000<000Ioo`8000Ioo`03001oogoo00Aoo`@000Ioo`03001oogoo0?moodAo
o`000goo00<007ooOol00goo0P001Woo00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogoo
A7oo0003Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03
001oogoo00aoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007oo
Ool037oo00<007ooOol00goo10001Woo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0=Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000=oo`03001oogoo00Uoo`05001oogoo
Ool00004Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000<000aoo`D000Aoo`@000Ioo`800?mo
odEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`0067oo1@001Goo00<0
07ooOol0ogooA7oo000JOol00`00Oomoo`05Ool00`00Oomoo`3oOom4Ool001Yoo`03001oogoo00Eo
o`03001oogoo0?moodAoo`006Woo00<007ooOol01Goo0`00f7ooEP005Goo000JOol00`00Oomoo`05
Ool00`00Oomoo`2hOolP001[Ool001Yoo`03001oogoo00Eoo`03001oogoo0:Qooa0008]oo`006Woo
00<007ooOol01Goo00<007ooOol0W7oo3000Vgoo000HOol30007Ool00`00Oomoo`2BOol:002WOol0
029oo`8008eoo`H00;5oo`008Woo00<007ooOol0QWoo1P00]goo000ROol00`00Oomoo`1oOol7002m
Ool0029oo`03001oogoo07Yoo`D00<Aoo`008Woo0P00MWoo1@00bGoo000ROol00`00Oomoo`1aOol4
003>Ool0029oo`03001oogoo06ioo`<00=9oo`008Woo00<007ooOol0Jgoo0`00eGoo000ROol00`00
Oomoo`1XOol3003HOol0029oo`8006Ioo`<00=]oo`008Woo00<007ooOol0HWoo0`00gWoo000ROol0
0`00Oomoo`1OOol3003QOol0029oo`03001oogoo05aoo`<00>Aoo`008Woo00<007ooOol0FWoo0P00
igoo000ROol2001HOol3003YOol0029oo`03001oogoo05Eoo`800>aoo`001@0017oo0P0017oo1@00
17oo10001Woo00<007ooOol0Dgoo0P00kWoo0002Ool00`00Oomoo`04Ool20005Ool01000Oomoo`00
27oo00<007ooOol00goo00<007ooOol0DGoo0P00l7oo0002Ool00`00Oomoo`0<Ool00`00Oomoo`08
Ool00`00Oomoo`03Ool3001>Ool3003bOol0009oo`03001oogoo00eoo`03001oogoo00Moo`03001o
ogoo00=oo`03001oogoo04aoo`800?Eoo`000Woo00<007ooOol03Woo00<007ooOol00Woo10001Woo
00<007ooOol0BWoo0P00mgoo0002Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`07Ool0
0`00Oomoo`18Ool2003iOol0009oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00Oomoo`07
Ool00`00Oomoo`17Ool00`00Oomoo`3iOol000<000eoo`<000Eoo`@000Ioo`8004Ioo`800?aoo`00
8Woo00<007ooOol0A7oo00<007ooOol0o7oo000ROol00`00Oomoo`12Ool2003oOol0029oo`03001o
ogoo045oo`03001oogoo0?moo`008Woo00<007ooOol0?goo0P00ogoo0goo000ROol2000oOol00`00
Oomoo`3oOol3Ool0029oo`03001oogoo03aoo`800?moo`Ioo`008Woo00<007ooOol0>goo00<007oo
Ool0ogoo1Woo000ROol00`00Oomoo`0iOol2003oOol9Ool0029oo`8003Uoo`03001oogoo0?moo`Uo
o`008Woo00<007ooOol0=Woo0P00ogoo37oo000ROol00`00Oomoo`0eOol00`00Oomoo`3oOol<Ool0
029oo`03001oogoo03Aoo`03001oogoo0?moo`eoo`008Woo00<007ooOol0<Woo0P00ogoo47oo000R
Ool2000bOol00`00Oomoo`3oOol@Ool0029oo`03001oogoo02moo`800?mooa=oo`0027oo1@0017oo
0P001Goo10001Woo00<007ooOol0;Woo00<007ooOol0ogoo4goo000:Ool00`00Oomoo`04Ool20009
Ool00`00Oomoo`03Ool00`00Oomoo`0]Ool00`00Oomoo`3oOolDOol000Yoo`03001oogoo00moo`03
001oogoo00=oo`03001oogoo02]oo`800?mooaMoo`002Woo00<007ooOol03goo00<007ooOol00goo
0`00:Woo00<007ooOol0ogoo5goo000:Ool00`00Oomoo`0;Ool40006Ool00`00Oomoo`0YOol00`00
Oomoo`3oOolHOol000Yoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo02Qoo`03001oogoo
0?mooaUoo`002Woo00<007ooOol02goo00<007ooOol01goo00<007ooOol09Woo0P00ogoo77oo0008
Ool3000=Ool40006Ool00`00Oomoo`0UOol00`00Oomoo`3oOolLOol0029oo`8002Eoo`03001oogoo
0?mooaeoo`008Woo00<007ooOol08goo00<007ooOol0ogoo7Woo000ROol00`00Oomoo`0ROol00`00
Oomoo`3oOolOOol0029oo`03001oogoo025oo`03001oogoo0?moob1oo`008Woo0P008Goo00<007oo
Ool0ogoo8Goo000ROol00`00Oomoo`0OOol00`00Oomoo`3oOolROol0029oo`03001oogoo01ioo`03
001oogoo0?moob=oo`008Woo00<007ooOol07Goo00<007ooOol0ogoo97oo000ROol00`00Oomoo`0L
Ool00`00Oomoo`3oOolUOol0029oo`8001aoo`03001oogoo0?moobIoo`008Woo00<007ooOol06Woo
00<007ooOol0ogoo9goo000ROol00`00Oomoo`0IOol00`00Oomoo`3oOolXOol0029oo`03001oogoo
01Qoo`03001oogoo0?moobUoo`008Woo00<007ooOol05goo00<007ooOol0ogoo:Woo000ROol2000G
Ool00`00Oomoo`3oOol[Ool0029oo`03001oogoo01Eoo`03001oogoo0?moobaoo`001@0017oo0P00
1Woo00<007ooOol017oo10001Woo00<007ooOol057oo00<007ooOol0ogoo;Goo0002Ool00`00Oomo
o`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`0COol00`00Oomoo`3oOol^
Ool0009oo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00=oo`<0019oo`03001oogoo0?mo
obmoo`000Woo00<007ooOol03Goo00<007ooOol01goo00<007ooOol00goo00<007ooOol04Goo00<0
07ooOol0ogoo<7oo0002Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool40006Ool00`00Oomoo`0@Ool0
0`00Oomoo`3oOolaOol0009oo`03001oogoo00ioo`03001oogoo009oo`03001oogoo00Moo`03001o
ogoo00moo`03001oogoo0?mooc9oo`000Woo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001o
ogoo00Moo`03001oogoo00ioo`03001oogoo0?mooc=oo`000`0037oo1@0017oo10001Woo0P003Woo
00<007ooOol0ogoo=7oo000ROol00`00Oomoo`0<Ool00`00Oomoo`3oOoleOol0029oo`03001oogoo
00]oo`03001oogoo0?moocIoo`008Woo00<007ooOol02Woo00<007ooOol0ogoo=goo000ROol00`00
Oomoo`09Ool00`00Oomoo`3oOolhOol0029oo`8000Yoo`03001oogoo0?moocQoo`008Woo00<007oo
Ool027oo00<007ooOol0ogoo>Goo000ROol00`00Oomoo`07Ool00`00Oomoo`3oOoljOol0029oo`03
001oogoo00Ioo`03001oogoo0?mooc]oo`008Woo0P001Woo00<007ooOol0ogoo?7oo000ROol00`00
Oomoo`04Ool00`00Oomoo`3oOolmOol0029oo`03001oogoo00=oo`03001oogoo0?moocioo`008Woo
00<007ooOol00goo00<007ooOol0ogoo?Woo000ROol00`00Oomoo`02Ool00`00Oomoo`3oOoloOol0
029oo`80009oo`03001oogoo0?mood1oo`008Woo00@007ooOol00?mood=oo`005goo1@001Woo00<0
07oo0000ogooA7oo000HOol01000Oomoo`001Woo0P00ogooAGoo000IOol00`00Oomoo`06Ool00`00
Oomoo`3oOom4Ool001Yoo`03001oogoo00Eoo`<00?moodAoo`006goo00<007ooOol0ogooBgoo000K
Ool00`00Oomoo`3oOom;Ool001Moo`05001oogooOol0003oOom=Ool001Qoo`<00?moodioo`00ogoo
JGoo002EOol2000;Ool00`00Oomoo`0<Ool20005Ool00`00Oomoo`2]Ool009Eoo`03001oogoo00Yo
o`8000ioo`03001oogoo00=oo`800:ioo`00RWoo1@001Woo00@007ooOomoo`80009oo`8000Aoo`03
001oogoo00Aoo`<000Eoo`03001oogoo00Aoo`03001oogoo00aoo`<000]oo`D000Aoo`8000Eoo`@0
07ioo`00S7oo00<007ooOol01Woo00<007ooOol00Woo00@007ooOol000Eoo`8000Aoo`05001oogoo
Ool00004Ool00`00Oomoo`04Ool2000<Ool01@00Oomoogoo00000Woo1P0017oo00<007ooOol017oo
0P002Goo00<007ooOol0Ngoo002<Ool00`00Oomoo`06Ool00`00Oomoo`03Ool2000<Ool00`00Oomo
o`06Ool00`00Oomoo`0BOol00`00Oomoo`0>Ool00`00Oomoo`0?Ool00`00Oomoo`1kOol008aoo`03
001oogoo00Ioo`03001oogoo00=oo`8000aoo`03001oogoo00Ioo`03001oogoo019oo`03001oogoo
00Aoo`H000Aoo`03001oogoo00moo`03001oogoo07]oo`00S7oo00<007ooOol01Woo00<007ooOol0
0Woo00@007ooOol000]oo`03001oogoo00Ioo`03001oogoo019oo`03001oogoo00ioo`03001oogoo
00]oo`@007ioo`00RGoo00@007ooOol0009oo`03001oogoo00=oo`04001oogooOol20002Ool20008
Ool60005Ool00`00Oomoo`0@Ool6000=Ool00`00Oomoo`0;Ool00`00Oomoo`1oOol008Uoo`04001o
ogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`06Ool00`00Oomoo`0BOol00`00
Oomoo`0>Ool00`00Oomoo`0;Ool00`00Oomoo`1oOol008Uoo`L000Eoo`80019oo`03001oogoo00Eo
o`8001Aoo`03001oogoo00aoo`<000eoo`@007ioo`00ogooJGoo003oOomYOol00?moofUoo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .59001 m
.04057 .56726 L
.08481 .53816 L
.12636 .5093 L
.16632 .48184 L
.20885 .45415 L
.2498 .42978 L
.29331 .40677 L
.33524 .38759 L
.37557 .37187 L
.41848 .35791 L
.4598 .34692 L
.49953 .33834 L
.54183 .33105 L
.58254 .32555 L
.62583 .32105 L
.66752 .31777 L
.70762 .3154 L
.7503 .31353 L
.79139 .31222 L
.81236 .31171 L
.83505 .31125 L
.87712 .31061 L
.89805 .31038 L
.92017 .31019 L
.93012 .31012 L
.94079 .31006 L
.95079 .31001 L
.96004 .30998 L
.96987 .30995 L
.97505 .30994 L
.98056 .30993 L
.98533 .30992 L
.9898 .30992 L
.99236 .30991 L
.99471 .30991 L
.99594 .30991 L
.99729 .30991 L
.99797 .30991 L
.99869 .30991 L
1 .30991 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
00<000Ioo`8000Aoo`D000Aoo`@000Ioo`03001oogoo0?moodAoo`000goo00<007ooOol00goo0P00
1Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007ooOol02goo
00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0<Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03001oogoo00eoo`03001oogoo009oo`@0
00Ioo`03001oogoo0?moodAoo`000goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol0ogooA7oo0003Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol01goo
00<007ooOol0ogooA7oo0003000=Ool30005Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`0027oo0`001Woo0P00
1Goo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol0
0goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000047oo00<007ooOol00goo0`00ogooA7oo
0007Ool01@00Oomoogoo000047oo00<007ooOol00goo00<007ooOol0ogooA7oo0007Ool01@00Oomo
ogoo000037oo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol0
1goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol01goo00<007ooOol0
ogooA7oo0008Ool3000=Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol0
0`00Oomoo`3oOom4Ool000<000Ioo`8000Ioo`03001oogoo00Aoo`@000Ioo`03001oogoo0?moodAo
o`000goo00<007ooOol00goo0P001Woo00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogoo
A7oo0003Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03
001oogoo00aoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007oo
Ool037oo00<007ooOol00goo10001Woo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0=Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000=oo`03001oogoo00Uoo`05001oogoo
Ool00004Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000<000aoo`D000Aoo`@000Ioo`800?mo
odEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`0067oo1@001Goo00<0
07ooOol0ogooA7oo000JOol00`00Oomoo`05Ool00`00Oomoo`3oOom4Ool001Yoo`03001oogoo00Eo
o`03001oogoo0?moodAoo`006Woo00<007ooOol01Goo0`00ogoo0Woo;@005Goo000JOol00`00Oomo
o`05Ool00`00Oomoo`3KOolV0012Ool001Yoo`03001oogoo00Eoo`03001oogoo0<ioo`d006Qoo`00
6Woo00<007ooOol01Goo00<007ooOol0`Woo3000MGoo000HOol30007Ool00`00Oomoo`2eOol=0021
Ool0029oo`800:aoo`X008ioo`008Woo00<007ooOol0YGoo1P00V7oo000ROol00`00Oomoo`2OOol6
002NOol0029oo`03001oogoo09Qoo`L00:Aoo`008Woo0P00Tgoo1P00Zgoo000ROol00`00Oomoo`2<
Ool6002aOol0029oo`03001oogoo08Moo`D00;Moo`008Woo00<007ooOol0Q7oo0`00_7oo000ROol0
0`00Oomoo`21Ool3002oOol0029oo`8007moo`<00<9oo`008Woo00<007ooOol0NWoo1000aGoo000R
Ool00`00Oomoo`1gOol30039Ool0029oo`03001oogoo07Aoo`<00<aoo`008Woo00<007ooOol0LGoo
0`00cgoo000ROol2001_Ool3003BOol0029oo`03001oogoo06]oo`<00=Eoo`001@0017oo0P0017oo
1@0017oo10001Woo00<007ooOol0JGoo0P00f7oo0002Ool00`00Oomoo`04Ool20005Ool01000Oomo
o`0027oo00<007ooOol00goo00<007ooOol0Igoo0P00fWoo0002Ool00`00Oomoo`0<Ool00`00Oomo
o`08Ool00`00Oomoo`03Ool3001TOol3003LOol0009oo`03001oogoo00eoo`03001oogoo00Moo`03
001oogoo00=oo`03001oogoo069oo`800=moo`000Woo00<007ooOol03Woo00<007ooOol00Woo1000
1Woo00<007ooOol0H7oo0P00hGoo0002Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`07
Ool00`00Oomoo`1NOol2003SOol0009oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00Oomo
o`07Ool00`00Oomoo`1KOol3003UOol000<000eoo`<000Eoo`@000Ioo`8005Yoo`800>Qoo`008Woo
00<007ooOol0Egoo0P00jWoo000ROol00`00Oomoo`1EOol2003/Ool0029oo`03001oogoo05=oo`80
0>ioo`008Woo00<007ooOol0DGoo0P00l7oo000ROol2001@Ool2003bOol0029oo`03001oogoo04io
o`03001oogoo0?9oo`008Woo00<007ooOol0C7oo0P00mGoo000ROol00`00Oomoo`1:Ool2003gOol0
029oo`8004Uoo`800?Uoo`008Woo00<007ooOol0AWoo0P00ngoo000ROol00`00Oomoo`15Ool00`00
Oomoo`3kOol0029oo`03001oogoo04=oo`800?ioo`008Woo00<007ooOol0@Goo0P00ogoo0Goo000R
Ool20011Ool00`00Oomoo`3oOol1Ool0029oo`03001oogoo03ioo`800?moo`Aoo`0027oo1@0017oo
0P001Goo10001Woo00<007ooOol0?7oo0P00ogoo1Woo000:Ool00`00Oomoo`04Ool20009Ool00`00
Oomoo`03Ool00`00Oomoo`0kOol00`00Oomoo`3oOol6Ool000Yoo`03001oogoo00moo`03001oogoo
00=oo`03001oogoo03Uoo`800?moo`Uoo`002Woo00<007ooOol03goo00<007ooOol00goo0`00=goo
0P00ogoo2goo000:Ool00`00Oomoo`0;Ool40006Ool00`00Oomoo`0fOol00`00Oomoo`3oOol;Ool0
00Yoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo03Aoo`800?moo`ioo`002Woo00<007oo
Ool02goo00<007ooOol01goo00<007ooOol0<Woo0P00ogoo47oo0008Ool3000=Ool40006Ool00`00
Oomoo`0aOol00`00Oomoo`3oOol@Ool0029oo`80031oo`800?mooa=oo`008Woo00<007ooOol0;Woo
00<007ooOol0ogoo4goo000ROol00`00Oomoo`0/Ool2003oOolFOol0029oo`03001oogoo02]oo`03
001oogoo0?mooaIoo`008Woo0P00:Woo0P00ogoo6Goo000ROol00`00Oomoo`0XOol00`00Oomoo`3o
OolIOol0029oo`03001oogoo02Moo`03001oogoo0?mooaYoo`008Woo00<007ooOol09Goo0P00ogoo
7Goo000ROol00`00Oomoo`0TOol00`00Oomoo`3oOolMOol0029oo`8002=oo`800?moob1oo`008Woo
00<007ooOol08Goo00<007ooOol0ogoo87oo000ROol00`00Oomoo`0OOol2003oOolSOol0029oo`03
001oogoo01ioo`03001oogoo0?moob=oo`008Woo00<007ooOol077oo0P00ogoo9Woo000ROol2000L
Ool00`00Oomoo`3oOolVOol0029oo`03001oogoo01Uoo`800?moobUoo`001@0017oo0P001Woo00<0
07ooOol017oo10001Woo00<007ooOol067oo00<007ooOol0ogoo:Goo0002Ool00`00Oomoo`04Ool2
0006Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`0FOol2003oOol/Ool0009oo`03001o
ogoo00eoo`03001oogoo00Moo`03001oogoo00=oo`<001Eoo`03001oogoo0?moobaoo`000Woo00<0
07ooOol03Goo00<007ooOol01goo00<007ooOol00goo00<007ooOol04goo0P00ogoo;goo0002Ool0
0`00Oomoo`0=Ool00`00Oomoo`03Ool40006Ool00`00Oomoo`0BOol00`00Oomoo`3oOol_Ool0009o
o`03001oogoo00ioo`03001oogoo009oo`03001oogoo00Moo`03001oogoo011oo`800?mooc9oo`00
0Woo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo00Moo`03001oogoo00ioo`800?mo
ocAoo`000`0037oo1@0017oo10001Woo0P003Woo00<007ooOol0ogoo=7oo000ROol00`00Oomoo`0;
Ool2003oOolgOol0029oo`03001oogoo00Yoo`03001oogoo0?moocMoo`008Woo00<007ooOol027oo
0P00ogoo>Woo000ROol00`00Oomoo`06Ool2003oOollOol0029oo`8000Ioo`03001oogoo0?moocao
o`008Woo00<007ooOol00goo0P00ogoo?goo000ROol01000Oomoogoo0P00ogoo@Goo000ROol01000
Oomoo`00ogoo@goo000ROol3003oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo
000ROol00`00Oomoo`3oOom4Ool001Moo`D000Ioo`03001oogoo0?moodAoo`0067oo00@007ooOol0
00Ioo`03001oogoo0?moodAoo`006Goo00<007ooOol01Woo00<007ooOol0ogooA7oo000JOol00`00
Oomoo`05Ool3003oOom4Ool001]oo`03001oogoo0?mood]oo`006goo00<007ooOol0ogooBgoo000G
Ool01@00Oomoogoo0000ogooCGoo000HOol3003oOom>Ool00?moofUoo`00V7oo0P002goo00<007oo
Ool037oo0P001Woo00<007ooOol0ZGoo002HOol00`00Oomoo`0:Ool2000>Ool00`00Oomoo`04Ool2
002ZOol008ioo`D000Eoo`03001oogoo009oo`80009oo`8000=oo`03001oogoo00Eoo`<000Aoo`03
001oogoo00Eoo`03001oogoo00aoo`<000Yoo`D000Eoo`8008=oo`00T7oo00<007ooOol01Goo00<0
07ooOol00goo00@007ooOol000Aoo`8000Eoo`05001oogooOol00003Ool00`00Oomoo`05Ool2000<
Ool01P00Oomoogoo001oo`H000=oo`04001oogoo0005Ool20023Ool0091oo`03001oogoo00Eoo`03
001oogoo00Aoo`8000aoo`03001oogoo00Eoo`03001oogoo01=oo`03001oogoo00eoo`03001oogoo
08Yoo`00T7oo00<007ooOol01Goo00<007ooOol017oo0P0037oo00<007ooOol01Goo00<007ooOol0
4goo00<007ooOol00goo1P001Goo00<007ooOol0RGoo002@Ool00`00Oomoo`05Ool00`00Oomoo`03
Ool01000Oomoo`002goo00<007ooOol01Goo00<007ooOol04goo00<007ooOol03goo00<007ooOol0
R7oo002=Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol00Woo0P000Woo0P0027oo1P00
17oo00<007ooOol04Goo1P003Woo00<007ooOol0R7oo002=Ool01000Oomoo`000Woo00<007ooOol0
0Woo00<007ooOol04Woo00<007ooOol01Goo00<007ooOol04goo00<007ooOol02goo00D007ooOomo
o`0008Yoo`00SGoo1`0017oo0P004goo00<007ooOol017oo0P005Goo00<007ooOol037oo0`00Rgoo
003oOomYOol00?moofUoo`00ogooJGoo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .49396 m
.00942 .49685 L
.01975 .49927 L
.02496 .50021 L
.03053 .50101 L
.03578 .50159 L
.04057 .50197 L
.04332 .50212 L
.04483 .50219 L
.04624 .50224 L
.04744 .50227 L
.04873 .5023 L
.04946 .50231 L
.05016 .50232 L
.05147 .50233 L
.05222 .50233 L
.05289 .50233 L
.05367 .50233 L
.05441 .50232 L
.05572 .5023 L
.05645 .50228 L
.05713 .50227 L
.06014 .50216 L
.06165 .50209 L
.06331 .502 L
.06868 .50163 L
.07443 .50107 L
.08481 .49971 L
.09549 .49785 L
.10711 .49535 L
.12824 .48974 L
.17106 .47513 L
.21229 .45855 L
.25193 .44164 L
.29414 .42365 L
.33476 .4071 L
.37796 .39084 L
.41956 .37678 L
.45958 .36485 L
.50217 .3539 L
.54316 .34497 L
.58674 .33709 L
.62872 .33089 L
.66911 .32606 L
.71207 .32197 L
.75345 .3189 L
.79323 .31662 L
.83558 .3148 L
.87635 .31354 L
.89858 .31302 L
Mistroke
.91969 .31264 L
.92978 .31249 L
.94053 .31236 L
.9506 .31225 L
.95985 .31217 L
.96979 .3121 L
.97502 .31208 L
.98054 .31205 L
.98534 .31204 L
.98982 .31203 L
.99239 .31202 L
.99474 .31202 L
.99603 .31202 L
.99672 .31202 L
.99744 .31202 L
.99877 .31202 L
1 .31202 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
00<000Ioo`8000Aoo`D000Aoo`@000Ioo`03001oogoo0?moodAoo`000goo00<007ooOol00goo0P00
1Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007ooOol02goo
00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0<Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03001oogoo00eoo`03001oogoo009oo`@0
00Ioo`03001oogoo0?moodAoo`000goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol0ogooA7oo0003Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol01goo
00<007ooOol0ogooA7oo0003000=Ool30005Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`0027oo0`001Woo0P00
1Goo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol0
0goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000047oo00<007ooOol00goo0`00ogooA7oo
0007Ool01@00Oomoogoo000047oo00<007ooOol00goo00<007ooOol0ogooA7oo0007Ool01@00Oomo
ogoo000037oo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol0
1goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol01goo00<007ooOol0
ogooA7oo0008Ool3000=Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol0
0`00Oomoo`3oOom4Ool000<000Ioo`8000Ioo`03001oogoo00Aoo`@000Ioo`03001oogoo0?moodAo
o`000goo00<007ooOol00goo0P001Woo00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogoo
A7oo0003Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03
001oogoo00aoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007oo
Ool037oo00<007ooOol00goo10001Woo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0=Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000=oo`03001oogoo00Uoo`05001oogoo
Ool00004Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000<000aoo`D000Aoo`@000Ioo`800?mo
odEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`0067oo1@001Goo00<0
07ooOol0ogooA7oo000JOol00`00Oomoo`05Ool00`00Oomoo`3oOom4Ool001Yoo`03001oogoo00Eo
o`03001oogoo0?moodAoo`006Woo00<007ooOol01Goo0`00ogooA7oo000JOol00`00Oomoo`05Ool0
0`00Oomoo`3oOol2Ool]000EOol001Yoo`03001oogoo00Eoo`03001oogoo0>QooaT0049oo`006Woo
00<007ooOol01Goo00<007ooOol0g7oo3000Fgoo000HOol30007Ool00`00Oomoo`3?Ool=001WOol0
029oo`800<Ioo`X007Aoo`008Woo00<007ooOol0_goo1P00OWoo000ROol00`00Oomoo`2fOol90024
Ool0029oo`03001oogoo0:eoo`T008eoo`008Woo0P00ZGoo1@00UWoo000ROol00`00Oomoo`2TOol4
002KOol0029oo`03001oogoo0:1oo`@009moo`008Woo00<007ooOol0W7oo1000Xgoo000ROol00`00
Oomoo`2HOol4002WOol0029oo`8009Eoo`@00:]oo`008Woo00<007ooOol0Sgoo1@00[goo000ROol0
0`00Oomoo`2;Ool4002dOol0029oo`03001oogoo08Moo`@00;Qoo`008Woo00<007ooOol0PWoo1@00
_7oo000ROol2001oOol40031Ool0029oo`03001oogoo07]oo`<00<Eoo`001@0017oo0P0017oo1@00
17oo10001Woo00<007ooOol0N7oo0`00b7oo0002Ool00`00Oomoo`04Ool20005Ool01000Oomoo`00
27oo00<007ooOol00goo00<007ooOol0MWoo0P00bgoo0002Ool00`00Oomoo`0<Ool00`00Oomoo`08
Ool00`00Oomoo`03Ool3001dOol2003=Ool0009oo`03001oogoo00eoo`03001oogoo00Moo`03001o
ogoo00=oo`03001oogoo075oo`<00<moo`000Woo00<007ooOol03Woo00<007ooOol00Woo10001Woo
00<007ooOol0Kgoo0P00dWoo0002Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`07Ool0
0`00Oomoo`1/Ool3003DOol0009oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00Oomoo`07
Ool00`00Oomoo`1YOol3003GOol000<000eoo`<000Eoo`@000Ioo`8006Qoo`800=Yoo`008Woo00<0
07ooOol0I7oo0`00g7oo000ROol00`00Oomoo`1ROol2003OOol0029oo`03001oogoo05moo`<00>5o
o`008Woo00<007ooOol0G7oo0`00i7oo000ROol2001KOol2003WOol0029oo`03001oogoo05Moo`<0
0>Uoo`008Woo00<007ooOol0EGoo0P00k7oo000ROol00`00Oomoo`1BOol3003^Ool0029oo`80055o
o`800?5oo`008Woo00<007ooOol0CWoo0P00lgoo000ROol00`00Oomoo`1;Ool3003eOol0029oo`03
001oogoo04Uoo`800?Qoo`008Woo00<007ooOol0AWoo0`00nWoo000ROol20015Ool2003mOol0029o
o`03001oogoo049oo`800?moo`0027oo1@0017oo0P001Goo10001Woo00<007ooOol0?goo0`00ogoo
0Woo000:Ool00`00Oomoo`04Ool20009Ool00`00Oomoo`03Ool00`00Oomoo`0mOol2003oOol5Ool0
00Yoo`03001oogoo00moo`03001oogoo00=oo`03001oogoo03Yoo`<00?moo`Moo`002Woo00<007oo
Ool03goo00<007ooOol00goo0`00=goo0`00ogoo2Woo000:Ool00`00Oomoo`0;Ool40006Ool00`00
Oomoo`0eOol2003oOol=Ool000Yoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo039oo`<0
0?moo`moo`002Woo00<007ooOol02goo00<007ooOol01goo00<007ooOol0<7oo0P00ogoo4Woo0008
Ool3000=Ool40006Ool00`00Oomoo`0]Ool3003oOolDOol0029oo`8002]oo`<00?mooaMoo`008Woo
00<007ooOol0:7oo0P00ogoo6Woo000ROol00`00Oomoo`0UOol3003oOolLOol0029oo`03001oogoo
025oo`@00?mooamoo`008Woo0`0077oo1@00ogoo8goo000ROol00`00Oomoo`03000FOol3003oOolX
Ool0029oo`03001oogoo00=oo`L000Ioo`T00?moob]oo`008Woo00<007ooOol02Woo1`00ogoo<goo
000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol0
0`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2
003oOom5Ool0029oo`03001oogoo0?moodAoo`001@0017oo0P001Woo00<007ooOol017oo10001Woo
00<007ooOol0ogooA7oo0002Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`03
Ool00`00Oomoo`3oOom4Ool0009oo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00=oo`<0
0?moodAoo`000Woo00<007ooOol03Goo00<007ooOol01goo00<007ooOol00goo00<007ooOol0ogoo
A7oo0002Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool40006Ool00`00Oomoo`3oOom4Ool0009oo`03
001oogoo00ioo`03001oogoo009oo`03001oogoo00Moo`03001oogoo0?moodAoo`000Woo00<007oo
Ool02Woo00D007ooOomoo`0000Aoo`03001oogoo00Moo`03001oogoo0?moodAoo`000`0037oo1@00
17oo10001Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo
000GOol50006Ool00`00Oomoo`3oOom4Ool001Qoo`04001oogoo0006Ool00`00Oomoo`3oOom4Ool0
01Uoo`03001oogoo00Ioo`03001oogoo0?moodAoo`006Woo00<007ooOol01Goo0`00ogooA7oo000K
Ool00`00Oomoo`3oOom;Ool001]oo`03001oogoo0?mood]oo`005goo00D007ooOomoo`000?moodeo
o`0067oo0`00ogooCWoo003oOomYOol009Eoo`8000]oo`03001oogoo00aoo`8000Eoo`03001oogoo
0:eoo`00UGoo00<007ooOol02Woo0P003Woo00<007ooOol00goo0P00[Woo002:Ool50006Ool01000
Oomoogoo0P000Woo0P0017oo00<007ooOol017oo0`001Goo00<007ooOol017oo00<007ooOol037oo
0`002Woo1@001Goo0P001Goo1000OWoo002<Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomo
o`001Goo0P0017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`8000aoo`05001oogooOol00002
Ool60002Ool01000Oomoo`001Goo0P002Goo00<007ooOol0Ngoo002<Ool00`00Oomoo`06Ool00`00
Oomoo`03Ool2000<Ool00`00Oomoo`06Ool00`00Oomoo`0BOol00`00Oomoo`0=Ool00`00Oomoo`0@
Ool00`00Oomoo`1kOol008aoo`03001oogoo00Ioo`03001oogoo00=oo`8000aoo`03001oogoo00Io
o`03001oogoo019oo`03001oogoo00Aoo`H000Aoo`03001oogoo00moo`03001oogoo07]oo`00S7oo
00<007ooOol01Woo00<007ooOol00Woo00@007ooOol000]oo`03001oogoo00Ioo`03001oogoo019o
o`03001oogoo00moo`03001oogoo00Yoo`@007ioo`00RGoo00@007ooOol0009oo`03001oogoo00=o
o`04001oogooOol20002Ool20008Ool60005Ool00`00Oomoo`0@Ool6000>Ool00`00Oomoo`0:Ool0
0`00Oomoo`1oOol008Uoo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomo
o`06Ool00`00Oomoo`0BOol00`00Oomoo`0;Ool01@00Oomoogoo000037oo00<007ooOol0Ogoo0029
Ool70005Ool2000BOol00`00Oomoo`05Ool2000DOol00`00Oomoo`0<Ool3000=Ool4001nOol00?mo
ofUoo`00ogooJGoo003oOomYOol00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .35263 m
.01975 .37298 L
.04057 .39068 L
.06168 .40506 L
.08481 .41713 L
.10536 .425 L
.11687 .42836 L
.12734 .43082 L
.1378 .43274 L
.14745 .43408 L
.15249 .43462 L
.15804 .4351 L
.16083 .43529 L
.16384 .43547 L
.16669 .4356 L
.16927 .4357 L
.17193 .43577 L
.17339 .4358 L
.17477 .43583 L
.17605 .43584 L
.17722 .43585 L
.17852 .43585 L
.17988 .43585 L
.18126 .43584 L
.18203 .43584 L
.18273 .43583 L
.1841 .43581 L
.1854 .43578 L
.1883 .43571 L
.19146 .4356 L
.19677 .43534 L
.20242 .43498 L
.21255 .43413 L
.22239 .43305 L
.233 .43164 L
.25219 .42853 L
.29539 .41946 L
.337 .40901 L
.37701 .39824 L
.4196 .3867 L
.4606 .376 L
.50417 .36541 L
.54615 .35618 L
.58654 .3483 L
.6295 .34101 L
.67088 .33505 L
.71066 .33022 L
.75302 .326 L
.79378 .32273 L
.83712 .32004 L
Mistroke
.85878 .31897 L
.87887 .31813 L
.89956 .31741 L
.91903 .31686 L
.92941 .31662 L
.94062 .3164 L
.94994 .31624 L
.96017 .3161 L
.9702 .316 L
.97955 .31593 L
.98472 .3159 L
.98943 .31588 L
.99203 .31587 L
.9934 .31587 L
.99486 .31587 L
.99613 .31587 L
.99685 .31586 L
.99753 .31586 L
.99872 .31586 L
1 .31586 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
00<000Ioo`8000Aoo`D000Aoo`@000Ioo`03001oogoo0?moodAoo`000goo00<007ooOol00goo0P00
1Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007ooOol02goo
00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0<Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03001oogoo00eoo`03001oogoo009oo`@0
00Ioo`03001oogoo0?moodAoo`000goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol0ogooA7oo0003Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol01goo
00<007ooOol0ogooA7oo0003000=Ool30005Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`0027oo0`001Woo0P00
1Goo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol0
0goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000047oo00<007ooOol00goo0`00ogooA7oo
0007Ool01@00Oomoogoo000047oo00<007ooOol00goo00<007ooOol0ogooA7oo0007Ool01@00Oomo
ogoo000037oo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol0
1goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol01goo00<007ooOol0
ogooA7oo0008Ool3000=Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol0
0`00Oomoo`3oOom4Ool000<000Ioo`8000Ioo`03001oogoo00Aoo`@000Ioo`03001oogoo0?moodAo
o`000goo00<007ooOol00goo0P001Woo00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogoo
A7oo0003Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03
001oogoo00aoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007oo
Ool037oo00<007ooOol00goo10001Woo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0=Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000=oo`03001oogoo00Uoo`05001oogoo
Ool00004Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000<000aoo`D000Aoo`@000Ioo`800?mo
odEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`0067oo1@001Goo00<0
07ooOol0ogooA7oo000JOol00`00Oomoo`05Ool00`00Oomoo`3oOom4Ool001Yoo`03001oogoo00Eo
o`03001oogoo0?moodAoo`006Woo00<007ooOol01Goo0`00ogooA7oo000JOol00`00Oomoo`05Ool0
0`00Oomoo`3oOom4Ool001Yoo`03001oogoo00Eoo`03001oogoo0?moo`aoob<001Eoo`006Woo00<0
07ooOol01Goo00<007ooOol0mGoo5P00>7oo000HOol30007Ool00`00Oomoo`3XOol=001>Ool0029o
o`800=eoo``005]oo`008Woo00<007ooOol0dWoo2P00Igoo000ROol00`00Oomoo`3<Ool6001aOol0
029oo`03001oogoo0<Ioo`H007Moo`008Woo0P00`7oo1`00OGoo000ROol00`00Oomoo`2iOol60024
Ool0029oo`03001oogoo0;9oo`L008Yoo`008Woo00<007ooOol0[7oo1P00TGoo000ROol00`00Oomo
o`2VOol6002GOol0029oo`800:9oo`D009eoo`008Woo00<007oo0000W7oo1@00XWoo000ROol01000
Oomoo`00Ugoo1000Ygoo000ROol01@00Oomoogoo0000TWoo1000Zgoo000ROol00`00Oomoo`02Ool0
0`00Oomoo`2:Ool5002_Ool0029oo`8000Aoo`03001oogoo08Eoo`@00;Aoo`008Woo00<007ooOol0
17oo00<007ooOol0P7oo1000^7oo00050004Ool20004Ool50004Ool40006Ool00`00Oomoo`05Ool0
0`00Oomoo`1lOol3002lOol0009oo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomo
o`03Ool00`00Oomoo`06Ool00`00Oomoo`1hOol3002oOol0009oo`03001oogoo00aoo`03001oogoo
00Qoo`03001oogoo00=oo`<000Moo`03001oogoo07Aoo`<00<9oo`000Woo00<007ooOol03Goo00<0
07ooOol01goo00<007ooOol00goo00<007ooOol027oo00<007ooOol0Kgoo1000aGoo0002Ool00`00
Oomoo`0>Ool00`00Oomoo`02Ool40006Ool00`00Oomoo`09Ool2001[Ool40039Ool0009oo`03001o
ogoo00ioo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00]oo`8006Eoo`@00<eoo`000Woo
00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo
05ioo`@00=5oo`000`003Goo0`001Goo10001Woo0P003goo0P00FGoo1@00eGoo000ROol00`00Oomo
o`0@Ool2001COol4003JOol0029oo`03001oogoo019oo`8004eoo`@00=ioo`008Woo00<007ooOol0
57oo00<007ooOol0AWoo1000hWoo000ROol00`00Oomoo`0EOol20012Ool4003VOol0029oo`8001Qo
o`<003]oo`@00>Yoo`008Woo00<007ooOol06Woo0`00<goo1@00kWoo000ROol00`00Oomoo`0MOol3
000/Ool4003cOol0029oo`03001oogoo021oo`@002=oo`D00?Moo`008Woo0P009Goo1P006Goo1000
o7oo000ROol00`00Oomoo`0ZOolI003oOol1Ool0029oo`03001oogoo0?moodAoo`008Woo00<007oo
Ool0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogoo
A7oo0008Ool50004Ool20005Ool40006Ool00`00Oomoo`3oOom4Ool000Yoo`03001oogoo00Aoo`80
00Uoo`03001oogoo00=oo`03001oogoo0?moodAoo`002Woo00<007ooOol03goo00<007ooOol00goo
00<007ooOol0ogooA7oo000:Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool3003oOom4Ool000Yoo`03
001oogoo00]oo`@000Ioo`03001oogoo0?moodAoo`002Woo00<007ooOol02goo00<007ooOol01goo
00<007ooOol0ogooA7oo000:Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool0
00Qoo`<000eoo`@000Ioo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0
029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0
029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03
001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`80
0?moodEoo`008Woo00<007ooOol0ogooA7oo00050004Ool20006Ool00`00Oomoo`04Ool40006Ool0
0`00Oomoo`3oOom4Ool0009oo`03001oogoo00Aoo`8000Ioo`03001oogoo00Qoo`03001oogoo00=o
o`03001oogoo0?moodAoo`000Woo00<007ooOol03Goo00<007ooOol01goo00<007ooOol00goo0`00
ogooA7oo0002Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`3oOom4
Ool0009oo`03001oogoo00eoo`03001oogoo00=oo`@000Ioo`03001oogoo0?moodAoo`000Woo00<0
07ooOol03Woo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0ogooA7oo0002Ool00`00Oomo
o`0:Ool01@00Oomoogoo000017oo00<007ooOol01goo00<007ooOol0ogooA7oo0003000<Ool50004
Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
01Moo`D000Ioo`03001oogoo0?moodAoo`0067oo00@007ooOol000Ioo`03001oogoo0?moodAoo`00
6Goo00<007ooOol01Woo00<007ooOol0ogooA7oo000JOol00`00Oomoo`05Ool3003oOom4Ool001]o
o`03001oogoo0?mood]oo`006goo00<007ooOol0ogooBgoo000GOol01@00Oomoogoo0000ogooCGoo
000HOol3003oOom>Ool00?moofUoo`00V7oo0P002goo00<007ooOol037oo0P001Woo00<007ooOol0
ZGoo002HOol00`00Oomoo`0:Ool2000>Ool00`00Oomoo`04Ool2002ZOol008ioo`D000Eoo`03001o
ogoo009oo`80009oo`8000=oo`03001oogoo00Eoo`<000Aoo`03001oogoo00Eoo`03001oogoo00ao
o`<000]oo`<000Ioo`8008=oo`00T7oo00<007ooOol01Goo00<007ooOol00goo00@007ooOol000Ao
o`8000Eoo`05001oogooOol00003Ool00`00Oomoo`05Ool2000<Ool01P00Oomoogoo001oo`H0009o
o`05001oogooOol00005Ool20023Ool0091oo`03001oogoo00Eoo`03001oogoo00Aoo`8000aoo`03
001oogoo00Eoo`03001oogoo01=oo`03001oogoo00moo`03001oogoo08Qoo`00T7oo00<007ooOol0
1Goo00<007ooOol017oo0P0037oo00<007ooOol01Goo00<007ooOol04goo00<007ooOol00goo1P00
1Woo00<007ooOol0R7oo002@Ool00`00Oomoo`05Ool00`00Oomoo`03Ool01000Oomoo`002goo00<0
07ooOol01Goo00<007ooOol04goo00<007ooOol03Goo0P00Rgoo002=Ool01000Oomoo`000Woo00<0
07ooOol00Woo00<007ooOol00Woo0P000Woo0P0027oo1P0017oo00<007ooOol04Goo1P003Woo00<0
07ooOol0R7oo002=Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol04Woo00<007ooOol0
1Goo00<007ooOol04goo00<007ooOol02goo00D007ooOomoo`0008Yoo`00SGoo1`0017oo0P004goo
00<007ooOol017oo0P005Goo00<007ooOol037oo0`00Rgoo003oOomYOol00?moofUoo`00ogooJGoo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20062 m
.04057 .26035 L
.08481 .31004 L
.10632 .32903 L
.12636 .344 L
.16632 .3669 L
.18776 .37581 L
.20726 .38215 L
.22737 .3871 L
.23871 .38925 L
.24919 .39086 L
.25866 .39203 L
.26885 .39299 L
.27469 .39342 L
.28003 .39373 L
.2854 .39397 L
.29051 .39414 L
.29322 .3942 L
.29456 .39423 L
.29578 .39424 L
.29688 .39426 L
.29808 .39427 L
.29929 .39428 L
.30057 .39429 L
.30129 .39429 L
.30197 .39429 L
.30325 .39429 L
.30462 .39429 L
.3054 .39429 L
.30612 .39428 L
.30731 .39427 L
.30863 .39426 L
.3113 .39422 L
.3138 .39417 L
.31609 .39411 L
.32126 .39395 L
.33061 .39353 L
.3409 .3929 L
.35048 .39217 L
.37221 .39006 L
.41321 .38474 L
.45678 .37783 L
.49876 .37058 L
.53915 .3635 L
.58212 .35619 L
.62349 .34961 L
.66327 .34385 L
.70563 .3384 L
.7464 .33387 L
.78974 .32984 L
Mistroke
.83149 .32672 L
.87164 .3244 L
.89407 .32338 L
.91438 .32264 L
.93557 .32203 L
.95552 .32162 L
.96579 .32146 L
.97141 .3214 L
.97664 .32134 L
.98149 .32131 L
.9859 .32128 L
.98825 .32127 L
.9908 .32126 L
.9922 .32125 L
.9935 .32125 L
.99481 .32125 L
.99605 .32124 L
.99695 .32124 L
.99793 .32124 L
.99901 .32124 L
1 .32124 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
00<000Ioo`8000Aoo`D000Aoo`@000Ioo`03001oogoo0?moodAoo`000goo00<007ooOol00goo0P00
1Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007ooOol02goo
00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0<Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03001oogoo00eoo`03001oogoo009oo`@0
00Ioo`03001oogoo0?moodAoo`000goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol0ogooA7oo0003Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol01goo
00<007ooOol0ogooA7oo0003000=Ool30005Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`0027oo0`001Woo0P00
1Goo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol0
0goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000047oo00<007ooOol00goo0`00ogooA7oo
0007Ool01@00Oomoogoo000047oo00<007ooOol00goo00<007ooOol0ogooA7oo0007Ool01@00Oomo
ogoo000037oo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol0
1goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol01goo00<007ooOol0
ogooA7oo0008Ool3000=Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol0
0`00Ool0003oOom4Ool0029oo`03001oo`000?moodAoo`008Woo0P0000=oo`00Ool0ogoo@Woo000R
Ool01@00Oomoogoo0000ogoo@Woo00030006Ool20006Ool00`00Oomoo`04Ool40006Ool01@00Oomo
ogoo0000ogoo@Woo0003Ool00`00Oomoo`03Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`3oOoloOol000=oo`03001oogoo00aoo`03001oogoo00Moo`03001o
ogoo00=oo`<000=oo`03001oogoo0?moocioo`000goo00<007ooOol037oo00<007ooOol01goo00<0
07ooOol00goo00<007ooOol00goo00<007ooOol0ogoo?Woo0003Ool00`00Oomoo`0<Ool00`00Oomo
o`03Ool40006Ool00`00Oomoo`04Ool00`00Oomoo`3oOolmOol000=oo`03001oogoo00eoo`03001o
ogoo009oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo0?moocaoo`000goo00<007ooOol0
2Goo00D007ooOomoo`0000Aoo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo0?moocaoo`00
0`0037oo1@0017oo10001Woo0P001goo00<007ooOol0ogoo>goo000ROol00`00Oomoo`07Ool00`00
Oomoo`3oOoljOol0029oo`03001oogoo00Moo`03001oogoo0?moocYoo`008Woo00<007ooOol027oo
00<007ooOol0ogoo>Goo000ROol00`00Oomoo`09Ool00`00Oomoo`3oOolhOol0029oo`8000Yoo`03
001oogoo0?moocQoo`008Woo00<007ooOol02Woo00<007ooOol0ogoo=goo000ROol00`00Oomoo`0;
Ool00`00Oomoo`3oOolfOol0029oo`03001oogoo00aoo`03001oogoo0?moocEoo`008Woo00<007oo
Ool03Goo00<007ooOol0ogoo=7oo000ROol2000?Ool00`00Oomoo`3oOolcOol0029oo`03001oogoo
00moo`03001oogoo0?mooc9oo`008Woo00<007ooOol047oo00<007ooOol0ogoo<Goo000ROol00`00
Oomoo`0AOol00`00Oomoo`3oOol`Ool0029oo`8001=oo`03001oogoo0?moobmoo`008Woo00<007oo
Ool04goo00<007ooOol0ogoo;Woo000HOol50005Ool00`00Oomoo`0DOol00`00Oomoo`3oOol]Ool0
01Yoo`03001oogoo00Eoo`03001oogoo01Eoo`03001oogoo0?moobaoo`006Woo00<007ooOol01Goo
00<007ooOol05Woo00<007ooOol0ogoo:goo000JOol00`00Oomoo`05Ool3000GOol00`00Oomoo`3o
OolZOol001Yoo`03001oogoo00Eoo`03001oogoo01Qoo`03001oogoo0?moobUoo`006Woo00<007oo
Ool01Goo00<007ooOol06Goo00<007ooOol0ogoo:7oo000JOol00`00Oomoo`05Ool00`00Oomoo`0J
Ool00`00Oomoo`3oOolWOol001Qoo`<000Moo`03001oogoo01]oo`03001oogoo0>]oobD001Eoo`00
8Woo0P007Goo00<007ooOol0e7oo5P00>Woo000ROol00`00Oomoo`0MOol20038Ool<001@Ool0029o
o`03001oogoo01moo`03001oogoo0;]oo`X005aoo`008Woo00<007ooOol087oo00<007ooOol0/goo
1`00IWoo000ROol2000ROol00`00Oomoo`2/Ool6001]Ool0029oo`03001oogoo029oo`03001oogoo
0:Aoo`L007=oo`008Woo00<007ooOol08goo0P00Vgoo2@00NWoo000ROol00`00Oomoo`0UOol2002@
Ool90023Ool0029oo`03001oogoo02Moo`8008Qoo`H008aoo`008Woo0P00:Woo0P00P7oo1P00TWoo
000ROol00`00Oomoo`0[Ool00`00Oomoo`1fOol7002HOol0029oo`03001oogoo02aoo`80075oo`D0
09moo`008Woo00<007ooOol0;Woo0P00JWoo1@00Y7oo000ROol00`00Oomoo`0`Ool3001SOol4002Y
Ool0029oo`8003Aoo`<005]oo`D00:eoo`008Woo00<007ooOol0=Woo0`00DWoo1P00/Woo00050004
Ool20004Ool50004Ool40006Ool00`00Oomoo`0iOol30019Ool6002hOol0009oo`03001oogoo00Ao
o`8000Eoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`0lOol3000oOol7002nOol0009o
o`03001oogoo00aoo`03001oogoo00Qoo`03001oogoo00=oo`<003moo`<003Ioo`H00<Eoo`000Woo
00<007ooOol03Goo00<007ooOol01goo00<007ooOol00goo00<007ooOol0@Woo1`00:7oo1`00bgoo
0002Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool40006Ool00`00Oomoo`19Ool7000COol>003BOol0
009oo`03001oogoo00ioo`03001oogoo009oo`03001oogoo00Moo`03001oogoo051ooa<00>1oo`00
0Woo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo00Moo`03001oogoo0?moodAoo`00
0`003Goo0`001Goo10001Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo
0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEo
o`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAo
o`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo
00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007oo
Ool0ogooA7oo0008Ool50004Ool20005Ool40006Ool00`00Oomoo`3oOom4Ool000Yoo`03001oogoo
00Aoo`8000Uoo`03001oogoo00=oo`03001oogoo0?moodAoo`002Woo00<007ooOol03goo00<007oo
Ool00goo00<007ooOol0ogooA7oo000:Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool3003oOom4Ool0
00Yoo`03001oogoo00]oo`@000Ioo`03001oogoo0?moodAoo`002Woo00<007ooOol02goo00<007oo
Ool01goo00<007ooOol0ogooA7oo000:Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`3o
Oom4Ool000Qoo`<000eoo`@000Ioo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0
029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo00050004Ool20006Ool00`00Oomoo`04Ool4
0006Ool00`00Oomoo`3oOom4Ool0009oo`03001oogoo00Aoo`8000Ioo`03001oogoo00Qoo`03001o
ogoo00=oo`03001oogoo0?moodAoo`000Woo00<007ooOol03Goo00<007ooOol01goo00<007ooOol0
0goo0`00ogooA7oo0002Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomo
o`3oOom4Ool0009oo`03001oogoo00eoo`03001oogoo00=oo`@000Ioo`03001oogoo0?moodAoo`00
0Woo00<007ooOol03Woo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0ogooA7oo0002Ool0
0`00Oomoo`0:Ool01@00Oomoogoo000017oo00<007ooOol01goo00<007ooOol0ogooA7oo0003000<
Ool50004Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3o
Oom4Ool001Moo`D000Ioo`03001oogoo0?moodAoo`0067oo00@007ooOol000Ioo`03001oogoo0?mo
odAoo`006Goo00<007ooOol01Woo00<007ooOol0ogooA7oo000JOol00`00Oomoo`05Ool3003oOom4
Ool001]oo`03001oogoo0?mood]oo`006goo00<007ooOol0ogooBgoo000GOol01@00Oomoogoo0000
ogooCGoo000HOol3003oOom>Ool00?moofUoo`00UGoo0P002goo00<007ooOol037oo0P001Goo00<0
07ooOol0[Goo002EOol00`00Oomoo`0:Ool2000>Ool00`00Oomoo`03Ool2002^Ool008Yoo`D000Io
o`04001oogooOol20002Ool20004Ool00`00Oomoo`04Ool30005Ool00`00Oomoo`04Ool00`00Oomo
o`0<Ool3000;Ool30006Ool20005Ool4001nOol008aoo`03001oogoo00Ioo`03001oogoo009oo`04
001oogoo0005Ool20004Ool01@00Oomoogoo000017oo00<007ooOol017oo0P0037oo00D007ooOomo
o`00009oo`H00003Ool007oo009oo`03001oogoo00=oo`8000Uoo`03001oogoo07]oo`00S7oo00<0
07ooOol01Woo00<007ooOol00goo0P0037oo00<007ooOol01Woo00<007ooOol04Woo00<007ooOol0
3goo00<007ooOol03Woo00<007ooOol0Ngoo002<Ool00`00Oomoo`06Ool00`00Oomoo`03Ool2000<
Ool00`00Oomoo`06Ool00`00Oomoo`0BOol00`00Oomoo`04Ool60005Ool00`00Oomoo`0>Ool00`00
Oomoo`1kOol008aoo`03001oogoo00Ioo`03001oogoo009oo`04001oogoo000;Ool00`00Oomoo`06
Ool00`00Oomoo`0BOol00`00Oomoo`0=Ool2000=Ool4001nOol008Uoo`04001oogoo0002Ool00`00
Oomoo`03Ool01000Oomoogoo0P000Woo0P0027oo1P001Goo00<007ooOol047oo1P003Woo00<007oo
Ool02Woo00<007ooOol0Ogoo0029Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol04Goo
00<007ooOol01Woo00<007ooOol04Woo00<007ooOol02goo00D007ooOomoo`0000aoo`03001oogoo
07moo`00RGoo1`001Goo0P004Woo00<007ooOol01Goo0P0057oo00<007ooOol037oo0`003Goo1000
OWoo003oOomYOol00?moofUoo`00ogooJGoo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .07515 m
.04057 .14268 L
.08481 .20425 L
.12636 .2511 L
.16632 .28695 L
.20885 .31624 L
.2498 .33692 L
.27217 .34552 L
.29331 .35211 L
.31251 .35691 L
.33365 .36103 L
.35448 .36402 L
.36588 .36525 L
.37656 .36617 L
.38746 .36689 L
.39283 .36717 L
.39782 .36738 L
.40269 .36755 L
.40712 .36767 L
.41203 .36777 L
.41473 .36781 L
.41595 .36782 L
.41727 .36784 L
.41859 .36785 L
.4198 .36786 L
.42101 .36786 L
.42216 .36787 L
.42349 .36787 L
.42472 .36787 L
.42608 .36787 L
.42676 .36786 L
.42752 .36786 L
.42892 .36785 L
.43021 .36784 L
.43311 .36781 L
.43566 .36778 L
.43835 .36774 L
.44761 .36752 L
.45286 .36735 L
.45775 .36717 L
.47923 .3661 L
.49874 .3648 L
.54072 .36119 L
.58111 .35705 L
.62408 .35232 L
.66545 .34774 L
.70523 .34354 L
.74759 .33943 L
.78836 .33595 L
.8317 .33284 L
Mistroke
.87345 .33048 L
.9136 .32882 L
.9343 .32821 L
.94578 .32794 L
.95634 .32774 L
.96715 .32757 L
.97272 .32751 L
.97883 .32745 L
.98416 .32741 L
.98913 .32739 L
.99188 .32737 L
.99438 .32737 L
.99577 .32737 L
.99649 .32736 L
.99727 .32736 L
.99794 .32736 L
.99869 .32736 L
1 .32736 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
00<000Ioo`8000Aoo`D000Aoo`@000Ioo`03001oogoo0?moodAoo`000goo00<007ooOol00goo0P00
1Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007ooOol02goo
00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0<Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03001oogoo00eoo`03001oogoo009oo`@0
00Ioo`800?moodEoo`000goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01goo00<007oo
0000ogooA7oo0003Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol01goo00<007oo
0000ogooA7oo0003000=Ool30005Ool40006Ool200000goo001oo`3oOom2Ool0029oo`04001oogoo
003oOom3Ool0029oo`05001oogooOol0003oOom2Ool0029oo`03001oogoo009oo`03001oogoo0?mo
ocmoo`008Woo00<007ooOol00Woo00<007ooOol0ogoo?goo000ROol20004Ool00`00Oomoo`3oOoln
Ool0029oo`03001oogoo00=oo`03001oogoo0?moocioo`008Woo00<007ooOol017oo00<007ooOol0
ogoo?Goo000ROol00`00Oomoo`05Ool00`00Oomoo`3oOollOol0029oo`03001oogoo00Eoo`03001o
ogoo0?moocaoo`008Woo0P001goo00<007ooOol0ogoo>goo000ROol00`00Oomoo`06Ool00`00Oomo
o`3oOolkOol0029oo`03001oogoo00Moo`03001oogoo0?moocYoo`008Woo00<007ooOol027oo00<0
07ooOol0ogoo>Goo000ROol20009Ool00`00Oomoo`3oOoliOol0029oo`03001oogoo00Uoo`03001o
ogoo0?moocQoo`008Woo00<007ooOol02Goo00<007ooOol0ogoo>7oo0008Ool30006Ool20005Ool4
0006Ool00`00Oomoo`0:Ool00`00Oomoo`3oOolgOol000Moo`05001oogooOol00005Ool20009Ool0
0`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`3oOolfOol000Moo`05001oogooOol0000@Ool0
0`00Oomoo`03Ool3000<Ool00`00Oomoo`3oOoleOol000Moo`05001oogooOol0000@Ool00`00Oomo
o`03Ool00`00Oomoo`0<Ool00`00Oomoo`3oOoleOol000Moo`05001oogooOol0000<Ool40006Ool0
0`00Oomoo`0=Ool00`00Oomoo`3oOoldOol000Moo`05001oogooOol0000<Ool00`00Oomoo`07Ool0
0`00Oomoo`0>Ool00`00Oomoo`3oOolcOol000Moo`05001oogooOol0000<Ool00`00Oomoo`07Ool0
0`00Oomoo`0?Ool00`00Oomoo`3oOolbOol000Qoo`<000eoo`@000Ioo`80011oo`03001oogoo0?mo
oc9oo`008Woo00<007ooOol047oo00<007ooOol0ogoo<Goo000ROol00`00Oomoo`0AOol00`00Oomo
o`3oOol`Ool0029oo`03001oogoo015oo`03001oogoo0?mooc1oo`008Woo0P004goo00<007ooOol0
ogoo;goo000ROol00`00Oomoo`0COol00`00Oomoo`3oOol^Ool0029oo`03001oogoo01Aoo`03001o
ogoo0?moobeoo`008Woo00<007ooOol057oo00<007ooOol0ogoo;Goo000ROol00`00Oomoo`0EOol0
0`00Oomoo`3oOol/Ool0029oo`8001Moo`03001oogoo0?moob]oo`008Woo00<007ooOol05goo00<0
07ooOol0ogoo:Woo000ROol00`00Oomoo`0GOol00`00Oomoo`3oOolZOol0029oo`03001oogoo01Qo
o`03001oogoo0?moobUoo`008Woo00<007ooOol06Goo00<007ooOol0ogoo:7oo000ROol2000KOol0
0`00Oomoo`3oOolWOol0029oo`03001oogoo01]oo`03001oogoo0?moobIoo`000`001Woo0P001Woo
00<007ooOol017oo10001Woo00<007ooOol077oo00<007ooOol0ogoo9Goo0003Ool00`00Oomoo`03
Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`0MOol00`00Oomoo`3oOolTOol0
00=oo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo00=oo`<001eoo`03001oogoo0?moobAo
o`000goo00<007ooOol037oo00<007ooOol01goo00<007ooOol00goo00<007ooOol07Woo00<007oo
Ool0ogoo8goo0003Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool40006Ool00`00Oomoo`0OOol00`00
Oomoo`3oOolROol000=oo`03001oogoo00eoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo
021oo`03001oogoo0?moob5oo`000goo00<007ooOol02Goo00D007ooOomoo`0000Aoo`03001oogoo
00Moo`03001oogoo025oo`03001oogoo0?moob1oo`000`0037oo1@0017oo10001Woo0P008goo00<0
07ooOol0ogoo7goo000ROol00`00Oomoo`0SOol2003oOolOOol0029oo`03001oogoo02Eoo`03001o
ogoo0?mooaaoo`008Woo00<007ooOol09Woo00<007ooOol0ogoo6goo000ROol00`00Oomoo`0WOol0
0`00Oomoo`3oOolJOol0029oo`8002Uoo`03001oogoo0?mooaUoo`008Woo00<007ooOol0:Goo0P00
ogoo6Goo000ROol00`00Oomoo`0[Ool00`00Oomoo`3oOolFOol0029oo`03001oogoo02aoo`03001o
ogoo0?mooaEoo`008Woo00<007ooOol0;Goo00<007ooOol0ogoo57oo000ROol2000_Ool00`00Oomo
o`3oOolCOol0029oo`03001oogoo02moo`03001oogoo0?mooa9oo`008Woo00<007ooOol0<7oo0P00
ogoo4Woo000ROol00`00Oomoo`0bOol00`00Oomoo`3oOol?Ool0029oo`8003Aoo`800?moo`moo`00
8Woo00<007ooOol0=Goo00<007ooOol0ogoo37oo000HOol50005Ool00`00Oomoo`0fOol2003oOol<
Ool001Yoo`03001oogoo00Eoo`03001oogoo03Qoo`03001oogoo0?moo`Uoo`006Woo00<007ooOol0
1Goo00<007ooOol0>Goo00<007ooOol0ogoo27oo000JOol00`00Oomoo`05Ool3000jOol2003oOol8
Ool001Yoo`03001oogoo00Eoo`03001oogoo03aoo`03001oogoo0?moo`Eoo`006Woo00<007ooOol0
1Goo00<007ooOol0?Goo0P00ogoo1Goo000JOol00`00Oomoo`05Ool00`00Oomoo`0oOol2003oOol3
Ool001Qoo`<000Moo`03001oogoo045oo`800?moo`5oo`008Woo0P00A7oo0P00oWoo000ROol00`00
Oomoo`15Ool2002iOol^000EOol0029oo`03001oogoo04Moo`800:Yoo`d004=oo`008Woo00<007oo
Ool0BGoo0P00Vgoo3@00D7oo000ROol2001<Ool3002<Ool<001MOol0029oo`03001oogoo04ioo`80
081oo`X006Uoo`008Woo00<007ooOol0D7oo0`00Mgoo1P00Lgoo000ROol00`00Oomoo`1COol3001[
Ool9001iOol0029oo`03001oogoo05Ioo`@005ioo`T0089oo`008Woo0P00Fgoo1@00DWoo1`00Rgoo
000ROol00`00Oomoo`1OOol30015Ool:002BOol0029oo`03001oogoo069oo`D003Aoo``009aoo`00
8Woo00<007ooOol0Igoo3@0067oo3`00Z7oo000ROol00`00Oomoo`1dOolH002gOol0029oo`800?mo
odEoo`008Woo00<007ooOol0ogooA7oo00050004Ool20004Ool50004Ool40006Ool00`00Oomoo`3o
Oom4Ool0009oo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomo
o`3oOom4Ool0009oo`03001oogoo00aoo`03001oogoo00Qoo`03001oogoo00=oo`<00?moodAoo`00
0Woo00<007ooOol03Goo00<007ooOol01goo00<007ooOol00goo00<007ooOol0ogooA7oo0002Ool0
0`00Oomoo`0>Ool00`00Oomoo`02Ool40006Ool00`00Oomoo`3oOom4Ool0009oo`03001oogoo00io
o`03001oogoo009oo`03001oogoo00Moo`03001oogoo0?moodAoo`000Woo00<007ooOol02Woo00D0
07ooOomoo`0000Aoo`03001oogoo00Moo`03001oogoo0?moodAoo`000`003Goo0`001Goo10001Woo
0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007oo
Ool0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogoo
A7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo0008Ool50004
Ool20005Ool40006Ool00`00Oomoo`3oOom4Ool000Yoo`03001oogoo00Aoo`8000Uoo`03001oogoo
00=oo`03001oogoo0?moodAoo`002Woo00<007ooOol03goo00<007ooOol00goo00<007ooOol0ogoo
A7oo000:Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool3003oOom4Ool000Yoo`03001oogoo00]oo`@0
00Ioo`03001oogoo0?moodAoo`002Woo00<007ooOol02goo00<007ooOol01goo00<007ooOol0ogoo
A7oo000:Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000Qoo`<000eoo`@0
00Ioo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03
001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo
0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo
0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAo
o`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo
00<007ooOol0ogooA7oo00050004Ool20006Ool00`00Oomoo`04Ool40006Ool00`00Oomoo`3oOom4
Ool0009oo`03001oogoo00Aoo`8000Ioo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo0?mo
odAoo`000Woo00<007ooOol03Goo00<007ooOol01goo00<007ooOol00goo0`00ogooA7oo0002Ool0
0`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`3oOom4Ool0009oo`03001o
ogoo00eoo`03001oogoo00=oo`@000Ioo`03001oogoo0?moodAoo`000Woo00<007ooOol03Woo00<0
07ooOol00Woo00<007ooOol01goo00<007ooOol0ogooA7oo0002Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000017oo00<007ooOol01goo00<007ooOol0ogooA7oo0003000<Ool50004Ool40006Ool2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03
001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03
001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool001Moo`D000Ioo`03
001oogoo0?moodAoo`0067oo00@007ooOol000Ioo`03001oogoo0?moodAoo`006Goo00<007ooOol0
1Woo00<007ooOol0ogooA7oo000JOol00`00Oomoo`05Ool3003oOom4Ool001]oo`03001oogoo0?mo
od]oo`006goo00<007ooOol0ogooBgoo000GOol01@00Oomoogoo0000ogooCGoo000HOol3003oOom>
Ool00?moofUoo`00V7oo0P002goo00<007ooOol037oo0P001Woo00<007ooOol0ZGoo002HOol00`00
Oomoo`0:Ool2000>Ool00`00Oomoo`04Ool2002ZOol008ioo`D000Eoo`03001oogoo009oo`80009o
o`8000=oo`03001oogoo00Eoo`<000Aoo`03001oogoo00Eoo`03001oogoo00aoo`<000aoo`<000Eo
o`8008=oo`00T7oo00<007ooOol01Goo00<007ooOol00goo00@007ooOol000Aoo`8000Eoo`05001o
ogooOol00003Ool00`00Oomoo`05Ool2000<Ool01P00Oomoogoo001oo`H000Eoo`03001oogoo00Ao
o`8008=oo`00T7oo00<007ooOol01Goo00<007ooOol017oo0P0037oo00<007ooOol01Goo00<007oo
Ool04goo00<007ooOol02goo1@00RWoo002@Ool00`00Oomoo`05Ool00`00Oomoo`04Ool2000<Ool0
0`00Oomoo`05Ool00`00Oomoo`0COol00`00Oomoo`03Ool60002Ool01000Oomoo`00Rgoo002@Ool0
0`00Oomoo`05Ool00`00Oomoo`03Ool01000Oomoo`002goo00<007ooOol01Goo00<007ooOol04goo
00<007ooOol037oo00<007oo0000Rgoo002=Ool01000Oomoo`000Woo00<007ooOol00Woo00<007oo
Ool00Woo0P000Woo0P0027oo1P0017oo00<007ooOol04Goo1P002goo00<007oo0000Rgoo002=Ool0
1000Oomoo`000Woo00<007ooOol00Woo00<007ooOol04Woo00<007ooOol01Goo00<007ooOol04goo
00<007ooOol03Goo0P00Rgoo002=Ool70004Ool2000COol00`00Oomoo`04Ool2000EOol00`00Oomo
o`0>Ool00`00Oomoo`29Ool00?moofUoo`00ogooJGoo003oOomYOol00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.5) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .00694 m
.04057 .06636 L
.08481 .12539 L
.12636 .17426 L
.16632 .21482 L
.20885 .25105 L
.2498 .27947 L
.29331 .30328 L
.33524 .32067 L
.37557 .33295 L
.3964 .3378 L
.41848 .34196 L
.43923 .34504 L
.45821 .34724 L
.47859 .349 L
.48983 .34973 L
.50051 .35028 L
.51058 .35067 L
.5161 .35085 L
.52131 .35098 L
.52617 .35108 L
.53143 .35116 L
.53376 .35119 L
.53622 .35122 L
.53831 .35123 L
.54062 .35125 L
.54198 .35125 L
.54325 .35126 L
.54391 .35126 L
.54464 .35126 L
.5454 .35126 L
.54612 .35126 L
.54743 .35126 L
.54863 .35126 L
.54994 .35126 L
.55133 .35125 L
.5525 .35125 L
.55375 .35124 L
.556 .35123 L
.55867 .35121 L
.5611 .35118 L
.56652 .35111 L
.5724 .35101 L
.58306 .35078 L
.60393 .35013 L
.62603 .34922 L
.66581 .34715 L
.70816 .34462 L
.74893 .34209 L
.79227 .33952 L
Mistroke
.83402 .33732 L
.87418 .33556 L
.8966 .33477 L
.91691 .33417 L
.93811 .33368 L
.95805 .33335 L
.96833 .33323 L
.97394 .33317 L
.97917 .33313 L
.98364 .33311 L
.98843 .33309 L
.99116 .33308 L
.9925 .33307 L
.99374 .33307 L
.99485 .33307 L
.99606 .33307 L
.99729 .33306 L
.99858 .33306 L
.99927 .33306 L
1 .33306 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000R
Ool3003oOom4Ool0029oo`03001oo`000?moodAoo`008Woo00@007ooOol00?mood=oo`008Woo00D0
07ooOomoo`000?mood9oo`008Woo00D007ooOomoo`000?mood9oo`008Woo0P000goo00<007ooOol0
ogoo?goo000ROol00`00Oomoo`03Ool00`00Oomoo`3oOolnOol0029oo`03001oogoo00=oo`03001o
ogoo0?moocioo`008Woo00<007ooOol017oo00<007ooOol0ogoo?Goo000ROol20006Ool00`00Oomo
o`3oOollOol0029oo`03001oogoo00Eoo`03001oogoo0?moocaoo`008Woo00<007ooOol01Woo00<0
07ooOol0ogoo>goo000ROol00`00Oomoo`07Ool00`00Oomoo`3oOoljOol0029oo`03001oogoo00Mo
o`03001oogoo0?moocYoo`008Woo0P002Goo00<007ooOol0ogoo>Goo000ROol00`00Oomoo`09Ool0
0`00Oomoo`3oOolhOol000<000Ioo`8000Aoo`D000Aoo`@000Ioo`03001oogoo00Uoo`03001oogoo
0?moocQoo`000goo00<007ooOol00goo0P001Goo00@007ooOol000Qoo`03001oogoo00=oo`03001o
ogoo00Yoo`03001oogoo0?moocMoo`000goo00<007ooOol02goo00<007ooOol027oo00<007ooOol0
0goo00<007ooOol02goo00<007ooOol0ogoo=Woo0003Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool0
0`00Oomoo`03Ool3000<Ool00`00Oomoo`3oOoleOol000=oo`03001oogoo00eoo`03001oogoo009o
o`@000Ioo`03001oogoo00eoo`03001oogoo0?moocAoo`000goo00<007ooOol03Goo00<007ooOol0
0Woo00<007ooOol01goo00<007ooOol03Goo00<007ooOol0ogoo=7oo0003Ool00`00Oomoo`09Ool0
1@00Oomoogoo000017oo00<007ooOol01goo00<007ooOol03Woo00<007ooOol0ogoo<goo0003000=
Ool30005Ool40006Ool2000@Ool00`00Oomoo`3oOolbOol0029oo`03001oogoo011oo`03001oogoo
0?mooc5oo`008Woo00<007ooOol047oo00<007ooOol0ogoo<Goo000ROol00`00Oomoo`0AOol00`00
Oomoo`3oOol`Ool0029oo`03001oogoo019oo`03001oogoo0?moobmoo`008Woo0P0057oo00<007oo
Ool0ogoo;Woo000ROol00`00Oomoo`0DOol00`00Oomoo`3oOol]Ool0029oo`03001oogoo01Aoo`03
001oogoo0?moobeoo`008Woo00<007ooOol05Goo00<007ooOol0ogoo;7oo000ROol00`00Oomoo`0F
Ool00`00Oomoo`3oOol[Ool0029oo`8001Qoo`03001oogoo0?moobYoo`008Woo00<007ooOol05goo
00<007ooOol0ogoo:Woo000ROol00`00Oomoo`0HOol00`00Oomoo`3oOolYOol0029oo`03001oogoo
01Uoo`03001oogoo0?moobQoo`008Woo0P006goo00<007ooOol0ogoo9goo000ROol00`00Oomoo`0K
Ool00`00Oomoo`3oOolVOol0029oo`03001oogoo01]oo`03001oogoo0?moobIoo`0027oo0`001Woo
0P001Goo10001Woo00<007ooOol077oo00<007ooOol0ogoo9Goo0007Ool01@00Oomoogoo00001Goo
0P002Goo00<007ooOol00goo00<007ooOol07Goo00<007ooOol0ogoo97oo0007Ool01@00Oomoogoo
000047oo00<007ooOol00goo0`007Woo00<007ooOol0ogoo8goo0007Ool01@00Oomoogoo000047oo
00<007ooOol00goo00<007ooOol07goo00<007ooOol0ogoo8Woo0007Ool01@00Oomoogoo000037oo
10001Woo00<007ooOol07goo00<007ooOol0ogoo8Woo0007Ool01@00Oomoogoo000037oo00<007oo
Ool01goo00<007ooOol087oo00<007ooOol0ogoo8Goo0007Ool01@00Oomoogoo000037oo00<007oo
Ool01goo00<007ooOol08Goo00<007ooOol0ogoo87oo0008Ool3000=Ool40006Ool2000SOol00`00
Oomoo`3oOolOOol0029oo`03001oogoo02=oo`800?mooamoo`008Woo00<007ooOol09Goo00<007oo
Ool0ogoo77oo000ROol00`00Oomoo`0VOol00`00Oomoo`3oOolKOol0029oo`8002Qoo`03001oogoo
0?mooaYoo`008Woo00<007ooOol0:7oo00<007ooOol0ogoo6Goo000ROol00`00Oomoo`0YOol00`00
Oomoo`3oOolHOol0029oo`03001oogoo02Yoo`03001oogoo0?mooaMoo`008Woo00<007ooOol0:goo
00<007ooOol0ogoo5Woo000ROol2000]Ool00`00Oomoo`3oOolEOol0029oo`03001oogoo02eoo`03
001oogoo0?mooaAoo`008Woo00<007ooOol0;Woo00<007ooOol0ogoo4goo000ROol00`00Oomoo`0_
Ool00`00Oomoo`3oOolBOol0029oo`03001oogoo031oo`800?mooa9oo`008Woo0P00<goo00<007oo
Ool0ogoo3goo000ROol00`00Oomoo`0cOol00`00Oomoo`3oOol>Ool000<000Ioo`8000Ioo`03001o
ogoo00Aoo`@000Ioo`03001oogoo03Aoo`03001oogoo0?moo`eoo`000goo00<007ooOol00goo0P00
1Woo00<007ooOol027oo00<007ooOol00goo00<007ooOol0=Goo00<007ooOol0ogoo37oo0003Ool0
0`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`03Ool3000fOol2003oOol<Ool000=oo`03001o
ogoo00aoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo03Qoo`03001oogoo0?moo`Uoo`00
0goo00<007ooOol037oo00<007ooOol00goo10001Woo00<007ooOol0>Goo00<007ooOol0ogoo27oo
0003Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0jOol00`00Oomo
o`3oOol7Ool000=oo`03001oogoo00Uoo`05001oogooOol00004Ool00`00Oomoo`07Ool00`00Oomo
o`0kOol00`00Oomoo`3oOol6Ool000<000aoo`D000Aoo`@000Ioo`8003eoo`03001oogoo0?moo`Eo
o`008Woo00<007ooOol0?Goo0P00ogoo1Goo000ROol00`00Oomoo`0oOol00`00Oomoo`3oOol2Ool0
029oo`03001oogoo041oo`03001oogoo0?moo`5oo`008Woo00<007ooOol0@Goo0P00ogoo0Goo000R
Ool20014Ool00`00Oomoo`3mOol0029oo`03001oogoo04Aoo`03001oogoo0?aoo`008Woo00<007oo
Ool0AGoo0P00o7oo000ROol00`00Oomoo`17Ool00`00Oomoo`3iOol0029oo`03001oogoo04Qoo`03
001oogoo0?Qoo`008Woo0P00BWoo0P00n7oo000ROol00`00Oomoo`1;Ool2003fOol0029oo`03001o
ogoo04eoo`800?Aoo`008Woo00<007ooOol0Cgoo0P00lWoo000ROol2001BOol00`00Oomoo`3_Ool0
029oo`03001oogoo059oo`800>moo`0067oo1@001Goo00<007ooOol0E7oo0P00kGoo000JOol00`00
Oomoo`05Ool00`00Oomoo`1FOol2003[Ool001Yoo`03001oogoo00Eoo`03001oogoo05Qoo`<00>Qo
o`006Woo00<007ooOol01Goo0`00Fgoo0`00iGoo000JOol00`00Oomoo`05Ool00`00Oomoo`1NOol2
003SOol001Yoo`03001oogoo00Eoo`03001oogoo061oo`<00>1oo`006Woo00<007ooOol01Goo00<0
07ooOol0Hgoo0`00gGoo000HOol30007Ool00`00Oomoo`1VOol3003JOol0029oo`8006Yoo`<00=Mo
o`008Woo00<007ooOol0K7oo0`00e7oo000ROol00`00Oomoo`1_Ool3002UOolG000EOol0029oo`03
001oogoo079oo`<008]ooaL002aoo`008Woo0P00MWoo1@00KGoo6@00@goo000ROol00`00Oomoo`1j
Ool6001JOol=001LOol0029oo`03001oogoo081oo`H004Qoo``006Uoo`008Woo00<007ooOol0QWoo
4P006Goo7@00MGoo000ROol00`00Oomoo`2HOolI002BOol0029oo`800?moodEoo`008Woo00<007oo
Ool0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007oo
Ool0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`001@0017oo0P0017oo1@00
17oo10001Woo00<007ooOol0ogooA7oo0002Ool00`00Oomoo`04Ool20005Ool01000Oomoo`0027oo
00<007ooOol00goo00<007ooOol0ogooA7oo0002Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00
Oomoo`03Ool3003oOom4Ool0009oo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00=oo`03
001oogoo0?moodAoo`000Woo00<007ooOol03Woo00<007ooOol00Woo10001Woo00<007ooOol0ogoo
A7oo0002Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool0
009oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool0
00<000eoo`<000Eoo`@000Ioo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomo
o`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5
Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4
Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029o
o`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001o
ogoo0?moodAoo`0027oo1@0017oo0P001Goo10001Woo00<007ooOol0ogooA7oo000:Ool00`00Oomo
o`04Ool20009Ool00`00Oomoo`03Ool00`00Oomoo`3oOom4Ool000Yoo`03001oogoo00moo`03001o
ogoo00=oo`03001oogoo0?moodAoo`002Woo00<007ooOol03goo00<007ooOol00goo0`00ogooA7oo
000:Ool00`00Oomoo`0;Ool40006Ool00`00Oomoo`3oOom4Ool000Yoo`03001oogoo00]oo`03001o
ogoo00Moo`03001oogoo0?moodAoo`002Woo00<007ooOol02goo00<007ooOol01goo00<007ooOol0
ogooA7oo0008Ool3000=Ool40006Ool00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`001@0017oo0P001Woo00<007ooOol017oo
10001Woo00<007ooOol0ogooA7oo0002Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00
Oomoo`03Ool00`00Oomoo`3oOom4Ool0009oo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo
00=oo`<00?moodAoo`000Woo00<007ooOol03Goo00<007ooOol01goo00<007ooOol00goo00<007oo
Ool0ogooA7oo0002Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool40006Ool00`00Oomoo`3oOom4Ool0
009oo`03001oogoo00ioo`03001oogoo009oo`03001oogoo00Moo`03001oogoo0?moodAoo`000Woo
00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo00Moo`03001oogoo0?moodAoo`000`00
37oo1@0017oo10001Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0
ogooA7oo000GOol50006Ool00`00Oomoo`3oOom4Ool001Qoo`04001oogoo0006Ool00`00Oomoo`3o
Oom4Ool001Uoo`03001oogoo00Ioo`03001oogoo0?moodAoo`006Woo00<007ooOol01Goo0`00ogoo
A7oo000KOol00`00Oomoo`3oOom;Ool001]oo`03001oogoo0?mood]oo`005goo00D007ooOomoo`00
0?moodeoo`0067oo0`00ogooCWoo003oOomYOol009Eoo`8000]oo`03001oogoo00aoo`8000Eoo`03
001oogoo0:eoo`00UGoo00<007ooOol02Woo0P003Woo00<007ooOol00goo0P00[Woo002:Ool50006
Ool01000Oomoogoo0P000Woo0P0017oo00<007ooOol017oo0`001Goo00<007ooOol017oo00<007oo
Ool037oo0`0037oo0`001Goo0P001Goo1000OWoo002<Ool00`00Oomoo`06Ool00`00Oomoo`02Ool0
1000Oomoo`001Goo0P0017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`8000aoo`05001oogoo
Ool00002Ool60004Ool00`00Oomoo`04Ool20009Ool00`00Oomoo`1kOol008aoo`03001oogoo00Io
o`03001oogoo00=oo`8000aoo`03001oogoo00Ioo`03001oogoo019oo`03001oogoo00]oo`D0011o
o`03001oogoo07]oo`00S7oo00<007ooOol01Woo00<007ooOol00goo0P0037oo00<007ooOol01Woo
00<007ooOol04Woo00<007ooOol017oo1P0000Eoo`00Oomoo`00015oo`03001oogoo07]oo`00S7oo
00<007ooOol01Woo00<007ooOol00Woo00@007ooOol000]oo`03001oogoo00Ioo`03001oogoo019o
o`03001oogoo00aoo`03001oo`0000eoo`@007ioo`00RGoo00@007ooOol0009oo`03001oogoo00=o
o`04001oogooOol20002Ool20008Ool60005Ool00`00Oomoo`0@Ool6000;Ool00`00Ool0000=Ool0
0`00Oomoo`1oOol008Uoo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomo
o`06Ool00`00Oomoo`0BOol00`00Oomoo`0=Ool2000=Ool00`00Oomoo`1oOol008Uoo`L000Eoo`80
019oo`03001oogoo00Eoo`8001Aoo`03001oogoo00ioo`03001oogoo00]oo`@007ioo`00ogooJGoo
003oOomYOol00?moofUoo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .01269 m
.04057 .04998 L
.08481 .09258 L
.12636 .132 L
.16632 .16781 L
.20885 .20258 L
.2498 .23218 L
.29331 .25917 L
.33524 .28083 L
.37557 .29783 L
.41848 .31212 L
.4598 .3226 L
.49953 .33004 L
.51991 .33298 L
.54183 .33557 L
.56402 .33765 L
.58512 .33916 L
.60591 .34028 L
.62522 .34102 L
.63631 .34133 L
.64677 .34155 L
.65615 .3417 L
.66144 .34176 L
.66631 .34181 L
.67124 .34184 L
.67401 .34186 L
.67653 .34187 L
.67888 .34188 L
.6802 .34188 L
.68143 .34188 L
.6825 .34188 L
.68368 .34188 L
.68491 .34188 L
.68607 .34188 L
.68734 .34188 L
.68872 .34188 L
.68942 .34188 L
.69017 .34188 L
.69152 .34188 L
.69413 .34187 L
.69651 .34186 L
.7023 .34183 L
.70777 .34179 L
.71797 .34169 L
.72878 .34156 L
.74816 .34125 L
.78794 .34044 L
.8303 .33947 L
.87106 .33858 L
.8918 .33818 L
Mistroke
.9144 .33781 L
.93606 .33752 L
.95615 .33732 L
.96727 .33724 L
.97273 .33721 L
.97774 .33719 L
.98222 .33717 L
.98714 .33716 L
.98969 .33715 L
.99208 .33715 L
.9946 .33715 L
.99601 .33715 L
.99729 .33714 L
.99859 .33714 L
.99932 .33714 L
1 .33714 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000R
Ool3003oOom4Ool0029oo`04001oogoo003oOom3Ool0029oo`05001oogooOol0003oOom2Ool0029o
o`03001oogoo009oo`03001oogoo0?moocmoo`008Woo00<007ooOol00goo00<007ooOol0ogoo?Woo
000ROol20005Ool00`00Oomoo`3oOolmOol0029oo`03001oogoo00Eoo`03001oogoo0?moocaoo`00
8Woo00<007ooOol01Woo00<007ooOol0ogoo>goo000ROol00`00Oomoo`07Ool00`00Oomoo`3oOolj
Ool0029oo`8000Uoo`03001oogoo0?moocUoo`008Woo00<007ooOol02Goo0P00ogoo>Goo000ROol0
0`00Oomoo`0;Ool00`00Oomoo`3oOolfOol0029oo`03001oogoo00aoo`03001oogoo0?moocEoo`00
8Woo00<007ooOol03Goo00<007ooOol0ogoo=7oo000ROol2000?Ool00`00Oomoo`3oOolcOol0029o
o`03001oogoo00moo`03001oogoo0?mooc9oo`000`001Woo0P0017oo1@0017oo10001Woo00<007oo
Ool047oo00<007ooOol0ogoo<Goo0003Ool00`00Oomoo`03Ool20005Ool01000Oomoo`0027oo00<0
07ooOol00goo00<007ooOol04Goo00<007ooOol0ogoo<7oo0003Ool00`00Oomoo`0;Ool00`00Oomo
o`08Ool00`00Oomoo`03Ool00`00Oomoo`0BOol00`00Oomoo`3oOol_Ool000=oo`03001oogoo00ao
o`03001oogoo00Moo`03001oogoo00=oo`<001=oo`03001oogoo0?moobioo`000goo00<007ooOol0
3Goo00<007ooOol00Woo10001Woo00<007ooOol057oo00<007ooOol0ogoo;Goo0003Ool00`00Oomo
o`0=Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0EOol00`00Oomoo`3oOol/Ool000=o
o`03001oogoo00Uoo`05001oogooOol00004Ool00`00Oomoo`07Ool00`00Oomoo`0FOol00`00Oomo
o`3oOol[Ool000<000eoo`<000Eoo`@000Ioo`8001Qoo`03001oogoo0?moobYoo`008Woo00<007oo
Ool067oo00<007ooOol0ogoo:Goo000ROol00`00Oomoo`0IOol00`00Oomoo`3oOolXOol0029oo`03
001oogoo01Yoo`03001oogoo0?moobMoo`008Woo00<007ooOol06goo00<007ooOol0ogoo9Woo000R
Ool2000MOol00`00Oomoo`3oOolUOol0029oo`03001oogoo01eoo`03001oogoo0?moobAoo`008Woo
00<007ooOol07Woo00<007ooOol0ogoo8goo000ROol00`00Oomoo`0OOol00`00Oomoo`3oOolROol0
029oo`03001oogoo021oo`03001oogoo0?moob5oo`008Woo0P008Woo00<007ooOol0ogoo87oo000R
Ool00`00Oomoo`0ROol00`00Oomoo`3oOolOOol0029oo`03001oogoo02=oo`800?mooamoo`008Woo
00<007ooOol09Goo00<007ooOol0ogoo77oo000ROol2000WOol00`00Oomoo`3oOolKOol0029oo`03
001oogoo02Moo`03001oogoo0?mooaYoo`008Woo00<007ooOol0:7oo00<007ooOol0ogoo6Goo0008
Ool30006Ool20005Ool40006Ool00`00Oomoo`0YOol2003oOolIOol000Moo`05001oogooOol00005
Ool20009Ool00`00Oomoo`03Ool00`00Oomoo`0[Ool00`00Oomoo`3oOolFOol000Moo`05001oogoo
Ool0000@Ool00`00Oomoo`03Ool3000/Ool00`00Oomoo`3oOolEOol000Moo`05001oogooOol0000@
Ool00`00Oomoo`03Ool00`00Oomoo`0]Ool00`00Oomoo`3oOolDOol000Moo`05001oogooOol0000<
Ool40006Ool00`00Oomoo`0^Ool00`00Oomoo`3oOolCOol000Moo`05001oogooOol0000<Ool00`00
Oomoo`07Ool00`00Oomoo`0_Ool00`00Oomoo`3oOolBOol000Moo`05001oogooOol0000<Ool00`00
Oomoo`07Ool00`00Oomoo`0`Ool2003oOolBOol000Qoo`<000eoo`@000Ioo`8003=oo`03001oogoo
0?moo`moo`008Woo00<007ooOol0<goo00<007ooOol0ogoo3Woo000ROol00`00Oomoo`0dOol00`00
Oomoo`3oOol=Ool0029oo`03001oogoo03Eoo`03001oogoo0?moo`aoo`008Woo0P00=goo0P00ogoo
37oo000ROol00`00Oomoo`0hOol00`00Oomoo`3oOol9Ool0029oo`03001oogoo03Uoo`03001oogoo
0?moo`Qoo`008Woo00<007ooOol0>Woo00<007ooOol0ogoo1goo000ROol00`00Oomoo`0kOol00`00
Oomoo`3oOol6Ool0029oo`8003eoo`03001oogoo0?moo`Eoo`008Woo00<007ooOol0?Goo0P00ogoo
1Goo000ROol00`00Oomoo`0oOol00`00Oomoo`3oOol2Ool0029oo`03001oogoo041oo`03001oogoo
0?moo`5oo`008Woo00<007ooOol0@Goo0P00ogoo0Goo000ROol20014Ool00`00Oomoo`3mOol0029o
o`03001oogoo04Aoo`03001oogoo0?aoo`000`001Woo0P001Woo00<007ooOol017oo10001Woo00<0
07ooOol0AGoo0P00o7oo0003Ool00`00Oomoo`03Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`03
Ool00`00Oomoo`17Ool00`00Oomoo`3iOol000=oo`03001oogoo00aoo`03001oogoo00Moo`03001o
ogoo00=oo`<004Qoo`03001oogoo0?Qoo`000goo00<007ooOol037oo00<007ooOol01goo00<007oo
Ool00goo00<007ooOol0BGoo0P00n7oo0003Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool40006Ool0
0`00Oomoo`1;Ool00`00Oomoo`3eOol000=oo`03001oogoo00eoo`03001oogoo009oo`03001oogoo
00Moo`03001oogoo04aoo`800?Eoo`000goo00<007ooOol02Goo00D007ooOomoo`0000Aoo`03001o
ogoo00Moo`03001oogoo04ioo`800?=oo`000`0037oo1@0017oo10001Woo0P00DGoo00<007ooOol0
l7oo000ROol00`00Oomoo`1AOol2003`Ool0029oo`03001oogoo05=oo`800>ioo`008Woo00<007oo
Ool0EGoo00<007ooOol0jgoo000ROol00`00Oomoo`1FOol2003[Ool0029oo`8005Uoo`800>Uoo`00
8Woo00<007ooOol0FWoo0P00igoo000ROol00`00Oomoo`1LOol3003TOol0029oo`03001oogoo05mo
o`800>9oo`008Woo00<007ooOol0HGoo0P00h7oo000ROol2001TOol2003NOol0029oo`03001oogoo
06Eoo`800=aoo`008Woo00<007ooOol0Igoo0P00fWoo000ROol00`00Oomoo`1YOol2003HOol0029o
o`8006aoo`800=Ioo`008Woo00<007ooOol0KGoo0P00e7oo000HOol50005Ool00`00Oomoo`1_Ool3
003AOol001Yoo`03001oogoo00Eoo`03001oogoo079oo`<00<ioo`006Woo00<007ooOol01Goo00<0
07ooOol0MGoo0`00bgoo000JOol00`00Oomoo`05Ool3001hOol30038Ool001Yoo`03001oogoo00Eo
o`03001oogoo07]oo`@00<Aoo`006Woo00<007ooOol01Goo00<007ooOol0Ogoo1@00_goo000JOol0
0`00Oomoo`05Ool00`00Oomoo`24Ool4002kOol001Qoo`<000Moo`03001oogoo08Qoo`D00;Ioo`00
8Woo0P00SWoo1P00/7oo000ROol00`00Oomoo`2COol6002ZOol0029oo`03001oogoo09Uoo`L00:=o
o`008Woo00<007ooOol0X7oo1P00OWoo2P005Goo000ROol2002WOolC000]Ooln000OOol0029oo`03
001oogoo0;Uoobd005eoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029o
o`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001o
ogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?mo
odEoo`008Woo00<007ooOol0ogooA7oo00050004Ool20004Ool50004Ool40006Ool00`00Oomoo`3o
Oom4Ool0009oo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomo
o`3oOom4Ool0009oo`03001oogoo00aoo`03001oogoo00Qoo`03001oogoo00=oo`<00?moodAoo`00
0Woo00<007ooOol03Goo00<007ooOol01goo00<007ooOol00goo00<007ooOol0ogooA7oo0002Ool0
0`00Oomoo`0>Ool00`00Oomoo`02Ool40006Ool00`00Oomoo`3oOom4Ool0009oo`03001oogoo00io
o`03001oogoo009oo`03001oogoo00Moo`03001oogoo0?moodAoo`000Woo00<007ooOol02Woo00D0
07ooOomoo`0000Aoo`03001oogoo00Moo`03001oogoo0?moodAoo`000`003Goo0`001Goo10001Woo
0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007oo
Ool0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogoo
A7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo0008Ool50004
Ool20005Ool40006Ool00`00Oomoo`3oOom4Ool000Yoo`03001oogoo00Aoo`8000Uoo`03001oogoo
00=oo`03001oogoo0?moodAoo`002Woo00<007ooOol03goo00<007ooOol00goo00<007ooOol0ogoo
A7oo000:Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool3003oOom4Ool000Yoo`03001oogoo00]oo`@0
00Ioo`03001oogoo0?moodAoo`002Woo00<007ooOol02goo00<007ooOol01goo00<007ooOol0ogoo
A7oo000:Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000Qoo`<000eoo`@0
00Ioo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03
001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo
0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo
0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAo
o`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo
00<007ooOol0ogooA7oo00050004Ool20006Ool00`00Oomoo`04Ool40006Ool00`00Oomoo`3oOom4
Ool0009oo`03001oogoo00Aoo`8000Ioo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo0?mo
odAoo`000Woo00<007ooOol03Goo00<007ooOol01goo00<007ooOol00goo0`00ogooA7oo0002Ool0
0`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`3oOom4Ool0009oo`03001o
ogoo00eoo`03001oogoo00=oo`@000Ioo`03001oogoo0?moodAoo`000Woo00<007ooOol03Woo00<0
07ooOol00Woo00<007ooOol01goo00<007ooOol0ogooA7oo0002Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000017oo00<007ooOol01goo00<007ooOol0ogooA7oo0003000<Ool50004Ool40006Ool2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03
001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03
001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool001Moo`D000Ioo`03
001oogoo0?moodAoo`0067oo00@007ooOol000Ioo`03001oogoo0?moodAoo`006Goo00<007ooOol0
1Woo00<007ooOol0ogooA7oo000JOol00`00Oomoo`05Ool3003oOom4Ool001]oo`03001oogoo0?mo
od]oo`006goo00<007ooOol0ogooBgoo000GOol01@00Oomoogoo0000ogooCGoo000HOol3003oOom>
Ool00?moofUoo`00V7oo0P002goo00<007ooOol037oo0P001Woo00<007ooOol0ZGoo002HOol00`00
Oomoo`0:Ool2000>Ool00`00Oomoo`04Ool2002ZOol008ioo`D000Eoo`03001oogoo009oo`80009o
o`8000=oo`03001oogoo00Eoo`<000Aoo`03001oogoo00Eoo`03001oogoo00aoo`<000]oo`@000Eo
o`8008=oo`00T7oo00<007ooOol01Goo00<007ooOol00goo00@007ooOol000Aoo`8000Eoo`05001o
ogooOol00003Ool00`00Oomoo`05Ool2000<Ool01P00Oomoogoo001oo`H000Moo`03001oogoo009o
o`8008=oo`00T7oo00<007ooOol01Goo00<007ooOol017oo0P0037oo00<007ooOol01Goo00<007oo
Ool04goo00<007ooOol047oo00<007ooOol0Qgoo002@Ool00`00Oomoo`05Ool00`00Oomoo`04Ool2
000<Ool00`00Oomoo`05Ool00`00Oomoo`0COol00`00Oomoo`03Ool60007Ool00`00Oomoo`27Ool0
091oo`03001oogoo00Eoo`03001oogoo00=oo`04001oogoo000;Ool00`00Oomoo`05Ool00`00Oomo
o`0COol00`00Oomoo`0<Ool4002:Ool008eoo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool20002Ool20008Ool60004Ool00`00Oomoo`0AOol6000;Ool00`00Oomoo`2;Ool008eoo`04
001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`05Ool00`00Oomoo`0COol0
0`00Oomoo`0<Ool00`00Oomoo`2;Ool008eoo`L000Aoo`8001=oo`03001oogoo00Aoo`8001Eoo`03
001oogoo00aoo`@008Yoo`00ogooJGoo003oOomYOol00?moofUoo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.5) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .09099 m
.00236 .09109 L
.00488 .09123 L
.00942 .0916 L
.01483 .09221 L
.01975 .09293 L
.03045 .09497 L
.04057 .09747 L
.06178 .10429 L
.08481 .11371 L
.12772 .13522 L
.16904 .15878 L
.20876 .18234 L
.25107 .207 L
.29178 .22939 L
.33506 .25105 L
.37676 .26944 L
.41686 .28469 L
.45954 .29832 L
.50062 .30902 L
.54428 .31803 L
.58635 .32467 L
.62683 .32945 L
.64736 .33135 L
.66989 .33309 L
.71135 .33548 L
.73183 .33633 L
.75379 .33704 L
.77609 .33759 L
.79722 .33798 L
.80736 .33812 L
.81813 .33825 L
.83747 .33843 L
.84731 .3385 L
.85791 .33856 L
.86793 .3386 L
.87711 .33863 L
.8874 .33865 L
.89698 .33867 L
.90248 .33868 L
.90748 .33869 L
.91326 .33869 L
.91871 .33869 L
.92357 .3387 L
.92633 .3387 L
.92892 .3387 L
.93164 .3387 L
.93413 .3387 L
.9355 .3387 L
.93623 .3387 L
Mistroke
.937 .3387 L
.93774 .3387 L
.93841 .3387 L
.93973 .3387 L
.94094 .3387 L
.94223 .3387 L
.94332 .3387 L
.94452 .3387 L
.94582 .3387 L
.94721 .3387 L
.94971 .3387 L
.95462 .3387 L
.9591 .3387 L
1 .33869 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
00<000Ioo`8000Aoo`D000Aoo`@000Ioo`03001oogoo0?moodAoo`000goo00<007ooOol00goo0P00
1Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007ooOol02goo
00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0<Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03001oogoo00eoo`03001oogoo009oo`@0
00Ioo`03001oogoo0?moodAoo`000goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol0ogooA7oo0003Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol01goo
00<007ooOol0ogooA7oo0003000=Ool30005Ool40006Ool9003oOolnOol0029oo`03001oogoo00Io
o`<00?mooc]oo`008Woo00<007ooOol02Goo0`00ogoo>7oo000ROol00`00Oomoo`0<Ool3003oOole
Ool0029oo`03001oogoo00moo`<00?mooc9oo`008Woo0P004goo0`00ogoo;goo000ROol00`00Oomo
o`0EOol2003oOol]Ool0029oo`03001oogoo01Moo`800?moob]oo`008Woo00<007ooOol06Goo0P00
ogoo:Goo000ROol00`00Oomoo`0KOol2003oOolWOol0029oo`8001ioo`<00?moobAoo`008Woo00<0
07ooOol087oo0P00ogoo8Woo000ROol00`00Oomoo`0ROol2003oOolPOol0029oo`03001oogoo02Ao
o`800?mooaioo`008Woo0P009goo0P00ogoo77oo000ROol00`00Oomoo`0XOol00`00Oomoo`3oOolI
Ool0029oo`03001oogoo02Uoo`800?mooaUoo`0027oo0`001Woo0P001Goo10001Woo00<007ooOol0
:goo0P00ogoo5goo0007Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol00goo00<007ooOol0
;Goo00<007ooOol0ogoo57oo0007Ool01@00Oomoogoo000047oo00<007ooOol00goo0`00;Woo0P00
ogoo57oo0007Ool01@00Oomoogoo000047oo00<007ooOol00goo00<007ooOol0<7oo0P00ogoo4Woo
0007Ool01@00Oomoogoo000037oo10001Woo00<007ooOol0<Woo0P00ogoo47oo0007Ool01@00Oomo
ogoo000037oo00<007ooOol01goo00<007ooOol0=7oo00<007ooOol0ogoo3Goo0007Ool01@00Oomo
ogoo000037oo00<007ooOol01goo00<007ooOol0=Goo0P00ogoo3Goo0008Ool3000=Ool40006Ool2
000hOol2003oOol;Ool0029oo`03001oogoo03Uoo`03001oogoo0?moo`Qoo`008Woo00<007ooOol0
>Woo0P00ogoo27oo000ROol00`00Oomoo`0lOol2003oOol6Ool0029oo`8003moo`03001oogoo0?mo
o`=oo`008Woo00<007ooOol0?goo0P00ogoo0goo000ROol00`00Oomoo`11Ool2003oOol1Ool0029o
o`03001oogoo04=oo`03001oogoo0?eoo`008Woo00<007ooOol0A7oo0P00oGoo000ROol20017Ool2
003kOol0029oo`03001oogoo04Qoo`03001oogoo0?Qoo`008Woo00<007ooOol0BGoo0P00n7oo000R
Ool00`00Oomoo`1;Ool2003fOol0029oo`03001oogoo04eoo`800?Aoo`008Woo0P00D7oo0P00lWoo
000ROol00`00Oomoo`1AOol00`00Oomoo`3_Ool000<000Ioo`8000Ioo`03001oogoo00Aoo`@000Io
o`03001oogoo059oo`800>moo`000goo00<007ooOol00goo0P001Woo00<007ooOol027oo00<007oo
Ool00goo00<007ooOol0E7oo0P00kGoo0003Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomo
o`03Ool3001FOol2003[Ool000=oo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo00=oo`03
001oogoo05Qoo`800>Uoo`000goo00<007ooOol037oo00<007ooOol00goo10001Woo00<007ooOol0
FWoo0P00igoo0003Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`1L
Ool3003TOol000=oo`03001oogoo00Uoo`05001oogooOol00004Ool00`00Oomoo`07Ool00`00Oomo
o`1OOol2003ROol000<000aoo`D000Aoo`@000Ioo`80069oo`800>1oo`008Woo00<007ooOol0Hgoo
0P00gWoo000ROol00`00Oomoo`1UOol2003LOol0029oo`03001oogoo06Moo`800=Yoo`008Woo00<0
07ooOol0JGoo0P00f7oo000ROol2001/Ool2003FOol0029oo`03001oogoo06eoo`800=Aoo`008Woo
00<007ooOol0Kgoo0P00dWoo000ROol00`00Oomoo`1aOol3003?Ool0029oo`03001oogoo07Aoo`<0
0<aoo`008Woo0P00N7oo0P00bWoo000ROol00`00Oomoo`1iOol30037Ool0029oo`03001oogoo07ao
o`<00<Aoo`008Woo00<007ooOol0Ogoo0`00`Goo000ROol20023Ool3002nOol0029oo`03001oogoo
08Eoo`<00;]oo`0067oo1@001Goo00<007ooOol0R7oo1000]goo000JOol00`00Oomoo`05Ool00`00
Oomoo`2<Ool4002cOol001Yoo`03001oogoo00Eoo`03001oogoo091oo`@00:moo`006Woo00<007oo
Ool01Goo0`00U7oo1000Zgoo000JOol00`00Oomoo`05Ool00`00Oomoo`2HOol5002VOol001Yoo`03
001oogoo00Eoo`03001oogoo09eoo`@00:9oo`006Woo00<007ooOol01Goo00<007ooOol0XGoo1@00
WGoo000HOol30007Ool00`00Oomoo`2VOol7002FOol0029oo`800:ioo`T008eoo`008Woo00<007oo
Ool0]Woo2P00Pgoo000ROol00`00Oomoo`30Ool@001cOol0029oo`03001oogoo0=1ooaL005aoo`00
8Woo0P00j7ooA`005Goo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo
00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007oo
Ool0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007oo
Ool0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`001@0017oo0P0017oo1@00
17oo10001Woo00<007ooOol0ogooA7oo0002Ool00`00Oomoo`04Ool20005Ool01000Oomoo`0027oo
00<007ooOol00goo00<007ooOol0ogooA7oo0002Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00
Oomoo`03Ool3003oOom4Ool0009oo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00=oo`03
001oogoo0?moodAoo`000Woo00<007ooOol03Woo00<007ooOol00Woo10001Woo00<007ooOol0ogoo
A7oo0002Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool0
009oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool0
00<000eoo`<000Eoo`@000Ioo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomo
o`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5
Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4
Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029o
o`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001o
ogoo0?moodAoo`0027oo1@0017oo0P001Goo10001Woo00<007ooOol0ogooA7oo000:Ool00`00Oomo
o`04Ool20009Ool00`00Oomoo`03Ool00`00Oomoo`3oOom4Ool000Yoo`03001oogoo00moo`03001o
ogoo00=oo`03001oogoo0?moodAoo`002Woo00<007ooOol03goo00<007ooOol00goo0`00ogooA7oo
000:Ool00`00Oomoo`0;Ool40006Ool00`00Oomoo`3oOom4Ool000Yoo`03001oogoo00]oo`03001o
ogoo00Moo`03001oogoo0?moodAoo`002Woo00<007ooOol02goo00<007ooOol01goo00<007ooOol0
ogooA7oo0008Ool3000=Ool40006Ool00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`001@0017oo0P001Woo00<007ooOol017oo
10001Woo00<007ooOol0ogooA7oo0002Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00
Oomoo`03Ool00`00Oomoo`3oOom4Ool0009oo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo
00=oo`<00?moodAoo`000Woo00<007ooOol03Goo00<007ooOol01goo00<007ooOol00goo00<007oo
Ool0ogooA7oo0002Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool40006Ool00`00Oomoo`3oOom4Ool0
009oo`03001oogoo00ioo`03001oogoo009oo`03001oogoo00Moo`03001oogoo0?moodAoo`000Woo
00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo00Moo`03001oogoo0?moodAoo`000`00
37oo1@0017oo10001Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0
ogooA7oo000GOol50006Ool00`00Oomoo`3oOom4Ool001Qoo`04001oogoo0006Ool00`00Oomoo`3o
Oom4Ool001Uoo`03001oogoo00Ioo`03001oogoo0?moodAoo`006Woo00<007ooOol01Goo0`00ogoo
A7oo000KOol00`00Oomoo`3oOom;Ool001]oo`03001oogoo0?mood]oo`005goo00D007ooOomoo`00
0?moodeoo`0067oo0`00ogooCWoo003oOomYOol009Eoo`8000]oo`03001oogoo00aoo`8000Eoo`03
001oogoo0:eoo`00UGoo00<007ooOol02Woo0P003Woo00<007ooOol00goo0P00[Woo002:Ool50006
Ool01000Oomoogoo0P000Woo0P0017oo00<007ooOol017oo0`001Goo00<007ooOol017oo00<007oo
Ool037oo0`002goo10001Goo0P001Goo1000OWoo002<Ool00`00Oomoo`06Ool00`00Oomoo`02Ool0
1000Oomoo`001Goo0P0017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`8000aoo`05001oogoo
Ool00002Ool60006Ool00`00Oomoo`02Ool20009Ool00`00Oomoo`1kOol008aoo`03001oogoo00Io
o`03001oogoo00=oo`8000aoo`03001oogoo00Ioo`03001oogoo019oo`03001oogoo011oo`03001o
ogoo00eoo`03001oogoo07]oo`00S7oo00<007ooOol01Woo00<007ooOol00goo0P0037oo00<007oo
Ool01Woo00<007ooOol04Woo00<007ooOol017oo1P001Woo00<007ooOol03Goo00<007ooOol0Ngoo
002<Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomoo`002goo00<007ooOol01Woo00<007oo
Ool04Woo00<007ooOol037oo100037oo1000OWoo0029Ool01000Oomoo`000Woo00<007ooOol00goo
00@007ooOomoo`80009oo`8000Qoo`H000Eoo`03001oogoo011oo`H000]oo`03001oogoo00eoo`03
001oogoo07moo`00RGoo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo015oo`03001oogoo
00Ioo`03001oogoo019oo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo07moo`00RGoo1`00
1Goo0P004Woo00<007ooOol01Goo0P0057oo00<007ooOol037oo100037oo1000OWoo003oOomYOol0
0?moofUoo`00ogooJGoo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .22267 m
.01975 .2085 L
.04057 .19716 L
.06168 .18902 L
.07365 .18574 L
.079 .18457 L
.08481 .18349 L
.09054 .18261 L
.09583 .18196 L
.10089 .18148 L
.10347 .18128 L
.10625 .18111 L
.10875 .18098 L
.11104 .1809 L
.11214 .18086 L
.11334 .18083 L
.11447 .18081 L
.11553 .1808 L
.11686 .18078 L
.11812 .18078 L
.11925 .18078 L
.12048 .18079 L
.12181 .18081 L
.12249 .18082 L
.12322 .18084 L
.12575 .1809 L
.12839 .18101 L
.13125 .18115 L
.13647 .18149 L
.14154 .18193 L
.14624 .18241 L
.15688 .1838 L
.1682 .18567 L
.20784 .19489 L
.25005 .20794 L
.29067 .22222 L
.33387 .23804 L
.37547 .25304 L
.41549 .26666 L
.45808 .27991 L
.49907 .29122 L
.54265 .3016 L
.58463 .31 L
.62502 .31669 L
.66798 .32244 L
.70935 .3268 L
.74914 .33005 L
.79149 .33267 L
.83226 .3345 L
.85449 .33527 L
Mistroke
.8756 .33587 L
.89667 .33635 L
.91576 .33669 L
.93645 .33698 L
.94781 .3371 L
.95849 .33719 L
.96877 .33726 L
.97394 .33728 L
.97961 .3373 L
.98446 .33732 L
.98713 .33733 L
.98966 .33733 L
.99201 .33734 L
.99324 .33734 L
.99456 .33734 L
.99566 .33734 L
.99688 .33734 L
.99798 .33734 L
.99902 .33734 L
1 .33734 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
00<000Ioo`8000Aoo`D000Aoo`@000Ioo`03001oogoo0?moodAoo`000goo00<007ooOol00goo0P00
1Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007ooOol02goo
00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0<Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03001oogoo00eoo`03001oogoo009oo`@0
00Ioo`03001oogoo0?moodAoo`000goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol0ogooA7oo0003Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol01goo
00<007ooOol0ogooA7oo0003000=Ool30005Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`0027oo0`001Woo0P00
1Goo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol0
0goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000047oo00<007ooOol00goo0`00ogooA7oo
0007Ool01@00Oomoogoo000047oo00<007ooOol00goo00<007ooOol0ogooA7oo0007Ool01@00Oomo
ogoo000037oo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol0
1goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol01goo00<007ooOol0
ogooA7oo0008Ool3000=Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`0JOol@003oOolJOol0029oo`8001Eoo`H0011oo`H00?mo
oaAoo`008Woo00<007ooOol04Woo0P0077oo1000ogoo47oo000ROol00`00Oomoo`0>Ool4000ROol6
003oOol:Ool0029oo`03001oogoo00]oo`<002aoo`D00?moo`Eoo`008Woo00<007ooOol027oo0`00
=7oo0`00ogoo0Woo000ROol20007Ool2000jOol3003nOol0029oo`03001oogoo00Aoo`8003moo`<0
0?]oo`008Woo00<007ooOol00Woo0P00A7oo0`00n7oo000ROol01@00Oomoogoo0000BGoo0`00mGoo
000ROol01000Oomoo`00CGoo0P00lgoo000ROol3001@Ool2003aOol0029oo`8005=oo`<00>ioo`00
0`001Woo0P001Woo00<007ooOol017oo10001Woo00<007ooOol0EGoo0`00jgoo0003Ool00`00Oomo
o`03Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`1HOol3003XOol000=oo`03
001oogoo00aoo`03001oogoo00Moo`03001oogoo00=oo`<005]oo`<00>Eoo`000goo00<007ooOol0
37oo00<007ooOol01goo00<007ooOol00goo00<007ooOol0GWoo0`00hWoo0003Ool00`00Oomoo`0<
Ool00`00Oomoo`03Ool40006Ool00`00Oomoo`1QOol3003OOol000=oo`03001oogoo00eoo`03001o
ogoo009oo`03001oogoo00Moo`03001oogoo06Aoo`<00=aoo`000goo00<007ooOol02Goo00D007oo
Oomoo`0000Aoo`03001oogoo00Moo`03001oogoo06Moo`<00=Uoo`000`0037oo1@0017oo10001Woo
0P00Jgoo0P00egoo000ROol00`00Oomoo`1/Ool3003DOol0029oo`03001oogoo06moo`<00=5oo`00
8Woo00<007ooOol0LWoo0`00cWoo000ROol00`00Oomoo`1eOol3003;Ool0029oo`8007Uoo`<00<Qo
o`008Woo00<007ooOol0Ngoo0`00aGoo000ROol00`00Oomoo`1nOol30032Ool0029oo`03001oogoo
085oo`<00;moo`008Woo00<007ooOol0Q7oo0`00_7oo000ROol20028Ool4002hOol0029oo`03001o
ogoo08]oo`<00;Eoo`008Woo00<007ooOol0SWoo0`00/Woo000ROol00`00Oomoo`2AOol3002_Ool0
029oo`8009Eoo`@00:]oo`008Woo00<007ooOol0V7oo1@00YWoo000HOol50005Ool00`00Oomoo`2M
Ool4002ROol001Yoo`03001oogoo00Eoo`03001oogoo0:5oo`D009eoo`006Woo00<007ooOol01Goo
00<007ooOol0YWoo1`00UWoo000JOol00`00Oomoo`05Ool3002]Ool6002@Ool001Yoo`03001oogoo
00Eoo`03001oogoo0;=oo`H008Yoo`006Woo00<007ooOol01Goo00<007ooOol0^Goo1P00Q7oo000J
Ool00`00Oomoo`05Ool00`00Oomoo`2oOol7001mOol001Qoo`<000Moo`03001oogoo0<Ioo`T007Ao
o`008Woo0P00d7oo3000J7oo000ROol00`00Oomoo`3KOol=001KOol0029oo`03001oogoo0>Qoo`d0
04ioo`008Woo00<007ooOol0mGoo;P0087oo000ROol2003oOolUOol;000EOol0029oo`03001oogoo
0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo
0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAo
o`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo
00<007ooOol0ogooA7oo00050004Ool20004Ool50004Ool40006Ool00`00Oomoo`3oOom4Ool0009o
o`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`3oOom4Ool0
009oo`03001oogoo00aoo`03001oogoo00Qoo`03001oogoo00=oo`<00?moodAoo`000Woo00<007oo
Ool03Goo00<007ooOol01goo00<007ooOol00goo00<007ooOol0ogooA7oo0002Ool00`00Oomoo`0>
Ool00`00Oomoo`02Ool40006Ool00`00Oomoo`3oOom4Ool0009oo`03001oogoo00ioo`03001oogoo
009oo`03001oogoo00Moo`03001oogoo0?moodAoo`000Woo00<007ooOol02Woo00D007ooOomoo`00
00Aoo`03001oogoo00Moo`03001oogoo0?moodAoo`000`003Goo0`001Goo10001Woo0P00ogooAGoo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol0
0`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomo
o`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomo
o`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo0008Ool50004Ool20005Ool4
0006Ool00`00Oomoo`3oOom4Ool000Yoo`03001oogoo00Aoo`8000Uoo`03001oogoo00=oo`03001o
ogoo0?moodAoo`002Woo00<007ooOol03goo00<007ooOol00goo00<007ooOol0ogooA7oo000:Ool0
0`00Oomoo`0?Ool00`00Oomoo`03Ool3003oOom4Ool000Yoo`03001oogoo00]oo`@000Ioo`03001o
ogoo0?moodAoo`002Woo00<007ooOol02goo00<007ooOol01goo00<007ooOol0ogooA7oo000:Ool0
0`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000Qoo`<000eoo`@000Ioo`03001o
ogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0
ogooA7oo00050004Ool20006Ool00`00Oomoo`04Ool40006Ool00`00Oomoo`3oOom4Ool0009oo`03
001oogoo00Aoo`8000Ioo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo0?moodAoo`000Woo
00<007ooOol03Goo00<007ooOol01goo00<007ooOol00goo0`00ogooA7oo0002Ool00`00Oomoo`0=
Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`3oOom4Ool0009oo`03001oogoo00eoo`03
001oogoo00=oo`@000Ioo`03001oogoo0?moodAoo`000Woo00<007ooOol03Woo00<007ooOol00Woo
00<007ooOol01goo00<007ooOol0ogooA7oo0002Ool00`00Oomoo`0:Ool01@00Oomoogoo000017oo
00<007ooOol01goo00<007ooOol0ogooA7oo0003000<Ool50004Ool40006Ool2003oOom5Ool0029o
o`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029o
o`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001o
ogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool001Moo`D000Ioo`03001oogoo0?mo
odAoo`0067oo00@007ooOol000Ioo`03001oogoo0?moodAoo`006Goo00<007ooOol01Woo00<007oo
Ool0ogooA7oo000JOol00`00Oomoo`05Ool3003oOom4Ool001]oo`03001oogoo0?mood]oo`006goo
00<007ooOol0ogooBgoo000GOol01@00Oomoogoo0000ogooCGoo000HOol3003oOom>Ool00?moofUo
o`00V7oo0P002goo00<007ooOol037oo0P001Woo00<007ooOol0ZGoo002HOol00`00Oomoo`0:Ool2
000>Ool00`00Oomoo`04Ool2002ZOol008ioo`D000Eoo`03001oogoo009oo`80009oo`8000=oo`03
001oogoo00Eoo`<000Aoo`03001oogoo00Eoo`03001oogoo00aoo`<000]oo`<000Ioo`8008=oo`00
T7oo00<007ooOol01Goo00<007ooOol00goo00@007ooOol000Aoo`8000Eoo`05001oogooOol00003
Ool00`00Oomoo`05Ool2000<Ool01P00Oomoogoo001oo`H0009oo`05001oogooOol00005Ool20023
Ool0091oo`03001oogoo00Eoo`03001oogoo00Aoo`8000aoo`03001oogoo00Eoo`03001oogoo01=o
o`03001oogoo00]oo`05001oogooOol0002:Ool0091oo`03001oogoo00Eoo`03001oogoo00Aoo`80
00aoo`03001oogoo00Eoo`03001oogoo01=oo`03001oogoo00=oo`H0009oo`05001oogooOol0002:
Ool0091oo`03001oogoo00Eoo`03001oogoo00=oo`04001oogoo000;Ool00`00Oomoo`05Ool00`00
Oomoo`0COol00`00Oomoo`0;Ool4002;Ool008eoo`04001oogoo0002Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool20002Ool20008Ool60004Ool00`00Oomoo`0AOol6000:Ool00`00Oomoo`2<Ool008eo
o`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`05Ool00`00Oomoo`0C
Ool00`00Oomoo`0<Ool00`00Oomoo`2;Ool008eoo`L000Aoo`8001=oo`03001oogoo00Aoo`8001Eo
o`03001oogoo00eoo`<008Yoo`00ogooJGoo003oOomYOol00?moofUoo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.5) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .37549 m
.04057 .3246 L
.06168 .30371 L
.08481 .28476 L
.10656 .27036 L
.12636 .25985 L
.14691 .25131 L
.15834 .2475 L
.16889 .24455 L
.189 .24028 L
.19959 .23869 L
.20545 .23798 L
.21082 .23745 L
.21554 .23706 L
.2207 .23672 L
.22353 .23657 L
.22615 .23646 L
.22882 .23636 L
.23133 .23629 L
.23367 .23624 L
.23499 .23621 L
.23621 .2362 L
.23723 .23619 L
.23836 .23618 L
.23953 .23618 L
.24063 .23618 L
.24192 .23618 L
.24313 .23619 L
.24423 .2362 L
.24542 .23622 L
.24808 .23627 L
.25055 .23633 L
.25541 .23649 L
.26065 .23674 L
.27014 .23734 L
.28143 .23831 L
.29178 .23941 L
.33338 .24558 L
.3734 .25338 L
.41598 .26276 L
.45698 .27217 L
.50055 .28202 L
.54254 .29097 L
.58293 .29887 L
.62589 .30634 L
.66726 .31259 L
.70704 .31772 L
.7494 .32226 L
.79017 .32579 L
.83351 .32872 L
Mistroke
.85517 .3299 L
.87526 .33082 L
.89595 .33161 L
.91541 .33222 L
.937 .33274 L
.95655 .33308 L
.96683 .33321 L
.97245 .33326 L
.97768 .3333 L
.98252 .33333 L
.98694 .33336 L
.98946 .33337 L
.99184 .33337 L
.99436 .33338 L
.99578 .33338 L
.99709 .33338 L
.99847 .33338 L
.99926 .33338 L
1 .33338 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
00<000Ioo`8000Aoo`D000Aoo`@000Ioo`03001oogoo0?moodAoo`000goo00<007ooOol00goo0P00
1Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007ooOol02goo
00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0<Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03001oogoo00eoo`03001oogoo009oo`@0
00Ioo`03001oogoo0?moodAoo`000goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol0ogooA7oo0003Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol01goo
00<007ooOol0ogooA7oo0003000=Ool30005Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`0027oo0`001Woo0P00
1Goo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol0
0goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000047oo00<007ooOol00goo0`00ogooA7oo
0007Ool01@00Oomoogoo000047oo00<007ooOol00goo00<007ooOol0ogooA7oo0007Ool01@00Oomo
ogoo000037oo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol0
1goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol01goo00<007ooOol0
ogooA7oo0008Ool3000=Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol0
0`00Oomoo`3oOom4Ool000<000Ioo`8000Ioo`03001oogoo00Aoo`@000Ioo`03001oogoo0?moodAo
o`000goo00<007ooOol00goo0P001Woo00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogoo
A7oo0003Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03
001oogoo00aoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007oo
Ool037oo00<007ooOol00goo10001Woo00<007ooOol0>goo6`00kGoo0003Ool00`00Oomoo`0=Ool0
0`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0cOol8000KOol4003YOol000=oo`03001oogoo
00Uoo`05001oogooOol00004Ool00`00Oomoo`07Ool00`00Oomoo`0_Ool4000WOol6003SOol000<0
00aoo`D000Aoo`@000Ioo`8002eoo`<0035oo`H00=eoo`008Woo00<007ooOol0:Goo0`00>Woo1P00
egoo000ROol00`00Oomoo`0VOol30013Ool5003BOol0029oo`03001oogoo02Aoo`8004]oo`D00<eo
o`008Woo00<007ooOol08Woo0P00DWoo1000bGoo000ROol2000QOol2001HOol40035Ool0029oo`03
001oogoo01ioo`8005ioo`D00<1oo`008Woo00<007ooOol077oo0P00IGoo1000_7oo000ROol00`00
Oomoo`0KOol00`00Oomoo`1YOol4002hOol0029oo`03001oogoo01Yoo`03001oogoo06ioo`D00;=o
o`008Woo0P006Woo00<007ooOol0M7oo1000[goo000ROol00`00Oomoo`0HOol00`00Oomoo`1iOol5
002ZOol0029oo`03001oogoo01Ioo`80085oo`L00:=oo`008Woo00<007ooOol05Goo00<007ooOol0
R7oo1@00WWoo000ROol2000DOol2002@Ool4002JOol0029oo`03001oogoo019oo`03001oogoo09Ao
o`@009Ioo`0067oo1@001Goo00<007ooOol04Goo00<007ooOol0VGoo1@00TGoo000JOol00`00Oomo
o`05Ool00`00Oomoo`0@Ool00`00Oomoo`2OOol7002:Ool001Yoo`03001oogoo00Eoo`03001oogoo
00moo`03001oogoo0:Moo`H008Aoo`006Woo00<007ooOol01Goo0`003Woo00<007ooOol0[Woo1`00
OGoo000JOol00`00Oomoo`05Ool00`00Oomoo`0=Ool00`00Oomoo`2fOol6001gOol001Yoo`03001o
ogoo00Eoo`03001oogoo00aoo`03001oogoo0;eoo`H0075oo`006Woo00<007ooOol01Goo00<007oo
Ool02goo00<007ooOol0a7oo2P00Igoo000HOol30007Ool00`00Oomoo`0:Ool00`00Oomoo`3?Ool<
001KOol0029oo`8000Yoo`03001oogoo0=aoo`d004ioo`008Woo00<007ooOol02Goo00<007ooOol0
jGoo4000?Woo000ROol00`00Oomoo`08Ool00`00Oomoo`3jOolY000EOol0029oo`03001oogoo00Mo
o`03001oogoo0?moocYoo`008Woo0P001goo00<007ooOol0ogoo>goo000ROol00`00Oomoo`05Ool0
0`00Oomoo`3oOollOol0029oo`03001oogoo00Eoo`03001oogoo0?moocaoo`008Woo00<007ooOol0
17oo00<007ooOol0ogoo?Goo000ROol00`00Oomoo`03Ool00`00Oomoo`3oOolnOol0029oo`8000=o
o`03001oogoo0?moocmoo`008Woo00D007ooOomoo`000?mood9oo`008Woo00D007ooOomoo`000?mo
od9oo`008Woo00@007ooOol00?mood=oo`008Woo00<007oo0000ogooA7oo000ROol2003oOom5Ool0
029oo`03001oogoo0?moodAoo`001@0017oo0P0017oo1@0017oo10001Woo00<007ooOol0ogooA7oo
0002Ool00`00Oomoo`04Ool20005Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0ogoo
A7oo0002Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`03Ool3003oOom4Ool0009oo`03
001oogoo00eoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo0?moodAoo`000Woo00<007oo
Ool03Woo00<007ooOol00Woo10001Woo00<007ooOol0ogooA7oo0002Ool00`00Oomoo`0>Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool0009oo`03001oogoo00Yoo`05001oogoo
Ool00004Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000<000eoo`<000Eoo`@000Ioo`800?mo
odEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`0027oo1@0017oo0P00
1Goo10001Woo00<007ooOol0ogooA7oo000:Ool00`00Oomoo`04Ool20009Ool00`00Oomoo`03Ool0
0`00Oomoo`3oOom4Ool000Yoo`03001oogoo00moo`03001oogoo00=oo`03001oogoo0?moodAoo`00
2Woo00<007ooOol03goo00<007ooOol00goo0`00ogooA7oo000:Ool00`00Oomoo`0;Ool40006Ool0
0`00Oomoo`3oOom4Ool000Yoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo0?moodAoo`00
2Woo00<007ooOol02goo00<007ooOol01goo00<007ooOol0ogooA7oo0008Ool3000=Ool40006Ool0
0`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomo
o`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4
Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4
Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029o
o`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001o
ogoo0?moodAoo`001@0017oo0P001Woo00<007ooOol017oo10001Woo00<007ooOol0ogooA7oo0002
Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`3oOom4Ool0
009oo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00=oo`<00?moodAoo`000Woo00<007oo
Ool03Goo00<007ooOol01goo00<007ooOol00goo00<007ooOol0ogooA7oo0002Ool00`00Oomoo`0=
Ool00`00Oomoo`03Ool40006Ool00`00Oomoo`3oOom4Ool0009oo`03001oogoo00ioo`03001oogoo
009oo`03001oogoo00Moo`03001oogoo0?moodAoo`000Woo00<007ooOol02Woo00D007ooOomoo`00
00Aoo`03001oogoo00Moo`03001oogoo0?moodAoo`000`0037oo1@0017oo10001Woo0P00ogooAGoo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol0
0`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomo
o`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomo
o`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000GOol50006Ool00`00Oomo
o`3oOom4Ool001Qoo`04001oogoo0006Ool00`00Oomoo`3oOom4Ool001Uoo`03001oogoo00Ioo`03
001oogoo0?moodAoo`006Woo00<007ooOol01Goo0`00ogooA7oo000KOol00`00Oomoo`3oOom;Ool0
01]oo`03001oogoo0?mood]oo`005goo00D007ooOomoo`000?moodeoo`0067oo0`00ogooCWoo003o
OomYOol009Eoo`8000]oo`03001oogoo00aoo`8000Eoo`03001oogoo0:eoo`00UGoo00<007ooOol0
2Woo0P003Woo00<007ooOol00goo0P00[Woo002:Ool50006Ool01000Oomoogoo0P000Woo0P0017oo
00<007ooOol017oo0`001Goo00<007ooOol017oo00<007ooOol037oo0`002goo0`001Woo0P001Goo
1000OWoo002<Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomoo`001Goo0P0017oo00D007oo
Oomoo`0000Aoo`03001oogoo00Aoo`8000aoo`05001oogooOol00002Ool600000goo001oo`02Ool0
0`00Oomoo`03Ool20009Ool00`00Oomoo`1kOol008aoo`03001oogoo00Ioo`03001oogoo00=oo`80
00aoo`03001oogoo00Ioo`03001oogoo019oo`03001oogoo00]oo`05001oogooOol0000@Ool00`00
Oomoo`1kOol008aoo`03001oogoo00Ioo`03001oogoo00=oo`8000aoo`03001oogoo00Ioo`03001o
ogoo019oo`03001oogoo00Aoo`H00003Ool007oo009oo`03001oogoo00ioo`03001oogoo07]oo`00
S7oo00<007ooOol01Woo00<007ooOol00Woo00@007ooOol000]oo`03001oogoo00Ioo`03001oogoo
019oo`03001oogoo00]oo`@000eoo`@007ioo`00RGoo00@007ooOol0009oo`03001oogoo00=oo`04
001oogooOol20002Ool20008Ool60005Ool00`00Oomoo`0@Ool6000:Ool00`00Oomoo`0>Ool00`00
Oomoo`1oOol008Uoo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`06
Ool00`00Oomoo`0BOol00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`1oOol008Uoo`L000Eo
o`80019oo`03001oogoo00Eoo`8001Aoo`03001oogoo00eoo`<000aoo`@007ioo`00ogooJGoo003o
OomYOol00?moofUoo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .51204 m
.04057 .44856 L
.08481 .39267 L
.12636 .35184 L
.16632 .32207 L
.18859 .30906 L
.20885 .29923 L
.23014 .29077 L
.2498 .28451 L
.2699 .2795 L
.28117 .27726 L
.29172 .27549 L
.31138 .273 L
.32182 .27207 L
.32764 .27166 L
.33304 .27135 L
.3386 .27109 L
.34365 .27091 L
.34634 .27083 L
.34926 .27077 L
.35086 .27074 L
.35233 .27072 L
.35373 .2707 L
.35523 .27068 L
.35655 .27067 L
.35776 .27067 L
.35897 .27066 L
.36012 .27066 L
.36146 .27066 L
.36269 .27066 L
.36405 .27067 L
.36473 .27068 L
.36549 .27068 L
.36818 .27071 L
.37108 .27076 L
.37633 .27087 L
.38153 .27103 L
.38638 .27121 L
.39737 .27174 L
.40808 .27241 L
.41952 .27326 L
.4631 .27765 L
.50508 .28302 L
.54547 .28874 L
.58843 .29499 L
.6298 .30085 L
.66959 .30615 L
.71194 .31126 L
.75271 .31559 L
.79605 .31948 L
Mistroke
.8378 .32252 L
.87795 .32478 L
.90038 .32576 L
.92069 .32648 L
.93088 .32678 L
.94188 .32705 L
.9514 .32725 L
.96183 .32743 L
.97144 .32755 L
.9804 .32764 L
.98536 .32767 L
.98987 .32769 L
.99236 .3277 L
.99368 .32771 L
.99507 .32771 L
.99629 .32771 L
.99763 .32771 L
.99886 .32771 L
1 .32771 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
00<000Ioo`8000Aoo`D000Aoo`@000Ioo`03001oogoo0?moodAoo`000goo00<007ooOol00goo0P00
1Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007ooOol02goo
00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0<Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03001oogoo00eoo`03001oogoo009oo`@0
00Ioo`03001oogoo0?moodAoo`000goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol0ogooA7oo0003Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol01goo
00<007ooOol0ogooA7oo0003000=Ool30005Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`0027oo0`001Woo0P00
1Goo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol0
0goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000047oo00<007ooOol00goo0`00ogooA7oo
0007Ool01@00Oomoogoo000047oo00<007ooOol00goo00<007ooOol0ogooA7oo0007Ool01@00Oomo
ogoo000037oo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol0
1goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol01goo00<007ooOol0
ogooA7oo0008Ool3000=Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol0
0`00Oomoo`3oOom4Ool000<000Ioo`8000Ioo`03001oogoo00Aoo`@000Ioo`03001oogoo0?moodAo
o`000goo00<007ooOol00goo0P001Woo00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogoo
A7oo0003Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03
001oogoo00aoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007oo
Ool037oo00<007ooOol00goo10001Woo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0=Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000=oo`03001oogoo00Uoo`05001oogoo
Ool00004Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000<000aoo`D000Aoo`@000Ioo`800?mo
odEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0Hgoo4P00cWoo000ROol00`00Oomoo`1IOol:000BOol?002oOol0029oo`03001o
ogoo055oo`P002]oo`X00;Eoo`008Woo0P00CGoo1@00?Goo1P00[goo000ROol00`00Oomoo`18Ool4
0018Ool6002YOol0029oo`03001oogoo04Eoo`<0059oo`L00:9oo`008Woo00<007ooOol0@Woo0`00
G7oo1P00W7oo000ROol20011Ool2001UOol7002EOol0029oo`03001oogoo03ioo`8006ioo`T008ao
o`0067oo1@001Goo00<007ooOol0?7oo0P00NGoo2@00Pgoo000JOol00`00Oomoo`05Ool00`00Oomo
o`0iOol30024Ool6001mOol001Yoo`03001oogoo00Eoo`03001oogoo03Moo`8008eoo`H007Moo`00
6Woo00<007ooOol01Goo0`00=Goo0P00UGoo1`00L7oo000JOol00`00Oomoo`05Ool00`00Oomoo`0d
Ool00`00Oomoo`2LOol:001VOol001Yoo`03001oogoo00Eoo`03001oogoo039oo`800:Uoo`d005Uo
o`006Woo00<007ooOol01Goo00<007ooOol0<Goo00<007ooOol0]Woo3000CGoo000HOol30007Ool0
0`00Oomoo`0_Ool20035Ool=0010Ool0029oo`8002moo`03001oogoo0=9ooah0029oo`008Woo00<0
07ooOol0;7oo0P00lgoo3@005Goo000ROol00`00Oomoo`0[Ool00`00Oomoo`3oOolFOol0029oo`03
001oogoo02Uoo`800?mooaUoo`008Woo0P00:Goo00<007ooOol0ogoo6Goo000ROol00`00Oomoo`0W
Ool00`00Oomoo`3oOolJOol0029oo`03001oogoo02Eoo`800?mooaeoo`008Woo00<007ooOol097oo
00<007ooOol0ogoo7Goo000ROol00`00Oomoo`0SOol00`00Oomoo`3oOolNOol0029oo`8002=oo`03
001oogoo0?mooamoo`008Woo00<007ooOol08Goo00<007ooOol0ogoo87oo000ROol00`00Oomoo`0P
Ool00`00Oomoo`3oOolQOol0029oo`03001oogoo01moo`03001oogoo0?moob9oo`008Woo00<007oo
Ool07Woo00<007ooOol0ogoo8goo000ROol2000NOol00`00Oomoo`3oOolTOol0029oo`03001oogoo
01aoo`03001oogoo0?moobEoo`001@0017oo0P0017oo1@0017oo10001Woo00<007ooOol06goo00<0
07ooOol0ogoo9Woo0002Ool00`00Oomoo`04Ool20005Ool01000Oomoo`0027oo00<007ooOol00goo
00<007ooOol06Woo00<007ooOol0ogoo9goo0002Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00
Oomoo`03Ool3000IOol00`00Oomoo`3oOolXOol0009oo`03001oogoo00eoo`03001oogoo00Moo`03
001oogoo00=oo`03001oogoo01Qoo`03001oogoo0?moobUoo`000Woo00<007ooOol03Woo00<007oo
Ool00Woo10001Woo00<007ooOol05goo00<007ooOol0ogoo:Woo0002Ool00`00Oomoo`0>Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0GOol00`00Oomoo`3oOolZOol0009oo`03001oogoo
00Yoo`05001oogooOol00004Ool00`00Oomoo`07Ool00`00Oomoo`0FOol00`00Oomoo`3oOol[Ool0
00<000eoo`<000Eoo`@000Ioo`8001Ioo`03001oogoo0?moobaoo`008Woo00<007ooOol057oo00<0
07ooOol0ogoo;Goo000ROol00`00Oomoo`0COol00`00Oomoo`3oOol^Ool0029oo`03001oogoo019o
o`03001oogoo0?moobmoo`008Woo00<007ooOol04Woo00<007ooOol0ogoo;goo000ROol2000BOol0
0`00Oomoo`3oOol`Ool0029oo`03001oogoo011oo`03001oogoo0?mooc5oo`008Woo00<007ooOol0
3goo00<007ooOol0ogoo<Woo000ROol00`00Oomoo`0>Ool00`00Oomoo`3oOolcOol0029oo`8000mo
o`03001oogoo0?mooc=oo`008Woo00<007ooOol03Goo00<007ooOol0ogoo=7oo000ROol00`00Oomo
o`0<Ool00`00Oomoo`3oOoleOol0029oo`03001oogoo00]oo`03001oogoo0?moocIoo`008Woo00<0
07ooOol02Woo00<007ooOol0ogoo=goo000ROol2000:Ool00`00Oomoo`3oOolhOol0029oo`03001o
ogoo00Uoo`03001oogoo0?moocQoo`0027oo1@0017oo0P001Goo10001Woo00<007ooOol027oo00<0
07ooOol0ogoo>Goo000:Ool00`00Oomoo`04Ool20009Ool00`00Oomoo`03Ool00`00Oomoo`07Ool0
0`00Oomoo`3oOoljOol000Yoo`03001oogoo00moo`03001oogoo00=oo`03001oogoo00Moo`03001o
ogoo0?moocYoo`002Woo00<007ooOol03goo00<007ooOol00goo0`001Woo00<007ooOol0ogoo>goo
000:Ool00`00Oomoo`0;Ool40006Ool00`00Oomoo`06Ool00`00Oomoo`3oOolkOol000Yoo`03001o
ogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo0?moocaoo`002Woo00<007ooOol0
2goo00<007ooOol01goo00<007ooOol017oo00<007ooOol0ogoo?Goo0008Ool3000=Ool40006Ool0
0`00Oomoo`04Ool00`00Oomoo`3oOolmOol0029oo`8000Aoo`03001oogoo0?moocioo`008Woo00<0
07ooOol00goo00<007ooOol0ogoo?Woo000ROol00`00Oomoo`02Ool00`00Oomoo`3oOoloOol0029o
o`05001oogooOol0003oOom2Ool0029oo`80009oo`03001oogoo0?mood1oo`008Woo00@007ooOol0
0?mood=oo`008Woo00@007ooOol00?mood=oo`008Woo00<007oo0000ogooA7oo000ROol2003oOom5
Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029o
o`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001o
ogoo0?moodAoo`001@0017oo0P001Woo00<007ooOol017oo10001Woo00<007ooOol0ogooA7oo0002
Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`3oOom4Ool0
009oo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00=oo`<00?moodAoo`000Woo00<007oo
Ool03Goo00<007ooOol01goo00<007ooOol00goo00<007ooOol0ogooA7oo0002Ool00`00Oomoo`0=
Ool00`00Oomoo`03Ool40006Ool00`00Oomoo`3oOom4Ool0009oo`03001oogoo00ioo`03001oogoo
009oo`03001oogoo00Moo`03001oogoo0?moodAoo`000Woo00<007ooOol02Woo00D007ooOomoo`00
00Aoo`03001oogoo00Moo`03001oogoo0?moodAoo`000`0037oo1@0017oo10001Woo0P00ogooAGoo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol0
0`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomo
o`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomo
o`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000GOol50006Ool00`00Oomo
o`3oOom4Ool001Qoo`04001oogoo0006Ool00`00Oomoo`3oOom4Ool001Uoo`03001oogoo00Ioo`03
001oogoo0?moodAoo`006Woo00<007ooOol01Goo0`00ogooA7oo000KOol00`00Oomoo`3oOom;Ool0
01]oo`03001oogoo0?mood]oo`005goo00D007ooOomoo`000?moodeoo`0067oo0`00ogooCWoo003o
OomYOol009Qoo`8000]oo`03001oogoo00aoo`8000Ioo`03001oogoo0:Uoo`00V7oo00<007ooOol0
2Woo0P003Woo00<007ooOol017oo0P00ZWoo002>Ool50005Ool00`00Oomoo`02Ool20002Ool20003
Ool00`00Oomoo`05Ool30004Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool3000<Ool00`00Oomoo`05
Ool20023Ool0091oo`03001oogoo00Eoo`03001oogoo00=oo`04001oogoo0004Ool20005Ool01@00
Oomoogoo00000goo00<007ooOol01Goo0P0037oo00H007ooOomoo`00Ool60004Ool00`00Oomoo`05
Ool20023Ool0091oo`03001oogoo00Eoo`03001oogoo00Aoo`8000aoo`03001oogoo00Eoo`03001o
ogoo01=oo`03001oogoo00ioo`03001oogoo08Uoo`00T7oo00<007ooOol01Goo00<007ooOol017oo
0P0037oo00<007ooOol01Goo00<007ooOol04goo00<007ooOol00goo1P001Goo00<007ooOol0RGoo
002@Ool00`00Oomoo`05Ool00`00Oomoo`03Ool01000Oomoo`002goo00<007ooOol01Goo00<007oo
Ool04goo00<007ooOol03Woo00<007ooOol0RGoo002=Ool01000Oomoo`000Woo00<007ooOol00Woo
00<007ooOol00Woo0P000Woo0P0027oo1P0017oo00<007ooOol04Goo1P003Woo00<007ooOol0R7oo
002=Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol04Woo00<007ooOol01Goo00<007oo
Ool04goo00<007ooOol02goo00D007ooOomoo`0008Yoo`00SGoo1`0017oo0P004goo00<007ooOol0
17oo0P005Goo00<007ooOol02goo1@00RWoo003oOomYOol00?moofUoo`00ogooJGoo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.5) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .59887 m
.04057 .53866 L
.08481 .48074 L
.12636 .4343 L
.16632 .39696 L
.20885 .36476 L
.2498 .34054 L
.29331 .32127 L
.31511 .31385 L
.33524 .30817 L
.35606 .30338 L
.37557 .2998 L
.39524 .297 L
.40634 .29574 L
.41689 .29475 L
.42706 .29397 L
.43815 .2933 L
.44824 .29284 L
.4576 .29255 L
.46293 .29243 L
.46594 .29237 L
.4687 .29234 L
.47112 .29231 L
.47378 .29229 L
.47512 .29228 L
.47586 .29228 L
.47656 .29227 L
.47791 .29227 L
.47915 .29227 L
.48027 .29227 L
.48151 .29227 L
.4828 .29228 L
.48401 .29228 L
.48514 .29229 L
.48618 .29229 L
.48851 .29231 L
.49088 .29234 L
.49347 .29237 L
.49869 .29246 L
.50424 .29258 L
.50948 .29272 L
.51928 .29304 L
.54128 .29402 L
.58167 .29655 L
.62463 .29994 L
.66601 .30353 L
.70579 .30702 L
.74814 .31057 L
.78891 .31367 L
.83225 .31651 L
Mistroke
.874 .3187 L
.91416 .32025 L
.93485 .32083 L
.94634 .32108 L
.95689 .32127 L
.96757 .32142 L
.97307 .32148 L
.9791 .32154 L
.98436 .32157 L
.98927 .3216 L
.99198 .32161 L
.99445 .32161 L
.99582 .32162 L
.99654 .32162 L
.9973 .32162 L
.99797 .32162 L
.9987 .32162 L
1 .32162 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
00<000Ioo`8000Aoo`D000Aoo`@000Ioo`03001oogoo0?moodAoo`000goo00<007ooOol00goo0P00
1Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007ooOol02goo
00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0<Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03001oogoo00eoo`03001oogoo009oo`@0
00Ioo`03001oogoo0?moodAoo`000goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol0ogooA7oo0003Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol01goo
00<007ooOol0ogooA7oo0003000=Ool30005Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`0027oo0`001Woo0P00
1Goo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol0
0goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000047oo00<007ooOol00goo0`00ogooA7oo
0007Ool01@00Oomoogoo000047oo00<007ooOol00goo00<007ooOol0ogooA7oo0007Ool01@00Oomo
ogoo000037oo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol0
1goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol01goo00<007ooOol0
ogooA7oo0008Ool3000=Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol0
0`00Oomoo`3oOom4Ool000<000Ioo`8000Ioo`03001oogoo00Aoo`@000Ioo`03001oogoo0?moodAo
o`000goo00<007ooOol00goo0P001Woo00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogoo
A7oo0003Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03
001oogoo00aoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007oo
Ool037oo00<007ooOol00goo10001Woo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0=Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000=oo`03001oogoo00Uoo`05001oogoo
Ool00004Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000<000aoo`D000Aoo`@000Ioo`800?mo
odEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol2001oOol[002JOol0029oo`03001oogoo079oo``002]oo`d008eoo`00
67oo1@001Goo00<007ooOol0K7oo1P00A7oo3000PGoo000JOol00`00Oomoo`05Ool00`00Oomoo`1X
Ool4001FOol<001eOol001Yoo`03001oogoo00Eoo`03001oogoo06Eoo`<006Ioo`d006Qoo`006Woo
00<007ooOol01Goo0`00H7oo1@00MWoo3@00Fgoo000JOol00`00Oomoo`05Ool00`00Oomoo`1LOol4
0028Ool=001>Ool001Yoo`03001oogoo00Eoo`03001oogoo05Uoo`<009Uoo``0049oo`006Woo00<0
07ooOol01Goo00<007ooOol0Egoo0P00Z7oo5P00;7oo000HOol30007Ool00`00Oomoo`1EOol20030
OolG000EOol0029oo`8005Aoo`800>ioo`008Woo00<007ooOol0DGoo0P00l7oo000ROol00`00Oomo
o`1>Ool3003bOol0029oo`03001oogoo04aoo`800?Eoo`008Woo0P00Bgoo0P00mgoo000ROol00`00
Oomoo`18Ool2003iOol0029oo`03001oogoo04Ioo`800?]oo`008Woo00<007ooOol0AGoo00<007oo
Ool0ngoo000ROol00`00Oomoo`13Ool2003nOol0029oo`80049oo`800?moo`5oo`008Woo00<007oo
Ool0@7oo00<007ooOol0ogoo0Goo000ROol00`00Oomoo`0nOol2003oOol4Ool0029oo`03001oogoo
03aoo`800?moo`Ioo`008Woo00<007ooOol0>goo00<007ooOol0ogoo1Woo000ROol2000kOol00`00
Oomoo`3oOol7Ool0029oo`03001oogoo03Qoo`800?moo`Yoo`001@0017oo0P0017oo1@0017oo1000
1Woo00<007ooOol0=goo00<007ooOol0ogoo2Woo0002Ool00`00Oomoo`04Ool20005Ool01000Oomo
o`0027oo00<007ooOol00goo00<007ooOol0=Woo00<007ooOol0ogoo2goo0002Ool00`00Oomoo`0<
Ool00`00Oomoo`08Ool00`00Oomoo`03Ool3000eOol00`00Oomoo`3oOol<Ool0009oo`03001oogoo
00eoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo03=oo`800?moo`moo`000Woo00<007oo
Ool03Woo00<007ooOol00Woo10001Woo00<007ooOol0<Woo00<007ooOol0ogoo3goo0002Ool00`00
Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0aOol00`00Oomoo`3oOol@Ool0
009oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00Oomoo`07Ool00`00Oomoo`0_Ool2003o
OolCOol000<000eoo`<000Eoo`@000Ioo`8002moo`03001oogoo0?mooa=oo`008Woo00<007ooOol0
;Goo00<007ooOol0ogoo57oo000ROol00`00Oomoo`0/Ool00`00Oomoo`3oOolEOol0029oo`03001o
ogoo02]oo`03001oogoo0?mooaIoo`008Woo00<007ooOol0:Goo0P00ogoo6Goo000ROol2000YOol0
0`00Oomoo`3oOolIOol0029oo`03001oogoo02Moo`03001oogoo0?mooaYoo`008Woo00<007ooOol0
9Woo00<007ooOol0ogoo6goo000ROol00`00Oomoo`0UOol00`00Oomoo`3oOolLOol0029oo`8002Eo
o`03001oogoo0?mooaeoo`008Woo00<007ooOol08goo00<007ooOol0ogoo7Woo000ROol00`00Oomo
o`0SOol00`00Oomoo`3oOolNOol0029oo`03001oogoo029oo`03001oogoo0?mooamoo`008Woo00<0
07ooOol08Goo00<007ooOol0ogoo87oo000ROol2000QOol00`00Oomoo`3oOolQOol0029oo`03001o
ogoo01moo`03001oogoo0?moob9oo`0027oo1@0017oo0P001Goo10001Woo00<007ooOol07Woo00<0
07ooOol0ogoo8goo000:Ool00`00Oomoo`04Ool20009Ool00`00Oomoo`03Ool00`00Oomoo`0MOol0
0`00Oomoo`3oOolTOol000Yoo`03001oogoo00moo`03001oogoo00=oo`03001oogoo01eoo`03001o
ogoo0?moobAoo`002Woo00<007ooOol03goo00<007ooOol00goo0`0077oo00<007ooOol0ogoo9Goo
000:Ool00`00Oomoo`0;Ool40006Ool00`00Oomoo`0KOol00`00Oomoo`3oOolVOol000Yoo`03001o
ogoo00]oo`03001oogoo00Moo`03001oogoo01Yoo`03001oogoo0?moobMoo`002Woo00<007ooOol0
2goo00<007ooOol01goo00<007ooOol06Goo00<007ooOol0ogoo:7oo0008Ool3000=Ool40006Ool0
0`00Oomoo`0HOol00`00Oomoo`3oOolYOol0029oo`8001Qoo`03001oogoo0?moobYoo`008Woo00<0
07ooOol05goo00<007ooOol0ogoo:Woo000ROol00`00Oomoo`0FOol00`00Oomoo`3oOol[Ool0029o
o`03001oogoo01Eoo`03001oogoo0?moobaoo`008Woo0P005Goo00<007ooOol0ogoo;Goo000ROol0
0`00Oomoo`0COol00`00Oomoo`3oOol^Ool0029oo`03001oogoo01=oo`03001oogoo0?moobioo`00
8Woo00<007ooOol04Woo00<007ooOol0ogoo;goo000ROol00`00Oomoo`0AOol00`00Oomoo`3oOol`
Ool0029oo`80015oo`03001oogoo0?mooc5oo`008Woo00<007ooOol047oo00<007ooOol0ogoo<Goo
000ROol00`00Oomoo`0?Ool00`00Oomoo`3oOolbOol0029oo`03001oogoo00ioo`03001oogoo0?mo
oc=oo`008Woo00<007ooOol03Goo00<007ooOol0ogoo=7oo000ROol2000=Ool00`00Oomoo`3oOole
Ool0029oo`03001oogoo00aoo`03001oogoo0?moocEoo`001@0017oo0P001Woo00<007ooOol017oo
10001Woo00<007ooOol02goo00<007ooOol0ogoo=Woo0002Ool00`00Oomoo`04Ool20006Ool00`00
Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool00`00Oomoo`3oOolgOol0009oo`03001oogoo
00eoo`03001oogoo00Moo`03001oogoo00=oo`<000Uoo`03001oogoo0?moocQoo`000Woo00<007oo
Ool03Goo00<007ooOol01goo00<007ooOol00goo00<007ooOol02Goo00<007ooOol0ogoo>7oo0002
Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool40006Ool00`00Oomoo`08Ool00`00Oomoo`3oOoliOol0
009oo`03001oogoo00ioo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo
0?moocYoo`000Woo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo00Moo`03001oogoo
00Moo`03001oogoo0?moocYoo`000`0037oo1@0017oo10001Woo0P001goo00<007ooOol0ogoo>goo
000ROol00`00Oomoo`05Ool00`00Oomoo`3oOollOol0029oo`03001oogoo00Eoo`03001oogoo0?mo
ocaoo`008Woo00<007ooOol017oo00<007ooOol0ogoo?Goo000ROol00`00Oomoo`03Ool00`00Oomo
o`3oOolnOol0029oo`8000Aoo`03001oogoo0?moocioo`008Woo00<007ooOol00Woo00<007ooOol0
ogoo?goo000ROol01@00Oomoogoo0000ogoo@Woo000ROol01@00Oomoogoo0000ogoo@Woo000ROol2
00000goo001oo`3oOom2Ool0029oo`03001oo`000?moodAoo`008Woo00<007oo0000ogooA7oo000R
Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3o
Oom4Ool001Moo`D000Ioo`03001oogoo0?moodAoo`0067oo00@007ooOol000Ioo`03001oogoo0?mo
odAoo`006Goo00<007ooOol01Woo00<007ooOol0ogooA7oo000JOol00`00Oomoo`05Ool3003oOom4
Ool001]oo`03001oogoo0?mood]oo`006goo00<007ooOol0ogooBgoo000GOol01@00Oomoogoo0000
ogooCGoo000HOol3003oOom>Ool00?moofUoo`00UGoo0P002goo00<007ooOol037oo0P001Goo00<0
07ooOol0[Goo002EOol00`00Oomoo`0:Ool2000>Ool00`00Oomoo`03Ool2002^Ool008Yoo`D000Io
o`04001oogooOol20002Ool20004Ool00`00Oomoo`04Ool30005Ool00`00Oomoo`04Ool00`00Oomo
o`0<Ool3000<Ool00`00Oomoo`05Ool20005Ool4001nOol008aoo`03001oogoo00Ioo`03001oogoo
009oo`04001oogoo0005Ool20004Ool01@00Oomoogoo000017oo00<007ooOol017oo0P0037oo00D0
07ooOomoo`00009oo`H000=oo`03001oogoo00Eoo`8000Uoo`03001oogoo07]oo`00S7oo00<007oo
Ool01Woo00<007ooOol00goo0P0037oo00<007ooOol01Woo00<007ooOol04Woo00<007ooOol03Woo
00<007ooOol03goo00<007ooOol0Ngoo002<Ool00`00Oomoo`06Ool00`00Oomoo`03Ool2000<Ool0
0`00Oomoo`06Ool00`00Oomoo`0BOol00`00Oomoo`04Ool60004Ool00`00Oomoo`0?Ool00`00Oomo
o`1kOol008aoo`03001oogoo00Ioo`03001oogoo009oo`04001oogoo000;Ool00`00Oomoo`06Ool0
0`00Oomoo`0BOol00`00Oomoo`0>Ool00`00Oomoo`0;Ool4001nOol008Uoo`04001oogoo0002Ool0
0`00Oomoo`03Ool01000Oomoogoo0P000Woo0P0027oo1P001Goo00<007ooOol047oo1P003Woo00<0
07ooOol02Woo00<007ooOol0Ogoo0029Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol0
4Goo00<007ooOol01Woo00<007ooOol04Woo00<007ooOol02goo00D007ooOomoo`0000aoo`03001o
ogoo07moo`00RGoo1`001Goo0P004Woo00<007ooOol01Goo0P0057oo00<007ooOol02goo1@0037oo
1000OWoo003oOomYOol00?moofUoo`00ogooJGoo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8.) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .61475 m
.04057 .57283 L
.08481 .52736 L
.12636 .48697 L
.16632 .45148 L
.20885 .41809 L
.2498 .39055 L
.29331 .36627 L
.33524 .34752 L
.37557 .33344 L
.41848 .32223 L
.43982 .31795 L
.4598 .31462 L
.48017 .31186 L
.49953 .30976 L
.52079 .308 L
.54024 .30682 L
.55031 .30636 L
.56104 .30597 L
.57116 .3057 L
.58034 .30552 L
.58546 .30545 L
.58826 .30541 L
.59087 .30539 L
.59328 .30537 L
.59548 .30536 L
.59793 .30535 L
.59928 .30534 L
.60055 .30534 L
.6018 .30533 L
.60319 .30533 L
.60388 .30533 L
.60463 .30533 L
.60599 .30533 L
.60727 .30534 L
.60862 .30534 L
.60976 .30534 L
.61102 .30535 L
.61387 .30536 L
.61692 .30538 L
.62241 .30543 L
.62801 .3055 L
.63317 .30557 L
.64483 .30578 L
.66598 .30631 L
.70736 .30773 L
.74714 .30938 L
.7895 .31121 L
.83026 .31288 L
.8736 .31441 L
Mistroke
.89527 .31504 L
.91535 .31553 L
.9348 .31591 L
.95551 .31622 L
.96634 .31633 L
.97203 .31638 L
.97803 .31642 L
.9833 .31645 L
.98609 .31646 L
.98908 .31647 L
.99183 .31648 L
.99433 .31648 L
.99553 .31648 L
.99684 .31648 L
.99808 .31648 L
.99922 .31648 L
1 .31648 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
00<000Ioo`8000Aoo`D000Aoo`@000Ioo`03001oogoo0?moodAoo`000goo00<007ooOol00goo0P00
1Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007ooOol02goo
00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0<Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03001oogoo00eoo`03001oogoo009oo`@0
00Ioo`03001oogoo0?moodAoo`000goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol0ogooA7oo0003Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol01goo
00<007ooOol0ogooA7oo0003000=Ool30005Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`0027oo0`001Woo0P00
1Goo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol0
0goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000047oo00<007ooOol00goo0`00ogooA7oo
0007Ool01@00Oomoogoo000047oo00<007ooOol00goo00<007ooOol0ogooA7oo0007Ool01@00Oomo
ogoo000037oo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol0
1goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol01goo00<007ooOol0
ogooA7oo0008Ool3000=Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol0
0`00Oomoo`3oOom4Ool000<000Ioo`8000Ioo`03001oogoo00Aoo`@000Ioo`03001oogoo0?moodAo
o`000goo00<007ooOol00goo0P001Woo00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogoo
A7oo0003Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03
001oogoo00aoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007oo
Ool037oo00<007ooOol00goo10001Woo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0=Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000=oo`03001oogoo00Uoo`05001oogoo
Ool00004Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000<000aoo`D000Aoo`@000Ioo`800?mo
odEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`0067oo1@001Goo00<0
07ooOol0ogooA7oo000JOol00`00Oomoo`05Ool00`00Oomoo`3oOom4Ool001Yoo`03001oogoo00Eo
o`03001oogoo09iooc4007Aoo`006Woo00<007ooOol01Goo0`00TWoo3000<Goo6@00Fgoo000JOol0
0`00Oomoo`05Ool00`00Oomoo`2<Ool6001FOolI0012Ool001Yoo`03001oogoo00Eoo`03001oogoo
08Ioo`H007Eoobd001Eoo`006Woo00<007ooOol01Goo00<007ooOol0P7oo1P00_Goo000HOol30007
Ool00`00Oomoo`1jOol60033Ool0029oo`8007Ioo`D00<Uoo`008Woo00<007ooOol0LGoo1000cWoo
000ROol00`00Oomoo`1^Ool3003BOol0029oo`03001oogoo06]oo`<00=Eoo`008Woo0P00JWoo0P00
f7oo000ROol00`00Oomoo`1WOol2003JOol0029oo`03001oogoo06Aoo`<00=aoo`008Woo00<007oo
Ool0HWoo0P00ggoo000ROol00`00Oomoo`1OOol3003QOol0029oo`8005eoo`<00>Aoo`008Woo00<0
07ooOol0FWoo0P00igoo000ROol00`00Oomoo`1GOol3003YOol0029oo`03001oogoo05Eoo`800>ao
o`008Woo00<007ooOol0E7oo00<007ooOol0k7oo000ROol2001COol2003_Ool0029oo`03001oogoo
051oo`800?5oo`001@0017oo0P0017oo1@0017oo10001Woo00<007ooOol0Cgoo00<007ooOol0lGoo
0002Ool00`00Oomoo`04Ool20005Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0CGoo
0P00m7oo0002Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`03Ool3001;Ool2003fOol0
009oo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo04Yoo`03001oogoo
0?Ioo`000Woo00<007ooOol03Woo00<007ooOol00Woo10001Woo00<007ooOol0B7oo0P00nGoo0002
Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`17Ool00`00Oomoo`3i
Ool0009oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00Oomoo`07Ool00`00Oomoo`15Ool2
003lOol000<000eoo`<000Eoo`@000Ioo`8004Eoo`03001oogoo0?aoo`008Woo00<007ooOol0@Woo
0P00ogoo000ROol00`00Oomoo`11Ool00`00Oomoo`3oOol0029oo`03001oogoo03moo`800?moo`=o
o`008Woo00<007ooOol0?Woo00<007ooOol0ogoo0goo000ROol2000mOol2003oOol6Ool0029oo`03
001oogoo03]oo`03001oogoo0?moo`Ioo`008Woo00<007ooOol0>Woo00<007ooOol0ogoo1goo000R
Ool00`00Oomoo`0hOol2003oOol:Ool0029oo`8003Qoo`03001oogoo0?moo`Yoo`008Woo00<007oo
Ool0=Woo00<007ooOol0ogoo2goo000ROol00`00Oomoo`0eOol00`00Oomoo`3oOol<Ool0029oo`03
001oogoo03=oo`800?moo`moo`008Woo00<007ooOol0<Woo00<007ooOol0ogoo3goo000ROol2000b
Ool00`00Oomoo`3oOol@Ool0029oo`03001oogoo02moo`800?mooa=oo`0027oo1@0017oo0P001Goo
10001Woo00<007ooOol0;Woo00<007ooOol0ogoo4goo000:Ool00`00Oomoo`04Ool20009Ool00`00
Oomoo`03Ool00`00Oomoo`0]Ool00`00Oomoo`3oOolDOol000Yoo`03001oogoo00moo`03001oogoo
00=oo`03001oogoo02aoo`03001oogoo0?mooaEoo`002Woo00<007ooOol03goo00<007ooOol00goo
0`00:goo00<007ooOol0ogoo5Woo000:Ool00`00Oomoo`0;Ool40006Ool00`00Oomoo`0YOol2003o
OolIOol000Yoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo02Qoo`03001oogoo0?mooaUo
o`002Woo00<007ooOol02goo00<007ooOol01goo00<007ooOol09goo00<007ooOol0ogoo6Woo0008
Ool3000=Ool40006Ool00`00Oomoo`0VOol00`00Oomoo`3oOolKOol0029oo`8002Ioo`03001oogoo
0?mooaaoo`008Woo00<007ooOol097oo00<007ooOol0ogoo7Goo000ROol00`00Oomoo`0SOol00`00
Oomoo`3oOolNOol0029oo`03001oogoo029oo`03001oogoo0?mooamoo`008Woo0P008Woo00<007oo
Ool0ogoo87oo000ROol00`00Oomoo`0POol00`00Oomoo`3oOolQOol0029oo`03001oogoo01moo`03
001oogoo0?moob9oo`008Woo00<007ooOol07Woo00<007ooOol0ogoo8goo000ROol00`00Oomoo`0M
Ool00`00Oomoo`3oOolTOol0029oo`8001eoo`03001oogoo0?moobEoo`008Woo00<007ooOol06goo
00<007ooOol0ogoo9Woo000ROol00`00Oomoo`0JOol00`00Oomoo`3oOolWOol0029oo`03001oogoo
01Uoo`03001oogoo0?moobQoo`008Woo00<007ooOol067oo00<007ooOol0ogoo:Goo000ROol2000H
Ool00`00Oomoo`3oOolZOol0029oo`03001oogoo01Ioo`03001oogoo0?moob]oo`001@0017oo0P00
1Woo00<007ooOol017oo10001Woo00<007ooOol05Goo00<007ooOol0ogoo;7oo0002Ool00`00Oomo
o`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`0DOol00`00Oomoo`3oOol]
Ool0009oo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00=oo`<001=oo`03001oogoo0?mo
obioo`000Woo00<007ooOol03Goo00<007ooOol01goo00<007ooOol00goo00<007ooOol04Woo00<0
07ooOol0ogoo;goo0002Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool40006Ool00`00Oomoo`0AOol0
0`00Oomoo`3oOol`Ool0009oo`03001oogoo00ioo`03001oogoo009oo`03001oogoo00Moo`03001o
ogoo011oo`03001oogoo0?mooc5oo`000Woo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001o
ogoo00Moo`03001oogoo00moo`03001oogoo0?mooc9oo`000`0037oo1@0017oo10001Woo0P003goo
00<007ooOol0ogoo<goo000ROol00`00Oomoo`0=Ool00`00Oomoo`3oOoldOol0029oo`03001oogoo
00aoo`03001oogoo0?moocEoo`008Woo00<007ooOol02goo00<007ooOol0ogoo=Woo000ROol00`00
Oomoo`0:Ool00`00Oomoo`3oOolgOol0029oo`8000Yoo`03001oogoo0?moocQoo`008Woo00<007oo
Ool02Goo00<007ooOol0ogoo>7oo000ROol00`00Oomoo`08Ool00`00Oomoo`3oOoliOol0029oo`03
001oogoo00Moo`03001oogoo0?moocYoo`008Woo0P001goo00<007ooOol0ogoo>goo000ROol00`00
Oomoo`05Ool00`00Oomoo`3oOollOol0029oo`03001oogoo00Aoo`03001oogoo0?mooceoo`008Woo
00<007ooOol00goo00<007ooOol0ogoo?Woo000ROol00`00Oomoo`02Ool00`00Oomoo`3oOoloOol0
029oo`80009oo`03001oogoo0?mood1oo`008Woo00@007ooOol00?mood=oo`005goo1@001Woo00<0
07oo0000ogooA7oo000HOol01000Oomoo`001Woo0P00ogooAGoo000IOol00`00Oomoo`06Ool00`00
Oomoo`3oOom4Ool001Yoo`03001oogoo00Eoo`<00?moodAoo`006goo00<007ooOol0ogooBgoo000K
Ool00`00Oomoo`3oOom;Ool001Moo`05001oogooOol0003oOom=Ool001Qoo`<00?moodioo`00ogoo
JGoo002HOol2000;Ool00`00Oomoo`0<Ool20006Ool00`00Oomoo`2YOol009Qoo`03001oogoo00Yo
o`8000ioo`03001oogoo00Aoo`800:Yoo`00SWoo1@001Goo00<007ooOol00Woo0P000Woo0P000goo
00<007ooOol01Goo0`0017oo00<007ooOol01Goo00<007ooOol037oo0`002goo0`001Woo0P00Pgoo
002@Ool00`00Oomoo`05Ool00`00Oomoo`03Ool01000Oomoo`0017oo0P001Goo00D007ooOomoo`00
00=oo`03001oogoo00Eoo`8000aoo`06001oogooOol007oo1P000Woo00D007ooOomoo`0000Eoo`80
08=oo`00T7oo00<007ooOol01Goo00<007ooOol017oo0P0037oo00<007ooOol01Goo00<007ooOol0
4goo00<007ooOol02goo00D007ooOomoo`0008Yoo`00T7oo00<007ooOol01Goo00<007ooOol017oo
0P0037oo00<007ooOol01Goo00<007ooOol04goo00<007ooOol00goo1P000Woo00D007ooOomoo`00
08Yoo`00T7oo00<007ooOol01Goo00<007ooOol00goo00@007ooOol000]oo`03001oogoo00Eoo`03
001oogoo01=oo`03001oogoo00aoo`<008]oo`00SGoo00@007ooOol0009oo`03001oogoo009oo`03
001oogoo009oo`80009oo`8000Qoo`H000Aoo`03001oogoo015oo`H000Yoo`05001oogooOol0002:
Ool008eoo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`05Ool00`00
Oomoo`0COol00`00Oomoo`0;Ool01@00Oomoogoo0000RWoo002=Ool70004Ool2000COol00`00Oomo
o`04Ool2000EOol00`00Oomoo`0<Ool3002;Ool00?moofUoo`00ogooJGoo003oOomYOol00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8.5) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .55576 m
.01975 .5504 L
.04057 .54268 L
.08481 .5211 L
.12477 .49788 L
.1673 .47161 L
.20824 .44644 L
.25176 .42111 L
.29369 .39893 L
.33402 .38008 L
.37693 .36292 L
.41825 .34922 L
.45798 .33854 L
.50028 .32963 L
.54099 .32318 L
.56169 .3206 L
.58428 .31827 L
.60614 .31644 L
.62597 .31511 L
.64663 .31402 L
.66865 .31314 L
.68886 .31257 L
.70024 .31233 L
.71072 .31215 L
.72094 .31202 L
.73048 .31193 L
.73596 .3119 L
.74096 .31187 L
.74372 .31186 L
.74672 .31185 L
.74956 .31184 L
.75083 .31184 L
.75218 .31183 L
.75339 .31183 L
.75472 .31183 L
.75592 .31183 L
.75704 .31183 L
.75837 .31183 L
.75958 .31183 L
.76025 .31183 L
.76097 .31183 L
.76229 .31183 L
.76343 .31183 L
.76469 .31183 L
.76723 .31183 L
.76958 .31184 L
.77178 .31184 L
.77723 .31186 L
.78221 .31188 L
.79341 .31194 L
Mistroke
.81338 .31208 L
.83516 .31228 L
.87789 .31272 L
.91903 .3131 L
.94156 .31326 L
.95187 .31331 L
.96275 .31336 L
.97201 .3134 L
.97691 .31341 L
.98216 .31342 L
.98699 .31343 L
.98928 .31344 L
.99139 .31344 L
.99351 .31344 L
.99461 .31344 L
.99582 .31344 L
.99686 .31344 L
.99785 .31344 L
.99888 .31344 L
1 .31344 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
00<000Ioo`8000Aoo`D000Aoo`@000Ioo`03001oogoo0?moodAoo`000goo00<007ooOol00goo0P00
1Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007ooOol02goo
00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0<Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03001oogoo00eoo`03001oogoo009oo`@0
00Ioo`03001oogoo0?moodAoo`000goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol0ogooA7oo0003Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol01goo
00<007ooOol0ogooA7oo0003000=Ool30005Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`0027oo0`001Woo0P00
1Goo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol0
0goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000047oo00<007ooOol00goo0`00ogooA7oo
0007Ool01@00Oomoogoo000047oo00<007ooOol00goo00<007ooOol0ogooA7oo0007Ool01@00Oomo
ogoo000037oo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol0
1goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol01goo00<007ooOol0
ogooA7oo0008Ool3000=Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol0
0`00Oomoo`3oOom4Ool000<000Ioo`8000Ioo`03001oogoo00Aoo`@000Ioo`03001oogoo0?moodAo
o`000goo00<007ooOol00goo0P001Woo00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogoo
A7oo0003Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03
001oogoo00aoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007oo
Ool037oo00<007ooOol00goo10001Woo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0=Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000=oo`03001oogoo00Uoo`05001oogoo
Ool00004Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000<000aoo`D000Aoo`@000Ioo`800?mo
odEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`0067oo1@001Goo00<0
07ooOol0ogooA7oo000JOol00`00Oomoo`05Ool00`00Oomoo`3oOom4Ool001Yoo`03001oogoo00Eo
o`03001oogoo0?moodAoo`006Woo00<007ooOol01Goo0`00ogooA7oo000JOol00`00Oomoo`05Ool0
0`00Oomoo`2nOom`000EOol001Yoo`03001oogoo00Eoo`03001oogoo0;9oo``008Eoo`006Woo00<0
07ooOol01Goo00<007ooOol0YGoo3@00TGoo000HOol30007Ool00`00Oomoo`2NOol7002NOol0029o
o`8009Uoo`H00:Eoo`008Woo00<007ooOol0Tgoo1@00Zgoo000ROol00`00Oomoo`2>Ool5002`Ool0
029oo`03001oogoo08Yoo`@00;Eoo`008Woo0P00Qgoo1000^Goo000ROol00`00Oomoo`22Ool4002m
Ool0029oo`03001oogoo07ioo`@00<5oo`008Woo00<007ooOol0Ngoo0`00aGoo000ROol00`00Oomo
o`1hOol30038Ool0029oo`8007Ioo`<00<]oo`008Woo00<007ooOol0LWoo0`00cWoo000ROol00`00
Oomoo`1_Ool3003AOol0029oo`03001oogoo06aoo`<00=Aoo`008Woo00<007ooOol0JGoo0`00egoo
000ROol2001WOol3003JOol0029oo`03001oogoo06=oo`<00=eoo`001@0017oo0P0017oo1@0017oo
10001Woo00<007ooOol0HGoo0P00h7oo0002Ool00`00Oomoo`04Ool20005Ool01000Oomoo`0027oo
00<007ooOol00goo00<007ooOol0Ggoo0P00hWoo0002Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool0
0`00Oomoo`03Ool3001MOol2003TOol0009oo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo
00=oo`03001oogoo05]oo`800>Ioo`000Woo00<007ooOol03Woo00<007ooOol00Woo10001Woo00<0
07ooOol0FGoo0P00j7oo0002Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00
Oomoo`1GOol2003ZOol0009oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00Oomoo`07Ool0
0`00Oomoo`1EOol2003/Ool000<000eoo`<000Eoo`@000Ioo`8005Aoo`800>ioo`008Woo00<007oo
Ool0DWoo00<007ooOol0kWoo000ROol00`00Oomoo`1@Ool2003aOol0029oo`03001oogoo04ioo`80
0?=oo`008Woo00<007ooOol0CGoo00<007ooOol0lgoo000ROol2001<Ool2003fOol0029oo`03001o
ogoo04Uoo`800?Qoo`008Woo00<007ooOol0Agoo0P00nWoo000ROol00`00Oomoo`16Ool00`00Oomo
o`3jOol0029oo`8004Eoo`800?eoo`008Woo00<007ooOol0@Woo0P00ogoo000ROol00`00Oomoo`10
Ool2003oOol2Ool0029oo`03001oogoo03moo`03001oogoo0?moo`9oo`008Woo00<007ooOol0?Goo
0P00ogoo1Goo000ROol2000lOol2003oOol7Ool0029oo`03001oogoo03Uoo`800?moo`Uoo`0027oo
1@0017oo0P001Goo10001Woo00<007ooOol0>7oo00<007ooOol0ogoo2Goo000:Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`03Ool00`00Oomoo`0fOol2003oOol<Ool000Yoo`03001oogoo00moo`03
001oogoo00=oo`03001oogoo03Aoo`800?moo`ioo`002Woo00<007ooOol03goo00<007ooOol00goo
0`00<goo00<007ooOol0ogoo3Woo000:Ool00`00Oomoo`0;Ool40006Ool00`00Oomoo`0aOol2003o
OolAOol000Yoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo02moo`800?mooa=oo`002Woo
00<007ooOol02goo00<007ooOol01goo00<007ooOol0;Woo00<007ooOol0ogoo4goo0008Ool3000=
Ool40006Ool00`00Oomoo`0/Ool2003oOolFOol0029oo`8002]oo`800?mooaQoo`008Woo00<007oo
Ool0:Goo00<007ooOol0ogoo67oo000ROol00`00Oomoo`0WOol2003oOolKOol0029oo`03001oogoo
02Eoo`800?mooaeoo`008Woo0P009Goo00<007ooOol0ogoo7Goo000ROol00`00Oomoo`0ROol2003o
OolPOol0029oo`03001oogoo021oo`800?moob9oo`008Woo00<007ooOol07goo00<007ooOol0ogoo
8Woo000ROol00`00Oomoo`0MOol2003oOolUOol0029oo`8001aoo`800?moobMoo`008Woo00<007oo
Ool06Woo00<007ooOol0ogoo9goo000ROol00`00Oomoo`0HOol2003oOolZOol0029oo`03001oogoo
01Ioo`800?moobaoo`008Woo00<007ooOol057oo0P00ogoo;Woo000ROol2000COol2003oOol`Ool0
029oo`03001oogoo011oo`800?mooc9oo`001@0017oo0P001Woo00<007ooOol017oo10001Woo00<0
07ooOol03Woo0P00ogoo=7oo0002Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomo
o`03Ool00`00Oomoo`0<Ool2003oOolfOol0009oo`03001oogoo00eoo`03001oogoo00Moo`03001o
ogoo00=oo`<000Yoo`800?moocQoo`000Woo00<007ooOol03Goo00<007ooOol01goo00<007ooOol0
0goo00<007ooOol027oo0P00ogoo>Woo0002Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool40006Ool0
0`00Oomoo`05Ool3003oOollOol0009oo`03001oogoo00ioo`03001oogoo009oo`03001oogoo00Mo
o`03001oogoo009oo`<00?moocmoo`000Woo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001o
ogoo00Moo`03001oo`0000800?mood9oo`000`0037oo1@0017oo10001Woo0P00ogooAGoo000ROol0
0`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol0
0`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomo
o`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4
Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4
Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000GOol50006Ool00`00Oomoo`3oOom4
Ool001Qoo`04001oogoo0006Ool00`00Oomoo`3oOom4Ool001Uoo`03001oogoo00Ioo`03001oogoo
0?moodAoo`006Woo00<007ooOol01Goo0`00ogooA7oo000KOol00`00Oomoo`3oOom;Ool001]oo`03
001oogoo0?mood]oo`005goo00D007ooOomoo`000?moodeoo`0067oo0`00ogooCWoo003oOomYOol0
09Eoo`8000]oo`03001oogoo00aoo`8000Eoo`03001oogoo0:eoo`00UGoo00<007ooOol02Woo0P00
3Woo00<007ooOol00goo0P00[Woo002:Ool50006Ool01000Oomoogoo0P000Woo0P0017oo00<007oo
Ool017oo0`001Goo00<007ooOol017oo00<007ooOol037oo0`002goo0`001Woo0P001Goo1000OWoo
002<Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomoo`001Goo0P0017oo00D007ooOomoo`00
00Aoo`03001oogoo00Aoo`8000aoo`05001oogooOol00002Ool600000goo001oo`02Ool00`00Oomo
o`03Ool20009Ool00`00Oomoo`1kOol008aoo`03001oogoo00Ioo`03001oogoo00=oo`8000aoo`03
001oogoo00Ioo`03001oogoo019oo`03001oogoo00]oo`05001oogooOol0000@Ool00`00Oomoo`1k
Ool008aoo`03001oogoo00Ioo`03001oogoo00=oo`8000aoo`03001oogoo00Ioo`03001oogoo019o
o`03001oogoo00Aoo`H00003Ool007oo009oo`03001oogoo00ioo`03001oogoo07]oo`00S7oo00<0
07ooOol01Woo00<007ooOol00Woo00@007ooOol000]oo`03001oogoo00Ioo`03001oogoo019oo`03
001oogoo00aoo`<000eoo`@007ioo`00RGoo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo
Ool20002Ool20008Ool60005Ool00`00Oomoo`0@Ool6000:Ool01@00Oomoogoo000037oo00<007oo
Ool0Ogoo0029Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol04Goo00<007ooOol01Woo
00<007ooOol04Woo00<007ooOol02goo00D007ooOomoo`0000aoo`03001oogoo07moo`00RGoo1`00
1Goo0P004Woo00<007ooOol01Goo0P0057oo00<007ooOol037oo0`003Goo1000OWoo003oOomYOol0
0?moofUoo`00ogooJGoo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9.) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .43637 m
.01975 .44736 L
.04057 .45557 L
.0515 .45864 L
.06168 .4608 L
.06753 .46175 L
.07286 .46245 L
.0758 .46277 L
.079 .46306 L
.0818 .46326 L
.08481 .46344 L
.08748 .46356 L
.08993 .46364 L
.0911 .46367 L
.09238 .46369 L
.0936 .46371 L
.09472 .46371 L
.09541 .46371 L
.09615 .46371 L
.09749 .4637 L
.0988 .46369 L
.1 .46366 L
.10131 .46363 L
.10274 .46359 L
.10564 .46347 L
.10852 .46332 L
.11115 .46316 L
.11706 .46268 L
.12772 .46148 L
.13813 .45991 L
.14776 .45816 L
.16956 .45324 L
.21079 .44117 L
.25042 .42747 L
.29264 .41193 L
.33326 .39702 L
.37646 .38198 L
.41806 .36877 L
.45808 .35752 L
.50066 .3472 L
.54166 .33891 L
.58523 .33175 L
.62722 .32634 L
.66761 .32232 L
.71057 .31913 L
.73194 .3179 L
.75194 .31693 L
.79172 .31545 L
.81303 .31487 L
.83249 .31443 L
Mistroke
.85415 .31405 L
.87424 .31377 L
.89369 .31356 L
.9144 .31338 L
.92522 .31331 L
.93692 .31325 L
.94703 .31321 L
.95811 .31317 L
.96866 .31314 L
.97371 .31313 L
.97849 .31313 L
.98393 .31312 L
.98888 .31311 L
.99165 .31311 L
.99421 .31311 L
.99555 .31311 L
.99632 .31311 L
.99702 .31311 L
.99776 .31311 L
.99856 .31311 L
.99926 .31311 L
1 .31311 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
00<000Ioo`8000Aoo`D000Aoo`@000Ioo`03001oogoo0?moodAoo`000goo00<007ooOol00goo0P00
1Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007ooOol02goo
00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0<Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03001oogoo00eoo`03001oogoo009oo`@0
00Ioo`03001oogoo0?moodAoo`000goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol0ogooA7oo0003Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol01goo
00<007ooOol0ogooA7oo0003000=Ool30005Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`0027oo0`001Woo0P00
1Goo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol0
0goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000047oo00<007ooOol00goo0`00ogooA7oo
0007Ool01@00Oomoogoo000047oo00<007ooOol00goo00<007ooOol0ogooA7oo0007Ool01@00Oomo
ogoo000037oo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol0
1goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol01goo00<007ooOol0
ogooA7oo0008Ool3000=Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol0
0`00Oomoo`3oOom4Ool000<000Ioo`8000Ioo`03001oogoo00Aoo`@000Ioo`03001oogoo0?moodAo
o`000goo00<007ooOol00goo0P001Woo00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogoo
A7oo0003Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03
001oogoo00aoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007oo
Ool037oo00<007ooOol00goo10001Woo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0=Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000=oo`03001oogoo00Uoo`05001oogoo
Ool00004Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000<000aoo`D000Aoo`@000Ioo`800?mo
odEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`0067oo1@001Goo00<0
07ooOol0ogooA7oo000JOol00`00Oomoo`05Ool00`00Oomoo`3oOom4Ool001Yoo`03001oogoo00Eo
o`03001oogoo0?moodAoo`006Woo00<007ooOol01Goo0`00ogooA7oo000JOol00`00Oomoo`05Ool0
0`00Oomoo`3mOola000EOol001Yoo`03001oogoo00Eoo`03001oogoo0=iooal004Ioo`006Woo00<0
07ooOol01Goo00<007ooOol0cgoo3`00IGoo000HOol30007Ool00`00Oomoo`32Ool=001dOol0029o
o`800;Uoo`X0085oo`008Woo00<007ooOol0/Woo1P00Rgoo000ROol00`00Oomoo`2/Ool6002AOol0
029oo`03001oogoo0:Eoo`L009Moo`008Woo0P00X7oo1P00WWoo000ROol00`00Oomoo`2KOol4002T
Ool0029oo`03001oogoo09Moo`@00:Qoo`008Woo00<007ooOol0Tgoo1000[7oo000ROol00`00Oomo
o`2>Ool5002`Ool0029oo`8008]oo`@00;Eoo`008Woo00<007ooOol0QWoo1000^Goo000ROol00`00
Oomoo`22Ool4002mOol0029oo`03001oogoo07ioo`@00<5oo`008Woo00<007ooOol0NWoo1000aGoo
000ROol2001hOol30039Ool0029oo`03001oogoo07Aoo`<00<aoo`001@0017oo0P0017oo1@0017oo
10001Woo00<007ooOol0LGoo0`00cgoo0002Ool00`00Oomoo`04Ool20005Ool01000Oomoo`0027oo
00<007ooOol00goo00<007ooOol0KWoo0`00dWoo0002Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool0
0`00Oomoo`03Ool3001[Ool3003EOol0009oo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo
00=oo`03001oogoo06Qoo`<00=Qoo`000Woo00<007ooOol03Woo00<007ooOol00Woo10001Woo00<0
07ooOol0IWoo0P00fgoo0002Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00
Oomoo`1SOol3003MOol0009oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00Oomoo`07Ool0
0`00Oomoo`1QOol2003POol000<000eoo`<000Eoo`@000Ioo`8005moo`<00>9oo`008Woo00<007oo
Ool0Fgoo0`00iGoo000ROol00`00Oomoo`1HOol3003XOol0029oo`03001oogoo05Eoo`<00>]oo`00
8Woo00<007ooOol0DWoo0`00kWoo000ROol2001@Ool3003aOol0029oo`03001oogoo04eoo`800?Ao
o`008Woo00<007ooOol0BWoo0`00mWoo000ROol00`00Oomoo`18Ool2003iOol0029oo`8004Ioo`<0
0?]oo`008Woo00<007ooOol0@Woo0`00oWoo000ROol20010Ool3003oOol2Ool0029oo`04001oo`00
000kOol3003oOol5Ool0029oo`04001oogooOol2000fOol3003oOol8Ool0029oo`8000Aoo`<0031o
o`<00?moo`]oo`008Woo00<007ooOol01Woo0`00:Woo0`00ogoo3Woo0008Ool50004Ool20005Ool4
0006Ool00`00Oomoo`09Ool3000ROol5003oOolAOol000Yoo`03001oogoo00Aoo`8000Uoo`03001o
ogoo00=oo`03001oogoo00aoo`@001Uoo`D00?mooaIoo`002Woo00<007ooOol03goo00<007ooOol0
0goo00<007ooOol047oo10003goo1P00ogoo6goo000:Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool3
000DOol?003oOolQOol000Yoo`03001oogoo00]oo`@000Ioo`03001oogoo0?moodAoo`002Woo00<0
07ooOol02goo00<007ooOol01goo00<007ooOol0ogooA7oo000:Ool00`00Oomoo`0;Ool00`00Oomo
o`07Ool00`00Oomoo`3oOom4Ool000Qoo`<000eoo`@000Ioo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol0
0`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol0
0`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo00050004Ool20006
Ool00`00Oomoo`04Ool40006Ool00`00Oomoo`3oOom4Ool0009oo`03001oogoo00Aoo`8000Ioo`03
001oogoo00Qoo`03001oogoo00=oo`03001oogoo0?moodAoo`000Woo00<007ooOol03Goo00<007oo
Ool01goo00<007ooOol00goo0`00ogooA7oo0002Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00
Oomoo`03Ool00`00Oomoo`3oOom4Ool0009oo`03001oogoo00eoo`03001oogoo00=oo`@000Ioo`03
001oogoo0?moodAoo`000Woo00<007ooOol03Woo00<007ooOol00Woo00<007ooOol01goo00<007oo
Ool0ogooA7oo0002Ool00`00Oomoo`0:Ool01@00Oomoogoo000017oo00<007ooOol01goo00<007oo
Ool0ogooA7oo0003000<Ool50004Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo
000ROol00`00Oomoo`3oOom4Ool001Moo`D000Ioo`03001oogoo0?moodAoo`0067oo00@007ooOol0
00Ioo`03001oogoo0?moodAoo`006Goo00<007ooOol01Woo00<007ooOol0ogooA7oo000JOol00`00
Oomoo`05Ool3003oOom4Ool001]oo`03001oogoo0?mood]oo`006goo00<007ooOol0ogooBgoo000G
Ool01@00Oomoogoo0000ogooCGoo000HOol3003oOom>Ool00?moofUoo`00V7oo0P002goo00<007oo
Ool037oo0P001Woo00<007ooOol0ZGoo002HOol00`00Oomoo`0:Ool2000>Ool00`00Oomoo`04Ool2
002ZOol008ioo`D000Eoo`03001oogoo009oo`80009oo`8000=oo`03001oogoo00Eoo`<000Aoo`03
001oogoo00Eoo`03001oogoo00aoo`<000Yoo`<000Moo`8008=oo`00T7oo00<007ooOol01Goo00<0
07ooOol00goo00@007ooOol000Aoo`8000Eoo`05001oogooOol00003Ool00`00Oomoo`05Ool2000<
Ool01P00Oomoogoo001oo`H000Eoo`03001oogoo00Aoo`8008=oo`00T7oo00<007ooOol01Goo00<0
07ooOol017oo0P0037oo00<007ooOol01Goo00<007ooOol04goo00<007ooOol03goo00<007ooOol0
R7oo002@Ool00`00Oomoo`05Ool00`00Oomoo`04Ool2000<Ool00`00Oomoo`05Ool00`00Oomoo`0C
Ool00`00Oomoo`03Ool60003Ool4002:Ool0091oo`03001oogoo00Eoo`03001oogoo00=oo`04001o
ogoo000;Ool00`00Oomoo`05Ool00`00Oomoo`0COol00`00Oomoo`0;Ool01@00Oomoogoo0000RWoo
002=Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol00Woo0P000Woo0P0027oo1P0017oo
00<007ooOol04Goo1P002Woo00D007ooOomoo`0008Yoo`00SGoo00@007ooOol0009oo`03001oogoo
009oo`03001oogoo019oo`03001oogoo00Eoo`03001oogoo01=oo`03001oogoo00]oo`05001oogoo
Ool0002:Ool008eoo`L000Aoo`8001=oo`03001oogoo00Aoo`8001Eoo`03001oogoo00aoo`<008]o
o`00ogooJGoo003oOomYOol00?moofUoo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9.5) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .28579 m
.01975 .31057 L
.04057 .33283 L
.06347 .35314 L
.08481 .36849 L
.10535 .38033 L
.12477 .38914 L
.14621 .39648 L
.16571 .40123 L
.17589 .40305 L
.18668 .40452 L
.1959 .40545 L
.20114 .40584 L
.20605 .40612 L
.20857 .40624 L
.21126 .40634 L
.21421 .40643 L
.21694 .40648 L
.21829 .4065 L
.219 .40651 L
.21974 .40652 L
.22112 .40653 L
.22238 .40653 L
.22359 .40653 L
.22473 .40653 L
.22597 .40652 L
.2273 .4065 L
.2286 .40648 L
.22981 .40646 L
.23253 .4064 L
.23493 .40633 L
.23748 .40624 L
.24676 .40578 L
.25189 .40543 L
.25659 .40507 L
.2672 .40408 L
.28639 .40177 L
.328 .39498 L
.36801 .38693 L
.4106 .37761 L
.4516 .36854 L
.49517 .35928 L
.53715 .35106 L
.57754 .34398 L
.62051 .33743 L
.66188 .33209 L
.70166 .32781 L
.74402 .32411 L
.78478 .3213 L
.82812 .31903 L
Mistroke
.84979 .31813 L
.86987 .31743 L
.89056 .31683 L
.91003 .31637 L
.93162 .31597 L
.95117 .31571 L
.96145 .31561 L
.96706 .31557 L
.9723 .31553 L
.97714 .3155 L
.98156 .31548 L
.98646 .31547 L
.98915 .31546 L
.99171 .31545 L
.9938 .31545 L
.99485 .31545 L
.99602 .31545 L
.99701 .31545 L
.99807 .31545 L
.99908 .31545 L
1 .31544 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
00<000Ioo`8000Aoo`D000Aoo`@000Ioo`03001oogoo0?moodAoo`000goo00<007ooOol00goo0P00
1Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007ooOol02goo
00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0<Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03001oogoo00eoo`03001oogoo009oo`@0
00Ioo`03001oogoo0?moodAoo`000goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol0ogooA7oo0003Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol01goo
00<007ooOol0ogooA7oo0003000=Ool30005Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`0027oo0`001Woo0P00
1Goo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol0
0goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000047oo00<007ooOol00goo0`00ogooA7oo
0007Ool01@00Oomoogoo000047oo00<007ooOol00goo00<007ooOol0ogooA7oo0007Ool01@00Oomo
ogoo000037oo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol0
1goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol01goo00<007ooOol0
ogooA7oo0008Ool3000=Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol0
0`00Oomoo`3oOom4Ool000<000Ioo`8000Ioo`03001oogoo00Aoo`@000Ioo`03001oogoo0?moodAo
o`000goo00<007ooOol00goo0P001Woo00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogoo
A7oo0003Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03
001oogoo00aoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007oo
Ool037oo00<007ooOol00goo10001Woo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0=Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000=oo`03001oogoo00Uoo`05001oogoo
Ool00004Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000<000aoo`D000Aoo`@000Ioo`800?mo
odEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oo`000?moodAoo`0067oo1@001Goo00@0
07ooOol00?mood=oo`006Woo00<007ooOol01Goo00D007ooOomoo`000?mood9oo`006Woo00<007oo
Ool01Goo00<007ooOol00Woo00<007ooOol0ogoo?goo000JOol00`00Oomoo`05Ool30003Ool00`00
Oomoo`3oOolnOol001Yoo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo0?moocioo`006Woo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol0ngoo;0005Goo000JOol00`00Oomoo`05Ool0
0`00Oomoo`05Ool00`00Oomoo`3ZOol@0011Ool001Qoo`<000Moo`03001oogoo00Ioo`03001oogoo
0=aoo`d0055oo`008Woo0P0027oo00<007ooOol0cgoo3000GWoo000ROol00`00Oomoo`08Ool00`00
Oomoo`31Ool=001ZOol0029oo`03001oogoo00Uoo`800;Qoo`T007Moo`008Woo00<007ooOol02goo
00<007ooOol0[Woo1`00P7oo000ROol2000=Ool00`00Oomoo`2WOol60027Ool0029oo`03001oogoo
00eoo`03001oogoo09moo`L008eoo`008Woo00<007ooOol03Woo00<007ooOol0V7oo1P00U7oo000R
Ool00`00Oomoo`0?Ool00`00Oomoo`2AOol6002JOol0029oo`03001oogoo011oo`8008]oo`H00:1o
o`008Woo0P004goo00<007ooOol0PGoo1`00YWoo000ROol00`00Oomoo`0COol2001lOol5002]Ool0
029oo`03001oogoo01Eoo`03001oogoo07Aoo`D00;9oo`008Woo00<007ooOol05Woo00<007ooOol0
Kgoo1000]goo000ROol00`00Oomoo`0GOol2001[Ool4002kOol0029oo`8001Yoo`03001oogoo06Ao
o`@00;moo`008Woo00<007ooOol06Woo0P00H7oo1000`goo00050004Ool20004Ool50004Ool40006
Ool00`00Oomoo`0LOol00`00Oomoo`1IOol40037Ool0009oo`03001oogoo00Aoo`8000Eoo`04001o
ogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`0MOol3001COol5003;Ool0009oo`03001oogoo00ao
o`03001oogoo00Qoo`03001oogoo00=oo`<0021oo`<004aoo`@00=1oo`000Woo00<007ooOol03Goo
00<007ooOol01goo00<007ooOol00goo00<007ooOol08goo0`00A7oo1@00e7oo0002Ool00`00Oomo
o`0>Ool00`00Oomoo`02Ool40006Ool00`00Oomoo`0VOol3000kOol6003IOol0009oo`03001oogoo
00ioo`03001oogoo009oo`03001oogoo00Moo`03001oogoo02Uoo`<0039oo`H00=moo`000Woo00<0
07ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo00Moo`03001oogoo02aoo`<002Qoo`L00>Eo
o`000`003Goo0`001Goo10001Woo0P00<7oo1`006goo1P00k7oo000ROol00`00Oomoo`0fOol90005
Ool=003bOol0029oo`03001oogoo03moo`D00?moo`008Woo00<007ooOol0ogooA7oo000ROol00`00
Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0
029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo0008Ool50004Ool20005Ool40006Ool00`00
Oomoo`3oOom4Ool000Yoo`03001oogoo00Aoo`8000Uoo`03001oogoo00=oo`03001oogoo0?moodAo
o`002Woo00<007ooOol03goo00<007ooOol00goo00<007ooOol0ogooA7oo000:Ool00`00Oomoo`0?
Ool00`00Oomoo`03Ool3003oOom4Ool000Yoo`03001oogoo00]oo`@000Ioo`03001oogoo0?moodAo
o`002Woo00<007ooOol02goo00<007ooOol01goo00<007ooOol0ogooA7oo000:Ool00`00Oomoo`0;
Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000Qoo`<000eoo`@000Ioo`03001oogoo0?moodAo
o`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo
00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007oo
Ool0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogoo
AGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo0005
0004Ool20006Ool00`00Oomoo`04Ool40006Ool00`00Oomoo`3oOom4Ool0009oo`03001oogoo00Ao
o`8000Ioo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo0?moodAoo`000Woo00<007ooOol0
3Goo00<007ooOol01goo00<007ooOol00goo0`00ogooA7oo0002Ool00`00Oomoo`0=Ool00`00Oomo
o`07Ool00`00Oomoo`03Ool00`00Oomoo`3oOom4Ool0009oo`03001oogoo00eoo`03001oogoo00=o
o`@000Ioo`03001oogoo0?moodAoo`000Woo00<007ooOol03Woo00<007ooOol00Woo00<007ooOol0
1goo00<007ooOol0ogooA7oo0002Ool00`00Oomoo`0:Ool01@00Oomoogoo000017oo00<007ooOol0
1goo00<007ooOol0ogooA7oo0003000<Ool50004Ool40006Ool2003oOom5Ool0029oo`03001oogoo
0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo
0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAo
o`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo
00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo
0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool001Moo`D000Ioo`03001oogoo0?moodAoo`0067oo
00@007ooOol000Ioo`03001oogoo0?moodAoo`006Goo00<007ooOol01Woo00<007ooOol0ogooA7oo
000JOol00`00Oomoo`05Ool3003oOom4Ool001]oo`03001oogoo0?mood]oo`006goo00<007ooOol0
ogooBgoo000GOol01@00Oomoogoo0000ogooCGoo000HOol3003oOom>Ool00?moofUoo`00UGoo0P00
2goo00<007ooOol037oo0P001Goo00<007ooOol0[Goo002EOol00`00Oomoo`0:Ool2000>Ool00`00
Oomoo`03Ool2002^Ool008Yoo`D000Ioo`04001oogooOol20002Ool20004Ool00`00Oomoo`04Ool3
0005Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool3000:Ool30007Ool20005Ool4001nOol008aoo`03
001oogoo00Ioo`03001oogoo009oo`04001oogoo0005Ool20004Ool01@00Oomoogoo000017oo00<0
07ooOol017oo0P0037oo00D007ooOomoo`00009oo`H000Aoo`03001oogoo00Aoo`8000Uoo`03001o
ogoo07]oo`00S7oo00<007ooOol01Woo00<007ooOol00goo0P0037oo00<007ooOol01Woo00<007oo
Ool04Woo00<007ooOol03goo00<007ooOol03Woo00<007ooOol0Ngoo002<Ool00`00Oomoo`06Ool0
0`00Oomoo`03Ool2000<Ool00`00Oomoo`06Ool00`00Oomoo`0BOol00`00Oomoo`04Ool60002Ool4
000@Ool00`00Oomoo`1kOol008aoo`03001oogoo00Ioo`03001oogoo009oo`04001oogoo000;Ool0
0`00Oomoo`06Ool00`00Oomoo`0BOol00`00Oomoo`0;Ool01@00Oomoogoo000037oo1000OWoo0029
Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOomoo`80009oo`8000Qoo`H000Eoo`03001o
ogoo011oo`H000Yoo`05001oogooOol0000<Ool00`00Oomoo`1oOol008Uoo`04001oogoo0002Ool0
0`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`06Ool00`00Oomoo`0BOol00`00Oomoo`0;Ool0
1@00Oomoogoo000037oo00<007ooOol0Ogoo0029Ool70005Ool2000BOol00`00Oomoo`05Ool2000D
Ool00`00Oomoo`0<Ool3000=Ool4001nOol00?moofUoo`00ogooJGoo003oOomYOol00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10.) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .14091 m
.04057 .20449 L
.08481 .25946 L
.12636 .29884 L
.16632 .32699 L
.18687 .33822 L
.20885 .34807 L
.22972 .35555 L
.25237 .36184 L
.26295 .36419 L
.27417 .3663 L
.2943 .36918 L
.30418 .37021 L
.31481 .37107 L
.31995 .37139 L
.32484 .37164 L
.32957 .37184 L
.33402 .37198 L
.33656 .37205 L
.3393 .37211 L
.3418 .37215 L
.34409 .37218 L
.34538 .37219 L
.34658 .3722 L
.34789 .3722 L
.34863 .3722 L
.34931 .37221 L
.35066 .37221 L
.35143 .3722 L
.35214 .3722 L
.35344 .3722 L
.35482 .37219 L
.3571 .37216 L
.35955 .37213 L
.364 .37204 L
.36928 .3719 L
.37413 .37174 L
.38442 .37129 L
.394 .37075 L
.41573 .36915 L
.45673 .36504 L
.5003 .35968 L
.54228 .35408 L
.58267 .34865 L
.62564 .34311 L
.66701 .3382 L
.70679 .33397 L
.74915 .33007 L
.78991 .32692 L
.83325 .32422 L
Mistroke
.875 .32224 L
.91516 .32089 L
.93586 .3204 L
.94645 .3202 L
.95789 .32003 L
.96339 .31996 L
.9692 .3199 L
.97458 .31985 L
.97959 .31981 L
.98429 .31978 L
.9867 .31977 L
.98933 .31976 L
.99082 .31976 L
.9922 .31976 L
.99349 .31975 L
.99491 .31975 L
.99619 .31975 L
.99738 .31975 L
.99864 .31975 L
1 .31975 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
00<000Ioo`8000Aoo`D000Aoo`@000Ioo`03001oogoo0?moodAoo`000goo00<007ooOol00goo0P00
1Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007ooOol02goo
00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0<Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03001oogoo00eoo`03001oogoo009oo`@0
00Ioo`03001oogoo0?moodAoo`000goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol0ogooA7oo0003Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol01goo
00<007ooOol0ogooA7oo0003000=Ool30005Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`0027oo0`001Woo0P00
1Goo10001Woo0P00ogooAGoo0007Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol00goo00<0
07oo0000ogooA7oo0007Ool01@00Oomoogoo000047oo00<007ooOol00goo0`00ogooA7oo0007Ool0
1@00Oomoogoo000047oo00<007ooOol00goo00@007ooOol00?mood=oo`001goo00D007ooOomoo`00
00aoo`@000Ioo`04001oogoo003oOom3Ool000Moo`05001oogooOol0000<Ool00`00Oomoo`07Ool0
1@00Oomoogoo0000ogoo@Woo0007Ool01@00Oomoogoo000037oo00<007ooOol01goo00<007ooOol0
0Woo00<007ooOol0ogoo?goo0008Ool3000=Ool40006Ool20003Ool00`00Oomoo`3oOoloOol0029o
o`03001oogoo00=oo`03001oogoo0?moocioo`008Woo00<007ooOol017oo00<007ooOol0ogoo?Goo
000ROol00`00Oomoo`04Ool00`00Oomoo`3oOolmOol0029oo`8000Ioo`03001oogoo0?moocaoo`00
8Woo00<007ooOol01Woo00<007ooOol0ogoo>goo000ROol00`00Oomoo`06Ool00`00Oomoo`3oOolk
Ool0029oo`03001oogoo00Moo`03001oogoo0?moocYoo`008Woo00<007ooOol01goo00<007ooOol0
ogoo>Woo000ROol20009Ool00`00Oomoo`3oOoliOol0029oo`03001oogoo00Uoo`03001oogoo0?mo
ocQoo`008Woo00<007ooOol02Goo00<007ooOol0ogoo>7oo000ROol00`00Oomoo`0:Ool00`00Oomo
o`3oOolgOol0029oo`03001oogoo00]oo`03001oogoo0?moocIoo`008Woo0P003Goo00<007ooOol0
ogoo=Goo000ROol00`00Oomoo`0=Ool00`00Oomoo`3oOoldOol000<000Ioo`8000Ioo`03001oogoo
00Aoo`@000Ioo`03001oogoo00ioo`03001oogoo0?mooc=oo`000goo00<007ooOol00goo0P001Woo
00<007ooOol027oo00<007ooOol00goo00<007ooOol03Woo00<007ooOol0ogoo<goo0003Ool00`00
Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`03Ool3000?Ool00`00Oomoo`3oOolbOol000=oo`03
001oogoo00aoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo011oo`03001oogoo0?mooc5o
o`000goo00<007ooOol037oo00<007ooOol00goo10001Woo00<007ooOol04Goo00<007ooOol0ogoo
<7oo0003Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0BOol00`00
Oomoo`3oOol_Ool000=oo`03001oogoo00Uoo`05001oogooOol00004Ool00`00Oomoo`07Ool00`00
Oomoo`0BOol00`00Oomoo`3oOol_Ool000<000aoo`D000Aoo`@000Ioo`8001Aoo`03001oogoo0?mo
obioo`008Woo00<007ooOol057oo00<007ooOol0ogoo;Goo000ROol00`00Oomoo`0EOol00`00Oomo
o`3oOol/Ool0029oo`03001oogoo01Ioo`03001oogoo0?moob]oo`008Woo00<007ooOol05goo00<0
07ooOol0ogoo:Woo000ROol2000IOol00`00Oomoo`3oOolYOol0029oo`03001oogoo01Uoo`03001o
ogoo0?moobQoo`008Woo00<007ooOol06Woo00<007ooOol0ogoo9goo000ROol00`00Oomoo`0KOol0
0`00Oomoo`3oOolVOol0029oo`03001oogoo01aoo`03001oogoo0?moobEoo`008Woo0P007Woo00<0
07ooOol0ogoo97oo000ROol00`00Oomoo`0NOol00`00Oomoo`3oOolSOol0029oo`03001oogoo01mo
o`03001oogoo0?moob9oo`008Woo00<007ooOol087oo00<007ooOol0ogoo8Goo000ROol2000ROol0
0`00Oomoo`3oOolPOol0029oo`03001oogoo029oo`03001oogoo0?mooamoo`0067oo1@001Goo00<0
07ooOol08goo0P00ogoo7goo000JOol00`00Oomoo`05Ool00`00Oomoo`0UOol00`00Oomoo`3oOolL
Ool001Yoo`03001oogoo00Eoo`03001oogoo02Ioo`800?mooaaoo`006Woo00<007ooOol01Goo0`00
:7oo0P00ogoo6Woo000JOol00`00Oomoo`05Ool00`00Oomoo`0ZOol00`00Oomoo`3oOolGOol001Yo
o`03001oogoo00Eoo`03001oogoo02]oo`800?mooaMoo`006Woo00<007ooOol01Goo00<007ooOol0
;Goo0P00igoo60005Goo000HOol30007Ool00`00Oomoo`0_Ool00`00Oomoo`3?OolE000]Ool0029o
o`80035oo`800;EooaX0049oo`008Woo00<007ooOol0<Woo00<007ooOol0Z7oo2P00G7oo000ROol0
0`00Oomoo`0cOol2002ROol6001VOol0029oo`03001oogoo03Eoo`03001oogoo09Ioo`T006aoo`00
8Woo0P00=goo0P00RWoo3000MGoo000ROol00`00Oomoo`0hOol3001mOol:0021Ool0029oo`03001o
ogoo03]oo`8007Aoo`L008]oo`008Woo00<007ooOol0?Goo0`00Jgoo1P00TWoo000ROol00`00Oomo
o`10Ool3001ROol6002HOol0029oo`8004Aoo`<005Ioo`T009ioo`008Woo00<007ooOol0AWoo0`00
BGoo2P00Ygoo000ROol00`00Oomoo`19Ool4000nOol7002aOol0029oo`03001oogoo04eoo`L002io
o`T00;Qoo`008Woo00<007ooOol0E7oo1@007goo2P00`Goo000ROol2001JOolO003;Ool0029oo`03
001oogoo0?moodAoo`001@0017oo0P0017oo1@0017oo10001Woo00<007ooOol0ogooA7oo0002Ool0
0`00Oomoo`04Ool20005Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0ogooA7oo0002
Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`03Ool3003oOom4Ool0009oo`03001oogoo
00eoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo0?moodAoo`000Woo00<007ooOol03Woo
00<007ooOol00Woo10001Woo00<007ooOol0ogooA7oo0002Ool00`00Oomoo`0>Ool00`00Oomoo`02
Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool0009oo`03001oogoo00Yoo`05001oogooOol00004
Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000<000eoo`<000Eoo`@000Ioo`800?moodEoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`0027oo1@0017oo0P001Goo1000
1Woo00<007ooOol0ogooA7oo000:Ool00`00Oomoo`04Ool20009Ool00`00Oomoo`03Ool00`00Oomo
o`3oOom4Ool000Yoo`03001oogoo00moo`03001oogoo00=oo`03001oogoo0?moodAoo`002Woo00<0
07ooOol03goo00<007ooOol00goo0`00ogooA7oo000:Ool00`00Oomoo`0;Ool40006Ool00`00Oomo
o`3oOom4Ool000Yoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo0?moodAoo`002Woo00<0
07ooOol02goo00<007ooOol01goo00<007ooOol0ogooA7oo0008Ool3000=Ool40006Ool00`00Oomo
o`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4
Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029o
o`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029o
o`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001o
ogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`001@0017oo0P001Woo00<007ooOol017oo10001Woo00<007ooOol0ogooA7oo0002Ool00`00
Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`3oOom4Ool0009oo`03
001oogoo00eoo`03001oogoo00Moo`03001oogoo00=oo`<00?moodAoo`000Woo00<007ooOol03Goo
00<007ooOol01goo00<007ooOol00goo00<007ooOol0ogooA7oo0002Ool00`00Oomoo`0=Ool00`00
Oomoo`03Ool40006Ool00`00Oomoo`3oOom4Ool0009oo`03001oogoo00ioo`03001oogoo009oo`03
001oogoo00Moo`03001oogoo0?moodAoo`000Woo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03
001oogoo00Moo`03001oogoo0?moodAoo`000`0037oo1@0017oo10001Woo0P00ogooAGoo000ROol0
0`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol0
0`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomo
o`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4
Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4
Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000GOol50006Ool00`00Oomoo`3oOom4
Ool001Qoo`04001oogoo0006Ool00`00Oomoo`3oOom4Ool001Uoo`03001oogoo00Ioo`03001oogoo
0?moodAoo`006Woo00<007ooOol01Goo0`00ogooA7oo000KOol00`00Oomoo`3oOom;Ool001]oo`03
001oogoo0?mood]oo`005goo00D007ooOomoo`000?moodeoo`0067oo0`00ogooCWoo003oOomYOol0
09Eoo`8000]oo`03001oogoo00aoo`8000Eoo`03001oogoo0:eoo`00UGoo00<007ooOol02Woo0P00
3Woo00<007ooOol00goo0P00[Woo002:Ool50006Ool01000Oomoogoo0P000Woo0P0017oo00<007oo
Ool017oo0`001Goo00<007ooOol017oo00<007ooOol037oo0`002goo1@000goo0`001Woo0P00Ogoo
002<Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomoo`001Goo0P0017oo00D007ooOomoo`00
00Aoo`03001oogoo00Aoo`8000aoo`05001oogooOol00002Ool60004Ool00`00Oomoo`02Ool01@00
Oomoogoo00001Goo0P00Ogoo002<Ool00`00Oomoo`06Ool00`00Oomoo`03Ool2000<Ool00`00Oomo
o`06Ool00`00Oomoo`0BOol00`00Oomoo`0>Ool00`00Oomoo`02Ool01@00Oomoogoo0000QWoo002<
Ool00`00Oomoo`06Ool00`00Oomoo`03Ool2000<Ool00`00Oomoo`06Ool00`00Oomoo`0BOol00`00
Oomoo`04Ool60004Ool00`00Oomoo`02Ool01@00Oomoogoo0000QWoo002<Ool00`00Oomoo`06Ool0
0`00Oomoo`02Ool01000Oomoo`002goo00<007ooOol01Woo00<007ooOol04Woo00<007ooOol03Woo
00<007ooOol00Woo00D007ooOomoo`0008Ioo`00RGoo00@007ooOol0009oo`03001oogoo00=oo`04
001oogooOol20002Ool20008Ool60005Ool00`00Oomoo`0@Ool6000=Ool00`00Oomoo`02Ool01@00
Oomoogoo0000QWoo0029Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol04Goo00<007oo
Ool01Woo00<007ooOol04Woo00<007ooOol03Woo00<007ooOol00Woo00D007ooOomoo`0008Ioo`00
RGoo1`001Goo0P004Woo00<007ooOol01Goo0P0057oo00<007ooOol037oo0`001Goo0`00Qgoo003o
OomYOol00?moofUoo`00ogooJGoo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10.5) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .03718 m
.04057 .10197 L
.08481 .16303 L
.12636 .21109 L
.16632 .24913 L
.20885 .28145 L
.2498 .30541 L
.27066 .31521 L
.29331 .32418 L
.33524 .33676 L
.35607 .34129 L
.37815 .34503 L
.39866 .34763 L
.41788 .34938 L
.42878 .35011 L
.43914 .35064 L
.44844 .351 L
.4537 .35115 L
.45859 .35126 L
.46392 .35135 L
.46692 .35139 L
.46835 .3514 L
.46968 .35141 L
.47095 .35142 L
.47211 .35143 L
.47339 .35143 L
.47477 .35143 L
.47609 .35144 L
.47683 .35144 L
.47752 .35144 L
.47879 .35143 L
.48013 .35143 L
.48134 .35142 L
.48244 .35142 L
.48492 .3514 L
.48712 .35138 L
.48942 .35136 L
.49432 .35128 L
.49967 .35118 L
.51046 .3509 L
.52026 .35057 L
.54226 .3496 L
.58424 .34707 L
.62463 .3441 L
.6676 .34069 L
.70897 .33742 L
.74875 .33445 L
.79111 .33162 L
.83187 .32929 L
.87521 .32731 L
Mistroke
.89688 .32653 L
.91696 .32594 L
.93641 .32548 L
.95712 .32513 L
.96774 .325 L
.97332 .32495 L
.97921 .3249 L
.98438 .32487 L
.98731 .32486 L
.99005 .32485 L
.99256 .32484 L
.99485 .32484 L
.99612 .32484 L
.9975 .32484 L
.9988 .32483 L
1 .32483 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol3003oOom4Ool0
029oo`03001oo`000?moodAoo`008Woo00@007ooOol00?mood=oo`008Woo00@007ooOol00?mood=o
o`008Woo00D007ooOomoo`000?mood9oo`008Woo0P000goo00<007ooOol0ogoo?goo000ROol00`00
Oomoo`02Ool00`00Oomoo`3oOoloOol000<000Ioo`8000Aoo`D000Aoo`@000Ioo`03001oogoo00=o
o`03001oogoo0?moocioo`000goo00<007ooOol00goo0P001Goo00@007ooOol000Qoo`03001oogoo
00=oo`03001oogoo00=oo`03001oogoo0?moocioo`000goo00<007ooOol02goo00<007ooOol027oo
00<007ooOol00goo00<007ooOol017oo00<007ooOol0ogoo?Goo0003Ool00`00Oomoo`0<Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool30005Ool00`00Oomoo`3oOollOol000=oo`03001oogoo00eoo`03
001oogoo009oo`@000Ioo`03001oogoo00Eoo`03001oogoo0?moocaoo`000goo00<007ooOol03Goo
00<007ooOol00Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol0ogoo>goo0003Ool00`00
Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol01goo00<007ooOol01Woo00<007ooOol0ogoo
>goo0003000=Ool30005Ool40006Ool20008Ool00`00Oomoo`3oOoljOol0029oo`03001oogoo00Qo
o`03001oogoo0?moocUoo`008Woo00<007ooOol027oo00<007ooOol0ogoo>Goo000ROol00`00Oomo
o`09Ool00`00Oomoo`3oOolhOol0029oo`03001oogoo00Uoo`03001oogoo0?moocQoo`008Woo0P00
2goo00<007ooOol0ogoo=goo000ROol00`00Oomoo`0;Ool00`00Oomoo`3oOolfOol0029oo`03001o
ogoo00aoo`03001oogoo0?moocEoo`008Woo00<007ooOol037oo00<007ooOol0ogoo=Goo000ROol0
0`00Oomoo`0=Ool00`00Oomoo`3oOoldOol0029oo`8000moo`03001oogoo0?mooc=oo`008Woo00<0
07ooOol03goo00<007ooOol0ogoo<Woo000ROol00`00Oomoo`0?Ool00`00Oomoo`3oOolbOol0029o
o`03001oogoo011oo`03001oogoo0?mooc5oo`008Woo0P004Woo00<007ooOol0ogoo<7oo000ROol0
0`00Oomoo`0AOol00`00Oomoo`3oOol`Ool0029oo`03001oogoo019oo`03001oogoo0?moobmoo`00
27oo0`001Woo0P001Goo10001Woo00<007ooOol04goo00<007ooOol0ogoo;Woo0007Ool01@00Oomo
ogoo00001Goo0P002Goo00<007ooOol00goo00<007ooOol057oo00<007ooOol0ogoo;Goo0007Ool0
1@00Oomoogoo000047oo00<007ooOol00goo0`0057oo00<007ooOol0ogoo;Goo0007Ool01@00Oomo
ogoo000047oo00<007ooOol00goo00<007ooOol05Goo00<007ooOol0ogoo;7oo0007Ool01@00Oomo
ogoo000037oo10001Woo00<007ooOol05Woo00<007ooOol0ogoo:goo0007Ool01@00Oomoogoo0000
37oo00<007ooOol01goo00<007ooOol05goo00<007ooOol0ogoo:Woo0007Ool01@00Oomoogoo0000
37oo00<007ooOol01goo00<007ooOol05goo00<007ooOol0ogoo:Woo0008Ool3000=Ool40006Ool2
000IOol00`00Oomoo`3oOolYOol0029oo`03001oogoo01Uoo`03001oogoo0?moobQoo`008Woo00<0
07ooOol06Woo00<007ooOol0ogoo9goo000ROol00`00Oomoo`0KOol00`00Oomoo`3oOolVOol0029o
o`8001eoo`03001oogoo0?moobEoo`008Woo00<007ooOol07Goo00<007ooOol0ogoo97oo000ROol0
0`00Oomoo`0MOol00`00Oomoo`3oOolTOol0029oo`03001oogoo01ioo`03001oogoo0?moob=oo`00
8Woo00<007ooOol07goo00<007ooOol0ogoo8Woo000ROol2000QOol00`00Oomoo`3oOolQOol0029o
o`03001oogoo025oo`03001oogoo0?moob1oo`008Woo00<007ooOol08Woo00<007ooOol0ogoo7goo
000ROol00`00Oomoo`0SOol2003oOolOOol0029oo`03001oogoo02Eoo`03001oogoo0?mooaaoo`00
8Woo0P009goo00<007ooOol0ogoo6goo000ROol00`00Oomoo`0WOol00`00Oomoo`3oOolJOol000<0
00Ioo`8000Ioo`03001oogoo00Aoo`@000Ioo`03001oogoo02Qoo`03001oogoo0?mooaUoo`000goo
00<007ooOol00goo0P001Woo00<007ooOol027oo00<007ooOol00goo00<007ooOol0:Goo00<007oo
Ool0ogoo67oo0003Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`03Ool3000ZOol00`00
Oomoo`3oOolGOol000=oo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo
02]oo`03001oogoo0?mooaIoo`000goo00<007ooOol037oo00<007ooOol00goo10001Woo00<007oo
Ool0;7oo00<007ooOol0ogoo5Goo0003Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`07
Ool00`00Oomoo`0]Ool00`00Oomoo`3oOolDOol000=oo`03001oogoo00Uoo`05001oogooOol00004
Ool00`00Oomoo`07Ool00`00Oomoo`0^Ool00`00Oomoo`3oOolCOol000<000aoo`D000Aoo`@000Io
o`80031oo`03001oogoo0?mooa9oo`008Woo00<007ooOol0<7oo0P00ogoo4Woo000ROol00`00Oomo
o`0bOol00`00Oomoo`3oOol?Ool0029oo`03001oogoo03=oo`03001oogoo0?moo`ioo`008Woo00<0
07ooOol0=7oo0P00ogoo3Woo000ROol2000gOol00`00Oomoo`3oOol;Ool0029oo`03001oogoo03Mo
o`03001oogoo0?moo`Yoo`008Woo00<007ooOol0>7oo00<007ooOol0ogoo2Goo000ROol00`00Oomo
o`0iOol2003oOol9Ool0029oo`03001oogoo03]oo`03001oogoo0?moo`Ioo`008Woo0P00?Goo00<0
07ooOol0ogoo1Goo000ROol00`00Oomoo`0mOol2003oOol5Ool0029oo`03001oogoo03moo`800?mo
o`=oo`008Woo00<007ooOol0@Goo00<007ooOol0ogoo000ROol20013Ool2003oOol0029oo`03001o
ogoo04Aoo`800?eoo`0067oo1@001Goo00<007ooOol0AWoo00<007ooOol0nWoo000JOol00`00Oomo
o`05Ool00`00Oomoo`17Ool2003jOol001Yoo`03001oogoo00Eoo`03001oogoo04Uoo`800?Qoo`00
6Woo00<007ooOol01Goo0`00Bgoo0P00mWoo000JOol00`00Oomoo`05Ool00`00Oomoo`1=Ool2003d
Ool001Yoo`03001oogoo00Eoo`03001oogoo04moo`800?9oo`006Woo00<007ooOol01Goo00<007oo
Ool0DGoo0`00kgoo000HOol30007Ool00`00Oomoo`1DOol2003]Ool0029oo`8005Moo`<00:Qoobd0
01Eoo`008Woo00<007ooOol0FGoo1@00UWoo3@00@Woo000ROol00`00Oomoo`1NOol40025Ool=001?
Ool0029oo`03001oogoo069oo`@007Aoo`d005aoo`008Woo0P00Igoo0`00IGoo3000JGoo000ROol0
0`00Oomoo`1YOol5001DOol<001eOol0029oo`03001oogoo06ioo`H003AooaX0085oo`008Woo00<0
07ooOol0M7oo3P007Goo2@00Vgoo000ROol00`00Oomoo`22OolM002TOol0029oo`800?moodEoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`001@0017oo
0P0017oo1@0017oo10001Woo00<007ooOol0ogooA7oo0002Ool00`00Oomoo`04Ool20005Ool01000
Oomoo`0027oo00<007ooOol00goo00<007ooOol0ogooA7oo0002Ool00`00Oomoo`0<Ool00`00Oomo
o`08Ool00`00Oomoo`03Ool3003oOom4Ool0009oo`03001oogoo00eoo`03001oogoo00Moo`03001o
ogoo00=oo`03001oogoo0?moodAoo`000Woo00<007ooOol03Woo00<007ooOol00Woo10001Woo00<0
07ooOol0ogooA7oo0002Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomo
o`3oOom4Ool0009oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00Oomoo`07Ool00`00Oomo
o`3oOom4Ool000<000eoo`<000Eoo`@000Ioo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00
Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0
029oo`03001oogoo0?moodAoo`0027oo1@0017oo0P001Goo10001Woo00<007ooOol0ogooA7oo000:
Ool00`00Oomoo`04Ool20009Ool00`00Oomoo`03Ool00`00Oomoo`3oOom4Ool000Yoo`03001oogoo
00moo`03001oogoo00=oo`03001oogoo0?moodAoo`002Woo00<007ooOol03goo00<007ooOol00goo
0`00ogooA7oo000:Ool00`00Oomoo`0;Ool40006Ool00`00Oomoo`3oOom4Ool000Yoo`03001oogoo
00]oo`03001oogoo00Moo`03001oogoo0?moodAoo`002Woo00<007ooOol02goo00<007ooOol01goo
00<007ooOol0ogooA7oo0008Ool3000=Ool40006Ool00`00Oomoo`3oOom4Ool0029oo`800?moodEo
o`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAo
o`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo
00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007oo
Ool0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007oo
Ool0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`001@0017oo0P001Woo00<0
07ooOol017oo10001Woo00<007ooOol0ogooA7oo0002Ool00`00Oomoo`04Ool20006Ool00`00Oomo
o`08Ool00`00Oomoo`03Ool00`00Oomoo`3oOom4Ool0009oo`03001oogoo00eoo`03001oogoo00Mo
o`03001oogoo00=oo`<00?moodAoo`000Woo00<007ooOol03Goo00<007ooOol01goo00<007ooOol0
0goo00<007ooOol0ogooA7oo0002Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool40006Ool00`00Oomo
o`3oOom4Ool0009oo`03001oogoo00ioo`03001oogoo009oo`03001oogoo00Moo`03001oogoo0?mo
odAoo`000Woo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo00Moo`03001oogoo0?mo
odAoo`000`0037oo1@0017oo10001Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03
001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`80
0?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo
0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAo
o`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo
00<007ooOol0ogooA7oo000GOol50006Ool00`00Oomoo`3oOom4Ool001Qoo`04001oogoo0006Ool0
0`00Oomoo`3oOom4Ool001Uoo`03001oogoo00Ioo`03001oogoo0?moodAoo`006Woo00<007ooOol0
1Goo0`00ogooA7oo000KOol00`00Oomoo`3oOom;Ool001]oo`03001oogoo0?mood]oo`005goo00D0
07ooOomoo`000?moodeoo`0067oo0`00ogooCWoo003oOomYOol0095oo`8000]oo`03001oogoo00ao
o`8000Eoo`03001oogoo0;5oo`00TGoo00<007ooOol02Woo0P003Woo00<007ooOol00goo0P00/Woo
0026Ool50006Ool01000Oomoogoo0P000Woo0P0017oo00<007ooOol017oo0`001Goo00<007ooOol0
17oo00<007ooOol037oo0`002goo1@000goo0`001Woo0P001Goo1000NWoo0028Ool00`00Oomoo`06
Ool00`00Oomoo`02Ool01000Oomoo`001Goo0P0017oo00D007ooOomoo`0000Aoo`03001oogoo00Ao
o`8000aoo`05001oogooOol00002Ool60004Ool00`00Oomoo`02Ool01@00Oomoogoo00001Goo0P00
2Goo00<007ooOol0Mgoo0028Ool00`00Oomoo`06Ool00`00Oomoo`03Ool2000<Ool00`00Oomoo`06
Ool00`00Oomoo`0BOol00`00Oomoo`0>Ool00`00Oomoo`02Ool01@00Oomoogoo000047oo00<007oo
Ool0Mgoo0028Ool00`00Oomoo`06Ool00`00Oomoo`03Ool2000<Ool00`00Oomoo`06Ool00`00Oomo
o`0BOol00`00Oomoo`04Ool60004Ool00`00Oomoo`02Ool01@00Oomoogoo000047oo00<007ooOol0
Mgoo0028Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomoo`002goo00<007ooOol01Woo00<0
07ooOol04Woo00<007ooOol03Woo00<007ooOol00Woo00D007ooOomoo`0000aoo`@007Yoo`00QGoo
00@007ooOol0009oo`03001oogoo00=oo`04001oogooOol20002Ool20008Ool60005Ool00`00Oomo
o`0@Ool6000=Ool00`00Oomoo`02Ool01@00Oomoogoo000037oo00<007ooOol0Ngoo0025Ool01000
Oomoo`000Woo00<007ooOol00goo00<007ooOol04Goo00<007ooOol01Woo00<007ooOol04Woo00<0
07ooOol03Woo00<007ooOol00Woo00D007ooOomoo`0000aoo`03001oogoo07]oo`00QGoo1`001Goo
0P004Woo00<007ooOol01Goo0P0057oo00<007ooOol037oo0`001Goo0`003Goo1000NWoo003oOomY
Ool00?moofUoo`00ogooJGoo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11.) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.04057 .05035 L
.08481 .10279 L
.12636 .14798 L
.16632 .18681 L
.20885 .22266 L
.2498 .25176 L
.29331 .27707 L
.33524 .29638 L
.37557 .31074 L
.39599 .3166 L
.41848 .32207 L
.4598 .32973 L
.48018 .33251 L
.5021 .33486 L
.5243 .33664 L
.53451 .33727 L
.54539 .33784 L
.5563 .3383 L
.56619 .33862 L
.57613 .33887 L
.58549 .33903 L
.59038 .3391 L
.59574 .33915 L
.59845 .33917 L
.59994 .33917 L
.60135 .33918 L
.60266 .33918 L
.60408 .33919 L
.60538 .33919 L
.60657 .33919 L
.60768 .33919 L
.60888 .33919 L
.61001 .33919 L
.61104 .33919 L
.61219 .33919 L
.61345 .33919 L
.61598 .33918 L
.61848 .33917 L
.62116 .33915 L
.62597 .33911 L
.63157 .33905 L
.63673 .33899 L
.64838 .33879 L
.66954 .33832 L
.71092 .33703 L
.7507 .33555 L
.79305 .33391 L
.83382 .33243 L
.87716 .33109 L
Mistroke
.89882 .33055 L
.91891 .33012 L
.93836 .3298 L
.95907 .32954 L
.96921 .32946 L
.97453 .32942 L
.98016 .32939 L
.98509 .32937 L
.98789 .32936 L
.9905 .32935 L
.9929 .32935 L
.99509 .32934 L
.9963 .32934 L
.99761 .32934 L
.99885 .32934 L
1 .32934 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol2000TOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomo
o`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomo
o`08Ool20002Ool20005Ool0029oo`03001oo`000?moodAoo`008Woo00@007ooOol00?mood=oo`00
8Woo0P000Woo00<007ooOol0ogoo@7oo000ROol01@00Oomoogoo0000ogoo@Woo000ROol00`00Oomo
o`02Ool00`00Oomoo`3oOoloOol0029oo`03001oogoo00=oo`03001oogoo0?moocioo`008Woo00<0
07ooOol017oo00<007ooOol0ogoo?Goo000ROol20006Ool00`00Oomoo`3oOollOol0029oo`03001o
ogoo00Eoo`03001oogoo0?moocaoo`008Woo00<007ooOol01Woo00<007ooOol0ogoo>goo000ROol0
0`00Oomoo`07Ool00`00Oomoo`3oOoljOol0029oo`8000Uoo`03001oogoo0?moocUoo`008Woo00<0
07ooOol02Goo00<007ooOol0ogoo>7oo000ROol00`00Oomoo`09Ool00`00Oomoo`3oOolhOol0029o
o`03001oogoo00Yoo`03001oogoo0?moocMoo`008Woo00<007ooOol02goo00<007ooOol0ogoo=Woo
000ROol2000=Ool00`00Oomoo`3oOoleOol0029oo`03001oogoo00eoo`03001oogoo0?moocAoo`00
0`001Woo0P0017oo1@0017oo10001Woo00<007ooOol03Woo00<007ooOol0ogoo<goo0003Ool00`00
Oomoo`03Ool20005Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol03goo00<007ooOol0
ogoo<Woo0003Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`0@Ool0
0`00Oomoo`3oOolaOol000=oo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo00=oo`<0011o
o`03001oogoo0?mooc5oo`000goo00<007ooOol03Goo00<007ooOol00Woo10001Woo00<007ooOol0
4Goo00<007ooOol0ogoo<7oo0003Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`07Ool0
0`00Oomoo`0BOol00`00Oomoo`3oOol_Ool000=oo`03001oogoo00Uoo`05001oogooOol00004Ool0
0`00Oomoo`07Ool00`00Oomoo`0COol00`00Oomoo`3oOol^Ool000<000eoo`<000Eoo`@000Ioo`80
01Eoo`03001oogoo0?moobeoo`008Woo00<007ooOol05Goo00<007ooOol0ogoo;7oo000ROol00`00
Oomoo`0FOol00`00Oomoo`3oOol[Ool0029oo`03001oogoo01Moo`03001oogoo0?moobYoo`008Woo
00<007ooOol05goo00<007ooOol0ogoo:Woo000ROol2000IOol00`00Oomoo`3oOolYOol0029oo`03
001oogoo01Uoo`03001oogoo0?moobQoo`008Woo00<007ooOol06Woo00<007ooOol0ogoo9goo000R
Ool00`00Oomoo`0KOol00`00Oomoo`3oOolVOol0029oo`03001oogoo01aoo`03001oogoo0?moobEo
o`008Woo0P007Woo00<007ooOol0ogoo97oo000ROol00`00Oomoo`0MOol00`00Oomoo`3oOolTOol0
029oo`03001oogoo01ioo`03001oogoo0?moob=oo`008Woo00<007ooOol07goo00<007ooOol0ogoo
8Woo000ROol2000QOol00`00Oomoo`3oOolQOol0029oo`03001oogoo025oo`03001oogoo0?moob1o
o`008Woo00<007ooOol08Woo00<007ooOol0ogoo7goo0008Ool30006Ool20005Ool40006Ool00`00
Oomoo`0SOol2003oOolOOol000Moo`05001oogooOol00005Ool20009Ool00`00Oomoo`03Ool00`00
Oomoo`0UOol00`00Oomoo`3oOolLOol000Moo`05001oogooOol0000@Ool00`00Oomoo`03Ool3000V
Ool00`00Oomoo`3oOolKOol000Moo`05001oogooOol0000@Ool00`00Oomoo`03Ool00`00Oomoo`0W
Ool00`00Oomoo`3oOolJOol000Moo`05001oogooOol0000<Ool40006Ool00`00Oomoo`0XOol00`00
Oomoo`3oOolIOol000Moo`05001oogooOol0000<Ool00`00Oomoo`07Ool00`00Oomoo`0YOol00`00
Oomoo`3oOolHOol000Moo`05001oogooOol0000<Ool00`00Oomoo`07Ool00`00Oomoo`0ZOol00`00
Oomoo`3oOolGOol000Qoo`<000eoo`@000Ioo`8002aoo`03001oogoo0?mooaIoo`008Woo00<007oo
Ool0;7oo00<007ooOol0ogoo5Goo000ROol00`00Oomoo`0]Ool00`00Oomoo`3oOolDOol0029oo`03
001oogoo02ioo`03001oogoo0?mooa=oo`008Woo0P00<7oo00<007ooOol0ogoo4Woo000ROol00`00
Oomoo`0`Ool2003oOolBOol0029oo`03001oogoo039oo`03001oogoo0?moo`moo`008Woo00<007oo
Ool0<goo00<007ooOol0ogoo3Woo000ROol00`00Oomoo`0dOol00`00Oomoo`3oOol=Ool0029oo`80
03Ioo`03001oogoo0?moo`aoo`008Woo00<007ooOol0=Woo0P00ogoo37oo000ROol00`00Oomoo`0h
Ool00`00Oomoo`3oOol9Ool0029oo`03001oogoo03Uoo`03001oogoo0?moo`Qoo`008Woo00<007oo
Ool0>Woo00<007ooOol0ogoo1goo000ROol2000lOol00`00Oomoo`3oOol6Ool0029oo`03001oogoo
03aoo`03001oogoo0?moo`Eoo`000`001Woo0P001Woo00<007ooOol017oo10001Woo00<007ooOol0
?Goo0P00ogoo1Goo0003Ool00`00Oomoo`03Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`03Ool0
0`00Oomoo`0oOol00`00Oomoo`3oOol2Ool000=oo`03001oogoo00aoo`03001oogoo00Moo`03001o
ogoo00=oo`<0041oo`03001oogoo0?moo`5oo`000goo00<007ooOol037oo00<007ooOol01goo00<0
07ooOol00goo00<007ooOol0@Goo0P00ogoo0Goo0003Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool4
0006Ool00`00Oomoo`13Ool00`00Oomoo`3mOol000=oo`03001oogoo00eoo`03001oogoo009oo`03
001oogoo00Moo`03001oogoo04Aoo`03001oogoo0?aoo`000goo00<007ooOol02Goo00D007ooOomo
o`0000Aoo`03001oogoo00Moo`03001oogoo04Eoo`800?aoo`000`0037oo1@0017oo10001Woo0P00
B7oo00<007ooOol0nGoo000ROol00`00Oomoo`18Ool00`00Oomoo`3hOol0029oo`03001oogoo04Uo
o`800?Qoo`008Woo00<007ooOol0Bgoo0P00mWoo000ROol00`00Oomoo`1=Ool2003dOol0029oo`80
051oo`800?9oo`008Woo00<007ooOol0DGoo00<007ooOol0kgoo000ROol00`00Oomoo`1BOol2003_
Ool0029oo`03001oogoo05Aoo`800>eoo`008Woo00<007ooOol0EWoo0P00jgoo000ROol2001IOol2
003YOol0029oo`03001oogoo05Yoo`800>Moo`008Woo00<007ooOol0G7oo0`00i7oo000ROol00`00
Oomoo`1OOol2003ROol0029oo`80069oo`800>1oo`008Woo00<007ooOol0Hgoo0`00gGoo000HOol5
0005Ool00`00Oomoo`1VOol3003JOol001Yoo`03001oogoo00Eoo`03001oogoo06Uoo`<00=Moo`00
6Woo00<007ooOol01Goo00<007ooOol0K7oo0`00e7oo000JOol00`00Oomoo`05Ool3001_Ool3003A
Ool001Yoo`03001oogoo00Eoo`03001oogoo079oo`<00<ioo`006Woo00<007ooOol01Goo00<007oo
Ool0MGoo0`00bgoo000JOol00`00Oomoo`05Ool00`00Oomoo`1hOol30038Ool001Qoo`<000Moo`03
001oogoo07]oo`D00<=oo`008Woo0P00PGoo1`00_7oo000ROol00`00Oomoo`27Ool6001nOolS000E
Ool0029oo`03001oogoo08eoo`H005Eoob<003Qoo`008Woo00<007ooOol0Tgoo3000<7oo6@00Fgoo
000ROol2002POol`001dOol0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00
Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo00050004Ool20004Ool5
0004Ool40006Ool00`00Oomoo`3oOom4Ool0009oo`03001oogoo00Aoo`8000Eoo`04001oogoo0008
Ool00`00Oomoo`03Ool00`00Oomoo`3oOom4Ool0009oo`03001oogoo00aoo`03001oogoo00Qoo`03
001oogoo00=oo`<00?moodAoo`000Woo00<007ooOol03Goo00<007ooOol01goo00<007ooOol00goo
00<007ooOol0ogooA7oo0002Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool40006Ool00`00Oomoo`3o
Oom4Ool0009oo`03001oogoo00ioo`03001oogoo009oo`03001oogoo00Moo`03001oogoo0?moodAo
o`000Woo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo00Moo`03001oogoo0?moodAo
o`000`003Goo0`001Goo10001Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001o
ogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?mo
odEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo0008Ool50004Ool20005Ool40006Ool00`00Oomoo`3oOom4Ool000Yoo`03001o
ogoo00Aoo`8000Uoo`03001oogoo00=oo`03001oogoo0?moodAoo`002Woo00<007ooOol03goo00<0
07ooOol00goo00<007ooOol0ogooA7oo000:Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool3003oOom4
Ool000Yoo`03001oogoo00]oo`@000Ioo`03001oogoo0?moodAoo`002Woo00<007ooOol02goo00<0
07ooOol01goo00<007ooOol0ogooA7oo000:Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomo
o`3oOom4Ool000Qoo`<000eoo`@000Ioo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol0
0`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2
003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomo
o`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4
Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4
Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo00050004Ool20006Ool00`00Oomoo`04
Ool40006Ool00`00Oomoo`3oOom4Ool0009oo`03001oogoo00Aoo`8000Ioo`03001oogoo00Qoo`03
001oogoo00=oo`03001oogoo0?moodAoo`000Woo00<007ooOol03Goo00<007ooOol01goo00<007oo
Ool00goo0`00ogooA7oo0002Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00
Oomoo`3oOom4Ool0009oo`03001oogoo00eoo`03001oogoo00=oo`@000Ioo`03001oogoo0?moodAo
o`000Woo00<007ooOol03Woo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0ogooA7oo0002
Ool00`00Oomoo`0:Ool01@00Oomoogoo000017oo00<007ooOol01goo00<007ooOol0ogooA7oo0003
000<Ool50004Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol0
0`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomo
o`3oOom4Ool001Moo`D000Ioo`03001oogoo0?moodAoo`0067oo00@007ooOol000Ioo`03001oogoo
0?moodAoo`006Goo00<007ooOol01Woo00<007ooOol0ogooA7oo000JOol00`00Oomoo`05Ool3003o
Oom4Ool001]oo`03001oogoo0?mood]oo`006goo00<007ooOol0ogooBgoo000GOol01@00Oomoogoo
0000ogooCGoo000HOol3003oOom>Ool00?moofUoo`00UGoo0P002goo00<007ooOol037oo0P001Goo
00<007ooOol0[Goo002EOol00`00Oomoo`0:Ool2000>Ool00`00Oomoo`03Ool2002^Ool008Yoo`D0
00Ioo`04001oogooOol20002Ool20004Ool00`00Oomoo`04Ool30005Ool00`00Oomoo`04Ool00`00
Oomoo`0<Ool3000;Ool50003Ool50004Ool2001oOol008aoo`03001oogoo00Ioo`03001oogoo009o
o`04001oogoo0005Ool20004Ool01@00Oomoogoo000017oo00<007ooOol017oo0P0037oo00D007oo
Oomoo`00009oo`H000Aoo`03001oogoo00Eoo`03001oogoo00Aoo`8007moo`00S7oo00<007ooOol0
1Woo00<007ooOol00goo0P0037oo00<007ooOol01Woo00<007ooOol04Woo00<007ooOol03Woo00<0
07ooOol01Goo00<007ooOol0QGoo002<Ool00`00Oomoo`06Ool00`00Oomoo`03Ool2000<Ool00`00
Oomoo`06Ool00`00Oomoo`0BOol00`00Oomoo`04Ool60004Ool00`00Oomoo`05Ool00`00Oomoo`25
Ool008aoo`03001oogoo00Ioo`03001oogoo009oo`04001oogoo000;Ool00`00Oomoo`06Ool00`00
Oomoo`0BOol00`00Oomoo`0>Ool00`00Oomoo`05Ool00`00Oomoo`25Ool008Uoo`04001oogoo0002
Ool00`00Oomoo`03Ool01000Oomoogoo0P000Woo0P0027oo1P001Goo00<007ooOol047oo1P003Goo
00<007ooOol01Goo00<007ooOol0QGoo0029Ool01000Oomoo`000Woo00<007ooOol00goo00<007oo
Ool04Goo00<007ooOol01Woo00<007ooOol04Woo00<007ooOol03Woo00<007ooOol01Goo00<007oo
Ool0QGoo0029Ool70005Ool2000BOol00`00Oomoo`05Ool2000DOol00`00Oomoo`0<Ool30005Ool3
0027Ool00?moofUoo`00ogooJGoo003oOomYOol00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11.5) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .03849 m
.04057 .06227 L
.08481 .09346 L
.12636 .12493 L
.16632 .15523 L
.20885 .18605 L
.2498 .21336 L
.29331 .2392 L
.33524 .2607 L
.37557 .27819 L
.41848 .29348 L
.4598 .30522 L
.49953 .31403 L
.54183 .32109 L
.58254 .32598 L
.60473 .32798 L
.62583 .3295 L
.64686 .3307 L
.66593 .33154 L
.68659 .33223 L
.69793 .33252 L
.70861 .33274 L
.71886 .33291 L
.72969 .33305 L
.73894 .33314 L
.7438 .33318 L
.74909 .33321 L
.75459 .33324 L
.75712 .33325 L
.7598 .33326 L
.76221 .33326 L
.76488 .33327 L
.76604 .33327 L
.7673 .33327 L
.7684 .33327 L
.76957 .33327 L
.77095 .33328 L
.77224 .33328 L
.77302 .33328 L
.77376 .33328 L
.77515 .33328 L
.77586 .33328 L
.77662 .33327 L
.77797 .33327 L
.77943 .33327 L
.78103 .33327 L
.78364 .33327 L
.78645 .33326 L
.79153 .33325 L
.80217 .3332 L
Mistroke
.81376 .33314 L
.83487 .333 L
.8776 .33265 L
.91875 .33234 L
.94127 .3322 L
.95158 .33215 L
.96246 .33211 L
.97179 .33208 L
.97673 .33207 L
.98202 .33206 L
.98689 .33205 L
.9892 .33205 L
.99133 .33204 L
.99346 .33204 L
.99457 .33204 L
.99578 .33204 L
.99684 .33204 L
.99783 .33204 L
.99887 .33204 L
1 .33204 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00@007oo00000?mood=oo`008Woo0P000Woo00<0
07ooOol0ogoo@7oo000ROol00`00Oomoo`02Ool2003oOom0Ool0029oo`03001oogoo00Aoo`800?mo
ocioo`008Woo00<007ooOol01Woo00<007ooOol0ogoo>goo000ROol00`00Oomoo`07Ool2003oOolk
Ool0029oo`8000Yoo`800?moocUoo`008Woo00<007ooOol02goo00<007ooOol0ogoo=Woo00030006
Ool20004Ool50004Ool40006Ool00`00Oomoo`0<Ool2003oOolfOol000=oo`03001oogoo00=oo`80
00Eoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`3oOolcOol000=o
o`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo00moo`03001oogoo0?mo
oc9oo`000goo00<007ooOol037oo00<007ooOol01goo00<007ooOol00goo0`0047oo0P00ogoo<Woo
0003Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool40006Ool00`00Oomoo`0BOol00`00Oomoo`3oOol_
Ool000=oo`03001oogoo00eoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo01=oo`800?mo
obmoo`000goo00<007ooOol02Goo00D007ooOomoo`0000Aoo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo0?moobaoo`000`003Goo0`001Goo10001Woo0P005goo00<007ooOol0ogoo:goo000R
Ool00`00Oomoo`0GOol2003oOol[Ool0029oo`03001oogoo01Uoo`03001oogoo0?moobQoo`008Woo
00<007ooOol06Woo00<007ooOol0ogoo9goo000ROol00`00Oomoo`0KOol2003oOolWOol0029oo`80
01ioo`03001oogoo0?moobAoo`008Woo00<007ooOol07Woo00<007ooOol0ogoo8goo000ROol00`00
Oomoo`0OOol2003oOolSOol0029oo`03001oogoo025oo`03001oogoo0?moob1oo`008Woo00<007oo
Ool08Woo00<007ooOol0ogoo7goo000ROol2000TOol2003oOolOOol0029oo`03001oogoo02Eoo`03
001oogoo0?mooaaoo`008Woo00<007ooOol09Woo0P00ogoo77oo000ROol00`00Oomoo`0XOol00`00
Oomoo`3oOolIOol0029oo`8002Yoo`800?mooaUoo`008Woo00<007ooOol0:goo00<007ooOol0ogoo
5Woo000ROol00`00Oomoo`0/Ool00`00Oomoo`3oOolEOol000Qoo`<000Ioo`8000Eoo`@000Ioo`03
001oogoo02eoo`800?mooaEoo`001goo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo00=oo`03
001oogoo02moo`03001oogoo0?mooa9oo`001goo00D007ooOomoo`00011oo`03001oogoo00=oo`<0
031oo`800?mooa9oo`001goo00D007ooOomoo`00011oo`03001oogoo00=oo`03001oogoo039oo`03
001oogoo0?moo`moo`001goo00D007ooOomoo`0000aoo`@000Ioo`03001oogoo03=oo`03001oogoo
0?moo`ioo`001goo00D007ooOomoo`0000aoo`03001oogoo00Moo`03001oogoo03Aoo`800?moo`io
o`001goo00D007ooOomoo`0000aoo`03001oogoo00Moo`03001oogoo03Ioo`03001oogoo0?moo`]o
o`0027oo0`003Goo10001Woo0P00>7oo00<007ooOol0ogoo2Woo000ROol00`00Oomoo`0hOol00`00
Oomoo`3oOol9Ool0029oo`03001oogoo03Uoo`800?moo`Uoo`008Woo00<007ooOol0>goo00<007oo
Ool0ogoo1Woo000ROol2000mOol00`00Oomoo`3oOol5Ool0029oo`03001oogoo03eoo`800?moo`Eo
o`008Woo00<007ooOol0?goo00<007ooOol0ogoo0Woo000ROol00`00Oomoo`10Ool2003oOol2Ool0
029oo`03001oogoo049oo`03001oogoo0?ioo`008Woo0P00A7oo0P00oWoo000ROol00`00Oomoo`15
Ool00`00Oomoo`3kOol0029oo`03001oogoo04Ioo`800?]oo`008Woo00<007ooOol0B7oo00<007oo
Ool0n7oo000ROol00`00Oomoo`19Ool2003hOol0029oo`8004aoo`03001oogoo0?Eoo`008Woo00<0
07ooOol0C7oo0P00mGoo00030006Ool20006Ool00`00Oomoo`04Ool40006Ool00`00Oomoo`1>Ool2
003cOol000=oo`03001oogoo00=oo`8000Ioo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo
051oo`03001oogoo0?1oo`000goo00<007ooOol037oo00<007ooOol01goo00<007ooOol00goo0`00
DGoo0P00l7oo0003Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`1C
Ool2003^Ool000=oo`03001oogoo00aoo`03001oogoo00=oo`@000Ioo`03001oogoo05Eoo`03001o
ogoo0>]oo`000goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0EWoo
0P00jgoo0003Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol01goo00<007ooOol0
F7oo0P00jGoo0003000<Ool50004Ool40006Ool2001KOol2003WOol0029oo`03001oogoo05aoo`<0
0>Aoo`008Woo00<007ooOol0Ggoo0P00hWoo000ROol00`00Oomoo`1QOol2003POol0029oo`03001o
ogoo06=oo`800=ioo`008Woo0P00IWoo0P00g7oo000ROol00`00Oomoo`1WOol2003JOol0029oo`03
001oogoo06Uoo`800=Qoo`008Woo00<007ooOol0Jgoo0P00eWoo000ROol00`00Oomoo`1]Ool2003D
Ool0029oo`80071oo`<00=5oo`008Woo00<007ooOol0LWoo0`00cWoo000ROol00`00Oomoo`1eOol3
003;Ool0029oo`03001oogoo07Qoo`<00<Qoo`008Woo0P00O7oo1000a7oo000ROol00`00Oomoo`1o
Ool30031Ool001Qoo`D000Eoo`03001oogoo089oo`<00;ioo`006Woo00<007ooOol01Goo00<007oo
Ool0QGoo0`00^goo000JOol00`00Oomoo`05Ool00`00Oomoo`28Ool5002fOol001Yoo`03001oogoo
00Eoo`<008eoo`H00;1oo`006Woo00<007ooOol01Goo00<007ooOol0Tgoo1@00Zgoo000JOol00`00
Oomoo`05Ool00`00Oomoo`2HOol5002VOol001Yoo`03001oogoo00Eoo`03001oogoo09eoo`@00:9o
o`0067oo0`001goo00<007ooOol0XGoo2000VWoo000ROol2002ZOol:002@Ool0029oo`03001oogoo
0;=oo``008Aoo`008Woo00<007ooOol0_gooK`005Goo000ROol00`00Oomoo`3oOom4Ool0029oo`80
0?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo
0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAo
o`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAo
o`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool000D000Aoo`8000Aoo`D000Aoo`@000Io
o`03001oogoo0?moodAoo`000Woo00<007ooOol017oo0P001Goo00@007ooOol000Qoo`03001oogoo
00=oo`03001oogoo0?moodAoo`000Woo00<007ooOol037oo00<007ooOol027oo00<007ooOol00goo
0`00ogooA7oo0002Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`3o
Oom4Ool0009oo`03001oogoo00ioo`03001oogoo009oo`@000Ioo`03001oogoo0?moodAoo`000Woo
00<007ooOol03Woo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0ogooA7oo0002Ool00`00
Oomoo`0:Ool01@00Oomoogoo000017oo00<007ooOol01goo00<007ooOol0ogooA7oo0003000=Ool3
0005Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol0
0`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2
003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomo
o`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4
Ool000Qoo`D000Aoo`8000Eoo`@000Ioo`03001oogoo0?moodAoo`002Woo00<007ooOol017oo0P00
2Goo00<007ooOol00goo00<007ooOol0ogooA7oo000:Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool0
0`00Oomoo`3oOom4Ool000Yoo`03001oogoo00moo`03001oogoo00=oo`<00?moodAoo`002Woo00<0
07ooOol02goo10001Woo00<007ooOol0ogooA7oo000:Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool0
0`00Oomoo`3oOom4Ool000Yoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo0?moodAoo`00
27oo0`003Goo10001Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool000D000Aoo`8000Ioo`03001oogoo00Aoo`@000Ioo`03
001oogoo0?moodAoo`000Woo00<007ooOol017oo0P001Woo00<007ooOol027oo00<007ooOol00goo
00<007ooOol0ogooA7oo0002Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`03Ool3003o
Oom4Ool0009oo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo0?moodAo
o`000Woo00<007ooOol03Goo00<007ooOol00goo10001Woo00<007ooOol0ogooA7oo0002Ool00`00
Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool0009oo`03001oogoo
00Yoo`05001oogooOol00004Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000<000aoo`D000Ao
o`@000Ioo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029o
o`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001o
ogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?mo
odEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`00
5goo1@001Woo00<007ooOol0ogooA7oo000HOol01000Oomoo`001Woo00<007ooOol0ogooA7oo000I
Ool00`00Oomoo`06Ool00`00Oomoo`3oOom4Ool001Yoo`03001oogoo00Eoo`<00?moodAoo`006goo
00<007ooOol0ogooBgoo000KOol00`00Oomoo`3oOom;Ool001Moo`05001oogooOol0003oOom=Ool0
01Qoo`<00?moodioo`00ogooJGoo002AOol2000;Ool00`00Oomoo`0<Ool20005Ool00`00Oomoo`2a
Ool0095oo`03001oogoo00Yoo`8000ioo`03001oogoo00=oo`800;9oo`00QWoo1@001Woo00@007oo
Oomoo`80009oo`8000Aoo`03001oogoo00Aoo`<000Eoo`03001oogoo00Aoo`03001oogoo00aoo`<0
00]oo`D000=oo`D000Aoo`8000Eoo`@007Yoo`00R7oo00<007ooOol01Woo00<007ooOol00Woo00@0
07ooOol000Eoo`8000Aoo`05001oogooOol00004Ool00`00Oomoo`04Ool2000<Ool01@00Oomoogoo
00000Woo1P0017oo00<007ooOol01Goo00<007ooOol017oo0P002Goo00<007ooOol0Mgoo0028Ool0
0`00Oomoo`06Ool00`00Oomoo`03Ool2000<Ool00`00Oomoo`06Ool00`00Oomoo`0BOol00`00Oomo
o`0>Ool00`00Oomoo`05Ool00`00Oomoo`0?Ool00`00Oomoo`1gOol008Qoo`03001oogoo00Ioo`03
001oogoo00=oo`8000aoo`03001oogoo00Ioo`03001oogoo019oo`03001oogoo00Aoo`H000Aoo`03
001oogoo00Eoo`03001oogoo00moo`03001oogoo07Moo`00R7oo00<007ooOol01Woo00<007ooOol0
0Woo00@007ooOol000]oo`03001oogoo00Ioo`03001oogoo019oo`03001oogoo00ioo`03001oogoo
00Eoo`03001oogoo00]oo`@007Yoo`00QGoo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo
Ool20002Ool20008Ool60005Ool00`00Oomoo`0@Ool6000=Ool00`00Oomoo`05Ool00`00Oomoo`0;
Ool00`00Oomoo`1kOol008Eoo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`0AOol00`00
Oomoo`06Ool00`00Oomoo`0BOol00`00Oomoo`0>Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00
Oomoo`1kOol008Eoo`L000Eoo`80019oo`03001oogoo00Eoo`8001Aoo`03001oogoo00aoo`<000Eo
o`<000eoo`@007Yoo`00ogooJGoo003oOomYOol00?moofUoo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12.) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .14321 m
.00942 .14016 L
.01975 .13761 L
.02496 .13663 L
.03053 .13579 L
.03578 .13518 L
.04057 .13479 L
.04332 .13463 L
.04471 .13457 L
.04624 .13452 L
.04754 .13448 L
.04826 .13446 L
.04894 .13445 L
.05026 .13443 L
.05147 .13443 L
.05222 .13443 L
.05289 .13443 L
.05367 .13444 L
.05441 .13445 L
.05572 .13448 L
.05713 .13451 L
.0587 .13457 L
.06035 .13464 L
.06331 .13481 L
.06861 .13522 L
.07356 .13573 L
.08481 .13732 L
.09578 .13941 L
.10618 .14182 L
.12566 .14734 L
.16591 .16193 L
.20873 .18048 L
.24996 .19963 L
.2896 .2181 L
.33181 .23693 L
.37243 .25367 L
.41563 .26959 L
.45724 .28291 L
.49725 .29382 L
.53984 .30346 L
.58084 .31097 L
.62441 .31724 L
.66639 .32186 L
.70678 .32518 L
.72724 .32652 L
.74974 .32775 L
.79112 .32947 L
.81154 .3301 L
.83347 .33066 L
.85421 .33107 L
Mistroke
.87681 .33143 L
.89848 .33168 L
.91856 .33186 L
.92969 .33194 L
.94015 .332 L
.94948 .33205 L
.9597 .33209 L
.96992 .33212 L
.9755 .33213 L
.9807 .33214 L
.98558 .33215 L
.99002 .33215 L
.99248 .33215 L
.99378 .33215 L
.99515 .33216 L
.99635 .33216 L
.99767 .33216 L
.99887 .33216 L
1 .33216 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
00<000Ioo`8000Aoo`D000Aoo`@000Ioo`03001oogoo0?moodAoo`000goo00<007ooOol00goo0P00
1Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007ooOol02goo
00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0<Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03001oogoo00eoo`03001oogoo009oo`@0
00Ioo`03001oogoo0?moodAoo`000goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol0ogooA7oo0003Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol01goo
00<007ooOol0ogooA7oo0003000=Ool30005Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo00Iooa000?moobioo`00
8Woo0P000goo100047oo1`00ogoo9goo000ROol00`00Ool00002000KOol3003oOolTOol0029oo`80
025oo`<00?moob5oo`0027oo0`001Woo0P001Goo10001Woo00<007ooOol08goo0`00ogoo7Woo0007
Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol00goo00<007ooOol09Woo0`00ogoo6goo0007
Ool01@00Oomoogoo000047oo00<007ooOol00goo0`00:Goo0`00ogoo67oo0007Ool01@00Oomoogoo
000047oo00<007ooOol00goo00<007ooOol0;7oo0`00ogoo5Goo0007Ool01@00Oomoogoo000037oo
10001Woo00<007ooOol0;goo0P00ogoo4goo0007Ool01@00Oomoogoo000037oo00<007ooOol01goo
00<007ooOol0<Goo0P00ogoo4Goo0007Ool01@00Oomoogoo000037oo00<007ooOol01goo00<007oo
Ool0<goo0P00ogoo3goo0008Ool3000=Ool40006Ool2000fOol3003oOol<Ool0029oo`03001oogoo
03Qoo`800?moo`Yoo`008Woo00<007ooOol0>Woo0P00ogoo27oo000ROol00`00Oomoo`0lOol2003o
Ool6Ool0029oo`8003moo`800?moo`Aoo`008Woo00<007ooOol0@7oo0P00ogoo0Woo000ROol00`00
Oomoo`12Ool3003nOol0029oo`03001oogoo04Eoo`800?aoo`008Woo00<007ooOol0Agoo0P00nWoo
000ROol2001:Ool2003hOol0029oo`03001oogoo04]oo`<00?Eoo`008Woo00<007ooOol0CWoo0P00
lgoo000ROol00`00Oomoo`1@Ool2003aOol0029oo`03001oogoo059oo`<00>ioo`008Woo0P00EWoo
0P00k7oo000ROol00`00Oomoo`1GOol2003ZOol000<000Ioo`8000Ioo`03001oogoo00Aoo`@000Io
o`03001oogoo05Uoo`800>Qoo`000goo00<007ooOol00goo0P001Woo00<007ooOol027oo00<007oo
Ool00goo00<007ooOol0Fgoo0`00iGoo0003Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomo
o`03Ool3001NOol2003SOol000=oo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo00=oo`03
001oogoo061oo`800>5oo`000goo00<007ooOol037oo00<007ooOol00goo10001Woo00<007ooOol0
HWoo0P00ggoo0003Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`1T
Ool3003LOol000=oo`03001oogoo00Uoo`05001oogooOol00004Ool00`00Oomoo`07Ool00`00Oomo
o`1WOol2003JOol000<000aoo`D000Aoo`@000Ioo`8006Yoo`800=Qoo`008Woo00<007ooOol0Jgoo
0`00eGoo000ROol00`00Oomoo`1^Ool2003COol0029oo`03001oogoo071oo`<00=1oo`008Woo00<0
07ooOol0Lgoo0`00cGoo000ROol2001gOol2003;Ool0029oo`03001oogoo07Qoo`<00<Qoo`008Woo
00<007ooOol0Ngoo0`00aGoo000ROol00`00Oomoo`1nOol30032Ool0029oo`03001oogoo085oo`<0
0;moo`008Woo0P00QGoo0`00_7oo000ROol00`00Oomoo`27Ool4002hOol0029oo`03001oogoo08]o
o`@00;Aoo`008Woo00<007ooOol0Sgoo1000/7oo000ROol2002DOol4002/Ool0029oo`03001oogoo
09Moo`D00:Moo`0067oo1@001Goo00<007ooOol0W7oo1000Xgoo000JOol00`00Oomoo`05Ool00`00
Oomoo`2POol4002OOol001Yoo`03001oogoo00Eoo`03001oogoo0:Aoo`@009]oo`006Woo00<007oo
Ool01Goo0`00Z7oo1000Ugoo000JOol00`00Oomoo`05Ool00`00Oomoo`2/Ool9002>Ool001Yoo`03
001oogoo00Eoo`03001oogoo0;Eoo`X008Aoo`006Woo00<007ooOol01Goo00<007ooOol0_goo1P00
OWoo000HOol30007Ool00`00Oomoo`35Ool:001dOol0029oo`800=1ooa0006Aoo`008Woo00<007oo
Ool0ggoo6@00Bgoo000ROol00`00Oomoo`3hOolf000EOol0029oo`03001oogoo0?moodAoo`008Woo
0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007oo
Ool0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogoo
A7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`001@0017oo0P0017oo1@0017oo1000
1Woo00<007ooOol0ogooA7oo0002Ool00`00Oomoo`04Ool20005Ool01000Oomoo`0027oo00<007oo
Ool00goo00<007ooOol0ogooA7oo0002Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`03
Ool3003oOom4Ool0009oo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo
0?moodAoo`000Woo00<007ooOol03Woo00<007ooOol00Woo10001Woo00<007ooOol0ogooA7oo0002
Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool0009oo`03
001oogoo00Yoo`05001oogooOol00004Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000<000eo
o`<000Eoo`@000Ioo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4
Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029o
o`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029o
o`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001o
ogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`0027oo1@0017oo0P001Goo10001Woo00<007ooOol0ogooA7oo000:Ool00`00Oomoo`04Ool2
0009Ool00`00Oomoo`03Ool00`00Oomoo`3oOom4Ool000Yoo`03001oogoo00moo`03001oogoo00=o
o`03001oogoo0?moodAoo`002Woo00<007ooOol03goo00<007ooOol00goo0`00ogooA7oo000:Ool0
0`00Oomoo`0;Ool40006Ool00`00Oomoo`3oOom4Ool000Yoo`03001oogoo00]oo`03001oogoo00Mo
o`03001oogoo0?moodAoo`002Woo00<007ooOol02goo00<007ooOol01goo00<007ooOol0ogooA7oo
0008Ool3000=Ool40006Ool00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol0
0`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2
003oOom5Ool0029oo`03001oogoo0?moodAoo`001@0017oo0P001Woo00<007ooOol017oo10001Woo
00<007ooOol0ogooA7oo0002Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`03
Ool00`00Oomoo`3oOom4Ool0009oo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00=oo`<0
0?moodAoo`000Woo00<007ooOol03Goo00<007ooOol01goo00<007ooOol00goo00<007ooOol0ogoo
A7oo0002Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool40006Ool00`00Oomoo`3oOom4Ool0009oo`03
001oogoo00ioo`03001oogoo009oo`03001oogoo00Moo`03001oogoo0?moodAoo`000Woo00<007oo
Ool02Woo00D007ooOomoo`0000Aoo`03001oogoo00Moo`03001oogoo0?moodAoo`000`0037oo1@00
17oo10001Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo
000GOol50006Ool00`00Oomoo`3oOom4Ool001Qoo`04001oogoo0006Ool00`00Oomoo`3oOom4Ool0
01Uoo`03001oogoo00Ioo`03001oogoo0?moodAoo`006Woo00<007ooOol01Goo0`00ogooA7oo000K
Ool00`00Oomoo`3oOom;Ool001]oo`03001oogoo0?mood]oo`005goo00D007ooOomoo`000?moodeo
o`0067oo0`00ogooCWoo003oOomYOol009Eoo`8000]oo`03001oogoo00aoo`8000Eoo`03001oogoo
0:eoo`00UGoo00<007ooOol02Woo0P003Woo00<007ooOol00goo0P00[Woo002:Ool50006Ool01000
Oomoogoo0P000Woo0P0017oo00<007ooOol017oo0`001Goo00<007ooOol017oo00<007ooOol037oo
0`002goo1@000Woo1@001Goo0P00Ogoo002<Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomo
o`001Goo0P0017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`8000aoo`05001oogooOol00002
Ool60004Ool00`00Oomoo`03Ool01000Oomoo`001Goo0P00Ogoo002<Ool00`00Oomoo`06Ool00`00
Oomoo`03Ool2000<Ool00`00Oomoo`06Ool00`00Oomoo`0BOol00`00Oomoo`0>Ool00`00Oomoo`04
Ool00`00Oomoo`26Ool008aoo`03001oogoo00Ioo`03001oogoo00=oo`8000aoo`03001oogoo00Io
o`03001oogoo019oo`03001oogoo00Aoo`H000Aoo`03001oogoo00Eoo`03001oogoo08Eoo`00S7oo
00<007ooOol01Woo00<007ooOol00Woo00@007ooOol000]oo`03001oogoo00Ioo`03001oogoo019o
o`03001oogoo00ioo`03001oogoo00Ioo`03001oogoo08Aoo`00RGoo00@007ooOol0009oo`03001o
ogoo00=oo`04001oogooOol20002Ool20008Ool60005Ool00`00Oomoo`0@Ool6000=Ool00`00Oomo
o`06Ool00`00Oomoo`24Ool008Uoo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`0AOol0
0`00Oomoo`06Ool00`00Oomoo`0BOol00`00Oomoo`0>Ool00`00Oomoo`02Ool01@00Oomoogoo0000
QWoo0029Ool70005Ool2000BOol00`00Oomoo`05Ool2000DOol00`00Oomoo`0<Ool30005Ool30027
Ool00?moofUoo`00ogooJGoo003oOomYOol00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12.5) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .28852 m
.01975 .26799 L
.04057 .25016 L
.06168 .2357 L
.08481 .22361 L
.10536 .21579 L
.11687 .21249 L
.12734 .2101 L
.1378 .20825 L
.14745 .207 L
.15249 .20651 L
.15804 .2061 L
.16083 .20593 L
.16384 .20579 L
.16667 .20569 L
.16927 .20563 L
.17062 .2056 L
.17189 .20559 L
.17304 .20558 L
.17427 .20557 L
.17562 .20557 L
.1763 .20557 L
.17705 .20558 L
.17837 .20559 L
.17961 .20561 L
.18085 .20563 L
.18203 .20566 L
.18424 .20572 L
.1892 .20592 L
.19462 .20622 L
.19963 .20658 L
.21096 .20766 L
.23056 .21029 L
.25219 .21415 L
.29441 .22383 L
.33503 .23482 L
.37822 .24727 L
.41983 .25926 L
.45984 .27028 L
.50243 .28112 L
.54343 .29046 L
.587 .29913 L
.62898 .30623 L
.66937 .31195 L
.71234 .31692 L
.75371 .32074 L
.79349 .32362 L
.83585 .32596 L
.87662 .32758 L
.89885 .32825 L
Mistroke
.91996 .32874 L
.93005 .32894 L
.94079 .32911 L
.95086 .32925 L
.96011 .32935 L
.96999 .32944 L
.97519 .32947 L
.98066 .3295 L
.98544 .32952 L
.98989 .32953 L
.99244 .32954 L
.99477 .32954 L
.99606 .32955 L
.99674 .32955 L
.99746 .32955 L
.99878 .32955 L
1 .32955 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
00<000Ioo`8000Aoo`D000Aoo`@000Ioo`03001oogoo0?moodAoo`000goo00<007ooOol00goo0P00
1Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007ooOol02goo
00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0<Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03001oogoo00eoo`03001oogoo009oo`@0
00Ioo`03001oogoo0?moodAoo`000goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol0ogooA7oo0003Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol01goo
00<007ooOol0ogooA7oo0003000=Ool30005Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`0027oo0`001Woo0P00
1Goo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol0
0goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000047oo00<007ooOol00goo0`00ogooA7oo
0007Ool01@00Oomoogoo000047oo00<007ooOol00goo00<007ooOol0ogooA7oo0007Ool01@00Oomo
ogoo000037oo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol0
1goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol01goo00<007ooOol0
ogooA7oo0008Ool3000=Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol09Woo6`00
ogoo0goo000ROol00`00Oomoo`0SOol3000KOol7003kOol0029oo`03001oogoo01moo`@002Eoo`D0
0?Ioo`008Woo0P007Goo0`00;Woo1000lWoo000ROol00`00Oomoo`0IOol3000eOol4003^Ool000<0
00Ioo`8000Ioo`03001oogoo00Aoo`@000Ioo`03001oogoo01Ioo`<003aoo`@00>Yoo`000goo00<0
07ooOol00goo0P001Woo00<007ooOol027oo00<007ooOol00goo00<007ooOol057oo0P00@goo1@00
iGoo0003Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`03Ool3000COol00`00Oomoo`18
Ool4003QOol000=oo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo015o
o`8004moo`@00=eoo`000goo00<007ooOol037oo00<007ooOol00goo10001Woo00<007ooOol03goo
0P00EGoo0`00fWoo0003Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomo
o`0=Ool2001JOol3003GOol000=oo`03001oogoo00Uoo`05001oogooOol00004Ool00`00Oomoo`07
Ool00`00Oomoo`0<Ool00`00Oomoo`1MOol3003DOol000<000aoo`D000Aoo`@000Ioo`8000]oo`80
06=oo`@00=1oo`008Woo00<007ooOol027oo0P00JGoo0`00cGoo000ROol00`00Oomoo`07Ool00`00
Oomoo`1/Ool3003:Ool0029oo`03001oogoo00Ioo`03001oogoo071oo`<00<Moo`008Woo00<007oo
Ool01Goo00<007ooOol0M7oo1000`goo000ROol20005Ool00`00Oomoo`1iOol4002oOol0029oo`03
001oogoo00=oo`03001oogoo07ioo`@00;]oo`008Woo00<007ooOol00goo00<007ooOol0PWoo1000
]goo000ROol00`00Oomoo`02Ool00`00Oomoo`27Ool5002bOol0029oo`05001oogooOol0002?Ool4
002^Ool0029oo`800003Ool007oo09=oo`@00:Yoo`008Woo00<007oo0000VGoo1000YWoo000ROol2
002NOol4002ROol0029oo`03001oogoo0:5oo`@009ioo`008Woo0P00YWoo1@00VGoo000ROol00`00
Oomoo`2ZOol4002EOol001Qoo`D000Eoo`03001oogoo0:ioo`D0091oo`006Woo00<007ooOol01Goo
00<007ooOol0/goo1`00RGoo000JOol00`00Oomoo`05Ool00`00Oomoo`2jOol60023Ool001Yoo`03
001oogoo00Eoo`<00<1oo`H007eoo`006Woo00<007ooOol01Goo00<007ooOol0aWoo2P00Lgoo000J
Ool00`00Oomoo`05Ool00`00Oomoo`3@Ool=001VOol001Yoo`03001oogoo00Eoo`03001oogoo0=eo
o``005Yoo`0067oo0`001goo00<007ooOol0jGoo3@00CGoo000ROol2003gOol<0011Ool0029oo`03
001oogoo0?moo`=oob`001Eoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0
029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03
001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo
0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo
0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool000D000Aoo`8000Aoo`D000Ao
o`@000Ioo`03001oogoo0?moodAoo`000Woo00<007ooOol017oo0P001Goo00@007ooOol000Qoo`03
001oogoo00=oo`03001oogoo0?moodAoo`000Woo00<007ooOol037oo00<007ooOol027oo00<007oo
Ool00goo0`00ogooA7oo0002Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00
Oomoo`3oOom4Ool0009oo`03001oogoo00ioo`03001oogoo009oo`@000Ioo`03001oogoo0?moodAo
o`000Woo00<007ooOol03Woo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0ogooA7oo0002
Ool00`00Oomoo`0:Ool01@00Oomoogoo000017oo00<007ooOol01goo00<007ooOol0ogooA7oo0003
000=Ool30005Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol0
0`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomo
o`3oOom4Ool000Qoo`D000Aoo`8000Eoo`@000Ioo`03001oogoo0?moodAoo`002Woo00<007ooOol0
17oo0P002Goo00<007ooOol00goo00<007ooOol0ogooA7oo000:Ool00`00Oomoo`0?Ool00`00Oomo
o`03Ool00`00Oomoo`3oOom4Ool000Yoo`03001oogoo00moo`03001oogoo00=oo`<00?moodAoo`00
2Woo00<007ooOol02goo10001Woo00<007ooOol0ogooA7oo000:Ool00`00Oomoo`0;Ool00`00Oomo
o`07Ool00`00Oomoo`3oOom4Ool000Yoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo0?mo
odAoo`0027oo0`003Goo10001Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001o
ogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?mo
odEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool000D000Aoo`8000Ioo`03001oogoo00Aoo`@0
00Ioo`03001oogoo0?moodAoo`000Woo00<007ooOol017oo0P001Woo00<007ooOol027oo00<007oo
Ool00goo00<007ooOol0ogooA7oo0002Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`03
Ool3003oOom4Ool0009oo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo
0?moodAoo`000Woo00<007ooOol03Goo00<007ooOol00goo10001Woo00<007ooOol0ogooA7oo0002
Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool0009oo`03
001oogoo00Yoo`05001oogooOol00004Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000<000ao
o`D000Aoo`@000Ioo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4
Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029o
o`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029o
o`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001o
ogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`005goo1@001Woo00<007ooOol0ogooA7oo000HOol01000Oomoo`001Woo00<007ooOol0ogoo
A7oo000IOol00`00Oomoo`06Ool00`00Oomoo`3oOom4Ool001Yoo`03001oogoo00Eoo`<00?moodAo
o`006goo00<007ooOol0ogooBgoo000KOol00`00Oomoo`3oOom;Ool001Moo`05001oogooOol0003o
Oom=Ool001Qoo`<00?moodioo`00ogooJGoo002AOol2000;Ool00`00Oomoo`0<Ool20005Ool00`00
Oomoo`2aOol0095oo`03001oogoo00Yoo`8000ioo`03001oogoo00=oo`800;9oo`00QWoo1@001Woo
00@007ooOomoo`80009oo`8000Aoo`03001oogoo00Aoo`<000Eoo`03001oogoo00Aoo`03001oogoo
00aoo`<000]oo`D0009oo`D000Eoo`8000Eoo`@007Yoo`00R7oo00<007ooOol01Woo00<007ooOol0
0Woo00@007ooOol000Eoo`8000Aoo`05001oogooOol00004Ool00`00Oomoo`04Ool2000<Ool01@00
Oomoogoo00000Woo1P0017oo00<007ooOol00goo00@007ooOol000Eoo`8000Uoo`03001oogoo07Mo
o`00R7oo00<007ooOol01Woo00<007ooOol00goo0P0037oo00<007ooOol01Woo00<007ooOol04Woo
00<007ooOol03Woo00<007ooOol017oo00<007ooOol047oo00<007ooOol0Mgoo0028Ool00`00Oomo
o`06Ool00`00Oomoo`03Ool2000<Ool00`00Oomoo`06Ool00`00Oomoo`0BOol00`00Oomoo`04Ool6
0004Ool00`00Oomoo`05Ool00`00Oomoo`0?Ool00`00Oomoo`1gOol008Qoo`03001oogoo00Ioo`03
001oogoo009oo`04001oogoo000;Ool00`00Oomoo`06Ool00`00Oomoo`0BOol00`00Oomoo`0>Ool0
0`00Oomoo`06Ool00`00Oomoo`0:Ool4001jOol008Eoo`04001oogoo0002Ool00`00Oomoo`03Ool0
1000Oomoogoo0P000Woo0P0027oo1P001Goo00<007ooOol047oo1P003Goo00<007ooOol01Woo00<0
07ooOol02Woo00<007ooOol0Ngoo0025Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol0
4Goo00<007ooOol01Woo00<007ooOol04Woo00<007ooOol03Woo00<007ooOol00Woo00D007ooOomo
o`0000aoo`03001oogoo07]oo`00QGoo1`001Goo0P004Woo00<007ooOol01Goo0P0057oo00<007oo
Ool037oo0`001Goo0`003Goo1000NWoo003oOomYOol00?moofUoo`00ogooJGoo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .43886 m
.04057 .38012 L
.08481 .33119 L
.10632 .31249 L
.12636 .29777 L
.16632 .27534 L
.18776 .26666 L
.20726 .26055 L
.22737 .25582 L
.23871 .2538 L
.24919 .25231 L
.25934 .25119 L
.26885 .25041 L
.2743 .25008 L
.27928 .24984 L
.28203 .24974 L
.28504 .24964 L
.28787 .24957 L
.29051 .24953 L
.29186 .24951 L
.29259 .2495 L
.29328 .2495 L
.2945 .24949 L
.29584 .24948 L
.29658 .24948 L
.29729 .24948 L
.29862 .24948 L
.29936 .24949 L
.30005 .24949 L
.3016 .2495 L
.30284 .24952 L
.30401 .24953 L
.30667 .24958 L
.30926 .24964 L
.31205 .24972 L
.31702 .2499 L
.32225 .25014 L
.33159 .25068 L
.35232 .25239 L
.37161 .2545 L
.4126 .26026 L
.45618 .26759 L
.49816 .27519 L
.53855 .28254 L
.58151 .29006 L
.62288 .29676 L
.66267 .30258 L
.70502 .30803 L
.74579 .31251 L
.78913 .31645 L
Mistroke
.83088 .31948 L
.87103 .32172 L
.89346 .32269 L
.91377 .3234 L
.93497 .32398 L
.95491 .32438 L
.96519 .32452 L
.9708 .32459 L
.97603 .32464 L
.98088 .32467 L
.98529 .3247 L
.98764 .32471 L
.99019 .32472 L
.99159 .32473 L
.99289 .32473 L
.99421 .32473 L
.99544 .32474 L
.99649 .32474 L
.99761 .32474 L
.99886 .32474 L
1 .32474 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
00<000Ioo`8000Aoo`D000Aoo`@000Ioo`03001oogoo0?moodAoo`000goo00<007ooOol00goo0P00
1Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007ooOol02goo
00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0<Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03001oogoo00eoo`03001oogoo009oo`@0
00Ioo`03001oogoo0?moodAoo`000goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol0ogooA7oo0003Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol01goo
00<007ooOol0ogooA7oo0003000=Ool30005Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`0027oo0`001Woo0P00
1Goo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol0
0goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000047oo00<007ooOol00goo0`00ogooA7oo
0007Ool01@00Oomoogoo000047oo00<007ooOol00goo00<007ooOol0ogooA7oo0007Ool01@00Oomo
ogoo000037oo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol0
1goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol01goo00<007ooOol0
ogooA7oo0008Ool3000=Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol0
0`00Oomoo`3oOom4Ool000<000Ioo`8000Ioo`03001oogoo00Aoo`@000Ioo`03001oogoo0?moodAo
o`000goo00<007ooOol00goo0P001Woo00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogoo
A7oo0003Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03
001oogoo00aoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007oo
Ool037oo00<007ooOol00goo10001Woo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0=Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000=oo`03001oogoo00Uoo`05001oogoo
Ool00004Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000<000aoo`D000Aoo`@000Ioo`800?mo
odEoo`008Woo00<007ooOol0Bgoo6`00gGoo000ROol00`00Oomoo`14Ool7000KOol<003AOol0029o
o`03001oogoo03moo`D002ioo`H00<]oo`008Woo00<007ooOol0>goo1000>Goo1`00a7oo000ROol2
000iOol30014Ool7002mOol0029oo`03001oogoo03Eoo`<004ioo`D00;Qoo`008Woo00<007ooOol0
<goo0P00EWoo1000]7oo000ROol00`00Oomoo`0aOol2001LOol4002`Ool0029oo`03001oogoo02mo
o`80069oo`D00:]oo`008Woo0P00;Woo0P00JGoo1`00Y7oo000ROol00`00Oomoo`0[Ool2001bOol6
002NOol0029oo`03001oogoo02Uoo`8007Yoo`L009Moo`008Woo00<007ooOol0:7oo00<007ooOol0
PGoo1P00TGoo000ROol2000WOol2002:Ool6002;Ool0029oo`03001oogoo02Aoo`80099oo`H008Eo
o`0067oo1@001Goo00<007ooOol08Woo0P00VWoo1P00Ogoo000JOol00`00Oomoo`05Ool00`00Oomo
o`0QOol00`00Oomoo`2POol6001iOol001Yoo`03001oogoo00Eoo`03001oogoo01moo`800:Uoo`L0
079oo`006Woo00<007ooOol01Goo0`007Woo00<007ooOol0/7oo2@00JGoo000JOol00`00Oomoo`05
Ool00`00Oomoo`0MOol00`00Oomoo`2jOol=001LOol001Yoo`03001oogoo00Eoo`03001oogoo01ao
o`03001oogoo0<Qoo`d004moo`006Woo00<007ooOol01Goo00<007ooOol06goo00<007ooOol0eWoo
3000@goo000HOol30007Ool00`00Oomoo`0JOol00`00Oomoo`3SOolM000VOol0029oo`8001Yoo`03
001oogoo0?moo`9ooa4001Eoo`008Woo00<007ooOol067oo00<007ooOol0ogoo:Goo000ROol00`00
Oomoo`0GOol00`00Oomoo`3oOolZOol0029oo`03001oogoo01Moo`03001oogoo0?moobYoo`008Woo
0P005goo00<007ooOol0ogoo:goo000ROol00`00Oomoo`0EOol00`00Oomoo`3oOol/Ool0029oo`03
001oogoo01Aoo`03001oogoo0?moobeoo`008Woo00<007ooOol04goo00<007ooOol0ogoo;Woo000R
Ool00`00Oomoo`0BOol00`00Oomoo`3oOol_Ool0029oo`80019oo`03001oogoo0?mooc1oo`008Woo
00<007ooOol047oo00<007ooOol0ogoo<Goo000ROol00`00Oomoo`0?Ool00`00Oomoo`3oOolbOol0
029oo`03001oogoo00ioo`03001oogoo0?mooc=oo`008Woo00<007ooOol03Goo00<007ooOol0ogoo
=7oo000ROol2000=Ool00`00Oomoo`3oOoleOol0029oo`03001oogoo00]oo`03001oogoo0?moocIo
o`001@0017oo0P0017oo1@0017oo10001Woo00<007ooOol02Woo00<007ooOol0ogoo=goo0002Ool0
0`00Oomoo`04Ool20005Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol02Goo00<007oo
Ool0ogoo>7oo0002Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`03Ool30009Ool00`00
Oomoo`3oOolhOol0009oo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo
00Qoo`03001oogoo0?moocUoo`000Woo00<007ooOol03Woo00<007ooOol00Woo10001Woo00<007oo
Ool01goo00<007ooOol0ogoo>Woo0002Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`3oOoljOol0009oo`03001oogoo00Yoo`05001oogooOol00004
Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`3oOolkOol000<000eoo`<000Eoo`@000Io
o`8000Ioo`03001oogoo0?moocaoo`008Woo00<007ooOol017oo00<007ooOol0ogoo?Goo000ROol0
0`00Oomoo`04Ool00`00Oomoo`3oOolmOol0029oo`03001oogoo00=oo`03001oogoo0?moocioo`00
8Woo00<007ooOol00Woo00<007ooOol0ogoo?goo000ROol20003Ool00`00Oomoo`3oOoloOol0029o
o`05001oogooOol0003oOom2Ool0029oo`04001oogoo003oOom3Ool0029oo`03001oo`000?moodAo
o`008Woo0`00ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007oo
Ool0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogoo
A7oo0008Ool50004Ool20005Ool40006Ool00`00Oomoo`3oOom4Ool000Yoo`03001oogoo00Aoo`80
00Uoo`03001oogoo00=oo`03001oogoo0?moodAoo`002Woo00<007ooOol03goo00<007ooOol00goo
00<007ooOol0ogooA7oo000:Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool3003oOom4Ool000Yoo`03
001oogoo00]oo`@000Ioo`03001oogoo0?moodAoo`002Woo00<007ooOol02goo00<007ooOol01goo
00<007ooOol0ogooA7oo000:Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool0
00Qoo`<000eoo`@000Ioo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0
029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0
029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03
001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`80
0?moodEoo`008Woo00<007ooOol0ogooA7oo00050004Ool20006Ool00`00Oomoo`04Ool40006Ool0
0`00Oomoo`3oOom4Ool0009oo`03001oogoo00Aoo`8000Ioo`03001oogoo00Qoo`03001oogoo00=o
o`03001oogoo0?moodAoo`000Woo00<007ooOol03Goo00<007ooOol01goo00<007ooOol00goo0`00
ogooA7oo0002Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`3oOom4
Ool0009oo`03001oogoo00eoo`03001oogoo00=oo`@000Ioo`03001oogoo0?moodAoo`000Woo00<0
07ooOol03Woo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0ogooA7oo0002Ool00`00Oomo
o`0:Ool01@00Oomoogoo000017oo00<007ooOol01goo00<007ooOol0ogooA7oo0003000<Ool50004
Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
01Moo`D000Ioo`03001oogoo0?moodAoo`0067oo00@007ooOol000Ioo`03001oogoo0?moodAoo`00
6Goo00<007ooOol01Woo00<007ooOol0ogooA7oo000JOol00`00Oomoo`05Ool3003oOom4Ool001]o
o`03001oogoo0?mood]oo`006goo00<007ooOol0ogooBgoo000GOol01@00Oomoogoo0000ogooCGoo
000HOol3003oOom>Ool00?moofUoo`00UGoo0P002goo00<007ooOol037oo0P001Goo00<007ooOol0
[Goo002EOol00`00Oomoo`0:Ool2000>Ool00`00Oomoo`03Ool2002^Ool008Yoo`D000Ioo`04001o
ogooOol20002Ool20004Ool00`00Oomoo`04Ool30005Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool3
000;Ool50003Ool30006Ool2001oOol008aoo`03001oogoo00Ioo`03001oogoo009oo`04001oogoo
0005Ool20004Ool01@00Oomoogoo000017oo00<007ooOol017oo0P0037oo00D007ooOomoo`00009o
o`H000Aoo`03001oogoo009oo`05001oogooOol00005Ool2001oOol008aoo`03001oogoo00Ioo`03
001oogoo00=oo`8000aoo`03001oogoo00Ioo`03001oogoo019oo`03001oogoo00ioo`03001oogoo
00Ioo`03001oogoo08Aoo`00S7oo00<007ooOol01Woo00<007ooOol00goo0P0037oo00<007ooOol0
1Woo00<007ooOol04Woo00<007ooOol017oo1P0017oo00<007ooOol01Woo00<007ooOol0Q7oo002<
Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomoo`002goo00<007ooOol01Woo00<007ooOol0
4Woo00<007ooOol03Woo00<007ooOol017oo0P00Qgoo0029Ool01000Oomoo`000Woo00<007ooOol0
0goo00@007ooOomoo`80009oo`8000Qoo`H000Eoo`03001oogoo011oo`H000eoo`03001oogoo00Io
o`03001oogoo08Aoo`00RGoo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo015oo`03001o
ogoo00Ioo`03001oogoo019oo`03001oogoo00ioo`03001oogoo009oo`05001oogooOol00026Ool0
08Uoo`L000Eoo`80019oo`03001oogoo00Eoo`8001Aoo`03001oogoo00aoo`<000Eoo`<008Moo`00
ogooJGoo003oOomYOol00?moofUoo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.5) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .5574 m
.04057 .49285 L
.08481 .4337 L
.12636 .38854 L
.16632 .35393 L
.20885 .32565 L
.2498 .30574 L
.27217 .2975 L
.29331 .29122 L
.31429 .28632 L
.33365 .28283 L
.35331 .2802 L
.36449 .27909 L
.37497 .27827 L
.38018 .27793 L
.38587 .27763 L
.39088 .2774 L
.39623 .27721 L
.40152 .27707 L
.40631 .27697 L
.40863 .27694 L
.40985 .27693 L
.41113 .27691 L
.41226 .27691 L
.4135 .2769 L
.41463 .27689 L
.41568 .27689 L
.417 .27689 L
.41767 .27689 L
.41841 .27689 L
.41971 .27689 L
.42093 .2769 L
.42163 .2769 L
.42237 .2769 L
.42368 .27691 L
.42665 .27694 L
.42922 .27698 L
.43162 .27702 L
.43705 .27714 L
.44647 .27743 L
.45653 .27784 L
.47894 .2791 L
.5001 .28067 L
.54049 .2844 L
.58346 .28902 L
.62483 .29374 L
.66461 .29824 L
.70697 .30279 L
.74773 .30677 L
.79107 .31047 L
Mistroke
.83282 .31344 L
.87298 .31569 L
.89541 .31669 L
.91571 .31743 L
.93691 .31804 L
.95685 .31845 L
.96713 .3186 L
.97275 .31866 L
.97798 .31871 L
.98282 .31875 L
.98724 .31878 L
.98976 .31879 L
.99214 .3188 L
.99336 .3188 L
.99465 .3188 L
.99608 .3188 L
.99739 .31881 L
.99874 .31881 L
1 .31881 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
00<000Ioo`8000Aoo`D000Aoo`@000Ioo`03001oogoo0?moodAoo`000goo00<007ooOol00goo0P00
1Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007ooOol02goo
00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0<Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03001oogoo00eoo`03001oogoo009oo`@0
00Ioo`03001oogoo0?moodAoo`000goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol0ogooA7oo0003Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol01goo
00<007ooOol0ogooA7oo0003000=Ool30005Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`0027oo0`001Woo0P00
1Goo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol0
0goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000047oo00<007ooOol00goo0`00ogooA7oo
0007Ool01@00Oomoogoo000047oo00<007ooOol00goo00<007ooOol0ogooA7oo0007Ool01@00Oomo
ogoo000037oo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol0
1goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol01goo00<007ooOol0
ogooA7oo0008Ool3000=Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol0
0`00Oomoo`3oOom4Ool000<000Ioo`8000Ioo`03001oogoo00Aoo`@000Ioo`03001oogoo0?moodAo
o`000goo00<007ooOol00goo0P001Woo00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogoo
A7oo0003Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03
001oogoo00aoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007oo
Ool037oo00<007ooOol00goo10001Woo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0=Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000=oo`03001oogoo00Uoo`05001oogoo
Ool00004Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000<000aoo`D000Aoo`@000Ioo`800?mo
odEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo075ooa/00;Mo
o`008Woo0P00IWoo30006goo4000Ygoo000ROol00`00Oomoo`1POol5000gOol9002NOol0029oo`03
001oogoo05]oo`D004Eoo`L009Moo`008Woo00<007ooOol0F7oo0`00DGoo2P00SGoo000ROol2001D
Ool5001NOol90024Ool0029oo`03001oogoo04moo`@006aoo`H007ioo`0067oo1@001Goo00<007oo
Ool0C7oo0`00MWoo2P00M7oo000JOol00`00Oomoo`05Ool00`00Oomoo`1:Ool20023Ool<001XOol0
01Yoo`03001oogoo00Eoo`03001oogoo04Qoo`80095oo`d005]oo`006Woo00<007ooOol01Goo0`00
AWoo0P00X7oo3@00CWoo000JOol00`00Oomoo`05Ool00`00Oomoo`14Ool2002_Ool<0012Ool001Yo
o`03001oogoo00Eoo`03001oogoo049oo`800;eooaH002aoo`006Woo00<007ooOol01Goo00<007oo
Ool0@7oo0P00eGoo5`005Goo000HOol30007Ool00`00Oomoo`0nOol2003oOol4Ool0029oo`8003eo
o`800?moo`Ioo`008Woo00<007ooOol0>goo00<007ooOol0ogoo1Woo000ROol00`00Oomoo`0iOol2
003oOol9Ool0029oo`03001oogoo03Qoo`03001oogoo0?moo`Uoo`008Woo0P00=goo0P00ogoo37oo
000ROol00`00Oomoo`0eOol00`00Oomoo`3oOol<Ool0029oo`03001oogoo03Aoo`03001oogoo0?mo
o`eoo`008Woo00<007ooOol0<Woo0P00ogoo47oo000ROol00`00Oomoo`0aOol00`00Oomoo`3oOol@
Ool0029oo`80031oo`800?mooa=oo`008Woo00<007ooOol0;Woo00<007ooOol0ogoo4goo000ROol0
0`00Oomoo`0]Ool00`00Oomoo`3oOolDOol0029oo`03001oogoo02]oo`800?mooaMoo`008Woo00<0
07ooOol0:Woo00<007ooOol0ogoo5goo000ROol2000ZOol00`00Oomoo`3oOolHOol0029oo`03001o
ogoo02Qoo`03001oogoo0?mooaUoo`001@0017oo0P0017oo1@0017oo10001Woo00<007ooOol09Woo
0P00ogoo77oo0002Ool00`00Oomoo`04Ool20005Ool01000Oomoo`0027oo00<007ooOol00goo00<0
07ooOol09Goo00<007ooOol0ogoo77oo0002Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomo
o`03Ool3000TOol00`00Oomoo`3oOolMOol0009oo`03001oogoo00eoo`03001oogoo00Moo`03001o
ogoo00=oo`03001oogoo02=oo`03001oogoo0?mooaioo`000Woo00<007ooOol03Woo00<007ooOol0
0Woo10001Woo00<007ooOol08goo00<007ooOol0ogoo7Woo0002Ool00`00Oomoo`0>Ool00`00Oomo
o`02Ool00`00Oomoo`07Ool00`00Oomoo`0ROol00`00Oomoo`3oOolOOol0009oo`03001oogoo00Yo
o`05001oogooOol00004Ool00`00Oomoo`07Ool00`00Oomoo`0QOol00`00Oomoo`3oOolPOol000<0
00eoo`<000Eoo`@000Ioo`80025oo`03001oogoo0?moob5oo`008Woo00<007ooOol07goo00<007oo
Ool0ogoo8Woo000ROol00`00Oomoo`0NOol00`00Oomoo`3oOolSOol0029oo`03001oogoo01eoo`03
001oogoo0?moobAoo`008Woo00<007ooOol07Goo00<007ooOol0ogoo97oo000ROol2000MOol00`00
Oomoo`3oOolUOol0029oo`03001oogoo01]oo`03001oogoo0?moobIoo`008Woo00<007ooOol06Woo
00<007ooOol0ogoo9goo000ROol00`00Oomoo`0IOol00`00Oomoo`3oOolXOol0029oo`8001Uoo`03
001oogoo0?moobUoo`008Woo00<007ooOol05goo00<007ooOol0ogoo:Woo000ROol00`00Oomoo`0G
Ool00`00Oomoo`3oOolZOol0029oo`03001oogoo01Ioo`03001oogoo0?moob]oo`008Woo00<007oo
Ool05Goo00<007ooOol0ogoo;7oo000ROol2000EOol00`00Oomoo`3oOol]Ool0029oo`03001oogoo
01=oo`03001oogoo0?moobioo`0027oo1@0017oo0P001Goo10001Woo00<007ooOol04goo00<007oo
Ool0ogoo;Woo000:Ool00`00Oomoo`04Ool20009Ool00`00Oomoo`03Ool00`00Oomoo`0BOol00`00
Oomoo`3oOol_Ool000Yoo`03001oogoo00moo`03001oogoo00=oo`03001oogoo015oo`03001oogoo
0?mooc1oo`002Woo00<007ooOol03goo00<007ooOol00goo0`0047oo00<007ooOol0ogoo<Goo000:
Ool00`00Oomoo`0;Ool40006Ool00`00Oomoo`0@Ool00`00Oomoo`3oOolaOol000Yoo`03001oogoo
00]oo`03001oogoo00Moo`03001oogoo00moo`03001oogoo0?mooc9oo`002Woo00<007ooOol02goo
00<007ooOol01goo00<007ooOol03Woo00<007ooOol0ogoo<goo0008Ool3000=Ool40006Ool00`00
Oomoo`0=Ool00`00Oomoo`3oOoldOol0029oo`8000eoo`03001oogoo0?moocEoo`008Woo00<007oo
Ool037oo00<007ooOol0ogoo=Goo000ROol00`00Oomoo`0;Ool00`00Oomoo`3oOolfOol0029oo`03
001oogoo00Yoo`03001oogoo0?moocMoo`008Woo0P002Woo00<007ooOol0ogoo>7oo000ROol00`00
Oomoo`09Ool00`00Oomoo`3oOolhOol0029oo`03001oogoo00Qoo`03001oogoo0?moocUoo`008Woo
00<007ooOol01goo00<007ooOol0ogoo>Woo000ROol00`00Oomoo`07Ool00`00Oomoo`3oOoljOol0
029oo`8000Moo`03001oogoo0?mooc]oo`008Woo00<007ooOol01Woo00<007ooOol0ogoo>goo000R
Ool00`00Oomoo`05Ool00`00Oomoo`3oOollOol0029oo`03001oogoo00Aoo`03001oogoo0?mooceo
o`008Woo00<007ooOol017oo00<007ooOol0ogoo?Goo000ROol20004Ool00`00Oomoo`3oOolnOol0
029oo`03001oogoo009oo`03001oogoo0?moocmoo`001@0017oo0P001Woo00<007ooOol017oo1000
1Woo00<007ooOol00Woo00<007ooOol0ogoo?goo0002Ool00`00Oomoo`04Ool20006Ool00`00Oomo
o`08Ool00`00Oomoo`03Ool01@00Oomoogoo0000ogoo@Woo0002Ool00`00Oomoo`0=Ool00`00Oomo
o`07Ool00`00Oomoo`03Ool4003oOom3Ool0009oo`03001oogoo00eoo`03001oogoo00Moo`03001o
ogoo00=oo`04001oogoo003oOom3Ool0009oo`03001oogoo00eoo`03001oogoo00=oo`@000Ioo`03
001oo`000?moodAoo`000Woo00<007ooOol03Woo00<007ooOol00Woo00<007ooOol01goo00<007oo
0000ogooA7oo0002Ool00`00Oomoo`0:Ool01@00Oomoogoo000017oo00<007ooOol01goo0P00ogoo
AGoo0003000<Ool50004Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol0
0`00Oomoo`3oOom4Ool001Moo`D000Ioo`03001oogoo0?moodAoo`0067oo00@007ooOol000Ioo`03
001oogoo0?moodAoo`006Goo00<007ooOol01Woo00<007ooOol0ogooA7oo000JOol00`00Oomoo`05
Ool3003oOom4Ool001]oo`03001oogoo0?mood]oo`006goo00<007ooOol0ogooBgoo000GOol01@00
Oomoogoo0000ogooCGoo000HOol3003oOom>Ool00?moofUoo`00TGoo0P002goo00<007ooOol037oo
0P001Goo00<007ooOol0/Goo002AOol00`00Oomoo`0:Ool2000>Ool00`00Oomoo`03Ool2002bOol0
08Ioo`D000Ioo`04001oogooOol20002Ool20004Ool00`00Oomoo`04Ool30005Ool00`00Oomoo`04
Ool00`00Oomoo`0<Ool3000;Ool50003Ool30006Ool20005Ool4001jOol008Qoo`03001oogoo00Io
o`03001oogoo009oo`04001oogoo0005Ool20004Ool01@00Oomoogoo000017oo00<007ooOol017oo
0P0037oo00D007ooOomoo`00009oo`H000Aoo`03001oogoo009oo`05001oogooOol00005Ool20009
Ool00`00Oomoo`1gOol008Qoo`03001oogoo00Ioo`03001oogoo00=oo`8000aoo`03001oogoo00Io
o`03001oogoo019oo`03001oogoo00ioo`03001oogoo00Ioo`03001oogoo00ioo`03001oogoo07Mo
o`00R7oo00<007ooOol01Woo00<007ooOol00goo0P0037oo00<007ooOol01Woo00<007ooOol04Woo
00<007ooOol017oo1P0017oo00<007ooOol01Woo00<007ooOol03Woo00<007ooOol0Mgoo0028Ool0
0`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomoo`002goo00<007ooOol01Woo00<007ooOol04Woo
00<007ooOol03Woo00<007ooOol017oo0P003Goo1000NWoo0025Ool01000Oomoo`000Woo00<007oo
Ool00goo00@007ooOomoo`80009oo`8000Qoo`H000Eoo`03001oogoo011oo`H000eoo`03001oogoo
00Ioo`03001oogoo00Yoo`03001oogoo07]oo`00QGoo00@007ooOol0009oo`03001oogoo00=oo`03
001oogoo015oo`03001oogoo00Ioo`03001oogoo019oo`03001oogoo00ioo`03001oogoo009oo`05
001oogooOol0000<Ool00`00Oomoo`1kOol008Eoo`L000Eoo`80019oo`03001oogoo00Eoo`8001Ao
o`03001oogoo00aoo`<000Eoo`<000eoo`@007Yoo`00ogooJGoo003oOomYOol00?moofUoo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14.) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .61513 m
.04057 .56073 L
.08481 .50604 L
.12636 .46035 L
.16632 .4222 L
.20885 .38796 L
.2498 .36105 L
.29331 .33848 L
.33524 .32202 L
.37557 .31046 L
.3964 .30592 L
.41848 .30205 L
.439 .29924 L
.45821 .29722 L
.46911 .29632 L
.47947 .29561 L
.48967 .29504 L
.49892 .29464 L
.50899 .2943 L
.51451 .29416 L
.51972 .29406 L
.52455 .29399 L
.52899 .29394 L
.53132 .29392 L
.53265 .29392 L
.53387 .29391 L
.53516 .29391 L
.53654 .2939 L
.53781 .2939 L
.53902 .2939 L
.54022 .2939 L
.54151 .2939 L
.54273 .29391 L
.54384 .29391 L
.54643 .29392 L
.54916 .29394 L
.5543 .294 L
.55993 .29408 L
.56995 .29427 L
.57927 .29451 L
.60075 .29525 L
.62027 .29611 L
.66225 .29839 L
.70264 .30091 L
.7456 .30368 L
.78698 .30622 L
.82676 .30841 L
.86911 .31036 L
.90988 .31178 L
.93211 .31235 L
Mistroke
.94234 .31255 L
.95322 .31274 L
.96416 .31289 L
.97406 .31299 L
.97884 .31303 L
.98401 .31306 L
.98639 .31307 L
.98889 .31308 L
.99106 .31309 L
.99338 .31309 L
.9943 .31309 L
.99517 .3131 L
.99602 .3131 L
.9968 .3131 L
.99755 .3131 L
.99834 .3131 L
.99913 .3131 L
1 .3131 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
00<000Ioo`8000Aoo`D000Aoo`@000Ioo`03001oogoo0?moodAoo`000goo00<007ooOol00goo0P00
1Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007ooOol02goo
00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0<Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03001oogoo00eoo`03001oogoo009oo`@0
00Ioo`03001oogoo0?moodAoo`000goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol0ogooA7oo0003Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol01goo
00<007ooOol0ogooA7oo0003000=Ool30005Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`0027oo0`001Woo0P00
1Goo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol0
0goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000047oo00<007ooOol00goo0`00ogooA7oo
0007Ool01@00Oomoogoo000047oo00<007ooOol00goo00<007ooOol0ogooA7oo0007Ool01@00Oomo
ogoo000037oo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol0
1goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol01goo00<007ooOol0
ogooA7oo0008Ool3000=Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol0
0`00Oomoo`3oOom4Ool000<000Ioo`8000Ioo`03001oogoo00Aoo`@000Ioo`03001oogoo0?moodAo
o`000goo00<007ooOol00goo0P001Woo00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogoo
A7oo0003Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03
001oogoo00aoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007oo
Ool037oo00<007ooOol00goo10001Woo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0=Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000=oo`03001oogoo00Uoo`05001oogoo
Ool00004Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000<000aoo`D000Aoo`@000Ioo`800?mo
odEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol2002HOolF002FOol0029oo`03001oogoo08Eooa8001Iooa@0089oo`00
67oo1@001Goo00<007ooOol0Ogoo1P00?7oo6@00JGoo000JOol00`00Oomoo`05Ool00`00Oomoo`1i
Ool6001KOol=001LOol001Yoo`03001oogoo00Eoo`03001oogoo079oo`L006ioo``0051oo`006Woo
00<007ooOol01Goo0`00KWoo1000PGoo6@00=goo000JOol00`00Oomoo`05Ool00`00Oomoo`1[Ool3
002NOolR000EOol001Yoo`03001oogoo00Eoo`03001oogoo06Qoo`<00=Qoo`006Woo00<007ooOol0
1Goo00<007ooOol0IGoo0`00fgoo000HOol30007Ool00`00Oomoo`1ROol3003NOol0029oo`80061o
o`<00>5oo`008Woo00<007ooOol0G7oo0`00i7oo000ROol00`00Oomoo`1JOol2003WOol0029oo`03
001oogoo05Moo`<00>Uoo`008Woo0P00EWoo0P00k7oo000ROol00`00Oomoo`1COol2003^Ool0029o
o`03001oogoo055oo`800?1oo`008Woo00<007ooOol0Cgoo0P00lWoo000ROol00`00Oomoo`1>Ool0
0`00Oomoo`3bOol0029oo`8004eoo`800?Eoo`008Woo00<007ooOol0BWoo0P00mgoo000ROol00`00
Oomoo`18Ool2003iOol0029oo`03001oogoo04Moo`03001oogoo0?Uoo`008Woo00<007ooOol0AGoo
0P00o7oo000ROol20015Ool00`00Oomoo`3lOol0029oo`03001oogoo049oo`800?moo`001@0017oo
0P0017oo1@0017oo10001Woo00<007ooOol0@Goo00<007ooOol0ogoo0002Ool00`00Oomoo`04Ool2
0005Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0?goo0P00ogoo0goo0002Ool00`00
Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`03Ool3000nOol00`00Oomoo`3oOol3Ool0009oo`03
001oogoo00eoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo03aoo`800?moo`Ioo`000Woo
00<007ooOol03Woo00<007ooOol00Woo10001Woo00<007ooOol0>goo00<007ooOol0ogoo1Woo0002
Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0jOol00`00Oomoo`3o
Ool7Ool0009oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00Oomoo`07Ool00`00Oomoo`0h
Ool2003oOol:Ool000<000eoo`<000Eoo`@000Ioo`8003Qoo`03001oogoo0?moo`Yoo`008Woo00<0
07ooOol0=Woo00<007ooOol0ogoo2goo000ROol00`00Oomoo`0eOol00`00Oomoo`3oOol<Ool0029o
o`03001oogoo03=oo`800?moo`moo`008Woo00<007ooOol0<Woo00<007ooOol0ogoo3goo000ROol2
000bOol00`00Oomoo`3oOol@Ool0029oo`03001oogoo02moo`800?mooa=oo`008Woo00<007ooOol0
;Woo00<007ooOol0ogoo4goo000ROol00`00Oomoo`0]Ool00`00Oomoo`3oOolDOol0029oo`8002eo
o`03001oogoo0?mooaEoo`008Woo00<007ooOol0:goo00<007ooOol0ogoo5Woo000ROol00`00Oomo
o`0ZOol00`00Oomoo`3oOolGOol0029oo`03001oogoo02Uoo`03001oogoo0?mooaQoo`008Woo00<0
07ooOol0:7oo00<007ooOol0ogoo6Goo000ROol2000XOol00`00Oomoo`3oOolJOol0029oo`03001o
ogoo02Ioo`03001oogoo0?mooa]oo`0027oo1@0017oo0P001Goo10001Woo00<007ooOol09Goo00<0
07ooOol0ogoo77oo000:Ool00`00Oomoo`04Ool20009Ool00`00Oomoo`03Ool00`00Oomoo`0TOol0
0`00Oomoo`3oOolMOol000Yoo`03001oogoo00moo`03001oogoo00=oo`03001oogoo02=oo`03001o
ogoo0?mooaioo`002Woo00<007ooOol03goo00<007ooOol00goo0`008goo00<007ooOol0ogoo7Woo
000:Ool00`00Oomoo`0;Ool40006Ool00`00Oomoo`0ROol00`00Oomoo`3oOolOOol000Yoo`03001o
ogoo00]oo`03001oogoo00Moo`03001oogoo025oo`03001oogoo0?moob1oo`002Woo00<007ooOol0
2goo00<007ooOol01goo00<007ooOol087oo00<007ooOol0ogoo8Goo0008Ool3000=Ool40006Ool0
0`00Oomoo`0OOol00`00Oomoo`3oOolROol0029oo`8001moo`03001oogoo0?moob=oo`008Woo00<0
07ooOol07Goo00<007ooOol0ogoo97oo000ROol00`00Oomoo`0MOol00`00Oomoo`3oOolTOol0029o
o`03001oogoo01aoo`03001oogoo0?moobEoo`008Woo0P0077oo00<007ooOol0ogoo9Woo000ROol0
0`00Oomoo`0JOol00`00Oomoo`3oOolWOol0029oo`03001oogoo01Uoo`03001oogoo0?moobQoo`00
8Woo00<007ooOol067oo00<007ooOol0ogoo:Goo000ROol00`00Oomoo`0GOol00`00Oomoo`3oOolZ
Ool0029oo`8001Qoo`03001oogoo0?moobYoo`008Woo00<007ooOol05Woo00<007ooOol0ogoo:goo
000ROol00`00Oomoo`0EOol00`00Oomoo`3oOol/Ool0029oo`03001oogoo01Aoo`03001oogoo0?mo
obeoo`008Woo00<007ooOol04goo00<007ooOol0ogoo;Woo000ROol2000COol00`00Oomoo`3oOol_
Ool0029oo`03001oogoo015oo`03001oogoo0?mooc1oo`001@0017oo0P001Woo00<007ooOol017oo
10001Woo00<007ooOol047oo00<007ooOol0ogoo<Goo0002Ool00`00Oomoo`04Ool20006Ool00`00
Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`0@Ool00`00Oomoo`3oOolaOol0009oo`03001oogoo
00eoo`03001oogoo00Moo`03001oogoo00=oo`<000moo`03001oogoo0?mooc9oo`000Woo00<007oo
Ool03Goo00<007ooOol01goo00<007ooOol00goo00<007ooOol03Woo00<007ooOol0ogoo<goo0002
Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool40006Ool00`00Oomoo`0=Ool00`00Oomoo`3oOoldOol0
009oo`03001oogoo00ioo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00aoo`03001oogoo
0?moocEoo`000Woo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo00Moo`03001oogoo
00]oo`03001oogoo0?moocIoo`000`0037oo1@0017oo10001Woo0P002goo00<007ooOol0ogoo=goo
000ROol00`00Oomoo`09Ool00`00Oomoo`3oOolhOol0029oo`03001oogoo00Uoo`03001oogoo0?mo
ocQoo`008Woo00<007ooOol027oo00<007ooOol0ogoo>Goo000ROol00`00Oomoo`07Ool00`00Oomo
o`3oOoljOol0029oo`8000Qoo`03001oogoo0?moocYoo`008Woo00<007ooOol01Woo00<007ooOol0
ogoo>goo000ROol00`00Oomoo`05Ool00`00Oomoo`3oOollOol0029oo`03001oogoo00Aoo`03001o
ogoo0?mooceoo`008Woo0P001Goo00<007ooOol0ogoo?Goo000ROol00`00Oomoo`03Ool00`00Oomo
o`3oOolnOol0029oo`03001oogoo009oo`03001oogoo0?moocmoo`008Woo00<007ooOol00Woo00<0
07ooOol0ogoo?goo000ROol01@00Oomoogoo0000ogoo@Woo000ROol200000goo001oo`3oOom2Ool0
029oo`03001oo`000?moodAoo`005goo1@001Woo00<007oo0000ogooA7oo000HOol01000Oomoo`00
1Woo0P00ogooAGoo000IOol00`00Oomoo`06Ool00`00Oomoo`3oOom4Ool001Yoo`03001oogoo00Eo
o`<00?moodAoo`006goo00<007ooOol0ogooBgoo000KOol00`00Oomoo`3oOom;Ool001Moo`05001o
ogooOol0003oOom=Ool001Qoo`<00?moodioo`00ogooJGoo002EOol2000;Ool00`00Oomoo`0<Ool2
0005Ool00`00Oomoo`2]Ool009Eoo`03001oogoo00Yoo`8000ioo`03001oogoo00=oo`800:ioo`00
RWoo1@001Woo00@007ooOomoo`80009oo`8000Aoo`03001oogoo00Aoo`<000Eoo`03001oogoo00Ao
o`03001oogoo00aoo`<000]oo`D000Aoo`<000Eoo`8007moo`00S7oo00<007ooOol01Woo00<007oo
Ool00Woo00@007ooOol000Eoo`8000Aoo`05001oogooOol00004Ool00`00Oomoo`04Ool2000<Ool0
1@00Oomoogoo00000Woo1P0017oo00<007ooOol01Goo00<007ooOol017oo0P00Ogoo002<Ool00`00
Oomoo`06Ool00`00Oomoo`03Ool2000<Ool00`00Oomoo`06Ool00`00Oomoo`0BOol00`00Oomoo`0>
Ool00`00Oomoo`02Ool50026Ool008aoo`03001oogoo00Ioo`03001oogoo00=oo`8000aoo`03001o
ogoo00Ioo`03001oogoo019oo`03001oogoo00Aoo`H000Aoo`03001oogoo009oo`04001oogoo0027
Ool008aoo`03001oogoo00Ioo`03001oogoo009oo`04001oogoo000;Ool00`00Oomoo`06Ool00`00
Oomoo`0BOol00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Ool00027Ool008Uoo`04001oogoo0002
Ool00`00Oomoo`03Ool01000Oomoogoo0P000Woo0P0027oo1P001Goo00<007ooOol047oo1P003Goo
00<007ooOol00goo00<007oo0000Qgoo0029Ool01000Oomoo`000Woo00<007ooOol00goo00<007oo
Ool04Goo00<007ooOol01Woo00<007ooOol04Woo00<007ooOol03Woo00<007ooOol017oo0P00Qgoo
0029Ool70005Ool2000BOol00`00Oomoo`05Ool2000DOol00`00Oomoo`0<Ool30007Ool00`00Oomo
o`25Ool00?moofUoo`00ogooJGoo003oOomYOol00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14.5) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .59792 m
.04057 .56715 L
.08481 .53047 L
.12636 .49561 L
.16632 .46341 L
.20885 .43176 L
.2498 .40459 L
.29331 .37964 L
.33524 .35955 L
.37557 .34375 L
.41848 .33047 L
.4598 .32076 L
.49953 .31391 L
.51991 .31122 L
.54183 .30887 L
.56402 .30702 L
.58512 .30569 L
.59518 .30518 L
.60591 .30473 L
.61597 .30438 L
.62522 .30412 L
.63602 .30389 L
.6417 .30379 L
.6477 .30371 L
.65292 .30366 L
.6578 .30362 L
.6606 .3036 L
.66315 .30358 L
.66456 .30358 L
.66609 .30357 L
.66755 .30357 L
.66888 .30357 L
.67007 .30356 L
.67133 .30356 L
.67259 .30356 L
.67397 .30356 L
.67517 .30356 L
.67645 .30356 L
.67765 .30357 L
.67875 .30357 L
.68144 .30357 L
.68435 .30359 L
.68964 .30361 L
.69522 .30365 L
.70112 .30371 L
.7117 .30383 L
.73225 .30415 L
.75148 .30453 L
.79225 .30549 L
.83559 .30658 L
Mistroke
.87734 .30753 L
.9175 .30826 L
.93819 .30854 L
.94879 .30866 L
.96023 .30876 L
.97091 .30883 L
.97559 .30886 L
.98072 .30888 L
.98558 .30889 L
.9901 .3089 L
.9926 .30891 L
.99488 .30891 L
.99614 .30891 L
.99751 .30891 L
.99881 .30891 L
1 .30891 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
00<000Ioo`8000Aoo`D000Aoo`@000Ioo`03001oogoo0?moodAoo`000goo00<007ooOol00goo0P00
1Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007ooOol02goo
00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0<Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03001oogoo00eoo`03001oogoo009oo`@0
00Ioo`03001oogoo0?moodAoo`000goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol0ogooA7oo0003Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol01goo
00<007ooOol0ogooA7oo0003000=Ool30005Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`0027oo0`001Woo0P00
1Goo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol0
0goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000047oo00<007ooOol00goo0`00ogooA7oo
0007Ool01@00Oomoogoo000047oo00<007ooOol00goo00<007ooOol0ogooA7oo0007Ool01@00Oomo
ogoo000037oo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol0
1goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol01goo00<007ooOol0
ogooA7oo0008Ool3000=Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol0
0`00Oomoo`3oOom4Ool000<000Ioo`8000Ioo`03001oogoo00Aoo`@000Ioo`03001oogoo0?moodAo
o`000goo00<007ooOol00goo0P001Woo00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogoo
A7oo0003Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03
001oogoo00aoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007oo
Ool037oo00<007ooOol00goo10001Woo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0=Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000=oo`03001oogoo00Uoo`05001oogoo
Ool00004Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000<000aoo`D000Aoo`@000Ioo`800?mo
odEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`0067oo1@001Goo00<0
07ooOol0ogooA7oo000JOol00`00Oomoo`05Ool00`00Oomoo`2jOolU001TOol001Yoo`03001oogoo
00Eoo`03001oogoo0:EooaD002Eooc0003Aoo`006Woo00<007ooOol01Goo0`00Wgoo1P00JWoo7`00
5Goo000JOol00`00Oomoo`05Ool00`00Oomoo`2BOol=002TOol001Yoo`03001oogoo00Eoo`03001o
ogoo08aoo`H00;5oo`006Woo00<007ooOol01Goo00<007ooOol0Qgoo1@00]goo000HOol30007Ool0
0`00Oomoo`22Ool5002lOol0029oo`8007moo`@00<5oo`008Woo00<007ooOol0NWoo1000aGoo000R
Ool00`00Oomoo`1gOol30039Ool0029oo`03001oogoo07Aoo`<00<aoo`008Woo0P00LWoo0`00cgoo
000ROol00`00Oomoo`1^Ool3003BOol0029oo`03001oogoo06]oo`<00=Eoo`008Woo00<007ooOol0
JGoo0P00f7oo000ROol00`00Oomoo`1WOol2003JOol0029oo`8006Eoo`<00=aoo`008Woo00<007oo
Ool0HWoo0P00ggoo000ROol00`00Oomoo`1POol2003QOol0029oo`03001oogoo05ioo`800>=oo`00
8Woo00<007ooOol0Fgoo0`00iGoo000ROol2001JOol2003XOol0029oo`03001oogoo05Moo`800>Yo
o`001@0017oo0P0017oo1@0017oo10001Woo00<007ooOol0EGoo0P00k7oo0002Ool00`00Oomoo`04
Ool20005Ool01000Oomoo`0027oo00<007ooOol00goo00<007ooOol0E7oo00<007ooOol0k7oo0002
Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`03Ool3001BOol2003_Ool0009oo`03001o
ogoo00eoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo051oo`800?5oo`000Woo00<007oo
Ool03Woo00<007ooOol00Woo10001Woo00<007ooOol0Cgoo00<007ooOol0lGoo0002Ool00`00Oomo
o`0>Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`1=Ool2003dOol0009oo`03001oogoo
00Yoo`05001oogooOol00004Ool00`00Oomoo`07Ool00`00Oomoo`1;Ool2003fOol000<000eoo`<0
00Eoo`@000Ioo`8004]oo`03001oogoo0?Ioo`008Woo00<007ooOol0B7oo0P00nGoo000ROol00`00
Oomoo`17Ool00`00Oomoo`3iOol0029oo`03001oogoo04Eoo`800?aoo`008Woo00<007ooOol0A7oo
00<007ooOol0o7oo000ROol20013Ool2003oOol0029oo`03001oogoo045oo`03001oogoo0?moo`00
8Woo00<007ooOol0?goo0P00ogoo0goo000ROol00`00Oomoo`0nOol00`00Oomoo`3oOol3Ool0029o
o`8003eoo`800?moo`Ioo`008Woo00<007ooOol0>goo00<007ooOol0ogoo1Woo000ROol00`00Oomo
o`0jOol00`00Oomoo`3oOol7Ool0029oo`03001oogoo03Qoo`800?moo`Yoo`008Woo00<007ooOol0
=goo00<007ooOol0ogoo2Woo000ROol2000gOol00`00Oomoo`3oOol;Ool0029oo`03001oogoo03Eo
o`03001oogoo0?moo`aoo`0027oo1@0017oo0P001Goo10001Woo00<007ooOol0<goo0P00ogoo3goo
000:Ool00`00Oomoo`04Ool20009Ool00`00Oomoo`03Ool00`00Oomoo`0bOol00`00Oomoo`3oOol?
Ool000Yoo`03001oogoo00moo`03001oogoo00=oo`03001oogoo035oo`03001oogoo0?mooa1oo`00
2Woo00<007ooOol03goo00<007ooOol00goo0`00;goo0P00ogoo4goo000:Ool00`00Oomoo`0;Ool4
0006Ool00`00Oomoo`0^Ool00`00Oomoo`3oOolCOol000Yoo`03001oogoo00]oo`03001oogoo00Mo
o`03001oogoo02eoo`03001oogoo0?mooaAoo`002Woo00<007ooOol02goo00<007ooOol01goo00<0
07ooOol0:goo0P00ogoo5goo0008Ool3000=Ool40006Ool00`00Oomoo`0ZOol00`00Oomoo`3oOolG
Ool0029oo`8002Yoo`03001oogoo0?mooaQoo`008Woo00<007ooOol0:7oo00<007ooOol0ogoo6Goo
000ROol00`00Oomoo`0VOol2003oOolLOol0029oo`03001oogoo02Eoo`03001oogoo0?mooaaoo`00
8Woo0P009Goo00<007ooOol0ogoo7Goo000ROol00`00Oomoo`0ROol2003oOolPOol0029oo`03001o
ogoo025oo`03001oogoo0?moob1oo`008Woo00<007ooOol087oo00<007ooOol0ogoo8Goo000ROol0
0`00Oomoo`0OOol00`00Oomoo`3oOolROol0029oo`8001moo`03001oogoo0?moob=oo`008Woo00<0
07ooOol077oo0P00ogoo9Woo000ROol00`00Oomoo`0KOol00`00Oomoo`3oOolVOol0029oo`03001o
ogoo01Yoo`03001oogoo0?moobMoo`008Woo00<007ooOol06Goo00<007ooOol0ogoo:7oo000ROol2
000IOol00`00Oomoo`3oOolYOol0029oo`03001oogoo01Ioo`800?moobaoo`001@0017oo0P001Woo
00<007ooOol017oo10001Woo00<007ooOol05Goo00<007ooOol0ogoo;7oo0002Ool00`00Oomoo`04
Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`0DOol00`00Oomoo`3oOol]Ool0
009oo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00=oo`<001=oo`03001oogoo0?moobio
o`000Woo00<007ooOol03Goo00<007ooOol01goo00<007ooOol00goo00<007ooOol04Goo0P00ogoo
<Goo0002Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool40006Ool00`00Oomoo`0@Ool00`00Oomoo`3o
OolaOol0009oo`03001oogoo00ioo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00moo`03
001oogoo0?mooc9oo`000Woo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo00Moo`03
001oogoo00eoo`800?moocEoo`000`0037oo1@0017oo10001Woo0P003Goo00<007ooOol0ogoo=Goo
000ROol00`00Oomoo`0;Ool00`00Oomoo`3oOolfOol0029oo`03001oogoo00Yoo`03001oogoo0?mo
ocMoo`008Woo00<007ooOol027oo0P00ogoo>Woo000ROol00`00Oomoo`07Ool00`00Oomoo`3oOolj
Ool0029oo`8000Moo`03001oogoo0?mooc]oo`008Woo00<007ooOol01Goo00<007ooOol0ogoo?7oo
000ROol00`00Oomoo`04Ool00`00Oomoo`3oOolmOol0029oo`03001oogoo009oo`800?mood1oo`00
8Woo0P000Woo00<007ooOol0ogoo@7oo000ROol01000Oomoo`00ogoo@goo000ROol00`00Ool0003o
Oom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03
001oogoo0?moodAoo`005goo1@001Woo00<007ooOol0ogooA7oo000HOol01000Oomoo`001Woo00<0
07ooOol0ogooA7oo000IOol00`00Oomoo`06Ool00`00Oomoo`3oOom4Ool001Yoo`03001oogoo00Eo
o`<00?moodAoo`006goo00<007ooOol0ogooBgoo000KOol00`00Oomoo`3oOom;Ool001Moo`05001o
ogooOol0003oOom=Ool001Qoo`<00?moodioo`00ogooJGoo002AOol2000;Ool00`00Oomoo`0<Ool2
0005Ool00`00Oomoo`2aOol0095oo`03001oogoo00Yoo`8000ioo`03001oogoo00=oo`800;9oo`00
QWoo1@001Woo00@007ooOomoo`80009oo`8000Aoo`03001oogoo00Aoo`<000Eoo`03001oogoo00Ao
o`03001oogoo00aoo`<000]oo`D000Aoo`<000Eoo`8000Eoo`@007Yoo`00R7oo00<007ooOol01Woo
00<007ooOol00Woo00@007ooOol000Eoo`8000Aoo`05001oogooOol00004Ool00`00Oomoo`04Ool2
000<Ool01@00Oomoogoo00000Woo1P0017oo00<007ooOol01Goo00<007ooOol017oo0P002Goo00<0
07ooOol0Mgoo0028Ool00`00Oomoo`06Ool00`00Oomoo`03Ool2000<Ool00`00Oomoo`06Ool00`00
Oomoo`0BOol00`00Oomoo`0>Ool00`00Oomoo`02Ool5000@Ool00`00Oomoo`1gOol008Qoo`03001o
ogoo00Ioo`03001oogoo00=oo`8000aoo`03001oogoo00Ioo`03001oogoo019oo`03001oogoo00Ao
o`H000Aoo`03001oogoo009oo`04001oogoo000AOol00`00Oomoo`1gOol008Qoo`03001oogoo00Io
o`03001oogoo009oo`04001oogoo000;Ool00`00Oomoo`06Ool00`00Oomoo`0BOol00`00Oomoo`0>
Ool00`00Oomoo`03Ool00`00Ool0000=Ool4001jOol008Eoo`04001oogoo0002Ool00`00Oomoo`03
Ool01000Oomoogoo0P000Woo0P0027oo1P001Goo00<007ooOol047oo1P003Goo00<007ooOol00goo
00<007oo00003Goo00<007ooOol0Ngoo0025Ool01000Oomoo`000Woo00<007ooOol00goo00<007oo
Ool04Goo00<007ooOol01Woo00<007ooOol04Woo00<007ooOol03Woo00<007ooOol017oo0P003Goo
00<007ooOol0Ngoo0025Ool70005Ool2000BOol00`00Oomoo`05Ool2000DOol00`00Oomoo`0<Ool3
0007Ool00`00Oomoo`0;Ool4001jOol00?moofUoo`00ogooJGoo003oOomYOol00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.309017 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15.) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .50997 m
.00488 .51062 L
.00942 .51107 L
.01204 .51126 L
.01441 .5114 L
.01573 .51145 L
.01716 .5115 L
.0185 .51154 L
.01975 .51156 L
.02094 .51157 L
.02223 .51157 L
.02345 .51157 L
.02456 .51155 L
.02586 .51153 L
.02727 .51148 L
.02985 .51138 L
.03254 .51122 L
.03541 .51101 L
.04057 .51052 L
.04631 .5098 L
.05251 .50883 L
.06377 .50661 L
.08481 .501 L
.12786 .48503 L
.16932 .46599 L
.20919 .44612 L
.25164 .42474 L
.29249 .40498 L
.33592 .38564 L
.37776 .36907 L
.41801 .35526 L
.46083 .3429 L
.50206 .33319 L
.5417 .32573 L
.58391 .31958 L
.62453 .31518 L
.64516 .31343 L
.66773 .31185 L
.70933 .30971 L
.72992 .30896 L
.75192 .30835 L
.77434 .30789 L
.78461 .30772 L
.79549 .30758 L
.8055 .30747 L
.81651 .30737 L
.82645 .3073 L
.83588 .30724 L
.84655 .3072 L
.8563 .30717 L
Mistroke
.86175 .30715 L
.8668 .30714 L
.87234 .30713 L
.87521 .30713 L
.87824 .30713 L
.88093 .30713 L
.88388 .30712 L
.88657 .30712 L
.88777 .30712 L
.88907 .30712 L
.88986 .30712 L
.89059 .30712 L
.89127 .30712 L
.89203 .30712 L
.89333 .30712 L
.89472 .30712 L
.8955 .30712 L
.89622 .30712 L
.89701 .30712 L
.89784 .30712 L
.89924 .30712 L
.90077 .30712 L
.90355 .30712 L
.90608 .30712 L
.91175 .30713 L
.92196 .30713 L
.94384 .30715 L
.96399 .30717 L
.97304 .30717 L
.98149 .30718 L
.98575 .30718 L
.99031 .30718 L
.99291 .30718 L
.99419 .30718 L
.99538 .30718 L
.99645 .30718 L
.99759 .30718 L
.99874 .30718 L
1 .30718 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool003Yoo`<000Ioo`8000Aoo`D000Aoo`@000ioo`<000Ioo`8000Eoo`@000ioo`<000Ioo`8000Io
o`03001oogoo00Aoo`@001Ioo`D001Eoo`D000Aoo`8000Aoo`D000Aoo`@000ioo`D000Aoo`8000Eo
o`@000ioo`D000Aoo`8000Ioo`03001oogoo00Aoo`@001Eoo`D001Aoo`00>Goo00D007ooOomoo`00
00Eoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo0P002Goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001o
ogoo01Moo`03001oogoo00Aoo`8000Eoo`04001oogoo0008Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool20009Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0C
Ool01000Oomoo`0057oo000iOol01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol02Woo
00D007ooOomoo`00011oo`03001oogoo00Yoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00
Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00
Oomoo`0DOol003Uoo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00Oomo
ogoo000047oo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo00Moo`03001oogoo01Eo
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo01=o
o`00>Goo00D007ooOomoo`0000moo`03001oogoo009oo`@000eoo`05001oogooOol0000<Ool4000=
Ool01@00Oomoogoo00003Woo00<007ooOol00goo100067oo00<007ooOol05goo00<007ooOol03Woo
00<007ooOol00Woo100047oo00<007ooOol02goo100047oo00<007ooOol03Goo00<007ooOol00goo
10006Goo00<007ooOol04Woo000iOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
3Woo00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0
0`00Oomoo`0BOol003Uoo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol03Woo
00D007ooOomoo`0000aoo`03001oogoo00ioo`05001oogooOol0000;Ool01@00Oomoogoo000017oo
00<007ooOol06Goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00
Oomoo`0FOol01@00Oomoogoo000057oo000jOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3
000<Ool50004Ool4000FOol3000GOol3000=Ool30005Ool4000>Ool3000=Ool4000>Ool3000<Ool5
0004Ool4000FOol3000EOol00?moofUoo`00ogooJGoo003oOomNOol20002Ool20005Ool00?mooemo
o`04001oogoo0006Ool00?moof1oo`8000Moo`008Wooo`00<P0037oo0P001goo000ROol00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool01000Oomoo`001Woo000ROol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0SOol0
0`00Oomoo`08Ool20002Ool20005Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogoo
A7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000R
Ool00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00
Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol2003o
Oom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0
00<000Ioo`8000Aoo`D000Aoo`@000Ioo`03001oogoo0?moodAoo`000goo00<007ooOol00goo0P00
1Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007ooOol02goo
00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0<Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03001oogoo00eoo`03001oogoo009oo`@0
00Ioo`03001oogoo0?moodAoo`000goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol0ogooA7oo0003Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol01goo
00<007ooOol0ogooA7oo0003000=Ool30005Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00
ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`0027oo0`001Woo0P00
1Goo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo00001Goo0P002Goo00<007ooOol0
0goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000047oo00<007ooOol00goo0`00ogooA7oo
0007Ool01@00Oomoogoo000047oo00<007ooOol00goo00<007ooOol0ogooA7oo0007Ool01@00Oomo
ogoo000037oo10001Woo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol0
1goo00<007ooOol0ogooA7oo0007Ool01@00Oomoogoo000037oo00<007ooOol01goo00<007ooOol0
ogooA7oo0008Ool3000=Ool40006Ool2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0
ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0
ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo
000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol0
0`00Oomoo`3oOom4Ool000<000Ioo`8000Ioo`03001oogoo00Aoo`@000Ioo`03001oogoo0?moodAo
o`000goo00<007ooOol00goo0P001Woo00<007ooOol027oo00<007ooOol00goo00<007ooOol0ogoo
A7oo0003Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`03Ool3003oOom4Ool000=oo`03
001oogoo00aoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo0?moodAoo`000goo00<007oo
Ool037oo00<007ooOol00goo10001Woo00<007ooOol0ogooA7oo0003Ool00`00Oomoo`0=Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000=oo`03001oogoo00Uoo`05001oogoo
Ool00004Ool00`00Oomoo`07Ool00`00Oomoo`3oOom4Ool000<000aoo`D000Aoo`@000Ioo`800?mo
odEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?mo
odAoo`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`00
8Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`00
8Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<0
07ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`0067oo1@001Goo00<0
07ooOol0ogooA7oo000JOol00`00Oomoo`05Ool00`00Oomoo`3oOom4Ool001Yoo`03001oogoo00Eo
o`03001oogoo0?5oocd001Eoo`006Woo00<007ooOol01Goo0`00cWoo8`00DWoo000JOol00`00Oomo
o`05Ool00`00Oomoo`2nOol@001eOol001Yoo`03001oogoo00Eoo`03001oogoo0;Eoo`T008Eoo`00
6Woo00<007ooOol01Goo00<007ooOol0Zgoo2P00SWoo000HOol30007Ool00`00Oomoo`2UOol6002H
Ool0029oo`800:1oo`H009ioo`008Woo00<007ooOol0V7oo1`00Y7oo000ROol00`00Oomoo`2COol5
002[Ool0029oo`03001oogoo08moo`@00;1oo`008Woo0P00S7oo1000]7oo000ROol00`00Oomoo`27
Ool4002hOol0029oo`03001oogoo08Aoo`<00;aoo`008Woo00<007ooOol0PGoo0`00_goo000ROol0
0`00Oomoo`1nOol30032Ool0029oo`8007aoo`<00<Eoo`008Woo00<007ooOol0N7oo0`00b7oo000R
Ool00`00Oomoo`1eOol3003;Ool0029oo`03001oogoo079oo`<00<ioo`008Woo00<007ooOol0Kgoo
0`00dGoo000ROol2001]Ool3003DOol0029oo`03001oogoo06Uoo`<00=Moo`001@0017oo0P0017oo
1@0017oo10001Woo00<007ooOol0Igoo0P00fWoo0002Ool00`00Oomoo`04Ool20005Ool01000Oomo
o`0027oo00<007ooOol00goo00<007ooOol0I7oo0`00g7oo0002Ool00`00Oomoo`0<Ool00`00Oomo
o`08Ool00`00Oomoo`03Ool3001ROol2003OOol0009oo`03001oogoo00eoo`03001oogoo00Moo`03
001oogoo00=oo`03001oogoo061oo`800>5oo`000Woo00<007ooOol03Woo00<007ooOol00Woo1000
1Woo00<007ooOol0GWoo0P00hgoo0002Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`07
Ool00`00Oomoo`1KOol3003UOol0009oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00Oomo
o`07Ool00`00Oomoo`1IOol2003XOol000<000eoo`<000Eoo`@000Ioo`8005Qoo`800>Yoo`008Woo
00<007ooOol0EGoo0P00k7oo000ROol00`00Oomoo`1COol2003^Ool0029oo`03001oogoo055oo`80
0?1oo`008Woo00<007ooOol0CWoo0`00lWoo000ROol2001=Ool2003eOol0029oo`03001oogoo04Yo
o`800?Moo`008Woo00<007ooOol0B7oo0P00nGoo000ROol00`00Oomoo`16Ool2003kOol0029oo`80
04Ioo`03001oogoo0?]oo`008Woo00<007ooOol0@goo0P00oWoo000ROol00`00Oomoo`11Ool2003o
Ool1Ool0029oo`03001oogoo041oo`03001oogoo0?moo`5oo`008Woo00<007ooOol0?Woo0P00ogoo
17oo000ROol2000mOol2003oOol6Ool0029oo`03001oogoo03Yoo`800?moo`Qoo`0027oo1@0017oo
0P001Goo10001Woo00<007ooOol0>7oo0P00ogoo2Woo000:Ool00`00Oomoo`04Ool20009Ool00`00
Oomoo`03Ool00`00Oomoo`0fOol2003oOol<Ool000Yoo`03001oogoo00moo`03001oogoo00=oo`03
001oogoo03Aoo`800?moo`ioo`002Woo00<007ooOol03goo00<007ooOol00goo0`00<Woo0P00ogoo
47oo000:Ool00`00Oomoo`0;Ool40006Ool00`00Oomoo`0`Ool2003oOolBOol000Yoo`03001oogoo
00]oo`03001oogoo00Moo`03001oogoo02eoo`<00?mooaAoo`002Woo00<007ooOol02goo00<007oo
Ool01goo00<007ooOol0:Woo0`00ogoo5goo0008Ool3000=Ool40006Ool00`00Oomoo`0XOol2003o
OolJOol0029oo`8002Ioo`<00?mooaaoo`008Woo00<007ooOol08goo0P00ogoo7goo000ROol00`00
Oomoo`0POol3003oOolQOol0029oo`03001oogoo01eoo`<00?moobAoo`008Woo0P0077oo0P00ogoo
9goo000ROol00`00Oomoo`0HOol3003oOolYOol0029oo`03001oogoo01Eoo`<00?moobaoo`008Woo
00<007ooOol04Woo0`00ogoo;goo000ROol00`00Oomoo`0?Ool3003oOolbOol0029ooa800?moocEo
o`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`03001oogoo0?moodAo
o`008Woo00<007ooOol0ogooA7oo000ROol2003oOom5Ool0029oo`03001oogoo0?moodAoo`001@00
17oo0P001Woo00<007ooOol017oo10001Woo00<007ooOol0ogooA7oo0002Ool00`00Oomoo`04Ool2
0006Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`3oOom4Ool0009oo`03001oogoo00eo
o`03001oogoo00Moo`03001oogoo00=oo`<00?moodAoo`000Woo00<007ooOol03Goo00<007ooOol0
1goo00<007ooOol00goo00<007ooOol0ogooA7oo0002Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool4
0006Ool00`00Oomoo`3oOom4Ool0009oo`03001oogoo00ioo`03001oogoo009oo`03001oogoo00Mo
o`03001oogoo0?moodAoo`000Woo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo00Mo
o`03001oogoo0?moodAoo`000`0037oo1@0017oo10001Woo0P00ogooAGoo000ROol00`00Oomoo`3o
Oom4Ool0029oo`03001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3o
Oom4Ool0029oo`800?moodEoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0
029oo`03001oogoo0?moodAoo`008Woo0P00ogooAGoo000ROol00`00Oomoo`3oOom4Ool0029oo`03
001oogoo0?moodAoo`008Woo00<007ooOol0ogooA7oo000ROol00`00Oomoo`3oOom4Ool0029oo`80
0?moodEoo`008Woo00<007ooOol0ogooA7oo000GOol50006Ool00`00Oomoo`3oOom4Ool001Qoo`04
001oogoo0006Ool00`00Oomoo`3oOom4Ool001Uoo`03001oogoo00Ioo`03001oogoo0?moodAoo`00
6Woo00<007ooOol01Goo0`00ogooA7oo000KOol00`00Oomoo`3oOom;Ool001]oo`03001oogoo0?mo
od]oo`005goo00D007ooOomoo`000?moodeoo`0067oo0`00ogooCWoo003oOomYOol009Eoo`8000]o
o`03001oogoo00aoo`8000Eoo`03001oogoo0:eoo`00UGoo00<007ooOol02Woo0P003Woo00<007oo
Ool00goo0P00[Woo002:Ool50006Ool01000Oomoogoo0P000Woo0P0017oo00<007ooOol017oo0`00
1Goo00<007ooOol017oo00<007ooOol037oo0`002goo1@000goo10001Goo0P00Ogoo002<Ool00`00
Oomoo`06Ool00`00Oomoo`02Ool01000Oomoo`001Goo0P0017oo00D007ooOomoo`0000Aoo`03001o
ogoo00Aoo`8000aoo`05001oogooOol00002Ool60004Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2
001oOol008aoo`03001oogoo00Ioo`03001oogoo00=oo`8000aoo`03001oogoo00Ioo`03001oogoo
019oo`03001oogoo00ioo`03001oogoo00Moo`03001oogoo08=oo`00S7oo00<007ooOol01Woo00<0
07ooOol00goo0P0037oo00<007ooOol01Woo00<007ooOol04Woo00<007ooOol017oo1P0017oo00<0
07ooOol01goo00<007ooOol0Pgoo002<Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomoo`00
2goo00<007ooOol01Woo00<007ooOol04Woo00<007ooOol03Woo00<007ooOol00goo1000QWoo0029
Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOomoo`80009oo`8000Qoo`H000Eoo`03001o
ogoo011oo`H000eoo`03001oogoo00=oo`03001oogoo08Moo`00RGoo00@007ooOol0009oo`03001o
ogoo00=oo`03001oogoo015oo`03001oogoo00Ioo`03001oogoo019oo`03001oogoo00ioo`03001o
ogoo00=oo`03001oogoo08Moo`00RGoo1`001Goo0P004Woo00<007ooOol01Goo0P0057oo00<007oo
Ool037oo0`001Goo1000QWoo003oOomYOol00?moofUoo`00ogooJGoo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "This solution exhibits the same behavior as was observed in Example 1 of \
Sec. ",
  ButtonBox["4.2.2",
    ButtonData:>{"Chapter4.nb", "c:20"},
    ButtonStyle->"Hyperlink"],
  ", where we solved a similar problem using the exact eigenmodes for the \
system. The temperature oscillations only penetrate a short distance into the \
material before they are averaged out."
}], "Text"],

Cell["\<\
\tBelow, we collect the Galerkin method commands in one \
module:\
\>", "Text",
  CellTags->"i:13"],

Cell[BoxData[
    RowBox[{\(galerkint[M_, \[Tau]_]\), " ", ":=", " ", 
      RowBox[{"Module", "[", 
        RowBox[{\({u, v, norm, L, eq, ic, eqns, vars}\), ",", 
          "\[IndentingNewLine]", 
          
          StyleBox[\( (*\ 
              define\ the\ function\ u\ used\ to\ match\ inhomogeneous\ \
boundary\ conditions, \ if\ any\ *) \),
            FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
          
          RowBox[{\(u[x_, t_]\  = \ T1[t]\), " ", ";", "\[IndentingNewLine]", 
            
            
            StyleBox[\( (*\ define\ the\ basis\ \(\(functions\)\(:\)\)\ *) \),
              
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(v[n_, x_]\  = \ 
              x\^n\ \ \((1 - n\/\(n + 1\)\ \((x/b)\))\)\), ";", 
            "\[IndentingNewLine]", 
            RowBox[{
              StyleBox["(*",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[" ",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[\(define\ the\ inner\ product\),
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[
                RowBox[{
                  StyleBox[" ",
                    FontColor->RGBColor[1, 0, 0]], " "}]], 
              StyleBox["*)",
                FontColor->RGBColor[1, 0, 0]]}], 
            "\[IndentingNewLine]", \(norm[f_, g_]\  := \ 
              Integrate[f\ g, {x, 0, b}]\), " ", ";", "\[IndentingNewLine]", 
            StyleBox[\( (*\ define\ the\ \(\(operator\)\(:\)\)\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(L\&^[f_]\  := \ \[Chi]\ D[f, {x, 2}]\), 
            " ", ";", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                determine\ the\ projection\ of\ the\ operator\ onto\ the\ \
basis\ \(\(functions\)\(:\)\)\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(L[m_, n_]\  := \ 
              norm[v[m, x], \ L\&^[v[n, x]]]\), ";", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                determine\ the\ norm\ of\ the\ basis\ functions\ with\ each\ \
other . \ 
                    Use\ symmetry\ of\ the\ norm\ to\ reduce\ the\ number\ of\
\ integrals\ that\ need\ be\ done; \ 
                remember\ their\ \(\(values\)\(.\)\)\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(nm[n_, 
                m_]\  := \ \((nm[n, m]\  = \ norm[v[m, x], v[n, x]]\ )\) /; 
                n \[GreaterEqual] \ m\), "  ", ";", 
            "\[IndentingNewLine]", \(nm[n_, m_]\  := \ 
              nm[m, n]\  /; \ n < m\), "  ", ";", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                determine\ the\ projection\ of\ S\&_\ onto\ the\ basis\ \
\(\(functions\)\(:\)\)\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(S\&_[m_]\  := \ 
              norm[v[m, x], \ 
                S[x, t] - 
                  D[u[x, t], t]\  + \ \ \(\(\ \)\(L\)\)\&^[u[x, t]]]\), ";", 
            "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                define\ the\ equations\ for\ the\ Fourier\ coefficients\ \(c[
                      n]\)[t]\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(eq[m_]\  := \(eq[m]\  = \ 
                Sum[nm[m, n]\ D[\(c[n]\)[t], t], {n, 1, M}]\  \[Equal] \ 
                  Sum[L[m, n]\ \(c[n]\)[t], {n, 1, M}]\  + \ \ S\&_[m]\)\), 
            ";", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                Print\ out\ the\ equations\ \((not\ necessary, \ 
                    but\ a\ useful\ check)\)\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(Do[
              Print["\<eq[\>", m, "\<]= \>", eq[m]], {m, 1, M}]\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ define\ the\ initial\ conditions\ \ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(ic[m_]\  := \ \(ic[m]\  = \ 
                Sum[nm[m, n]\ \(c[n]\)[0], {n, 1, M}]\  \[Equal] \ 
                  norm[v[m, x], T0[x] - u[x, 0]]\)\), ";", 
            "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                Print\ out\ the\ initial\ conditions\ \((not\ necessary, \ 
                    but\ a\ useful\ check)\)\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(Do[
              Print["\<ic[\>", m, "\<]= \>", ic[m]], {m, 1, M}]\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ create\ lists\ of\ equations, \ variables\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(eqns\  = \ 
              Join[Table[eq[m], {m, 1, M}], Table[ic[m], {m, 1, M}]]\), ";", 
            "\[IndentingNewLine]", \(vars\  = \ 
              Table[\(c[m]\)[t], {m, 1, M}]\), ";", "\[IndentingNewLine]", 
            StyleBox[\( (*\ solve\ the\ equations\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(coefficients\  = \ \(NDSolve[eqns, 
                  vars, {t, 0, \[Tau]}]\)[\([1]\)]\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ define\ the\ solution\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(T[x_, t_]\  = \ 
              u[x, t]\  + \ Evaluate[Sum[\(c[n]\)[t]\ v[n, x], {n, 1, M}]]\), 
            ";", "\[IndentingNewLine]", \(T[x_, t_]\  = \ 
              T[x, t] /. coefficients\), ";"}]}], "]"}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.47"]
}, Closed]],

Cell[CellGroupData[{

Cell["Reflection of a Quantum Particle from a Barrier ", "Section",
  CellTags->{"i:14", "c:11"}],

Cell["\<\
\tThe evolution of a quantum particle  moving in an external \
potential is another case where the Galerkin method is useful. This is a case \
where all of the steps in the method can be performed analytically, except \
for the solution of the coupled ODEs. \
\>", "Text"],

Cell[TextData[{
  "\tWe consider a particle  that encounters a potential barrier ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\)]],
  " of finite height and width. The particle wave function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, t)\)]],
  " satisfies the time-dependent ",
  "Schr\[ODoubleDot]dinger",
  " equation,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI]\ \[HBar] \(\[PartialD]\/\[PartialD]t\) \
\(\[Psi](x, 
            t)\) = \(-\(\[HBar]\^2\/\(2\ m\)\)\) \
\(\[PartialD]\^2\/\[PartialD]x\^2\) \(\[Psi](x, t)\)\  + \ \(V(x)\) \(\[Psi](
              x, t)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.27)"],

Cell["The initial condition on the wave function is", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, 0) = \(\[Psi]\_o\)(x)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.28)"],

Cell[TextData[{
  "For this problem",
  ",",
  " we take the barrier potential ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\)]],
  " to be"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(V(x)\), " ", "=", " ", 
        TagBox[
          RowBox[{
            StyleBox["{",
              ShowAutoStyles->False,
              FontSize->16], 
            StyleBox[GridBox[{
                  {\(V\_o, \ \(\(|\)\(x\)\(|\)\(\(<\)\(a\)\)\), \)},
                  {\(0, \ \ \ \ \(\(|\)\(x\)\(|\)\(\(\[GreaterEqual]\)\(\ \
\)\(\(a\)\(.\)\)\)\)\)}
                  }],
              ShowAutoStyles->True]}],
          (#&)]}], TraditionalForm]]]], "NumberedEquation",
  CellTags->"(6.1.29)"],

Cell[TextData[{
  "We will assume that the system has periodic boundary conditions, with \
period ",
  Cell[BoxData[
      \(TraditionalForm\`2  L\)]],
  ". (So this barrier, and the wave function itself,  are periodically \
replicated in cells of width ",
  Cell[BoxData[
      \(TraditionalForm\`2  L\)]],
  ".) Then to match these boundary conditions we will expand the ",
  "wave function",
  " in terms of a periodic exponential Fourier series,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, 
          t)\  = \[Sum]\+k\(\( c\_k\)(
              t)\) \[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\)]],
  ",   ",
  Cell[BoxData[
      \(TraditionalForm\`k\  = \ n\ \[Pi]/L, \ \ \ \ n = \(-M\),  ... , 
      M\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.30)"],

Cell[TextData[{
  "Substituting this series into Eq. ",
  ButtonBox["(6.1.27)",
    ButtonData:>"(6.1.27)",
    ButtonStyle->"Hyperlink"],
  ", we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI]\ \[HBar] \(\[Sum]\+k\(\[PartialD]\/\
\[PartialD]t\) \(\(c\_k\)(
                t)\) \[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\) = \[Sum]\+k\(\
\(\( \[HBar]\^2\) k\^2\)\/\(2\ m\)\) \(\(c\_k\)(
                t)\) \[ExponentialE]\^\(\[ImaginaryI]\ k\ x\) + \
\[Sum]\+\(k\&_\)\(\(c\_k\&_\)(t)\) \(V(
                x)\) \[ExponentialE]\^\(\[ImaginaryI]\ k\&_\ x\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.31)"],

Cell[TextData[{
  "In the last term, we replaced the dummy variable ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`k\&_\)]],
  ". For the inner product, we choose the one for which the Fourier modes are \
orthogonal:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\)\  = \ \[Integral]\_\(-L\)\%L\( f\^*\) g \[DifferentialD]x\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.32)"],

Cell[TextData[{
  "Then, taking an inner product of Eq. ",
  ButtonBox["(6.1.31)",
    ButtonData:>{"Chapter6.nb", "(6.1.31)"},
    ButtonStyle->"Hyperlink"],
  " with respect to  ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\)]],
  "  yields the following coupled equations for the Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_k\)(t)\)]],
  ":"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI]\ \[HBar] \(\[PartialD]\/\[PartialD]t\) \
\(\(c\_k\)(t)\) = \(\(\(\[HBar]\^2\) k\^2\)\/\(2\ m\)\) \(\(c\_k\)(
              t)\) + \[Sum]\+\(k\&_\)\(V\_\(k\ k\&_\)\) \(\(c\_k\&_\)(
                t)\)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(6.1.33)"],

Cell[TextData[{
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`V\_\(k\ k\&_\)\)]],
  " is the projection of the potential onto the Fourier modes:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`V\_\(k\ k\&_\) = \((\[ExponentialE]\^\(\[ImaginaryI]\
\ k\ x\), \ \(V(
                x)\)\ \[ExponentialE]\^\(\[ImaginaryI]\ \(k\&_\) x\))\)/\((\
\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\), \[ExponentialE]\^\(\[ImaginaryI]\ k\
\ x\))\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.34)"],

Cell[TextData[{
  "For the barrier potential of Eq. ",
  ButtonBox["(6.1.29)",
    ButtonData:>"(6.1.29)",
    ButtonStyle->"Hyperlink"],
  ", this matrix can be evaluated analytically:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`V\_\(k\ k\&_\) = \(V\_o\/\(\((k\&_ - k)\) 
                L\)\) \(sin(k\&_ - k)\) a\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.35)"],

Cell[TextData[{
  "We are then left with the task of solving the coupled ODEs given by Eq. ",
  ButtonBox["(6.1.33)",
    ButtonData:>"(6.1.33)",
    ButtonStyle->"Hyperlink"],
  ", subject to the initial condition, Eq . ",
  ButtonBox["(6.1.28)",
    ButtonData:>"(6.1.28)",
    ButtonStyle->"Hyperlink"],
  ". When Eq. ",
  ButtonBox["(6.1.30)",
    ButtonData:>"(6.1.30)",
    ButtonStyle->"Hyperlink"],
  " is used in Eq. ",
  ButtonBox["(6.1.28)",
    ButtonData:>"(6.1.28)",
    ButtonStyle->"Hyperlink"],
  " and an inner product is taken, we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(c\_k\)(
          0) = \(\((\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\), \(\[Psi]\_o\)(
                x))\)/\((\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\), \
\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\))\) = \(1\/\(2  
                  L\)\) \(\[Integral]\_\(-L\)\%L\( \[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ k\ x\)\) \(\(\[Psi]\_o\)(x)\) \[DifferentialD]x\)\)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(6.1.36)"],

Cell["\<\
which is simply the usual expression for the Fourier coefficient of \
the initial condition. 
\tLet's solve this problem for specific (dimensionless) choices of the \
parameters:\
\>", "Text"],

Cell[BoxData[
    \(\[HBar] = 1; \ mass = 1;\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.48"],

Cell[TextData[{
  "For the initial condition, we choose a ",
  "wave function",
  " centered at ",
  Cell[BoxData[
      \(TraditionalForm\`k\_o = 5\)]],
  " and at position ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(-5\)\)]],
  ", moving toward the potential barrier from the left:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_o\)(
          x)\  = \ \(\[ExponentialE]\^\(\(-2\) \((x + 5)\)\^2\)\) \
\[ExponentialE]\^\(\(\ \ \)\(5\ \[ImaginaryI]\ x\)\)\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "This corresponds to a classical particle with energy ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[HBar]\ k\_o)\)\^2/\((2\ m)\) = 12.5\)]],
  " in our dimensionless units. We take the potential barrier height equal to \
",
  Cell[BoxData[
      \(TraditionalForm\`V\_o = 15\)]],
  ",",
  " in order to reflect the classical particle.  "
}], "Text"],

Cell[TextData[{
  "\tThe Fourier coefficients of the initial condition can be evaluated for \
general ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(c\_k\)(
          0) = \(\[ExponentialE]\^\(\(-50\) - 1\/8\ \((\((\(-5\) - 20\ \
\[ImaginaryI])\) + k)\)\^2\)\ \@\(\[Pi]\/2\)\)\/\(2\ L\)\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "\tThe following module integrates the equations of motion for this initial \
condition. The Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_k\)(t)\)]],
  " are referred to as ",
  StyleBox["c[n][t]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`k = 2  \[Pi]\ n/\((2  L)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = \(-M\), , , \(\(.\)\(M\)\)\)]],
  ". The equations for the coefficients are integrated up to time ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)]],
  ". The module can be easily modified to solve for propagation of a quantum \
wave function starting with any initial condition and moving in any \
one-dimensional potential, simply by changing the definition of the initial \
conditions ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_k\)(0)\)]],
  " and the potential matrix ",
  Cell[BoxData[
      \(TraditionalForm\`V\_\(k\ k\&_\)\)]],
  "."
}], "Text"],

Cell[BoxData[
    RowBox[{\(schroedinger[L_, a_, V0_, M_, \[Tau]_]\), ":=", 
      RowBox[{"Module", "[", 
        RowBox[{\({k, v, ic, V, eq, eqns, vars}\), ",", "\[IndentingNewLine]",
           
          StyleBox[\( (*\ DEFINE\ THE\ WAVENUMBER\ *) \),
            FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
          RowBox[{\(k[n_]\  = \ Pi\ n/L\), ";", "\[IndentingNewLine]", 
            StyleBox[\( (*\ DEFINE\ THE\ BASIS\ FUNCTIONS\ *) \),
              FontColor->RGBColor[0, 0, 1]], 
            "\[IndentingNewLine]", \(v[n_, x_]\  = \ Exp[I\ k[n]\ x]\), ";", 
            "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                DEFINE\ AND\ PRINT\ THE\ INITIAL\ CONDITIONS\ *) \),
              FontColor->RGBColor[0, 0, 1]], 
            "\[IndentingNewLine]", \(ic[
                m_]\  := \ \(ic[
                  m]\  = \ \(c[m]\)[
                    0]\  \[Equal] \ \(\[ExponentialE]\^\(\(-50\) - 1\/8\ \
\((\((\(-5\) - 20\ \[ImaginaryI])\) + k[m])\)\^2\)\ \@\(\[Pi]\/2\)\)\/\(2\ \
L\)\)\), ";", 
            "\[IndentingNewLine]", \(Do[
              Print["\<ic[\>", m, "\<]=\>", ic[m]], {m, \(-M\), M}]\), ";", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                DEFINE\ PROJECTION\ OF\ THE\ POTENTIAL\ ONTO\ THE\ MODEs\ *) \
\),
              FontColor->RGBColor[0, 0, 1]], 
            "\[IndentingNewLine]", \(V[n_, m_]\  := \ 
              V0\ Sin[\((k[n] - k[m])\) a]/\((\((k[n] - k[m])\) L)\)\  /; \ 
                n \[NotEqual] \ m\), ";", 
            "\[IndentingNewLine]", \(V[n_, n_]\  := \ V0\ a/L\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ DEFINE\ AND\ PRINT\ THE\ ODEs\ *) \),
              FontColor->RGBColor[0, 0, 1]], 
            "\[IndentingNewLine]", \(eq[
                n_]\  := \ \(eq[
                  n]\  = \ \ I\ \ D[\(c[n]\)[t], 
                      t]\  \[Equal] \ \(\[HBar]\^2\) 
                      k[n]\^2/\((2  mass\ )\)\ \(c[n]\)[t] + \ 
                    Sum[V[n, m]\ \(c[m]\)[t], {m, \(-M\), M}]\)\), " ", ";", 
            "\[IndentingNewLine]", \(Do[
              Print["\<eq[\>", m, "\<]=\>", eq[m]], {m, \(-M\), M}]\), ";", 
            "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                CREATE\ LISTS\ OF\ THE\ EQUATIONS\ AND\ VARIABLES\ FOR\ USE\ \
IN\ NDSOLVE*) \),
              FontColor->RGBColor[0, 0, 1]], 
            "\[IndentingNewLine]", \(eqns\  = \ 
              Join[Table[eq[m], {m, \(-M\), M}], 
                Table[ic[m], {m, \(-M\), M}]]\), ";", 
            "\[IndentingNewLine]", \(vars\  = \ 
              Table[\(c[n]\)[t], {n, \(-M\), M}]\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ SOLVE\ THE\ EQUATIONS\ *) \),
              FontColor->RGBColor[0, 0, 1]], 
            "\[IndentingNewLine]", \(coefficients\  = \ \(NDSolve[eqns, 
                  vars, {t, 0, \[Tau]}, MaxSteps \[Rule] 6000]\)[\([1]\)]\), 
            ";", "\[IndentingNewLine]", 
            StyleBox[\( (*\ THE\ SOLUTION\ \ *) \),
              FontColor->RGBColor[0, 0, 1]], 
            "\[IndentingNewLine]", \(\[Psi][x_, t_]\  = \ 
              Sum[\(c[n]\)[t]\ v[n, x], {n, \(-M\), M}]\), " ", ";", 
            "\[IndentingNewLine]", \(\[Psi][x_, t_\ ] = \ \[Psi][x, t] /. 
                coefficients\), ";"}]}], "]"}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.49"],

Cell[TextData[{
  "In Cell ",
  ButtonBox["6.50",
    ButtonData:>"Cell 6.50",
    ButtonStyle->"Hyperlink"],
  " we run this module,  taking ",
  Cell[BoxData[
      \(TraditionalForm\`L = 15\)]],
  " and a barrier half width ",
  Cell[BoxData[
      \(TraditionalForm\`a = 1\)]],
  ". We integrate over a time ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau] = 2.4\)]],
  " and take ",
  Cell[BoxData[
      \(TraditionalForm\`M = 60\)]],
  " (a large number of modes must be kept in order to represent the sharply \
peaked initial condition)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(schroedinger[15. , 1. , 15. , 60, 2.4];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.50"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-60\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-60\)]\)[0] == 
          7.335331140938072`*^-19 + 
            9.794604115626626`*^-20\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -60, "]=", 
        Equal[ 
          c[ -60][ 0], 
          Complex[ 7.3353311409380722*^-19, 9.7946041156266262*^-20]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-59\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-59\)]\)[0] == 
          7.034481033127066`*^-19 + 
            1.7071591735034567`*^-18\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -59, "]=", 
        Equal[ 
          c[ -59][ 0], 
          Complex[ 7.0344810331270663*^-19, 1.7071591735034567*^-18]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-58\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-58\)]\)[0] == \(-2.7805081148506073`*^-18\) + 
            3.609844913780214`*^-18\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -58, "]=", 
        Equal[ 
          c[ -58][ 0], 
          Complex[ -2.7805081148506073*^-18, 3.6098449137802142*^-18]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-57\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-57\)]\)[0] == \(-1.1024151804199695`*^-17\) - 
            1.4720153808748337`*^-18\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -57, "]=", 
        Equal[ 
          c[ -57][ 0], 
          Complex[ -1.1024151804199695*^-17, -1.4720153808748337*^-18]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-56\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-56\)]\)[0] == \(-1.022986277449601`*^-17\) - 
            2.4826286398272097`*^-17\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -56, "]=", 
        Equal[ 
          c[ -56][ 0], 
          Complex[ -1.022986277449601*^-17, -2.4826286398272097*^-17]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-55\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-55\)]\)[0] == 
          3.912678790478846`*^-17 - 
            5.079705955767508`*^-17\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -55, "]=", 
        Equal[ 
          c[ -55][ 0], 
          Complex[ 3.9126787904788461*^-17, -5.0797059557675078*^-17]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-54\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-54\)]\)[0] == 
          1.501092649792993`*^-16 + 
            2.004355081332875`*^-17\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -54, "]=", 
        Equal[ 
          c[ -54][ 0], 
          Complex[ 1.501092649792993*^-16, 2.0043550813328751*^-17]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-53\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-53\)]\)[0] == 
          1.3478588227660792`*^-16 + 
            3.2710437956071307`*^-16\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -53, "]=", 
        Equal[ 
          c[ -53][ 0], 
          Complex[ 1.3478588227660792*^-16, 3.2710437956071307*^-16]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-52\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-52\)]\)[0] == \(-4.988397789818807`*^-16\) + 
            6.476277588730456`*^-16\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -52, "]=", 
        Equal[ 
          c[ -52][ 0], 
          Complex[ -4.9883977898188071*^-16, 6.4762775887304558*^-16]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-51\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-51\)]\)[0] == \(-1.8518536616583415`*^-15\) - 
            2.472713657709106`*^-16\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -51, "]=", 
        Equal[ 
          c[ -51][ 0], 
          Complex[ -1.8518536616583415*^-15, -2.472713657709106*^-16]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-50\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-50\)]\)[0] == \(-1.6089993038929722`*^-15\) - 
            3.9047911407623456`*^-15\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -50, "]=", 
        Equal[ 
          c[ -50][ 0], 
          Complex[ -1.6089993038929722*^-15, -3.9047911407623456*^-15]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-49\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-49\)]\)[0] == 
          5.762153359157374`*^-15 - 
            7.480819741140575`*^-15\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -49, "]=", 
        Equal[ 
          c[ -49][ 0], 
          Complex[ 5.7621533591573736*^-15, -7.4808197411405753*^-15]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-48\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-48\)]\)[0] == 
          2.0698681576699788`*^-14 + 
            2.763820581019623`*^-15\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -48, "]=", 
        Equal[ 
          c[ -48][ 0], 
          Complex[ 2.0698681576699788*^-14, 2.7638205810196231*^-15]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-47\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-47\)]\)[0] == 
          1.7402200149787806`*^-14 + 
            4.2232434041615534`*^-14\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -47, "]=", 
        Equal[ 
          c[ -47][ 0], 
          Complex[ 1.7402200149787806*^-14, 4.2232434041615534*^-14]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-46\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-46\)]\)[0] == \(-6.030390003406935`*^-14\) + 
            7.829062812528366`*^-14\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -46, "]=", 
        Equal[ 
          c[ -46][ 0], 
          Complex[ -6.0303900034069348*^-14, 7.8290628125283658*^-14]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-45\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-45\)]\)[0] == \(-2.096117168449568`*^-13\) - 
            2.798869941992378`*^-14\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -45, "]=", 
        Equal[ 
          c[ -45][ 0], 
          Complex[ -2.0961171684495679*^-13, -2.798869941992378*^-14]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-44\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-44\)]\)[0] == \(-1.7052549355217378`*^-13\) - 
            4.138388592745842`*^-13\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -44, "]=", 
        Equal[ 
          c[ -44][ 0], 
          Complex[ -1.7052549355217378*^-13, -4.1383885927458422*^-13]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-43\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-43\)]\)[0] == 
          5.717982742117037`*^-13 - 
            7.423474439247849`*^-13\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -43, "]=", 
        Equal[ 
          c[ -43][ 0], 
          Complex[ 5.717982742117037*^-13, -7.4234744392478492*^-13]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-42\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-42\)]\)[0] == 
          1.9232036715401016`*^-12 + 
            2.5679847623139305`*^-13\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -42, "]=", 
        Equal[ 
          c[ -42][ 0], 
          Complex[ 1.9232036715401016*^-12, 2.5679847623139305*^-13]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-41\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-41\)]\)[0] == 
          1.5139492728678873`*^-12 + 
            3.674119493995461`*^-12\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -41, "]=", 
        Equal[ 
          c[ -41][ 0], 
          Complex[ 1.5139492728678873*^-12, 3.6741194939954606*^-12]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-40\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-40\)]\)[0] == \(-4.912212354134527`*^-12\) + 
            6.377368469911435`*^-12\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -40, "]=", 
        Equal[ 
          c[ -40][ 0], 
          Complex[ -4.9122123541345273*^-12, 6.3773684699114347*^-12]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-39\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-39\)]\)[0] == \(-1.5987179694847674`*^-11\) - 
            2.1347106630606324`*^-12\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -39, "]=", 
        Equal[ 
          c[ -39][ 0], 
          Complex[ -1.5987179694847674*^-11, -2.1347106630606324*^-12]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-38\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-38\)]\)[0] == \(-1.2177837791385021`*^-11\) - 
            2.955371888998911`*^-11\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -38, "]=", 
        Equal[ 
          c[ -38][ 0], 
          Complex[ -1.2177837791385021*^-11, -2.9553718889989107*^-11]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-37\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-37\)]\)[0] == 
          3.823387170140352`*^-11 - 4.96378149584561`*^-11\ \[ImaginaryI]\)\),
      
      SequenceForm[ "ic[", -37, "]=", 
        Equal[ 
          c[ -37][ 0], 
          Complex[ 3.8233871701403521*^-11, -4.9637814958456102*^-11]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-36\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-36\)]\)[0] == 
          1.2040798430646403`*^-10 + 
            1.6077645521147805`*^-11\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -36, "]=", 
        Equal[ 
          c[ -36][ 0], 
          Complex[ 1.2040798430646403*^-10, 1.6077645521147805*^-11]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-35\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-35\)]\)[0] == 
          8.87494967118347`*^-11 + 
            2.1538122960589162`*^-10\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -35, "]=", 
        Equal[ 
          c[ -35][ 0], 
          Complex[ 8.8749496711834706*^-11, 2.1538122960589162*^-10]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-34\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-34\)]\)[0] == \(-2.6962259027406485`*^-10\) + 
            3.5004240086290474`*^-10\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -34, "]=", 
        Equal[ 
          c[ -34][ 0], 
          Complex[ -2.6962259027406485*^-10, 3.5004240086290474*^-10]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-33\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-33\)]\)[0] == \(-8.216286385355219`*^-10\) - 
            1.0970912000964858`*^-10\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -33, "]=", 
        Equal[ 
          c[ -33][ 0], 
          Complex[ -8.2162863853552194*^-10, -1.0970912000964858*^-10]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-32\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-32\)]\)[0] == \(-5.860011462731532`*^-10\) - 
            1.4221336696092427`*^-9\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -32, "]=", 
        Equal[ 
          c[ -32][ 0], 
          Complex[ -5.8600114627315315*^-10, -1.4221336696092427*^-09]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-31\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-31\)]\)[0] == 
          1.722666179841179`*^-9 - 2.2364825026864333`*^-9\ \[ImaginaryI]\)\),
      
      SequenceForm[ "ic[", -31, "]=", 
        Equal[ 
          c[ -31][ 0], 
          Complex[ 1.722666179841179*^-09, -2.2364825026864333*^-09]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-30\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-30\)]\)[0] == 
          5.079637300825355`*^-9 + 6.782657177517886`*^-10\ \[ImaginaryI]\)\),
      
      SequenceForm[ "ic[", -30, "]=", 
        Equal[ 
          c[ -30][ 0], 
          Complex[ 5.079637300825355*^-09, 6.7826571775178858*^-10]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-29\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-29\)]\)[0] == 
          3.5056445950433573`*^-9 + 8.507654368940215`*^-9\ \[ImaginaryI]\)\),
      
      SequenceForm[ "ic[", -29, "]=", 
        Equal[ 
          c[ -29][ 0], 
          Complex[ 3.5056445950433573*^-09, 8.5076543689402149*^-09]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-28\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-28\)]\)[0] == \(-9.972012887709568`*^-9\) + 
            1.294634596122509`*^-8\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -28, "]=", 
        Equal[ 
          c[ -28][ 0], 
          Complex[ -9.9720128877095675*^-09, 1.294634596122509*^-08]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-27\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-27\)]\)[0] == \(-2.8452910085798516`*^-8\) - 
            3.799214853063425`*^-9\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -27, "]=", 
        Equal[ 
          c[ -27][ 0], 
          Complex[ -2.8452910085798516*^-08, -3.799214853063425*^-09]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-26\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-26\)]\)[0] == \(-1.900089932667854`*^-8\) - 
            4.6112228375623136`*^-8\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -26, "]=", 
        Equal[ 
          c[ -26][ 0], 
          Complex[ -1.9000899326678539*^-08, -4.6112228375623136*^-08]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-25\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-25\)]\)[0] == 
          5.2299963693679614`*^-8 - 6.78993731117622`*^-8\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -25, "]=", 
        Equal[ 
          c[ -25][ 0], 
          Complex[ 5.2299963693679614*^-08, -6.7899373111762194*^-08]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-24\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-24\)]\)[0] == 
          1.4439678772753906`*^-7 + 1.928078425070984`*^-8\ \[ImaginaryI]\)\),
      
      SequenceForm[ "ic[", -24, "]=", 
        Equal[ 
          c[ -24][ 0], 
          Complex[ 1.4439678772753906*^-07, 1.9280784250709841*^-08]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-23\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-23\)]\)[0] == 
          9.330765644954433`*^-8 + 2.264431745793443`*^-7\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -23, "]=", 
        Equal[ 
          c[ -23][ 0], 
          Complex[ 9.3307656449544327*^-08, 2.2644317457934431*^-07]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-22\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-22\)]\)[0] == \(-2.485173971388517`*^-7\) + 
            3.226422024291764`*^-7\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -22, "]=", 
        Equal[ 
          c[ -22][ 0], 
          Complex[ -2.4851739713885171*^-07, 3.2264220242917638*^-07]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-21\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-21\)]\)[0] == \(-6.639344827402652`*^-7\) - 
            8.865278597801253`*^-8\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -21, "]=", 
        Equal[ 
          c[ -21][ 0], 
          Complex[ -6.6393448274026523*^-07, -8.8652785978012531*^-08]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-20\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-20\)]\)[0] == \(-4.1514256000433074`*^-7\) - 
            1.00748644610114`*^-6\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -20, "]=", 
        Equal[ 
          c[ -20][ 0], 
          Complex[ -4.1514256000433074*^-07, -1.00748644610114*^-06]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-19\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-19\)]\)[0] == 
          1.0699144623146792`*^-6 - 1.389035787861438`*^-6\ \[ImaginaryI]\)\),
      
      SequenceForm[ "ic[", -19, "]=", 
        Equal[ 
          c[ -19][ 0], 
          Complex[ 1.0699144623146792*^-06, -1.3890357878614381*^-06]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-18\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-18\)]\)[0] == 
          2.7658573092806585`*^-6 + 3.693149888425013`*^-7\ \[ImaginaryI]\)\),
      
      SequenceForm[ "ic[", -18, "]=", 
        Equal[ 
          c[ -18][ 0], 
          Complex[ 2.7658573092806585*^-06, 3.6931498884250133*^-07]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-17\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-17\)]\)[0] == 
          1.673455195657134`*^-6 + 4.061215568368823`*^-6\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -17, "]=", 
        Equal[ 
          c[ -17][ 0], 
          Complex[ 1.673455195657134*^-06, 4.0612155683688226*^-06]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-16\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-16\)]\)[0] == \(-4.173286230466249`*^-6\) + 
            5.418044274834741`*^-6\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -16, "]=", 
        Equal[ 
          c[ -16][ 0], 
          Complex[ -4.173286230466249*^-06, 5.4180442748347407*^-06]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-15\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-15\)]\)[0] == \(-0.000010439294984769792`\) - 
            1.3939215511542179`*^-6\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -15, "]=", 
        Equal[ 
          c[ -15][ 0], 
          Complex[ -1.0439294984769792*^-05, -1.3939215511542179*^-06]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-14\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-14\)]\)[0] == \(-6.111780832071051`*^-6\) - 
            0.000014832341809974786`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -14, "]=", 
        Equal[ 
          c[ -14][ 0], 
          Complex[ -6.1117808320710512*^-06, -1.4832341809974786*^-05]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-13\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-13\)]\)[
            0] == \(\(0.000014748373906686519`\)\(\[InvisibleSpace]\)\) - 
            0.000019147342979951347`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -13, "]=", 
        Equal[ 
          c[ -13][ 0], 
          Complex[ 1.4748373906686519*^-05, -1.9147342979951347*^-05]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-12\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-12\)]\)[
            0] == \(\(0.00003569845503170215`\)\(\[InvisibleSpace]\)\) + 
            4.766686436603075`*^-6\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -12, "]=", 
        Equal[ 
          c[ -12][ 0], 
          Complex[ 3.5698455031702147*^-05, 4.7666864366030747*^-06]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-11\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-11\)]\)[
            0] == \(\(0.000020223592586349957`\)\(\[InvisibleSpace]\)\) + 
            0.000049079514810540953`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -11, "]=", 
        Equal[ 
          c[ -11][ 0], 
          Complex[ 2.0223592586349957*^-05, 4.9079514810540953*^-05]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-10\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-10\)]\)[0] == \(-0.00004722228079096236`\) + 
            0.0000613071795115112`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -10, "]=", 
        Equal[ 
          c[ -10][ 0], 
          Complex[ -4.7222280790962357*^-05, 6.1307179511511193*^-05]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-9\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-9\)]\)[0] == \(-0.0001106023933848528`\) - 
            0.000014768340196662326`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -9, "]=", 
        Equal[ 
          c[ -9][ 0], 
          Complex[ -0.00011060239338485281, -1.4768340196662326*^-05]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-8\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-8\)]\)[0] == \(-0.00006062973860757475`\) - 
            0.00014713894879182711`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -8, "]=", 
        Equal[ 
          c[ -8][ 0], 
          Complex[ -6.0629738607574752*^-05, -0.00014713894879182711]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-7\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-7\)]\)[
            0] == \(\(0.00013698929534785198`\)\(\[InvisibleSpace]\)\) - 
            0.00017784882856936433`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -7, "]=", 
        Equal[ 
          c[ -7][ 0], 
          Complex[ 0.00013698929534785198, -0.00017784882856936433]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-6\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-6\)]\)[
            0] == \(\(0.00031046774100934176`\)\(\[InvisibleSpace]\)\) + 
            0.00004145564195307023`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -6, "]=", 
        Equal[ 
          c[ -6][ 0], 
          Complex[ 0.00031046774100934176, 4.1455641953070233*^-05]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-5\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-5\)]\)[
            0] == \(\(0.0001646834425047736`\)\(\[InvisibleSpace]\)\) + 
            0.000399661109713977`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -5, "]=", 
        Equal[ 
          c[ -5][ 0], 
          Complex[ 0.0001646834425047736, 0.00039966110971397699]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-4\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-4\)]\)[0] == \(-0.00036005028324573703`\) + 
            0.0004674417876135656`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -4, "]=", 
        Equal[ 
          c[ -4][ 0], 
          Complex[ -0.00036005028324573703, 0.00046744178761356559]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-3\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-3\)]\)[0] == \(-0.0007895966391387181`\) - 
            0.00010543200222047335`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -3, "]=", 
        Equal[ 
          c[ -3][ 0], 
          Complex[ -0.00078959663913871813, -0.00010543200222047335]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-2\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-2\)]\)[0] == \(-0.0004052761347469436`\) - 
            0.0009835421660490228`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -2, "]=", 
        Equal[ 
          c[ -2][ 0], 
          Complex[ -0.00040527613474694362, -0.00098354216604902285]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-1\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-1\)]\)[
            0] == \(\(0.0008573862902450275`\)\(\[InvisibleSpace]\)\) - 
            0.0011131172473317155`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -1, "]=", 
        Equal[ 
          c[ -1][ 0], 
          Complex[ 0.00085738629024502747, -0.0011131172473317155]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]0\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[0]\)[
            0] == \(\(0.0018194115745414745`\)\(\[InvisibleSpace]\)\) + 
            0.00024293949044191843`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 0, "]=", 
        Equal[ 
          c[ 0][ 0], 
          Complex[ 0.0018194115745414745, 0.00024293949044191843]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]1\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[1]\)[
            0] == \(\(0.0009036265377110837`\)\(\[InvisibleSpace]\)\) + 
            0.0021929611097250535`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 1, "]=", 
        Equal[ 
          c[ 1][ 0], 
          Complex[ 0.00090362653771108371, 0.0021929611097250535]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]2\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[2]\)[0] == \(-0.0018498084771490925`\) + 
            0.002401547288080178`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 2, "]=", 
        Equal[ 
          c[ 2][ 0], 
          Complex[ -0.0018498084771490925, 0.0024015472880801782]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]3\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[3]\)[0] == \(-0.0037983367726630436`\) - 
            0.0005071782619114722`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 3, "]=", 
        Equal[ 
          c[ 3][ 0], 
          Complex[ -0.0037983367726630436, -0.00050717826191147217]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]4\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[4]\)[0] == \(-0.0018254240826702153`\) - 
            0.00443002042878384`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 4, "]=", 
        Equal[ 
          c[ 4][ 0], 
          Complex[ -0.0018254240826702153, -0.0044300204287838398]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]5\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[5]\)[
            0] == \(\(0.0036158786637345034`\)\(\[InvisibleSpace]\)\) - 
            0.004694379826987181`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 5, "]=", 
        Equal[ 
          c[ 5][ 0], 
          Complex[ 0.0036158786637345034, -0.0046943798269871813]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]6\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[6]\)[
            0] == \(\(0.00718443856709052`\)\(\[InvisibleSpace]\)\) + 
            0.0009593122683305472`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 6, "]=", 
        Equal[ 
          c[ 6][ 0], 
          Complex[ 0.00718443856709052, 0.00095931226833054716]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]7\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[7]\)[
            0] == \(\(0.0033409919374256408`\)\(\[InvisibleSpace]\)\) + 
            0.00810806796936044`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 7, "]=", 
        Equal[ 
          c[ 7][ 0], 
          Complex[ 0.0033409919374256408, 0.0081080679693604392]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]8\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[8]\)[0] == \(-0.00640380036581786`\) + 
            0.00831384956438234`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 8, "]=", 
        Equal[ 
          c[ 8][ 0], 
          Complex[ -0.0064038003658178598, 0.0083138495643823394]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]9\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[9]\)[0] == \(-0.01231201272726306`\) - 
            0.0016439788226748522`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 9, "]=", 
        Equal[ 
          c[ 9][ 0], 
          Complex[ -0.012312012727263059, -0.0016439788226748522]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]10\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[10]\)[0] == \(-0.005540180725635956`\) - 
            0.013445157224955658`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 10, "]=", 
        Equal[ 
          c[ 10][ 0], 
          Complex[ -0.0055401807256359563, -0.013445157224955658]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]11\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[11]\)[
            0] == \(\(0.010275396125376408`\)\(\[InvisibleSpace]\)\) - 
            0.013340218732740933`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 11, "]=", 
        Equal[ 
          c[ 11][ 0], 
          Complex[ 0.010275396125376408, -0.013340218732740933]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]12\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[12]\)[
            0] == \(\(0.019116224784602547`\)\(\[InvisibleSpace]\)\) + 
            0.0025525208113040022`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 12, "]=", 
        Equal[ 
          c[ 12][ 0], 
          Complex[ 0.019116224784602547, 0.0025525208113040022]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]13\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[13]\)[
            0] == \(\(0.00832356334834773`\)\(\[InvisibleSpace]\)\) + 
            0.020199994085493885`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 13, "]=", 
        Equal[ 
          c[ 13][ 0], 
          Complex[ 0.00832356334834773, 0.020199994085493885]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]14\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[14]\)[0] == \(-0.01493812931490832`\) + 
            0.01939369636823092`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 14, "]=", 
        Equal[ 
          c[ 14][ 0], 
          Complex[ -0.01493812931490832, 0.01939369636823092]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]15\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[15]\)[0] == \(-0.026891315886045992`\) - 
            0.0035907007903448543`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 15, "]=", 
        Equal[ 
          c[ 15][ 0], 
          Complex[ -0.026891315886045992, -0.0035907007903448543]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]16\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[16]\)[0] == \(-0.011330041458550844`\) - 
            0.027496249006930273`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 16, "]=", 
        Equal[ 
          c[ 16][ 0], 
          Complex[ -0.011330041458550844, -0.027496249006930273]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]17\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[17]\)[
            0] == \(\(0.019675723404882765`\)\(\[InvisibleSpace]\)\) - 
            0.025544363520723232`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 17, "]=", 
        Equal[ 
          c[ 17][ 0], 
          Complex[ 0.019675723404882765, -0.025544363520723232]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]18\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[18]\)[
            0] == \(\(0.034273529663558164`\)\(\[InvisibleSpace]\)\) + 
            0.004576421271920926`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 18, "]=", 
        Equal[ 
          c[ 18][ 0], 
          Complex[ 0.034273529663558164, 0.0045764212719209257]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]19\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[19]\)[
            0] == \(\(0.013973029037588841`\)\(\[InvisibleSpace]\)\) + 
            0.03391036892531824`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 19, "]=", 
        Equal[ 
          c[ 19][ 0], 
          Complex[ 0.013973029037588841, 0.033910368925318242]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]20\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[20]\)[0] == \(-0.023480214257171367`\) + 
            0.030483612530394166`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 20, "]=", 
        Equal[ 
          c[ 20][ 0], 
          Complex[ -0.023480214257171367, 0.030483612530394166]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]21\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[21]\)[0] == \(-0.03957696288435094`\) - 
            0.005284569654772027`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 21, "]=", 
        Equal[ 
          c[ 21][ 0], 
          Complex[ -0.03957696288435094, -0.0052845696547720268]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]22\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[22]\)[0] == \(-0.015613004210010856`\) - 
            0.037890333682822706`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 22, "]=", 
        Equal[ 
          c[ 22][ 0], 
          Complex[ -0.015613004210010856, -0.037890333682822706]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]23\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[23]\)[
            0] == \(\(0.025386934061987446`\)\(\[InvisibleSpace]\)\) - 
            0.03295904597820822`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 23, "]=", 
        Equal[ 
          c[ 23][ 0], 
          Complex[ 0.025386934061987446, -0.032959045978208222]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]24\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[24]\)[
            0] == \(\(0.04140596849358669`\)\(\[InvisibleSpace]\)\) + 
            0.0055287902021955064`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 24, "]=", 
        Equal[ 
          c[ 24][ 0], 
          Complex[ 0.041405968493586687, 0.0055287902021955064]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]25\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[25]\)[
            0] == \(\(0.01580590053952679`\)\(\[InvisibleSpace]\)\) + 
            0.03835846308272794`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 25, "]=", 
        Equal[ 
          c[ 25][ 0], 
          Complex[ 0.015805900539526789, 0.038358463082727938]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]26\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[26]\)[0] == \(-0.024868827344722216`\) + 
            0.03228640456848667`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 26, "]=", 
        Equal[ 
          c[ 26][ 0], 
          Complex[ -0.024868827344722216, 0.032286404568486672]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]27\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[27]\)[0] == \(-0.039248248783685276`\) - 
            0.005240677641972817`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 27, "]=", 
        Equal[ 
          c[ 27][ 0], 
          Complex[ -0.039248248783685276, -0.0052406776419728169]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]28\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[28]\)[0] == \(-0.014497358061258837`\) - 
            0.03518283394224964`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 28, "]=", 
        Equal[ 
          c[ 28][ 0], 
          Complex[ -0.014497358061258837, -0.035182833942249643]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]29\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[29]\)[
            0] == \(\(0.02207177254967996`\)\(\[InvisibleSpace]\)\) - 
            0.02865507762809014`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 29, "]=", 
        Equal[ 
          c[ 29][ 0], 
          Complex[ 0.022071772549679961, -0.02865507762809014]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]30\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[30]\)[
            0] == \(\(0.03370656318130526`\)\(\[InvisibleSpace]\)\) + 
            0.0045007162746440385`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 30, "]=", 
        Equal[ 
          c[ 30][ 0], 
          Complex[ 0.033706563181305257, 0.0045007162746440385]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]31\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[31]\)[
            0] == \(\(0.012047455720440194`\)\(\[InvisibleSpace]\)\) + 
            0.029237301875818317`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 31, "]=", 
        Equal[ 
          c[ 31][ 0], 
          Complex[ 0.012047455720440194, 0.029237301875818317]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]32\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[32]\)[0] == \(-0.017748267660308285`\) + 
            0.0230420092643457`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 32, "]=", 
        Equal[ 
          c[ 32][ 0], 
          Complex[ -0.017748267660308285, 0.0230420092643457]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]33\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[33]\)[0] == \(-0.026226812696659125`\) - 
            0.0035019720670116552`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 33, "]=", 
        Equal[ 
          c[ 33][ 0], 
          Complex[ -0.026226812696659125, -0.0035019720670116552]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]34\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[34]\)[0] == \(-0.009070655330537277`\) - 
            0.022013070167211105`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 34, "]=", 
        Equal[ 
          c[ 34][ 0], 
          Complex[ -0.0090706553305372768, -0.022013070167211105]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]35\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[35]\)[
            0] == \(\(0.012930388686575991`\)\(\[InvisibleSpace]\)\) - 
            0.01678711081048119`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 35, "]=", 
        Equal[ 
          c[ 35][ 0], 
          Complex[ 0.012930388686575991, -0.01678711081048119]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]36\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[36]\)[
            0] == \(\(0.018488999435306422`\)\(\[InvisibleSpace]\)\) + 
            0.0024687696640196453`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 36, "]=", 
        Equal[ 
          c[ 36][ 0], 
          Complex[ 0.018488999435306422, 0.0024687696640196453]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]37\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[37]\)[
            0] == \(\(0.006187551740693366`\)\(\[InvisibleSpace]\)\) + 
            0.015016226024218735`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 37, "]=", 
        Equal[ 
          c[ 37][ 0], 
          Complex[ 0.0061875517406933664, 0.015016226024218735]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]38\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[38]\)[0] == \(-0.00853501016960533`\) + 
            0.011080731210694106`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 38, "]=", 
        Equal[ 
          c[ 38][ 0], 
          Complex[ -0.0085350101696053306, 0.011080731210694106]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]39\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[39]\)[0] == \(-0.011809136875938927`\) - 
            0.0015768316170696305`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 39, "]=", 
        Equal[ 
          c[ 39][ 0], 
          Complex[ -0.011809136875938927, -0.0015768316170696305]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]40\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[40]\)[0] == \(-0.003824158419086434`\) - 
            0.009280637896853482`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 40, "]=", 
        Equal[ 
          c[ 40][ 0], 
          Complex[ -0.0038241584190864342, -0.0092806378968534817]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]41\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[41]\)[
            0] == \(\(0.005104266702750216`\)\(\[InvisibleSpace]\)\) - 
            0.006626706499107406`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 41, "]=", 
        Equal[ 
          c[ 41][ 0], 
          Complex[ 0.0051042667027502162, -0.006626706499107406]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]42\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[42]\)[
            0] == \(\(0.0068337605334866155`\)\(\[InvisibleSpace]\)\) + 
            0.0009124874904820301`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 42, "]=", 
        Equal[ 
          c[ 42][ 0], 
          Complex[ 0.0068337605334866155, 0.00091248749048203012]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]43\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[43]\)[
            0] == \(\(0.0021413603610994977`\)\(\[InvisibleSpace]\)\) + 
            0.005196748654253613`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 43, "]=", 
        Equal[ 
          c[ 43][ 0], 
          Complex[ 0.0021413603610994977, 0.0051967486542536133]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]44\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[44]\)[0] == \(-0.0027656647028044194`\) + 
            0.0035905741858181404`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 44, "]=", 
        Equal[ 
          c[ 44][ 0], 
          Complex[ -0.0027656647028044194, 0.0035905741858181404]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]45\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[45]\)[0] == \(-0.003582929055634179`\) - 
            0.0004784156434118898`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 45, "]=", 
        Equal[ 
          c[ 45][ 0], 
          Complex[ -0.003582929055634179, -0.00047841564341188979]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]46\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[46]\)[0] == \(-0.0010863768337557103`\) - 
            0.002636467663916894`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 46, "]=", 
        Equal[ 
          c[ 46][ 0], 
          Complex[ -0.0010863768337557103, -0.0026364676639168941]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]47\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[47]\)[
            0] == \(\(0.0013576960299129625`\)\(\[InvisibleSpace]\)\) - 
            0.0017626534092328836`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 47, "]=", 
        Equal[ 
          c[ 47][ 0], 
          Complex[ 0.0013576960299129625, -0.0017626534092328836]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]48\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[48]\)[
            0] == \(\(0.0017019763235314503`\)\(\[InvisibleSpace]\)\) + 
            0.00022725878331687432`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 48, "]=", 
        Equal[ 
          c[ 48][ 0], 
          Complex[ 0.0017019763235314503, 0.00022725878331687432]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]49\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[49]\)[
            0] == \(\(0.0004993534854337122`\)\(\[InvisibleSpace]\)\) + 
            0.0012118532688687965`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 49, "]=", 
        Equal[ 
          c[ 49][ 0], 
          Complex[ 0.00049935348543371223, 0.0012118532688687965]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]50\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[50]\)[0] == \(-0.000603868564028268`\) + 
            0.0007839832773034097`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 50, "]=", 
        Equal[ 
          c[ 50][ 0], 
          Complex[ -0.00060386856402826802, 0.00078398327730340965]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]51\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[51]\)[0] == \(-0.0007324966996513722`\) - 
            0.00009780765245957932`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 51, "]=", 
        Equal[ 
          c[ 51][ 0], 
          Complex[ -0.00073249669965137223, -9.7807652459579319*^-05]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]52\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[52]\)[0] == \(-0.0002079565135738711`\) - 
            0.0005046781250323431`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 52, "]=", 
        Equal[ 
          c[ 52][ 0], 
          Complex[ -0.00020795651357387109, -0.00050467812503234314]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]53\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[53]\)[
            0] == \(\(0.0002433431627626659`\)\(\[InvisibleSpace]\)\) - 
            0.0003159246591334756`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 53, "]=", 
        Equal[ 
          c[ 53][ 0], 
          Complex[ 0.0002433431627626659, -0.00031592465913347559]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]54\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[54]\)[
            0] == \(\(0.0002856239908441051`\)\(\[InvisibleSpace]\)\) + 
            0.00003813834525656477`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 54, "]=", 
        Equal[ 
          c[ 54][ 0], 
          Complex[ 0.0002856239908441051, 3.8138345256564772*^-05]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]55\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[55]\)[
            0] == \(\(0.00007846461041173066`\)\(\[InvisibleSpace]\)\) + 
            0.0001904214096661091`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 55, "]=", 
        Equal[ 
          c[ 55][ 0], 
          Complex[ 7.8464610411730655*^-05, 0.00019042140966610911]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]56\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[56]\)[0] == \(-0.00008884494595643638`\) + 
            0.0001153445568322568`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 56, "]=", 
        Equal[ 
          c[ 56][ 0], 
          Complex[ -8.8844945956436384*^-05, 0.0001153445568322568]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]57\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[57]\)[0] == \(-0.00010090682614907303`\) - 
            0.000013473725939631881`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 57, "]=", 
        Equal[ 
          c[ 57][ 0], 
          Complex[ -0.00010090682614907303, -1.3473725939631881*^-05]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]58\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[58]\)[0] == \(-0.00002682328539272314`\) - 
            0.00006509594312081132`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 58, "]=", 
        Equal[ 
          c[ 58][ 0], 
          Complex[ -2.682328539272314*^-05, -6.5095943120811319*^-05]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]59\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[59]\)[
            0] == \(\(0.000029388888379470103`\)\(\[InvisibleSpace]\)\) - 
            0.000038154655500435244`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 59, "]=", 
        Equal[ 
          c[ 59][ 0], 
          Complex[ 2.9388888379470103*^-05, -3.8154655500435244*^-05]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]60\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[60]\)[
            0] == \(\(0.00003229856761218889`\)\(\[InvisibleSpace]\)\) + 
            4.31271168519765`*^-6\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 60, "]=", 
        Equal[ 
          c[ 60][ 0], 
          Complex[ 3.2298567612188888*^-05, 4.3127116851976502*^-06]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-60\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-60\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(79.95683520871486`\ \(c[\(-60\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-59\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-58\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-57\)]\)[t] + 
            0.8870637930591835`\ \(c[\(-56\)]\)[t] + 
            0.826993343132688`\ \(c[\(-55\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-54\)]\)[t] + 
            0.6783560385470627`\ \(c[\(-53\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-52\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-51\)]\)[t] + 
            0.4134966715663436`\ \(c[\(-50\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-49\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-48\)]\)[t] + 
            0.14938649372796314`\ \(c[\(-47\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-46\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-45\)]\)[t] - 
            0.06204407497545072`\ \(c[\(-44\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-43\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-42\)]\)[t] - 
            0.18675027222298618`\ \(c[\(-41\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-40\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-39\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-38\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-37\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-36\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-35\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-34\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-33\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-32\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-31\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-30\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-29\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-28\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-27\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-26\)]\)[t] + 
            0.1181419061618126`\ \(c[\(-25\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-24\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-23\)]\)[t] + 
            0.12496032289024847`\ \(c[\(-22\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-21\)]\)[t] + 
            0.10337416789158595`\ \(c[\(-20\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-19\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-18\)]\)[t] + 
            0.045163358568919114`\ \(c[\(-17\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-16\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-15\)]\)[t] - 
            0.021580547817548056`\ \(c[\(-14\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-13\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-12\)]\)[t] - 
            0.07241337086197425`\ \(c[\(-11\)]\)[t] - 
            0.08269933431326881`\ \(c[\(-10\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-9\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-8\)]\)[t] - 
            0.08959419377036684`\ \(c[\(-7\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-6\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-5\)]\)[t] - 
            0.0633616995042274`\ \(c[\(-4\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-3\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-2\)]\)[t] - 
            0.016825511857749262`\ \(c[\(-1\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[0]\)[t] + 
            0.016273855731265604`\ \(c[1]\)[t] + 
            0.0313229744913472`\ \(c[2]\)[t] + 
            0.04454710875183992`\ \(c[3]\)[t] + 
            0.05544148706619893`\ \(c[4]\)[t] + 
            0.06361487254866832`\ \(c[5]\)[t] + 
            0.06880242987642335`\ \(c[6]\)[t] + 
            0.07087301895267824`\ \(c[7]\)[t] + 
            0.06983076867396239`\ \(c[8]\)[t] + 
            0.06581101988179627`\ \(c[9]\)[t] + 
            0.059070953080906326`\ \(c[10]\)[t] + 
            0.049975424961080865`\ \(c[11]\)[t] + 
            0.03897872015785999`\ \(c[12]\)[t] + 
            0.026603074225527826`\ \(c[13]\)[t] + 
            0.013414935129827233`\ \(c[14]\)[t] + 
            3.898171832519376`*^-17\ \(c[15]\)[t] - 
            0.013061910521147383`\ \(c[16]\)[t] - 
            0.025221096343682053`\ \(c[17]\)[t] - 
            0.03598035706879378`\ \(c[18]\)[t] - 
            0.04491462243337642`\ \(c[19]\)[t] - 
            0.05168708394579296`\ \(c[20]\)[t] - 
            0.056061239158567186`\ \(c[21]\)[t] - 
            0.0579084423149932`\ \(c[22]\)[t] - 
            0.05721075023890897`\ \(c[23]\)[t] - 
            0.054059052045761224`\ \(c[24]\)[t] - 
            0.04864666724309928`\ \(c[25]\)[t] - 
            0.04125878107252025`\ \(c[26]\)[t] - 
            0.03225825116512552`\ \(c[27]\)[t] - 
            0.022068459300722043`\ \(c[28]\)[t] - 
            0.011153991006822649`\ \(c[29]\)[t] - 
            3.8981718325193755`*^-17\ \(c[30]\)[t] + 
            0.010908848347331966`\ \(c[31]\)[t] + 
            0.021108961070255627`\ \(c[32]\)[t] + 
            0.030177073670601236`\ \(c[33]\)[t] + 
            0.03774739544932687`\ \(c[34]\)[t] + 
            0.04352596542803616`\ \(c[35]\)[t] + 
            0.04730167054004106`\ \(c[36]\)[t] + 
            0.04895352855494272`\ \(c[37]\)[t] + 
            0.04845400275336168`\ \(c[38]\)[t] + 
            0.045868286584282256`\ \(c[39]\)[t] + 
            0.04134966715663448`\ \(c[40]\)[t] + 
            0.035131239329076656`\ \(c[41]\)[t] + 
            0.027514390699665887`\ \(c[42]\)[t] + 
            0.018854606004500233`\ \(c[43]\)[t] + 
            0.009545242303915543`\ \(c[44]\)[t] + 
            3.8981718325193755`*^-17\ \(c[45]\)[t] - 
            0.009365143392520679`\ \(c[46]\)[t] - 
            0.018149760920219783`\ \(c[47]\)[t] - 
            0.02598581343857328`\ \(c[48]\)[t] - 
            0.032552799745291155`\ \(c[49]\)[t] - 
            0.037590606506031236`\ \(c[50]\)[t] - 
            0.040909552899494966`\ \(c[51]\)[t] - 
            0.04239725240919144`\ \(c[52]\)[t] - 
            0.042022055485216314`\ \(c[53]\)[t] - 
            0.039832985717929335`\ \(c[54]\)[t] - 
            0.03595623231011687`\ \(c[55]\)[t] - 
            0.030588406657213296`\ \(c[56]\)[t] - 
            0.023986904712529237`\ \(c[57]\)[t] - 
            0.01645783405477577`\ \(c[58]\)[t] - 
            0.008342060500900982`\ \(c[59]\)[t] - 
            3.898171832519376`*^-17\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -60, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -60]][ t]], 
          Plus[ 
            Times[ 79.956835208714864, 
              c[ -60][ t]], 
            Times[ 0.99270519960720671, 
              c[ -59][ t]], 
            Times[ 0.9710122092317629, 
              c[ -58][ t]], 
            Times[ 0.93548928378863916, 
              c[ -57][ t]], 
            Times[ 0.88706379305918348, 
              c[ -56][ t]], 
            Times[ 0.82699334313268802, 
              c[ -55][ t]], 
            Times[ 0.75682672864065692, 
              c[ -54][ t]], 
            Times[ 0.67835603854706272, 
              c[ -53][ t]], 
            Times[ 0.59356153372868015, 
              c[ -52][ t]], 
            Times[ 0.50455115242710469, 
              c[ -51][ t]], 
            Times[ 0.41349667156634362, 
              c[ -50][ t]], 
            Times[ 0.32256865202152113, 
              c[ -49][ t]], 
            Times[ 0.23387232094715985, 
              c[ -48][ t]], 
            Times[ 0.14938649372796314, 
              c[ -47][ t]], 
            Times[ 0.070907514257657456, 
              c[ -46][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -45][ t]], 
            Times[ -0.062044074975450718, 
              c[ -44][ t]], 
            Times[ -0.11423673049785459, 
              c[ -43][ t]], 
            Times[ -0.15591488063143982, 
              c[ -42][ t]], 
            Times[ -0.18675027222298618, 
              c[ -41][ t]], 
            Times[ -0.20674833578317206, 
              c[ -40][ t]], 
            Times[ -0.21623620818304484, 
              c[ -39][ t]], 
            Times[ -0.21584055771952013, 
              c[ -38][ t]], 
            Times[ -0.20645618564475834, 
              c[ -37][ t]], 
            Times[ -0.18920668216016426, 
              c[ -36][ t]], 
            Times[ -0.1653986686265376, 
              c[ -35][ t]], 
            Times[ -0.13647135277833591, 
              c[ -34][ t]], 
            Times[ -0.10394325375429328, 
              c[ -33][ t]], 
            Times[ -0.069358014945125918, 
              c[ -32][ t]], 
            Times[ -0.034231213779558796, 
              c[ -31][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -30][ t]], 
            Times[ 0.032022748374426029, 
              c[ -29][ t]], 
            Times[ 0.060688263076985223, 
              c[ -28][ t]], 
            Times[ 0.085044480344421705, 
              c[ -27][ t]], 
            Times[ 0.10436044624225692, 
              c[ -26][ t]], 
            Times[ 0.1181419061618126, 
              c[ -25][ t]], 
            Times[ 0.12613778810677614, 
              c[ -24][ t]], 
            Times[ 0.12833762891430925, 
              c[ -23][ t]], 
            Times[ 0.12496032289024847, 
              c[ -22][ t]], 
            Times[ 0.11643488132933186, 
              c[ -21][ t]], 
            Times[ 0.10337416789158595, 
              c[ -20][ t]], 
            Times[ 0.086542809078944752, 
              c[ -19][ t]], 
            Times[ 0.066820663127759972, 
              c[ -18][ t]], 
            Times[ 0.045163358568919114, 
              c[ -17][ t]], 
            Times[ 0.022561481809254675, 
              c[ -16][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -15][ t]], 
            Times[ -0.021580547817548056, 
              c[ -14][ t]], 
            Times[ -0.041319668477947373, 
              c[ -13][ t]], 
            Times[ -0.058468080236789913, 
              c[ -12][ t]], 
            Times[ -0.072413370861974247, 
              c[ -11][ t]], 
            Times[ -0.082699334313268813, 
              c[ -10][ t]], 
            Times[ -0.089038438663606695, 
              c[ -9][ t]], 
            Times[ -0.091317159035181589, 
              c[ -8][ t]], 
            Times[ -0.089594193770366842, 
              c[ -7][ t]], 
            Times[ -0.084091858737850814, 
              c[ -6][ t]], 
            Times[ -0.075181213012062598, 
              c[ -5][ t]], 
            Times[ -0.063361699504227403, 
              c[ -4][ t]], 
            Times[ -0.049236278094138941, 
              c[ -3][ t]], 
            Times[ -0.033483179628681567, 
              c[ -2][ t]], 
            Times[ -0.016825511857749262, 
              c[ -1][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 0][ t]], 
            Times[ 0.016273855731265604, 
              c[ 1][ t]], 
            Times[ 0.031322974491347202, 
              c[ 2][ t]], 
            Times[ 0.044547108751839919, 
              c[ 3][ t]], 
            Times[ 0.055441487066198933, 
              c[ 4][ t]], 
            Times[ 0.063614872548668322, 
              c[ 5][ t]], 
            Times[ 0.068802429876423349, 
              c[ 6][ t]], 
            Times[ 0.070873018952678238, 
              c[ 7][ t]], 
            Times[ 0.069830768673962387, 
              c[ 8][ t]], 
            Times[ 0.065811019881796273, 
              c[ 9][ t]], 
            Times[ 0.059070953080906326, 
              c[ 10][ t]], 
            Times[ 0.049975424961080865, 
              c[ 11][ t]], 
            Times[ 0.03897872015785999, 
              c[ 12][ t]], 
            Times[ 0.026603074225527826, 
              c[ 13][ t]], 
            Times[ 0.013414935129827233, 
              c[ 14][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 15][ t]], 
            Times[ -0.013061910521147383, 
              c[ 16][ t]], 
            Times[ -0.025221096343682053, 
              c[ 17][ t]], 
            Times[ -0.035980357068793781, 
              c[ 18][ t]], 
            Times[ -0.044914622433376419, 
              c[ 19][ t]], 
            Times[ -0.05168708394579296, 
              c[ 20][ t]], 
            Times[ -0.056061239158567186, 
              c[ 21][ t]], 
            Times[ -0.057908442314993203, 
              c[ 22][ t]], 
            Times[ -0.057210750238908967, 
              c[ 23][ t]], 
            Times[ -0.054059052045761224, 
              c[ 24][ t]], 
            Times[ -0.048646667243099281, 
              c[ 25][ t]], 
            Times[ -0.041258781072520248, 
              c[ 26][ t]], 
            Times[ -0.032258251165125519, 
              c[ 27][ t]], 
            Times[ -0.022068459300722043, 
              c[ 28][ t]], 
            Times[ -0.011153991006822649, 
              c[ 29][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 30][ t]], 
            Times[ 0.010908848347331966, 
              c[ 31][ t]], 
            Times[ 0.021108961070255627, 
              c[ 32][ t]], 
            Times[ 0.030177073670601236, 
              c[ 33][ t]], 
            Times[ 0.03774739544932687, 
              c[ 34][ t]], 
            Times[ 0.043525965428036162, 
              c[ 35][ t]], 
            Times[ 0.047301670540041058, 
              c[ 36][ t]], 
            Times[ 0.04895352855494272, 
              c[ 37][ t]], 
            Times[ 0.048454002753361682, 
              c[ 38][ t]], 
            Times[ 0.045868286584282256, 
              c[ 39][ t]], 
            Times[ 0.041349667156634483, 
              c[ 40][ t]], 
            Times[ 0.035131239329076656, 
              c[ 41][ t]], 
            Times[ 0.027514390699665887, 
              c[ 42][ t]], 
            Times[ 0.018854606004500233, 
              c[ 43][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 44][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 45][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 46][ t]], 
            Times[ -0.018149760920219783, 
              c[ 47][ t]], 
            Times[ -0.025985813438573278, 
              c[ 48][ t]], 
            Times[ -0.032552799745291155, 
              c[ 49][ t]], 
            Times[ -0.037590606506031236, 
              c[ 50][ t]], 
            Times[ -0.040909552899494966, 
              c[ 51][ t]], 
            Times[ -0.042397252409191441, 
              c[ 52][ t]], 
            Times[ -0.042022055485216314, 
              c[ 53][ t]], 
            Times[ -0.039832985717929335, 
              c[ 54][ t]], 
            Times[ -0.035956232310116867, 
              c[ 55][ t]], 
            Times[ -0.030588406657213296, 
              c[ 56][ t]], 
            Times[ -0.023986904712529237, 
              c[ 57][ t]], 
            Times[ -0.016457834054775768, 
              c[ 58][ t]], 
            Times[ -0.0083420605009009823, 
              c[ 59][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-59\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-59\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.9927051996072067`\ \(c[\(-60\)]\)[t] + 
            77.34687315598232`\ \(c[\(-59\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-58\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-57\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-56\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-55\)]\)[t] + 
            0.8269933431326885`\ \(c[\(-54\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-53\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-52\)]\)[t] + 
            0.5935615337286809`\ \(c[\(-51\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-50\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-49\)]\)[t] + 
            0.3225686520215219`\ \(c[\(-48\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-47\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-46\)]\)[t] + 
            0.0709075142576581`\ \(c[\(-45\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-44\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-43\)]\)[t] - 
            0.11423673049785416`\ \(c[\(-42\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-41\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-40\)]\)[t] - 
            0.2067483357831719`\ \(c[\(-39\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-38\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-37\)]\)[t] - 
            0.20645618564475848`\ \(c[\(-36\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-35\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-34\)]\)[t] - 
            0.13647135277833616`\ \(c[\(-33\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-32\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-31\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-30\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-29\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-28\)]\)[t] + 
            0.060688263076985`\ \(c[\(-27\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-26\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-25\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-24\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-23\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-22\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-21\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-20\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-19\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-18\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-17\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-16\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-15\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-14\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-13\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-12\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-11\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-10\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-9\)]\)[t] - 
            0.08903843866360665`\ \(c[\(-8\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-7\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-6\)]\)[t] - 
            0.08409185873785086`\ \(c[\(-5\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-4\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-3\)]\)[t] - 
            0.049236278094139066`\ \(c[\(-2\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-1\)]\)[t] - 
            0.0168255118577494`\ \(c[0]\)[t] - 
            1.8033970416801674`*^-16\ \(c[1]\)[t] + 
            0.016273855731265604`\ \(c[2]\)[t] + 
            0.03132297449134708`\ \(c[3]\)[t] + 
            0.044547108751839815`\ \(c[4]\)[t] + 
            0.05544148706619893`\ \(c[5]\)[t] + 
            0.06361487254866825`\ \(c[6]\)[t] + 
            0.06880242987642332`\ \(c[7]\)[t] + 
            0.07087301895267824`\ \(c[8]\)[t] + 
            0.06983076867396242`\ \(c[9]\)[t] + 
            0.06581101988179631`\ \(c[10]\)[t] + 
            0.0590709530809064`\ \(c[11]\)[t] + 
            0.049975424961080865`\ \(c[12]\)[t] + 
            0.03897872015786009`\ \(c[13]\)[t] + 
            0.026603074225527937`\ \(c[14]\)[t] + 
            0.013414935129827233`\ \(c[15]\)[t] + 
            1.5206810699945212`*^-16\ \(c[16]\)[t] - 
            0.013061910521147276`\ \(c[17]\)[t] - 
            0.025221096343682053`\ \(c[18]\)[t] - 
            0.03598035706879378`\ \(c[19]\)[t] - 
            0.04491462243337629`\ \(c[20]\)[t] - 
            0.05168708394579296`\ \(c[21]\)[t] - 
            0.05606123915856713`\ \(c[22]\)[t] - 
            0.0579084423149932`\ \(c[23]\)[t] - 
            0.05721075023890897`\ \(c[24]\)[t] - 
            0.054059052045761224`\ \(c[25]\)[t] - 
            0.0486466672430994`\ \(c[26]\)[t] - 
            0.04125878107252025`\ \(c[27]\)[t] - 
            0.03225825116512568`\ \(c[28]\)[t] - 
            0.022068459300722043`\ \(c[29]\)[t] - 
            0.011153991006822649`\ \(c[30]\)[t] - 
            3.8981718325193755`*^-17\ \(c[31]\)[t] + 
            0.010908848347331785`\ \(c[32]\)[t] + 
            0.021108961070255627`\ \(c[33]\)[t] + 
            0.030177073670601094`\ \(c[34]\)[t] + 
            0.03774739544932687`\ \(c[35]\)[t] + 
            0.04352596542803616`\ \(c[36]\)[t] + 
            0.04730167054004106`\ \(c[37]\)[t] + 
            0.0489535285549427`\ \(c[38]\)[t] + 
            0.04845400275336168`\ \(c[39]\)[t] + 
            0.04586828658428231`\ \(c[40]\)[t] + 
            0.04134966715663448`\ \(c[41]\)[t] + 
            0.035131239329076656`\ \(c[42]\)[t] + 
            0.027514390699665887`\ \(c[43]\)[t] + 
            0.01885460600450039`\ \(c[44]\)[t] + 
            0.009545242303915543`\ \(c[45]\)[t] + 
            2.0053370214556287`*^-16\ \(c[46]\)[t] - 
            0.009365143392520679`\ \(c[47]\)[t] - 
            0.018149760920219783`\ \(c[48]\)[t] - 
            0.02598581343857328`\ \(c[49]\)[t] - 
            0.03255279974529105`\ \(c[50]\)[t] - 
            0.037590606506031236`\ \(c[51]\)[t] - 
            0.040909552899494925`\ \(c[52]\)[t] - 
            0.04239725240919144`\ \(c[53]\)[t] - 
            0.042022055485216314`\ \(c[54]\)[t] - 
            0.039832985717929335`\ \(c[55]\)[t] - 
            0.035956232310116944`\ \(c[56]\)[t] - 
            0.030588406657213296`\ \(c[57]\)[t] - 
            0.02398690471252936`\ \(c[58]\)[t] - 
            0.01645783405477577`\ \(c[59]\)[t] - 
            0.008342060500900982`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -59, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -59]][ t]], 
          Plus[ 
            Times[ 0.99270519960720671, 
              c[ -60][ t]], 
            Times[ 77.346873155982323, 
              c[ -59][ t]], 
            Times[ 0.99270519960720693, 
              c[ -58][ t]], 
            Times[ 0.9710122092317629, 
              c[ -57][ t]], 
            Times[ 0.93548928378863916, 
              c[ -56][ t]], 
            Times[ 0.88706379305918392, 
              c[ -55][ t]], 
            Times[ 0.82699334313268846, 
              c[ -54][ t]], 
            Times[ 0.75682672864065692, 
              c[ -53][ t]], 
            Times[ 0.67835603854706361, 
              c[ -52][ t]], 
            Times[ 0.59356153372868092, 
              c[ -51][ t]], 
            Times[ 0.50455115242710469, 
              c[ -50][ t]], 
            Times[ 0.41349667156634429, 
              c[ -49][ t]], 
            Times[ 0.32256865202152191, 
              c[ -48][ t]], 
            Times[ 0.23387232094715985, 
              c[ -47][ t]], 
            Times[ 0.14938649372796384, 
              c[ -46][ t]], 
            Times[ 0.070907514257658094, 
              c[ -45][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -44][ t]], 
            Times[ -0.062044074975450239, 
              c[ -43][ t]], 
            Times[ -0.11423673049785416, 
              c[ -42][ t]], 
            Times[ -0.15591488063143982, 
              c[ -41][ t]], 
            Times[ -0.18675027222298593, 
              c[ -40][ t]], 
            Times[ -0.20674833578317189, 
              c[ -39][ t]], 
            Times[ -0.21623620818304481, 
              c[ -38][ t]], 
            Times[ -0.21584055771952015, 
              c[ -37][ t]], 
            Times[ -0.20645618564475848, 
              c[ -36][ t]], 
            Times[ -0.18920668216016434, 
              c[ -35][ t]], 
            Times[ -0.16539866862653771, 
              c[ -34][ t]], 
            Times[ -0.13647135277833616, 
              c[ -33][ t]], 
            Times[ -0.1039432537542934, 
              c[ -32][ t]], 
            Times[ -0.06935801494512607, 
              c[ -31][ t]], 
            Times[ -0.034231213779559094, 
              c[ -30][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -29][ t]], 
            Times[ 0.032022748374425904, 
              c[ -28][ t]], 
            Times[ 0.060688263076985001, 
              c[ -27][ t]], 
            Times[ 0.085044480344421608, 
              c[ -26][ t]], 
            Times[ 0.10436044624225685, 
              c[ -25][ t]], 
            Times[ 0.11814190616181253, 
              c[ -24][ t]], 
            Times[ 0.12613778810677612, 
              c[ -23][ t]], 
            Times[ 0.12833762891430928, 
              c[ -22][ t]], 
            Times[ 0.12496032289024853, 
              c[ -21][ t]], 
            Times[ 0.11643488132933186, 
              c[ -20][ t]], 
            Times[ 0.10337416789158609, 
              c[ -19][ t]], 
            Times[ 0.086542809078944891, 
              c[ -18][ t]], 
            Times[ 0.066820663127759972, 
              c[ -17][ t]], 
            Times[ 0.045163358568919301, 
              c[ -16][ t]], 
            Times[ 0.022561481809254869, 
              c[ -15][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -14][ t]], 
            Times[ -0.021580547817547879, 
              c[ -13][ t]], 
            Times[ -0.04131966847794722, 
              c[ -12][ t]], 
            Times[ -0.058468080236789913, 
              c[ -11][ t]], 
            Times[ -0.072413370861974122, 
              c[ -10][ t]], 
            Times[ -0.082699334313268744, 
              c[ -9][ t]], 
            Times[ -0.089038438663606653, 
              c[ -8][ t]], 
            Times[ -0.091317159035181589, 
              c[ -7][ t]], 
            Times[ -0.089594193770366884, 
              c[ -6][ t]], 
            Times[ -0.084091858737850855, 
              c[ -5][ t]], 
            Times[ -0.075181213012062598, 
              c[ -4][ t]], 
            Times[ -0.063361699504227528, 
              c[ -3][ t]], 
            Times[ -0.049236278094139066, 
              c[ -2][ t]], 
            Times[ -0.033483179628681567, 
              c[ -1][ t]], 
            Times[ -0.016825511857749401, 
              c[ 0][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 1][ t]], 
            Times[ 0.016273855731265604, 
              c[ 2][ t]], 
            Times[ 0.031322974491347078, 
              c[ 3][ t]], 
            Times[ 0.044547108751839815, 
              c[ 4][ t]], 
            Times[ 0.055441487066198933, 
              c[ 5][ t]], 
            Times[ 0.063614872548668253, 
              c[ 6][ t]], 
            Times[ 0.068802429876423321, 
              c[ 7][ t]], 
            Times[ 0.070873018952678238, 
              c[ 8][ t]], 
            Times[ 0.069830768673962415, 
              c[ 9][ t]], 
            Times[ 0.065811019881796315, 
              c[ 10][ t]], 
            Times[ 0.059070953080906402, 
              c[ 11][ t]], 
            Times[ 0.049975424961080865, 
              c[ 12][ t]], 
            Times[ 0.038978720157860088, 
              c[ 13][ t]], 
            Times[ 0.026603074225527937, 
              c[ 14][ t]], 
            Times[ 0.013414935129827233, 
              c[ 15][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ 16][ t]], 
            Times[ -0.013061910521147276, 
              c[ 17][ t]], 
            Times[ -0.025221096343682053, 
              c[ 18][ t]], 
            Times[ -0.035980357068793781, 
              c[ 19][ t]], 
            Times[ -0.044914622433376288, 
              c[ 20][ t]], 
            Times[ -0.05168708394579296, 
              c[ 21][ t]], 
            Times[ -0.05606123915856713, 
              c[ 22][ t]], 
            Times[ -0.057908442314993203, 
              c[ 23][ t]], 
            Times[ -0.057210750238908967, 
              c[ 24][ t]], 
            Times[ -0.054059052045761224, 
              c[ 25][ t]], 
            Times[ -0.048646667243099399, 
              c[ 26][ t]], 
            Times[ -0.041258781072520248, 
              c[ 27][ t]], 
            Times[ -0.032258251165125679, 
              c[ 28][ t]], 
            Times[ -0.022068459300722043, 
              c[ 29][ t]], 
            Times[ -0.011153991006822649, 
              c[ 30][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 31][ t]], 
            Times[ 0.010908848347331785, 
              c[ 32][ t]], 
            Times[ 0.021108961070255627, 
              c[ 33][ t]], 
            Times[ 0.030177073670601094, 
              c[ 34][ t]], 
            Times[ 0.03774739544932687, 
              c[ 35][ t]], 
            Times[ 0.043525965428036162, 
              c[ 36][ t]], 
            Times[ 0.047301670540041058, 
              c[ 37][ t]], 
            Times[ 0.048953528554942699, 
              c[ 38][ t]], 
            Times[ 0.048454002753361682, 
              c[ 39][ t]], 
            Times[ 0.045868286584282311, 
              c[ 40][ t]], 
            Times[ 0.041349667156634483, 
              c[ 41][ t]], 
            Times[ 0.035131239329076656, 
              c[ 42][ t]], 
            Times[ 0.027514390699665887, 
              c[ 43][ t]], 
            Times[ 0.018854606004500389, 
              c[ 44][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 45][ t]], 
            Times[ 2.0053370214556287*^-16, 
              c[ 46][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 47][ t]], 
            Times[ -0.018149760920219783, 
              c[ 48][ t]], 
            Times[ -0.025985813438573278, 
              c[ 49][ t]], 
            Times[ -0.032552799745291051, 
              c[ 50][ t]], 
            Times[ -0.037590606506031236, 
              c[ 51][ t]], 
            Times[ -0.040909552899494925, 
              c[ 52][ t]], 
            Times[ -0.042397252409191441, 
              c[ 53][ t]], 
            Times[ -0.042022055485216314, 
              c[ 54][ t]], 
            Times[ -0.039832985717929335, 
              c[ 55][ t]], 
            Times[ -0.035956232310116944, 
              c[ 56][ t]], 
            Times[ -0.030588406657213296, 
              c[ 57][ t]], 
            Times[ -0.023986904712529358, 
              c[ 58][ t]], 
            Times[ -0.016457834054775768, 
              c[ 59][ t]], 
            Times[ -0.0083420605009009823, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-58\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-58\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.9710122092317629`\ \(c[\(-60\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-59\)]\)[t] + 
            74.7807760116991`\ \(c[\(-58\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-57\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-56\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-55\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-54\)]\)[t] + 
            0.826993343132688`\ \(c[\(-53\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-52\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-51\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-50\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-49\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-48\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-47\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-46\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-45\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-44\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-43\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-42\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-41\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-40\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-39\)]\)[t] - 
            0.206748335783172`\ \(c[\(-38\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-37\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-36\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-35\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-34\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-33\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-32\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-31\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-30\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-29\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-28\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-27\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-26\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-25\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-24\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-23\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-22\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-21\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-20\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-19\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-18\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-17\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-16\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-15\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-14\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-13\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-12\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-11\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-10\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-9\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-8\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-7\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-6\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-5\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-4\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-3\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-2\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-1\)]\)[t] - 
            0.03348317962868157`\ \(c[0]\)[t] - 
            0.0168255118577494`\ \(c[1]\)[t] - 
            3.898171832519376`*^-17\ \(c[2]\)[t] + 
            0.016273855731265604`\ \(c[3]\)[t] + 
            0.03132297449134708`\ \(c[4]\)[t] + 
            0.04454710875183992`\ \(c[5]\)[t] + 
            0.05544148706619893`\ \(c[6]\)[t] + 
            0.06361487254866825`\ \(c[7]\)[t] + 
            0.06880242987642335`\ \(c[8]\)[t] + 
            0.07087301895267824`\ \(c[9]\)[t] + 
            0.06983076867396242`\ \(c[10]\)[t] + 
            0.06581101988179627`\ \(c[11]\)[t] + 
            0.059070953080906326`\ \(c[12]\)[t] + 
            0.049975424961080865`\ \(c[13]\)[t] + 
            0.03897872015785999`\ \(c[14]\)[t] + 
            0.026603074225527826`\ \(c[15]\)[t] + 
            0.013414935129827233`\ \(c[16]\)[t] + 
            3.898171832519376`*^-17\ \(c[17]\)[t] - 
            0.013061910521147383`\ \(c[18]\)[t] - 
            0.025221096343682053`\ \(c[19]\)[t] - 
            0.03598035706879378`\ \(c[20]\)[t] - 
            0.04491462243337642`\ \(c[21]\)[t] - 
            0.05168708394579296`\ \(c[22]\)[t] - 
            0.056061239158567186`\ \(c[23]\)[t] - 
            0.0579084423149932`\ \(c[24]\)[t] - 
            0.05721075023890897`\ \(c[25]\)[t] - 
            0.054059052045761224`\ \(c[26]\)[t] - 
            0.04864666724309928`\ \(c[27]\)[t] - 
            0.04125878107252025`\ \(c[28]\)[t] - 
            0.03225825116512552`\ \(c[29]\)[t] - 
            0.022068459300722043`\ \(c[30]\)[t] - 
            0.011153991006822649`\ \(c[31]\)[t] - 
            3.8981718325193755`*^-17\ \(c[32]\)[t] + 
            0.010908848347331966`\ \(c[33]\)[t] + 
            0.021108961070255627`\ \(c[34]\)[t] + 
            0.030177073670601236`\ \(c[35]\)[t] + 
            0.03774739544932687`\ \(c[36]\)[t] + 
            0.04352596542803616`\ \(c[37]\)[t] + 
            0.04730167054004106`\ \(c[38]\)[t] + 
            0.04895352855494272`\ \(c[39]\)[t] + 
            0.04845400275336168`\ \(c[40]\)[t] + 
            0.04586828658428231`\ \(c[41]\)[t] + 
            0.04134966715663448`\ \(c[42]\)[t] + 
            0.035131239329076656`\ \(c[43]\)[t] + 
            0.027514390699665887`\ \(c[44]\)[t] + 
            0.018854606004500233`\ \(c[45]\)[t] + 
            0.009545242303915543`\ \(c[46]\)[t] + 
            2.0053370214556287`*^-16\ \(c[47]\)[t] - 
            0.009365143392520679`\ \(c[48]\)[t] - 
            0.018149760920219783`\ \(c[49]\)[t] - 
            0.02598581343857328`\ \(c[50]\)[t] - 
            0.032552799745291155`\ \(c[51]\)[t] - 
            0.037590606506031236`\ \(c[52]\)[t] - 
            0.040909552899494925`\ \(c[53]\)[t] - 
            0.04239725240919144`\ \(c[54]\)[t] - 
            0.042022055485216314`\ \(c[55]\)[t] - 
            0.039832985717929335`\ \(c[56]\)[t] - 
            0.03595623231011687`\ \(c[57]\)[t] - 
            0.030588406657213296`\ \(c[58]\)[t] - 
            0.02398690471252936`\ \(c[59]\)[t] - 
            0.01645783405477577`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -58, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -58]][ t]], 
          Plus[ 
            Times[ 0.9710122092317629, 
              c[ -60][ t]], 
            Times[ 0.99270519960720693, 
              c[ -59][ t]], 
            Times[ 74.780776011699103, 
              c[ -58][ t]], 
            Times[ 0.99270519960720693, 
              c[ -57][ t]], 
            Times[ 0.9710122092317629, 
              c[ -56][ t]], 
            Times[ 0.93548928378863916, 
              c[ -55][ t]], 
            Times[ 0.88706379305918392, 
              c[ -54][ t]], 
            Times[ 0.82699334313268802, 
              c[ -53][ t]], 
            Times[ 0.75682672864065692, 
              c[ -52][ t]], 
            Times[ 0.67835603854706361, 
              c[ -51][ t]], 
            Times[ 0.59356153372868015, 
              c[ -50][ t]], 
            Times[ 0.50455115242710469, 
              c[ -49][ t]], 
            Times[ 0.41349667156634429, 
              c[ -48][ t]], 
            Times[ 0.32256865202152113, 
              c[ -47][ t]], 
            Times[ 0.23387232094715985, 
              c[ -46][ t]], 
            Times[ 0.14938649372796384, 
              c[ -45][ t]], 
            Times[ 0.070907514257657456, 
              c[ -44][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -43][ t]], 
            Times[ -0.062044074975450239, 
              c[ -42][ t]], 
            Times[ -0.11423673049785459, 
              c[ -41][ t]], 
            Times[ -0.15591488063143982, 
              c[ -40][ t]], 
            Times[ -0.18675027222298593, 
              c[ -39][ t]], 
            Times[ -0.206748335783172, 
              c[ -38][ t]], 
            Times[ -0.21623620818304484, 
              c[ -37][ t]], 
            Times[ -0.21584055771952015, 
              c[ -36][ t]], 
            Times[ -0.20645618564475843, 
              c[ -35][ t]], 
            Times[ -0.18920668216016426, 
              c[ -34][ t]], 
            Times[ -0.16539866862653771, 
              c[ -33][ t]], 
            Times[ -0.13647135277833605, 
              c[ -32][ t]], 
            Times[ -0.10394325375429328, 
              c[ -31][ t]], 
            Times[ -0.06935801494512607, 
              c[ -30][ t]], 
            Times[ -0.034231213779558949, 
              c[ -29][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -28][ t]], 
            Times[ 0.032022748374425904, 
              c[ -27][ t]], 
            Times[ 0.060688263076985105, 
              c[ -26][ t]], 
            Times[ 0.085044480344421705, 
              c[ -25][ t]], 
            Times[ 0.10436044624225685, 
              c[ -24][ t]], 
            Times[ 0.11814190616181255, 
              c[ -23][ t]], 
            Times[ 0.12613778810677614, 
              c[ -22][ t]], 
            Times[ 0.12833762891430928, 
              c[ -21][ t]], 
            Times[ 0.12496032289024853, 
              c[ -20][ t]], 
            Times[ 0.11643488132933186, 
              c[ -19][ t]], 
            Times[ 0.10337416789158609, 
              c[ -18][ t]], 
            Times[ 0.086542809078944891, 
              c[ -17][ t]], 
            Times[ 0.066820663127759972, 
              c[ -16][ t]], 
            Times[ 0.045163358568919301, 
              c[ -15][ t]], 
            Times[ 0.022561481809254869, 
              c[ -14][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -13][ t]], 
            Times[ -0.021580547817547879, 
              c[ -12][ t]], 
            Times[ -0.04131966847794722, 
              c[ -11][ t]], 
            Times[ -0.058468080236789913, 
              c[ -10][ t]], 
            Times[ -0.072413370861974122, 
              c[ -9][ t]], 
            Times[ -0.082699334313268744, 
              c[ -8][ t]], 
            Times[ -0.089038438663606695, 
              c[ -7][ t]], 
            Times[ -0.091317159035181589, 
              c[ -6][ t]], 
            Times[ -0.089594193770366884, 
              c[ -5][ t]], 
            Times[ -0.084091858737850814, 
              c[ -4][ t]], 
            Times[ -0.075181213012062598, 
              c[ -3][ t]], 
            Times[ -0.063361699504227528, 
              c[ -2][ t]], 
            Times[ -0.049236278094138941, 
              c[ -1][ t]], 
            Times[ -0.033483179628681567, 
              c[ 0][ t]], 
            Times[ -0.016825511857749401, 
              c[ 1][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 2][ t]], 
            Times[ 0.016273855731265604, 
              c[ 3][ t]], 
            Times[ 0.031322974491347078, 
              c[ 4][ t]], 
            Times[ 0.044547108751839919, 
              c[ 5][ t]], 
            Times[ 0.055441487066198933, 
              c[ 6][ t]], 
            Times[ 0.063614872548668253, 
              c[ 7][ t]], 
            Times[ 0.068802429876423349, 
              c[ 8][ t]], 
            Times[ 0.070873018952678238, 
              c[ 9][ t]], 
            Times[ 0.069830768673962415, 
              c[ 10][ t]], 
            Times[ 0.065811019881796273, 
              c[ 11][ t]], 
            Times[ 0.059070953080906326, 
              c[ 12][ t]], 
            Times[ 0.049975424961080865, 
              c[ 13][ t]], 
            Times[ 0.03897872015785999, 
              c[ 14][ t]], 
            Times[ 0.026603074225527826, 
              c[ 15][ t]], 
            Times[ 0.013414935129827233, 
              c[ 16][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 17][ t]], 
            Times[ -0.013061910521147383, 
              c[ 18][ t]], 
            Times[ -0.025221096343682053, 
              c[ 19][ t]], 
            Times[ -0.035980357068793781, 
              c[ 20][ t]], 
            Times[ -0.044914622433376419, 
              c[ 21][ t]], 
            Times[ -0.05168708394579296, 
              c[ 22][ t]], 
            Times[ -0.056061239158567186, 
              c[ 23][ t]], 
            Times[ -0.057908442314993203, 
              c[ 24][ t]], 
            Times[ -0.057210750238908967, 
              c[ 25][ t]], 
            Times[ -0.054059052045761224, 
              c[ 26][ t]], 
            Times[ -0.048646667243099281, 
              c[ 27][ t]], 
            Times[ -0.041258781072520248, 
              c[ 28][ t]], 
            Times[ -0.032258251165125519, 
              c[ 29][ t]], 
            Times[ -0.022068459300722043, 
              c[ 30][ t]], 
            Times[ -0.011153991006822649, 
              c[ 31][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 32][ t]], 
            Times[ 0.010908848347331966, 
              c[ 33][ t]], 
            Times[ 0.021108961070255627, 
              c[ 34][ t]], 
            Times[ 0.030177073670601236, 
              c[ 35][ t]], 
            Times[ 0.03774739544932687, 
              c[ 36][ t]], 
            Times[ 0.043525965428036162, 
              c[ 37][ t]], 
            Times[ 0.047301670540041058, 
              c[ 38][ t]], 
            Times[ 0.04895352855494272, 
              c[ 39][ t]], 
            Times[ 0.048454002753361682, 
              c[ 40][ t]], 
            Times[ 0.045868286584282311, 
              c[ 41][ t]], 
            Times[ 0.041349667156634483, 
              c[ 42][ t]], 
            Times[ 0.035131239329076656, 
              c[ 43][ t]], 
            Times[ 0.027514390699665887, 
              c[ 44][ t]], 
            Times[ 0.018854606004500233, 
              c[ 45][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 46][ t]], 
            Times[ 2.0053370214556287*^-16, 
              c[ 47][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 48][ t]], 
            Times[ -0.018149760920219783, 
              c[ 49][ t]], 
            Times[ -0.025985813438573278, 
              c[ 50][ t]], 
            Times[ -0.032552799745291155, 
              c[ 51][ t]], 
            Times[ -0.037590606506031236, 
              c[ 52][ t]], 
            Times[ -0.040909552899494925, 
              c[ 53][ t]], 
            Times[ -0.042397252409191441, 
              c[ 54][ t]], 
            Times[ -0.042022055485216314, 
              c[ 55][ t]], 
            Times[ -0.039832985717929335, 
              c[ 56][ t]], 
            Times[ -0.035956232310116867, 
              c[ 57][ t]], 
            Times[ -0.030588406657213296, 
              c[ 58][ t]], 
            Times[ -0.023986904712529358, 
              c[ 59][ t]], 
            Times[ -0.016457834054775768, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-57\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-57\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.9354892837886392`\ \(c[\(-60\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-59\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-58\)]\)[t] + 
            72.25854377586516`\ \(c[\(-57\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-56\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-55\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-54\)]\)[t] + 
            0.8870637930591835`\ \(c[\(-53\)]\)[t] + 
            0.826993343132688`\ \(c[\(-52\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-51\)]\)[t] + 
            0.6783560385470627`\ \(c[\(-50\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-49\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-48\)]\)[t] + 
            0.4134966715663436`\ \(c[\(-47\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-46\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-45\)]\)[t] + 
            0.14938649372796314`\ \(c[\(-44\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-43\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-42\)]\)[t] - 
            0.06204407497545072`\ \(c[\(-41\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-40\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-39\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-38\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-37\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-36\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-35\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-34\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-33\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-32\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-31\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-30\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-29\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-28\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-27\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-26\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-25\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-24\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-23\)]\)[t] + 
            0.1181419061618126`\ \(c[\(-22\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-21\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-20\)]\)[t] + 
            0.12496032289024847`\ \(c[\(-19\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-18\)]\)[t] + 
            0.10337416789158595`\ \(c[\(-17\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-16\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-15\)]\)[t] + 
            0.045163358568919114`\ \(c[\(-14\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-13\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-12\)]\)[t] - 
            0.021580547817548056`\ \(c[\(-11\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-10\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-9\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-8\)]\)[t] - 
            0.08269933431326881`\ \(c[\(-7\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-6\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-5\)]\)[t] - 
            0.08959419377036684`\ \(c[\(-4\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-3\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-2\)]\)[t] - 
            0.0633616995042274`\ \(c[\(-1\)]\)[t] - 
            0.04923627809413894`\ \(c[0]\)[t] - 
            0.03348317962868157`\ \(c[1]\)[t] - 
            0.016825511857749262`\ \(c[2]\)[t] - 
            3.898171832519376`*^-17\ \(c[3]\)[t] + 
            0.016273855731265604`\ \(c[4]\)[t] + 
            0.0313229744913472`\ \(c[5]\)[t] + 
            0.04454710875183992`\ \(c[6]\)[t] + 
            0.05544148706619893`\ \(c[7]\)[t] + 
            0.06361487254866832`\ \(c[8]\)[t] + 
            0.06880242987642335`\ \(c[9]\)[t] + 
            0.07087301895267824`\ \(c[10]\)[t] + 
            0.06983076867396242`\ \(c[11]\)[t] + 
            0.06581101988179627`\ \(c[12]\)[t] + 
            0.059070953080906326`\ \(c[13]\)[t] + 
            0.049975424961080865`\ \(c[14]\)[t] + 
            0.03897872015785999`\ \(c[15]\)[t] + 
            0.026603074225527826`\ \(c[16]\)[t] + 
            0.013414935129827233`\ \(c[17]\)[t] + 
            3.898171832519376`*^-17\ \(c[18]\)[t] - 
            0.013061910521147383`\ \(c[19]\)[t] - 
            0.025221096343682053`\ \(c[20]\)[t] - 
            0.03598035706879378`\ \(c[21]\)[t] - 
            0.04491462243337642`\ \(c[22]\)[t] - 
            0.05168708394579296`\ \(c[23]\)[t] - 
            0.056061239158567186`\ \(c[24]\)[t] - 
            0.0579084423149932`\ \(c[25]\)[t] - 
            0.05721075023890897`\ \(c[26]\)[t] - 
            0.054059052045761224`\ \(c[27]\)[t] - 
            0.04864666724309928`\ \(c[28]\)[t] - 
            0.04125878107252025`\ \(c[29]\)[t] - 
            0.03225825116512552`\ \(c[30]\)[t] - 
            0.022068459300722043`\ \(c[31]\)[t] - 
            0.011153991006822649`\ \(c[32]\)[t] - 
            3.8981718325193755`*^-17\ \(c[33]\)[t] + 
            0.010908848347331966`\ \(c[34]\)[t] + 
            0.021108961070255627`\ \(c[35]\)[t] + 
            0.030177073670601236`\ \(c[36]\)[t] + 
            0.03774739544932687`\ \(c[37]\)[t] + 
            0.04352596542803616`\ \(c[38]\)[t] + 
            0.04730167054004106`\ \(c[39]\)[t] + 
            0.04895352855494272`\ \(c[40]\)[t] + 
            0.04845400275336168`\ \(c[41]\)[t] + 
            0.045868286584282256`\ \(c[42]\)[t] + 
            0.04134966715663448`\ \(c[43]\)[t] + 
            0.035131239329076656`\ \(c[44]\)[t] + 
            0.027514390699665887`\ \(c[45]\)[t] + 
            0.018854606004500233`\ \(c[46]\)[t] + 
            0.009545242303915543`\ \(c[47]\)[t] + 
            3.8981718325193755`*^-17\ \(c[48]\)[t] - 
            0.009365143392520679`\ \(c[49]\)[t] - 
            0.018149760920219783`\ \(c[50]\)[t] - 
            0.02598581343857328`\ \(c[51]\)[t] - 
            0.032552799745291155`\ \(c[52]\)[t] - 
            0.037590606506031236`\ \(c[53]\)[t] - 
            0.040909552899494966`\ \(c[54]\)[t] - 
            0.04239725240919144`\ \(c[55]\)[t] - 
            0.042022055485216314`\ \(c[56]\)[t] - 
            0.039832985717929335`\ \(c[57]\)[t] - 
            0.03595623231011687`\ \(c[58]\)[t] - 
            0.030588406657213296`\ \(c[59]\)[t] - 
            0.023986904712529237`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -57, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -57]][ t]], 
          Plus[ 
            Times[ 0.93548928378863916, 
              c[ -60][ t]], 
            Times[ 0.9710122092317629, 
              c[ -59][ t]], 
            Times[ 0.99270519960720693, 
              c[ -58][ t]], 
            Times[ 72.258543775865164, 
              c[ -57][ t]], 
            Times[ 0.99270519960720671, 
              c[ -56][ t]], 
            Times[ 0.9710122092317629, 
              c[ -55][ t]], 
            Times[ 0.93548928378863916, 
              c[ -54][ t]], 
            Times[ 0.88706379305918348, 
              c[ -53][ t]], 
            Times[ 0.82699334313268802, 
              c[ -52][ t]], 
            Times[ 0.75682672864065692, 
              c[ -51][ t]], 
            Times[ 0.67835603854706272, 
              c[ -50][ t]], 
            Times[ 0.59356153372868015, 
              c[ -49][ t]], 
            Times[ 0.50455115242710469, 
              c[ -48][ t]], 
            Times[ 0.41349667156634362, 
              c[ -47][ t]], 
            Times[ 0.32256865202152113, 
              c[ -46][ t]], 
            Times[ 0.23387232094715985, 
              c[ -45][ t]], 
            Times[ 0.14938649372796314, 
              c[ -44][ t]], 
            Times[ 0.070907514257657456, 
              c[ -43][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -42][ t]], 
            Times[ -0.062044074975450718, 
              c[ -41][ t]], 
            Times[ -0.11423673049785459, 
              c[ -40][ t]], 
            Times[ -0.15591488063143982, 
              c[ -39][ t]], 
            Times[ -0.18675027222298607, 
              c[ -38][ t]], 
            Times[ -0.20674833578317206, 
              c[ -37][ t]], 
            Times[ -0.21623620818304484, 
              c[ -36][ t]], 
            Times[ -0.21584055771952013, 
              c[ -35][ t]], 
            Times[ -0.20645618564475834, 
              c[ -34][ t]], 
            Times[ -0.18920668216016426, 
              c[ -33][ t]], 
            Times[ -0.1653986686265376, 
              c[ -32][ t]], 
            Times[ -0.13647135277833591, 
              c[ -31][ t]], 
            Times[ -0.10394325375429328, 
              c[ -30][ t]], 
            Times[ -0.069358014945125918, 
              c[ -29][ t]], 
            Times[ -0.034231213779558796, 
              c[ -28][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -27][ t]], 
            Times[ 0.032022748374426029, 
              c[ -26][ t]], 
            Times[ 0.060688263076985223, 
              c[ -25][ t]], 
            Times[ 0.085044480344421705, 
              c[ -24][ t]], 
            Times[ 0.10436044624225692, 
              c[ -23][ t]], 
            Times[ 0.1181419061618126, 
              c[ -22][ t]], 
            Times[ 0.12613778810677614, 
              c[ -21][ t]], 
            Times[ 0.12833762891430925, 
              c[ -20][ t]], 
            Times[ 0.12496032289024847, 
              c[ -19][ t]], 
            Times[ 0.11643488132933186, 
              c[ -18][ t]], 
            Times[ 0.10337416789158595, 
              c[ -17][ t]], 
            Times[ 0.086542809078944752, 
              c[ -16][ t]], 
            Times[ 0.066820663127759972, 
              c[ -15][ t]], 
            Times[ 0.045163358568919114, 
              c[ -14][ t]], 
            Times[ 0.022561481809254675, 
              c[ -13][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -12][ t]], 
            Times[ -0.021580547817548056, 
              c[ -11][ t]], 
            Times[ -0.041319668477947373, 
              c[ -10][ t]], 
            Times[ -0.058468080236789913, 
              c[ -9][ t]], 
            Times[ -0.072413370861974122, 
              c[ -8][ t]], 
            Times[ -0.082699334313268813, 
              c[ -7][ t]], 
            Times[ -0.089038438663606695, 
              c[ -6][ t]], 
            Times[ -0.091317159035181589, 
              c[ -5][ t]], 
            Times[ -0.089594193770366842, 
              c[ -4][ t]], 
            Times[ -0.084091858737850814, 
              c[ -3][ t]], 
            Times[ -0.075181213012062598, 
              c[ -2][ t]], 
            Times[ -0.063361699504227403, 
              c[ -1][ t]], 
            Times[ -0.049236278094138941, 
              c[ 0][ t]], 
            Times[ -0.033483179628681567, 
              c[ 1][ t]], 
            Times[ -0.016825511857749262, 
              c[ 2][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 3][ t]], 
            Times[ 0.016273855731265604, 
              c[ 4][ t]], 
            Times[ 0.031322974491347202, 
              c[ 5][ t]], 
            Times[ 0.044547108751839919, 
              c[ 6][ t]], 
            Times[ 0.055441487066198933, 
              c[ 7][ t]], 
            Times[ 0.063614872548668322, 
              c[ 8][ t]], 
            Times[ 0.068802429876423349, 
              c[ 9][ t]], 
            Times[ 0.070873018952678238, 
              c[ 10][ t]], 
            Times[ 0.069830768673962415, 
              c[ 11][ t]], 
            Times[ 0.065811019881796273, 
              c[ 12][ t]], 
            Times[ 0.059070953080906326, 
              c[ 13][ t]], 
            Times[ 0.049975424961080865, 
              c[ 14][ t]], 
            Times[ 0.03897872015785999, 
              c[ 15][ t]], 
            Times[ 0.026603074225527826, 
              c[ 16][ t]], 
            Times[ 0.013414935129827233, 
              c[ 17][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 18][ t]], 
            Times[ -0.013061910521147383, 
              c[ 19][ t]], 
            Times[ -0.025221096343682053, 
              c[ 20][ t]], 
            Times[ -0.035980357068793781, 
              c[ 21][ t]], 
            Times[ -0.044914622433376419, 
              c[ 22][ t]], 
            Times[ -0.05168708394579296, 
              c[ 23][ t]], 
            Times[ -0.056061239158567186, 
              c[ 24][ t]], 
            Times[ -0.057908442314993203, 
              c[ 25][ t]], 
            Times[ -0.057210750238908967, 
              c[ 26][ t]], 
            Times[ -0.054059052045761224, 
              c[ 27][ t]], 
            Times[ -0.048646667243099281, 
              c[ 28][ t]], 
            Times[ -0.041258781072520248, 
              c[ 29][ t]], 
            Times[ -0.032258251165125519, 
              c[ 30][ t]], 
            Times[ -0.022068459300722043, 
              c[ 31][ t]], 
            Times[ -0.011153991006822649, 
              c[ 32][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 33][ t]], 
            Times[ 0.010908848347331966, 
              c[ 34][ t]], 
            Times[ 0.021108961070255627, 
              c[ 35][ t]], 
            Times[ 0.030177073670601236, 
              c[ 36][ t]], 
            Times[ 0.03774739544932687, 
              c[ 37][ t]], 
            Times[ 0.043525965428036162, 
              c[ 38][ t]], 
            Times[ 0.047301670540041058, 
              c[ 39][ t]], 
            Times[ 0.04895352855494272, 
              c[ 40][ t]], 
            Times[ 0.048454002753361682, 
              c[ 41][ t]], 
            Times[ 0.045868286584282256, 
              c[ 42][ t]], 
            Times[ 0.041349667156634483, 
              c[ 43][ t]], 
            Times[ 0.035131239329076656, 
              c[ 44][ t]], 
            Times[ 0.027514390699665887, 
              c[ 45][ t]], 
            Times[ 0.018854606004500233, 
              c[ 46][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 47][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 48][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 49][ t]], 
            Times[ -0.018149760920219783, 
              c[ 50][ t]], 
            Times[ -0.025985813438573278, 
              c[ 51][ t]], 
            Times[ -0.032552799745291155, 
              c[ 52][ t]], 
            Times[ -0.037590606506031236, 
              c[ 53][ t]], 
            Times[ -0.040909552899494966, 
              c[ 54][ t]], 
            Times[ -0.042397252409191441, 
              c[ 55][ t]], 
            Times[ -0.042022055485216314, 
              c[ 56][ t]], 
            Times[ -0.039832985717929335, 
              c[ 57][ t]], 
            Times[ -0.035956232310116867, 
              c[ 58][ t]], 
            Times[ -0.030588406657213296, 
              c[ 59][ t]], 
            Times[ -0.023986904712529237, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-56\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-56\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.8870637930591835`\ \(c[\(-60\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-59\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-58\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-57\)]\)[t] + 
            69.78017644848049`\ \(c[\(-56\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-55\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-54\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-53\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-52\)]\)[t] + 
            0.8269933431326885`\ \(c[\(-51\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-50\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-49\)]\)[t] + 
            0.5935615337286809`\ \(c[\(-48\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-47\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-46\)]\)[t] + 
            0.3225686520215219`\ \(c[\(-45\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-44\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-43\)]\)[t] + 
            0.0709075142576581`\ \(c[\(-42\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-41\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-40\)]\)[t] - 
            0.11423673049785416`\ \(c[\(-39\)]\)[t] - 
            0.15591488063143966`\ \(c[\(-38\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-37\)]\)[t] - 
            0.2067483357831719`\ \(c[\(-36\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-35\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-34\)]\)[t] - 
            0.20645618564475848`\ \(c[\(-33\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-32\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-31\)]\)[t] - 
            0.13647135277833616`\ \(c[\(-30\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-29\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-28\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-27\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-26\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-25\)]\)[t] + 
            0.060688263076985`\ \(c[\(-24\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-23\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-22\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-21\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-20\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-19\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-18\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-17\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-16\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-15\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-14\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-13\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-12\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-11\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-10\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-9\)]\)[t] - 
            0.058468080236789774`\ \(c[\(-8\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-7\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-6\)]\)[t] - 
            0.08903843866360665`\ \(c[\(-5\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-4\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-3\)]\)[t] - 
            0.08409185873785086`\ \(c[\(-2\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-1\)]\)[t] - 
            0.06336169950422753`\ \(c[0]\)[t] - 
            0.049236278094139066`\ \(c[1]\)[t] - 
            0.03348317962868157`\ \(c[2]\)[t] - 
            0.0168255118577494`\ \(c[3]\)[t] - 
            1.8033970416801674`*^-16\ \(c[4]\)[t] + 
            0.016273855731265604`\ \(c[5]\)[t] + 
            0.03132297449134708`\ \(c[6]\)[t] + 
            0.044547108751839815`\ \(c[7]\)[t] + 
            0.05544148706619893`\ \(c[8]\)[t] + 
            0.06361487254866825`\ \(c[9]\)[t] + 
            0.06880242987642332`\ \(c[10]\)[t] + 
            0.07087301895267824`\ \(c[11]\)[t] + 
            0.06983076867396242`\ \(c[12]\)[t] + 
            0.06581101988179631`\ \(c[13]\)[t] + 
            0.0590709530809064`\ \(c[14]\)[t] + 
            0.049975424961080865`\ \(c[15]\)[t] + 
            0.03897872015786009`\ \(c[16]\)[t] + 
            0.026603074225527937`\ \(c[17]\)[t] + 
            0.013414935129827233`\ \(c[18]\)[t] + 
            1.5206810699945212`*^-16\ \(c[19]\)[t] - 
            0.013061910521147276`\ \(c[20]\)[t] - 
            0.025221096343682053`\ \(c[21]\)[t] - 
            0.03598035706879378`\ \(c[22]\)[t] - 
            0.04491462243337629`\ \(c[23]\)[t] - 
            0.05168708394579296`\ \(c[24]\)[t] - 
            0.05606123915856713`\ \(c[25]\)[t] - 
            0.0579084423149932`\ \(c[26]\)[t] - 
            0.05721075023890897`\ \(c[27]\)[t] - 
            0.054059052045761224`\ \(c[28]\)[t] - 
            0.0486466672430994`\ \(c[29]\)[t] - 
            0.04125878107252025`\ \(c[30]\)[t] - 
            0.03225825116512568`\ \(c[31]\)[t] - 
            0.022068459300722043`\ \(c[32]\)[t] - 
            0.011153991006822649`\ \(c[33]\)[t] - 
            3.8981718325193755`*^-17\ \(c[34]\)[t] + 
            0.010908848347331785`\ \(c[35]\)[t] + 
            0.021108961070255627`\ \(c[36]\)[t] + 
            0.030177073670601094`\ \(c[37]\)[t] + 
            0.03774739544932687`\ \(c[38]\)[t] + 
            0.04352596542803616`\ \(c[39]\)[t] + 
            0.04730167054004106`\ \(c[40]\)[t] + 
            0.0489535285549427`\ \(c[41]\)[t] + 
            0.04845400275336168`\ \(c[42]\)[t] + 
            0.04586828658428231`\ \(c[43]\)[t] + 
            0.04134966715663448`\ \(c[44]\)[t] + 
            0.035131239329076656`\ \(c[45]\)[t] + 
            0.027514390699665887`\ \(c[46]\)[t] + 
            0.01885460600450039`\ \(c[47]\)[t] + 
            0.009545242303915543`\ \(c[48]\)[t] + 
            2.0053370214556287`*^-16\ \(c[49]\)[t] - 
            0.009365143392520679`\ \(c[50]\)[t] - 
            0.018149760920219783`\ \(c[51]\)[t] - 
            0.02598581343857328`\ \(c[52]\)[t] - 
            0.03255279974529105`\ \(c[53]\)[t] - 
            0.037590606506031236`\ \(c[54]\)[t] - 
            0.040909552899494925`\ \(c[55]\)[t] - 
            0.04239725240919144`\ \(c[56]\)[t] - 
            0.042022055485216314`\ \(c[57]\)[t] - 
            0.039832985717929335`\ \(c[58]\)[t] - 
            0.035956232310116944`\ \(c[59]\)[t] - 
            0.030588406657213296`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -56, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -56]][ t]], 
          Plus[ 
            Times[ 0.88706379305918348, 
              c[ -60][ t]], 
            Times[ 0.93548928378863916, 
              c[ -59][ t]], 
            Times[ 0.9710122092317629, 
              c[ -58][ t]], 
            Times[ 0.99270519960720671, 
              c[ -57][ t]], 
            Times[ 69.780176448480489, 
              c[ -56][ t]], 
            Times[ 0.99270519960720693, 
              c[ -55][ t]], 
            Times[ 0.9710122092317629, 
              c[ -54][ t]], 
            Times[ 0.93548928378863916, 
              c[ -53][ t]], 
            Times[ 0.88706379305918392, 
              c[ -52][ t]], 
            Times[ 0.82699334313268846, 
              c[ -51][ t]], 
            Times[ 0.75682672864065692, 
              c[ -50][ t]], 
            Times[ 0.67835603854706361, 
              c[ -49][ t]], 
            Times[ 0.59356153372868092, 
              c[ -48][ t]], 
            Times[ 0.50455115242710469, 
              c[ -47][ t]], 
            Times[ 0.41349667156634429, 
              c[ -46][ t]], 
            Times[ 0.32256865202152191, 
              c[ -45][ t]], 
            Times[ 0.23387232094715985, 
              c[ -44][ t]], 
            Times[ 0.14938649372796384, 
              c[ -43][ t]], 
            Times[ 0.070907514257658094, 
              c[ -42][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -41][ t]], 
            Times[ -0.062044074975450239, 
              c[ -40][ t]], 
            Times[ -0.11423673049785416, 
              c[ -39][ t]], 
            Times[ -0.15591488063143966, 
              c[ -38][ t]], 
            Times[ -0.18675027222298593, 
              c[ -37][ t]], 
            Times[ -0.20674833578317189, 
              c[ -36][ t]], 
            Times[ -0.21623620818304481, 
              c[ -35][ t]], 
            Times[ -0.21584055771952015, 
              c[ -34][ t]], 
            Times[ -0.20645618564475848, 
              c[ -33][ t]], 
            Times[ -0.18920668216016434, 
              c[ -32][ t]], 
            Times[ -0.16539866862653771, 
              c[ -31][ t]], 
            Times[ -0.13647135277833616, 
              c[ -30][ t]], 
            Times[ -0.1039432537542934, 
              c[ -29][ t]], 
            Times[ -0.06935801494512607, 
              c[ -28][ t]], 
            Times[ -0.034231213779559094, 
              c[ -27][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -26][ t]], 
            Times[ 0.032022748374425904, 
              c[ -25][ t]], 
            Times[ 0.060688263076985001, 
              c[ -24][ t]], 
            Times[ 0.085044480344421608, 
              c[ -23][ t]], 
            Times[ 0.10436044624225685, 
              c[ -22][ t]], 
            Times[ 0.11814190616181253, 
              c[ -21][ t]], 
            Times[ 0.12613778810677612, 
              c[ -20][ t]], 
            Times[ 0.12833762891430928, 
              c[ -19][ t]], 
            Times[ 0.12496032289024853, 
              c[ -18][ t]], 
            Times[ 0.11643488132933186, 
              c[ -17][ t]], 
            Times[ 0.10337416789158609, 
              c[ -16][ t]], 
            Times[ 0.086542809078944891, 
              c[ -15][ t]], 
            Times[ 0.066820663127759972, 
              c[ -14][ t]], 
            Times[ 0.045163358568919301, 
              c[ -13][ t]], 
            Times[ 0.022561481809254869, 
              c[ -12][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -11][ t]], 
            Times[ -0.021580547817547879, 
              c[ -10][ t]], 
            Times[ -0.04131966847794722, 
              c[ -9][ t]], 
            Times[ -0.058468080236789774, 
              c[ -8][ t]], 
            Times[ -0.072413370861974122, 
              c[ -7][ t]], 
            Times[ -0.082699334313268744, 
              c[ -6][ t]], 
            Times[ -0.089038438663606653, 
              c[ -5][ t]], 
            Times[ -0.091317159035181589, 
              c[ -4][ t]], 
            Times[ -0.089594193770366884, 
              c[ -3][ t]], 
            Times[ -0.084091858737850855, 
              c[ -2][ t]], 
            Times[ -0.075181213012062598, 
              c[ -1][ t]], 
            Times[ -0.063361699504227528, 
              c[ 0][ t]], 
            Times[ -0.049236278094139066, 
              c[ 1][ t]], 
            Times[ -0.033483179628681567, 
              c[ 2][ t]], 
            Times[ -0.016825511857749401, 
              c[ 3][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 4][ t]], 
            Times[ 0.016273855731265604, 
              c[ 5][ t]], 
            Times[ 0.031322974491347078, 
              c[ 6][ t]], 
            Times[ 0.044547108751839815, 
              c[ 7][ t]], 
            Times[ 0.055441487066198933, 
              c[ 8][ t]], 
            Times[ 0.063614872548668253, 
              c[ 9][ t]], 
            Times[ 0.068802429876423321, 
              c[ 10][ t]], 
            Times[ 0.070873018952678238, 
              c[ 11][ t]], 
            Times[ 0.069830768673962415, 
              c[ 12][ t]], 
            Times[ 0.065811019881796315, 
              c[ 13][ t]], 
            Times[ 0.059070953080906402, 
              c[ 14][ t]], 
            Times[ 0.049975424961080865, 
              c[ 15][ t]], 
            Times[ 0.038978720157860088, 
              c[ 16][ t]], 
            Times[ 0.026603074225527937, 
              c[ 17][ t]], 
            Times[ 0.013414935129827233, 
              c[ 18][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ 19][ t]], 
            Times[ -0.013061910521147276, 
              c[ 20][ t]], 
            Times[ -0.025221096343682053, 
              c[ 21][ t]], 
            Times[ -0.035980357068793781, 
              c[ 22][ t]], 
            Times[ -0.044914622433376288, 
              c[ 23][ t]], 
            Times[ -0.05168708394579296, 
              c[ 24][ t]], 
            Times[ -0.05606123915856713, 
              c[ 25][ t]], 
            Times[ -0.057908442314993203, 
              c[ 26][ t]], 
            Times[ -0.057210750238908967, 
              c[ 27][ t]], 
            Times[ -0.054059052045761224, 
              c[ 28][ t]], 
            Times[ -0.048646667243099399, 
              c[ 29][ t]], 
            Times[ -0.041258781072520248, 
              c[ 30][ t]], 
            Times[ -0.032258251165125679, 
              c[ 31][ t]], 
            Times[ -0.022068459300722043, 
              c[ 32][ t]], 
            Times[ -0.011153991006822649, 
              c[ 33][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 34][ t]], 
            Times[ 0.010908848347331785, 
              c[ 35][ t]], 
            Times[ 0.021108961070255627, 
              c[ 36][ t]], 
            Times[ 0.030177073670601094, 
              c[ 37][ t]], 
            Times[ 0.03774739544932687, 
              c[ 38][ t]], 
            Times[ 0.043525965428036162, 
              c[ 39][ t]], 
            Times[ 0.047301670540041058, 
              c[ 40][ t]], 
            Times[ 0.048953528554942699, 
              c[ 41][ t]], 
            Times[ 0.048454002753361682, 
              c[ 42][ t]], 
            Times[ 0.045868286584282311, 
              c[ 43][ t]], 
            Times[ 0.041349667156634483, 
              c[ 44][ t]], 
            Times[ 0.035131239329076656, 
              c[ 45][ t]], 
            Times[ 0.027514390699665887, 
              c[ 46][ t]], 
            Times[ 0.018854606004500389, 
              c[ 47][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 48][ t]], 
            Times[ 2.0053370214556287*^-16, 
              c[ 49][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 50][ t]], 
            Times[ -0.018149760920219783, 
              c[ 51][ t]], 
            Times[ -0.025985813438573278, 
              c[ 52][ t]], 
            Times[ -0.032552799745291051, 
              c[ 53][ t]], 
            Times[ -0.037590606506031236, 
              c[ 54][ t]], 
            Times[ -0.040909552899494925, 
              c[ 55][ t]], 
            Times[ -0.042397252409191441, 
              c[ 56][ t]], 
            Times[ -0.042022055485216314, 
              c[ 57][ t]], 
            Times[ -0.039832985717929335, 
              c[ 58][ t]], 
            Times[ -0.035956232310116944, 
              c[ 59][ t]], 
            Times[ -0.030588406657213296, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-55\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-55\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.826993343132688`\ \(c[\(-60\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-59\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-58\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-57\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-56\)]\)[t] + 
            67.34567402954512`\ \(c[\(-55\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-54\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-53\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-52\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-51\)]\)[t] + 
            0.826993343132688`\ \(c[\(-50\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-49\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-48\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-47\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-46\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-45\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-44\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-43\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-42\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-41\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-40\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-39\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-38\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-37\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-36\)]\)[t] - 
            0.206748335783172`\ \(c[\(-35\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-34\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-33\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-32\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-31\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-30\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-29\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-28\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-27\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-26\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-25\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-24\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-23\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-22\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-21\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-20\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-19\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-18\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-17\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-16\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-15\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-14\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-13\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-12\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-11\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-10\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-9\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-8\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-7\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-6\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-5\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-4\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-3\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-2\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-1\)]\)[t] - 
            0.0751812130120626`\ \(c[0]\)[t] - 
            0.06336169950422753`\ \(c[1]\)[t] - 
            0.04923627809413894`\ \(c[2]\)[t] - 
            0.03348317962868157`\ \(c[3]\)[t] - 
            0.0168255118577494`\ \(c[4]\)[t] - 
            3.898171832519376`*^-17\ \(c[5]\)[t] + 
            0.016273855731265604`\ \(c[6]\)[t] + 
            0.03132297449134708`\ \(c[7]\)[t] + 
            0.04454710875183992`\ \(c[8]\)[t] + 
            0.05544148706619893`\ \(c[9]\)[t] + 
            0.06361487254866825`\ \(c[10]\)[t] + 
            0.06880242987642335`\ \(c[11]\)[t] + 
            0.07087301895267824`\ \(c[12]\)[t] + 
            0.06983076867396242`\ \(c[13]\)[t] + 
            0.06581101988179627`\ \(c[14]\)[t] + 
            0.059070953080906326`\ \(c[15]\)[t] + 
            0.049975424961080865`\ \(c[16]\)[t] + 
            0.03897872015785999`\ \(c[17]\)[t] + 
            0.026603074225527826`\ \(c[18]\)[t] + 
            0.013414935129827233`\ \(c[19]\)[t] + 
            3.898171832519376`*^-17\ \(c[20]\)[t] - 
            0.013061910521147383`\ \(c[21]\)[t] - 
            0.025221096343682053`\ \(c[22]\)[t] - 
            0.03598035706879378`\ \(c[23]\)[t] - 
            0.04491462243337642`\ \(c[24]\)[t] - 
            0.05168708394579296`\ \(c[25]\)[t] - 
            0.056061239158567186`\ \(c[26]\)[t] - 
            0.0579084423149932`\ \(c[27]\)[t] - 
            0.05721075023890897`\ \(c[28]\)[t] - 
            0.054059052045761224`\ \(c[29]\)[t] - 
            0.04864666724309928`\ \(c[30]\)[t] - 
            0.04125878107252025`\ \(c[31]\)[t] - 
            0.03225825116512552`\ \(c[32]\)[t] - 
            0.022068459300722043`\ \(c[33]\)[t] - 
            0.011153991006822649`\ \(c[34]\)[t] - 
            3.8981718325193755`*^-17\ \(c[35]\)[t] + 
            0.010908848347331966`\ \(c[36]\)[t] + 
            0.021108961070255627`\ \(c[37]\)[t] + 
            0.030177073670601236`\ \(c[38]\)[t] + 
            0.03774739544932687`\ \(c[39]\)[t] + 
            0.04352596542803616`\ \(c[40]\)[t] + 
            0.04730167054004106`\ \(c[41]\)[t] + 
            0.04895352855494272`\ \(c[42]\)[t] + 
            0.04845400275336168`\ \(c[43]\)[t] + 
            0.04586828658428231`\ \(c[44]\)[t] + 
            0.04134966715663448`\ \(c[45]\)[t] + 
            0.035131239329076656`\ \(c[46]\)[t] + 
            0.027514390699665887`\ \(c[47]\)[t] + 
            0.018854606004500233`\ \(c[48]\)[t] + 
            0.009545242303915543`\ \(c[49]\)[t] + 
            2.0053370214556287`*^-16\ \(c[50]\)[t] - 
            0.009365143392520679`\ \(c[51]\)[t] - 
            0.018149760920219783`\ \(c[52]\)[t] - 
            0.02598581343857328`\ \(c[53]\)[t] - 
            0.032552799745291155`\ \(c[54]\)[t] - 
            0.037590606506031236`\ \(c[55]\)[t] - 
            0.040909552899494925`\ \(c[56]\)[t] - 
            0.04239725240919144`\ \(c[57]\)[t] - 
            0.042022055485216314`\ \(c[58]\)[t] - 
            0.039832985717929335`\ \(c[59]\)[t] - 
            0.03595623231011687`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -55, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -55]][ t]], 
          Plus[ 
            Times[ 0.82699334313268802, 
              c[ -60][ t]], 
            Times[ 0.88706379305918392, 
              c[ -59][ t]], 
            Times[ 0.93548928378863916, 
              c[ -58][ t]], 
            Times[ 0.9710122092317629, 
              c[ -57][ t]], 
            Times[ 0.99270519960720693, 
              c[ -56][ t]], 
            Times[ 67.345674029545123, 
              c[ -55][ t]], 
            Times[ 0.99270519960720693, 
              c[ -54][ t]], 
            Times[ 0.9710122092317629, 
              c[ -53][ t]], 
            Times[ 0.93548928378863916, 
              c[ -52][ t]], 
            Times[ 0.88706379305918392, 
              c[ -51][ t]], 
            Times[ 0.82699334313268802, 
              c[ -50][ t]], 
            Times[ 0.75682672864065692, 
              c[ -49][ t]], 
            Times[ 0.67835603854706361, 
              c[ -48][ t]], 
            Times[ 0.59356153372868015, 
              c[ -47][ t]], 
            Times[ 0.50455115242710469, 
              c[ -46][ t]], 
            Times[ 0.41349667156634429, 
              c[ -45][ t]], 
            Times[ 0.32256865202152113, 
              c[ -44][ t]], 
            Times[ 0.23387232094715985, 
              c[ -43][ t]], 
            Times[ 0.14938649372796384, 
              c[ -42][ t]], 
            Times[ 0.070907514257657456, 
              c[ -41][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -40][ t]], 
            Times[ -0.062044074975450239, 
              c[ -39][ t]], 
            Times[ -0.11423673049785436, 
              c[ -38][ t]], 
            Times[ -0.15591488063143982, 
              c[ -37][ t]], 
            Times[ -0.18675027222298593, 
              c[ -36][ t]], 
            Times[ -0.206748335783172, 
              c[ -35][ t]], 
            Times[ -0.21623620818304484, 
              c[ -34][ t]], 
            Times[ -0.21584055771952015, 
              c[ -33][ t]], 
            Times[ -0.20645618564475843, 
              c[ -32][ t]], 
            Times[ -0.18920668216016426, 
              c[ -31][ t]], 
            Times[ -0.16539866862653771, 
              c[ -30][ t]], 
            Times[ -0.13647135277833605, 
              c[ -29][ t]], 
            Times[ -0.10394325375429328, 
              c[ -28][ t]], 
            Times[ -0.06935801494512607, 
              c[ -27][ t]], 
            Times[ -0.034231213779558949, 
              c[ -26][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -25][ t]], 
            Times[ 0.032022748374425904, 
              c[ -24][ t]], 
            Times[ 0.060688263076985105, 
              c[ -23][ t]], 
            Times[ 0.085044480344421705, 
              c[ -22][ t]], 
            Times[ 0.10436044624225685, 
              c[ -21][ t]], 
            Times[ 0.11814190616181255, 
              c[ -20][ t]], 
            Times[ 0.12613778810677614, 
              c[ -19][ t]], 
            Times[ 0.12833762891430928, 
              c[ -18][ t]], 
            Times[ 0.12496032289024853, 
              c[ -17][ t]], 
            Times[ 0.11643488132933186, 
              c[ -16][ t]], 
            Times[ 0.10337416789158609, 
              c[ -15][ t]], 
            Times[ 0.086542809078944891, 
              c[ -14][ t]], 
            Times[ 0.066820663127759972, 
              c[ -13][ t]], 
            Times[ 0.045163358568919301, 
              c[ -12][ t]], 
            Times[ 0.022561481809254869, 
              c[ -11][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -10][ t]], 
            Times[ -0.021580547817547879, 
              c[ -9][ t]], 
            Times[ -0.04131966847794722, 
              c[ -8][ t]], 
            Times[ -0.058468080236789913, 
              c[ -7][ t]], 
            Times[ -0.072413370861974122, 
              c[ -6][ t]], 
            Times[ -0.082699334313268744, 
              c[ -5][ t]], 
            Times[ -0.089038438663606695, 
              c[ -4][ t]], 
            Times[ -0.091317159035181589, 
              c[ -3][ t]], 
            Times[ -0.089594193770366884, 
              c[ -2][ t]], 
            Times[ -0.084091858737850814, 
              c[ -1][ t]], 
            Times[ -0.075181213012062598, 
              c[ 0][ t]], 
            Times[ -0.063361699504227528, 
              c[ 1][ t]], 
            Times[ -0.049236278094138941, 
              c[ 2][ t]], 
            Times[ -0.033483179628681567, 
              c[ 3][ t]], 
            Times[ -0.016825511857749401, 
              c[ 4][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 5][ t]], 
            Times[ 0.016273855731265604, 
              c[ 6][ t]], 
            Times[ 0.031322974491347078, 
              c[ 7][ t]], 
            Times[ 0.044547108751839919, 
              c[ 8][ t]], 
            Times[ 0.055441487066198933, 
              c[ 9][ t]], 
            Times[ 0.063614872548668253, 
              c[ 10][ t]], 
            Times[ 0.068802429876423349, 
              c[ 11][ t]], 
            Times[ 0.070873018952678238, 
              c[ 12][ t]], 
            Times[ 0.069830768673962415, 
              c[ 13][ t]], 
            Times[ 0.065811019881796273, 
              c[ 14][ t]], 
            Times[ 0.059070953080906326, 
              c[ 15][ t]], 
            Times[ 0.049975424961080865, 
              c[ 16][ t]], 
            Times[ 0.03897872015785999, 
              c[ 17][ t]], 
            Times[ 0.026603074225527826, 
              c[ 18][ t]], 
            Times[ 0.013414935129827233, 
              c[ 19][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 20][ t]], 
            Times[ -0.013061910521147383, 
              c[ 21][ t]], 
            Times[ -0.025221096343682053, 
              c[ 22][ t]], 
            Times[ -0.035980357068793781, 
              c[ 23][ t]], 
            Times[ -0.044914622433376419, 
              c[ 24][ t]], 
            Times[ -0.05168708394579296, 
              c[ 25][ t]], 
            Times[ -0.056061239158567186, 
              c[ 26][ t]], 
            Times[ -0.057908442314993203, 
              c[ 27][ t]], 
            Times[ -0.057210750238908967, 
              c[ 28][ t]], 
            Times[ -0.054059052045761224, 
              c[ 29][ t]], 
            Times[ -0.048646667243099281, 
              c[ 30][ t]], 
            Times[ -0.041258781072520248, 
              c[ 31][ t]], 
            Times[ -0.032258251165125519, 
              c[ 32][ t]], 
            Times[ -0.022068459300722043, 
              c[ 33][ t]], 
            Times[ -0.011153991006822649, 
              c[ 34][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 35][ t]], 
            Times[ 0.010908848347331966, 
              c[ 36][ t]], 
            Times[ 0.021108961070255627, 
              c[ 37][ t]], 
            Times[ 0.030177073670601236, 
              c[ 38][ t]], 
            Times[ 0.03774739544932687, 
              c[ 39][ t]], 
            Times[ 0.043525965428036162, 
              c[ 40][ t]], 
            Times[ 0.047301670540041058, 
              c[ 41][ t]], 
            Times[ 0.04895352855494272, 
              c[ 42][ t]], 
            Times[ 0.048454002753361682, 
              c[ 43][ t]], 
            Times[ 0.045868286584282311, 
              c[ 44][ t]], 
            Times[ 0.041349667156634483, 
              c[ 45][ t]], 
            Times[ 0.035131239329076656, 
              c[ 46][ t]], 
            Times[ 0.027514390699665887, 
              c[ 47][ t]], 
            Times[ 0.018854606004500233, 
              c[ 48][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 49][ t]], 
            Times[ 2.0053370214556287*^-16, 
              c[ 50][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 51][ t]], 
            Times[ -0.018149760920219783, 
              c[ 52][ t]], 
            Times[ -0.025985813438573278, 
              c[ 53][ t]], 
            Times[ -0.032552799745291155, 
              c[ 54][ t]], 
            Times[ -0.037590606506031236, 
              c[ 55][ t]], 
            Times[ -0.040909552899494925, 
              c[ 56][ t]], 
            Times[ -0.042397252409191441, 
              c[ 57][ t]], 
            Times[ -0.042022055485216314, 
              c[ 58][ t]], 
            Times[ -0.039832985717929335, 
              c[ 59][ t]], 
            Times[ -0.035956232310116867, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-54\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-54\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.7568267286406569`\ \(c[\(-60\)]\)[t] + 
            0.8269933431326885`\ \(c[\(-59\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-58\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-57\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-56\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-55\)]\)[t] + 
            64.95503651905904`\ \(c[\(-54\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-53\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-52\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-51\)]\)[t] + 
            0.8870637930591835`\ \(c[\(-50\)]\)[t] + 
            0.826993343132688`\ \(c[\(-49\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-48\)]\)[t] + 
            0.6783560385470627`\ \(c[\(-47\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-46\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-45\)]\)[t] + 
            0.4134966715663436`\ \(c[\(-44\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-43\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-42\)]\)[t] + 
            0.14938649372796314`\ \(c[\(-41\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-40\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-39\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-38\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-37\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-36\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-35\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-34\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-33\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-32\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-31\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-30\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-29\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-28\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-27\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-26\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-25\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-24\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-23\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-22\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-21\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-20\)]\)[t] + 
            0.1181419061618126`\ \(c[\(-19\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-18\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-17\)]\)[t] + 
            0.12496032289024847`\ \(c[\(-16\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-15\)]\)[t] + 
            0.10337416789158595`\ \(c[\(-14\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-13\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-12\)]\)[t] + 
            0.045163358568919114`\ \(c[\(-11\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-10\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-9\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-8\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-7\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-6\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-5\)]\)[t] - 
            0.08269933431326881`\ \(c[\(-4\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-3\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-2\)]\)[t] - 
            0.08959419377036684`\ \(c[\(-1\)]\)[t] - 
            0.08409185873785081`\ \(c[0]\)[t] - 
            0.0751812130120626`\ \(c[1]\)[t] - 
            0.0633616995042274`\ \(c[2]\)[t] - 
            0.04923627809413894`\ \(c[3]\)[t] - 
            0.03348317962868157`\ \(c[4]\)[t] - 
            0.016825511857749262`\ \(c[5]\)[t] - 
            3.898171832519376`*^-17\ \(c[6]\)[t] + 
            0.016273855731265604`\ \(c[7]\)[t] + 
            0.0313229744913472`\ \(c[8]\)[t] + 
            0.04454710875183992`\ \(c[9]\)[t] + 
            0.05544148706619893`\ \(c[10]\)[t] + 
            0.06361487254866825`\ \(c[11]\)[t] + 
            0.06880242987642335`\ \(c[12]\)[t] + 
            0.07087301895267824`\ \(c[13]\)[t] + 
            0.06983076867396242`\ \(c[14]\)[t] + 
            0.06581101988179627`\ \(c[15]\)[t] + 
            0.059070953080906326`\ \(c[16]\)[t] + 
            0.049975424961080865`\ \(c[17]\)[t] + 
            0.03897872015785999`\ \(c[18]\)[t] + 
            0.026603074225527826`\ \(c[19]\)[t] + 
            0.013414935129827233`\ \(c[20]\)[t] + 
            3.898171832519376`*^-17\ \(c[21]\)[t] - 
            0.013061910521147383`\ \(c[22]\)[t] - 
            0.025221096343682053`\ \(c[23]\)[t] - 
            0.03598035706879378`\ \(c[24]\)[t] - 
            0.04491462243337642`\ \(c[25]\)[t] - 
            0.05168708394579296`\ \(c[26]\)[t] - 
            0.056061239158567186`\ \(c[27]\)[t] - 
            0.0579084423149932`\ \(c[28]\)[t] - 
            0.05721075023890897`\ \(c[29]\)[t] - 
            0.054059052045761224`\ \(c[30]\)[t] - 
            0.04864666724309928`\ \(c[31]\)[t] - 
            0.04125878107252025`\ \(c[32]\)[t] - 
            0.03225825116512552`\ \(c[33]\)[t] - 
            0.022068459300722043`\ \(c[34]\)[t] - 
            0.011153991006822649`\ \(c[35]\)[t] - 
            3.8981718325193755`*^-17\ \(c[36]\)[t] + 
            0.010908848347331966`\ \(c[37]\)[t] + 
            0.021108961070255627`\ \(c[38]\)[t] + 
            0.030177073670601236`\ \(c[39]\)[t] + 
            0.03774739544932687`\ \(c[40]\)[t] + 
            0.04352596542803616`\ \(c[41]\)[t] + 
            0.04730167054004106`\ \(c[42]\)[t] + 
            0.04895352855494272`\ \(c[43]\)[t] + 
            0.04845400275336168`\ \(c[44]\)[t] + 
            0.045868286584282256`\ \(c[45]\)[t] + 
            0.04134966715663448`\ \(c[46]\)[t] + 
            0.035131239329076656`\ \(c[47]\)[t] + 
            0.027514390699665887`\ \(c[48]\)[t] + 
            0.018854606004500233`\ \(c[49]\)[t] + 
            0.009545242303915543`\ \(c[50]\)[t] + 
            3.8981718325193755`*^-17\ \(c[51]\)[t] - 
            0.009365143392520679`\ \(c[52]\)[t] - 
            0.018149760920219783`\ \(c[53]\)[t] - 
            0.02598581343857328`\ \(c[54]\)[t] - 
            0.032552799745291155`\ \(c[55]\)[t] - 
            0.037590606506031236`\ \(c[56]\)[t] - 
            0.040909552899494966`\ \(c[57]\)[t] - 
            0.04239725240919144`\ \(c[58]\)[t] - 
            0.042022055485216314`\ \(c[59]\)[t] - 
            0.039832985717929335`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -54, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -54]][ t]], 
          Plus[ 
            Times[ 0.75682672864065692, 
              c[ -60][ t]], 
            Times[ 0.82699334313268846, 
              c[ -59][ t]], 
            Times[ 0.88706379305918392, 
              c[ -58][ t]], 
            Times[ 0.93548928378863916, 
              c[ -57][ t]], 
            Times[ 0.9710122092317629, 
              c[ -56][ t]], 
            Times[ 0.99270519960720693, 
              c[ -55][ t]], 
            Times[ 64.955036519059036, 
              c[ -54][ t]], 
            Times[ 0.99270519960720671, 
              c[ -53][ t]], 
            Times[ 0.9710122092317629, 
              c[ -52][ t]], 
            Times[ 0.93548928378863916, 
              c[ -51][ t]], 
            Times[ 0.88706379305918348, 
              c[ -50][ t]], 
            Times[ 0.82699334313268802, 
              c[ -49][ t]], 
            Times[ 0.75682672864065692, 
              c[ -48][ t]], 
            Times[ 0.67835603854706272, 
              c[ -47][ t]], 
            Times[ 0.59356153372868015, 
              c[ -46][ t]], 
            Times[ 0.50455115242710469, 
              c[ -45][ t]], 
            Times[ 0.41349667156634362, 
              c[ -44][ t]], 
            Times[ 0.32256865202152113, 
              c[ -43][ t]], 
            Times[ 0.23387232094715985, 
              c[ -42][ t]], 
            Times[ 0.14938649372796314, 
              c[ -41][ t]], 
            Times[ 0.070907514257657456, 
              c[ -40][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -39][ t]], 
            Times[ -0.062044074975450475, 
              c[ -38][ t]], 
            Times[ -0.11423673049785459, 
              c[ -37][ t]], 
            Times[ -0.15591488063143982, 
              c[ -36][ t]], 
            Times[ -0.18675027222298607, 
              c[ -35][ t]], 
            Times[ -0.20674833578317206, 
              c[ -34][ t]], 
            Times[ -0.21623620818304484, 
              c[ -33][ t]], 
            Times[ -0.21584055771952013, 
              c[ -32][ t]], 
            Times[ -0.20645618564475834, 
              c[ -31][ t]], 
            Times[ -0.18920668216016426, 
              c[ -30][ t]], 
            Times[ -0.1653986686265376, 
              c[ -29][ t]], 
            Times[ -0.13647135277833591, 
              c[ -28][ t]], 
            Times[ -0.10394325375429328, 
              c[ -27][ t]], 
            Times[ -0.069358014945125918, 
              c[ -26][ t]], 
            Times[ -0.034231213779558796, 
              c[ -25][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -24][ t]], 
            Times[ 0.032022748374426029, 
              c[ -23][ t]], 
            Times[ 0.060688263076985223, 
              c[ -22][ t]], 
            Times[ 0.085044480344421705, 
              c[ -21][ t]], 
            Times[ 0.10436044624225692, 
              c[ -20][ t]], 
            Times[ 0.1181419061618126, 
              c[ -19][ t]], 
            Times[ 0.12613778810677614, 
              c[ -18][ t]], 
            Times[ 0.12833762891430925, 
              c[ -17][ t]], 
            Times[ 0.12496032289024847, 
              c[ -16][ t]], 
            Times[ 0.11643488132933186, 
              c[ -15][ t]], 
            Times[ 0.10337416789158595, 
              c[ -14][ t]], 
            Times[ 0.086542809078944752, 
              c[ -13][ t]], 
            Times[ 0.066820663127759972, 
              c[ -12][ t]], 
            Times[ 0.045163358568919114, 
              c[ -11][ t]], 
            Times[ 0.022561481809254675, 
              c[ -10][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -9][ t]], 
            Times[ -0.021580547817547879, 
              c[ -8][ t]], 
            Times[ -0.041319668477947373, 
              c[ -7][ t]], 
            Times[ -0.058468080236789913, 
              c[ -6][ t]], 
            Times[ -0.072413370861974122, 
              c[ -5][ t]], 
            Times[ -0.082699334313268813, 
              c[ -4][ t]], 
            Times[ -0.089038438663606695, 
              c[ -3][ t]], 
            Times[ -0.091317159035181589, 
              c[ -2][ t]], 
            Times[ -0.089594193770366842, 
              c[ -1][ t]], 
            Times[ -0.084091858737850814, 
              c[ 0][ t]], 
            Times[ -0.075181213012062598, 
              c[ 1][ t]], 
            Times[ -0.063361699504227403, 
              c[ 2][ t]], 
            Times[ -0.049236278094138941, 
              c[ 3][ t]], 
            Times[ -0.033483179628681567, 
              c[ 4][ t]], 
            Times[ -0.016825511857749262, 
              c[ 5][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 6][ t]], 
            Times[ 0.016273855731265604, 
              c[ 7][ t]], 
            Times[ 0.031322974491347202, 
              c[ 8][ t]], 
            Times[ 0.044547108751839919, 
              c[ 9][ t]], 
            Times[ 0.055441487066198933, 
              c[ 10][ t]], 
            Times[ 0.063614872548668253, 
              c[ 11][ t]], 
            Times[ 0.068802429876423349, 
              c[ 12][ t]], 
            Times[ 0.070873018952678238, 
              c[ 13][ t]], 
            Times[ 0.069830768673962415, 
              c[ 14][ t]], 
            Times[ 0.065811019881796273, 
              c[ 15][ t]], 
            Times[ 0.059070953080906326, 
              c[ 16][ t]], 
            Times[ 0.049975424961080865, 
              c[ 17][ t]], 
            Times[ 0.03897872015785999, 
              c[ 18][ t]], 
            Times[ 0.026603074225527826, 
              c[ 19][ t]], 
            Times[ 0.013414935129827233, 
              c[ 20][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 21][ t]], 
            Times[ -0.013061910521147383, 
              c[ 22][ t]], 
            Times[ -0.025221096343682053, 
              c[ 23][ t]], 
            Times[ -0.035980357068793781, 
              c[ 24][ t]], 
            Times[ -0.044914622433376419, 
              c[ 25][ t]], 
            Times[ -0.05168708394579296, 
              c[ 26][ t]], 
            Times[ -0.056061239158567186, 
              c[ 27][ t]], 
            Times[ -0.057908442314993203, 
              c[ 28][ t]], 
            Times[ -0.057210750238908967, 
              c[ 29][ t]], 
            Times[ -0.054059052045761224, 
              c[ 30][ t]], 
            Times[ -0.048646667243099281, 
              c[ 31][ t]], 
            Times[ -0.041258781072520248, 
              c[ 32][ t]], 
            Times[ -0.032258251165125519, 
              c[ 33][ t]], 
            Times[ -0.022068459300722043, 
              c[ 34][ t]], 
            Times[ -0.011153991006822649, 
              c[ 35][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 36][ t]], 
            Times[ 0.010908848347331966, 
              c[ 37][ t]], 
            Times[ 0.021108961070255627, 
              c[ 38][ t]], 
            Times[ 0.030177073670601236, 
              c[ 39][ t]], 
            Times[ 0.03774739544932687, 
              c[ 40][ t]], 
            Times[ 0.043525965428036162, 
              c[ 41][ t]], 
            Times[ 0.047301670540041058, 
              c[ 42][ t]], 
            Times[ 0.04895352855494272, 
              c[ 43][ t]], 
            Times[ 0.048454002753361682, 
              c[ 44][ t]], 
            Times[ 0.045868286584282256, 
              c[ 45][ t]], 
            Times[ 0.041349667156634483, 
              c[ 46][ t]], 
            Times[ 0.035131239329076656, 
              c[ 47][ t]], 
            Times[ 0.027514390699665887, 
              c[ 48][ t]], 
            Times[ 0.018854606004500233, 
              c[ 49][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 50][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 51][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 52][ t]], 
            Times[ -0.018149760920219783, 
              c[ 53][ t]], 
            Times[ -0.025985813438573278, 
              c[ 54][ t]], 
            Times[ -0.032552799745291155, 
              c[ 55][ t]], 
            Times[ -0.037590606506031236, 
              c[ 56][ t]], 
            Times[ -0.040909552899494966, 
              c[ 57][ t]], 
            Times[ -0.042397252409191441, 
              c[ 58][ t]], 
            Times[ -0.042022055485216314, 
              c[ 59][ t]], 
            Times[ -0.039832985717929335, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-53\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-53\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.6783560385470627`\ \(c[\(-60\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-59\)]\)[t] + 
            0.826993343132688`\ \(c[\(-58\)]\)[t] + 
            0.8870637930591835`\ \(c[\(-57\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-56\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-55\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-54\)]\)[t] + 
            62.60826391702222`\ \(c[\(-53\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-52\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-51\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-50\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-49\)]\)[t] + 
            0.8269933431326885`\ \(c[\(-48\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-47\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-46\)]\)[t] + 
            0.5935615337286809`\ \(c[\(-45\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-44\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-43\)]\)[t] + 
            0.3225686520215219`\ \(c[\(-42\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-41\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-40\)]\)[t] + 
            0.0709075142576581`\ \(c[\(-39\)]\)[t] + 
            3.216976900108398`*^-16\ \(c[\(-38\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-37\)]\)[t] - 
            0.11423673049785416`\ \(c[\(-36\)]\)[t] - 
            0.15591488063143966`\ \(c[\(-35\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-34\)]\)[t] - 
            0.2067483357831719`\ \(c[\(-33\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-32\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-31\)]\)[t] - 
            0.20645618564475848`\ \(c[\(-30\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-29\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-28\)]\)[t] - 
            0.13647135277833616`\ \(c[\(-27\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-26\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-25\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-24\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-23\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-22\)]\)[t] + 
            0.060688263076985`\ \(c[\(-21\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-20\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-19\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-18\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-17\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-16\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-15\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-14\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-13\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-12\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-11\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-10\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-9\)]\)[t] + 
            2.274590327822911`*^-16\ \(c[\(-8\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-7\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-6\)]\)[t] - 
            0.058468080236789774`\ \(c[\(-5\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-4\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-3\)]\)[t] - 
            0.08903843866360665`\ \(c[\(-2\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-1\)]\)[t] - 
            0.08959419377036688`\ \(c[0]\)[t] - 
            0.08409185873785086`\ \(c[1]\)[t] - 
            0.0751812130120626`\ \(c[2]\)[t] - 
            0.06336169950422753`\ \(c[3]\)[t] - 
            0.049236278094139066`\ \(c[4]\)[t] - 
            0.03348317962868157`\ \(c[5]\)[t] - 
            0.0168255118577494`\ \(c[6]\)[t] - 
            1.8033970416801674`*^-16\ \(c[7]\)[t] + 
            0.016273855731265604`\ \(c[8]\)[t] + 
            0.03132297449134708`\ \(c[9]\)[t] + 
            0.044547108751839815`\ \(c[10]\)[t] + 
            0.055441487066198857`\ \(c[11]\)[t] + 
            0.06361487254866825`\ \(c[12]\)[t] + 
            0.06880242987642332`\ \(c[13]\)[t] + 
            0.07087301895267824`\ \(c[14]\)[t] + 
            0.06983076867396242`\ \(c[15]\)[t] + 
            0.06581101988179631`\ \(c[16]\)[t] + 
            0.0590709530809064`\ \(c[17]\)[t] + 
            0.049975424961080865`\ \(c[18]\)[t] + 
            0.03897872015786009`\ \(c[19]\)[t] + 
            0.026603074225527937`\ \(c[20]\)[t] + 
            0.013414935129827233`\ \(c[21]\)[t] + 
            1.5206810699945212`*^-16\ \(c[22]\)[t] - 
            0.013061910521147276`\ \(c[23]\)[t] - 
            0.025221096343682053`\ \(c[24]\)[t] - 
            0.03598035706879378`\ \(c[25]\)[t] - 
            0.04491462243337629`\ \(c[26]\)[t] - 
            0.05168708394579296`\ \(c[27]\)[t] - 
            0.05606123915856713`\ \(c[28]\)[t] - 
            0.0579084423149932`\ \(c[29]\)[t] - 
            0.05721075023890897`\ \(c[30]\)[t] - 
            0.054059052045761224`\ \(c[31]\)[t] - 
            0.0486466672430994`\ \(c[32]\)[t] - 
            0.04125878107252025`\ \(c[33]\)[t] - 
            0.03225825116512568`\ \(c[34]\)[t] - 
            0.022068459300722043`\ \(c[35]\)[t] - 
            0.011153991006822649`\ \(c[36]\)[t] - 
            3.8981718325193755`*^-17\ \(c[37]\)[t] + 
            0.010908848347331785`\ \(c[38]\)[t] + 
            0.021108961070255627`\ \(c[39]\)[t] + 
            0.030177073670601094`\ \(c[40]\)[t] + 
            0.03774739544932687`\ \(c[41]\)[t] + 
            0.04352596542803616`\ \(c[42]\)[t] + 
            0.04730167054004106`\ \(c[43]\)[t] + 
            0.0489535285549427`\ \(c[44]\)[t] + 
            0.04845400275336168`\ \(c[45]\)[t] + 
            0.04586828658428231`\ \(c[46]\)[t] + 
            0.04134966715663448`\ \(c[47]\)[t] + 
            0.035131239329076656`\ \(c[48]\)[t] + 
            0.027514390699665887`\ \(c[49]\)[t] + 
            0.01885460600450039`\ \(c[50]\)[t] + 
            0.009545242303915543`\ \(c[51]\)[t] + 
            2.0053370214556287`*^-16\ \(c[52]\)[t] - 
            0.009365143392520679`\ \(c[53]\)[t] - 
            0.018149760920219783`\ \(c[54]\)[t] - 
            0.02598581343857328`\ \(c[55]\)[t] - 
            0.03255279974529105`\ \(c[56]\)[t] - 
            0.037590606506031236`\ \(c[57]\)[t] - 
            0.040909552899494925`\ \(c[58]\)[t] - 
            0.04239725240919144`\ \(c[59]\)[t] - 
            0.042022055485216314`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -53, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -53]][ t]], 
          Plus[ 
            Times[ 0.67835603854706272, 
              c[ -60][ t]], 
            Times[ 0.75682672864065692, 
              c[ -59][ t]], 
            Times[ 0.82699334313268802, 
              c[ -58][ t]], 
            Times[ 0.88706379305918348, 
              c[ -57][ t]], 
            Times[ 0.93548928378863916, 
              c[ -56][ t]], 
            Times[ 0.9710122092317629, 
              c[ -55][ t]], 
            Times[ 0.99270519960720671, 
              c[ -54][ t]], 
            Times[ 62.608263917022221, 
              c[ -53][ t]], 
            Times[ 0.99270519960720693, 
              c[ -52][ t]], 
            Times[ 0.9710122092317629, 
              c[ -51][ t]], 
            Times[ 0.93548928378863916, 
              c[ -50][ t]], 
            Times[ 0.88706379305918392, 
              c[ -49][ t]], 
            Times[ 0.82699334313268846, 
              c[ -48][ t]], 
            Times[ 0.75682672864065692, 
              c[ -47][ t]], 
            Times[ 0.67835603854706361, 
              c[ -46][ t]], 
            Times[ 0.59356153372868092, 
              c[ -45][ t]], 
            Times[ 0.50455115242710469, 
              c[ -44][ t]], 
            Times[ 0.41349667156634429, 
              c[ -43][ t]], 
            Times[ 0.32256865202152191, 
              c[ -42][ t]], 
            Times[ 0.23387232094715985, 
              c[ -41][ t]], 
            Times[ 0.14938649372796384, 
              c[ -40][ t]], 
            Times[ 0.070907514257658094, 
              c[ -39][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ -38][ t]], 
            Times[ -0.062044074975450239, 
              c[ -37][ t]], 
            Times[ -0.11423673049785416, 
              c[ -36][ t]], 
            Times[ -0.15591488063143966, 
              c[ -35][ t]], 
            Times[ -0.18675027222298593, 
              c[ -34][ t]], 
            Times[ -0.20674833578317189, 
              c[ -33][ t]], 
            Times[ -0.21623620818304481, 
              c[ -32][ t]], 
            Times[ -0.21584055771952015, 
              c[ -31][ t]], 
            Times[ -0.20645618564475848, 
              c[ -30][ t]], 
            Times[ -0.18920668216016434, 
              c[ -29][ t]], 
            Times[ -0.16539866862653771, 
              c[ -28][ t]], 
            Times[ -0.13647135277833616, 
              c[ -27][ t]], 
            Times[ -0.1039432537542934, 
              c[ -26][ t]], 
            Times[ -0.06935801494512607, 
              c[ -25][ t]], 
            Times[ -0.034231213779559094, 
              c[ -24][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -23][ t]], 
            Times[ 0.032022748374425904, 
              c[ -22][ t]], 
            Times[ 0.060688263076985001, 
              c[ -21][ t]], 
            Times[ 0.085044480344421608, 
              c[ -20][ t]], 
            Times[ 0.10436044624225685, 
              c[ -19][ t]], 
            Times[ 0.11814190616181253, 
              c[ -18][ t]], 
            Times[ 0.12613778810677612, 
              c[ -17][ t]], 
            Times[ 0.12833762891430928, 
              c[ -16][ t]], 
            Times[ 0.12496032289024853, 
              c[ -15][ t]], 
            Times[ 0.11643488132933186, 
              c[ -14][ t]], 
            Times[ 0.10337416789158609, 
              c[ -13][ t]], 
            Times[ 0.086542809078944891, 
              c[ -12][ t]], 
            Times[ 0.066820663127759972, 
              c[ -11][ t]], 
            Times[ 0.045163358568919301, 
              c[ -10][ t]], 
            Times[ 0.022561481809254869, 
              c[ -9][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ -8][ t]], 
            Times[ -0.021580547817547879, 
              c[ -7][ t]], 
            Times[ -0.04131966847794722, 
              c[ -6][ t]], 
            Times[ -0.058468080236789774, 
              c[ -5][ t]], 
            Times[ -0.072413370861974122, 
              c[ -4][ t]], 
            Times[ -0.082699334313268744, 
              c[ -3][ t]], 
            Times[ -0.089038438663606653, 
              c[ -2][ t]], 
            Times[ -0.091317159035181589, 
              c[ -1][ t]], 
            Times[ -0.089594193770366884, 
              c[ 0][ t]], 
            Times[ -0.084091858737850855, 
              c[ 1][ t]], 
            Times[ -0.075181213012062598, 
              c[ 2][ t]], 
            Times[ -0.063361699504227528, 
              c[ 3][ t]], 
            Times[ -0.049236278094139066, 
              c[ 4][ t]], 
            Times[ -0.033483179628681567, 
              c[ 5][ t]], 
            Times[ -0.016825511857749401, 
              c[ 6][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 7][ t]], 
            Times[ 0.016273855731265604, 
              c[ 8][ t]], 
            Times[ 0.031322974491347078, 
              c[ 9][ t]], 
            Times[ 0.044547108751839815, 
              c[ 10][ t]], 
            Times[ 0.055441487066198857, 
              c[ 11][ t]], 
            Times[ 0.063614872548668253, 
              c[ 12][ t]], 
            Times[ 0.068802429876423321, 
              c[ 13][ t]], 
            Times[ 0.070873018952678238, 
              c[ 14][ t]], 
            Times[ 0.069830768673962415, 
              c[ 15][ t]], 
            Times[ 0.065811019881796315, 
              c[ 16][ t]], 
            Times[ 0.059070953080906402, 
              c[ 17][ t]], 
            Times[ 0.049975424961080865, 
              c[ 18][ t]], 
            Times[ 0.038978720157860088, 
              c[ 19][ t]], 
            Times[ 0.026603074225527937, 
              c[ 20][ t]], 
            Times[ 0.013414935129827233, 
              c[ 21][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ 22][ t]], 
            Times[ -0.013061910521147276, 
              c[ 23][ t]], 
            Times[ -0.025221096343682053, 
              c[ 24][ t]], 
            Times[ -0.035980357068793781, 
              c[ 25][ t]], 
            Times[ -0.044914622433376288, 
              c[ 26][ t]], 
            Times[ -0.05168708394579296, 
              c[ 27][ t]], 
            Times[ -0.05606123915856713, 
              c[ 28][ t]], 
            Times[ -0.057908442314993203, 
              c[ 29][ t]], 
            Times[ -0.057210750238908967, 
              c[ 30][ t]], 
            Times[ -0.054059052045761224, 
              c[ 31][ t]], 
            Times[ -0.048646667243099399, 
              c[ 32][ t]], 
            Times[ -0.041258781072520248, 
              c[ 33][ t]], 
            Times[ -0.032258251165125679, 
              c[ 34][ t]], 
            Times[ -0.022068459300722043, 
              c[ 35][ t]], 
            Times[ -0.011153991006822649, 
              c[ 36][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 37][ t]], 
            Times[ 0.010908848347331785, 
              c[ 38][ t]], 
            Times[ 0.021108961070255627, 
              c[ 39][ t]], 
            Times[ 0.030177073670601094, 
              c[ 40][ t]], 
            Times[ 0.03774739544932687, 
              c[ 41][ t]], 
            Times[ 0.043525965428036162, 
              c[ 42][ t]], 
            Times[ 0.047301670540041058, 
              c[ 43][ t]], 
            Times[ 0.048953528554942699, 
              c[ 44][ t]], 
            Times[ 0.048454002753361682, 
              c[ 45][ t]], 
            Times[ 0.045868286584282311, 
              c[ 46][ t]], 
            Times[ 0.041349667156634483, 
              c[ 47][ t]], 
            Times[ 0.035131239329076656, 
              c[ 48][ t]], 
            Times[ 0.027514390699665887, 
              c[ 49][ t]], 
            Times[ 0.018854606004500389, 
              c[ 50][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 51][ t]], 
            Times[ 2.0053370214556287*^-16, 
              c[ 52][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 53][ t]], 
            Times[ -0.018149760920219783, 
              c[ 54][ t]], 
            Times[ -0.025985813438573278, 
              c[ 55][ t]], 
            Times[ -0.032552799745291051, 
              c[ 56][ t]], 
            Times[ -0.037590606506031236, 
              c[ 57][ t]], 
            Times[ -0.040909552899494925, 
              c[ 58][ t]], 
            Times[ -0.042397252409191441, 
              c[ 59][ t]], 
            Times[ -0.042022055485216314, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-52\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-52\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.5935615337286801`\ \(c[\(-60\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-59\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-58\)]\)[t] + 
            0.826993343132688`\ \(c[\(-57\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-56\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-55\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-54\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-53\)]\)[t] + 
            60.305356223434714`\ \(c[\(-52\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-51\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-50\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-49\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-48\)]\)[t] + 
            0.826993343132688`\ \(c[\(-47\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-46\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-45\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-44\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-43\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-42\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-41\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-40\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-39\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-38\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-37\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-36\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-35\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-34\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-33\)]\)[t] - 
            0.206748335783172`\ \(c[\(-32\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-31\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-30\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-29\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-28\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-27\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-26\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-25\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-24\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-23\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-22\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-21\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-20\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-19\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-18\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-17\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-16\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-15\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-14\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-13\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-12\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-11\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-10\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-9\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-8\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-7\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-6\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-5\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-4\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-3\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-2\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-1\)]\)[t] - 
            0.09131715903518159`\ \(c[0]\)[t] - 
            0.08959419377036688`\ \(c[1]\)[t] - 
            0.08409185873785081`\ \(c[2]\)[t] - 
            0.0751812130120626`\ \(c[3]\)[t] - 
            0.06336169950422753`\ \(c[4]\)[t] - 
            0.04923627809413894`\ \(c[5]\)[t] - 
            0.03348317962868157`\ \(c[6]\)[t] - 
            0.0168255118577494`\ \(c[7]\)[t] - 
            3.898171832519376`*^-17\ \(c[8]\)[t] + 
            0.016273855731265604`\ \(c[9]\)[t] + 
            0.03132297449134708`\ \(c[10]\)[t] + 
            0.04454710875183992`\ \(c[11]\)[t] + 
            0.05544148706619893`\ \(c[12]\)[t] + 
            0.06361487254866825`\ \(c[13]\)[t] + 
            0.06880242987642335`\ \(c[14]\)[t] + 
            0.07087301895267824`\ \(c[15]\)[t] + 
            0.06983076867396242`\ \(c[16]\)[t] + 
            0.06581101988179627`\ \(c[17]\)[t] + 
            0.059070953080906326`\ \(c[18]\)[t] + 
            0.049975424961080865`\ \(c[19]\)[t] + 
            0.03897872015785999`\ \(c[20]\)[t] + 
            0.026603074225527826`\ \(c[21]\)[t] + 
            0.013414935129827233`\ \(c[22]\)[t] + 
            3.898171832519376`*^-17\ \(c[23]\)[t] - 
            0.013061910521147383`\ \(c[24]\)[t] - 
            0.025221096343682053`\ \(c[25]\)[t] - 
            0.03598035706879378`\ \(c[26]\)[t] - 
            0.04491462243337642`\ \(c[27]\)[t] - 
            0.05168708394579296`\ \(c[28]\)[t] - 
            0.056061239158567186`\ \(c[29]\)[t] - 
            0.0579084423149932`\ \(c[30]\)[t] - 
            0.05721075023890897`\ \(c[31]\)[t] - 
            0.054059052045761224`\ \(c[32]\)[t] - 
            0.04864666724309928`\ \(c[33]\)[t] - 
            0.04125878107252025`\ \(c[34]\)[t] - 
            0.03225825116512552`\ \(c[35]\)[t] - 
            0.022068459300722043`\ \(c[36]\)[t] - 
            0.011153991006822649`\ \(c[37]\)[t] - 
            3.8981718325193755`*^-17\ \(c[38]\)[t] + 
            0.010908848347331966`\ \(c[39]\)[t] + 
            0.021108961070255627`\ \(c[40]\)[t] + 
            0.030177073670601094`\ \(c[41]\)[t] + 
            0.03774739544932687`\ \(c[42]\)[t] + 
            0.04352596542803616`\ \(c[43]\)[t] + 
            0.04730167054004106`\ \(c[44]\)[t] + 
            0.04895352855494272`\ \(c[45]\)[t] + 
            0.04845400275336168`\ \(c[46]\)[t] + 
            0.04586828658428231`\ \(c[47]\)[t] + 
            0.04134966715663448`\ \(c[48]\)[t] + 
            0.035131239329076656`\ \(c[49]\)[t] + 
            0.027514390699665887`\ \(c[50]\)[t] + 
            0.018854606004500233`\ \(c[51]\)[t] + 
            0.009545242303915543`\ \(c[52]\)[t] + 
            2.0053370214556287`*^-16\ \(c[53]\)[t] - 
            0.009365143392520679`\ \(c[54]\)[t] - 
            0.018149760920219783`\ \(c[55]\)[t] - 
            0.02598581343857328`\ \(c[56]\)[t] - 
            0.032552799745291155`\ \(c[57]\)[t] - 
            0.037590606506031236`\ \(c[58]\)[t] - 
            0.040909552899494925`\ \(c[59]\)[t] - 
            0.04239725240919144`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -52, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -52]][ t]], 
          Plus[ 
            Times[ 0.59356153372868015, 
              c[ -60][ t]], 
            Times[ 0.67835603854706361, 
              c[ -59][ t]], 
            Times[ 0.75682672864065692, 
              c[ -58][ t]], 
            Times[ 0.82699334313268802, 
              c[ -57][ t]], 
            Times[ 0.88706379305918392, 
              c[ -56][ t]], 
            Times[ 0.93548928378863916, 
              c[ -55][ t]], 
            Times[ 0.9710122092317629, 
              c[ -54][ t]], 
            Times[ 0.99270519960720693, 
              c[ -53][ t]], 
            Times[ 60.305356223434714, 
              c[ -52][ t]], 
            Times[ 0.99270519960720693, 
              c[ -51][ t]], 
            Times[ 0.9710122092317629, 
              c[ -50][ t]], 
            Times[ 0.93548928378863916, 
              c[ -49][ t]], 
            Times[ 0.88706379305918392, 
              c[ -48][ t]], 
            Times[ 0.82699334313268802, 
              c[ -47][ t]], 
            Times[ 0.75682672864065692, 
              c[ -46][ t]], 
            Times[ 0.67835603854706361, 
              c[ -45][ t]], 
            Times[ 0.59356153372868015, 
              c[ -44][ t]], 
            Times[ 0.50455115242710469, 
              c[ -43][ t]], 
            Times[ 0.41349667156634429, 
              c[ -42][ t]], 
            Times[ 0.32256865202152113, 
              c[ -41][ t]], 
            Times[ 0.23387232094715985, 
              c[ -40][ t]], 
            Times[ 0.14938649372796384, 
              c[ -39][ t]], 
            Times[ 0.070907514257657775, 
              c[ -38][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -37][ t]], 
            Times[ -0.062044074975450239, 
              c[ -36][ t]], 
            Times[ -0.11423673049785436, 
              c[ -35][ t]], 
            Times[ -0.15591488063143982, 
              c[ -34][ t]], 
            Times[ -0.18675027222298593, 
              c[ -33][ t]], 
            Times[ -0.206748335783172, 
              c[ -32][ t]], 
            Times[ -0.21623620818304484, 
              c[ -31][ t]], 
            Times[ -0.21584055771952015, 
              c[ -30][ t]], 
            Times[ -0.20645618564475843, 
              c[ -29][ t]], 
            Times[ -0.18920668216016426, 
              c[ -28][ t]], 
            Times[ -0.16539866862653771, 
              c[ -27][ t]], 
            Times[ -0.13647135277833605, 
              c[ -26][ t]], 
            Times[ -0.10394325375429328, 
              c[ -25][ t]], 
            Times[ -0.06935801494512607, 
              c[ -24][ t]], 
            Times[ -0.034231213779558949, 
              c[ -23][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -22][ t]], 
            Times[ 0.032022748374425904, 
              c[ -21][ t]], 
            Times[ 0.060688263076985105, 
              c[ -20][ t]], 
            Times[ 0.085044480344421705, 
              c[ -19][ t]], 
            Times[ 0.10436044624225685, 
              c[ -18][ t]], 
            Times[ 0.11814190616181255, 
              c[ -17][ t]], 
            Times[ 0.12613778810677614, 
              c[ -16][ t]], 
            Times[ 0.12833762891430928, 
              c[ -15][ t]], 
            Times[ 0.12496032289024853, 
              c[ -14][ t]], 
            Times[ 0.11643488132933186, 
              c[ -13][ t]], 
            Times[ 0.10337416789158609, 
              c[ -12][ t]], 
            Times[ 0.086542809078944891, 
              c[ -11][ t]], 
            Times[ 0.066820663127759972, 
              c[ -10][ t]], 
            Times[ 0.045163358568919301, 
              c[ -9][ t]], 
            Times[ 0.022561481809254869, 
              c[ -8][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -7][ t]], 
            Times[ -0.021580547817547879, 
              c[ -6][ t]], 
            Times[ -0.04131966847794722, 
              c[ -5][ t]], 
            Times[ -0.058468080236789913, 
              c[ -4][ t]], 
            Times[ -0.072413370861974122, 
              c[ -3][ t]], 
            Times[ -0.082699334313268744, 
              c[ -2][ t]], 
            Times[ -0.089038438663606695, 
              c[ -1][ t]], 
            Times[ -0.091317159035181589, 
              c[ 0][ t]], 
            Times[ -0.089594193770366884, 
              c[ 1][ t]], 
            Times[ -0.084091858737850814, 
              c[ 2][ t]], 
            Times[ -0.075181213012062598, 
              c[ 3][ t]], 
            Times[ -0.063361699504227528, 
              c[ 4][ t]], 
            Times[ -0.049236278094138941, 
              c[ 5][ t]], 
            Times[ -0.033483179628681567, 
              c[ 6][ t]], 
            Times[ -0.016825511857749401, 
              c[ 7][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 8][ t]], 
            Times[ 0.016273855731265604, 
              c[ 9][ t]], 
            Times[ 0.031322974491347078, 
              c[ 10][ t]], 
            Times[ 0.044547108751839919, 
              c[ 11][ t]], 
            Times[ 0.055441487066198933, 
              c[ 12][ t]], 
            Times[ 0.063614872548668253, 
              c[ 13][ t]], 
            Times[ 0.068802429876423349, 
              c[ 14][ t]], 
            Times[ 0.070873018952678238, 
              c[ 15][ t]], 
            Times[ 0.069830768673962415, 
              c[ 16][ t]], 
            Times[ 0.065811019881796273, 
              c[ 17][ t]], 
            Times[ 0.059070953080906326, 
              c[ 18][ t]], 
            Times[ 0.049975424961080865, 
              c[ 19][ t]], 
            Times[ 0.03897872015785999, 
              c[ 20][ t]], 
            Times[ 0.026603074225527826, 
              c[ 21][ t]], 
            Times[ 0.013414935129827233, 
              c[ 22][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 23][ t]], 
            Times[ -0.013061910521147383, 
              c[ 24][ t]], 
            Times[ -0.025221096343682053, 
              c[ 25][ t]], 
            Times[ -0.035980357068793781, 
              c[ 26][ t]], 
            Times[ -0.044914622433376419, 
              c[ 27][ t]], 
            Times[ -0.05168708394579296, 
              c[ 28][ t]], 
            Times[ -0.056061239158567186, 
              c[ 29][ t]], 
            Times[ -0.057908442314993203, 
              c[ 30][ t]], 
            Times[ -0.057210750238908967, 
              c[ 31][ t]], 
            Times[ -0.054059052045761224, 
              c[ 32][ t]], 
            Times[ -0.048646667243099281, 
              c[ 33][ t]], 
            Times[ -0.041258781072520248, 
              c[ 34][ t]], 
            Times[ -0.032258251165125519, 
              c[ 35][ t]], 
            Times[ -0.022068459300722043, 
              c[ 36][ t]], 
            Times[ -0.011153991006822649, 
              c[ 37][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 38][ t]], 
            Times[ 0.010908848347331966, 
              c[ 39][ t]], 
            Times[ 0.021108961070255627, 
              c[ 40][ t]], 
            Times[ 0.030177073670601094, 
              c[ 41][ t]], 
            Times[ 0.03774739544932687, 
              c[ 42][ t]], 
            Times[ 0.043525965428036162, 
              c[ 43][ t]], 
            Times[ 0.047301670540041058, 
              c[ 44][ t]], 
            Times[ 0.04895352855494272, 
              c[ 45][ t]], 
            Times[ 0.048454002753361682, 
              c[ 46][ t]], 
            Times[ 0.045868286584282311, 
              c[ 47][ t]], 
            Times[ 0.041349667156634483, 
              c[ 48][ t]], 
            Times[ 0.035131239329076656, 
              c[ 49][ t]], 
            Times[ 0.027514390699665887, 
              c[ 50][ t]], 
            Times[ 0.018854606004500233, 
              c[ 51][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 52][ t]], 
            Times[ 2.0053370214556287*^-16, 
              c[ 53][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 54][ t]], 
            Times[ -0.018149760920219783, 
              c[ 55][ t]], 
            Times[ -0.025985813438573278, 
              c[ 56][ t]], 
            Times[ -0.032552799745291155, 
              c[ 57][ t]], 
            Times[ -0.037590606506031236, 
              c[ 58][ t]], 
            Times[ -0.040909552899494925, 
              c[ 59][ t]], 
            Times[ -0.042397252409191441, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-51\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-51\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.5045511524271047`\ \(c[\(-60\)]\)[t] + 
            0.5935615337286809`\ \(c[\(-59\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-58\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-57\)]\)[t] + 
            0.8269933431326885`\ \(c[\(-56\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-55\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-54\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-53\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-52\)]\)[t] + 
            58.04631343829649`\ \(c[\(-51\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-50\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-49\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-48\)]\)[t] + 
            0.8870637930591835`\ \(c[\(-47\)]\)[t] + 
            0.826993343132688`\ \(c[\(-46\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-45\)]\)[t] + 
            0.6783560385470627`\ \(c[\(-44\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-43\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-42\)]\)[t] + 
            0.4134966715663436`\ \(c[\(-41\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-40\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-39\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-38\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-37\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-36\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-35\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-34\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-33\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-32\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-31\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-30\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-29\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-28\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-27\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-26\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-25\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-24\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-23\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-22\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-21\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-20\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-19\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-18\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-17\)]\)[t] + 
            0.1181419061618126`\ \(c[\(-16\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-15\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-14\)]\)[t] + 
            0.12496032289024847`\ \(c[\(-13\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-12\)]\)[t] + 
            0.10337416789158595`\ \(c[\(-11\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-10\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-9\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-8\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-7\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-6\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-5\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-4\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-3\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-2\)]\)[t] - 
            0.08269933431326881`\ \(c[\(-1\)]\)[t] - 
            0.0890384386636067`\ \(c[0]\)[t] - 
            0.09131715903518159`\ \(c[1]\)[t] - 
            0.08959419377036684`\ \(c[2]\)[t] - 
            0.08409185873785081`\ \(c[3]\)[t] - 
            0.0751812130120626`\ \(c[4]\)[t] - 
            0.0633616995042274`\ \(c[5]\)[t] - 
            0.04923627809413894`\ \(c[6]\)[t] - 
            0.03348317962868157`\ \(c[7]\)[t] - 
            0.016825511857749262`\ \(c[8]\)[t] - 
            3.898171832519376`*^-17\ \(c[9]\)[t] + 
            0.016273855731265604`\ \(c[10]\)[t] + 
            0.03132297449134708`\ \(c[11]\)[t] + 
            0.04454710875183992`\ \(c[12]\)[t] + 
            0.05544148706619893`\ \(c[13]\)[t] + 
            0.06361487254866825`\ \(c[14]\)[t] + 
            0.06880242987642335`\ \(c[15]\)[t] + 
            0.07087301895267824`\ \(c[16]\)[t] + 
            0.06983076867396242`\ \(c[17]\)[t] + 
            0.06581101988179627`\ \(c[18]\)[t] + 
            0.059070953080906326`\ \(c[19]\)[t] + 
            0.049975424961080865`\ \(c[20]\)[t] + 
            0.03897872015785999`\ \(c[21]\)[t] + 
            0.026603074225527826`\ \(c[22]\)[t] + 
            0.013414935129827233`\ \(c[23]\)[t] + 
            3.898171832519376`*^-17\ \(c[24]\)[t] - 
            0.013061910521147383`\ \(c[25]\)[t] - 
            0.025221096343682053`\ \(c[26]\)[t] - 
            0.03598035706879378`\ \(c[27]\)[t] - 
            0.04491462243337642`\ \(c[28]\)[t] - 
            0.05168708394579296`\ \(c[29]\)[t] - 
            0.056061239158567186`\ \(c[30]\)[t] - 
            0.0579084423149932`\ \(c[31]\)[t] - 
            0.05721075023890897`\ \(c[32]\)[t] - 
            0.054059052045761224`\ \(c[33]\)[t] - 
            0.04864666724309928`\ \(c[34]\)[t] - 
            0.04125878107252025`\ \(c[35]\)[t] - 
            0.03225825116512552`\ \(c[36]\)[t] - 
            0.022068459300722043`\ \(c[37]\)[t] - 
            0.011153991006822649`\ \(c[38]\)[t] - 
            3.8981718325193755`*^-17\ \(c[39]\)[t] + 
            0.010908848347331966`\ \(c[40]\)[t] + 
            0.021108961070255627`\ \(c[41]\)[t] + 
            0.030177073670601236`\ \(c[42]\)[t] + 
            0.03774739544932687`\ \(c[43]\)[t] + 
            0.04352596542803616`\ \(c[44]\)[t] + 
            0.04730167054004106`\ \(c[45]\)[t] + 
            0.04895352855494272`\ \(c[46]\)[t] + 
            0.04845400275336168`\ \(c[47]\)[t] + 
            0.045868286584282256`\ \(c[48]\)[t] + 
            0.04134966715663448`\ \(c[49]\)[t] + 
            0.035131239329076656`\ \(c[50]\)[t] + 
            0.027514390699665887`\ \(c[51]\)[t] + 
            0.018854606004500233`\ \(c[52]\)[t] + 
            0.009545242303915543`\ \(c[53]\)[t] + 
            3.8981718325193755`*^-17\ \(c[54]\)[t] - 
            0.009365143392520679`\ \(c[55]\)[t] - 
            0.018149760920219783`\ \(c[56]\)[t] - 
            0.02598581343857328`\ \(c[57]\)[t] - 
            0.032552799745291155`\ \(c[58]\)[t] - 
            0.037590606506031236`\ \(c[59]\)[t] - 
            0.040909552899494966`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -51, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -51]][ t]], 
          Plus[ 
            Times[ 0.50455115242710469, 
              c[ -60][ t]], 
            Times[ 0.59356153372868092, 
              c[ -59][ t]], 
            Times[ 0.67835603854706361, 
              c[ -58][ t]], 
            Times[ 0.75682672864065692, 
              c[ -57][ t]], 
            Times[ 0.82699334313268846, 
              c[ -56][ t]], 
            Times[ 0.88706379305918392, 
              c[ -55][ t]], 
            Times[ 0.93548928378863916, 
              c[ -54][ t]], 
            Times[ 0.9710122092317629, 
              c[ -53][ t]], 
            Times[ 0.99270519960720693, 
              c[ -52][ t]], 
            Times[ 58.046313438296487, 
              c[ -51][ t]], 
            Times[ 0.99270519960720671, 
              c[ -50][ t]], 
            Times[ 0.9710122092317629, 
              c[ -49][ t]], 
            Times[ 0.93548928378863916, 
              c[ -48][ t]], 
            Times[ 0.88706379305918348, 
              c[ -47][ t]], 
            Times[ 0.82699334313268802, 
              c[ -46][ t]], 
            Times[ 0.75682672864065692, 
              c[ -45][ t]], 
            Times[ 0.67835603854706272, 
              c[ -44][ t]], 
            Times[ 0.59356153372868015, 
              c[ -43][ t]], 
            Times[ 0.50455115242710469, 
              c[ -42][ t]], 
            Times[ 0.41349667156634362, 
              c[ -41][ t]], 
            Times[ 0.32256865202152113, 
              c[ -40][ t]], 
            Times[ 0.23387232094715985, 
              c[ -39][ t]], 
            Times[ 0.14938649372796345, 
              c[ -38][ t]], 
            Times[ 0.070907514257657456, 
              c[ -37][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -36][ t]], 
            Times[ -0.062044074975450475, 
              c[ -35][ t]], 
            Times[ -0.11423673049785459, 
              c[ -34][ t]], 
            Times[ -0.15591488063143982, 
              c[ -33][ t]], 
            Times[ -0.18675027222298607, 
              c[ -32][ t]], 
            Times[ -0.20674833578317206, 
              c[ -31][ t]], 
            Times[ -0.21623620818304484, 
              c[ -30][ t]], 
            Times[ -0.21584055771952013, 
              c[ -29][ t]], 
            Times[ -0.20645618564475834, 
              c[ -28][ t]], 
            Times[ -0.18920668216016426, 
              c[ -27][ t]], 
            Times[ -0.1653986686265376, 
              c[ -26][ t]], 
            Times[ -0.13647135277833591, 
              c[ -25][ t]], 
            Times[ -0.10394325375429328, 
              c[ -24][ t]], 
            Times[ -0.069358014945125918, 
              c[ -23][ t]], 
            Times[ -0.034231213779558796, 
              c[ -22][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -21][ t]], 
            Times[ 0.032022748374426029, 
              c[ -20][ t]], 
            Times[ 0.060688263076985223, 
              c[ -19][ t]], 
            Times[ 0.085044480344421705, 
              c[ -18][ t]], 
            Times[ 0.10436044624225692, 
              c[ -17][ t]], 
            Times[ 0.1181419061618126, 
              c[ -16][ t]], 
            Times[ 0.12613778810677614, 
              c[ -15][ t]], 
            Times[ 0.12833762891430925, 
              c[ -14][ t]], 
            Times[ 0.12496032289024847, 
              c[ -13][ t]], 
            Times[ 0.11643488132933186, 
              c[ -12][ t]], 
            Times[ 0.10337416789158595, 
              c[ -11][ t]], 
            Times[ 0.086542809078944752, 
              c[ -10][ t]], 
            Times[ 0.066820663127759972, 
              c[ -9][ t]], 
            Times[ 0.045163358568919301, 
              c[ -8][ t]], 
            Times[ 0.022561481809254675, 
              c[ -7][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -6][ t]], 
            Times[ -0.021580547817547879, 
              c[ -5][ t]], 
            Times[ -0.041319668477947373, 
              c[ -4][ t]], 
            Times[ -0.058468080236789913, 
              c[ -3][ t]], 
            Times[ -0.072413370861974122, 
              c[ -2][ t]], 
            Times[ -0.082699334313268813, 
              c[ -1][ t]], 
            Times[ -0.089038438663606695, 
              c[ 0][ t]], 
            Times[ -0.091317159035181589, 
              c[ 1][ t]], 
            Times[ -0.089594193770366842, 
              c[ 2][ t]], 
            Times[ -0.084091858737850814, 
              c[ 3][ t]], 
            Times[ -0.075181213012062598, 
              c[ 4][ t]], 
            Times[ -0.063361699504227403, 
              c[ 5][ t]], 
            Times[ -0.049236278094138941, 
              c[ 6][ t]], 
            Times[ -0.033483179628681567, 
              c[ 7][ t]], 
            Times[ -0.016825511857749262, 
              c[ 8][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 9][ t]], 
            Times[ 0.016273855731265604, 
              c[ 10][ t]], 
            Times[ 0.031322974491347078, 
              c[ 11][ t]], 
            Times[ 0.044547108751839919, 
              c[ 12][ t]], 
            Times[ 0.055441487066198933, 
              c[ 13][ t]], 
            Times[ 0.063614872548668253, 
              c[ 14][ t]], 
            Times[ 0.068802429876423349, 
              c[ 15][ t]], 
            Times[ 0.070873018952678238, 
              c[ 16][ t]], 
            Times[ 0.069830768673962415, 
              c[ 17][ t]], 
            Times[ 0.065811019881796273, 
              c[ 18][ t]], 
            Times[ 0.059070953080906326, 
              c[ 19][ t]], 
            Times[ 0.049975424961080865, 
              c[ 20][ t]], 
            Times[ 0.03897872015785999, 
              c[ 21][ t]], 
            Times[ 0.026603074225527826, 
              c[ 22][ t]], 
            Times[ 0.013414935129827233, 
              c[ 23][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 24][ t]], 
            Times[ -0.013061910521147383, 
              c[ 25][ t]], 
            Times[ -0.025221096343682053, 
              c[ 26][ t]], 
            Times[ -0.035980357068793781, 
              c[ 27][ t]], 
            Times[ -0.044914622433376419, 
              c[ 28][ t]], 
            Times[ -0.05168708394579296, 
              c[ 29][ t]], 
            Times[ -0.056061239158567186, 
              c[ 30][ t]], 
            Times[ -0.057908442314993203, 
              c[ 31][ t]], 
            Times[ -0.057210750238908967, 
              c[ 32][ t]], 
            Times[ -0.054059052045761224, 
              c[ 33][ t]], 
            Times[ -0.048646667243099281, 
              c[ 34][ t]], 
            Times[ -0.041258781072520248, 
              c[ 35][ t]], 
            Times[ -0.032258251165125519, 
              c[ 36][ t]], 
            Times[ -0.022068459300722043, 
              c[ 37][ t]], 
            Times[ -0.011153991006822649, 
              c[ 38][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 39][ t]], 
            Times[ 0.010908848347331966, 
              c[ 40][ t]], 
            Times[ 0.021108961070255627, 
              c[ 41][ t]], 
            Times[ 0.030177073670601236, 
              c[ 42][ t]], 
            Times[ 0.03774739544932687, 
              c[ 43][ t]], 
            Times[ 0.043525965428036162, 
              c[ 44][ t]], 
            Times[ 0.047301670540041058, 
              c[ 45][ t]], 
            Times[ 0.04895352855494272, 
              c[ 46][ t]], 
            Times[ 0.048454002753361682, 
              c[ 47][ t]], 
            Times[ 0.045868286584282256, 
              c[ 48][ t]], 
            Times[ 0.041349667156634483, 
              c[ 49][ t]], 
            Times[ 0.035131239329076656, 
              c[ 50][ t]], 
            Times[ 0.027514390699665887, 
              c[ 51][ t]], 
            Times[ 0.018854606004500233, 
              c[ 52][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 53][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 54][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 55][ t]], 
            Times[ -0.018149760920219783, 
              c[ 56][ t]], 
            Times[ -0.025985813438573278, 
              c[ 57][ t]], 
            Times[ -0.032552799745291155, 
              c[ 58][ t]], 
            Times[ -0.037590606506031236, 
              c[ 59][ t]], 
            Times[ -0.040909552899494966, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-50\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-50\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.4134966715663436`\ \(c[\(-60\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-59\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-58\)]\)[t] + 
            0.6783560385470627`\ \(c[\(-57\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-56\)]\)[t] + 
            0.826993343132688`\ \(c[\(-55\)]\)[t] + 
            0.8870637930591835`\ \(c[\(-54\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-53\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-52\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-51\)]\)[t] + 
            55.83113556160753`\ \(c[\(-50\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-49\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-48\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-47\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-46\)]\)[t] + 
            0.8269933431326885`\ \(c[\(-45\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-44\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-43\)]\)[t] + 
            0.5935615337286809`\ \(c[\(-42\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-41\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-40\)]\)[t] + 
            0.3225686520215219`\ \(c[\(-39\)]\)[t] + 
            0.23387232094716018`\ \(c[\(-38\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-37\)]\)[t] + 
            0.0709075142576581`\ \(c[\(-36\)]\)[t] + 
            3.216976900108398`*^-16\ \(c[\(-35\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-34\)]\)[t] - 
            0.11423673049785416`\ \(c[\(-33\)]\)[t] - 
            0.15591488063143966`\ \(c[\(-32\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-31\)]\)[t] - 
            0.2067483357831719`\ \(c[\(-30\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-29\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-28\)]\)[t] - 
            0.20645618564475848`\ \(c[\(-27\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-26\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-25\)]\)[t] - 
            0.13647135277833616`\ \(c[\(-24\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-23\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-22\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-21\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-20\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-19\)]\)[t] + 
            0.060688263076985`\ \(c[\(-18\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-17\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-16\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-15\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-14\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-13\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-12\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-11\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-10\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-9\)]\)[t] + 
            0.06682066312776015`\ \(c[\(-8\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-7\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-6\)]\)[t] + 
            2.274590327822911`*^-16\ \(c[\(-5\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-4\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-3\)]\)[t] - 
            0.058468080236789774`\ \(c[\(-2\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-1\)]\)[t] - 
            0.08269933431326874`\ \(c[0]\)[t] - 
            0.08903843866360665`\ \(c[1]\)[t] - 
            0.09131715903518159`\ \(c[2]\)[t] - 
            0.08959419377036688`\ \(c[3]\)[t] - 
            0.08409185873785086`\ \(c[4]\)[t] - 
            0.0751812130120626`\ \(c[5]\)[t] - 
            0.06336169950422753`\ \(c[6]\)[t] - 
            0.049236278094139066`\ \(c[7]\)[t] - 
            0.03348317962868157`\ \(c[8]\)[t] - 
            0.0168255118577494`\ \(c[9]\)[t] - 
            1.8033970416801674`*^-16\ \(c[10]\)[t] + 
            0.01627385573126547`\ \(c[11]\)[t] + 
            0.03132297449134708`\ \(c[12]\)[t] + 
            0.044547108751839815`\ \(c[13]\)[t] + 
            0.055441487066198857`\ \(c[14]\)[t] + 
            0.06361487254866825`\ \(c[15]\)[t] + 
            0.06880242987642332`\ \(c[16]\)[t] + 
            0.07087301895267824`\ \(c[17]\)[t] + 
            0.06983076867396242`\ \(c[18]\)[t] + 
            0.06581101988179631`\ \(c[19]\)[t] + 
            0.0590709530809064`\ \(c[20]\)[t] + 
            0.049975424961080865`\ \(c[21]\)[t] + 
            0.03897872015786009`\ \(c[22]\)[t] + 
            0.026603074225527937`\ \(c[23]\)[t] + 
            0.013414935129827233`\ \(c[24]\)[t] + 
            1.5206810699945212`*^-16\ \(c[25]\)[t] - 
            0.013061910521147276`\ \(c[26]\)[t] - 
            0.025221096343682053`\ \(c[27]\)[t] - 
            0.03598035706879378`\ \(c[28]\)[t] - 
            0.04491462243337629`\ \(c[29]\)[t] - 
            0.05168708394579296`\ \(c[30]\)[t] - 
            0.05606123915856713`\ \(c[31]\)[t] - 
            0.0579084423149932`\ \(c[32]\)[t] - 
            0.05721075023890897`\ \(c[33]\)[t] - 
            0.054059052045761224`\ \(c[34]\)[t] - 
            0.0486466672430994`\ \(c[35]\)[t] - 
            0.04125878107252025`\ \(c[36]\)[t] - 
            0.03225825116512568`\ \(c[37]\)[t] - 
            0.022068459300722043`\ \(c[38]\)[t] - 
            0.011153991006822649`\ \(c[39]\)[t] - 
            3.8981718325193755`*^-17\ \(c[40]\)[t] + 
            0.010908848347331785`\ \(c[41]\)[t] + 
            0.021108961070255627`\ \(c[42]\)[t] + 
            0.030177073670601094`\ \(c[43]\)[t] + 
            0.03774739544932687`\ \(c[44]\)[t] + 
            0.04352596542803616`\ \(c[45]\)[t] + 
            0.04730167054004106`\ \(c[46]\)[t] + 
            0.0489535285549427`\ \(c[47]\)[t] + 
            0.04845400275336168`\ \(c[48]\)[t] + 
            0.04586828658428231`\ \(c[49]\)[t] + 
            0.04134966715663448`\ \(c[50]\)[t] + 
            0.035131239329076656`\ \(c[51]\)[t] + 
            0.027514390699665887`\ \(c[52]\)[t] + 
            0.01885460600450039`\ \(c[53]\)[t] + 
            0.009545242303915543`\ \(c[54]\)[t] + 
            2.0053370214556287`*^-16\ \(c[55]\)[t] - 
            0.009365143392520679`\ \(c[56]\)[t] - 
            0.018149760920219783`\ \(c[57]\)[t] - 
            0.02598581343857328`\ \(c[58]\)[t] - 
            0.03255279974529105`\ \(c[59]\)[t] - 
            0.037590606506031236`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -50, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -50]][ t]], 
          Plus[ 
            Times[ 0.41349667156634362, 
              c[ -60][ t]], 
            Times[ 0.50455115242710469, 
              c[ -59][ t]], 
            Times[ 0.59356153372868015, 
              c[ -58][ t]], 
            Times[ 0.67835603854706272, 
              c[ -57][ t]], 
            Times[ 0.75682672864065692, 
              c[ -56][ t]], 
            Times[ 0.82699334313268802, 
              c[ -55][ t]], 
            Times[ 0.88706379305918348, 
              c[ -54][ t]], 
            Times[ 0.93548928378863916, 
              c[ -53][ t]], 
            Times[ 0.9710122092317629, 
              c[ -52][ t]], 
            Times[ 0.99270519960720671, 
              c[ -51][ t]], 
            Times[ 55.831135561607532, 
              c[ -50][ t]], 
            Times[ 0.99270519960720693, 
              c[ -49][ t]], 
            Times[ 0.9710122092317629, 
              c[ -48][ t]], 
            Times[ 0.93548928378863916, 
              c[ -47][ t]], 
            Times[ 0.88706379305918392, 
              c[ -46][ t]], 
            Times[ 0.82699334313268846, 
              c[ -45][ t]], 
            Times[ 0.75682672864065692, 
              c[ -44][ t]], 
            Times[ 0.67835603854706361, 
              c[ -43][ t]], 
            Times[ 0.59356153372868092, 
              c[ -42][ t]], 
            Times[ 0.50455115242710469, 
              c[ -41][ t]], 
            Times[ 0.41349667156634429, 
              c[ -40][ t]], 
            Times[ 0.32256865202152191, 
              c[ -39][ t]], 
            Times[ 0.23387232094716018, 
              c[ -38][ t]], 
            Times[ 0.14938649372796384, 
              c[ -37][ t]], 
            Times[ 0.070907514257658094, 
              c[ -36][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ -35][ t]], 
            Times[ -0.062044074975450239, 
              c[ -34][ t]], 
            Times[ -0.11423673049785416, 
              c[ -33][ t]], 
            Times[ -0.15591488063143966, 
              c[ -32][ t]], 
            Times[ -0.18675027222298593, 
              c[ -31][ t]], 
            Times[ -0.20674833578317189, 
              c[ -30][ t]], 
            Times[ -0.21623620818304481, 
              c[ -29][ t]], 
            Times[ -0.21584055771952015, 
              c[ -28][ t]], 
            Times[ -0.20645618564475848, 
              c[ -27][ t]], 
            Times[ -0.18920668216016434, 
              c[ -26][ t]], 
            Times[ -0.16539866862653771, 
              c[ -25][ t]], 
            Times[ -0.13647135277833616, 
              c[ -24][ t]], 
            Times[ -0.1039432537542934, 
              c[ -23][ t]], 
            Times[ -0.06935801494512607, 
              c[ -22][ t]], 
            Times[ -0.034231213779559094, 
              c[ -21][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -20][ t]], 
            Times[ 0.032022748374425904, 
              c[ -19][ t]], 
            Times[ 0.060688263076985001, 
              c[ -18][ t]], 
            Times[ 0.085044480344421608, 
              c[ -17][ t]], 
            Times[ 0.10436044624225685, 
              c[ -16][ t]], 
            Times[ 0.11814190616181253, 
              c[ -15][ t]], 
            Times[ 0.12613778810677612, 
              c[ -14][ t]], 
            Times[ 0.12833762891430928, 
              c[ -13][ t]], 
            Times[ 0.12496032289024853, 
              c[ -12][ t]], 
            Times[ 0.11643488132933186, 
              c[ -11][ t]], 
            Times[ 0.10337416789158609, 
              c[ -10][ t]], 
            Times[ 0.086542809078944891, 
              c[ -9][ t]], 
            Times[ 0.066820663127760152, 
              c[ -8][ t]], 
            Times[ 0.045163358568919301, 
              c[ -7][ t]], 
            Times[ 0.022561481809254869, 
              c[ -6][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ -5][ t]], 
            Times[ -0.021580547817547879, 
              c[ -4][ t]], 
            Times[ -0.04131966847794722, 
              c[ -3][ t]], 
            Times[ -0.058468080236789774, 
              c[ -2][ t]], 
            Times[ -0.072413370861974122, 
              c[ -1][ t]], 
            Times[ -0.082699334313268744, 
              c[ 0][ t]], 
            Times[ -0.089038438663606653, 
              c[ 1][ t]], 
            Times[ -0.091317159035181589, 
              c[ 2][ t]], 
            Times[ -0.089594193770366884, 
              c[ 3][ t]], 
            Times[ -0.084091858737850855, 
              c[ 4][ t]], 
            Times[ -0.075181213012062598, 
              c[ 5][ t]], 
            Times[ -0.063361699504227528, 
              c[ 6][ t]], 
            Times[ -0.049236278094139066, 
              c[ 7][ t]], 
            Times[ -0.033483179628681567, 
              c[ 8][ t]], 
            Times[ -0.016825511857749401, 
              c[ 9][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 10][ t]], 
            Times[ 0.016273855731265469, 
              c[ 11][ t]], 
            Times[ 0.031322974491347078, 
              c[ 12][ t]], 
            Times[ 0.044547108751839815, 
              c[ 13][ t]], 
            Times[ 0.055441487066198857, 
              c[ 14][ t]], 
            Times[ 0.063614872548668253, 
              c[ 15][ t]], 
            Times[ 0.068802429876423321, 
              c[ 16][ t]], 
            Times[ 0.070873018952678238, 
              c[ 17][ t]], 
            Times[ 0.069830768673962415, 
              c[ 18][ t]], 
            Times[ 0.065811019881796315, 
              c[ 19][ t]], 
            Times[ 0.059070953080906402, 
              c[ 20][ t]], 
            Times[ 0.049975424961080865, 
              c[ 21][ t]], 
            Times[ 0.038978720157860088, 
              c[ 22][ t]], 
            Times[ 0.026603074225527937, 
              c[ 23][ t]], 
            Times[ 0.013414935129827233, 
              c[ 24][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ 25][ t]], 
            Times[ -0.013061910521147276, 
              c[ 26][ t]], 
            Times[ -0.025221096343682053, 
              c[ 27][ t]], 
            Times[ -0.035980357068793781, 
              c[ 28][ t]], 
            Times[ -0.044914622433376288, 
              c[ 29][ t]], 
            Times[ -0.05168708394579296, 
              c[ 30][ t]], 
            Times[ -0.05606123915856713, 
              c[ 31][ t]], 
            Times[ -0.057908442314993203, 
              c[ 32][ t]], 
            Times[ -0.057210750238908967, 
              c[ 33][ t]], 
            Times[ -0.054059052045761224, 
              c[ 34][ t]], 
            Times[ -0.048646667243099399, 
              c[ 35][ t]], 
            Times[ -0.041258781072520248, 
              c[ 36][ t]], 
            Times[ -0.032258251165125679, 
              c[ 37][ t]], 
            Times[ -0.022068459300722043, 
              c[ 38][ t]], 
            Times[ -0.011153991006822649, 
              c[ 39][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 40][ t]], 
            Times[ 0.010908848347331785, 
              c[ 41][ t]], 
            Times[ 0.021108961070255627, 
              c[ 42][ t]], 
            Times[ 0.030177073670601094, 
              c[ 43][ t]], 
            Times[ 0.03774739544932687, 
              c[ 44][ t]], 
            Times[ 0.043525965428036162, 
              c[ 45][ t]], 
            Times[ 0.047301670540041058, 
              c[ 46][ t]], 
            Times[ 0.048953528554942699, 
              c[ 47][ t]], 
            Times[ 0.048454002753361682, 
              c[ 48][ t]], 
            Times[ 0.045868286584282311, 
              c[ 49][ t]], 
            Times[ 0.041349667156634483, 
              c[ 50][ t]], 
            Times[ 0.035131239329076656, 
              c[ 51][ t]], 
            Times[ 0.027514390699665887, 
              c[ 52][ t]], 
            Times[ 0.018854606004500389, 
              c[ 53][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 54][ t]], 
            Times[ 2.0053370214556287*^-16, 
              c[ 55][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 56][ t]], 
            Times[ -0.018149760920219783, 
              c[ 57][ t]], 
            Times[ -0.025985813438573278, 
              c[ 58][ t]], 
            Times[ -0.032552799745291051, 
              c[ 59][ t]], 
            Times[ -0.037590606506031236, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-49\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-49\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.32256865202152113`\ \(c[\(-60\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-59\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-58\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-57\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-56\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-55\)]\)[t] + 
            0.826993343132688`\ \(c[\(-54\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-53\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-52\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-51\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-50\)]\)[t] + 
            53.65982259336788`\ \(c[\(-49\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-48\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-47\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-46\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-45\)]\)[t] + 
            0.826993343132688`\ \(c[\(-44\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-43\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-42\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-41\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-40\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-39\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-38\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-37\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-36\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-35\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-34\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-33\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-32\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-31\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-30\)]\)[t] - 
            0.206748335783172`\ \(c[\(-29\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-28\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-27\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-26\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-25\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-24\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-23\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-22\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-21\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-20\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-19\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-18\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-17\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-16\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-15\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-14\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-13\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-12\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-11\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-10\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-9\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-8\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-7\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-6\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-5\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-4\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-3\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-2\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-1\)]\)[t] - 
            0.07241337086197412`\ \(c[0]\)[t] - 
            0.08269933431326874`\ \(c[1]\)[t] - 
            0.0890384386636067`\ \(c[2]\)[t] - 
            0.09131715903518159`\ \(c[3]\)[t] - 
            0.08959419377036688`\ \(c[4]\)[t] - 
            0.08409185873785081`\ \(c[5]\)[t] - 
            0.0751812130120626`\ \(c[6]\)[t] - 
            0.06336169950422753`\ \(c[7]\)[t] - 
            0.04923627809413894`\ \(c[8]\)[t] - 
            0.03348317962868157`\ \(c[9]\)[t] - 
            0.0168255118577494`\ \(c[10]\)[t] - 
            3.898171832519376`*^-17\ \(c[11]\)[t] + 
            0.016273855731265604`\ \(c[12]\)[t] + 
            0.03132297449134708`\ \(c[13]\)[t] + 
            0.04454710875183992`\ \(c[14]\)[t] + 
            0.05544148706619893`\ \(c[15]\)[t] + 
            0.06361487254866825`\ \(c[16]\)[t] + 
            0.06880242987642335`\ \(c[17]\)[t] + 
            0.07087301895267824`\ \(c[18]\)[t] + 
            0.06983076867396242`\ \(c[19]\)[t] + 
            0.06581101988179627`\ \(c[20]\)[t] + 
            0.059070953080906326`\ \(c[21]\)[t] + 
            0.049975424961080865`\ \(c[22]\)[t] + 
            0.03897872015785999`\ \(c[23]\)[t] + 
            0.026603074225527826`\ \(c[24]\)[t] + 
            0.013414935129827233`\ \(c[25]\)[t] + 
            3.898171832519376`*^-17\ \(c[26]\)[t] - 
            0.013061910521147383`\ \(c[27]\)[t] - 
            0.025221096343682053`\ \(c[28]\)[t] - 
            0.03598035706879378`\ \(c[29]\)[t] - 
            0.04491462243337642`\ \(c[30]\)[t] - 
            0.05168708394579296`\ \(c[31]\)[t] - 
            0.056061239158567186`\ \(c[32]\)[t] - 
            0.0579084423149932`\ \(c[33]\)[t] - 
            0.05721075023890897`\ \(c[34]\)[t] - 
            0.054059052045761224`\ \(c[35]\)[t] - 
            0.04864666724309928`\ \(c[36]\)[t] - 
            0.04125878107252025`\ \(c[37]\)[t] - 
            0.03225825116512552`\ \(c[38]\)[t] - 
            0.022068459300722043`\ \(c[39]\)[t] - 
            0.011153991006822649`\ \(c[40]\)[t] - 
            3.8981718325193755`*^-17\ \(c[41]\)[t] + 
            0.010908848347331966`\ \(c[42]\)[t] + 
            0.021108961070255627`\ \(c[43]\)[t] + 
            0.030177073670601094`\ \(c[44]\)[t] + 
            0.03774739544932687`\ \(c[45]\)[t] + 
            0.04352596542803616`\ \(c[46]\)[t] + 
            0.04730167054004106`\ \(c[47]\)[t] + 
            0.04895352855494272`\ \(c[48]\)[t] + 
            0.04845400275336168`\ \(c[49]\)[t] + 
            0.04586828658428231`\ \(c[50]\)[t] + 
            0.04134966715663448`\ \(c[51]\)[t] + 
            0.035131239329076656`\ \(c[52]\)[t] + 
            0.027514390699665887`\ \(c[53]\)[t] + 
            0.018854606004500233`\ \(c[54]\)[t] + 
            0.009545242303915543`\ \(c[55]\)[t] + 
            2.0053370214556287`*^-16\ \(c[56]\)[t] - 
            0.009365143392520679`\ \(c[57]\)[t] - 
            0.018149760920219783`\ \(c[58]\)[t] - 
            0.02598581343857328`\ \(c[59]\)[t] - 
            0.032552799745291155`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -49, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -49]][ t]], 
          Plus[ 
            Times[ 0.32256865202152113, 
              c[ -60][ t]], 
            Times[ 0.41349667156634429, 
              c[ -59][ t]], 
            Times[ 0.50455115242710469, 
              c[ -58][ t]], 
            Times[ 0.59356153372868015, 
              c[ -57][ t]], 
            Times[ 0.67835603854706361, 
              c[ -56][ t]], 
            Times[ 0.75682672864065692, 
              c[ -55][ t]], 
            Times[ 0.82699334313268802, 
              c[ -54][ t]], 
            Times[ 0.88706379305918392, 
              c[ -53][ t]], 
            Times[ 0.93548928378863916, 
              c[ -52][ t]], 
            Times[ 0.9710122092317629, 
              c[ -51][ t]], 
            Times[ 0.99270519960720693, 
              c[ -50][ t]], 
            Times[ 53.659822593367878, 
              c[ -49][ t]], 
            Times[ 0.99270519960720693, 
              c[ -48][ t]], 
            Times[ 0.9710122092317629, 
              c[ -47][ t]], 
            Times[ 0.93548928378863916, 
              c[ -46][ t]], 
            Times[ 0.88706379305918392, 
              c[ -45][ t]], 
            Times[ 0.82699334313268802, 
              c[ -44][ t]], 
            Times[ 0.75682672864065692, 
              c[ -43][ t]], 
            Times[ 0.67835603854706361, 
              c[ -42][ t]], 
            Times[ 0.59356153372868015, 
              c[ -41][ t]], 
            Times[ 0.50455115242710469, 
              c[ -40][ t]], 
            Times[ 0.41349667156634429, 
              c[ -39][ t]], 
            Times[ 0.32256865202152157, 
              c[ -38][ t]], 
            Times[ 0.23387232094715985, 
              c[ -37][ t]], 
            Times[ 0.14938649372796384, 
              c[ -36][ t]], 
            Times[ 0.070907514257657775, 
              c[ -35][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -34][ t]], 
            Times[ -0.062044074975450239, 
              c[ -33][ t]], 
            Times[ -0.11423673049785436, 
              c[ -32][ t]], 
            Times[ -0.15591488063143982, 
              c[ -31][ t]], 
            Times[ -0.18675027222298593, 
              c[ -30][ t]], 
            Times[ -0.206748335783172, 
              c[ -29][ t]], 
            Times[ -0.21623620818304484, 
              c[ -28][ t]], 
            Times[ -0.21584055771952015, 
              c[ -27][ t]], 
            Times[ -0.20645618564475843, 
              c[ -26][ t]], 
            Times[ -0.18920668216016426, 
              c[ -25][ t]], 
            Times[ -0.16539866862653771, 
              c[ -24][ t]], 
            Times[ -0.13647135277833605, 
              c[ -23][ t]], 
            Times[ -0.10394325375429328, 
              c[ -22][ t]], 
            Times[ -0.06935801494512607, 
              c[ -21][ t]], 
            Times[ -0.034231213779558949, 
              c[ -20][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -19][ t]], 
            Times[ 0.032022748374425904, 
              c[ -18][ t]], 
            Times[ 0.060688263076985105, 
              c[ -17][ t]], 
            Times[ 0.085044480344421705, 
              c[ -16][ t]], 
            Times[ 0.10436044624225685, 
              c[ -15][ t]], 
            Times[ 0.11814190616181255, 
              c[ -14][ t]], 
            Times[ 0.12613778810677614, 
              c[ -13][ t]], 
            Times[ 0.12833762891430928, 
              c[ -12][ t]], 
            Times[ 0.12496032289024853, 
              c[ -11][ t]], 
            Times[ 0.11643488132933186, 
              c[ -10][ t]], 
            Times[ 0.10337416789158609, 
              c[ -9][ t]], 
            Times[ 0.086542809078944891, 
              c[ -8][ t]], 
            Times[ 0.066820663127759972, 
              c[ -7][ t]], 
            Times[ 0.045163358568919301, 
              c[ -6][ t]], 
            Times[ 0.022561481809254869, 
              c[ -5][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -4][ t]], 
            Times[ -0.021580547817547879, 
              c[ -3][ t]], 
            Times[ -0.04131966847794722, 
              c[ -2][ t]], 
            Times[ -0.058468080236789913, 
              c[ -1][ t]], 
            Times[ -0.072413370861974122, 
              c[ 0][ t]], 
            Times[ -0.082699334313268744, 
              c[ 1][ t]], 
            Times[ -0.089038438663606695, 
              c[ 2][ t]], 
            Times[ -0.091317159035181589, 
              c[ 3][ t]], 
            Times[ -0.089594193770366884, 
              c[ 4][ t]], 
            Times[ -0.084091858737850814, 
              c[ 5][ t]], 
            Times[ -0.075181213012062598, 
              c[ 6][ t]], 
            Times[ -0.063361699504227528, 
              c[ 7][ t]], 
            Times[ -0.049236278094138941, 
              c[ 8][ t]], 
            Times[ -0.033483179628681567, 
              c[ 9][ t]], 
            Times[ -0.016825511857749401, 
              c[ 10][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 11][ t]], 
            Times[ 0.016273855731265604, 
              c[ 12][ t]], 
            Times[ 0.031322974491347078, 
              c[ 13][ t]], 
            Times[ 0.044547108751839919, 
              c[ 14][ t]], 
            Times[ 0.055441487066198933, 
              c[ 15][ t]], 
            Times[ 0.063614872548668253, 
              c[ 16][ t]], 
            Times[ 0.068802429876423349, 
              c[ 17][ t]], 
            Times[ 0.070873018952678238, 
              c[ 18][ t]], 
            Times[ 0.069830768673962415, 
              c[ 19][ t]], 
            Times[ 0.065811019881796273, 
              c[ 20][ t]], 
            Times[ 0.059070953080906326, 
              c[ 21][ t]], 
            Times[ 0.049975424961080865, 
              c[ 22][ t]], 
            Times[ 0.03897872015785999, 
              c[ 23][ t]], 
            Times[ 0.026603074225527826, 
              c[ 24][ t]], 
            Times[ 0.013414935129827233, 
              c[ 25][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 26][ t]], 
            Times[ -0.013061910521147383, 
              c[ 27][ t]], 
            Times[ -0.025221096343682053, 
              c[ 28][ t]], 
            Times[ -0.035980357068793781, 
              c[ 29][ t]], 
            Times[ -0.044914622433376419, 
              c[ 30][ t]], 
            Times[ -0.05168708394579296, 
              c[ 31][ t]], 
            Times[ -0.056061239158567186, 
              c[ 32][ t]], 
            Times[ -0.057908442314993203, 
              c[ 33][ t]], 
            Times[ -0.057210750238908967, 
              c[ 34][ t]], 
            Times[ -0.054059052045761224, 
              c[ 35][ t]], 
            Times[ -0.048646667243099281, 
              c[ 36][ t]], 
            Times[ -0.041258781072520248, 
              c[ 37][ t]], 
            Times[ -0.032258251165125519, 
              c[ 38][ t]], 
            Times[ -0.022068459300722043, 
              c[ 39][ t]], 
            Times[ -0.011153991006822649, 
              c[ 40][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 41][ t]], 
            Times[ 0.010908848347331966, 
              c[ 42][ t]], 
            Times[ 0.021108961070255627, 
              c[ 43][ t]], 
            Times[ 0.030177073670601094, 
              c[ 44][ t]], 
            Times[ 0.03774739544932687, 
              c[ 45][ t]], 
            Times[ 0.043525965428036162, 
              c[ 46][ t]], 
            Times[ 0.047301670540041058, 
              c[ 47][ t]], 
            Times[ 0.04895352855494272, 
              c[ 48][ t]], 
            Times[ 0.048454002753361682, 
              c[ 49][ t]], 
            Times[ 0.045868286584282311, 
              c[ 50][ t]], 
            Times[ 0.041349667156634483, 
              c[ 51][ t]], 
            Times[ 0.035131239329076656, 
              c[ 52][ t]], 
            Times[ 0.027514390699665887, 
              c[ 53][ t]], 
            Times[ 0.018854606004500233, 
              c[ 54][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 55][ t]], 
            Times[ 2.0053370214556287*^-16, 
              c[ 56][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 57][ t]], 
            Times[ -0.018149760920219783, 
              c[ 58][ t]], 
            Times[ -0.025985813438573278, 
              c[ 59][ t]], 
            Times[ -0.032552799745291155, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-48\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-48\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.23387232094715985`\ \(c[\(-60\)]\)[t] + 
            0.3225686520215219`\ \(c[\(-59\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-58\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-57\)]\)[t] + 
            0.5935615337286809`\ \(c[\(-56\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-55\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-54\)]\)[t] + 
            0.8269933431326885`\ \(c[\(-53\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-52\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-51\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-50\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-49\)]\)[t] + 
            51.53237453357751`\ \(c[\(-48\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-47\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-46\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-45\)]\)[t] + 
            0.8870637930591835`\ \(c[\(-44\)]\)[t] + 
            0.826993343132688`\ \(c[\(-43\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-42\)]\)[t] + 
            0.6783560385470627`\ \(c[\(-41\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-40\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-39\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-38\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-37\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-36\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-35\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-34\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-33\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-32\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-31\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-30\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-29\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-28\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-27\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-26\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-25\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-24\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-23\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-22\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-21\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-20\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-19\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-18\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-17\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-16\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-15\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-14\)]\)[t] + 
            0.1181419061618126`\ \(c[\(-13\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-12\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-11\)]\)[t] + 
            0.12496032289024847`\ \(c[\(-10\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-9\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-8\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-7\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-6\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-5\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-4\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-3\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-2\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-1\)]\)[t] - 
            0.05846808023678991`\ \(c[0]\)[t] - 
            0.07241337086197412`\ \(c[1]\)[t] - 
            0.08269933431326881`\ \(c[2]\)[t] - 
            0.0890384386636067`\ \(c[3]\)[t] - 
            0.09131715903518159`\ \(c[4]\)[t] - 
            0.08959419377036684`\ \(c[5]\)[t] - 
            0.08409185873785081`\ \(c[6]\)[t] - 
            0.0751812130120626`\ \(c[7]\)[t] - 
            0.0633616995042274`\ \(c[8]\)[t] - 
            0.04923627809413894`\ \(c[9]\)[t] - 
            0.03348317962868157`\ \(c[10]\)[t] - 
            0.0168255118577494`\ \(c[11]\)[t] - 
            3.898171832519376`*^-17\ \(c[12]\)[t] + 
            0.016273855731265604`\ \(c[13]\)[t] + 
            0.03132297449134708`\ \(c[14]\)[t] + 
            0.04454710875183992`\ \(c[15]\)[t] + 
            0.05544148706619893`\ \(c[16]\)[t] + 
            0.06361487254866825`\ \(c[17]\)[t] + 
            0.06880242987642335`\ \(c[18]\)[t] + 
            0.07087301895267824`\ \(c[19]\)[t] + 
            0.06983076867396242`\ \(c[20]\)[t] + 
            0.06581101988179627`\ \(c[21]\)[t] + 
            0.059070953080906326`\ \(c[22]\)[t] + 
            0.049975424961080865`\ \(c[23]\)[t] + 
            0.03897872015785999`\ \(c[24]\)[t] + 
            0.026603074225527826`\ \(c[25]\)[t] + 
            0.013414935129827233`\ \(c[26]\)[t] + 
            3.898171832519376`*^-17\ \(c[27]\)[t] - 
            0.013061910521147383`\ \(c[28]\)[t] - 
            0.025221096343682053`\ \(c[29]\)[t] - 
            0.03598035706879378`\ \(c[30]\)[t] - 
            0.04491462243337642`\ \(c[31]\)[t] - 
            0.05168708394579296`\ \(c[32]\)[t] - 
            0.056061239158567186`\ \(c[33]\)[t] - 
            0.0579084423149932`\ \(c[34]\)[t] - 
            0.05721075023890897`\ \(c[35]\)[t] - 
            0.054059052045761224`\ \(c[36]\)[t] - 
            0.04864666724309928`\ \(c[37]\)[t] - 
            0.04125878107252025`\ \(c[38]\)[t] - 
            0.03225825116512552`\ \(c[39]\)[t] - 
            0.022068459300722043`\ \(c[40]\)[t] - 
            0.011153991006822649`\ \(c[41]\)[t] - 
            3.8981718325193755`*^-17\ \(c[42]\)[t] + 
            0.010908848347331966`\ \(c[43]\)[t] + 
            0.021108961070255627`\ \(c[44]\)[t] + 
            0.030177073670601236`\ \(c[45]\)[t] + 
            0.03774739544932687`\ \(c[46]\)[t] + 
            0.04352596542803616`\ \(c[47]\)[t] + 
            0.04730167054004106`\ \(c[48]\)[t] + 
            0.04895352855494272`\ \(c[49]\)[t] + 
            0.04845400275336168`\ \(c[50]\)[t] + 
            0.045868286584282256`\ \(c[51]\)[t] + 
            0.04134966715663448`\ \(c[52]\)[t] + 
            0.035131239329076656`\ \(c[53]\)[t] + 
            0.027514390699665887`\ \(c[54]\)[t] + 
            0.018854606004500233`\ \(c[55]\)[t] + 
            0.009545242303915543`\ \(c[56]\)[t] + 
            3.8981718325193755`*^-17\ \(c[57]\)[t] - 
            0.009365143392520679`\ \(c[58]\)[t] - 
            0.018149760920219783`\ \(c[59]\)[t] - 
            0.02598581343857328`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -48, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -48]][ t]], 
          Plus[ 
            Times[ 0.23387232094715985, 
              c[ -60][ t]], 
            Times[ 0.32256865202152191, 
              c[ -59][ t]], 
            Times[ 0.41349667156634429, 
              c[ -58][ t]], 
            Times[ 0.50455115242710469, 
              c[ -57][ t]], 
            Times[ 0.59356153372868092, 
              c[ -56][ t]], 
            Times[ 0.67835603854706361, 
              c[ -55][ t]], 
            Times[ 0.75682672864065692, 
              c[ -54][ t]], 
            Times[ 0.82699334313268846, 
              c[ -53][ t]], 
            Times[ 0.88706379305918392, 
              c[ -52][ t]], 
            Times[ 0.93548928378863916, 
              c[ -51][ t]], 
            Times[ 0.9710122092317629, 
              c[ -50][ t]], 
            Times[ 0.99270519960720693, 
              c[ -49][ t]], 
            Times[ 51.53237453357751, 
              c[ -48][ t]], 
            Times[ 0.99270519960720671, 
              c[ -47][ t]], 
            Times[ 0.9710122092317629, 
              c[ -46][ t]], 
            Times[ 0.93548928378863916, 
              c[ -45][ t]], 
            Times[ 0.88706379305918348, 
              c[ -44][ t]], 
            Times[ 0.82699334313268802, 
              c[ -43][ t]], 
            Times[ 0.75682672864065692, 
              c[ -42][ t]], 
            Times[ 0.67835603854706272, 
              c[ -41][ t]], 
            Times[ 0.59356153372868015, 
              c[ -40][ t]], 
            Times[ 0.50455115242710469, 
              c[ -39][ t]], 
            Times[ 0.41349667156634395, 
              c[ -38][ t]], 
            Times[ 0.32256865202152113, 
              c[ -37][ t]], 
            Times[ 0.23387232094715985, 
              c[ -36][ t]], 
            Times[ 0.14938649372796345, 
              c[ -35][ t]], 
            Times[ 0.070907514257657456, 
              c[ -34][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -33][ t]], 
            Times[ -0.062044074975450475, 
              c[ -32][ t]], 
            Times[ -0.11423673049785459, 
              c[ -31][ t]], 
            Times[ -0.15591488063143982, 
              c[ -30][ t]], 
            Times[ -0.18675027222298607, 
              c[ -29][ t]], 
            Times[ -0.20674833578317206, 
              c[ -28][ t]], 
            Times[ -0.21623620818304484, 
              c[ -27][ t]], 
            Times[ -0.21584055771952013, 
              c[ -26][ t]], 
            Times[ -0.20645618564475834, 
              c[ -25][ t]], 
            Times[ -0.18920668216016426, 
              c[ -24][ t]], 
            Times[ -0.1653986686265376, 
              c[ -23][ t]], 
            Times[ -0.13647135277833591, 
              c[ -22][ t]], 
            Times[ -0.10394325375429328, 
              c[ -21][ t]], 
            Times[ -0.069358014945125918, 
              c[ -20][ t]], 
            Times[ -0.034231213779558796, 
              c[ -19][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -18][ t]], 
            Times[ 0.032022748374426029, 
              c[ -17][ t]], 
            Times[ 0.060688263076985223, 
              c[ -16][ t]], 
            Times[ 0.085044480344421705, 
              c[ -15][ t]], 
            Times[ 0.10436044624225692, 
              c[ -14][ t]], 
            Times[ 0.1181419061618126, 
              c[ -13][ t]], 
            Times[ 0.12613778810677614, 
              c[ -12][ t]], 
            Times[ 0.12833762891430925, 
              c[ -11][ t]], 
            Times[ 0.12496032289024847, 
              c[ -10][ t]], 
            Times[ 0.11643488132933186, 
              c[ -9][ t]], 
            Times[ 0.10337416789158609, 
              c[ -8][ t]], 
            Times[ 0.086542809078944752, 
              c[ -7][ t]], 
            Times[ 0.066820663127759972, 
              c[ -6][ t]], 
            Times[ 0.045163358568919301, 
              c[ -5][ t]], 
            Times[ 0.022561481809254675, 
              c[ -4][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -3][ t]], 
            Times[ -0.021580547817547879, 
              c[ -2][ t]], 
            Times[ -0.041319668477947373, 
              c[ -1][ t]], 
            Times[ -0.058468080236789913, 
              c[ 0][ t]], 
            Times[ -0.072413370861974122, 
              c[ 1][ t]], 
            Times[ -0.082699334313268813, 
              c[ 2][ t]], 
            Times[ -0.089038438663606695, 
              c[ 3][ t]], 
            Times[ -0.091317159035181589, 
              c[ 4][ t]], 
            Times[ -0.089594193770366842, 
              c[ 5][ t]], 
            Times[ -0.084091858737850814, 
              c[ 6][ t]], 
            Times[ -0.075181213012062598, 
              c[ 7][ t]], 
            Times[ -0.063361699504227403, 
              c[ 8][ t]], 
            Times[ -0.049236278094138941, 
              c[ 9][ t]], 
            Times[ -0.033483179628681567, 
              c[ 10][ t]], 
            Times[ -0.016825511857749401, 
              c[ 11][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 12][ t]], 
            Times[ 0.016273855731265604, 
              c[ 13][ t]], 
            Times[ 0.031322974491347078, 
              c[ 14][ t]], 
            Times[ 0.044547108751839919, 
              c[ 15][ t]], 
            Times[ 0.055441487066198933, 
              c[ 16][ t]], 
            Times[ 0.063614872548668253, 
              c[ 17][ t]], 
            Times[ 0.068802429876423349, 
              c[ 18][ t]], 
            Times[ 0.070873018952678238, 
              c[ 19][ t]], 
            Times[ 0.069830768673962415, 
              c[ 20][ t]], 
            Times[ 0.065811019881796273, 
              c[ 21][ t]], 
            Times[ 0.059070953080906326, 
              c[ 22][ t]], 
            Times[ 0.049975424961080865, 
              c[ 23][ t]], 
            Times[ 0.03897872015785999, 
              c[ 24][ t]], 
            Times[ 0.026603074225527826, 
              c[ 25][ t]], 
            Times[ 0.013414935129827233, 
              c[ 26][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 27][ t]], 
            Times[ -0.013061910521147383, 
              c[ 28][ t]], 
            Times[ -0.025221096343682053, 
              c[ 29][ t]], 
            Times[ -0.035980357068793781, 
              c[ 30][ t]], 
            Times[ -0.044914622433376419, 
              c[ 31][ t]], 
            Times[ -0.05168708394579296, 
              c[ 32][ t]], 
            Times[ -0.056061239158567186, 
              c[ 33][ t]], 
            Times[ -0.057908442314993203, 
              c[ 34][ t]], 
            Times[ -0.057210750238908967, 
              c[ 35][ t]], 
            Times[ -0.054059052045761224, 
              c[ 36][ t]], 
            Times[ -0.048646667243099281, 
              c[ 37][ t]], 
            Times[ -0.041258781072520248, 
              c[ 38][ t]], 
            Times[ -0.032258251165125519, 
              c[ 39][ t]], 
            Times[ -0.022068459300722043, 
              c[ 40][ t]], 
            Times[ -0.011153991006822649, 
              c[ 41][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 42][ t]], 
            Times[ 0.010908848347331966, 
              c[ 43][ t]], 
            Times[ 0.021108961070255627, 
              c[ 44][ t]], 
            Times[ 0.030177073670601236, 
              c[ 45][ t]], 
            Times[ 0.03774739544932687, 
              c[ 46][ t]], 
            Times[ 0.043525965428036162, 
              c[ 47][ t]], 
            Times[ 0.047301670540041058, 
              c[ 48][ t]], 
            Times[ 0.04895352855494272, 
              c[ 49][ t]], 
            Times[ 0.048454002753361682, 
              c[ 50][ t]], 
            Times[ 0.045868286584282256, 
              c[ 51][ t]], 
            Times[ 0.041349667156634483, 
              c[ 52][ t]], 
            Times[ 0.035131239329076656, 
              c[ 53][ t]], 
            Times[ 0.027514390699665887, 
              c[ 54][ t]], 
            Times[ 0.018854606004500233, 
              c[ 55][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 56][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 57][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 58][ t]], 
            Times[ -0.018149760920219783, 
              c[ 59][ t]], 
            Times[ -0.025985813438573278, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-47\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-47\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.14938649372796314`\ \(c[\(-60\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-59\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-58\)]\)[t] + 
            0.4134966715663436`\ \(c[\(-57\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-56\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-55\)]\)[t] + 
            0.6783560385470627`\ \(c[\(-54\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-53\)]\)[t] + 
            0.826993343132688`\ \(c[\(-52\)]\)[t] + 
            0.8870637930591835`\ \(c[\(-51\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-50\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-49\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-48\)]\)[t] + 
            49.448791382236415`\ \(c[\(-47\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-46\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-45\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-44\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-43\)]\)[t] + 
            0.8269933431326885`\ \(c[\(-42\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-41\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-40\)]\)[t] + 
            0.5935615337286809`\ \(c[\(-39\)]\)[t] + 
            0.504551152427105`\ \(c[\(-38\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-37\)]\)[t] + 
            0.3225686520215219`\ \(c[\(-36\)]\)[t] + 
            0.23387232094716018`\ \(c[\(-35\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-34\)]\)[t] + 
            0.0709075142576581`\ \(c[\(-33\)]\)[t] + 
            3.216976900108398`*^-16\ \(c[\(-32\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-31\)]\)[t] - 
            0.11423673049785416`\ \(c[\(-30\)]\)[t] - 
            0.15591488063143966`\ \(c[\(-29\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-28\)]\)[t] - 
            0.2067483357831719`\ \(c[\(-27\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-26\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-25\)]\)[t] - 
            0.20645618564475848`\ \(c[\(-24\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-23\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-22\)]\)[t] - 
            0.13647135277833616`\ \(c[\(-21\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-20\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-19\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-18\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-17\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-16\)]\)[t] + 
            0.060688263076985`\ \(c[\(-15\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-14\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-13\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-12\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-11\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-10\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-9\)]\)[t] + 
            0.11643488132933195`\ \(c[\(-8\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-7\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-6\)]\)[t] + 
            0.06682066312776015`\ \(c[\(-5\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-4\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-3\)]\)[t] + 
            2.274590327822911`*^-16\ \(c[\(-2\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-1\)]\)[t] - 
            0.04131966847794722`\ \(c[0]\)[t] - 
            0.058468080236789774`\ \(c[1]\)[t] - 
            0.07241337086197412`\ \(c[2]\)[t] - 
            0.08269933431326874`\ \(c[3]\)[t] - 
            0.08903843866360665`\ \(c[4]\)[t] - 
            0.09131715903518159`\ \(c[5]\)[t] - 
            0.08959419377036688`\ \(c[6]\)[t] - 
            0.08409185873785086`\ \(c[7]\)[t] - 
            0.0751812130120626`\ \(c[8]\)[t] - 
            0.06336169950422753`\ \(c[9]\)[t] - 
            0.049236278094139066`\ \(c[10]\)[t] - 
            0.033483179628681706`\ \(c[11]\)[t] - 
            0.0168255118577494`\ \(c[12]\)[t] - 
            1.8033970416801674`*^-16\ \(c[13]\)[t] + 
            0.01627385573126547`\ \(c[14]\)[t] + 
            0.03132297449134708`\ \(c[15]\)[t] + 
            0.044547108751839815`\ \(c[16]\)[t] + 
            0.055441487066198857`\ \(c[17]\)[t] + 
            0.06361487254866825`\ \(c[18]\)[t] + 
            0.06880242987642332`\ \(c[19]\)[t] + 
            0.07087301895267824`\ \(c[20]\)[t] + 
            0.06983076867396242`\ \(c[21]\)[t] + 
            0.06581101988179631`\ \(c[22]\)[t] + 
            0.0590709530809064`\ \(c[23]\)[t] + 
            0.049975424961080865`\ \(c[24]\)[t] + 
            0.03897872015786009`\ \(c[25]\)[t] + 
            0.026603074225527937`\ \(c[26]\)[t] + 
            0.013414935129827233`\ \(c[27]\)[t] + 
            1.5206810699945212`*^-16\ \(c[28]\)[t] - 
            0.013061910521147276`\ \(c[29]\)[t] - 
            0.025221096343682053`\ \(c[30]\)[t] - 
            0.03598035706879378`\ \(c[31]\)[t] - 
            0.04491462243337629`\ \(c[32]\)[t] - 
            0.05168708394579296`\ \(c[33]\)[t] - 
            0.05606123915856713`\ \(c[34]\)[t] - 
            0.0579084423149932`\ \(c[35]\)[t] - 
            0.05721075023890897`\ \(c[36]\)[t] - 
            0.054059052045761224`\ \(c[37]\)[t] - 
            0.0486466672430994`\ \(c[38]\)[t] - 
            0.04125878107252025`\ \(c[39]\)[t] - 
            0.03225825116512568`\ \(c[40]\)[t] - 
            0.022068459300722043`\ \(c[41]\)[t] - 
            0.011153991006822649`\ \(c[42]\)[t] - 
            3.8981718325193755`*^-17\ \(c[43]\)[t] + 
            0.010908848347331785`\ \(c[44]\)[t] + 
            0.021108961070255627`\ \(c[45]\)[t] + 
            0.030177073670601094`\ \(c[46]\)[t] + 
            0.03774739544932687`\ \(c[47]\)[t] + 
            0.04352596542803616`\ \(c[48]\)[t] + 
            0.04730167054004106`\ \(c[49]\)[t] + 
            0.0489535285549427`\ \(c[50]\)[t] + 
            0.04845400275336168`\ \(c[51]\)[t] + 
            0.04586828658428231`\ \(c[52]\)[t] + 
            0.04134966715663448`\ \(c[53]\)[t] + 
            0.035131239329076656`\ \(c[54]\)[t] + 
            0.027514390699665887`\ \(c[55]\)[t] + 
            0.01885460600450039`\ \(c[56]\)[t] + 
            0.009545242303915543`\ \(c[57]\)[t] + 
            2.0053370214556287`*^-16\ \(c[58]\)[t] - 
            0.009365143392520679`\ \(c[59]\)[t] - 
            0.018149760920219783`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -47, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -47]][ t]], 
          Plus[ 
            Times[ 0.14938649372796314, 
              c[ -60][ t]], 
            Times[ 0.23387232094715985, 
              c[ -59][ t]], 
            Times[ 0.32256865202152113, 
              c[ -58][ t]], 
            Times[ 0.41349667156634362, 
              c[ -57][ t]], 
            Times[ 0.50455115242710469, 
              c[ -56][ t]], 
            Times[ 0.59356153372868015, 
              c[ -55][ t]], 
            Times[ 0.67835603854706272, 
              c[ -54][ t]], 
            Times[ 0.75682672864065692, 
              c[ -53][ t]], 
            Times[ 0.82699334313268802, 
              c[ -52][ t]], 
            Times[ 0.88706379305918348, 
              c[ -51][ t]], 
            Times[ 0.93548928378863916, 
              c[ -50][ t]], 
            Times[ 0.9710122092317629, 
              c[ -49][ t]], 
            Times[ 0.99270519960720671, 
              c[ -48][ t]], 
            Times[ 49.448791382236415, 
              c[ -47][ t]], 
            Times[ 0.99270519960720693, 
              c[ -46][ t]], 
            Times[ 0.9710122092317629, 
              c[ -45][ t]], 
            Times[ 0.93548928378863916, 
              c[ -44][ t]], 
            Times[ 0.88706379305918392, 
              c[ -43][ t]], 
            Times[ 0.82699334313268846, 
              c[ -42][ t]], 
            Times[ 0.75682672864065692, 
              c[ -41][ t]], 
            Times[ 0.67835603854706361, 
              c[ -40][ t]], 
            Times[ 0.59356153372868092, 
              c[ -39][ t]], 
            Times[ 0.50455115242710502, 
              c[ -38][ t]], 
            Times[ 0.41349667156634429, 
              c[ -37][ t]], 
            Times[ 0.32256865202152191, 
              c[ -36][ t]], 
            Times[ 0.23387232094716018, 
              c[ -35][ t]], 
            Times[ 0.14938649372796384, 
              c[ -34][ t]], 
            Times[ 0.070907514257658094, 
              c[ -33][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ -32][ t]], 
            Times[ -0.062044074975450239, 
              c[ -31][ t]], 
            Times[ -0.11423673049785416, 
              c[ -30][ t]], 
            Times[ -0.15591488063143966, 
              c[ -29][ t]], 
            Times[ -0.18675027222298593, 
              c[ -28][ t]], 
            Times[ -0.20674833578317189, 
              c[ -27][ t]], 
            Times[ -0.21623620818304481, 
              c[ -26][ t]], 
            Times[ -0.21584055771952015, 
              c[ -25][ t]], 
            Times[ -0.20645618564475848, 
              c[ -24][ t]], 
            Times[ -0.18920668216016434, 
              c[ -23][ t]], 
            Times[ -0.16539866862653771, 
              c[ -22][ t]], 
            Times[ -0.13647135277833616, 
              c[ -21][ t]], 
            Times[ -0.1039432537542934, 
              c[ -20][ t]], 
            Times[ -0.06935801494512607, 
              c[ -19][ t]], 
            Times[ -0.034231213779559094, 
              c[ -18][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -17][ t]], 
            Times[ 0.032022748374425904, 
              c[ -16][ t]], 
            Times[ 0.060688263076985001, 
              c[ -15][ t]], 
            Times[ 0.085044480344421608, 
              c[ -14][ t]], 
            Times[ 0.10436044624225685, 
              c[ -13][ t]], 
            Times[ 0.11814190616181253, 
              c[ -12][ t]], 
            Times[ 0.12613778810677612, 
              c[ -11][ t]], 
            Times[ 0.12833762891430928, 
              c[ -10][ t]], 
            Times[ 0.12496032289024853, 
              c[ -9][ t]], 
            Times[ 0.11643488132933195, 
              c[ -8][ t]], 
            Times[ 0.10337416789158609, 
              c[ -7][ t]], 
            Times[ 0.086542809078944891, 
              c[ -6][ t]], 
            Times[ 0.066820663127760152, 
              c[ -5][ t]], 
            Times[ 0.045163358568919301, 
              c[ -4][ t]], 
            Times[ 0.022561481809254869, 
              c[ -3][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ -2][ t]], 
            Times[ -0.021580547817547879, 
              c[ -1][ t]], 
            Times[ -0.04131966847794722, 
              c[ 0][ t]], 
            Times[ -0.058468080236789774, 
              c[ 1][ t]], 
            Times[ -0.072413370861974122, 
              c[ 2][ t]], 
            Times[ -0.082699334313268744, 
              c[ 3][ t]], 
            Times[ -0.089038438663606653, 
              c[ 4][ t]], 
            Times[ -0.091317159035181589, 
              c[ 5][ t]], 
            Times[ -0.089594193770366884, 
              c[ 6][ t]], 
            Times[ -0.084091858737850855, 
              c[ 7][ t]], 
            Times[ -0.075181213012062598, 
              c[ 8][ t]], 
            Times[ -0.063361699504227528, 
              c[ 9][ t]], 
            Times[ -0.049236278094139066, 
              c[ 10][ t]], 
            Times[ -0.033483179628681706, 
              c[ 11][ t]], 
            Times[ -0.016825511857749401, 
              c[ 12][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 13][ t]], 
            Times[ 0.016273855731265469, 
              c[ 14][ t]], 
            Times[ 0.031322974491347078, 
              c[ 15][ t]], 
            Times[ 0.044547108751839815, 
              c[ 16][ t]], 
            Times[ 0.055441487066198857, 
              c[ 17][ t]], 
            Times[ 0.063614872548668253, 
              c[ 18][ t]], 
            Times[ 0.068802429876423321, 
              c[ 19][ t]], 
            Times[ 0.070873018952678238, 
              c[ 20][ t]], 
            Times[ 0.069830768673962415, 
              c[ 21][ t]], 
            Times[ 0.065811019881796315, 
              c[ 22][ t]], 
            Times[ 0.059070953080906402, 
              c[ 23][ t]], 
            Times[ 0.049975424961080865, 
              c[ 24][ t]], 
            Times[ 0.038978720157860088, 
              c[ 25][ t]], 
            Times[ 0.026603074225527937, 
              c[ 26][ t]], 
            Times[ 0.013414935129827233, 
              c[ 27][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ 28][ t]], 
            Times[ -0.013061910521147276, 
              c[ 29][ t]], 
            Times[ -0.025221096343682053, 
              c[ 30][ t]], 
            Times[ -0.035980357068793781, 
              c[ 31][ t]], 
            Times[ -0.044914622433376288, 
              c[ 32][ t]], 
            Times[ -0.05168708394579296, 
              c[ 33][ t]], 
            Times[ -0.05606123915856713, 
              c[ 34][ t]], 
            Times[ -0.057908442314993203, 
              c[ 35][ t]], 
            Times[ -0.057210750238908967, 
              c[ 36][ t]], 
            Times[ -0.054059052045761224, 
              c[ 37][ t]], 
            Times[ -0.048646667243099399, 
              c[ 38][ t]], 
            Times[ -0.041258781072520248, 
              c[ 39][ t]], 
            Times[ -0.032258251165125679, 
              c[ 40][ t]], 
            Times[ -0.022068459300722043, 
              c[ 41][ t]], 
            Times[ -0.011153991006822649, 
              c[ 42][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 43][ t]], 
            Times[ 0.010908848347331785, 
              c[ 44][ t]], 
            Times[ 0.021108961070255627, 
              c[ 45][ t]], 
            Times[ 0.030177073670601094, 
              c[ 46][ t]], 
            Times[ 0.03774739544932687, 
              c[ 47][ t]], 
            Times[ 0.043525965428036162, 
              c[ 48][ t]], 
            Times[ 0.047301670540041058, 
              c[ 49][ t]], 
            Times[ 0.048953528554942699, 
              c[ 50][ t]], 
            Times[ 0.048454002753361682, 
              c[ 51][ t]], 
            Times[ 0.045868286584282311, 
              c[ 52][ t]], 
            Times[ 0.041349667156634483, 
              c[ 53][ t]], 
            Times[ 0.035131239329076656, 
              c[ 54][ t]], 
            Times[ 0.027514390699665887, 
              c[ 55][ t]], 
            Times[ 0.018854606004500389, 
              c[ 56][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 57][ t]], 
            Times[ 2.0053370214556287*^-16, 
              c[ 58][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 59][ t]], 
            Times[ -0.018149760920219783, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-46\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-46\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.07090751425765746`\ \(c[\(-60\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-59\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-58\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-57\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-56\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-55\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-54\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-53\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-52\)]\)[t] + 
            0.826993343132688`\ \(c[\(-51\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-50\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-49\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-48\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-47\)]\)[t] + 
            47.40907313934462`\ \(c[\(-46\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-45\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-44\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-43\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-42\)]\)[t] + 
            0.826993343132688`\ \(c[\(-41\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-40\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-39\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-38\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-37\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-36\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-35\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-34\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-33\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-32\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-31\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-30\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-29\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-28\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-27\)]\)[t] - 
            0.206748335783172`\ \(c[\(-26\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-25\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-24\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-23\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-22\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-21\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-20\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-19\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-18\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-17\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-16\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-15\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-14\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-13\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-12\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-11\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-10\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-9\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-8\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-7\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-6\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-5\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-4\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-3\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-2\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-1\)]\)[t] - 
            0.02158054781754788`\ \(c[0]\)[t] - 
            0.04131966847794722`\ \(c[1]\)[t] - 
            0.05846808023678991`\ \(c[2]\)[t] - 
            0.07241337086197412`\ \(c[3]\)[t] - 
            0.08269933431326874`\ \(c[4]\)[t] - 
            0.0890384386636067`\ \(c[5]\)[t] - 
            0.09131715903518159`\ \(c[6]\)[t] - 
            0.08959419377036688`\ \(c[7]\)[t] - 
            0.08409185873785081`\ \(c[8]\)[t] - 
            0.0751812130120626`\ \(c[9]\)[t] - 
            0.06336169950422753`\ \(c[10]\)[t] - 
            0.04923627809413894`\ \(c[11]\)[t] - 
            0.03348317962868157`\ \(c[12]\)[t] - 
            0.0168255118577494`\ \(c[13]\)[t] - 
            3.898171832519376`*^-17\ \(c[14]\)[t] + 
            0.016273855731265604`\ \(c[15]\)[t] + 
            0.03132297449134708`\ \(c[16]\)[t] + 
            0.04454710875183992`\ \(c[17]\)[t] + 
            0.05544148706619893`\ \(c[18]\)[t] + 
            0.06361487254866825`\ \(c[19]\)[t] + 
            0.06880242987642335`\ \(c[20]\)[t] + 
            0.07087301895267824`\ \(c[21]\)[t] + 
            0.06983076867396242`\ \(c[22]\)[t] + 
            0.06581101988179627`\ \(c[23]\)[t] + 
            0.059070953080906326`\ \(c[24]\)[t] + 
            0.049975424961080865`\ \(c[25]\)[t] + 
            0.03897872015785999`\ \(c[26]\)[t] + 
            0.026603074225527826`\ \(c[27]\)[t] + 
            0.013414935129827233`\ \(c[28]\)[t] + 
            3.898171832519376`*^-17\ \(c[29]\)[t] - 
            0.013061910521147383`\ \(c[30]\)[t] - 
            0.025221096343682053`\ \(c[31]\)[t] - 
            0.03598035706879378`\ \(c[32]\)[t] - 
            0.04491462243337642`\ \(c[33]\)[t] - 
            0.05168708394579296`\ \(c[34]\)[t] - 
            0.056061239158567186`\ \(c[35]\)[t] - 
            0.0579084423149932`\ \(c[36]\)[t] - 
            0.05721075023890897`\ \(c[37]\)[t] - 
            0.054059052045761224`\ \(c[38]\)[t] - 
            0.04864666724309928`\ \(c[39]\)[t] - 
            0.04125878107252025`\ \(c[40]\)[t] - 
            0.03225825116512568`\ \(c[41]\)[t] - 
            0.022068459300722043`\ \(c[42]\)[t] - 
            0.011153991006822649`\ \(c[43]\)[t] - 
            3.8981718325193755`*^-17\ \(c[44]\)[t] + 
            0.010908848347331966`\ \(c[45]\)[t] + 
            0.021108961070255627`\ \(c[46]\)[t] + 
            0.030177073670601094`\ \(c[47]\)[t] + 
            0.03774739544932687`\ \(c[48]\)[t] + 
            0.04352596542803616`\ \(c[49]\)[t] + 
            0.04730167054004106`\ \(c[50]\)[t] + 
            0.04895352855494272`\ \(c[51]\)[t] + 
            0.04845400275336168`\ \(c[52]\)[t] + 
            0.04586828658428231`\ \(c[53]\)[t] + 
            0.04134966715663448`\ \(c[54]\)[t] + 
            0.035131239329076656`\ \(c[55]\)[t] + 
            0.027514390699665887`\ \(c[56]\)[t] + 
            0.018854606004500233`\ \(c[57]\)[t] + 
            0.009545242303915543`\ \(c[58]\)[t] + 
            2.0053370214556287`*^-16\ \(c[59]\)[t] - 
            0.009365143392520679`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -46, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -46]][ t]], 
          Plus[ 
            Times[ 0.070907514257657456, 
              c[ -60][ t]], 
            Times[ 0.14938649372796384, 
              c[ -59][ t]], 
            Times[ 0.23387232094715985, 
              c[ -58][ t]], 
            Times[ 0.32256865202152113, 
              c[ -57][ t]], 
            Times[ 0.41349667156634429, 
              c[ -56][ t]], 
            Times[ 0.50455115242710469, 
              c[ -55][ t]], 
            Times[ 0.59356153372868015, 
              c[ -54][ t]], 
            Times[ 0.67835603854706361, 
              c[ -53][ t]], 
            Times[ 0.75682672864065692, 
              c[ -52][ t]], 
            Times[ 0.82699334313268802, 
              c[ -51][ t]], 
            Times[ 0.88706379305918392, 
              c[ -50][ t]], 
            Times[ 0.93548928378863916, 
              c[ -49][ t]], 
            Times[ 0.9710122092317629, 
              c[ -48][ t]], 
            Times[ 0.99270519960720693, 
              c[ -47][ t]], 
            Times[ 47.409073139344621, 
              c[ -46][ t]], 
            Times[ 0.99270519960720693, 
              c[ -45][ t]], 
            Times[ 0.9710122092317629, 
              c[ -44][ t]], 
            Times[ 0.93548928378863916, 
              c[ -43][ t]], 
            Times[ 0.88706379305918392, 
              c[ -42][ t]], 
            Times[ 0.82699334313268802, 
              c[ -41][ t]], 
            Times[ 0.75682672864065692, 
              c[ -40][ t]], 
            Times[ 0.67835603854706361, 
              c[ -39][ t]], 
            Times[ 0.59356153372868059, 
              c[ -38][ t]], 
            Times[ 0.50455115242710469, 
              c[ -37][ t]], 
            Times[ 0.41349667156634429, 
              c[ -36][ t]], 
            Times[ 0.32256865202152157, 
              c[ -35][ t]], 
            Times[ 0.23387232094715985, 
              c[ -34][ t]], 
            Times[ 0.14938649372796384, 
              c[ -33][ t]], 
            Times[ 0.070907514257657775, 
              c[ -32][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -31][ t]], 
            Times[ -0.062044074975450239, 
              c[ -30][ t]], 
            Times[ -0.11423673049785436, 
              c[ -29][ t]], 
            Times[ -0.15591488063143982, 
              c[ -28][ t]], 
            Times[ -0.18675027222298593, 
              c[ -27][ t]], 
            Times[ -0.206748335783172, 
              c[ -26][ t]], 
            Times[ -0.21623620818304484, 
              c[ -25][ t]], 
            Times[ -0.21584055771952015, 
              c[ -24][ t]], 
            Times[ -0.20645618564475843, 
              c[ -23][ t]], 
            Times[ -0.18920668216016426, 
              c[ -22][ t]], 
            Times[ -0.16539866862653771, 
              c[ -21][ t]], 
            Times[ -0.13647135277833605, 
              c[ -20][ t]], 
            Times[ -0.10394325375429328, 
              c[ -19][ t]], 
            Times[ -0.06935801494512607, 
              c[ -18][ t]], 
            Times[ -0.034231213779558949, 
              c[ -17][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -16][ t]], 
            Times[ 0.032022748374425904, 
              c[ -15][ t]], 
            Times[ 0.060688263076985105, 
              c[ -14][ t]], 
            Times[ 0.085044480344421705, 
              c[ -13][ t]], 
            Times[ 0.10436044624225685, 
              c[ -12][ t]], 
            Times[ 0.11814190616181255, 
              c[ -11][ t]], 
            Times[ 0.12613778810677614, 
              c[ -10][ t]], 
            Times[ 0.12833762891430928, 
              c[ -9][ t]], 
            Times[ 0.12496032289024853, 
              c[ -8][ t]], 
            Times[ 0.11643488132933186, 
              c[ -7][ t]], 
            Times[ 0.10337416789158609, 
              c[ -6][ t]], 
            Times[ 0.086542809078944891, 
              c[ -5][ t]], 
            Times[ 0.066820663127759972, 
              c[ -4][ t]], 
            Times[ 0.045163358568919301, 
              c[ -3][ t]], 
            Times[ 0.022561481809254869, 
              c[ -2][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -1][ t]], 
            Times[ -0.021580547817547879, 
              c[ 0][ t]], 
            Times[ -0.04131966847794722, 
              c[ 1][ t]], 
            Times[ -0.058468080236789913, 
              c[ 2][ t]], 
            Times[ -0.072413370861974122, 
              c[ 3][ t]], 
            Times[ -0.082699334313268744, 
              c[ 4][ t]], 
            Times[ -0.089038438663606695, 
              c[ 5][ t]], 
            Times[ -0.091317159035181589, 
              c[ 6][ t]], 
            Times[ -0.089594193770366884, 
              c[ 7][ t]], 
            Times[ -0.084091858737850814, 
              c[ 8][ t]], 
            Times[ -0.075181213012062598, 
              c[ 9][ t]], 
            Times[ -0.063361699504227528, 
              c[ 10][ t]], 
            Times[ -0.049236278094138941, 
              c[ 11][ t]], 
            Times[ -0.033483179628681567, 
              c[ 12][ t]], 
            Times[ -0.016825511857749401, 
              c[ 13][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 14][ t]], 
            Times[ 0.016273855731265604, 
              c[ 15][ t]], 
            Times[ 0.031322974491347078, 
              c[ 16][ t]], 
            Times[ 0.044547108751839919, 
              c[ 17][ t]], 
            Times[ 0.055441487066198933, 
              c[ 18][ t]], 
            Times[ 0.063614872548668253, 
              c[ 19][ t]], 
            Times[ 0.068802429876423349, 
              c[ 20][ t]], 
            Times[ 0.070873018952678238, 
              c[ 21][ t]], 
            Times[ 0.069830768673962415, 
              c[ 22][ t]], 
            Times[ 0.065811019881796273, 
              c[ 23][ t]], 
            Times[ 0.059070953080906326, 
              c[ 24][ t]], 
            Times[ 0.049975424961080865, 
              c[ 25][ t]], 
            Times[ 0.03897872015785999, 
              c[ 26][ t]], 
            Times[ 0.026603074225527826, 
              c[ 27][ t]], 
            Times[ 0.013414935129827233, 
              c[ 28][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 29][ t]], 
            Times[ -0.013061910521147383, 
              c[ 30][ t]], 
            Times[ -0.025221096343682053, 
              c[ 31][ t]], 
            Times[ -0.035980357068793781, 
              c[ 32][ t]], 
            Times[ -0.044914622433376419, 
              c[ 33][ t]], 
            Times[ -0.05168708394579296, 
              c[ 34][ t]], 
            Times[ -0.056061239158567186, 
              c[ 35][ t]], 
            Times[ -0.057908442314993203, 
              c[ 36][ t]], 
            Times[ -0.057210750238908967, 
              c[ 37][ t]], 
            Times[ -0.054059052045761224, 
              c[ 38][ t]], 
            Times[ -0.048646667243099281, 
              c[ 39][ t]], 
            Times[ -0.041258781072520248, 
              c[ 40][ t]], 
            Times[ -0.032258251165125679, 
              c[ 41][ t]], 
            Times[ -0.022068459300722043, 
              c[ 42][ t]], 
            Times[ -0.011153991006822649, 
              c[ 43][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 44][ t]], 
            Times[ 0.010908848347331966, 
              c[ 45][ t]], 
            Times[ 0.021108961070255627, 
              c[ 46][ t]], 
            Times[ 0.030177073670601094, 
              c[ 47][ t]], 
            Times[ 0.03774739544932687, 
              c[ 48][ t]], 
            Times[ 0.043525965428036162, 
              c[ 49][ t]], 
            Times[ 0.047301670540041058, 
              c[ 50][ t]], 
            Times[ 0.04895352855494272, 
              c[ 51][ t]], 
            Times[ 0.048454002753361682, 
              c[ 52][ t]], 
            Times[ 0.045868286584282311, 
              c[ 53][ t]], 
            Times[ 0.041349667156634483, 
              c[ 54][ t]], 
            Times[ 0.035131239329076656, 
              c[ 55][ t]], 
            Times[ 0.027514390699665887, 
              c[ 56][ t]], 
            Times[ 0.018854606004500233, 
              c[ 57][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 58][ t]], 
            Times[ 2.0053370214556287*^-16, 
              c[ 59][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-45\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-45\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(3.898171832519376`*^-17\ \(c[\(-60\)]\)[t] + 
            0.0709075142576581`\ \(c[\(-59\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-58\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-57\)]\)[t] + 
            0.3225686520215219`\ \(c[\(-56\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-55\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-54\)]\)[t] + 
            0.5935615337286809`\ \(c[\(-53\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-52\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-51\)]\)[t] + 
            0.8269933431326885`\ \(c[\(-50\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-49\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-48\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-47\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-46\)]\)[t] + 
            45.41321980490211`\ \(c[\(-45\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-44\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-43\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-42\)]\)[t] + 
            0.8870637930591835`\ \(c[\(-41\)]\)[t] + 
            0.826993343132688`\ \(c[\(-40\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-39\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-38\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-37\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-36\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-35\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-34\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-33\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-32\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-31\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-30\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-29\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-28\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-27\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-26\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-25\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-24\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-23\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-22\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-21\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-20\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-19\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-18\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-17\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-16\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-15\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-14\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-13\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-12\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-11\)]\)[t] + 
            0.1181419061618126`\ \(c[\(-10\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-9\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-8\)]\)[t] + 
            0.12496032289024847`\ \(c[\(-7\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-6\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-5\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-4\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-3\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-2\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-1\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[0]\)[t] - 
            0.02158054781754788`\ \(c[1]\)[t] - 
            0.04131966847794737`\ \(c[2]\)[t] - 
            0.05846808023678991`\ \(c[3]\)[t] - 
            0.07241337086197412`\ \(c[4]\)[t] - 
            0.08269933431326881`\ \(c[5]\)[t] - 
            0.0890384386636067`\ \(c[6]\)[t] - 
            0.09131715903518159`\ \(c[7]\)[t] - 
            0.08959419377036684`\ \(c[8]\)[t] - 
            0.08409185873785081`\ \(c[9]\)[t] - 
            0.0751812130120626`\ \(c[10]\)[t] - 
            0.06336169950422753`\ \(c[11]\)[t] - 
            0.04923627809413894`\ \(c[12]\)[t] - 
            0.03348317962868157`\ \(c[13]\)[t] - 
            0.0168255118577494`\ \(c[14]\)[t] - 
            3.898171832519376`*^-17\ \(c[15]\)[t] + 
            0.016273855731265604`\ \(c[16]\)[t] + 
            0.03132297449134708`\ \(c[17]\)[t] + 
            0.04454710875183992`\ \(c[18]\)[t] + 
            0.05544148706619893`\ \(c[19]\)[t] + 
            0.06361487254866825`\ \(c[20]\)[t] + 
            0.06880242987642335`\ \(c[21]\)[t] + 
            0.07087301895267824`\ \(c[22]\)[t] + 
            0.06983076867396242`\ \(c[23]\)[t] + 
            0.06581101988179627`\ \(c[24]\)[t] + 
            0.059070953080906326`\ \(c[25]\)[t] + 
            0.049975424961080865`\ \(c[26]\)[t] + 
            0.03897872015785999`\ \(c[27]\)[t] + 
            0.026603074225527826`\ \(c[28]\)[t] + 
            0.013414935129827233`\ \(c[29]\)[t] + 
            3.898171832519376`*^-17\ \(c[30]\)[t] - 
            0.013061910521147383`\ \(c[31]\)[t] - 
            0.025221096343682053`\ \(c[32]\)[t] - 
            0.03598035706879378`\ \(c[33]\)[t] - 
            0.04491462243337642`\ \(c[34]\)[t] - 
            0.05168708394579296`\ \(c[35]\)[t] - 
            0.056061239158567186`\ \(c[36]\)[t] - 
            0.0579084423149932`\ \(c[37]\)[t] - 
            0.05721075023890897`\ \(c[38]\)[t] - 
            0.054059052045761224`\ \(c[39]\)[t] - 
            0.04864666724309928`\ \(c[40]\)[t] - 
            0.04125878107252025`\ \(c[41]\)[t] - 
            0.03225825116512552`\ \(c[42]\)[t] - 
            0.022068459300722043`\ \(c[43]\)[t] - 
            0.011153991006822649`\ \(c[44]\)[t] - 
            3.8981718325193755`*^-17\ \(c[45]\)[t] + 
            0.010908848347331966`\ \(c[46]\)[t] + 
            0.021108961070255627`\ \(c[47]\)[t] + 
            0.030177073670601236`\ \(c[48]\)[t] + 
            0.03774739544932687`\ \(c[49]\)[t] + 
            0.04352596542803616`\ \(c[50]\)[t] + 
            0.04730167054004106`\ \(c[51]\)[t] + 
            0.04895352855494272`\ \(c[52]\)[t] + 
            0.04845400275336168`\ \(c[53]\)[t] + 
            0.045868286584282256`\ \(c[54]\)[t] + 
            0.04134966715663448`\ \(c[55]\)[t] + 
            0.035131239329076656`\ \(c[56]\)[t] + 
            0.027514390699665887`\ \(c[57]\)[t] + 
            0.018854606004500233`\ \(c[58]\)[t] + 
            0.009545242303915543`\ \(c[59]\)[t] + 
            3.8981718325193755`*^-17\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -45, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -45]][ t]], 
          Plus[ 
            Times[ 3.8981718325193761*^-17, 
              c[ -60][ t]], 
            Times[ 0.070907514257658094, 
              c[ -59][ t]], 
            Times[ 0.14938649372796384, 
              c[ -58][ t]], 
            Times[ 0.23387232094715985, 
              c[ -57][ t]], 
            Times[ 0.32256865202152191, 
              c[ -56][ t]], 
            Times[ 0.41349667156634429, 
              c[ -55][ t]], 
            Times[ 0.50455115242710469, 
              c[ -54][ t]], 
            Times[ 0.59356153372868092, 
              c[ -53][ t]], 
            Times[ 0.67835603854706361, 
              c[ -52][ t]], 
            Times[ 0.75682672864065692, 
              c[ -51][ t]], 
            Times[ 0.82699334313268846, 
              c[ -50][ t]], 
            Times[ 0.88706379305918392, 
              c[ -49][ t]], 
            Times[ 0.93548928378863916, 
              c[ -48][ t]], 
            Times[ 0.9710122092317629, 
              c[ -47][ t]], 
            Times[ 0.99270519960720693, 
              c[ -46][ t]], 
            Times[ 45.413219804902113, 
              c[ -45][ t]], 
            Times[ 0.99270519960720671, 
              c[ -44][ t]], 
            Times[ 0.9710122092317629, 
              c[ -43][ t]], 
            Times[ 0.93548928378863916, 
              c[ -42][ t]], 
            Times[ 0.88706379305918348, 
              c[ -41][ t]], 
            Times[ 0.82699334313268802, 
              c[ -40][ t]], 
            Times[ 0.75682672864065692, 
              c[ -39][ t]], 
            Times[ 0.67835603854706317, 
              c[ -38][ t]], 
            Times[ 0.59356153372868015, 
              c[ -37][ t]], 
            Times[ 0.50455115242710469, 
              c[ -36][ t]], 
            Times[ 0.41349667156634395, 
              c[ -35][ t]], 
            Times[ 0.32256865202152113, 
              c[ -34][ t]], 
            Times[ 0.23387232094715985, 
              c[ -33][ t]], 
            Times[ 0.14938649372796345, 
              c[ -32][ t]], 
            Times[ 0.070907514257657456, 
              c[ -31][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -30][ t]], 
            Times[ -0.062044074975450475, 
              c[ -29][ t]], 
            Times[ -0.11423673049785459, 
              c[ -28][ t]], 
            Times[ -0.15591488063143982, 
              c[ -27][ t]], 
            Times[ -0.18675027222298607, 
              c[ -26][ t]], 
            Times[ -0.20674833578317206, 
              c[ -25][ t]], 
            Times[ -0.21623620818304484, 
              c[ -24][ t]], 
            Times[ -0.21584055771952013, 
              c[ -23][ t]], 
            Times[ -0.20645618564475834, 
              c[ -22][ t]], 
            Times[ -0.18920668216016426, 
              c[ -21][ t]], 
            Times[ -0.1653986686265376, 
              c[ -20][ t]], 
            Times[ -0.13647135277833591, 
              c[ -19][ t]], 
            Times[ -0.10394325375429328, 
              c[ -18][ t]], 
            Times[ -0.069358014945125918, 
              c[ -17][ t]], 
            Times[ -0.034231213779558796, 
              c[ -16][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -15][ t]], 
            Times[ 0.032022748374426029, 
              c[ -14][ t]], 
            Times[ 0.060688263076985223, 
              c[ -13][ t]], 
            Times[ 0.085044480344421705, 
              c[ -12][ t]], 
            Times[ 0.10436044624225692, 
              c[ -11][ t]], 
            Times[ 0.1181419061618126, 
              c[ -10][ t]], 
            Times[ 0.12613778810677614, 
              c[ -9][ t]], 
            Times[ 0.12833762891430925, 
              c[ -8][ t]], 
            Times[ 0.12496032289024847, 
              c[ -7][ t]], 
            Times[ 0.11643488132933186, 
              c[ -6][ t]], 
            Times[ 0.10337416789158609, 
              c[ -5][ t]], 
            Times[ 0.086542809078944752, 
              c[ -4][ t]], 
            Times[ 0.066820663127759972, 
              c[ -3][ t]], 
            Times[ 0.045163358568919301, 
              c[ -2][ t]], 
            Times[ 0.022561481809254675, 
              c[ -1][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 0][ t]], 
            Times[ -0.021580547817547879, 
              c[ 1][ t]], 
            Times[ -0.041319668477947373, 
              c[ 2][ t]], 
            Times[ -0.058468080236789913, 
              c[ 3][ t]], 
            Times[ -0.072413370861974122, 
              c[ 4][ t]], 
            Times[ -0.082699334313268813, 
              c[ 5][ t]], 
            Times[ -0.089038438663606695, 
              c[ 6][ t]], 
            Times[ -0.091317159035181589, 
              c[ 7][ t]], 
            Times[ -0.089594193770366842, 
              c[ 8][ t]], 
            Times[ -0.084091858737850814, 
              c[ 9][ t]], 
            Times[ -0.075181213012062598, 
              c[ 10][ t]], 
            Times[ -0.063361699504227528, 
              c[ 11][ t]], 
            Times[ -0.049236278094138941, 
              c[ 12][ t]], 
            Times[ -0.033483179628681567, 
              c[ 13][ t]], 
            Times[ -0.016825511857749401, 
              c[ 14][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 15][ t]], 
            Times[ 0.016273855731265604, 
              c[ 16][ t]], 
            Times[ 0.031322974491347078, 
              c[ 17][ t]], 
            Times[ 0.044547108751839919, 
              c[ 18][ t]], 
            Times[ 0.055441487066198933, 
              c[ 19][ t]], 
            Times[ 0.063614872548668253, 
              c[ 20][ t]], 
            Times[ 0.068802429876423349, 
              c[ 21][ t]], 
            Times[ 0.070873018952678238, 
              c[ 22][ t]], 
            Times[ 0.069830768673962415, 
              c[ 23][ t]], 
            Times[ 0.065811019881796273, 
              c[ 24][ t]], 
            Times[ 0.059070953080906326, 
              c[ 25][ t]], 
            Times[ 0.049975424961080865, 
              c[ 26][ t]], 
            Times[ 0.03897872015785999, 
              c[ 27][ t]], 
            Times[ 0.026603074225527826, 
              c[ 28][ t]], 
            Times[ 0.013414935129827233, 
              c[ 29][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 30][ t]], 
            Times[ -0.013061910521147383, 
              c[ 31][ t]], 
            Times[ -0.025221096343682053, 
              c[ 32][ t]], 
            Times[ -0.035980357068793781, 
              c[ 33][ t]], 
            Times[ -0.044914622433376419, 
              c[ 34][ t]], 
            Times[ -0.05168708394579296, 
              c[ 35][ t]], 
            Times[ -0.056061239158567186, 
              c[ 36][ t]], 
            Times[ -0.057908442314993203, 
              c[ 37][ t]], 
            Times[ -0.057210750238908967, 
              c[ 38][ t]], 
            Times[ -0.054059052045761224, 
              c[ 39][ t]], 
            Times[ -0.048646667243099281, 
              c[ 40][ t]], 
            Times[ -0.041258781072520248, 
              c[ 41][ t]], 
            Times[ -0.032258251165125519, 
              c[ 42][ t]], 
            Times[ -0.022068459300722043, 
              c[ 43][ t]], 
            Times[ -0.011153991006822649, 
              c[ 44][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 45][ t]], 
            Times[ 0.010908848347331966, 
              c[ 46][ t]], 
            Times[ 0.021108961070255627, 
              c[ 47][ t]], 
            Times[ 0.030177073670601236, 
              c[ 48][ t]], 
            Times[ 0.03774739544932687, 
              c[ 49][ t]], 
            Times[ 0.043525965428036162, 
              c[ 50][ t]], 
            Times[ 0.047301670540041058, 
              c[ 51][ t]], 
            Times[ 0.04895352855494272, 
              c[ 52][ t]], 
            Times[ 0.048454002753361682, 
              c[ 53][ t]], 
            Times[ 0.045868286584282256, 
              c[ 54][ t]], 
            Times[ 0.041349667156634483, 
              c[ 55][ t]], 
            Times[ 0.035131239329076656, 
              c[ 56][ t]], 
            Times[ 0.027514390699665887, 
              c[ 57][ t]], 
            Times[ 0.018854606004500233, 
              c[ 58][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 59][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-44\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-44\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.06204407497545072`\)\ \(c[\(-60\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-59\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-58\)]\)[t] + 
            0.14938649372796314`\ \(c[\(-57\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-56\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-55\)]\)[t] + 
            0.4134966715663436`\ \(c[\(-54\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-53\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-52\)]\)[t] + 
            0.6783560385470627`\ \(c[\(-51\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-50\)]\)[t] + 
            0.826993343132688`\ \(c[\(-49\)]\)[t] + 
            0.8870637930591835`\ \(c[\(-48\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-47\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-46\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-45\)]\)[t] + 
            43.46123137890887`\ \(c[\(-44\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-43\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-42\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-41\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-40\)]\)[t] + 
            0.8269933431326885`\ \(c[\(-39\)]\)[t] + 
            0.7568267286406574`\ \(c[\(-38\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-37\)]\)[t] + 
            0.5935615337286809`\ \(c[\(-36\)]\)[t] + 
            0.504551152427105`\ \(c[\(-35\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-34\)]\)[t] + 
            0.3225686520215219`\ \(c[\(-33\)]\)[t] + 
            0.23387232094716018`\ \(c[\(-32\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-31\)]\)[t] + 
            0.0709075142576581`\ \(c[\(-30\)]\)[t] + 
            3.216976900108398`*^-16\ \(c[\(-29\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-28\)]\)[t] - 
            0.11423673049785416`\ \(c[\(-27\)]\)[t] - 
            0.15591488063143966`\ \(c[\(-26\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-25\)]\)[t] - 
            0.2067483357831719`\ \(c[\(-24\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-23\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-22\)]\)[t] - 
            0.20645618564475848`\ \(c[\(-21\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-20\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-19\)]\)[t] - 
            0.13647135277833616`\ \(c[\(-18\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-17\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-16\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-15\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-14\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-13\)]\)[t] + 
            0.060688263076985`\ \(c[\(-12\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-11\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-10\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-9\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-8\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-7\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-6\)]\)[t] + 
            0.11643488132933195`\ \(c[\(-5\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-4\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-3\)]\)[t] + 
            0.06682066312776015`\ \(c[\(-2\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-1\)]\)[t] + 
            0.02256148180925487`\ \(c[0]\)[t] + 
            2.274590327822911`*^-16\ \(c[1]\)[t] - 
            0.02158054781754788`\ \(c[2]\)[t] - 
            0.04131966847794722`\ \(c[3]\)[t] - 
            0.058468080236789774`\ \(c[4]\)[t] - 
            0.07241337086197412`\ \(c[5]\)[t] - 
            0.08269933431326874`\ \(c[6]\)[t] - 
            0.08903843866360665`\ \(c[7]\)[t] - 
            0.09131715903518159`\ \(c[8]\)[t] - 
            0.08959419377036688`\ \(c[9]\)[t] - 
            0.08409185873785086`\ \(c[10]\)[t] - 
            0.0751812130120627`\ \(c[11]\)[t] - 
            0.06336169950422753`\ \(c[12]\)[t] - 
            0.049236278094139066`\ \(c[13]\)[t] - 
            0.033483179628681706`\ \(c[14]\)[t] - 
            0.0168255118577494`\ \(c[15]\)[t] - 
            1.8033970416801674`*^-16\ \(c[16]\)[t] + 
            0.01627385573126547`\ \(c[17]\)[t] + 
            0.03132297449134708`\ \(c[18]\)[t] + 
            0.044547108751839815`\ \(c[19]\)[t] + 
            0.055441487066198857`\ \(c[20]\)[t] + 
            0.06361487254866825`\ \(c[21]\)[t] + 
            0.06880242987642332`\ \(c[22]\)[t] + 
            0.07087301895267824`\ \(c[23]\)[t] + 
            0.06983076867396242`\ \(c[24]\)[t] + 
            0.06581101988179631`\ \(c[25]\)[t] + 
            0.0590709530809064`\ \(c[26]\)[t] + 
            0.049975424961080865`\ \(c[27]\)[t] + 
            0.03897872015786009`\ \(c[28]\)[t] + 
            0.026603074225527937`\ \(c[29]\)[t] + 
            0.013414935129827233`\ \(c[30]\)[t] + 
            1.5206810699945212`*^-16\ \(c[31]\)[t] - 
            0.013061910521147276`\ \(c[32]\)[t] - 
            0.025221096343682053`\ \(c[33]\)[t] - 
            0.03598035706879378`\ \(c[34]\)[t] - 
            0.04491462243337629`\ \(c[35]\)[t] - 
            0.05168708394579296`\ \(c[36]\)[t] - 
            0.05606123915856713`\ \(c[37]\)[t] - 
            0.0579084423149932`\ \(c[38]\)[t] - 
            0.05721075023890897`\ \(c[39]\)[t] - 
            0.054059052045761224`\ \(c[40]\)[t] - 
            0.0486466672430994`\ \(c[41]\)[t] - 
            0.04125878107252025`\ \(c[42]\)[t] - 
            0.03225825116512568`\ \(c[43]\)[t] - 
            0.022068459300722043`\ \(c[44]\)[t] - 
            0.011153991006822649`\ \(c[45]\)[t] - 
            3.8981718325193755`*^-17\ \(c[46]\)[t] + 
            0.010908848347331785`\ \(c[47]\)[t] + 
            0.021108961070255627`\ \(c[48]\)[t] + 
            0.030177073670601094`\ \(c[49]\)[t] + 
            0.03774739544932687`\ \(c[50]\)[t] + 
            0.04352596542803616`\ \(c[51]\)[t] + 
            0.04730167054004106`\ \(c[52]\)[t] + 
            0.0489535285549427`\ \(c[53]\)[t] + 
            0.04845400275336168`\ \(c[54]\)[t] + 
            0.04586828658428231`\ \(c[55]\)[t] + 
            0.04134966715663448`\ \(c[56]\)[t] + 
            0.035131239329076656`\ \(c[57]\)[t] + 
            0.027514390699665887`\ \(c[58]\)[t] + 
            0.01885460600450039`\ \(c[59]\)[t] + 
            0.009545242303915543`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -44, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -44]][ t]], 
          Plus[ 
            Times[ -0.062044074975450718, 
              c[ -60][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -59][ t]], 
            Times[ 0.070907514257657456, 
              c[ -58][ t]], 
            Times[ 0.14938649372796314, 
              c[ -57][ t]], 
            Times[ 0.23387232094715985, 
              c[ -56][ t]], 
            Times[ 0.32256865202152113, 
              c[ -55][ t]], 
            Times[ 0.41349667156634362, 
              c[ -54][ t]], 
            Times[ 0.50455115242710469, 
              c[ -53][ t]], 
            Times[ 0.59356153372868015, 
              c[ -52][ t]], 
            Times[ 0.67835603854706272, 
              c[ -51][ t]], 
            Times[ 0.75682672864065692, 
              c[ -50][ t]], 
            Times[ 0.82699334313268802, 
              c[ -49][ t]], 
            Times[ 0.88706379305918348, 
              c[ -48][ t]], 
            Times[ 0.93548928378863916, 
              c[ -47][ t]], 
            Times[ 0.9710122092317629, 
              c[ -46][ t]], 
            Times[ 0.99270519960720671, 
              c[ -45][ t]], 
            Times[ 43.46123137890887, 
              c[ -44][ t]], 
            Times[ 0.99270519960720693, 
              c[ -43][ t]], 
            Times[ 0.9710122092317629, 
              c[ -42][ t]], 
            Times[ 0.93548928378863916, 
              c[ -41][ t]], 
            Times[ 0.88706379305918392, 
              c[ -40][ t]], 
            Times[ 0.82699334313268846, 
              c[ -39][ t]], 
            Times[ 0.75682672864065736, 
              c[ -38][ t]], 
            Times[ 0.67835603854706361, 
              c[ -37][ t]], 
            Times[ 0.59356153372868092, 
              c[ -36][ t]], 
            Times[ 0.50455115242710502, 
              c[ -35][ t]], 
            Times[ 0.41349667156634429, 
              c[ -34][ t]], 
            Times[ 0.32256865202152191, 
              c[ -33][ t]], 
            Times[ 0.23387232094716018, 
              c[ -32][ t]], 
            Times[ 0.14938649372796384, 
              c[ -31][ t]], 
            Times[ 0.070907514257658094, 
              c[ -30][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ -29][ t]], 
            Times[ -0.062044074975450239, 
              c[ -28][ t]], 
            Times[ -0.11423673049785416, 
              c[ -27][ t]], 
            Times[ -0.15591488063143966, 
              c[ -26][ t]], 
            Times[ -0.18675027222298593, 
              c[ -25][ t]], 
            Times[ -0.20674833578317189, 
              c[ -24][ t]], 
            Times[ -0.21623620818304481, 
              c[ -23][ t]], 
            Times[ -0.21584055771952015, 
              c[ -22][ t]], 
            Times[ -0.20645618564475848, 
              c[ -21][ t]], 
            Times[ -0.18920668216016434, 
              c[ -20][ t]], 
            Times[ -0.16539866862653771, 
              c[ -19][ t]], 
            Times[ -0.13647135277833616, 
              c[ -18][ t]], 
            Times[ -0.1039432537542934, 
              c[ -17][ t]], 
            Times[ -0.06935801494512607, 
              c[ -16][ t]], 
            Times[ -0.034231213779559094, 
              c[ -15][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -14][ t]], 
            Times[ 0.032022748374425904, 
              c[ -13][ t]], 
            Times[ 0.060688263076985001, 
              c[ -12][ t]], 
            Times[ 0.085044480344421608, 
              c[ -11][ t]], 
            Times[ 0.10436044624225685, 
              c[ -10][ t]], 
            Times[ 0.11814190616181253, 
              c[ -9][ t]], 
            Times[ 0.12613778810677612, 
              c[ -8][ t]], 
            Times[ 0.12833762891430928, 
              c[ -7][ t]], 
            Times[ 0.12496032289024853, 
              c[ -6][ t]], 
            Times[ 0.11643488132933195, 
              c[ -5][ t]], 
            Times[ 0.10337416789158609, 
              c[ -4][ t]], 
            Times[ 0.086542809078944891, 
              c[ -3][ t]], 
            Times[ 0.066820663127760152, 
              c[ -2][ t]], 
            Times[ 0.045163358568919301, 
              c[ -1][ t]], 
            Times[ 0.022561481809254869, 
              c[ 0][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ 1][ t]], 
            Times[ -0.021580547817547879, 
              c[ 2][ t]], 
            Times[ -0.04131966847794722, 
              c[ 3][ t]], 
            Times[ -0.058468080236789774, 
              c[ 4][ t]], 
            Times[ -0.072413370861974122, 
              c[ 5][ t]], 
            Times[ -0.082699334313268744, 
              c[ 6][ t]], 
            Times[ -0.089038438663606653, 
              c[ 7][ t]], 
            Times[ -0.091317159035181589, 
              c[ 8][ t]], 
            Times[ -0.089594193770366884, 
              c[ 9][ t]], 
            Times[ -0.084091858737850855, 
              c[ 10][ t]], 
            Times[ -0.075181213012062695, 
              c[ 11][ t]], 
            Times[ -0.063361699504227528, 
              c[ 12][ t]], 
            Times[ -0.049236278094139066, 
              c[ 13][ t]], 
            Times[ -0.033483179628681706, 
              c[ 14][ t]], 
            Times[ -0.016825511857749401, 
              c[ 15][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 16][ t]], 
            Times[ 0.016273855731265469, 
              c[ 17][ t]], 
            Times[ 0.031322974491347078, 
              c[ 18][ t]], 
            Times[ 0.044547108751839815, 
              c[ 19][ t]], 
            Times[ 0.055441487066198857, 
              c[ 20][ t]], 
            Times[ 0.063614872548668253, 
              c[ 21][ t]], 
            Times[ 0.068802429876423321, 
              c[ 22][ t]], 
            Times[ 0.070873018952678238, 
              c[ 23][ t]], 
            Times[ 0.069830768673962415, 
              c[ 24][ t]], 
            Times[ 0.065811019881796315, 
              c[ 25][ t]], 
            Times[ 0.059070953080906402, 
              c[ 26][ t]], 
            Times[ 0.049975424961080865, 
              c[ 27][ t]], 
            Times[ 0.038978720157860088, 
              c[ 28][ t]], 
            Times[ 0.026603074225527937, 
              c[ 29][ t]], 
            Times[ 0.013414935129827233, 
              c[ 30][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ 31][ t]], 
            Times[ -0.013061910521147276, 
              c[ 32][ t]], 
            Times[ -0.025221096343682053, 
              c[ 33][ t]], 
            Times[ -0.035980357068793781, 
              c[ 34][ t]], 
            Times[ -0.044914622433376288, 
              c[ 35][ t]], 
            Times[ -0.05168708394579296, 
              c[ 36][ t]], 
            Times[ -0.05606123915856713, 
              c[ 37][ t]], 
            Times[ -0.057908442314993203, 
              c[ 38][ t]], 
            Times[ -0.057210750238908967, 
              c[ 39][ t]], 
            Times[ -0.054059052045761224, 
              c[ 40][ t]], 
            Times[ -0.048646667243099399, 
              c[ 41][ t]], 
            Times[ -0.041258781072520248, 
              c[ 42][ t]], 
            Times[ -0.032258251165125679, 
              c[ 43][ t]], 
            Times[ -0.022068459300722043, 
              c[ 44][ t]], 
            Times[ -0.011153991006822649, 
              c[ 45][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 46][ t]], 
            Times[ 0.010908848347331785, 
              c[ 47][ t]], 
            Times[ 0.021108961070255627, 
              c[ 48][ t]], 
            Times[ 0.030177073670601094, 
              c[ 49][ t]], 
            Times[ 0.03774739544932687, 
              c[ 50][ t]], 
            Times[ 0.043525965428036162, 
              c[ 51][ t]], 
            Times[ 0.047301670540041058, 
              c[ 52][ t]], 
            Times[ 0.048953528554942699, 
              c[ 53][ t]], 
            Times[ 0.048454002753361682, 
              c[ 54][ t]], 
            Times[ 0.045868286584282311, 
              c[ 55][ t]], 
            Times[ 0.041349667156634483, 
              c[ 56][ t]], 
            Times[ 0.035131239329076656, 
              c[ 57][ t]], 
            Times[ 0.027514390699665887, 
              c[ 58][ t]], 
            Times[ 0.018854606004500389, 
              c[ 59][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-43\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-43\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.11423673049785459`\)\ \(c[\(-60\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-59\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-58\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-57\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-56\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-55\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-54\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-53\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-52\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-51\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-50\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-49\)]\)[t] + 
            0.826993343132688`\ \(c[\(-48\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-47\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-46\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-45\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-44\)]\)[t] + 
            41.553107861364936`\ \(c[\(-43\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-42\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-41\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-40\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-39\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-38\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-37\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-36\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-35\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-34\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-33\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-32\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-31\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-30\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-29\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-28\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-27\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-26\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-25\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-24\)]\)[t] - 
            0.206748335783172`\ \(c[\(-23\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-22\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-21\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-20\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-19\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-18\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-17\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-16\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-15\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-14\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-13\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-12\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-11\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-10\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-9\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-8\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-7\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-6\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-5\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-4\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-3\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-2\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-1\)]\)[t] + 
            0.0451633585689193`\ \(c[0]\)[t] + 
            0.02256148180925487`\ \(c[1]\)[t] + 
            3.8981718325193755`*^-17\ \(c[2]\)[t] - 
            0.02158054781754788`\ \(c[3]\)[t] - 
            0.04131966847794722`\ \(c[4]\)[t] - 
            0.05846808023678991`\ \(c[5]\)[t] - 
            0.07241337086197412`\ \(c[6]\)[t] - 
            0.08269933431326874`\ \(c[7]\)[t] - 
            0.0890384386636067`\ \(c[8]\)[t] - 
            0.09131715903518159`\ \(c[9]\)[t] - 
            0.08959419377036688`\ \(c[10]\)[t] - 
            0.08409185873785081`\ \(c[11]\)[t] - 
            0.0751812130120626`\ \(c[12]\)[t] - 
            0.06336169950422753`\ \(c[13]\)[t] - 
            0.04923627809413894`\ \(c[14]\)[t] - 
            0.03348317962868157`\ \(c[15]\)[t] - 
            0.0168255118577494`\ \(c[16]\)[t] - 
            3.898171832519376`*^-17\ \(c[17]\)[t] + 
            0.016273855731265604`\ \(c[18]\)[t] + 
            0.03132297449134708`\ \(c[19]\)[t] + 
            0.04454710875183992`\ \(c[20]\)[t] + 
            0.05544148706619893`\ \(c[21]\)[t] + 
            0.06361487254866825`\ \(c[22]\)[t] + 
            0.06880242987642335`\ \(c[23]\)[t] + 
            0.07087301895267824`\ \(c[24]\)[t] + 
            0.06983076867396242`\ \(c[25]\)[t] + 
            0.06581101988179627`\ \(c[26]\)[t] + 
            0.059070953080906326`\ \(c[27]\)[t] + 
            0.049975424961080865`\ \(c[28]\)[t] + 
            0.03897872015785999`\ \(c[29]\)[t] + 
            0.026603074225527826`\ \(c[30]\)[t] + 
            0.013414935129827233`\ \(c[31]\)[t] + 
            3.898171832519376`*^-17\ \(c[32]\)[t] - 
            0.013061910521147383`\ \(c[33]\)[t] - 
            0.025221096343682053`\ \(c[34]\)[t] - 
            0.03598035706879378`\ \(c[35]\)[t] - 
            0.04491462243337642`\ \(c[36]\)[t] - 
            0.05168708394579296`\ \(c[37]\)[t] - 
            0.056061239158567186`\ \(c[38]\)[t] - 
            0.0579084423149932`\ \(c[39]\)[t] - 
            0.05721075023890897`\ \(c[40]\)[t] - 
            0.054059052045761224`\ \(c[41]\)[t] - 
            0.04864666724309928`\ \(c[42]\)[t] - 
            0.04125878107252025`\ \(c[43]\)[t] - 
            0.03225825116512568`\ \(c[44]\)[t] - 
            0.022068459300722043`\ \(c[45]\)[t] - 
            0.011153991006822649`\ \(c[46]\)[t] - 
            3.8981718325193755`*^-17\ \(c[47]\)[t] + 
            0.010908848347331966`\ \(c[48]\)[t] + 
            0.021108961070255627`\ \(c[49]\)[t] + 
            0.030177073670601094`\ \(c[50]\)[t] + 
            0.03774739544932687`\ \(c[51]\)[t] + 
            0.04352596542803616`\ \(c[52]\)[t] + 
            0.04730167054004106`\ \(c[53]\)[t] + 
            0.04895352855494272`\ \(c[54]\)[t] + 
            0.04845400275336168`\ \(c[55]\)[t] + 
            0.04586828658428231`\ \(c[56]\)[t] + 
            0.04134966715663448`\ \(c[57]\)[t] + 
            0.035131239329076656`\ \(c[58]\)[t] + 
            0.027514390699665887`\ \(c[59]\)[t] + 
            0.018854606004500233`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -43, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -43]][ t]], 
          Plus[ 
            Times[ -0.11423673049785459, 
              c[ -60][ t]], 
            Times[ -0.062044074975450239, 
              c[ -59][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -58][ t]], 
            Times[ 0.070907514257657456, 
              c[ -57][ t]], 
            Times[ 0.14938649372796384, 
              c[ -56][ t]], 
            Times[ 0.23387232094715985, 
              c[ -55][ t]], 
            Times[ 0.32256865202152113, 
              c[ -54][ t]], 
            Times[ 0.41349667156634429, 
              c[ -53][ t]], 
            Times[ 0.50455115242710469, 
              c[ -52][ t]], 
            Times[ 0.59356153372868015, 
              c[ -51][ t]], 
            Times[ 0.67835603854706361, 
              c[ -50][ t]], 
            Times[ 0.75682672864065692, 
              c[ -49][ t]], 
            Times[ 0.82699334313268802, 
              c[ -48][ t]], 
            Times[ 0.88706379305918392, 
              c[ -47][ t]], 
            Times[ 0.93548928378863916, 
              c[ -46][ t]], 
            Times[ 0.9710122092317629, 
              c[ -45][ t]], 
            Times[ 0.99270519960720693, 
              c[ -44][ t]], 
            Times[ 41.553107861364936, 
              c[ -43][ t]], 
            Times[ 0.99270519960720693, 
              c[ -42][ t]], 
            Times[ 0.9710122092317629, 
              c[ -41][ t]], 
            Times[ 0.93548928378863916, 
              c[ -40][ t]], 
            Times[ 0.88706379305918392, 
              c[ -39][ t]], 
            Times[ 0.82699334313268813, 
              c[ -38][ t]], 
            Times[ 0.75682672864065692, 
              c[ -37][ t]], 
            Times[ 0.67835603854706361, 
              c[ -36][ t]], 
            Times[ 0.59356153372868059, 
              c[ -35][ t]], 
            Times[ 0.50455115242710469, 
              c[ -34][ t]], 
            Times[ 0.41349667156634429, 
              c[ -33][ t]], 
            Times[ 0.32256865202152157, 
              c[ -32][ t]], 
            Times[ 0.23387232094715985, 
              c[ -31][ t]], 
            Times[ 0.14938649372796384, 
              c[ -30][ t]], 
            Times[ 0.070907514257657775, 
              c[ -29][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -28][ t]], 
            Times[ -0.062044074975450239, 
              c[ -27][ t]], 
            Times[ -0.11423673049785436, 
              c[ -26][ t]], 
            Times[ -0.15591488063143982, 
              c[ -25][ t]], 
            Times[ -0.18675027222298593, 
              c[ -24][ t]], 
            Times[ -0.206748335783172, 
              c[ -23][ t]], 
            Times[ -0.21623620818304484, 
              c[ -22][ t]], 
            Times[ -0.21584055771952015, 
              c[ -21][ t]], 
            Times[ -0.20645618564475843, 
              c[ -20][ t]], 
            Times[ -0.18920668216016426, 
              c[ -19][ t]], 
            Times[ -0.16539866862653771, 
              c[ -18][ t]], 
            Times[ -0.13647135277833605, 
              c[ -17][ t]], 
            Times[ -0.10394325375429328, 
              c[ -16][ t]], 
            Times[ -0.06935801494512607, 
              c[ -15][ t]], 
            Times[ -0.034231213779558949, 
              c[ -14][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -13][ t]], 
            Times[ 0.032022748374425904, 
              c[ -12][ t]], 
            Times[ 0.060688263076985105, 
              c[ -11][ t]], 
            Times[ 0.085044480344421705, 
              c[ -10][ t]], 
            Times[ 0.10436044624225685, 
              c[ -9][ t]], 
            Times[ 0.11814190616181255, 
              c[ -8][ t]], 
            Times[ 0.12613778810677614, 
              c[ -7][ t]], 
            Times[ 0.12833762891430928, 
              c[ -6][ t]], 
            Times[ 0.12496032289024853, 
              c[ -5][ t]], 
            Times[ 0.11643488132933186, 
              c[ -4][ t]], 
            Times[ 0.10337416789158609, 
              c[ -3][ t]], 
            Times[ 0.086542809078944891, 
              c[ -2][ t]], 
            Times[ 0.066820663127759972, 
              c[ -1][ t]], 
            Times[ 0.045163358568919301, 
              c[ 0][ t]], 
            Times[ 0.022561481809254869, 
              c[ 1][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 2][ t]], 
            Times[ -0.021580547817547879, 
              c[ 3][ t]], 
            Times[ -0.04131966847794722, 
              c[ 4][ t]], 
            Times[ -0.058468080236789913, 
              c[ 5][ t]], 
            Times[ -0.072413370861974122, 
              c[ 6][ t]], 
            Times[ -0.082699334313268744, 
              c[ 7][ t]], 
            Times[ -0.089038438663606695, 
              c[ 8][ t]], 
            Times[ -0.091317159035181589, 
              c[ 9][ t]], 
            Times[ -0.089594193770366884, 
              c[ 10][ t]], 
            Times[ -0.084091858737850814, 
              c[ 11][ t]], 
            Times[ -0.075181213012062598, 
              c[ 12][ t]], 
            Times[ -0.063361699504227528, 
              c[ 13][ t]], 
            Times[ -0.049236278094138941, 
              c[ 14][ t]], 
            Times[ -0.033483179628681567, 
              c[ 15][ t]], 
            Times[ -0.016825511857749401, 
              c[ 16][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 17][ t]], 
            Times[ 0.016273855731265604, 
              c[ 18][ t]], 
            Times[ 0.031322974491347078, 
              c[ 19][ t]], 
            Times[ 0.044547108751839919, 
              c[ 20][ t]], 
            Times[ 0.055441487066198933, 
              c[ 21][ t]], 
            Times[ 0.063614872548668253, 
              c[ 22][ t]], 
            Times[ 0.068802429876423349, 
              c[ 23][ t]], 
            Times[ 0.070873018952678238, 
              c[ 24][ t]], 
            Times[ 0.069830768673962415, 
              c[ 25][ t]], 
            Times[ 0.065811019881796273, 
              c[ 26][ t]], 
            Times[ 0.059070953080906326, 
              c[ 27][ t]], 
            Times[ 0.049975424961080865, 
              c[ 28][ t]], 
            Times[ 0.03897872015785999, 
              c[ 29][ t]], 
            Times[ 0.026603074225527826, 
              c[ 30][ t]], 
            Times[ 0.013414935129827233, 
              c[ 31][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 32][ t]], 
            Times[ -0.013061910521147383, 
              c[ 33][ t]], 
            Times[ -0.025221096343682053, 
              c[ 34][ t]], 
            Times[ -0.035980357068793781, 
              c[ 35][ t]], 
            Times[ -0.044914622433376419, 
              c[ 36][ t]], 
            Times[ -0.05168708394579296, 
              c[ 37][ t]], 
            Times[ -0.056061239158567186, 
              c[ 38][ t]], 
            Times[ -0.057908442314993203, 
              c[ 39][ t]], 
            Times[ -0.057210750238908967, 
              c[ 40][ t]], 
            Times[ -0.054059052045761224, 
              c[ 41][ t]], 
            Times[ -0.048646667243099281, 
              c[ 42][ t]], 
            Times[ -0.041258781072520248, 
              c[ 43][ t]], 
            Times[ -0.032258251165125679, 
              c[ 44][ t]], 
            Times[ -0.022068459300722043, 
              c[ 45][ t]], 
            Times[ -0.011153991006822649, 
              c[ 46][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 47][ t]], 
            Times[ 0.010908848347331966, 
              c[ 48][ t]], 
            Times[ 0.021108961070255627, 
              c[ 49][ t]], 
            Times[ 0.030177073670601094, 
              c[ 50][ t]], 
            Times[ 0.03774739544932687, 
              c[ 51][ t]], 
            Times[ 0.043525965428036162, 
              c[ 52][ t]], 
            Times[ 0.047301670540041058, 
              c[ 53][ t]], 
            Times[ 0.04895352855494272, 
              c[ 54][ t]], 
            Times[ 0.048454002753361682, 
              c[ 55][ t]], 
            Times[ 0.045868286584282311, 
              c[ 56][ t]], 
            Times[ 0.041349667156634483, 
              c[ 57][ t]], 
            Times[ 0.035131239329076656, 
              c[ 58][ t]], 
            Times[ 0.027514390699665887, 
              c[ 59][ t]], 
            Times[ 0.018854606004500233, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-42\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-42\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.15591488063143982`\)\ \(c[\(-60\)]\)[t] - 
            0.11423673049785416`\ \(c[\(-59\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-58\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-57\)]\)[t] + 
            0.0709075142576581`\ \(c[\(-56\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-55\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-54\)]\)[t] + 
            0.3225686520215219`\ \(c[\(-53\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-52\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-51\)]\)[t] + 
            0.5935615337286809`\ \(c[\(-50\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-49\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-48\)]\)[t] + 
            0.8269933431326885`\ \(c[\(-47\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-46\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-45\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-44\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-43\)]\)[t] + 
            39.68884925227028`\ \(c[\(-42\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-41\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-40\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-39\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-38\)]\)[t] + 
            0.826993343132688`\ \(c[\(-37\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-36\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-35\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-34\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-33\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-32\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-31\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-30\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-29\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-28\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-27\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-26\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-25\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-24\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-23\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-22\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-21\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-20\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-19\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-18\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-17\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-16\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-15\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-14\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-13\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-12\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-11\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-10\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-9\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-8\)]\)[t] + 
            0.1181419061618126`\ \(c[\(-7\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-6\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-5\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-4\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-3\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-2\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-1\)]\)[t] + 
            0.06682066312775997`\ \(c[0]\)[t] + 
            0.0451633585689193`\ \(c[1]\)[t] + 
            0.022561481809254675`\ \(c[2]\)[t] + 
            3.8981718325193755`*^-17\ \(c[3]\)[t] - 
            0.02158054781754788`\ \(c[4]\)[t] - 
            0.04131966847794737`\ \(c[5]\)[t] - 
            0.05846808023678991`\ \(c[6]\)[t] - 
            0.07241337086197412`\ \(c[7]\)[t] - 
            0.08269933431326881`\ \(c[8]\)[t] - 
            0.0890384386636067`\ \(c[9]\)[t] - 
            0.09131715903518159`\ \(c[10]\)[t] - 
            0.08959419377036688`\ \(c[11]\)[t] - 
            0.08409185873785081`\ \(c[12]\)[t] - 
            0.0751812130120626`\ \(c[13]\)[t] - 
            0.06336169950422753`\ \(c[14]\)[t] - 
            0.04923627809413894`\ \(c[15]\)[t] - 
            0.03348317962868157`\ \(c[16]\)[t] - 
            0.0168255118577494`\ \(c[17]\)[t] - 
            3.898171832519376`*^-17\ \(c[18]\)[t] + 
            0.016273855731265604`\ \(c[19]\)[t] + 
            0.03132297449134708`\ \(c[20]\)[t] + 
            0.04454710875183992`\ \(c[21]\)[t] + 
            0.05544148706619893`\ \(c[22]\)[t] + 
            0.06361487254866825`\ \(c[23]\)[t] + 
            0.06880242987642335`\ \(c[24]\)[t] + 
            0.07087301895267824`\ \(c[25]\)[t] + 
            0.06983076867396242`\ \(c[26]\)[t] + 
            0.06581101988179627`\ \(c[27]\)[t] + 
            0.059070953080906326`\ \(c[28]\)[t] + 
            0.049975424961080865`\ \(c[29]\)[t] + 
            0.03897872015785999`\ \(c[30]\)[t] + 
            0.026603074225527826`\ \(c[31]\)[t] + 
            0.013414935129827233`\ \(c[32]\)[t] + 
            3.898171832519376`*^-17\ \(c[33]\)[t] - 
            0.013061910521147383`\ \(c[34]\)[t] - 
            0.025221096343682053`\ \(c[35]\)[t] - 
            0.03598035706879378`\ \(c[36]\)[t] - 
            0.04491462243337642`\ \(c[37]\)[t] - 
            0.05168708394579296`\ \(c[38]\)[t] - 
            0.056061239158567186`\ \(c[39]\)[t] - 
            0.0579084423149932`\ \(c[40]\)[t] - 
            0.05721075023890897`\ \(c[41]\)[t] - 
            0.054059052045761224`\ \(c[42]\)[t] - 
            0.04864666724309928`\ \(c[43]\)[t] - 
            0.04125878107252025`\ \(c[44]\)[t] - 
            0.03225825116512552`\ \(c[45]\)[t] - 
            0.022068459300722043`\ \(c[46]\)[t] - 
            0.011153991006822649`\ \(c[47]\)[t] - 
            3.8981718325193755`*^-17\ \(c[48]\)[t] + 
            0.010908848347331966`\ \(c[49]\)[t] + 
            0.021108961070255627`\ \(c[50]\)[t] + 
            0.030177073670601236`\ \(c[51]\)[t] + 
            0.03774739544932687`\ \(c[52]\)[t] + 
            0.04352596542803616`\ \(c[53]\)[t] + 
            0.04730167054004106`\ \(c[54]\)[t] + 
            0.04895352855494272`\ \(c[55]\)[t] + 
            0.04845400275336168`\ \(c[56]\)[t] + 
            0.045868286584282256`\ \(c[57]\)[t] + 
            0.04134966715663448`\ \(c[58]\)[t] + 
            0.035131239329076656`\ \(c[59]\)[t] + 
            0.027514390699665887`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -42, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -42]][ t]], 
          Plus[ 
            Times[ -0.15591488063143982, 
              c[ -60][ t]], 
            Times[ -0.11423673049785416, 
              c[ -59][ t]], 
            Times[ -0.062044074975450239, 
              c[ -58][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -57][ t]], 
            Times[ 0.070907514257658094, 
              c[ -56][ t]], 
            Times[ 0.14938649372796384, 
              c[ -55][ t]], 
            Times[ 0.23387232094715985, 
              c[ -54][ t]], 
            Times[ 0.32256865202152191, 
              c[ -53][ t]], 
            Times[ 0.41349667156634429, 
              c[ -52][ t]], 
            Times[ 0.50455115242710469, 
              c[ -51][ t]], 
            Times[ 0.59356153372868092, 
              c[ -50][ t]], 
            Times[ 0.67835603854706361, 
              c[ -49][ t]], 
            Times[ 0.75682672864065692, 
              c[ -48][ t]], 
            Times[ 0.82699334313268846, 
              c[ -47][ t]], 
            Times[ 0.88706379305918392, 
              c[ -46][ t]], 
            Times[ 0.93548928378863916, 
              c[ -45][ t]], 
            Times[ 0.9710122092317629, 
              c[ -44][ t]], 
            Times[ 0.99270519960720693, 
              c[ -43][ t]], 
            Times[ 39.68884925227028, 
              c[ -42][ t]], 
            Times[ 0.99270519960720671, 
              c[ -41][ t]], 
            Times[ 0.9710122092317629, 
              c[ -40][ t]], 
            Times[ 0.93548928378863916, 
              c[ -39][ t]], 
            Times[ 0.88706379305918381, 
              c[ -38][ t]], 
            Times[ 0.82699334313268802, 
              c[ -37][ t]], 
            Times[ 0.75682672864065692, 
              c[ -36][ t]], 
            Times[ 0.67835603854706317, 
              c[ -35][ t]], 
            Times[ 0.59356153372868015, 
              c[ -34][ t]], 
            Times[ 0.50455115242710469, 
              c[ -33][ t]], 
            Times[ 0.41349667156634395, 
              c[ -32][ t]], 
            Times[ 0.32256865202152113, 
              c[ -31][ t]], 
            Times[ 0.23387232094715985, 
              c[ -30][ t]], 
            Times[ 0.14938649372796345, 
              c[ -29][ t]], 
            Times[ 0.070907514257657456, 
              c[ -28][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -27][ t]], 
            Times[ -0.062044074975450475, 
              c[ -26][ t]], 
            Times[ -0.11423673049785459, 
              c[ -25][ t]], 
            Times[ -0.15591488063143982, 
              c[ -24][ t]], 
            Times[ -0.18675027222298607, 
              c[ -23][ t]], 
            Times[ -0.20674833578317206, 
              c[ -22][ t]], 
            Times[ -0.21623620818304484, 
              c[ -21][ t]], 
            Times[ -0.21584055771952013, 
              c[ -20][ t]], 
            Times[ -0.20645618564475834, 
              c[ -19][ t]], 
            Times[ -0.18920668216016426, 
              c[ -18][ t]], 
            Times[ -0.1653986686265376, 
              c[ -17][ t]], 
            Times[ -0.13647135277833591, 
              c[ -16][ t]], 
            Times[ -0.10394325375429328, 
              c[ -15][ t]], 
            Times[ -0.069358014945125918, 
              c[ -14][ t]], 
            Times[ -0.034231213779558796, 
              c[ -13][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -12][ t]], 
            Times[ 0.032022748374426029, 
              c[ -11][ t]], 
            Times[ 0.060688263076985223, 
              c[ -10][ t]], 
            Times[ 0.085044480344421705, 
              c[ -9][ t]], 
            Times[ 0.10436044624225692, 
              c[ -8][ t]], 
            Times[ 0.1181419061618126, 
              c[ -7][ t]], 
            Times[ 0.12613778810677614, 
              c[ -6][ t]], 
            Times[ 0.12833762891430925, 
              c[ -5][ t]], 
            Times[ 0.12496032289024853, 
              c[ -4][ t]], 
            Times[ 0.11643488132933186, 
              c[ -3][ t]], 
            Times[ 0.10337416789158609, 
              c[ -2][ t]], 
            Times[ 0.086542809078944752, 
              c[ -1][ t]], 
            Times[ 0.066820663127759972, 
              c[ 0][ t]], 
            Times[ 0.045163358568919301, 
              c[ 1][ t]], 
            Times[ 0.022561481809254675, 
              c[ 2][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 3][ t]], 
            Times[ -0.021580547817547879, 
              c[ 4][ t]], 
            Times[ -0.041319668477947373, 
              c[ 5][ t]], 
            Times[ -0.058468080236789913, 
              c[ 6][ t]], 
            Times[ -0.072413370861974122, 
              c[ 7][ t]], 
            Times[ -0.082699334313268813, 
              c[ 8][ t]], 
            Times[ -0.089038438663606695, 
              c[ 9][ t]], 
            Times[ -0.091317159035181589, 
              c[ 10][ t]], 
            Times[ -0.089594193770366884, 
              c[ 11][ t]], 
            Times[ -0.084091858737850814, 
              c[ 12][ t]], 
            Times[ -0.075181213012062598, 
              c[ 13][ t]], 
            Times[ -0.063361699504227528, 
              c[ 14][ t]], 
            Times[ -0.049236278094138941, 
              c[ 15][ t]], 
            Times[ -0.033483179628681567, 
              c[ 16][ t]], 
            Times[ -0.016825511857749401, 
              c[ 17][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 18][ t]], 
            Times[ 0.016273855731265604, 
              c[ 19][ t]], 
            Times[ 0.031322974491347078, 
              c[ 20][ t]], 
            Times[ 0.044547108751839919, 
              c[ 21][ t]], 
            Times[ 0.055441487066198933, 
              c[ 22][ t]], 
            Times[ 0.063614872548668253, 
              c[ 23][ t]], 
            Times[ 0.068802429876423349, 
              c[ 24][ t]], 
            Times[ 0.070873018952678238, 
              c[ 25][ t]], 
            Times[ 0.069830768673962415, 
              c[ 26][ t]], 
            Times[ 0.065811019881796273, 
              c[ 27][ t]], 
            Times[ 0.059070953080906326, 
              c[ 28][ t]], 
            Times[ 0.049975424961080865, 
              c[ 29][ t]], 
            Times[ 0.03897872015785999, 
              c[ 30][ t]], 
            Times[ 0.026603074225527826, 
              c[ 31][ t]], 
            Times[ 0.013414935129827233, 
              c[ 32][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 33][ t]], 
            Times[ -0.013061910521147383, 
              c[ 34][ t]], 
            Times[ -0.025221096343682053, 
              c[ 35][ t]], 
            Times[ -0.035980357068793781, 
              c[ 36][ t]], 
            Times[ -0.044914622433376419, 
              c[ 37][ t]], 
            Times[ -0.05168708394579296, 
              c[ 38][ t]], 
            Times[ -0.056061239158567186, 
              c[ 39][ t]], 
            Times[ -0.057908442314993203, 
              c[ 40][ t]], 
            Times[ -0.057210750238908967, 
              c[ 41][ t]], 
            Times[ -0.054059052045761224, 
              c[ 42][ t]], 
            Times[ -0.048646667243099281, 
              c[ 43][ t]], 
            Times[ -0.041258781072520248, 
              c[ 44][ t]], 
            Times[ -0.032258251165125519, 
              c[ 45][ t]], 
            Times[ -0.022068459300722043, 
              c[ 46][ t]], 
            Times[ -0.011153991006822649, 
              c[ 47][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 48][ t]], 
            Times[ 0.010908848347331966, 
              c[ 49][ t]], 
            Times[ 0.021108961070255627, 
              c[ 50][ t]], 
            Times[ 0.030177073670601236, 
              c[ 51][ t]], 
            Times[ 0.03774739544932687, 
              c[ 52][ t]], 
            Times[ 0.043525965428036162, 
              c[ 53][ t]], 
            Times[ 0.047301670540041058, 
              c[ 54][ t]], 
            Times[ 0.04895352855494272, 
              c[ 55][ t]], 
            Times[ 0.048454002753361682, 
              c[ 56][ t]], 
            Times[ 0.045868286584282256, 
              c[ 57][ t]], 
            Times[ 0.041349667156634483, 
              c[ 58][ t]], 
            Times[ 0.035131239329076656, 
              c[ 59][ t]], 
            Times[ 0.027514390699665887, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-41\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-41\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.18675027222298618`\)\ \(c[\(-60\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-59\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-58\)]\)[t] - 
            0.06204407497545072`\ \(c[\(-57\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-56\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-55\)]\)[t] + 
            0.14938649372796314`\ \(c[\(-54\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-53\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-52\)]\)[t] + 
            0.4134966715663436`\ \(c[\(-51\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-50\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-49\)]\)[t] + 
            0.6783560385470627`\ \(c[\(-48\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-47\)]\)[t] + 
            0.826993343132688`\ \(c[\(-46\)]\)[t] + 
            0.8870637930591835`\ \(c[\(-45\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-44\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-43\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-42\)]\)[t] + 
            37.868455551624905`\ \(c[\(-41\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-40\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-39\)]\)[t] + 
            0.9354892837886393`\ \(c[\(-38\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-37\)]\)[t] + 
            0.8269933431326885`\ \(c[\(-36\)]\)[t] + 
            0.7568267286406574`\ \(c[\(-35\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-34\)]\)[t] + 
            0.5935615337286809`\ \(c[\(-33\)]\)[t] + 
            0.504551152427105`\ \(c[\(-32\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-31\)]\)[t] + 
            0.3225686520215219`\ \(c[\(-30\)]\)[t] + 
            0.23387232094716018`\ \(c[\(-29\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-28\)]\)[t] + 
            0.0709075142576581`\ \(c[\(-27\)]\)[t] + 
            3.216976900108398`*^-16\ \(c[\(-26\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-25\)]\)[t] - 
            0.11423673049785416`\ \(c[\(-24\)]\)[t] - 
            0.15591488063143966`\ \(c[\(-23\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-22\)]\)[t] - 
            0.2067483357831719`\ \(c[\(-21\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-20\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-19\)]\)[t] - 
            0.20645618564475848`\ \(c[\(-18\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-17\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-16\)]\)[t] - 
            0.13647135277833616`\ \(c[\(-15\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-14\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-13\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-12\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-11\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-10\)]\)[t] + 
            0.060688263076985`\ \(c[\(-9\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-8\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-7\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-6\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-5\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-4\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-3\)]\)[t] + 
            0.11643488132933195`\ \(c[\(-2\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-1\)]\)[t] + 
            0.08654280907894489`\ \(c[0]\)[t] + 
            0.06682066312776015`\ \(c[1]\)[t] + 
            0.0451633585689193`\ \(c[2]\)[t] + 
            0.02256148180925487`\ \(c[3]\)[t] + 
            2.274590327822911`*^-16\ \(c[4]\)[t] - 
            0.02158054781754788`\ \(c[5]\)[t] - 
            0.04131966847794722`\ \(c[6]\)[t] - 
            0.058468080236789774`\ \(c[7]\)[t] - 
            0.07241337086197412`\ \(c[8]\)[t] - 
            0.08269933431326874`\ \(c[9]\)[t] - 
            0.08903843866360665`\ \(c[10]\)[t] - 
            0.0913171590351816`\ \(c[11]\)[t] - 
            0.08959419377036688`\ \(c[12]\)[t] - 
            0.08409185873785086`\ \(c[13]\)[t] - 
            0.0751812130120627`\ \(c[14]\)[t] - 
            0.06336169950422753`\ \(c[15]\)[t] - 
            0.049236278094139066`\ \(c[16]\)[t] - 
            0.033483179628681706`\ \(c[17]\)[t] - 
            0.0168255118577494`\ \(c[18]\)[t] - 
            1.8033970416801674`*^-16\ \(c[19]\)[t] + 
            0.01627385573126547`\ \(c[20]\)[t] + 
            0.03132297449134708`\ \(c[21]\)[t] + 
            0.044547108751839815`\ \(c[22]\)[t] + 
            0.055441487066198857`\ \(c[23]\)[t] + 
            0.06361487254866825`\ \(c[24]\)[t] + 
            0.06880242987642332`\ \(c[25]\)[t] + 
            0.07087301895267824`\ \(c[26]\)[t] + 
            0.06983076867396242`\ \(c[27]\)[t] + 
            0.06581101988179631`\ \(c[28]\)[t] + 
            0.0590709530809064`\ \(c[29]\)[t] + 
            0.049975424961080865`\ \(c[30]\)[t] + 
            0.03897872015786009`\ \(c[31]\)[t] + 
            0.026603074225527937`\ \(c[32]\)[t] + 
            0.013414935129827233`\ \(c[33]\)[t] + 
            1.5206810699945212`*^-16\ \(c[34]\)[t] - 
            0.013061910521147276`\ \(c[35]\)[t] - 
            0.025221096343682053`\ \(c[36]\)[t] - 
            0.03598035706879378`\ \(c[37]\)[t] - 
            0.04491462243337629`\ \(c[38]\)[t] - 
            0.05168708394579296`\ \(c[39]\)[t] - 
            0.05606123915856713`\ \(c[40]\)[t] - 
            0.0579084423149932`\ \(c[41]\)[t] - 
            0.05721075023890897`\ \(c[42]\)[t] - 
            0.054059052045761224`\ \(c[43]\)[t] - 
            0.0486466672430994`\ \(c[44]\)[t] - 
            0.04125878107252025`\ \(c[45]\)[t] - 
            0.03225825116512568`\ \(c[46]\)[t] - 
            0.022068459300722043`\ \(c[47]\)[t] - 
            0.011153991006822649`\ \(c[48]\)[t] - 
            3.8981718325193755`*^-17\ \(c[49]\)[t] + 
            0.010908848347331785`\ \(c[50]\)[t] + 
            0.021108961070255627`\ \(c[51]\)[t] + 
            0.030177073670601094`\ \(c[52]\)[t] + 
            0.03774739544932687`\ \(c[53]\)[t] + 
            0.04352596542803616`\ \(c[54]\)[t] + 
            0.04730167054004106`\ \(c[55]\)[t] + 
            0.0489535285549427`\ \(c[56]\)[t] + 
            0.04845400275336168`\ \(c[57]\)[t] + 
            0.04586828658428231`\ \(c[58]\)[t] + 
            0.04134966715663448`\ \(c[59]\)[t] + 
            0.035131239329076656`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -41, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -41]][ t]], 
          Plus[ 
            Times[ -0.18675027222298618, 
              c[ -60][ t]], 
            Times[ -0.15591488063143982, 
              c[ -59][ t]], 
            Times[ -0.11423673049785459, 
              c[ -58][ t]], 
            Times[ -0.062044074975450718, 
              c[ -57][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -56][ t]], 
            Times[ 0.070907514257657456, 
              c[ -55][ t]], 
            Times[ 0.14938649372796314, 
              c[ -54][ t]], 
            Times[ 0.23387232094715985, 
              c[ -53][ t]], 
            Times[ 0.32256865202152113, 
              c[ -52][ t]], 
            Times[ 0.41349667156634362, 
              c[ -51][ t]], 
            Times[ 0.50455115242710469, 
              c[ -50][ t]], 
            Times[ 0.59356153372868015, 
              c[ -49][ t]], 
            Times[ 0.67835603854706272, 
              c[ -48][ t]], 
            Times[ 0.75682672864065692, 
              c[ -47][ t]], 
            Times[ 0.82699334313268802, 
              c[ -46][ t]], 
            Times[ 0.88706379305918348, 
              c[ -45][ t]], 
            Times[ 0.93548928378863916, 
              c[ -44][ t]], 
            Times[ 0.9710122092317629, 
              c[ -43][ t]], 
            Times[ 0.99270519960720671, 
              c[ -42][ t]], 
            Times[ 37.868455551624905, 
              c[ -41][ t]], 
            Times[ 0.99270519960720693, 
              c[ -40][ t]], 
            Times[ 0.9710122092317629, 
              c[ -39][ t]], 
            Times[ 0.93548928378863927, 
              c[ -38][ t]], 
            Times[ 0.88706379305918392, 
              c[ -37][ t]], 
            Times[ 0.82699334313268846, 
              c[ -36][ t]], 
            Times[ 0.75682672864065736, 
              c[ -35][ t]], 
            Times[ 0.67835603854706361, 
              c[ -34][ t]], 
            Times[ 0.59356153372868092, 
              c[ -33][ t]], 
            Times[ 0.50455115242710502, 
              c[ -32][ t]], 
            Times[ 0.41349667156634429, 
              c[ -31][ t]], 
            Times[ 0.32256865202152191, 
              c[ -30][ t]], 
            Times[ 0.23387232094716018, 
              c[ -29][ t]], 
            Times[ 0.14938649372796384, 
              c[ -28][ t]], 
            Times[ 0.070907514257658094, 
              c[ -27][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ -26][ t]], 
            Times[ -0.062044074975450239, 
              c[ -25][ t]], 
            Times[ -0.11423673049785416, 
              c[ -24][ t]], 
            Times[ -0.15591488063143966, 
              c[ -23][ t]], 
            Times[ -0.18675027222298593, 
              c[ -22][ t]], 
            Times[ -0.20674833578317189, 
              c[ -21][ t]], 
            Times[ -0.21623620818304481, 
              c[ -20][ t]], 
            Times[ -0.21584055771952015, 
              c[ -19][ t]], 
            Times[ -0.20645618564475848, 
              c[ -18][ t]], 
            Times[ -0.18920668216016434, 
              c[ -17][ t]], 
            Times[ -0.16539866862653771, 
              c[ -16][ t]], 
            Times[ -0.13647135277833616, 
              c[ -15][ t]], 
            Times[ -0.1039432537542934, 
              c[ -14][ t]], 
            Times[ -0.06935801494512607, 
              c[ -13][ t]], 
            Times[ -0.034231213779559094, 
              c[ -12][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -11][ t]], 
            Times[ 0.032022748374425904, 
              c[ -10][ t]], 
            Times[ 0.060688263076985001, 
              c[ -9][ t]], 
            Times[ 0.085044480344421608, 
              c[ -8][ t]], 
            Times[ 0.10436044624225685, 
              c[ -7][ t]], 
            Times[ 0.11814190616181253, 
              c[ -6][ t]], 
            Times[ 0.12613778810677612, 
              c[ -5][ t]], 
            Times[ 0.12833762891430925, 
              c[ -4][ t]], 
            Times[ 0.12496032289024853, 
              c[ -3][ t]], 
            Times[ 0.11643488132933195, 
              c[ -2][ t]], 
            Times[ 0.10337416789158609, 
              c[ -1][ t]], 
            Times[ 0.086542809078944891, 
              c[ 0][ t]], 
            Times[ 0.066820663127760152, 
              c[ 1][ t]], 
            Times[ 0.045163358568919301, 
              c[ 2][ t]], 
            Times[ 0.022561481809254869, 
              c[ 3][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ 4][ t]], 
            Times[ -0.021580547817547879, 
              c[ 5][ t]], 
            Times[ -0.04131966847794722, 
              c[ 6][ t]], 
            Times[ -0.058468080236789774, 
              c[ 7][ t]], 
            Times[ -0.072413370861974122, 
              c[ 8][ t]], 
            Times[ -0.082699334313268744, 
              c[ 9][ t]], 
            Times[ -0.089038438663606653, 
              c[ 10][ t]], 
            Times[ -0.091317159035181603, 
              c[ 11][ t]], 
            Times[ -0.089594193770366884, 
              c[ 12][ t]], 
            Times[ -0.084091858737850855, 
              c[ 13][ t]], 
            Times[ -0.075181213012062695, 
              c[ 14][ t]], 
            Times[ -0.063361699504227528, 
              c[ 15][ t]], 
            Times[ -0.049236278094139066, 
              c[ 16][ t]], 
            Times[ -0.033483179628681706, 
              c[ 17][ t]], 
            Times[ -0.016825511857749401, 
              c[ 18][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 19][ t]], 
            Times[ 0.016273855731265469, 
              c[ 20][ t]], 
            Times[ 0.031322974491347078, 
              c[ 21][ t]], 
            Times[ 0.044547108751839815, 
              c[ 22][ t]], 
            Times[ 0.055441487066198857, 
              c[ 23][ t]], 
            Times[ 0.063614872548668253, 
              c[ 24][ t]], 
            Times[ 0.068802429876423321, 
              c[ 25][ t]], 
            Times[ 0.070873018952678238, 
              c[ 26][ t]], 
            Times[ 0.069830768673962415, 
              c[ 27][ t]], 
            Times[ 0.065811019881796315, 
              c[ 28][ t]], 
            Times[ 0.059070953080906402, 
              c[ 29][ t]], 
            Times[ 0.049975424961080865, 
              c[ 30][ t]], 
            Times[ 0.038978720157860088, 
              c[ 31][ t]], 
            Times[ 0.026603074225527937, 
              c[ 32][ t]], 
            Times[ 0.013414935129827233, 
              c[ 33][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ 34][ t]], 
            Times[ -0.013061910521147276, 
              c[ 35][ t]], 
            Times[ -0.025221096343682053, 
              c[ 36][ t]], 
            Times[ -0.035980357068793781, 
              c[ 37][ t]], 
            Times[ -0.044914622433376288, 
              c[ 38][ t]], 
            Times[ -0.05168708394579296, 
              c[ 39][ t]], 
            Times[ -0.05606123915856713, 
              c[ 40][ t]], 
            Times[ -0.057908442314993203, 
              c[ 41][ t]], 
            Times[ -0.057210750238908967, 
              c[ 42][ t]], 
            Times[ -0.054059052045761224, 
              c[ 43][ t]], 
            Times[ -0.048646667243099399, 
              c[ 44][ t]], 
            Times[ -0.041258781072520248, 
              c[ 45][ t]], 
            Times[ -0.032258251165125679, 
              c[ 46][ t]], 
            Times[ -0.022068459300722043, 
              c[ 47][ t]], 
            Times[ -0.011153991006822649, 
              c[ 48][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 49][ t]], 
            Times[ 0.010908848347331785, 
              c[ 50][ t]], 
            Times[ 0.021108961070255627, 
              c[ 51][ t]], 
            Times[ 0.030177073670601094, 
              c[ 52][ t]], 
            Times[ 0.03774739544932687, 
              c[ 53][ t]], 
            Times[ 0.043525965428036162, 
              c[ 54][ t]], 
            Times[ 0.047301670540041058, 
              c[ 55][ t]], 
            Times[ 0.048953528554942699, 
              c[ 56][ t]], 
            Times[ 0.048454002753361682, 
              c[ 57][ t]], 
            Times[ 0.045868286584282311, 
              c[ 58][ t]], 
            Times[ 0.041349667156634483, 
              c[ 59][ t]], 
            Times[ 0.035131239329076656, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-40\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-40\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.20674833578317206`\)\ \(c[\(-60\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-59\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-58\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-57\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-56\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-55\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-54\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-53\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-52\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-51\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-50\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-49\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-48\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-47\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-46\)]\)[t] + 
            0.826993343132688`\ \(c[\(-45\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-44\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-43\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-42\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-41\)]\)[t] + 
            36.09192675942882`\ \(c[\(-40\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-39\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-38\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-37\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-36\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-35\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-34\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-33\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-32\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-31\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-30\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-29\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-28\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-27\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-26\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-25\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-24\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-23\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-22\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-21\)]\)[t] - 
            0.206748335783172`\ \(c[\(-20\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-19\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-18\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-17\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-16\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-15\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-14\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-13\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-12\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-11\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-10\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-9\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-8\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-7\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-6\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-5\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-4\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-3\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-2\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-1\)]\)[t] + 
            0.10337416789158609`\ \(c[0]\)[t] + 
            0.08654280907894489`\ \(c[1]\)[t] + 
            0.06682066312775997`\ \(c[2]\)[t] + 
            0.0451633585689193`\ \(c[3]\)[t] + 
            0.02256148180925487`\ \(c[4]\)[t] + 
            3.8981718325193755`*^-17\ \(c[5]\)[t] - 
            0.02158054781754788`\ \(c[6]\)[t] - 
            0.04131966847794722`\ \(c[7]\)[t] - 
            0.05846808023678991`\ \(c[8]\)[t] - 
            0.07241337086197412`\ \(c[9]\)[t] - 
            0.08269933431326874`\ \(c[10]\)[t] - 
            0.0890384386636067`\ \(c[11]\)[t] - 
            0.09131715903518159`\ \(c[12]\)[t] - 
            0.08959419377036688`\ \(c[13]\)[t] - 
            0.08409185873785081`\ \(c[14]\)[t] - 
            0.0751812130120626`\ \(c[15]\)[t] - 
            0.06336169950422753`\ \(c[16]\)[t] - 
            0.04923627809413894`\ \(c[17]\)[t] - 
            0.03348317962868157`\ \(c[18]\)[t] - 
            0.0168255118577494`\ \(c[19]\)[t] - 
            3.898171832519376`*^-17\ \(c[20]\)[t] + 
            0.016273855731265604`\ \(c[21]\)[t] + 
            0.03132297449134708`\ \(c[22]\)[t] + 
            0.04454710875183992`\ \(c[23]\)[t] + 
            0.05544148706619893`\ \(c[24]\)[t] + 
            0.06361487254866825`\ \(c[25]\)[t] + 
            0.06880242987642335`\ \(c[26]\)[t] + 
            0.07087301895267824`\ \(c[27]\)[t] + 
            0.06983076867396242`\ \(c[28]\)[t] + 
            0.06581101988179627`\ \(c[29]\)[t] + 
            0.059070953080906326`\ \(c[30]\)[t] + 
            0.049975424961080865`\ \(c[31]\)[t] + 
            0.03897872015785999`\ \(c[32]\)[t] + 
            0.026603074225527826`\ \(c[33]\)[t] + 
            0.013414935129827233`\ \(c[34]\)[t] + 
            3.898171832519376`*^-17\ \(c[35]\)[t] - 
            0.013061910521147383`\ \(c[36]\)[t] - 
            0.025221096343682053`\ \(c[37]\)[t] - 
            0.03598035706879378`\ \(c[38]\)[t] - 
            0.04491462243337642`\ \(c[39]\)[t] - 
            0.05168708394579296`\ \(c[40]\)[t] - 
            0.05606123915856713`\ \(c[41]\)[t] - 
            0.0579084423149932`\ \(c[42]\)[t] - 
            0.05721075023890897`\ \(c[43]\)[t] - 
            0.054059052045761224`\ \(c[44]\)[t] - 
            0.04864666724309928`\ \(c[45]\)[t] - 
            0.04125878107252025`\ \(c[46]\)[t] - 
            0.03225825116512568`\ \(c[47]\)[t] - 
            0.022068459300722043`\ \(c[48]\)[t] - 
            0.011153991006822649`\ \(c[49]\)[t] - 
            3.8981718325193755`*^-17\ \(c[50]\)[t] + 
            0.010908848347331966`\ \(c[51]\)[t] + 
            0.021108961070255627`\ \(c[52]\)[t] + 
            0.030177073670601094`\ \(c[53]\)[t] + 
            0.03774739544932687`\ \(c[54]\)[t] + 
            0.04352596542803616`\ \(c[55]\)[t] + 
            0.04730167054004106`\ \(c[56]\)[t] + 
            0.04895352855494272`\ \(c[57]\)[t] + 
            0.04845400275336168`\ \(c[58]\)[t] + 
            0.04586828658428231`\ \(c[59]\)[t] + 
            0.04134966715663448`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -40, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -40]][ t]], 
          Plus[ 
            Times[ -0.20674833578317206, 
              c[ -60][ t]], 
            Times[ -0.18675027222298593, 
              c[ -59][ t]], 
            Times[ -0.15591488063143982, 
              c[ -58][ t]], 
            Times[ -0.11423673049785459, 
              c[ -57][ t]], 
            Times[ -0.062044074975450239, 
              c[ -56][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -55][ t]], 
            Times[ 0.070907514257657456, 
              c[ -54][ t]], 
            Times[ 0.14938649372796384, 
              c[ -53][ t]], 
            Times[ 0.23387232094715985, 
              c[ -52][ t]], 
            Times[ 0.32256865202152113, 
              c[ -51][ t]], 
            Times[ 0.41349667156634429, 
              c[ -50][ t]], 
            Times[ 0.50455115242710469, 
              c[ -49][ t]], 
            Times[ 0.59356153372868015, 
              c[ -48][ t]], 
            Times[ 0.67835603854706361, 
              c[ -47][ t]], 
            Times[ 0.75682672864065692, 
              c[ -46][ t]], 
            Times[ 0.82699334313268802, 
              c[ -45][ t]], 
            Times[ 0.88706379305918392, 
              c[ -44][ t]], 
            Times[ 0.93548928378863916, 
              c[ -43][ t]], 
            Times[ 0.9710122092317629, 
              c[ -42][ t]], 
            Times[ 0.99270519960720693, 
              c[ -41][ t]], 
            Times[ 36.091926759428823, 
              c[ -40][ t]], 
            Times[ 0.99270519960720693, 
              c[ -39][ t]], 
            Times[ 0.9710122092317629, 
              c[ -38][ t]], 
            Times[ 0.93548928378863916, 
              c[ -37][ t]], 
            Times[ 0.88706379305918392, 
              c[ -36][ t]], 
            Times[ 0.82699334313268813, 
              c[ -35][ t]], 
            Times[ 0.75682672864065692, 
              c[ -34][ t]], 
            Times[ 0.67835603854706361, 
              c[ -33][ t]], 
            Times[ 0.59356153372868059, 
              c[ -32][ t]], 
            Times[ 0.50455115242710469, 
              c[ -31][ t]], 
            Times[ 0.41349667156634429, 
              c[ -30][ t]], 
            Times[ 0.32256865202152157, 
              c[ -29][ t]], 
            Times[ 0.23387232094715985, 
              c[ -28][ t]], 
            Times[ 0.14938649372796384, 
              c[ -27][ t]], 
            Times[ 0.070907514257657775, 
              c[ -26][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -25][ t]], 
            Times[ -0.062044074975450239, 
              c[ -24][ t]], 
            Times[ -0.11423673049785436, 
              c[ -23][ t]], 
            Times[ -0.15591488063143982, 
              c[ -22][ t]], 
            Times[ -0.18675027222298593, 
              c[ -21][ t]], 
            Times[ -0.206748335783172, 
              c[ -20][ t]], 
            Times[ -0.21623620818304484, 
              c[ -19][ t]], 
            Times[ -0.21584055771952015, 
              c[ -18][ t]], 
            Times[ -0.20645618564475843, 
              c[ -17][ t]], 
            Times[ -0.18920668216016426, 
              c[ -16][ t]], 
            Times[ -0.16539866862653771, 
              c[ -15][ t]], 
            Times[ -0.13647135277833605, 
              c[ -14][ t]], 
            Times[ -0.10394325375429328, 
              c[ -13][ t]], 
            Times[ -0.06935801494512607, 
              c[ -12][ t]], 
            Times[ -0.034231213779558949, 
              c[ -11][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -10][ t]], 
            Times[ 0.032022748374425904, 
              c[ -9][ t]], 
            Times[ 0.060688263076985105, 
              c[ -8][ t]], 
            Times[ 0.085044480344421705, 
              c[ -7][ t]], 
            Times[ 0.10436044624225685, 
              c[ -6][ t]], 
            Times[ 0.11814190616181255, 
              c[ -5][ t]], 
            Times[ 0.12613778810677612, 
              c[ -4][ t]], 
            Times[ 0.12833762891430928, 
              c[ -3][ t]], 
            Times[ 0.12496032289024853, 
              c[ -2][ t]], 
            Times[ 0.11643488132933186, 
              c[ -1][ t]], 
            Times[ 0.10337416789158609, 
              c[ 0][ t]], 
            Times[ 0.086542809078944891, 
              c[ 1][ t]], 
            Times[ 0.066820663127759972, 
              c[ 2][ t]], 
            Times[ 0.045163358568919301, 
              c[ 3][ t]], 
            Times[ 0.022561481809254869, 
              c[ 4][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 5][ t]], 
            Times[ -0.021580547817547879, 
              c[ 6][ t]], 
            Times[ -0.04131966847794722, 
              c[ 7][ t]], 
            Times[ -0.058468080236789913, 
              c[ 8][ t]], 
            Times[ -0.072413370861974122, 
              c[ 9][ t]], 
            Times[ -0.082699334313268744, 
              c[ 10][ t]], 
            Times[ -0.089038438663606695, 
              c[ 11][ t]], 
            Times[ -0.091317159035181589, 
              c[ 12][ t]], 
            Times[ -0.089594193770366884, 
              c[ 13][ t]], 
            Times[ -0.084091858737850814, 
              c[ 14][ t]], 
            Times[ -0.075181213012062598, 
              c[ 15][ t]], 
            Times[ -0.063361699504227528, 
              c[ 16][ t]], 
            Times[ -0.049236278094138941, 
              c[ 17][ t]], 
            Times[ -0.033483179628681567, 
              c[ 18][ t]], 
            Times[ -0.016825511857749401, 
              c[ 19][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 20][ t]], 
            Times[ 0.016273855731265604, 
              c[ 21][ t]], 
            Times[ 0.031322974491347078, 
              c[ 22][ t]], 
            Times[ 0.044547108751839919, 
              c[ 23][ t]], 
            Times[ 0.055441487066198933, 
              c[ 24][ t]], 
            Times[ 0.063614872548668253, 
              c[ 25][ t]], 
            Times[ 0.068802429876423349, 
              c[ 26][ t]], 
            Times[ 0.070873018952678238, 
              c[ 27][ t]], 
            Times[ 0.069830768673962415, 
              c[ 28][ t]], 
            Times[ 0.065811019881796273, 
              c[ 29][ t]], 
            Times[ 0.059070953080906326, 
              c[ 30][ t]], 
            Times[ 0.049975424961080865, 
              c[ 31][ t]], 
            Times[ 0.03897872015785999, 
              c[ 32][ t]], 
            Times[ 0.026603074225527826, 
              c[ 33][ t]], 
            Times[ 0.013414935129827233, 
              c[ 34][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 35][ t]], 
            Times[ -0.013061910521147383, 
              c[ 36][ t]], 
            Times[ -0.025221096343682053, 
              c[ 37][ t]], 
            Times[ -0.035980357068793781, 
              c[ 38][ t]], 
            Times[ -0.044914622433376419, 
              c[ 39][ t]], 
            Times[ -0.05168708394579296, 
              c[ 40][ t]], 
            Times[ -0.05606123915856713, 
              c[ 41][ t]], 
            Times[ -0.057908442314993203, 
              c[ 42][ t]], 
            Times[ -0.057210750238908967, 
              c[ 43][ t]], 
            Times[ -0.054059052045761224, 
              c[ 44][ t]], 
            Times[ -0.048646667243099281, 
              c[ 45][ t]], 
            Times[ -0.041258781072520248, 
              c[ 46][ t]], 
            Times[ -0.032258251165125679, 
              c[ 47][ t]], 
            Times[ -0.022068459300722043, 
              c[ 48][ t]], 
            Times[ -0.011153991006822649, 
              c[ 49][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 50][ t]], 
            Times[ 0.010908848347331966, 
              c[ 51][ t]], 
            Times[ 0.021108961070255627, 
              c[ 52][ t]], 
            Times[ 0.030177073670601094, 
              c[ 53][ t]], 
            Times[ 0.03774739544932687, 
              c[ 54][ t]], 
            Times[ 0.043525965428036162, 
              c[ 55][ t]], 
            Times[ 0.047301670540041058, 
              c[ 56][ t]], 
            Times[ 0.04895352855494272, 
              c[ 57][ t]], 
            Times[ 0.048454002753361682, 
              c[ 58][ t]], 
            Times[ 0.045868286584282311, 
              c[ 59][ t]], 
            Times[ 0.041349667156634483, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-39\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-39\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.21623620818304484`\)\ \(c[\(-60\)]\)[t] - 
            0.2067483357831719`\ \(c[\(-59\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-58\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-57\)]\)[t] - 
            0.11423673049785416`\ \(c[\(-56\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-55\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-54\)]\)[t] + 
            0.0709075142576581`\ \(c[\(-53\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-52\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-51\)]\)[t] + 
            0.3225686520215219`\ \(c[\(-50\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-49\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-48\)]\)[t] + 
            0.5935615337286809`\ \(c[\(-47\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-46\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-45\)]\)[t] + 
            0.8269933431326885`\ \(c[\(-44\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-43\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-42\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-41\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-40\)]\)[t] + 
            34.35926287568203`\ \(c[\(-39\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-38\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-37\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-36\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-35\)]\)[t] + 
            0.826993343132688`\ \(c[\(-34\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-33\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-32\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-31\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-30\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-29\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-28\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-27\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-26\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-25\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-24\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-23\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-22\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-21\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-20\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-19\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-18\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-17\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-16\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-15\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-14\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-13\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-12\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-11\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-10\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-9\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-8\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-7\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-6\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-5\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-4\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-3\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-2\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-1\)]\)[t] + 
            0.11643488132933186`\ \(c[0]\)[t] + 
            0.10337416789158609`\ \(c[1]\)[t] + 
            0.08654280907894475`\ \(c[2]\)[t] + 
            0.06682066312775997`\ \(c[3]\)[t] + 
            0.0451633585689193`\ \(c[4]\)[t] + 
            0.022561481809254675`\ \(c[5]\)[t] + 
            3.8981718325193755`*^-17\ \(c[6]\)[t] - 
            0.02158054781754788`\ \(c[7]\)[t] - 
            0.04131966847794737`\ \(c[8]\)[t] - 
            0.05846808023678991`\ \(c[9]\)[t] - 
            0.07241337086197412`\ \(c[10]\)[t] - 
            0.08269933431326874`\ \(c[11]\)[t] - 
            0.0890384386636067`\ \(c[12]\)[t] - 
            0.09131715903518159`\ \(c[13]\)[t] - 
            0.08959419377036688`\ \(c[14]\)[t] - 
            0.08409185873785081`\ \(c[15]\)[t] - 
            0.0751812130120626`\ \(c[16]\)[t] - 
            0.06336169950422753`\ \(c[17]\)[t] - 
            0.04923627809413894`\ \(c[18]\)[t] - 
            0.03348317962868157`\ \(c[19]\)[t] - 
            0.0168255118577494`\ \(c[20]\)[t] - 
            3.898171832519376`*^-17\ \(c[21]\)[t] + 
            0.016273855731265604`\ \(c[22]\)[t] + 
            0.03132297449134708`\ \(c[23]\)[t] + 
            0.04454710875183992`\ \(c[24]\)[t] + 
            0.05544148706619893`\ \(c[25]\)[t] + 
            0.06361487254866825`\ \(c[26]\)[t] + 
            0.06880242987642335`\ \(c[27]\)[t] + 
            0.07087301895267824`\ \(c[28]\)[t] + 
            0.06983076867396242`\ \(c[29]\)[t] + 
            0.06581101988179627`\ \(c[30]\)[t] + 
            0.059070953080906326`\ \(c[31]\)[t] + 
            0.049975424961080865`\ \(c[32]\)[t] + 
            0.03897872015785999`\ \(c[33]\)[t] + 
            0.026603074225527826`\ \(c[34]\)[t] + 
            0.013414935129827233`\ \(c[35]\)[t] + 
            3.898171832519376`*^-17\ \(c[36]\)[t] - 
            0.013061910521147383`\ \(c[37]\)[t] - 
            0.025221096343682053`\ \(c[38]\)[t] - 
            0.03598035706879378`\ \(c[39]\)[t] - 
            0.04491462243337642`\ \(c[40]\)[t] - 
            0.05168708394579296`\ \(c[41]\)[t] - 
            0.056061239158567186`\ \(c[42]\)[t] - 
            0.0579084423149932`\ \(c[43]\)[t] - 
            0.05721075023890897`\ \(c[44]\)[t] - 
            0.054059052045761224`\ \(c[45]\)[t] - 
            0.04864666724309928`\ \(c[46]\)[t] - 
            0.04125878107252025`\ \(c[47]\)[t] - 
            0.03225825116512552`\ \(c[48]\)[t] - 
            0.022068459300722043`\ \(c[49]\)[t] - 
            0.011153991006822649`\ \(c[50]\)[t] - 
            3.8981718325193755`*^-17\ \(c[51]\)[t] + 
            0.010908848347331966`\ \(c[52]\)[t] + 
            0.021108961070255627`\ \(c[53]\)[t] + 
            0.030177073670601236`\ \(c[54]\)[t] + 
            0.03774739544932687`\ \(c[55]\)[t] + 
            0.04352596542803616`\ \(c[56]\)[t] + 
            0.04730167054004106`\ \(c[57]\)[t] + 
            0.04895352855494272`\ \(c[58]\)[t] + 
            0.04845400275336168`\ \(c[59]\)[t] + 
            0.045868286584282256`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -39, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -39]][ t]], 
          Plus[ 
            Times[ -0.21623620818304484, 
              c[ -60][ t]], 
            Times[ -0.20674833578317189, 
              c[ -59][ t]], 
            Times[ -0.18675027222298593, 
              c[ -58][ t]], 
            Times[ -0.15591488063143982, 
              c[ -57][ t]], 
            Times[ -0.11423673049785416, 
              c[ -56][ t]], 
            Times[ -0.062044074975450239, 
              c[ -55][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -54][ t]], 
            Times[ 0.070907514257658094, 
              c[ -53][ t]], 
            Times[ 0.14938649372796384, 
              c[ -52][ t]], 
            Times[ 0.23387232094715985, 
              c[ -51][ t]], 
            Times[ 0.32256865202152191, 
              c[ -50][ t]], 
            Times[ 0.41349667156634429, 
              c[ -49][ t]], 
            Times[ 0.50455115242710469, 
              c[ -48][ t]], 
            Times[ 0.59356153372868092, 
              c[ -47][ t]], 
            Times[ 0.67835603854706361, 
              c[ -46][ t]], 
            Times[ 0.75682672864065692, 
              c[ -45][ t]], 
            Times[ 0.82699334313268846, 
              c[ -44][ t]], 
            Times[ 0.88706379305918392, 
              c[ -43][ t]], 
            Times[ 0.93548928378863916, 
              c[ -42][ t]], 
            Times[ 0.9710122092317629, 
              c[ -41][ t]], 
            Times[ 0.99270519960720693, 
              c[ -40][ t]], 
            Times[ 34.359262875682028, 
              c[ -39][ t]], 
            Times[ 0.99270519960720671, 
              c[ -38][ t]], 
            Times[ 0.9710122092317629, 
              c[ -37][ t]], 
            Times[ 0.93548928378863916, 
              c[ -36][ t]], 
            Times[ 0.88706379305918381, 
              c[ -35][ t]], 
            Times[ 0.82699334313268802, 
              c[ -34][ t]], 
            Times[ 0.75682672864065692, 
              c[ -33][ t]], 
            Times[ 0.67835603854706317, 
              c[ -32][ t]], 
            Times[ 0.59356153372868015, 
              c[ -31][ t]], 
            Times[ 0.50455115242710469, 
              c[ -30][ t]], 
            Times[ 0.41349667156634395, 
              c[ -29][ t]], 
            Times[ 0.32256865202152113, 
              c[ -28][ t]], 
            Times[ 0.23387232094715985, 
              c[ -27][ t]], 
            Times[ 0.14938649372796345, 
              c[ -26][ t]], 
            Times[ 0.070907514257657456, 
              c[ -25][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -24][ t]], 
            Times[ -0.062044074975450475, 
              c[ -23][ t]], 
            Times[ -0.11423673049785459, 
              c[ -22][ t]], 
            Times[ -0.15591488063143982, 
              c[ -21][ t]], 
            Times[ -0.18675027222298607, 
              c[ -20][ t]], 
            Times[ -0.20674833578317206, 
              c[ -19][ t]], 
            Times[ -0.21623620818304484, 
              c[ -18][ t]], 
            Times[ -0.21584055771952013, 
              c[ -17][ t]], 
            Times[ -0.20645618564475834, 
              c[ -16][ t]], 
            Times[ -0.18920668216016426, 
              c[ -15][ t]], 
            Times[ -0.1653986686265376, 
              c[ -14][ t]], 
            Times[ -0.13647135277833591, 
              c[ -13][ t]], 
            Times[ -0.10394325375429328, 
              c[ -12][ t]], 
            Times[ -0.069358014945125918, 
              c[ -11][ t]], 
            Times[ -0.034231213779558796, 
              c[ -10][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -9][ t]], 
            Times[ 0.032022748374426029, 
              c[ -8][ t]], 
            Times[ 0.060688263076985223, 
              c[ -7][ t]], 
            Times[ 0.085044480344421705, 
              c[ -6][ t]], 
            Times[ 0.10436044624225692, 
              c[ -5][ t]], 
            Times[ 0.11814190616181255, 
              c[ -4][ t]], 
            Times[ 0.12613778810677614, 
              c[ -3][ t]], 
            Times[ 0.12833762891430925, 
              c[ -2][ t]], 
            Times[ 0.12496032289024853, 
              c[ -1][ t]], 
            Times[ 0.11643488132933186, 
              c[ 0][ t]], 
            Times[ 0.10337416789158609, 
              c[ 1][ t]], 
            Times[ 0.086542809078944752, 
              c[ 2][ t]], 
            Times[ 0.066820663127759972, 
              c[ 3][ t]], 
            Times[ 0.045163358568919301, 
              c[ 4][ t]], 
            Times[ 0.022561481809254675, 
              c[ 5][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 6][ t]], 
            Times[ -0.021580547817547879, 
              c[ 7][ t]], 
            Times[ -0.041319668477947373, 
              c[ 8][ t]], 
            Times[ -0.058468080236789913, 
              c[ 9][ t]], 
            Times[ -0.072413370861974122, 
              c[ 10][ t]], 
            Times[ -0.082699334313268744, 
              c[ 11][ t]], 
            Times[ -0.089038438663606695, 
              c[ 12][ t]], 
            Times[ -0.091317159035181589, 
              c[ 13][ t]], 
            Times[ -0.089594193770366884, 
              c[ 14][ t]], 
            Times[ -0.084091858737850814, 
              c[ 15][ t]], 
            Times[ -0.075181213012062598, 
              c[ 16][ t]], 
            Times[ -0.063361699504227528, 
              c[ 17][ t]], 
            Times[ -0.049236278094138941, 
              c[ 18][ t]], 
            Times[ -0.033483179628681567, 
              c[ 19][ t]], 
            Times[ -0.016825511857749401, 
              c[ 20][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 21][ t]], 
            Times[ 0.016273855731265604, 
              c[ 22][ t]], 
            Times[ 0.031322974491347078, 
              c[ 23][ t]], 
            Times[ 0.044547108751839919, 
              c[ 24][ t]], 
            Times[ 0.055441487066198933, 
              c[ 25][ t]], 
            Times[ 0.063614872548668253, 
              c[ 26][ t]], 
            Times[ 0.068802429876423349, 
              c[ 27][ t]], 
            Times[ 0.070873018952678238, 
              c[ 28][ t]], 
            Times[ 0.069830768673962415, 
              c[ 29][ t]], 
            Times[ 0.065811019881796273, 
              c[ 30][ t]], 
            Times[ 0.059070953080906326, 
              c[ 31][ t]], 
            Times[ 0.049975424961080865, 
              c[ 32][ t]], 
            Times[ 0.03897872015785999, 
              c[ 33][ t]], 
            Times[ 0.026603074225527826, 
              c[ 34][ t]], 
            Times[ 0.013414935129827233, 
              c[ 35][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 36][ t]], 
            Times[ -0.013061910521147383, 
              c[ 37][ t]], 
            Times[ -0.025221096343682053, 
              c[ 38][ t]], 
            Times[ -0.035980357068793781, 
              c[ 39][ t]], 
            Times[ -0.044914622433376419, 
              c[ 40][ t]], 
            Times[ -0.05168708394579296, 
              c[ 41][ t]], 
            Times[ -0.056061239158567186, 
              c[ 42][ t]], 
            Times[ -0.057908442314993203, 
              c[ 43][ t]], 
            Times[ -0.057210750238908967, 
              c[ 44][ t]], 
            Times[ -0.054059052045761224, 
              c[ 45][ t]], 
            Times[ -0.048646667243099281, 
              c[ 46][ t]], 
            Times[ -0.041258781072520248, 
              c[ 47][ t]], 
            Times[ -0.032258251165125519, 
              c[ 48][ t]], 
            Times[ -0.022068459300722043, 
              c[ 49][ t]], 
            Times[ -0.011153991006822649, 
              c[ 50][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 51][ t]], 
            Times[ 0.010908848347331966, 
              c[ 52][ t]], 
            Times[ 0.021108961070255627, 
              c[ 53][ t]], 
            Times[ 0.030177073670601236, 
              c[ 54][ t]], 
            Times[ 0.03774739544932687, 
              c[ 55][ t]], 
            Times[ 0.043525965428036162, 
              c[ 56][ t]], 
            Times[ 0.047301670540041058, 
              c[ 57][ t]], 
            Times[ 0.04895352855494272, 
              c[ 58][ t]], 
            Times[ 0.048454002753361682, 
              c[ 59][ t]], 
            Times[ 0.045868286584282256, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-38\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-38\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.21584055771952013`\)\ \(c[\(-60\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-59\)]\)[t] - 
            0.206748335783172`\ \(c[\(-58\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-57\)]\)[t] - 
            0.15591488063143966`\ \(c[\(-56\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-55\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-54\)]\)[t] + 
            3.216976900108398`*^-16\ \(c[\(-53\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-52\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-51\)]\)[t] + 
            0.23387232094716018`\ \(c[\(-50\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-49\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-48\)]\)[t] + 
            0.504551152427105`\ \(c[\(-47\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-46\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-45\)]\)[t] + 
            0.7568267286406574`\ \(c[\(-44\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-43\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-42\)]\)[t] + 
            0.9354892837886393`\ \(c[\(-41\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-40\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-39\)]\)[t] + 
            32.67046390038452`\ \(c[\(-38\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-37\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-36\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-35\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-34\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-33\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-32\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-31\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-30\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-29\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-28\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-27\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-26\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-25\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-24\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-23\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-22\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-21\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-20\)]\)[t] - 
            0.186750272222986`\ \(c[\(-19\)]\)[t] - 
            0.206748335783172`\ \(c[\(-18\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-17\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-16\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-15\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-14\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-13\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-12\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-11\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-10\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-9\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-8\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-7\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-6\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-5\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-4\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-3\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-2\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-1\)]\)[t] + 
            0.12496032289024853`\ \(c[0]\)[t] + 
            0.11643488132933186`\ \(c[1]\)[t] + 
            0.10337416789158609`\ \(c[2]\)[t] + 
            0.08654280907894489`\ \(c[3]\)[t] + 
            0.06682066312775997`\ \(c[4]\)[t] + 
            0.0451633585689193`\ \(c[5]\)[t] + 
            0.02256148180925487`\ \(c[6]\)[t] + 
            3.8981718325193755`*^-17\ \(c[7]\)[t] - 
            0.02158054781754788`\ \(c[8]\)[t] - 
            0.04131966847794722`\ \(c[9]\)[t] - 
            0.05846808023678991`\ \(c[10]\)[t] - 
            0.07241337086197412`\ \(c[11]\)[t] - 
            0.08269933431326874`\ \(c[12]\)[t] - 
            0.0890384386636067`\ \(c[13]\)[t] - 
            0.09131715903518159`\ \(c[14]\)[t] - 
            0.08959419377036688`\ \(c[15]\)[t] - 
            0.08409185873785081`\ \(c[16]\)[t] - 
            0.0751812130120626`\ \(c[17]\)[t] - 
            0.06336169950422753`\ \(c[18]\)[t] - 
            0.04923627809413894`\ \(c[19]\)[t] - 
            0.03348317962868157`\ \(c[20]\)[t] - 
            0.0168255118577494`\ \(c[21]\)[t] - 
            3.898171832519376`*^-17\ \(c[22]\)[t] + 
            0.016273855731265604`\ \(c[23]\)[t] + 
            0.03132297449134708`\ \(c[24]\)[t] + 
            0.04454710875183992`\ \(c[25]\)[t] + 
            0.05544148706619893`\ \(c[26]\)[t] + 
            0.06361487254866825`\ \(c[27]\)[t] + 
            0.06880242987642335`\ \(c[28]\)[t] + 
            0.07087301895267824`\ \(c[29]\)[t] + 
            0.06983076867396242`\ \(c[30]\)[t] + 
            0.06581101988179627`\ \(c[31]\)[t] + 
            0.059070953080906326`\ \(c[32]\)[t] + 
            0.049975424961080865`\ \(c[33]\)[t] + 
            0.03897872015785999`\ \(c[34]\)[t] + 
            0.026603074225527826`\ \(c[35]\)[t] + 
            0.013414935129827233`\ \(c[36]\)[t] + 
            3.898171832519376`*^-17\ \(c[37]\)[t] - 
            0.013061910521147383`\ \(c[38]\)[t] - 
            0.025221096343682053`\ \(c[39]\)[t] - 
            0.03598035706879378`\ \(c[40]\)[t] - 
            0.04491462243337629`\ \(c[41]\)[t] - 
            0.05168708394579296`\ \(c[42]\)[t] - 
            0.056061239158567186`\ \(c[43]\)[t] - 
            0.0579084423149932`\ \(c[44]\)[t] - 
            0.05721075023890897`\ \(c[45]\)[t] - 
            0.054059052045761224`\ \(c[46]\)[t] - 
            0.0486466672430994`\ \(c[47]\)[t] - 
            0.04125878107252025`\ \(c[48]\)[t] - 
            0.03225825116512552`\ \(c[49]\)[t] - 
            0.022068459300722043`\ \(c[50]\)[t] - 
            0.011153991006822649`\ \(c[51]\)[t] - 
            3.8981718325193755`*^-17\ \(c[52]\)[t] + 
            0.010908848347331785`\ \(c[53]\)[t] + 
            0.021108961070255627`\ \(c[54]\)[t] + 
            0.030177073670601236`\ \(c[55]\)[t] + 
            0.03774739544932687`\ \(c[56]\)[t] + 
            0.04352596542803616`\ \(c[57]\)[t] + 
            0.04730167054004106`\ \(c[58]\)[t] + 
            0.0489535285549427`\ \(c[59]\)[t] + 
            0.04845400275336168`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -38, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -38]][ t]], 
          Plus[ 
            Times[ -0.21584055771952013, 
              c[ -60][ t]], 
            Times[ -0.21623620818304481, 
              c[ -59][ t]], 
            Times[ -0.206748335783172, 
              c[ -58][ t]], 
            Times[ -0.18675027222298607, 
              c[ -57][ t]], 
            Times[ -0.15591488063143966, 
              c[ -56][ t]], 
            Times[ -0.11423673049785436, 
              c[ -55][ t]], 
            Times[ -0.062044074975450475, 
              c[ -54][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ -53][ t]], 
            Times[ 0.070907514257657775, 
              c[ -52][ t]], 
            Times[ 0.14938649372796345, 
              c[ -51][ t]], 
            Times[ 0.23387232094716018, 
              c[ -50][ t]], 
            Times[ 0.32256865202152157, 
              c[ -49][ t]], 
            Times[ 0.41349667156634395, 
              c[ -48][ t]], 
            Times[ 0.50455115242710502, 
              c[ -47][ t]], 
            Times[ 0.59356153372868059, 
              c[ -46][ t]], 
            Times[ 0.67835603854706317, 
              c[ -45][ t]], 
            Times[ 0.75682672864065736, 
              c[ -44][ t]], 
            Times[ 0.82699334313268813, 
              c[ -43][ t]], 
            Times[ 0.88706379305918381, 
              c[ -42][ t]], 
            Times[ 0.93548928378863927, 
              c[ -41][ t]], 
            Times[ 0.9710122092317629, 
              c[ -40][ t]], 
            Times[ 0.99270519960720671, 
              c[ -39][ t]], 
            Times[ 32.670463900384519, 
              c[ -38][ t]], 
            Times[ 0.99270519960720671, 
              c[ -37][ t]], 
            Times[ 0.9710122092317629, 
              c[ -36][ t]], 
            Times[ 0.93548928378863916, 
              c[ -35][ t]], 
            Times[ 0.88706379305918381, 
              c[ -34][ t]], 
            Times[ 0.82699334313268813, 
              c[ -33][ t]], 
            Times[ 0.75682672864065692, 
              c[ -32][ t]], 
            Times[ 0.67835603854706317, 
              c[ -31][ t]], 
            Times[ 0.59356153372868059, 
              c[ -30][ t]], 
            Times[ 0.50455115242710469, 
              c[ -29][ t]], 
            Times[ 0.41349667156634395, 
              c[ -28][ t]], 
            Times[ 0.32256865202152157, 
              c[ -27][ t]], 
            Times[ 0.23387232094715985, 
              c[ -26][ t]], 
            Times[ 0.14938649372796345, 
              c[ -25][ t]], 
            Times[ 0.070907514257657775, 
              c[ -24][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -23][ t]], 
            Times[ -0.062044074975450475, 
              c[ -22][ t]], 
            Times[ -0.11423673049785436, 
              c[ -21][ t]], 
            Times[ -0.15591488063143982, 
              c[ -20][ t]], 
            Times[ -0.18675027222298601, 
              c[ -19][ t]], 
            Times[ -0.206748335783172, 
              c[ -18][ t]], 
            Times[ -0.21623620818304484, 
              c[ -17][ t]], 
            Times[ -0.21584055771952015, 
              c[ -16][ t]], 
            Times[ -0.20645618564475843, 
              c[ -15][ t]], 
            Times[ -0.18920668216016426, 
              c[ -14][ t]], 
            Times[ -0.16539866862653771, 
              c[ -13][ t]], 
            Times[ -0.13647135277833605, 
              c[ -12][ t]], 
            Times[ -0.10394325375429328, 
              c[ -11][ t]], 
            Times[ -0.06935801494512607, 
              c[ -10][ t]], 
            Times[ -0.034231213779558949, 
              c[ -9][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -8][ t]], 
            Times[ 0.032022748374425904, 
              c[ -7][ t]], 
            Times[ 0.060688263076985105, 
              c[ -6][ t]], 
            Times[ 0.085044480344421705, 
              c[ -5][ t]], 
            Times[ 0.10436044624225685, 
              c[ -4][ t]], 
            Times[ 0.11814190616181255, 
              c[ -3][ t]], 
            Times[ 0.12613778810677614, 
              c[ -2][ t]], 
            Times[ 0.12833762891430928, 
              c[ -1][ t]], 
            Times[ 0.12496032289024853, 
              c[ 0][ t]], 
            Times[ 0.11643488132933186, 
              c[ 1][ t]], 
            Times[ 0.10337416789158609, 
              c[ 2][ t]], 
            Times[ 0.086542809078944891, 
              c[ 3][ t]], 
            Times[ 0.066820663127759972, 
              c[ 4][ t]], 
            Times[ 0.045163358568919301, 
              c[ 5][ t]], 
            Times[ 0.022561481809254869, 
              c[ 6][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 7][ t]], 
            Times[ -0.021580547817547879, 
              c[ 8][ t]], 
            Times[ -0.04131966847794722, 
              c[ 9][ t]], 
            Times[ -0.058468080236789913, 
              c[ 10][ t]], 
            Times[ -0.072413370861974122, 
              c[ 11][ t]], 
            Times[ -0.082699334313268744, 
              c[ 12][ t]], 
            Times[ -0.089038438663606695, 
              c[ 13][ t]], 
            Times[ -0.091317159035181589, 
              c[ 14][ t]], 
            Times[ -0.089594193770366884, 
              c[ 15][ t]], 
            Times[ -0.084091858737850814, 
              c[ 16][ t]], 
            Times[ -0.075181213012062598, 
              c[ 17][ t]], 
            Times[ -0.063361699504227528, 
              c[ 18][ t]], 
            Times[ -0.049236278094138941, 
              c[ 19][ t]], 
            Times[ -0.033483179628681567, 
              c[ 20][ t]], 
            Times[ -0.016825511857749401, 
              c[ 21][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 22][ t]], 
            Times[ 0.016273855731265604, 
              c[ 23][ t]], 
            Times[ 0.031322974491347078, 
              c[ 24][ t]], 
            Times[ 0.044547108751839919, 
              c[ 25][ t]], 
            Times[ 0.055441487066198933, 
              c[ 26][ t]], 
            Times[ 0.063614872548668253, 
              c[ 27][ t]], 
            Times[ 0.068802429876423349, 
              c[ 28][ t]], 
            Times[ 0.070873018952678238, 
              c[ 29][ t]], 
            Times[ 0.069830768673962415, 
              c[ 30][ t]], 
            Times[ 0.065811019881796273, 
              c[ 31][ t]], 
            Times[ 0.059070953080906326, 
              c[ 32][ t]], 
            Times[ 0.049975424961080865, 
              c[ 33][ t]], 
            Times[ 0.03897872015785999, 
              c[ 34][ t]], 
            Times[ 0.026603074225527826, 
              c[ 35][ t]], 
            Times[ 0.013414935129827233, 
              c[ 36][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 37][ t]], 
            Times[ -0.013061910521147383, 
              c[ 38][ t]], 
            Times[ -0.025221096343682053, 
              c[ 39][ t]], 
            Times[ -0.035980357068793781, 
              c[ 40][ t]], 
            Times[ -0.044914622433376288, 
              c[ 41][ t]], 
            Times[ -0.05168708394579296, 
              c[ 42][ t]], 
            Times[ -0.056061239158567186, 
              c[ 43][ t]], 
            Times[ -0.057908442314993203, 
              c[ 44][ t]], 
            Times[ -0.057210750238908967, 
              c[ 45][ t]], 
            Times[ -0.054059052045761224, 
              c[ 46][ t]], 
            Times[ -0.048646667243099399, 
              c[ 47][ t]], 
            Times[ -0.041258781072520248, 
              c[ 48][ t]], 
            Times[ -0.032258251165125519, 
              c[ 49][ t]], 
            Times[ -0.022068459300722043, 
              c[ 50][ t]], 
            Times[ -0.011153991006822649, 
              c[ 51][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 52][ t]], 
            Times[ 0.010908848347331785, 
              c[ 53][ t]], 
            Times[ 0.021108961070255627, 
              c[ 54][ t]], 
            Times[ 0.030177073670601236, 
              c[ 55][ t]], 
            Times[ 0.03774739544932687, 
              c[ 56][ t]], 
            Times[ 0.043525965428036162, 
              c[ 57][ t]], 
            Times[ 0.047301670540041058, 
              c[ 58][ t]], 
            Times[ 0.048953528554942699, 
              c[ 59][ t]], 
            Times[ 0.048454002753361682, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-37\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-37\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.20645618564475834`\)\ \(c[\(-60\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-59\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-58\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-57\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-56\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-55\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-54\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-53\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-52\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-51\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-50\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-49\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-48\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-47\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-46\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-45\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-44\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-43\)]\)[t] + 
            0.826993343132688`\ \(c[\(-42\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-41\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-40\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-39\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-38\)]\)[t] + 
            31.025529833536286`\ \(c[\(-37\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-36\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-35\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-34\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-33\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-32\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-31\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-30\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-29\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-28\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-27\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-26\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-25\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-24\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-23\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-22\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-21\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-20\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-19\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-18\)]\)[t] - 
            0.206748335783172`\ \(c[\(-17\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-16\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-15\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-14\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-13\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-12\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-11\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-10\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-9\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-8\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-7\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-6\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-5\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-4\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-3\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-2\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-1\)]\)[t] + 
            0.12833762891430928`\ \(c[0]\)[t] + 
            0.12496032289024853`\ \(c[1]\)[t] + 
            0.11643488132933186`\ \(c[2]\)[t] + 
            0.10337416789158609`\ \(c[3]\)[t] + 
            0.08654280907894489`\ \(c[4]\)[t] + 
            0.06682066312775997`\ \(c[5]\)[t] + 
            0.0451633585689193`\ \(c[6]\)[t] + 
            0.02256148180925487`\ \(c[7]\)[t] + 
            3.8981718325193755`*^-17\ \(c[8]\)[t] - 
            0.02158054781754788`\ \(c[9]\)[t] - 
            0.04131966847794722`\ \(c[10]\)[t] - 
            0.05846808023678991`\ \(c[11]\)[t] - 
            0.07241337086197412`\ \(c[12]\)[t] - 
            0.08269933431326874`\ \(c[13]\)[t] - 
            0.0890384386636067`\ \(c[14]\)[t] - 
            0.09131715903518159`\ \(c[15]\)[t] - 
            0.08959419377036688`\ \(c[16]\)[t] - 
            0.08409185873785081`\ \(c[17]\)[t] - 
            0.0751812130120626`\ \(c[18]\)[t] - 
            0.06336169950422753`\ \(c[19]\)[t] - 
            0.04923627809413894`\ \(c[20]\)[t] - 
            0.03348317962868157`\ \(c[21]\)[t] - 
            0.0168255118577494`\ \(c[22]\)[t] - 
            3.898171832519376`*^-17\ \(c[23]\)[t] + 
            0.016273855731265604`\ \(c[24]\)[t] + 
            0.03132297449134708`\ \(c[25]\)[t] + 
            0.04454710875183992`\ \(c[26]\)[t] + 
            0.05544148706619893`\ \(c[27]\)[t] + 
            0.06361487254866825`\ \(c[28]\)[t] + 
            0.06880242987642335`\ \(c[29]\)[t] + 
            0.07087301895267824`\ \(c[30]\)[t] + 
            0.06983076867396242`\ \(c[31]\)[t] + 
            0.06581101988179627`\ \(c[32]\)[t] + 
            0.059070953080906326`\ \(c[33]\)[t] + 
            0.049975424961080865`\ \(c[34]\)[t] + 
            0.03897872015785999`\ \(c[35]\)[t] + 
            0.026603074225527826`\ \(c[36]\)[t] + 
            0.013414935129827233`\ \(c[37]\)[t] + 
            3.898171832519376`*^-17\ \(c[38]\)[t] - 
            0.013061910521147383`\ \(c[39]\)[t] - 
            0.025221096343682053`\ \(c[40]\)[t] - 
            0.03598035706879378`\ \(c[41]\)[t] - 
            0.04491462243337642`\ \(c[42]\)[t] - 
            0.05168708394579296`\ \(c[43]\)[t] - 
            0.05606123915856713`\ \(c[44]\)[t] - 
            0.0579084423149932`\ \(c[45]\)[t] - 
            0.05721075023890897`\ \(c[46]\)[t] - 
            0.054059052045761224`\ \(c[47]\)[t] - 
            0.04864666724309928`\ \(c[48]\)[t] - 
            0.04125878107252025`\ \(c[49]\)[t] - 
            0.03225825116512568`\ \(c[50]\)[t] - 
            0.022068459300722043`\ \(c[51]\)[t] - 
            0.011153991006822649`\ \(c[52]\)[t] - 
            3.8981718325193755`*^-17\ \(c[53]\)[t] + 
            0.010908848347331966`\ \(c[54]\)[t] + 
            0.021108961070255627`\ \(c[55]\)[t] + 
            0.030177073670601094`\ \(c[56]\)[t] + 
            0.03774739544932687`\ \(c[57]\)[t] + 
            0.04352596542803616`\ \(c[58]\)[t] + 
            0.04730167054004106`\ \(c[59]\)[t] + 
            0.04895352855494272`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -37, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -37]][ t]], 
          Plus[ 
            Times[ -0.20645618564475834, 
              c[ -60][ t]], 
            Times[ -0.21584055771952015, 
              c[ -59][ t]], 
            Times[ -0.21623620818304484, 
              c[ -58][ t]], 
            Times[ -0.20674833578317206, 
              c[ -57][ t]], 
            Times[ -0.18675027222298593, 
              c[ -56][ t]], 
            Times[ -0.15591488063143982, 
              c[ -55][ t]], 
            Times[ -0.11423673049785459, 
              c[ -54][ t]], 
            Times[ -0.062044074975450239, 
              c[ -53][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -52][ t]], 
            Times[ 0.070907514257657456, 
              c[ -51][ t]], 
            Times[ 0.14938649372796384, 
              c[ -50][ t]], 
            Times[ 0.23387232094715985, 
              c[ -49][ t]], 
            Times[ 0.32256865202152113, 
              c[ -48][ t]], 
            Times[ 0.41349667156634429, 
              c[ -47][ t]], 
            Times[ 0.50455115242710469, 
              c[ -46][ t]], 
            Times[ 0.59356153372868015, 
              c[ -45][ t]], 
            Times[ 0.67835603854706361, 
              c[ -44][ t]], 
            Times[ 0.75682672864065692, 
              c[ -43][ t]], 
            Times[ 0.82699334313268802, 
              c[ -42][ t]], 
            Times[ 0.88706379305918392, 
              c[ -41][ t]], 
            Times[ 0.93548928378863916, 
              c[ -40][ t]], 
            Times[ 0.9710122092317629, 
              c[ -39][ t]], 
            Times[ 0.99270519960720671, 
              c[ -38][ t]], 
            Times[ 31.025529833536286, 
              c[ -37][ t]], 
            Times[ 0.99270519960720693, 
              c[ -36][ t]], 
            Times[ 0.9710122092317629, 
              c[ -35][ t]], 
            Times[ 0.93548928378863916, 
              c[ -34][ t]], 
            Times[ 0.88706379305918392, 
              c[ -33][ t]], 
            Times[ 0.82699334313268813, 
              c[ -32][ t]], 
            Times[ 0.75682672864065692, 
              c[ -31][ t]], 
            Times[ 0.67835603854706361, 
              c[ -30][ t]], 
            Times[ 0.59356153372868059, 
              c[ -29][ t]], 
            Times[ 0.50455115242710469, 
              c[ -28][ t]], 
            Times[ 0.41349667156634429, 
              c[ -27][ t]], 
            Times[ 0.32256865202152157, 
              c[ -26][ t]], 
            Times[ 0.23387232094715985, 
              c[ -25][ t]], 
            Times[ 0.14938649372796384, 
              c[ -24][ t]], 
            Times[ 0.070907514257657775, 
              c[ -23][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -22][ t]], 
            Times[ -0.062044074975450239, 
              c[ -21][ t]], 
            Times[ -0.11423673049785436, 
              c[ -20][ t]], 
            Times[ -0.15591488063143974, 
              c[ -19][ t]], 
            Times[ -0.18675027222298593, 
              c[ -18][ t]], 
            Times[ -0.206748335783172, 
              c[ -17][ t]], 
            Times[ -0.21623620818304484, 
              c[ -16][ t]], 
            Times[ -0.21584055771952015, 
              c[ -15][ t]], 
            Times[ -0.20645618564475843, 
              c[ -14][ t]], 
            Times[ -0.18920668216016426, 
              c[ -13][ t]], 
            Times[ -0.16539866862653771, 
              c[ -12][ t]], 
            Times[ -0.13647135277833605, 
              c[ -11][ t]], 
            Times[ -0.10394325375429328, 
              c[ -10][ t]], 
            Times[ -0.06935801494512607, 
              c[ -9][ t]], 
            Times[ -0.034231213779558949, 
              c[ -8][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -7][ t]], 
            Times[ 0.032022748374425904, 
              c[ -6][ t]], 
            Times[ 0.060688263076985105, 
              c[ -5][ t]], 
            Times[ 0.085044480344421608, 
              c[ -4][ t]], 
            Times[ 0.10436044624225685, 
              c[ -3][ t]], 
            Times[ 0.11814190616181255, 
              c[ -2][ t]], 
            Times[ 0.12613778810677612, 
              c[ -1][ t]], 
            Times[ 0.12833762891430928, 
              c[ 0][ t]], 
            Times[ 0.12496032289024853, 
              c[ 1][ t]], 
            Times[ 0.11643488132933186, 
              c[ 2][ t]], 
            Times[ 0.10337416789158609, 
              c[ 3][ t]], 
            Times[ 0.086542809078944891, 
              c[ 4][ t]], 
            Times[ 0.066820663127759972, 
              c[ 5][ t]], 
            Times[ 0.045163358568919301, 
              c[ 6][ t]], 
            Times[ 0.022561481809254869, 
              c[ 7][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 8][ t]], 
            Times[ -0.021580547817547879, 
              c[ 9][ t]], 
            Times[ -0.04131966847794722, 
              c[ 10][ t]], 
            Times[ -0.058468080236789913, 
              c[ 11][ t]], 
            Times[ -0.072413370861974122, 
              c[ 12][ t]], 
            Times[ -0.082699334313268744, 
              c[ 13][ t]], 
            Times[ -0.089038438663606695, 
              c[ 14][ t]], 
            Times[ -0.091317159035181589, 
              c[ 15][ t]], 
            Times[ -0.089594193770366884, 
              c[ 16][ t]], 
            Times[ -0.084091858737850814, 
              c[ 17][ t]], 
            Times[ -0.075181213012062598, 
              c[ 18][ t]], 
            Times[ -0.063361699504227528, 
              c[ 19][ t]], 
            Times[ -0.049236278094138941, 
              c[ 20][ t]], 
            Times[ -0.033483179628681567, 
              c[ 21][ t]], 
            Times[ -0.016825511857749401, 
              c[ 22][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 23][ t]], 
            Times[ 0.016273855731265604, 
              c[ 24][ t]], 
            Times[ 0.031322974491347078, 
              c[ 25][ t]], 
            Times[ 0.044547108751839919, 
              c[ 26][ t]], 
            Times[ 0.055441487066198933, 
              c[ 27][ t]], 
            Times[ 0.063614872548668253, 
              c[ 28][ t]], 
            Times[ 0.068802429876423349, 
              c[ 29][ t]], 
            Times[ 0.070873018952678238, 
              c[ 30][ t]], 
            Times[ 0.069830768673962415, 
              c[ 31][ t]], 
            Times[ 0.065811019881796273, 
              c[ 32][ t]], 
            Times[ 0.059070953080906326, 
              c[ 33][ t]], 
            Times[ 0.049975424961080865, 
              c[ 34][ t]], 
            Times[ 0.03897872015785999, 
              c[ 35][ t]], 
            Times[ 0.026603074225527826, 
              c[ 36][ t]], 
            Times[ 0.013414935129827233, 
              c[ 37][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 38][ t]], 
            Times[ -0.013061910521147383, 
              c[ 39][ t]], 
            Times[ -0.025221096343682053, 
              c[ 40][ t]], 
            Times[ -0.035980357068793781, 
              c[ 41][ t]], 
            Times[ -0.044914622433376419, 
              c[ 42][ t]], 
            Times[ -0.05168708394579296, 
              c[ 43][ t]], 
            Times[ -0.05606123915856713, 
              c[ 44][ t]], 
            Times[ -0.057908442314993203, 
              c[ 45][ t]], 
            Times[ -0.057210750238908967, 
              c[ 46][ t]], 
            Times[ -0.054059052045761224, 
              c[ 47][ t]], 
            Times[ -0.048646667243099281, 
              c[ 48][ t]], 
            Times[ -0.041258781072520248, 
              c[ 49][ t]], 
            Times[ -0.032258251165125679, 
              c[ 50][ t]], 
            Times[ -0.022068459300722043, 
              c[ 51][ t]], 
            Times[ -0.011153991006822649, 
              c[ 52][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 53][ t]], 
            Times[ 0.010908848347331966, 
              c[ 54][ t]], 
            Times[ 0.021108961070255627, 
              c[ 55][ t]], 
            Times[ 0.030177073670601094, 
              c[ 56][ t]], 
            Times[ 0.03774739544932687, 
              c[ 57][ t]], 
            Times[ 0.043525965428036162, 
              c[ 58][ t]], 
            Times[ 0.047301670540041058, 
              c[ 59][ t]], 
            Times[ 0.04895352855494272, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-36\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-36\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.18920668216016426`\)\ \(c[\(-60\)]\)[t] - 
            0.20645618564475848`\ \(c[\(-59\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-58\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-57\)]\)[t] - 
            0.2067483357831719`\ \(c[\(-56\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-55\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-54\)]\)[t] - 
            0.11423673049785416`\ \(c[\(-53\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-52\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-51\)]\)[t] + 
            0.0709075142576581`\ \(c[\(-50\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-49\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-48\)]\)[t] + 
            0.3225686520215219`\ \(c[\(-47\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-46\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-45\)]\)[t] + 
            0.5935615337286809`\ \(c[\(-44\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-43\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-42\)]\)[t] + 
            0.8269933431326885`\ \(c[\(-41\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-40\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-39\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-38\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-37\)]\)[t] + 
            29.42446067513735`\ \(c[\(-36\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-35\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-34\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-33\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-32\)]\)[t] + 
            0.826993343132688`\ \(c[\(-31\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-30\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-29\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-28\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-27\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-26\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-25\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-24\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-23\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-22\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-21\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-20\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-19\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-18\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-17\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-16\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-15\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-14\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-13\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-12\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-11\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-10\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-9\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-8\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-7\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-6\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-5\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-4\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-3\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-2\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-1\)]\)[t] + 
            0.12613778810677614`\ \(c[0]\)[t] + 
            0.12833762891430925`\ \(c[1]\)[t] + 
            0.12496032289024853`\ \(c[2]\)[t] + 
            0.11643488132933186`\ \(c[3]\)[t] + 
            0.10337416789158609`\ \(c[4]\)[t] + 
            0.08654280907894475`\ \(c[5]\)[t] + 
            0.06682066312775997`\ \(c[6]\)[t] + 
            0.0451633585689193`\ \(c[7]\)[t] + 
            0.022561481809254675`\ \(c[8]\)[t] + 
            3.8981718325193755`*^-17\ \(c[9]\)[t] - 
            0.02158054781754788`\ \(c[10]\)[t] - 
            0.04131966847794722`\ \(c[11]\)[t] - 
            0.05846808023678991`\ \(c[12]\)[t] - 
            0.07241337086197412`\ \(c[13]\)[t] - 
            0.08269933431326874`\ \(c[14]\)[t] - 
            0.0890384386636067`\ \(c[15]\)[t] - 
            0.09131715903518159`\ \(c[16]\)[t] - 
            0.08959419377036688`\ \(c[17]\)[t] - 
            0.08409185873785081`\ \(c[18]\)[t] - 
            0.0751812130120626`\ \(c[19]\)[t] - 
            0.06336169950422753`\ \(c[20]\)[t] - 
            0.04923627809413894`\ \(c[21]\)[t] - 
            0.03348317962868157`\ \(c[22]\)[t] - 
            0.0168255118577494`\ \(c[23]\)[t] - 
            3.898171832519376`*^-17\ \(c[24]\)[t] + 
            0.016273855731265604`\ \(c[25]\)[t] + 
            0.03132297449134708`\ \(c[26]\)[t] + 
            0.04454710875183992`\ \(c[27]\)[t] + 
            0.05544148706619893`\ \(c[28]\)[t] + 
            0.06361487254866825`\ \(c[29]\)[t] + 
            0.06880242987642335`\ \(c[30]\)[t] + 
            0.07087301895267824`\ \(c[31]\)[t] + 
            0.06983076867396242`\ \(c[32]\)[t] + 
            0.06581101988179627`\ \(c[33]\)[t] + 
            0.059070953080906326`\ \(c[34]\)[t] + 
            0.049975424961080865`\ \(c[35]\)[t] + 
            0.03897872015785999`\ \(c[36]\)[t] + 
            0.026603074225527826`\ \(c[37]\)[t] + 
            0.013414935129827233`\ \(c[38]\)[t] + 
            3.898171832519376`*^-17\ \(c[39]\)[t] - 
            0.013061910521147383`\ \(c[40]\)[t] - 
            0.025221096343682053`\ \(c[41]\)[t] - 
            0.03598035706879378`\ \(c[42]\)[t] - 
            0.04491462243337642`\ \(c[43]\)[t] - 
            0.05168708394579296`\ \(c[44]\)[t] - 
            0.056061239158567186`\ \(c[45]\)[t] - 
            0.0579084423149932`\ \(c[46]\)[t] - 
            0.05721075023890897`\ \(c[47]\)[t] - 
            0.054059052045761224`\ \(c[48]\)[t] - 
            0.04864666724309928`\ \(c[49]\)[t] - 
            0.04125878107252025`\ \(c[50]\)[t] - 
            0.03225825116512552`\ \(c[51]\)[t] - 
            0.022068459300722043`\ \(c[52]\)[t] - 
            0.011153991006822649`\ \(c[53]\)[t] - 
            3.8981718325193755`*^-17\ \(c[54]\)[t] + 
            0.010908848347331966`\ \(c[55]\)[t] + 
            0.021108961070255627`\ \(c[56]\)[t] + 
            0.030177073670601236`\ \(c[57]\)[t] + 
            0.03774739544932687`\ \(c[58]\)[t] + 
            0.04352596542803616`\ \(c[59]\)[t] + 
            0.04730167054004106`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -36, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -36]][ t]], 
          Plus[ 
            Times[ -0.18920668216016426, 
              c[ -60][ t]], 
            Times[ -0.20645618564475848, 
              c[ -59][ t]], 
            Times[ -0.21584055771952015, 
              c[ -58][ t]], 
            Times[ -0.21623620818304484, 
              c[ -57][ t]], 
            Times[ -0.20674833578317189, 
              c[ -56][ t]], 
            Times[ -0.18675027222298593, 
              c[ -55][ t]], 
            Times[ -0.15591488063143982, 
              c[ -54][ t]], 
            Times[ -0.11423673049785416, 
              c[ -53][ t]], 
            Times[ -0.062044074975450239, 
              c[ -52][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -51][ t]], 
            Times[ 0.070907514257658094, 
              c[ -50][ t]], 
            Times[ 0.14938649372796384, 
              c[ -49][ t]], 
            Times[ 0.23387232094715985, 
              c[ -48][ t]], 
            Times[ 0.32256865202152191, 
              c[ -47][ t]], 
            Times[ 0.41349667156634429, 
              c[ -46][ t]], 
            Times[ 0.50455115242710469, 
              c[ -45][ t]], 
            Times[ 0.59356153372868092, 
              c[ -44][ t]], 
            Times[ 0.67835603854706361, 
              c[ -43][ t]], 
            Times[ 0.75682672864065692, 
              c[ -42][ t]], 
            Times[ 0.82699334313268846, 
              c[ -41][ t]], 
            Times[ 0.88706379305918392, 
              c[ -40][ t]], 
            Times[ 0.93548928378863916, 
              c[ -39][ t]], 
            Times[ 0.9710122092317629, 
              c[ -38][ t]], 
            Times[ 0.99270519960720693, 
              c[ -37][ t]], 
            Times[ 29.42446067513735, 
              c[ -36][ t]], 
            Times[ 0.99270519960720671, 
              c[ -35][ t]], 
            Times[ 0.9710122092317629, 
              c[ -34][ t]], 
            Times[ 0.93548928378863916, 
              c[ -33][ t]], 
            Times[ 0.88706379305918381, 
              c[ -32][ t]], 
            Times[ 0.82699334313268802, 
              c[ -31][ t]], 
            Times[ 0.75682672864065692, 
              c[ -30][ t]], 
            Times[ 0.67835603854706317, 
              c[ -29][ t]], 
            Times[ 0.59356153372868015, 
              c[ -28][ t]], 
            Times[ 0.50455115242710469, 
              c[ -27][ t]], 
            Times[ 0.41349667156634395, 
              c[ -26][ t]], 
            Times[ 0.32256865202152113, 
              c[ -25][ t]], 
            Times[ 0.23387232094715985, 
              c[ -24][ t]], 
            Times[ 0.14938649372796345, 
              c[ -23][ t]], 
            Times[ 0.070907514257657456, 
              c[ -22][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -21][ t]], 
            Times[ -0.062044074975450475, 
              c[ -20][ t]], 
            Times[ -0.11423673049785445, 
              c[ -19][ t]], 
            Times[ -0.15591488063143982, 
              c[ -18][ t]], 
            Times[ -0.18675027222298607, 
              c[ -17][ t]], 
            Times[ -0.20674833578317206, 
              c[ -16][ t]], 
            Times[ -0.21623620818304484, 
              c[ -15][ t]], 
            Times[ -0.21584055771952013, 
              c[ -14][ t]], 
            Times[ -0.20645618564475834, 
              c[ -13][ t]], 
            Times[ -0.18920668216016426, 
              c[ -12][ t]], 
            Times[ -0.1653986686265376, 
              c[ -11][ t]], 
            Times[ -0.13647135277833591, 
              c[ -10][ t]], 
            Times[ -0.10394325375429328, 
              c[ -9][ t]], 
            Times[ -0.069358014945125918, 
              c[ -8][ t]], 
            Times[ -0.034231213779558796, 
              c[ -7][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -6][ t]], 
            Times[ 0.032022748374426029, 
              c[ -5][ t]], 
            Times[ 0.060688263076985105, 
              c[ -4][ t]], 
            Times[ 0.085044480344421705, 
              c[ -3][ t]], 
            Times[ 0.10436044624225692, 
              c[ -2][ t]], 
            Times[ 0.11814190616181255, 
              c[ -1][ t]], 
            Times[ 0.12613778810677614, 
              c[ 0][ t]], 
            Times[ 0.12833762891430925, 
              c[ 1][ t]], 
            Times[ 0.12496032289024853, 
              c[ 2][ t]], 
            Times[ 0.11643488132933186, 
              c[ 3][ t]], 
            Times[ 0.10337416789158609, 
              c[ 4][ t]], 
            Times[ 0.086542809078944752, 
              c[ 5][ t]], 
            Times[ 0.066820663127759972, 
              c[ 6][ t]], 
            Times[ 0.045163358568919301, 
              c[ 7][ t]], 
            Times[ 0.022561481809254675, 
              c[ 8][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 9][ t]], 
            Times[ -0.021580547817547879, 
              c[ 10][ t]], 
            Times[ -0.04131966847794722, 
              c[ 11][ t]], 
            Times[ -0.058468080236789913, 
              c[ 12][ t]], 
            Times[ -0.072413370861974122, 
              c[ 13][ t]], 
            Times[ -0.082699334313268744, 
              c[ 14][ t]], 
            Times[ -0.089038438663606695, 
              c[ 15][ t]], 
            Times[ -0.091317159035181589, 
              c[ 16][ t]], 
            Times[ -0.089594193770366884, 
              c[ 17][ t]], 
            Times[ -0.084091858737850814, 
              c[ 18][ t]], 
            Times[ -0.075181213012062598, 
              c[ 19][ t]], 
            Times[ -0.063361699504227528, 
              c[ 20][ t]], 
            Times[ -0.049236278094138941, 
              c[ 21][ t]], 
            Times[ -0.033483179628681567, 
              c[ 22][ t]], 
            Times[ -0.016825511857749401, 
              c[ 23][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 24][ t]], 
            Times[ 0.016273855731265604, 
              c[ 25][ t]], 
            Times[ 0.031322974491347078, 
              c[ 26][ t]], 
            Times[ 0.044547108751839919, 
              c[ 27][ t]], 
            Times[ 0.055441487066198933, 
              c[ 28][ t]], 
            Times[ 0.063614872548668253, 
              c[ 29][ t]], 
            Times[ 0.068802429876423349, 
              c[ 30][ t]], 
            Times[ 0.070873018952678238, 
              c[ 31][ t]], 
            Times[ 0.069830768673962415, 
              c[ 32][ t]], 
            Times[ 0.065811019881796273, 
              c[ 33][ t]], 
            Times[ 0.059070953080906326, 
              c[ 34][ t]], 
            Times[ 0.049975424961080865, 
              c[ 35][ t]], 
            Times[ 0.03897872015785999, 
              c[ 36][ t]], 
            Times[ 0.026603074225527826, 
              c[ 37][ t]], 
            Times[ 0.013414935129827233, 
              c[ 38][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 39][ t]], 
            Times[ -0.013061910521147383, 
              c[ 40][ t]], 
            Times[ -0.025221096343682053, 
              c[ 41][ t]], 
            Times[ -0.035980357068793781, 
              c[ 42][ t]], 
            Times[ -0.044914622433376419, 
              c[ 43][ t]], 
            Times[ -0.05168708394579296, 
              c[ 44][ t]], 
            Times[ -0.056061239158567186, 
              c[ 45][ t]], 
            Times[ -0.057908442314993203, 
              c[ 46][ t]], 
            Times[ -0.057210750238908967, 
              c[ 47][ t]], 
            Times[ -0.054059052045761224, 
              c[ 48][ t]], 
            Times[ -0.048646667243099281, 
              c[ 49][ t]], 
            Times[ -0.041258781072520248, 
              c[ 50][ t]], 
            Times[ -0.032258251165125519, 
              c[ 51][ t]], 
            Times[ -0.022068459300722043, 
              c[ 52][ t]], 
            Times[ -0.011153991006822649, 
              c[ 53][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 54][ t]], 
            Times[ 0.010908848347331966, 
              c[ 55][ t]], 
            Times[ 0.021108961070255627, 
              c[ 56][ t]], 
            Times[ 0.030177073670601236, 
              c[ 57][ t]], 
            Times[ 0.03774739544932687, 
              c[ 58][ t]], 
            Times[ 0.043525965428036162, 
              c[ 59][ t]], 
            Times[ 0.047301670540041058, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-35\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-35\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.1653986686265376`\)\ \(c[\(-60\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-59\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-58\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-57\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-56\)]\)[t] - 
            0.206748335783172`\ \(c[\(-55\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-54\)]\)[t] - 
            0.15591488063143966`\ \(c[\(-53\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-52\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-51\)]\)[t] + 
            3.216976900108398`*^-16\ \(c[\(-50\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-49\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-48\)]\)[t] + 
            0.23387232094716018`\ \(c[\(-47\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-46\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-45\)]\)[t] + 
            0.504551152427105`\ \(c[\(-44\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-43\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-42\)]\)[t] + 
            0.7568267286406574`\ \(c[\(-41\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-40\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-39\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-38\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-37\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-36\)]\)[t] + 
            27.867256425187694`\ \(c[\(-35\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-34\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-33\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-32\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-31\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-30\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-29\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-28\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-27\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-26\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-25\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-24\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-23\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-22\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-21\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-20\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-19\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-18\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-17\)]\)[t] - 
            0.186750272222986`\ \(c[\(-16\)]\)[t] - 
            0.206748335783172`\ \(c[\(-15\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-14\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-13\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-12\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-11\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-10\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-9\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-8\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-7\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-6\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-5\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-4\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-3\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-2\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-1\)]\)[t] + 
            0.11814190616181255`\ \(c[0]\)[t] + 
            0.12613778810677614`\ \(c[1]\)[t] + 
            0.12833762891430928`\ \(c[2]\)[t] + 
            0.12496032289024853`\ \(c[3]\)[t] + 
            0.11643488132933186`\ \(c[4]\)[t] + 
            0.10337416789158609`\ \(c[5]\)[t] + 
            0.08654280907894489`\ \(c[6]\)[t] + 
            0.06682066312775997`\ \(c[7]\)[t] + 
            0.0451633585689193`\ \(c[8]\)[t] + 
            0.02256148180925487`\ \(c[9]\)[t] + 
            3.8981718325193755`*^-17\ \(c[10]\)[t] - 
            0.02158054781754788`\ \(c[11]\)[t] - 
            0.04131966847794722`\ \(c[12]\)[t] - 
            0.05846808023678991`\ \(c[13]\)[t] - 
            0.07241337086197412`\ \(c[14]\)[t] - 
            0.08269933431326874`\ \(c[15]\)[t] - 
            0.0890384386636067`\ \(c[16]\)[t] - 
            0.09131715903518159`\ \(c[17]\)[t] - 
            0.08959419377036688`\ \(c[18]\)[t] - 
            0.08409185873785081`\ \(c[19]\)[t] - 
            0.0751812130120626`\ \(c[20]\)[t] - 
            0.06336169950422753`\ \(c[21]\)[t] - 
            0.04923627809413894`\ \(c[22]\)[t] - 
            0.03348317962868157`\ \(c[23]\)[t] - 
            0.0168255118577494`\ \(c[24]\)[t] - 
            3.898171832519376`*^-17\ \(c[25]\)[t] + 
            0.016273855731265604`\ \(c[26]\)[t] + 
            0.03132297449134708`\ \(c[27]\)[t] + 
            0.04454710875183992`\ \(c[28]\)[t] + 
            0.05544148706619893`\ \(c[29]\)[t] + 
            0.06361487254866825`\ \(c[30]\)[t] + 
            0.06880242987642335`\ \(c[31]\)[t] + 
            0.07087301895267824`\ \(c[32]\)[t] + 
            0.06983076867396242`\ \(c[33]\)[t] + 
            0.06581101988179627`\ \(c[34]\)[t] + 
            0.059070953080906326`\ \(c[35]\)[t] + 
            0.049975424961080865`\ \(c[36]\)[t] + 
            0.03897872015785999`\ \(c[37]\)[t] + 
            0.026603074225527826`\ \(c[38]\)[t] + 
            0.013414935129827233`\ \(c[39]\)[t] + 
            3.898171832519376`*^-17\ \(c[40]\)[t] - 
            0.013061910521147276`\ \(c[41]\)[t] - 
            0.025221096343682053`\ \(c[42]\)[t] - 
            0.03598035706879378`\ \(c[43]\)[t] - 
            0.04491462243337629`\ \(c[44]\)[t] - 
            0.05168708394579296`\ \(c[45]\)[t] - 
            0.056061239158567186`\ \(c[46]\)[t] - 
            0.0579084423149932`\ \(c[47]\)[t] - 
            0.05721075023890897`\ \(c[48]\)[t] - 
            0.054059052045761224`\ \(c[49]\)[t] - 
            0.0486466672430994`\ \(c[50]\)[t] - 
            0.04125878107252025`\ \(c[51]\)[t] - 
            0.03225825116512552`\ \(c[52]\)[t] - 
            0.022068459300722043`\ \(c[53]\)[t] - 
            0.011153991006822649`\ \(c[54]\)[t] - 
            3.8981718325193755`*^-17\ \(c[55]\)[t] + 
            0.010908848347331785`\ \(c[56]\)[t] + 
            0.021108961070255627`\ \(c[57]\)[t] + 
            0.030177073670601236`\ \(c[58]\)[t] + 
            0.03774739544932687`\ \(c[59]\)[t] + 
            0.04352596542803616`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -35, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -35]][ t]], 
          Plus[ 
            Times[ -0.1653986686265376, 
              c[ -60][ t]], 
            Times[ -0.18920668216016434, 
              c[ -59][ t]], 
            Times[ -0.20645618564475843, 
              c[ -58][ t]], 
            Times[ -0.21584055771952013, 
              c[ -57][ t]], 
            Times[ -0.21623620818304481, 
              c[ -56][ t]], 
            Times[ -0.206748335783172, 
              c[ -55][ t]], 
            Times[ -0.18675027222298607, 
              c[ -54][ t]], 
            Times[ -0.15591488063143966, 
              c[ -53][ t]], 
            Times[ -0.11423673049785436, 
              c[ -52][ t]], 
            Times[ -0.062044074975450475, 
              c[ -51][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ -50][ t]], 
            Times[ 0.070907514257657775, 
              c[ -49][ t]], 
            Times[ 0.14938649372796345, 
              c[ -48][ t]], 
            Times[ 0.23387232094716018, 
              c[ -47][ t]], 
            Times[ 0.32256865202152157, 
              c[ -46][ t]], 
            Times[ 0.41349667156634395, 
              c[ -45][ t]], 
            Times[ 0.50455115242710502, 
              c[ -44][ t]], 
            Times[ 0.59356153372868059, 
              c[ -43][ t]], 
            Times[ 0.67835603854706317, 
              c[ -42][ t]], 
            Times[ 0.75682672864065736, 
              c[ -41][ t]], 
            Times[ 0.82699334313268813, 
              c[ -40][ t]], 
            Times[ 0.88706379305918381, 
              c[ -39][ t]], 
            Times[ 0.93548928378863916, 
              c[ -38][ t]], 
            Times[ 0.9710122092317629, 
              c[ -37][ t]], 
            Times[ 0.99270519960720671, 
              c[ -36][ t]], 
            Times[ 27.867256425187694, 
              c[ -35][ t]], 
            Times[ 0.99270519960720671, 
              c[ -34][ t]], 
            Times[ 0.9710122092317629, 
              c[ -33][ t]], 
            Times[ 0.93548928378863916, 
              c[ -32][ t]], 
            Times[ 0.88706379305918381, 
              c[ -31][ t]], 
            Times[ 0.82699334313268813, 
              c[ -30][ t]], 
            Times[ 0.75682672864065692, 
              c[ -29][ t]], 
            Times[ 0.67835603854706317, 
              c[ -28][ t]], 
            Times[ 0.59356153372868059, 
              c[ -27][ t]], 
            Times[ 0.50455115242710469, 
              c[ -26][ t]], 
            Times[ 0.41349667156634395, 
              c[ -25][ t]], 
            Times[ 0.32256865202152157, 
              c[ -24][ t]], 
            Times[ 0.23387232094715985, 
              c[ -23][ t]], 
            Times[ 0.14938649372796345, 
              c[ -22][ t]], 
            Times[ 0.070907514257657775, 
              c[ -21][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -20][ t]], 
            Times[ -0.062044074975450343, 
              c[ -19][ t]], 
            Times[ -0.11423673049785436, 
              c[ -18][ t]], 
            Times[ -0.15591488063143982, 
              c[ -17][ t]], 
            Times[ -0.18675027222298601, 
              c[ -16][ t]], 
            Times[ -0.206748335783172, 
              c[ -15][ t]], 
            Times[ -0.21623620818304484, 
              c[ -14][ t]], 
            Times[ -0.21584055771952015, 
              c[ -13][ t]], 
            Times[ -0.20645618564475843, 
              c[ -12][ t]], 
            Times[ -0.18920668216016426, 
              c[ -11][ t]], 
            Times[ -0.16539866862653771, 
              c[ -10][ t]], 
            Times[ -0.13647135277833605, 
              c[ -9][ t]], 
            Times[ -0.10394325375429328, 
              c[ -8][ t]], 
            Times[ -0.06935801494512607, 
              c[ -7][ t]], 
            Times[ -0.034231213779558949, 
              c[ -6][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -5][ t]], 
            Times[ 0.032022748374425904, 
              c[ -4][ t]], 
            Times[ 0.060688263076985105, 
              c[ -3][ t]], 
            Times[ 0.085044480344421705, 
              c[ -2][ t]], 
            Times[ 0.10436044624225685, 
              c[ -1][ t]], 
            Times[ 0.11814190616181255, 
              c[ 0][ t]], 
            Times[ 0.12613778810677614, 
              c[ 1][ t]], 
            Times[ 0.12833762891430928, 
              c[ 2][ t]], 
            Times[ 0.12496032289024853, 
              c[ 3][ t]], 
            Times[ 0.11643488132933186, 
              c[ 4][ t]], 
            Times[ 0.10337416789158609, 
              c[ 5][ t]], 
            Times[ 0.086542809078944891, 
              c[ 6][ t]], 
            Times[ 0.066820663127759972, 
              c[ 7][ t]], 
            Times[ 0.045163358568919301, 
              c[ 8][ t]], 
            Times[ 0.022561481809254869, 
              c[ 9][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 10][ t]], 
            Times[ -0.021580547817547879, 
              c[ 11][ t]], 
            Times[ -0.04131966847794722, 
              c[ 12][ t]], 
            Times[ -0.058468080236789913, 
              c[ 13][ t]], 
            Times[ -0.072413370861974122, 
              c[ 14][ t]], 
            Times[ -0.082699334313268744, 
              c[ 15][ t]], 
            Times[ -0.089038438663606695, 
              c[ 16][ t]], 
            Times[ -0.091317159035181589, 
              c[ 17][ t]], 
            Times[ -0.089594193770366884, 
              c[ 18][ t]], 
            Times[ -0.084091858737850814, 
              c[ 19][ t]], 
            Times[ -0.075181213012062598, 
              c[ 20][ t]], 
            Times[ -0.063361699504227528, 
              c[ 21][ t]], 
            Times[ -0.049236278094138941, 
              c[ 22][ t]], 
            Times[ -0.033483179628681567, 
              c[ 23][ t]], 
            Times[ -0.016825511857749401, 
              c[ 24][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 25][ t]], 
            Times[ 0.016273855731265604, 
              c[ 26][ t]], 
            Times[ 0.031322974491347078, 
              c[ 27][ t]], 
            Times[ 0.044547108751839919, 
              c[ 28][ t]], 
            Times[ 0.055441487066198933, 
              c[ 29][ t]], 
            Times[ 0.063614872548668253, 
              c[ 30][ t]], 
            Times[ 0.068802429876423349, 
              c[ 31][ t]], 
            Times[ 0.070873018952678238, 
              c[ 32][ t]], 
            Times[ 0.069830768673962415, 
              c[ 33][ t]], 
            Times[ 0.065811019881796273, 
              c[ 34][ t]], 
            Times[ 0.059070953080906326, 
              c[ 35][ t]], 
            Times[ 0.049975424961080865, 
              c[ 36][ t]], 
            Times[ 0.03897872015785999, 
              c[ 37][ t]], 
            Times[ 0.026603074225527826, 
              c[ 38][ t]], 
            Times[ 0.013414935129827233, 
              c[ 39][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 40][ t]], 
            Times[ -0.013061910521147276, 
              c[ 41][ t]], 
            Times[ -0.025221096343682053, 
              c[ 42][ t]], 
            Times[ -0.035980357068793781, 
              c[ 43][ t]], 
            Times[ -0.044914622433376288, 
              c[ 44][ t]], 
            Times[ -0.05168708394579296, 
              c[ 45][ t]], 
            Times[ -0.056061239158567186, 
              c[ 46][ t]], 
            Times[ -0.057908442314993203, 
              c[ 47][ t]], 
            Times[ -0.057210750238908967, 
              c[ 48][ t]], 
            Times[ -0.054059052045761224, 
              c[ 49][ t]], 
            Times[ -0.048646667243099399, 
              c[ 50][ t]], 
            Times[ -0.041258781072520248, 
              c[ 51][ t]], 
            Times[ -0.032258251165125519, 
              c[ 52][ t]], 
            Times[ -0.022068459300722043, 
              c[ 53][ t]], 
            Times[ -0.011153991006822649, 
              c[ 54][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 55][ t]], 
            Times[ 0.010908848347331785, 
              c[ 56][ t]], 
            Times[ 0.021108961070255627, 
              c[ 57][ t]], 
            Times[ 0.030177073670601236, 
              c[ 58][ t]], 
            Times[ 0.03774739544932687, 
              c[ 59][ t]], 
            Times[ 0.043525965428036162, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-34\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-34\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.1364713527783359`\)\ \(c[\(-60\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-59\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-58\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-57\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-56\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-55\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-54\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-53\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-52\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-51\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-50\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-49\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-48\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-47\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-46\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-45\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-44\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-43\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-42\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-41\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-40\)]\)[t] + 
            0.826993343132688`\ \(c[\(-39\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-38\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-37\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-36\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-35\)]\)[t] + 
            26.353917083687325`\ \(c[\(-34\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-33\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-32\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-31\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-30\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-29\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-28\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-27\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-26\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-25\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-24\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-23\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-22\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-21\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-20\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-19\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-18\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-17\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-16\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-15\)]\)[t] - 
            0.206748335783172`\ \(c[\(-14\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-13\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-12\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-11\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-10\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-9\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-8\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-7\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-6\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-5\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-4\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-3\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-2\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-1\)]\)[t] + 
            0.10436044624225685`\ \(c[0]\)[t] + 
            0.11814190616181255`\ \(c[1]\)[t] + 
            0.12613778810677612`\ \(c[2]\)[t] + 
            0.12833762891430928`\ \(c[3]\)[t] + 
            0.12496032289024853`\ \(c[4]\)[t] + 
            0.11643488132933186`\ \(c[5]\)[t] + 
            0.10337416789158609`\ \(c[6]\)[t] + 
            0.08654280907894489`\ \(c[7]\)[t] + 
            0.06682066312775997`\ \(c[8]\)[t] + 
            0.0451633585689193`\ \(c[9]\)[t] + 
            0.02256148180925487`\ \(c[10]\)[t] + 
            3.8981718325193755`*^-17\ \(c[11]\)[t] - 
            0.02158054781754788`\ \(c[12]\)[t] - 
            0.04131966847794722`\ \(c[13]\)[t] - 
            0.05846808023678991`\ \(c[14]\)[t] - 
            0.07241337086197412`\ \(c[15]\)[t] - 
            0.08269933431326874`\ \(c[16]\)[t] - 
            0.0890384386636067`\ \(c[17]\)[t] - 
            0.09131715903518159`\ \(c[18]\)[t] - 
            0.08959419377036688`\ \(c[19]\)[t] - 
            0.08409185873785081`\ \(c[20]\)[t] - 
            0.0751812130120626`\ \(c[21]\)[t] - 
            0.06336169950422753`\ \(c[22]\)[t] - 
            0.04923627809413894`\ \(c[23]\)[t] - 
            0.03348317962868157`\ \(c[24]\)[t] - 
            0.0168255118577494`\ \(c[25]\)[t] - 
            3.898171832519376`*^-17\ \(c[26]\)[t] + 
            0.016273855731265604`\ \(c[27]\)[t] + 
            0.03132297449134708`\ \(c[28]\)[t] + 
            0.04454710875183992`\ \(c[29]\)[t] + 
            0.05544148706619893`\ \(c[30]\)[t] + 
            0.06361487254866825`\ \(c[31]\)[t] + 
            0.06880242987642335`\ \(c[32]\)[t] + 
            0.07087301895267824`\ \(c[33]\)[t] + 
            0.06983076867396242`\ \(c[34]\)[t] + 
            0.06581101988179627`\ \(c[35]\)[t] + 
            0.059070953080906326`\ \(c[36]\)[t] + 
            0.049975424961080865`\ \(c[37]\)[t] + 
            0.03897872015785999`\ \(c[38]\)[t] + 
            0.026603074225527826`\ \(c[39]\)[t] + 
            0.013414935129827233`\ \(c[40]\)[t] + 
            1.5206810699945212`*^-16\ \(c[41]\)[t] - 
            0.013061910521147383`\ \(c[42]\)[t] - 
            0.025221096343682053`\ \(c[43]\)[t] - 
            0.03598035706879378`\ \(c[44]\)[t] - 
            0.04491462243337642`\ \(c[45]\)[t] - 
            0.05168708394579296`\ \(c[46]\)[t] - 
            0.05606123915856713`\ \(c[47]\)[t] - 
            0.0579084423149932`\ \(c[48]\)[t] - 
            0.05721075023890897`\ \(c[49]\)[t] - 
            0.054059052045761224`\ \(c[50]\)[t] - 
            0.04864666724309928`\ \(c[51]\)[t] - 
            0.04125878107252025`\ \(c[52]\)[t] - 
            0.03225825116512568`\ \(c[53]\)[t] - 
            0.022068459300722043`\ \(c[54]\)[t] - 
            0.011153991006822649`\ \(c[55]\)[t] - 
            3.8981718325193755`*^-17\ \(c[56]\)[t] + 
            0.010908848347331966`\ \(c[57]\)[t] + 
            0.021108961070255627`\ \(c[58]\)[t] + 
            0.030177073670601094`\ \(c[59]\)[t] + 
            0.03774739544932687`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -34, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -34]][ t]], 
          Plus[ 
            Times[ -0.13647135277833591, 
              c[ -60][ t]], 
            Times[ -0.16539866862653771, 
              c[ -59][ t]], 
            Times[ -0.18920668216016426, 
              c[ -58][ t]], 
            Times[ -0.20645618564475834, 
              c[ -57][ t]], 
            Times[ -0.21584055771952015, 
              c[ -56][ t]], 
            Times[ -0.21623620818304484, 
              c[ -55][ t]], 
            Times[ -0.20674833578317206, 
              c[ -54][ t]], 
            Times[ -0.18675027222298593, 
              c[ -53][ t]], 
            Times[ -0.15591488063143982, 
              c[ -52][ t]], 
            Times[ -0.11423673049785459, 
              c[ -51][ t]], 
            Times[ -0.062044074975450239, 
              c[ -50][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -49][ t]], 
            Times[ 0.070907514257657456, 
              c[ -48][ t]], 
            Times[ 0.14938649372796384, 
              c[ -47][ t]], 
            Times[ 0.23387232094715985, 
              c[ -46][ t]], 
            Times[ 0.32256865202152113, 
              c[ -45][ t]], 
            Times[ 0.41349667156634429, 
              c[ -44][ t]], 
            Times[ 0.50455115242710469, 
              c[ -43][ t]], 
            Times[ 0.59356153372868015, 
              c[ -42][ t]], 
            Times[ 0.67835603854706361, 
              c[ -41][ t]], 
            Times[ 0.75682672864065692, 
              c[ -40][ t]], 
            Times[ 0.82699334313268802, 
              c[ -39][ t]], 
            Times[ 0.88706379305918381, 
              c[ -38][ t]], 
            Times[ 0.93548928378863916, 
              c[ -37][ t]], 
            Times[ 0.9710122092317629, 
              c[ -36][ t]], 
            Times[ 0.99270519960720671, 
              c[ -35][ t]], 
            Times[ 26.353917083687325, 
              c[ -34][ t]], 
            Times[ 0.99270519960720693, 
              c[ -33][ t]], 
            Times[ 0.9710122092317629, 
              c[ -32][ t]], 
            Times[ 0.93548928378863916, 
              c[ -31][ t]], 
            Times[ 0.88706379305918392, 
              c[ -30][ t]], 
            Times[ 0.82699334313268813, 
              c[ -29][ t]], 
            Times[ 0.75682672864065692, 
              c[ -28][ t]], 
            Times[ 0.67835603854706361, 
              c[ -27][ t]], 
            Times[ 0.59356153372868059, 
              c[ -26][ t]], 
            Times[ 0.50455115242710469, 
              c[ -25][ t]], 
            Times[ 0.41349667156634429, 
              c[ -24][ t]], 
            Times[ 0.32256865202152157, 
              c[ -23][ t]], 
            Times[ 0.23387232094715985, 
              c[ -22][ t]], 
            Times[ 0.14938649372796384, 
              c[ -21][ t]], 
            Times[ 0.070907514257657775, 
              c[ -20][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -19][ t]], 
            Times[ -0.062044074975450239, 
              c[ -18][ t]], 
            Times[ -0.11423673049785436, 
              c[ -17][ t]], 
            Times[ -0.15591488063143974, 
              c[ -16][ t]], 
            Times[ -0.18675027222298593, 
              c[ -15][ t]], 
            Times[ -0.206748335783172, 
              c[ -14][ t]], 
            Times[ -0.21623620818304484, 
              c[ -13][ t]], 
            Times[ -0.21584055771952015, 
              c[ -12][ t]], 
            Times[ -0.20645618564475843, 
              c[ -11][ t]], 
            Times[ -0.18920668216016426, 
              c[ -10][ t]], 
            Times[ -0.16539866862653771, 
              c[ -9][ t]], 
            Times[ -0.13647135277833605, 
              c[ -8][ t]], 
            Times[ -0.10394325375429328, 
              c[ -7][ t]], 
            Times[ -0.06935801494512607, 
              c[ -6][ t]], 
            Times[ -0.034231213779558949, 
              c[ -5][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -4][ t]], 
            Times[ 0.032022748374425904, 
              c[ -3][ t]], 
            Times[ 0.060688263076985105, 
              c[ -2][ t]], 
            Times[ 0.085044480344421608, 
              c[ -1][ t]], 
            Times[ 0.10436044624225685, 
              c[ 0][ t]], 
            Times[ 0.11814190616181255, 
              c[ 1][ t]], 
            Times[ 0.12613778810677612, 
              c[ 2][ t]], 
            Times[ 0.12833762891430928, 
              c[ 3][ t]], 
            Times[ 0.12496032289024853, 
              c[ 4][ t]], 
            Times[ 0.11643488132933186, 
              c[ 5][ t]], 
            Times[ 0.10337416789158609, 
              c[ 6][ t]], 
            Times[ 0.086542809078944891, 
              c[ 7][ t]], 
            Times[ 0.066820663127759972, 
              c[ 8][ t]], 
            Times[ 0.045163358568919301, 
              c[ 9][ t]], 
            Times[ 0.022561481809254869, 
              c[ 10][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 11][ t]], 
            Times[ -0.021580547817547879, 
              c[ 12][ t]], 
            Times[ -0.04131966847794722, 
              c[ 13][ t]], 
            Times[ -0.058468080236789913, 
              c[ 14][ t]], 
            Times[ -0.072413370861974122, 
              c[ 15][ t]], 
            Times[ -0.082699334313268744, 
              c[ 16][ t]], 
            Times[ -0.089038438663606695, 
              c[ 17][ t]], 
            Times[ -0.091317159035181589, 
              c[ 18][ t]], 
            Times[ -0.089594193770366884, 
              c[ 19][ t]], 
            Times[ -0.084091858737850814, 
              c[ 20][ t]], 
            Times[ -0.075181213012062598, 
              c[ 21][ t]], 
            Times[ -0.063361699504227528, 
              c[ 22][ t]], 
            Times[ -0.049236278094138941, 
              c[ 23][ t]], 
            Times[ -0.033483179628681567, 
              c[ 24][ t]], 
            Times[ -0.016825511857749401, 
              c[ 25][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 26][ t]], 
            Times[ 0.016273855731265604, 
              c[ 27][ t]], 
            Times[ 0.031322974491347078, 
              c[ 28][ t]], 
            Times[ 0.044547108751839919, 
              c[ 29][ t]], 
            Times[ 0.055441487066198933, 
              c[ 30][ t]], 
            Times[ 0.063614872548668253, 
              c[ 31][ t]], 
            Times[ 0.068802429876423349, 
              c[ 32][ t]], 
            Times[ 0.070873018952678238, 
              c[ 33][ t]], 
            Times[ 0.069830768673962415, 
              c[ 34][ t]], 
            Times[ 0.065811019881796273, 
              c[ 35][ t]], 
            Times[ 0.059070953080906326, 
              c[ 36][ t]], 
            Times[ 0.049975424961080865, 
              c[ 37][ t]], 
            Times[ 0.03897872015785999, 
              c[ 38][ t]], 
            Times[ 0.026603074225527826, 
              c[ 39][ t]], 
            Times[ 0.013414935129827233, 
              c[ 40][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ 41][ t]], 
            Times[ -0.013061910521147383, 
              c[ 42][ t]], 
            Times[ -0.025221096343682053, 
              c[ 43][ t]], 
            Times[ -0.035980357068793781, 
              c[ 44][ t]], 
            Times[ -0.044914622433376419, 
              c[ 45][ t]], 
            Times[ -0.05168708394579296, 
              c[ 46][ t]], 
            Times[ -0.05606123915856713, 
              c[ 47][ t]], 
            Times[ -0.057908442314993203, 
              c[ 48][ t]], 
            Times[ -0.057210750238908967, 
              c[ 49][ t]], 
            Times[ -0.054059052045761224, 
              c[ 50][ t]], 
            Times[ -0.048646667243099281, 
              c[ 51][ t]], 
            Times[ -0.041258781072520248, 
              c[ 52][ t]], 
            Times[ -0.032258251165125679, 
              c[ 53][ t]], 
            Times[ -0.022068459300722043, 
              c[ 54][ t]], 
            Times[ -0.011153991006822649, 
              c[ 55][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 56][ t]], 
            Times[ 0.010908848347331966, 
              c[ 57][ t]], 
            Times[ 0.021108961070255627, 
              c[ 58][ t]], 
            Times[ 0.030177073670601094, 
              c[ 59][ t]], 
            Times[ 0.03774739544932687, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-33\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-33\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.10394325375429328`\)\ \(c[\(-60\)]\)[t] - 
            0.13647135277833616`\ \(c[\(-59\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-58\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-57\)]\)[t] - 
            0.20645618564475848`\ \(c[\(-56\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-55\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-54\)]\)[t] - 
            0.2067483357831719`\ \(c[\(-53\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-52\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-51\)]\)[t] - 
            0.11423673049785416`\ \(c[\(-50\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-49\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-48\)]\)[t] + 
            0.0709075142576581`\ \(c[\(-47\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-46\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-45\)]\)[t] + 
            0.3225686520215219`\ \(c[\(-44\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-43\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-42\)]\)[t] + 
            0.5935615337286809`\ \(c[\(-41\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-40\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-39\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-38\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-37\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-36\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-35\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-34\)]\)[t] + 
            24.884442650636245`\ \(c[\(-33\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-32\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-31\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-30\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-29\)]\)[t] + 
            0.826993343132688`\ \(c[\(-28\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-27\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-26\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-25\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-24\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-23\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-22\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-21\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-20\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-19\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-18\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-17\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-16\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-15\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-14\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-13\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-12\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-11\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-10\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-9\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-8\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-7\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-6\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-5\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-4\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-3\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-2\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-1\)]\)[t] + 
            0.0850444803444217`\ \(c[0]\)[t] + 
            0.10436044624225692`\ \(c[1]\)[t] + 
            0.11814190616181255`\ \(c[2]\)[t] + 
            0.12613778810677614`\ \(c[3]\)[t] + 
            0.12833762891430925`\ \(c[4]\)[t] + 
            0.12496032289024853`\ \(c[5]\)[t] + 
            0.11643488132933186`\ \(c[6]\)[t] + 
            0.10337416789158609`\ \(c[7]\)[t] + 
            0.08654280907894475`\ \(c[8]\)[t] + 
            0.06682066312775997`\ \(c[9]\)[t] + 
            0.0451633585689193`\ \(c[10]\)[t] + 
            0.02256148180925487`\ \(c[11]\)[t] + 
            3.8981718325193755`*^-17\ \(c[12]\)[t] - 
            0.02158054781754788`\ \(c[13]\)[t] - 
            0.04131966847794722`\ \(c[14]\)[t] - 
            0.05846808023678991`\ \(c[15]\)[t] - 
            0.07241337086197412`\ \(c[16]\)[t] - 
            0.08269933431326874`\ \(c[17]\)[t] - 
            0.0890384386636067`\ \(c[18]\)[t] - 
            0.09131715903518159`\ \(c[19]\)[t] - 
            0.08959419377036688`\ \(c[20]\)[t] - 
            0.08409185873785081`\ \(c[21]\)[t] - 
            0.0751812130120626`\ \(c[22]\)[t] - 
            0.06336169950422753`\ \(c[23]\)[t] - 
            0.04923627809413894`\ \(c[24]\)[t] - 
            0.03348317962868157`\ \(c[25]\)[t] - 
            0.0168255118577494`\ \(c[26]\)[t] - 
            3.898171832519376`*^-17\ \(c[27]\)[t] + 
            0.016273855731265604`\ \(c[28]\)[t] + 
            0.03132297449134708`\ \(c[29]\)[t] + 
            0.04454710875183992`\ \(c[30]\)[t] + 
            0.05544148706619893`\ \(c[31]\)[t] + 
            0.06361487254866825`\ \(c[32]\)[t] + 
            0.06880242987642335`\ \(c[33]\)[t] + 
            0.07087301895267824`\ \(c[34]\)[t] + 
            0.06983076867396242`\ \(c[35]\)[t] + 
            0.06581101988179627`\ \(c[36]\)[t] + 
            0.059070953080906326`\ \(c[37]\)[t] + 
            0.049975424961080865`\ \(c[38]\)[t] + 
            0.03897872015785999`\ \(c[39]\)[t] + 
            0.026603074225527826`\ \(c[40]\)[t] + 
            0.013414935129827233`\ \(c[41]\)[t] + 
            3.898171832519376`*^-17\ \(c[42]\)[t] - 
            0.013061910521147383`\ \(c[43]\)[t] - 
            0.025221096343682053`\ \(c[44]\)[t] - 
            0.03598035706879378`\ \(c[45]\)[t] - 
            0.04491462243337642`\ \(c[46]\)[t] - 
            0.05168708394579296`\ \(c[47]\)[t] - 
            0.056061239158567186`\ \(c[48]\)[t] - 
            0.0579084423149932`\ \(c[49]\)[t] - 
            0.05721075023890897`\ \(c[50]\)[t] - 
            0.054059052045761224`\ \(c[51]\)[t] - 
            0.04864666724309928`\ \(c[52]\)[t] - 
            0.04125878107252025`\ \(c[53]\)[t] - 
            0.03225825116512552`\ \(c[54]\)[t] - 
            0.022068459300722043`\ \(c[55]\)[t] - 
            0.011153991006822649`\ \(c[56]\)[t] - 
            3.8981718325193755`*^-17\ \(c[57]\)[t] + 
            0.010908848347331966`\ \(c[58]\)[t] + 
            0.021108961070255627`\ \(c[59]\)[t] + 
            0.030177073670601236`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -33, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -33]][ t]], 
          Plus[ 
            Times[ -0.10394325375429328, 
              c[ -60][ t]], 
            Times[ -0.13647135277833616, 
              c[ -59][ t]], 
            Times[ -0.16539866862653771, 
              c[ -58][ t]], 
            Times[ -0.18920668216016426, 
              c[ -57][ t]], 
            Times[ -0.20645618564475848, 
              c[ -56][ t]], 
            Times[ -0.21584055771952015, 
              c[ -55][ t]], 
            Times[ -0.21623620818304484, 
              c[ -54][ t]], 
            Times[ -0.20674833578317189, 
              c[ -53][ t]], 
            Times[ -0.18675027222298593, 
              c[ -52][ t]], 
            Times[ -0.15591488063143982, 
              c[ -51][ t]], 
            Times[ -0.11423673049785416, 
              c[ -50][ t]], 
            Times[ -0.062044074975450239, 
              c[ -49][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -48][ t]], 
            Times[ 0.070907514257658094, 
              c[ -47][ t]], 
            Times[ 0.14938649372796384, 
              c[ -46][ t]], 
            Times[ 0.23387232094715985, 
              c[ -45][ t]], 
            Times[ 0.32256865202152191, 
              c[ -44][ t]], 
            Times[ 0.41349667156634429, 
              c[ -43][ t]], 
            Times[ 0.50455115242710469, 
              c[ -42][ t]], 
            Times[ 0.59356153372868092, 
              c[ -41][ t]], 
            Times[ 0.67835603854706361, 
              c[ -40][ t]], 
            Times[ 0.75682672864065692, 
              c[ -39][ t]], 
            Times[ 0.82699334313268813, 
              c[ -38][ t]], 
            Times[ 0.88706379305918392, 
              c[ -37][ t]], 
            Times[ 0.93548928378863916, 
              c[ -36][ t]], 
            Times[ 0.9710122092317629, 
              c[ -35][ t]], 
            Times[ 0.99270519960720693, 
              c[ -34][ t]], 
            Times[ 24.884442650636245, 
              c[ -33][ t]], 
            Times[ 0.99270519960720671, 
              c[ -32][ t]], 
            Times[ 0.9710122092317629, 
              c[ -31][ t]], 
            Times[ 0.93548928378863916, 
              c[ -30][ t]], 
            Times[ 0.88706379305918381, 
              c[ -29][ t]], 
            Times[ 0.82699334313268802, 
              c[ -28][ t]], 
            Times[ 0.75682672864065692, 
              c[ -27][ t]], 
            Times[ 0.67835603854706317, 
              c[ -26][ t]], 
            Times[ 0.59356153372868015, 
              c[ -25][ t]], 
            Times[ 0.50455115242710469, 
              c[ -24][ t]], 
            Times[ 0.41349667156634395, 
              c[ -23][ t]], 
            Times[ 0.32256865202152113, 
              c[ -22][ t]], 
            Times[ 0.23387232094715985, 
              c[ -21][ t]], 
            Times[ 0.14938649372796345, 
              c[ -20][ t]], 
            Times[ 0.070907514257657622, 
              c[ -19][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -18][ t]], 
            Times[ -0.062044074975450475, 
              c[ -17][ t]], 
            Times[ -0.11423673049785445, 
              c[ -16][ t]], 
            Times[ -0.15591488063143982, 
              c[ -15][ t]], 
            Times[ -0.18675027222298607, 
              c[ -14][ t]], 
            Times[ -0.20674833578317206, 
              c[ -13][ t]], 
            Times[ -0.21623620818304484, 
              c[ -12][ t]], 
            Times[ -0.21584055771952013, 
              c[ -11][ t]], 
            Times[ -0.20645618564475834, 
              c[ -10][ t]], 
            Times[ -0.18920668216016426, 
              c[ -9][ t]], 
            Times[ -0.1653986686265376, 
              c[ -8][ t]], 
            Times[ -0.13647135277833591, 
              c[ -7][ t]], 
            Times[ -0.10394325375429328, 
              c[ -6][ t]], 
            Times[ -0.069358014945125918, 
              c[ -5][ t]], 
            Times[ -0.034231213779558949, 
              c[ -4][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -3][ t]], 
            Times[ 0.032022748374426029, 
              c[ -2][ t]], 
            Times[ 0.060688263076985105, 
              c[ -1][ t]], 
            Times[ 0.085044480344421705, 
              c[ 0][ t]], 
            Times[ 0.10436044624225692, 
              c[ 1][ t]], 
            Times[ 0.11814190616181255, 
              c[ 2][ t]], 
            Times[ 0.12613778810677614, 
              c[ 3][ t]], 
            Times[ 0.12833762891430925, 
              c[ 4][ t]], 
            Times[ 0.12496032289024853, 
              c[ 5][ t]], 
            Times[ 0.11643488132933186, 
              c[ 6][ t]], 
            Times[ 0.10337416789158609, 
              c[ 7][ t]], 
            Times[ 0.086542809078944752, 
              c[ 8][ t]], 
            Times[ 0.066820663127759972, 
              c[ 9][ t]], 
            Times[ 0.045163358568919301, 
              c[ 10][ t]], 
            Times[ 0.022561481809254869, 
              c[ 11][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 12][ t]], 
            Times[ -0.021580547817547879, 
              c[ 13][ t]], 
            Times[ -0.04131966847794722, 
              c[ 14][ t]], 
            Times[ -0.058468080236789913, 
              c[ 15][ t]], 
            Times[ -0.072413370861974122, 
              c[ 16][ t]], 
            Times[ -0.082699334313268744, 
              c[ 17][ t]], 
            Times[ -0.089038438663606695, 
              c[ 18][ t]], 
            Times[ -0.091317159035181589, 
              c[ 19][ t]], 
            Times[ -0.089594193770366884, 
              c[ 20][ t]], 
            Times[ -0.084091858737850814, 
              c[ 21][ t]], 
            Times[ -0.075181213012062598, 
              c[ 22][ t]], 
            Times[ -0.063361699504227528, 
              c[ 23][ t]], 
            Times[ -0.049236278094138941, 
              c[ 24][ t]], 
            Times[ -0.033483179628681567, 
              c[ 25][ t]], 
            Times[ -0.016825511857749401, 
              c[ 26][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 27][ t]], 
            Times[ 0.016273855731265604, 
              c[ 28][ t]], 
            Times[ 0.031322974491347078, 
              c[ 29][ t]], 
            Times[ 0.044547108751839919, 
              c[ 30][ t]], 
            Times[ 0.055441487066198933, 
              c[ 31][ t]], 
            Times[ 0.063614872548668253, 
              c[ 32][ t]], 
            Times[ 0.068802429876423349, 
              c[ 33][ t]], 
            Times[ 0.070873018952678238, 
              c[ 34][ t]], 
            Times[ 0.069830768673962415, 
              c[ 35][ t]], 
            Times[ 0.065811019881796273, 
              c[ 36][ t]], 
            Times[ 0.059070953080906326, 
              c[ 37][ t]], 
            Times[ 0.049975424961080865, 
              c[ 38][ t]], 
            Times[ 0.03897872015785999, 
              c[ 39][ t]], 
            Times[ 0.026603074225527826, 
              c[ 40][ t]], 
            Times[ 0.013414935129827233, 
              c[ 41][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 42][ t]], 
            Times[ -0.013061910521147383, 
              c[ 43][ t]], 
            Times[ -0.025221096343682053, 
              c[ 44][ t]], 
            Times[ -0.035980357068793781, 
              c[ 45][ t]], 
            Times[ -0.044914622433376419, 
              c[ 46][ t]], 
            Times[ -0.05168708394579296, 
              c[ 47][ t]], 
            Times[ -0.056061239158567186, 
              c[ 48][ t]], 
            Times[ -0.057908442314993203, 
              c[ 49][ t]], 
            Times[ -0.057210750238908967, 
              c[ 50][ t]], 
            Times[ -0.054059052045761224, 
              c[ 51][ t]], 
            Times[ -0.048646667243099281, 
              c[ 52][ t]], 
            Times[ -0.041258781072520248, 
              c[ 53][ t]], 
            Times[ -0.032258251165125519, 
              c[ 54][ t]], 
            Times[ -0.022068459300722043, 
              c[ 55][ t]], 
            Times[ -0.011153991006822649, 
              c[ 56][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 57][ t]], 
            Times[ 0.010908848347331966, 
              c[ 58][ t]], 
            Times[ 0.021108961070255627, 
              c[ 59][ t]], 
            Times[ 0.030177073670601236, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-32\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-32\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.06935801494512592`\)\ \(c[\(-60\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-59\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-58\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-57\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-56\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-55\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-54\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-53\)]\)[t] - 
            0.206748335783172`\ \(c[\(-52\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-51\)]\)[t] - 
            0.15591488063143966`\ \(c[\(-50\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-49\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-48\)]\)[t] + 
            3.216976900108398`*^-16\ \(c[\(-47\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-46\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-45\)]\)[t] + 
            0.23387232094716018`\ \(c[\(-44\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-43\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-42\)]\)[t] + 
            0.504551152427105`\ \(c[\(-41\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-40\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-39\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-38\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-37\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-36\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-35\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-34\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-33\)]\)[t] + 
            23.45883312603445`\ \(c[\(-32\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-31\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-30\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-29\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-28\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-27\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-26\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-25\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-24\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-23\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-22\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-21\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-20\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-19\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-18\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-17\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-16\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-15\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-14\)]\)[t] - 
            0.186750272222986`\ \(c[\(-13\)]\)[t] - 
            0.206748335783172`\ \(c[\(-12\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-11\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-10\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-9\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-8\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-7\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-6\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-5\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-4\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-3\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-2\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-1\)]\)[t] + 
            0.060688263076985105`\ \(c[0]\)[t] + 
            0.0850444803444217`\ \(c[1]\)[t] + 
            0.10436044624225685`\ \(c[2]\)[t] + 
            0.11814190616181255`\ \(c[3]\)[t] + 
            0.12613778810677614`\ \(c[4]\)[t] + 
            0.12833762891430928`\ \(c[5]\)[t] + 
            0.12496032289024853`\ \(c[6]\)[t] + 
            0.11643488132933186`\ \(c[7]\)[t] + 
            0.10337416789158609`\ \(c[8]\)[t] + 
            0.08654280907894489`\ \(c[9]\)[t] + 
            0.06682066312775997`\ \(c[10]\)[t] + 
            0.0451633585689193`\ \(c[11]\)[t] + 
            0.02256148180925487`\ \(c[12]\)[t] + 
            3.8981718325193755`*^-17\ \(c[13]\)[t] - 
            0.02158054781754788`\ \(c[14]\)[t] - 
            0.04131966847794722`\ \(c[15]\)[t] - 
            0.05846808023678991`\ \(c[16]\)[t] - 
            0.07241337086197412`\ \(c[17]\)[t] - 
            0.08269933431326874`\ \(c[18]\)[t] - 
            0.0890384386636067`\ \(c[19]\)[t] - 
            0.09131715903518159`\ \(c[20]\)[t] - 
            0.08959419377036688`\ \(c[21]\)[t] - 
            0.08409185873785081`\ \(c[22]\)[t] - 
            0.0751812130120626`\ \(c[23]\)[t] - 
            0.06336169950422753`\ \(c[24]\)[t] - 
            0.04923627809413894`\ \(c[25]\)[t] - 
            0.03348317962868157`\ \(c[26]\)[t] - 
            0.0168255118577494`\ \(c[27]\)[t] - 
            3.898171832519376`*^-17\ \(c[28]\)[t] + 
            0.016273855731265604`\ \(c[29]\)[t] + 
            0.03132297449134708`\ \(c[30]\)[t] + 
            0.04454710875183992`\ \(c[31]\)[t] + 
            0.05544148706619893`\ \(c[32]\)[t] + 
            0.06361487254866825`\ \(c[33]\)[t] + 
            0.06880242987642335`\ \(c[34]\)[t] + 
            0.07087301895267824`\ \(c[35]\)[t] + 
            0.06983076867396242`\ \(c[36]\)[t] + 
            0.06581101988179627`\ \(c[37]\)[t] + 
            0.059070953080906326`\ \(c[38]\)[t] + 
            0.049975424961080865`\ \(c[39]\)[t] + 
            0.03897872015785999`\ \(c[40]\)[t] + 
            0.026603074225527937`\ \(c[41]\)[t] + 
            0.013414935129827233`\ \(c[42]\)[t] + 
            3.898171832519376`*^-17\ \(c[43]\)[t] - 
            0.013061910521147276`\ \(c[44]\)[t] - 
            0.025221096343682053`\ \(c[45]\)[t] - 
            0.03598035706879378`\ \(c[46]\)[t] - 
            0.04491462243337629`\ \(c[47]\)[t] - 
            0.05168708394579296`\ \(c[48]\)[t] - 
            0.056061239158567186`\ \(c[49]\)[t] - 
            0.0579084423149932`\ \(c[50]\)[t] - 
            0.05721075023890897`\ \(c[51]\)[t] - 
            0.054059052045761224`\ \(c[52]\)[t] - 
            0.0486466672430994`\ \(c[53]\)[t] - 
            0.04125878107252025`\ \(c[54]\)[t] - 
            0.03225825116512552`\ \(c[55]\)[t] - 
            0.022068459300722043`\ \(c[56]\)[t] - 
            0.011153991006822649`\ \(c[57]\)[t] - 
            3.8981718325193755`*^-17\ \(c[58]\)[t] + 
            0.010908848347331785`\ \(c[59]\)[t] + 
            0.021108961070255627`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -32, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -32]][ t]], 
          Plus[ 
            Times[ -0.069358014945125918, 
              c[ -60][ t]], 
            Times[ -0.1039432537542934, 
              c[ -59][ t]], 
            Times[ -0.13647135277833605, 
              c[ -58][ t]], 
            Times[ -0.1653986686265376, 
              c[ -57][ t]], 
            Times[ -0.18920668216016434, 
              c[ -56][ t]], 
            Times[ -0.20645618564475843, 
              c[ -55][ t]], 
            Times[ -0.21584055771952013, 
              c[ -54][ t]], 
            Times[ -0.21623620818304481, 
              c[ -53][ t]], 
            Times[ -0.206748335783172, 
              c[ -52][ t]], 
            Times[ -0.18675027222298607, 
              c[ -51][ t]], 
            Times[ -0.15591488063143966, 
              c[ -50][ t]], 
            Times[ -0.11423673049785436, 
              c[ -49][ t]], 
            Times[ -0.062044074975450475, 
              c[ -48][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ -47][ t]], 
            Times[ 0.070907514257657775, 
              c[ -46][ t]], 
            Times[ 0.14938649372796345, 
              c[ -45][ t]], 
            Times[ 0.23387232094716018, 
              c[ -44][ t]], 
            Times[ 0.32256865202152157, 
              c[ -43][ t]], 
            Times[ 0.41349667156634395, 
              c[ -42][ t]], 
            Times[ 0.50455115242710502, 
              c[ -41][ t]], 
            Times[ 0.59356153372868059, 
              c[ -40][ t]], 
            Times[ 0.67835603854706317, 
              c[ -39][ t]], 
            Times[ 0.75682672864065692, 
              c[ -38][ t]], 
            Times[ 0.82699334313268813, 
              c[ -37][ t]], 
            Times[ 0.88706379305918381, 
              c[ -36][ t]], 
            Times[ 0.93548928378863916, 
              c[ -35][ t]], 
            Times[ 0.9710122092317629, 
              c[ -34][ t]], 
            Times[ 0.99270519960720671, 
              c[ -33][ t]], 
            Times[ 23.458833126034449, 
              c[ -32][ t]], 
            Times[ 0.99270519960720671, 
              c[ -31][ t]], 
            Times[ 0.9710122092317629, 
              c[ -30][ t]], 
            Times[ 0.93548928378863916, 
              c[ -29][ t]], 
            Times[ 0.88706379305918381, 
              c[ -28][ t]], 
            Times[ 0.82699334313268813, 
              c[ -27][ t]], 
            Times[ 0.75682672864065692, 
              c[ -26][ t]], 
            Times[ 0.67835603854706317, 
              c[ -25][ t]], 
            Times[ 0.59356153372868059, 
              c[ -24][ t]], 
            Times[ 0.50455115242710469, 
              c[ -23][ t]], 
            Times[ 0.41349667156634395, 
              c[ -22][ t]], 
            Times[ 0.32256865202152157, 
              c[ -21][ t]], 
            Times[ 0.23387232094715985, 
              c[ -20][ t]], 
            Times[ 0.14938649372796362, 
              c[ -19][ t]], 
            Times[ 0.070907514257657775, 
              c[ -18][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -17][ t]], 
            Times[ -0.062044074975450343, 
              c[ -16][ t]], 
            Times[ -0.11423673049785436, 
              c[ -15][ t]], 
            Times[ -0.15591488063143982, 
              c[ -14][ t]], 
            Times[ -0.18675027222298601, 
              c[ -13][ t]], 
            Times[ -0.206748335783172, 
              c[ -12][ t]], 
            Times[ -0.21623620818304484, 
              c[ -11][ t]], 
            Times[ -0.21584055771952015, 
              c[ -10][ t]], 
            Times[ -0.20645618564475843, 
              c[ -9][ t]], 
            Times[ -0.18920668216016426, 
              c[ -8][ t]], 
            Times[ -0.16539866862653771, 
              c[ -7][ t]], 
            Times[ -0.13647135277833605, 
              c[ -6][ t]], 
            Times[ -0.10394325375429328, 
              c[ -5][ t]], 
            Times[ -0.06935801494512607, 
              c[ -4][ t]], 
            Times[ -0.034231213779558949, 
              c[ -3][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -2][ t]], 
            Times[ 0.032022748374425904, 
              c[ -1][ t]], 
            Times[ 0.060688263076985105, 
              c[ 0][ t]], 
            Times[ 0.085044480344421705, 
              c[ 1][ t]], 
            Times[ 0.10436044624225685, 
              c[ 2][ t]], 
            Times[ 0.11814190616181255, 
              c[ 3][ t]], 
            Times[ 0.12613778810677614, 
              c[ 4][ t]], 
            Times[ 0.12833762891430928, 
              c[ 5][ t]], 
            Times[ 0.12496032289024853, 
              c[ 6][ t]], 
            Times[ 0.11643488132933186, 
              c[ 7][ t]], 
            Times[ 0.10337416789158609, 
              c[ 8][ t]], 
            Times[ 0.086542809078944891, 
              c[ 9][ t]], 
            Times[ 0.066820663127759972, 
              c[ 10][ t]], 
            Times[ 0.045163358568919301, 
              c[ 11][ t]], 
            Times[ 0.022561481809254869, 
              c[ 12][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 13][ t]], 
            Times[ -0.021580547817547879, 
              c[ 14][ t]], 
            Times[ -0.04131966847794722, 
              c[ 15][ t]], 
            Times[ -0.058468080236789913, 
              c[ 16][ t]], 
            Times[ -0.072413370861974122, 
              c[ 17][ t]], 
            Times[ -0.082699334313268744, 
              c[ 18][ t]], 
            Times[ -0.089038438663606695, 
              c[ 19][ t]], 
            Times[ -0.091317159035181589, 
              c[ 20][ t]], 
            Times[ -0.089594193770366884, 
              c[ 21][ t]], 
            Times[ -0.084091858737850814, 
              c[ 22][ t]], 
            Times[ -0.075181213012062598, 
              c[ 23][ t]], 
            Times[ -0.063361699504227528, 
              c[ 24][ t]], 
            Times[ -0.049236278094138941, 
              c[ 25][ t]], 
            Times[ -0.033483179628681567, 
              c[ 26][ t]], 
            Times[ -0.016825511857749401, 
              c[ 27][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 28][ t]], 
            Times[ 0.016273855731265604, 
              c[ 29][ t]], 
            Times[ 0.031322974491347078, 
              c[ 30][ t]], 
            Times[ 0.044547108751839919, 
              c[ 31][ t]], 
            Times[ 0.055441487066198933, 
              c[ 32][ t]], 
            Times[ 0.063614872548668253, 
              c[ 33][ t]], 
            Times[ 0.068802429876423349, 
              c[ 34][ t]], 
            Times[ 0.070873018952678238, 
              c[ 35][ t]], 
            Times[ 0.069830768673962415, 
              c[ 36][ t]], 
            Times[ 0.065811019881796273, 
              c[ 37][ t]], 
            Times[ 0.059070953080906326, 
              c[ 38][ t]], 
            Times[ 0.049975424961080865, 
              c[ 39][ t]], 
            Times[ 0.03897872015785999, 
              c[ 40][ t]], 
            Times[ 0.026603074225527937, 
              c[ 41][ t]], 
            Times[ 0.013414935129827233, 
              c[ 42][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 43][ t]], 
            Times[ -0.013061910521147276, 
              c[ 44][ t]], 
            Times[ -0.025221096343682053, 
              c[ 45][ t]], 
            Times[ -0.035980357068793781, 
              c[ 46][ t]], 
            Times[ -0.044914622433376288, 
              c[ 47][ t]], 
            Times[ -0.05168708394579296, 
              c[ 48][ t]], 
            Times[ -0.056061239158567186, 
              c[ 49][ t]], 
            Times[ -0.057908442314993203, 
              c[ 50][ t]], 
            Times[ -0.057210750238908967, 
              c[ 51][ t]], 
            Times[ -0.054059052045761224, 
              c[ 52][ t]], 
            Times[ -0.048646667243099399, 
              c[ 53][ t]], 
            Times[ -0.041258781072520248, 
              c[ 54][ t]], 
            Times[ -0.032258251165125519, 
              c[ 55][ t]], 
            Times[ -0.022068459300722043, 
              c[ 56][ t]], 
            Times[ -0.011153991006822649, 
              c[ 57][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 58][ t]], 
            Times[ 0.010908848347331785, 
              c[ 59][ t]], 
            Times[ 0.021108961070255627, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-31\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-31\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.034231213779558796`\)\ \(c[\(-60\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-59\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-58\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-57\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-56\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-55\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-54\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-53\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-52\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-51\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-50\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-49\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-48\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-47\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-46\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-45\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-44\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-43\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-42\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-41\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-40\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-39\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-38\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-37\)]\)[t] + 
            0.826993343132688`\ \(c[\(-36\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-35\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-34\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-33\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-32\)]\)[t] + 
            22.077088509881936`\ \(c[\(-31\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-30\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-29\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-28\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-27\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-26\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-25\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-24\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-23\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-22\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-21\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-20\)]\)[t] + 
            0.23387232094715998`\ \(c[\(-19\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-18\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-17\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-16\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-15\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-14\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-13\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-12\)]\)[t] - 
            0.206748335783172`\ \(c[\(-11\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-10\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-9\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-8\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-7\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-6\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-5\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-4\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-3\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-2\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-1\)]\)[t] + 
            0.032022748374425904`\ \(c[0]\)[t] + 
            0.060688263076985105`\ \(c[1]\)[t] + 
            0.08504448034442161`\ \(c[2]\)[t] + 
            0.10436044624225685`\ \(c[3]\)[t] + 
            0.11814190616181255`\ \(c[4]\)[t] + 
            0.12613778810677612`\ \(c[5]\)[t] + 
            0.12833762891430928`\ \(c[6]\)[t] + 
            0.12496032289024853`\ \(c[7]\)[t] + 
            0.11643488132933186`\ \(c[8]\)[t] + 
            0.10337416789158609`\ \(c[9]\)[t] + 
            0.08654280907894489`\ \(c[10]\)[t] + 
            0.06682066312775997`\ \(c[11]\)[t] + 
            0.0451633585689193`\ \(c[12]\)[t] + 
            0.02256148180925487`\ \(c[13]\)[t] + 
            3.8981718325193755`*^-17\ \(c[14]\)[t] - 
            0.02158054781754788`\ \(c[15]\)[t] - 
            0.04131966847794722`\ \(c[16]\)[t] - 
            0.05846808023678991`\ \(c[17]\)[t] - 
            0.07241337086197412`\ \(c[18]\)[t] - 
            0.08269933431326874`\ \(c[19]\)[t] - 
            0.0890384386636067`\ \(c[20]\)[t] - 
            0.09131715903518159`\ \(c[21]\)[t] - 
            0.08959419377036688`\ \(c[22]\)[t] - 
            0.08409185873785081`\ \(c[23]\)[t] - 
            0.0751812130120626`\ \(c[24]\)[t] - 
            0.06336169950422753`\ \(c[25]\)[t] - 
            0.04923627809413894`\ \(c[26]\)[t] - 
            0.03348317962868157`\ \(c[27]\)[t] - 
            0.0168255118577494`\ \(c[28]\)[t] - 
            3.898171832519376`*^-17\ \(c[29]\)[t] + 
            0.016273855731265604`\ \(c[30]\)[t] + 
            0.03132297449134708`\ \(c[31]\)[t] + 
            0.04454710875183992`\ \(c[32]\)[t] + 
            0.05544148706619893`\ \(c[33]\)[t] + 
            0.06361487254866825`\ \(c[34]\)[t] + 
            0.06880242987642335`\ \(c[35]\)[t] + 
            0.07087301895267824`\ \(c[36]\)[t] + 
            0.06983076867396242`\ \(c[37]\)[t] + 
            0.06581101988179627`\ \(c[38]\)[t] + 
            0.059070953080906326`\ \(c[39]\)[t] + 
            0.049975424961080865`\ \(c[40]\)[t] + 
            0.03897872015786009`\ \(c[41]\)[t] + 
            0.026603074225527826`\ \(c[42]\)[t] + 
            0.013414935129827233`\ \(c[43]\)[t] + 
            1.5206810699945212`*^-16\ \(c[44]\)[t] - 
            0.013061910521147383`\ \(c[45]\)[t] - 
            0.025221096343682053`\ \(c[46]\)[t] - 
            0.03598035706879378`\ \(c[47]\)[t] - 
            0.04491462243337642`\ \(c[48]\)[t] - 
            0.05168708394579296`\ \(c[49]\)[t] - 
            0.05606123915856713`\ \(c[50]\)[t] - 
            0.0579084423149932`\ \(c[51]\)[t] - 
            0.05721075023890897`\ \(c[52]\)[t] - 
            0.054059052045761224`\ \(c[53]\)[t] - 
            0.04864666724309928`\ \(c[54]\)[t] - 
            0.04125878107252025`\ \(c[55]\)[t] - 
            0.03225825116512568`\ \(c[56]\)[t] - 
            0.022068459300722043`\ \(c[57]\)[t] - 
            0.011153991006822649`\ \(c[58]\)[t] - 
            3.8981718325193755`*^-17\ \(c[59]\)[t] + 
            0.010908848347331966`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -31, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -31]][ t]], 
          Plus[ 
            Times[ -0.034231213779558796, 
              c[ -60][ t]], 
            Times[ -0.06935801494512607, 
              c[ -59][ t]], 
            Times[ -0.10394325375429328, 
              c[ -58][ t]], 
            Times[ -0.13647135277833591, 
              c[ -57][ t]], 
            Times[ -0.16539866862653771, 
              c[ -56][ t]], 
            Times[ -0.18920668216016426, 
              c[ -55][ t]], 
            Times[ -0.20645618564475834, 
              c[ -54][ t]], 
            Times[ -0.21584055771952015, 
              c[ -53][ t]], 
            Times[ -0.21623620818304484, 
              c[ -52][ t]], 
            Times[ -0.20674833578317206, 
              c[ -51][ t]], 
            Times[ -0.18675027222298593, 
              c[ -50][ t]], 
            Times[ -0.15591488063143982, 
              c[ -49][ t]], 
            Times[ -0.11423673049785459, 
              c[ -48][ t]], 
            Times[ -0.062044074975450239, 
              c[ -47][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -46][ t]], 
            Times[ 0.070907514257657456, 
              c[ -45][ t]], 
            Times[ 0.14938649372796384, 
              c[ -44][ t]], 
            Times[ 0.23387232094715985, 
              c[ -43][ t]], 
            Times[ 0.32256865202152113, 
              c[ -42][ t]], 
            Times[ 0.41349667156634429, 
              c[ -41][ t]], 
            Times[ 0.50455115242710469, 
              c[ -40][ t]], 
            Times[ 0.59356153372868015, 
              c[ -39][ t]], 
            Times[ 0.67835603854706317, 
              c[ -38][ t]], 
            Times[ 0.75682672864065692, 
              c[ -37][ t]], 
            Times[ 0.82699334313268802, 
              c[ -36][ t]], 
            Times[ 0.88706379305918381, 
              c[ -35][ t]], 
            Times[ 0.93548928378863916, 
              c[ -34][ t]], 
            Times[ 0.9710122092317629, 
              c[ -33][ t]], 
            Times[ 0.99270519960720671, 
              c[ -32][ t]], 
            Times[ 22.077088509881936, 
              c[ -31][ t]], 
            Times[ 0.99270519960720693, 
              c[ -30][ t]], 
            Times[ 0.9710122092317629, 
              c[ -29][ t]], 
            Times[ 0.93548928378863916, 
              c[ -28][ t]], 
            Times[ 0.88706379305918392, 
              c[ -27][ t]], 
            Times[ 0.82699334313268813, 
              c[ -26][ t]], 
            Times[ 0.75682672864065692, 
              c[ -25][ t]], 
            Times[ 0.67835603854706361, 
              c[ -24][ t]], 
            Times[ 0.59356153372868059, 
              c[ -23][ t]], 
            Times[ 0.50455115242710469, 
              c[ -22][ t]], 
            Times[ 0.41349667156634429, 
              c[ -21][ t]], 
            Times[ 0.32256865202152157, 
              c[ -20][ t]], 
            Times[ 0.23387232094715998, 
              c[ -19][ t]], 
            Times[ 0.14938649372796384, 
              c[ -18][ t]], 
            Times[ 0.070907514257657775, 
              c[ -17][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -16][ t]], 
            Times[ -0.062044074975450239, 
              c[ -15][ t]], 
            Times[ -0.11423673049785436, 
              c[ -14][ t]], 
            Times[ -0.15591488063143974, 
              c[ -13][ t]], 
            Times[ -0.18675027222298593, 
              c[ -12][ t]], 
            Times[ -0.206748335783172, 
              c[ -11][ t]], 
            Times[ -0.21623620818304484, 
              c[ -10][ t]], 
            Times[ -0.21584055771952015, 
              c[ -9][ t]], 
            Times[ -0.20645618564475843, 
              c[ -8][ t]], 
            Times[ -0.18920668216016426, 
              c[ -7][ t]], 
            Times[ -0.16539866862653771, 
              c[ -6][ t]], 
            Times[ -0.13647135277833605, 
              c[ -5][ t]], 
            Times[ -0.1039432537542934, 
              c[ -4][ t]], 
            Times[ -0.06935801494512607, 
              c[ -3][ t]], 
            Times[ -0.034231213779558949, 
              c[ -2][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -1][ t]], 
            Times[ 0.032022748374425904, 
              c[ 0][ t]], 
            Times[ 0.060688263076985105, 
              c[ 1][ t]], 
            Times[ 0.085044480344421608, 
              c[ 2][ t]], 
            Times[ 0.10436044624225685, 
              c[ 3][ t]], 
            Times[ 0.11814190616181255, 
              c[ 4][ t]], 
            Times[ 0.12613778810677612, 
              c[ 5][ t]], 
            Times[ 0.12833762891430928, 
              c[ 6][ t]], 
            Times[ 0.12496032289024853, 
              c[ 7][ t]], 
            Times[ 0.11643488132933186, 
              c[ 8][ t]], 
            Times[ 0.10337416789158609, 
              c[ 9][ t]], 
            Times[ 0.086542809078944891, 
              c[ 10][ t]], 
            Times[ 0.066820663127759972, 
              c[ 11][ t]], 
            Times[ 0.045163358568919301, 
              c[ 12][ t]], 
            Times[ 0.022561481809254869, 
              c[ 13][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 14][ t]], 
            Times[ -0.021580547817547879, 
              c[ 15][ t]], 
            Times[ -0.04131966847794722, 
              c[ 16][ t]], 
            Times[ -0.058468080236789913, 
              c[ 17][ t]], 
            Times[ -0.072413370861974122, 
              c[ 18][ t]], 
            Times[ -0.082699334313268744, 
              c[ 19][ t]], 
            Times[ -0.089038438663606695, 
              c[ 20][ t]], 
            Times[ -0.091317159035181589, 
              c[ 21][ t]], 
            Times[ -0.089594193770366884, 
              c[ 22][ t]], 
            Times[ -0.084091858737850814, 
              c[ 23][ t]], 
            Times[ -0.075181213012062598, 
              c[ 24][ t]], 
            Times[ -0.063361699504227528, 
              c[ 25][ t]], 
            Times[ -0.049236278094138941, 
              c[ 26][ t]], 
            Times[ -0.033483179628681567, 
              c[ 27][ t]], 
            Times[ -0.016825511857749401, 
              c[ 28][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 29][ t]], 
            Times[ 0.016273855731265604, 
              c[ 30][ t]], 
            Times[ 0.031322974491347078, 
              c[ 31][ t]], 
            Times[ 0.044547108751839919, 
              c[ 32][ t]], 
            Times[ 0.055441487066198933, 
              c[ 33][ t]], 
            Times[ 0.063614872548668253, 
              c[ 34][ t]], 
            Times[ 0.068802429876423349, 
              c[ 35][ t]], 
            Times[ 0.070873018952678238, 
              c[ 36][ t]], 
            Times[ 0.069830768673962415, 
              c[ 37][ t]], 
            Times[ 0.065811019881796273, 
              c[ 38][ t]], 
            Times[ 0.059070953080906326, 
              c[ 39][ t]], 
            Times[ 0.049975424961080865, 
              c[ 40][ t]], 
            Times[ 0.038978720157860088, 
              c[ 41][ t]], 
            Times[ 0.026603074225527826, 
              c[ 42][ t]], 
            Times[ 0.013414935129827233, 
              c[ 43][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ 44][ t]], 
            Times[ -0.013061910521147383, 
              c[ 45][ t]], 
            Times[ -0.025221096343682053, 
              c[ 46][ t]], 
            Times[ -0.035980357068793781, 
              c[ 47][ t]], 
            Times[ -0.044914622433376419, 
              c[ 48][ t]], 
            Times[ -0.05168708394579296, 
              c[ 49][ t]], 
            Times[ -0.05606123915856713, 
              c[ 50][ t]], 
            Times[ -0.057908442314993203, 
              c[ 51][ t]], 
            Times[ -0.057210750238908967, 
              c[ 52][ t]], 
            Times[ -0.054059052045761224, 
              c[ 53][ t]], 
            Times[ -0.048646667243099281, 
              c[ 54][ t]], 
            Times[ -0.041258781072520248, 
              c[ 55][ t]], 
            Times[ -0.032258251165125679, 
              c[ 56][ t]], 
            Times[ -0.022068459300722043, 
              c[ 57][ t]], 
            Times[ -0.011153991006822649, 
              c[ 58][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 59][ t]], 
            Times[ 0.010908848347331966, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-30\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-30\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-3.898171832519376`*^-17\)\ \(c[\(-60\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-59\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-58\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-57\)]\)[t] - 
            0.13647135277833616`\ \(c[\(-56\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-55\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-54\)]\)[t] - 
            0.20645618564475848`\ \(c[\(-53\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-52\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-51\)]\)[t] - 
            0.2067483357831719`\ \(c[\(-50\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-49\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-48\)]\)[t] - 
            0.11423673049785416`\ \(c[\(-47\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-46\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-45\)]\)[t] + 
            0.0709075142576581`\ \(c[\(-44\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-43\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-42\)]\)[t] + 
            0.3225686520215219`\ \(c[\(-41\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-40\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-39\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-38\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-37\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-36\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-35\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-34\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-33\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-32\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-31\)]\)[t] + 
            20.739208802178716`\ \(c[\(-30\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-29\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-28\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-27\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-26\)]\)[t] + 
            0.826993343132688`\ \(c[\(-25\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-24\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-23\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-22\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-21\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-20\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-19\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-18\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-17\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-16\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-15\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-14\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-13\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-12\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-11\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-10\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-9\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-8\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-7\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-6\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-5\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-4\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-3\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-2\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-1\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[0]\)[t] + 
            0.03202274837442603`\ \(c[1]\)[t] + 
            0.060688263076985105`\ \(c[2]\)[t] + 
            0.0850444803444217`\ \(c[3]\)[t] + 
            0.10436044624225692`\ \(c[4]\)[t] + 
            0.11814190616181255`\ \(c[5]\)[t] + 
            0.12613778810677614`\ \(c[6]\)[t] + 
            0.12833762891430928`\ \(c[7]\)[t] + 
            0.12496032289024853`\ \(c[8]\)[t] + 
            0.11643488132933186`\ \(c[9]\)[t] + 
            0.10337416789158609`\ \(c[10]\)[t] + 
            0.08654280907894489`\ \(c[11]\)[t] + 
            0.06682066312775997`\ \(c[12]\)[t] + 
            0.0451633585689193`\ \(c[13]\)[t] + 
            0.02256148180925487`\ \(c[14]\)[t] + 
            3.8981718325193755`*^-17\ \(c[15]\)[t] - 
            0.02158054781754788`\ \(c[16]\)[t] - 
            0.04131966847794722`\ \(c[17]\)[t] - 
            0.05846808023678991`\ \(c[18]\)[t] - 
            0.07241337086197412`\ \(c[19]\)[t] - 
            0.08269933431326874`\ \(c[20]\)[t] - 
            0.0890384386636067`\ \(c[21]\)[t] - 
            0.09131715903518159`\ \(c[22]\)[t] - 
            0.08959419377036688`\ \(c[23]\)[t] - 
            0.08409185873785081`\ \(c[24]\)[t] - 
            0.0751812130120626`\ \(c[25]\)[t] - 
            0.06336169950422753`\ \(c[26]\)[t] - 
            0.04923627809413894`\ \(c[27]\)[t] - 
            0.03348317962868157`\ \(c[28]\)[t] - 
            0.0168255118577494`\ \(c[29]\)[t] - 
            3.898171832519376`*^-17\ \(c[30]\)[t] + 
            0.016273855731265604`\ \(c[31]\)[t] + 
            0.03132297449134708`\ \(c[32]\)[t] + 
            0.04454710875183992`\ \(c[33]\)[t] + 
            0.05544148706619893`\ \(c[34]\)[t] + 
            0.06361487254866825`\ \(c[35]\)[t] + 
            0.06880242987642335`\ \(c[36]\)[t] + 
            0.07087301895267824`\ \(c[37]\)[t] + 
            0.06983076867396242`\ \(c[38]\)[t] + 
            0.06581101988179627`\ \(c[39]\)[t] + 
            0.059070953080906326`\ \(c[40]\)[t] + 
            0.049975424961080865`\ \(c[41]\)[t] + 
            0.03897872015785999`\ \(c[42]\)[t] + 
            0.026603074225527826`\ \(c[43]\)[t] + 
            0.013414935129827233`\ \(c[44]\)[t] + 
            3.898171832519376`*^-17\ \(c[45]\)[t] - 
            0.013061910521147383`\ \(c[46]\)[t] - 
            0.025221096343682053`\ \(c[47]\)[t] - 
            0.03598035706879378`\ \(c[48]\)[t] - 
            0.04491462243337642`\ \(c[49]\)[t] - 
            0.05168708394579296`\ \(c[50]\)[t] - 
            0.056061239158567186`\ \(c[51]\)[t] - 
            0.0579084423149932`\ \(c[52]\)[t] - 
            0.05721075023890897`\ \(c[53]\)[t] - 
            0.054059052045761224`\ \(c[54]\)[t] - 
            0.04864666724309928`\ \(c[55]\)[t] - 
            0.04125878107252025`\ \(c[56]\)[t] - 
            0.03225825116512552`\ \(c[57]\)[t] - 
            0.022068459300722043`\ \(c[58]\)[t] - 
            0.011153991006822649`\ \(c[59]\)[t] - 
            3.8981718325193755`*^-17\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -30, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -30]][ t]], 
          Plus[ 
            Times[ -3.8981718325193761*^-17, 
              c[ -60][ t]], 
            Times[ -0.034231213779559094, 
              c[ -59][ t]], 
            Times[ -0.06935801494512607, 
              c[ -58][ t]], 
            Times[ -0.10394325375429328, 
              c[ -57][ t]], 
            Times[ -0.13647135277833616, 
              c[ -56][ t]], 
            Times[ -0.16539866862653771, 
              c[ -55][ t]], 
            Times[ -0.18920668216016426, 
              c[ -54][ t]], 
            Times[ -0.20645618564475848, 
              c[ -53][ t]], 
            Times[ -0.21584055771952015, 
              c[ -52][ t]], 
            Times[ -0.21623620818304484, 
              c[ -51][ t]], 
            Times[ -0.20674833578317189, 
              c[ -50][ t]], 
            Times[ -0.18675027222298593, 
              c[ -49][ t]], 
            Times[ -0.15591488063143982, 
              c[ -48][ t]], 
            Times[ -0.11423673049785416, 
              c[ -47][ t]], 
            Times[ -0.062044074975450239, 
              c[ -46][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -45][ t]], 
            Times[ 0.070907514257658094, 
              c[ -44][ t]], 
            Times[ 0.14938649372796384, 
              c[ -43][ t]], 
            Times[ 0.23387232094715985, 
              c[ -42][ t]], 
            Times[ 0.32256865202152191, 
              c[ -41][ t]], 
            Times[ 0.41349667156634429, 
              c[ -40][ t]], 
            Times[ 0.50455115242710469, 
              c[ -39][ t]], 
            Times[ 0.59356153372868059, 
              c[ -38][ t]], 
            Times[ 0.67835603854706361, 
              c[ -37][ t]], 
            Times[ 0.75682672864065692, 
              c[ -36][ t]], 
            Times[ 0.82699334313268813, 
              c[ -35][ t]], 
            Times[ 0.88706379305918392, 
              c[ -34][ t]], 
            Times[ 0.93548928378863916, 
              c[ -33][ t]], 
            Times[ 0.9710122092317629, 
              c[ -32][ t]], 
            Times[ 0.99270519960720693, 
              c[ -31][ t]], 
            Times[ 20.739208802178716, 
              c[ -30][ t]], 
            Times[ 0.99270519960720671, 
              c[ -29][ t]], 
            Times[ 0.9710122092317629, 
              c[ -28][ t]], 
            Times[ 0.93548928378863916, 
              c[ -27][ t]], 
            Times[ 0.88706379305918381, 
              c[ -26][ t]], 
            Times[ 0.82699334313268802, 
              c[ -25][ t]], 
            Times[ 0.75682672864065692, 
              c[ -24][ t]], 
            Times[ 0.67835603854706317, 
              c[ -23][ t]], 
            Times[ 0.59356153372868015, 
              c[ -22][ t]], 
            Times[ 0.50455115242710469, 
              c[ -21][ t]], 
            Times[ 0.41349667156634395, 
              c[ -20][ t]], 
            Times[ 0.32256865202152135, 
              c[ -19][ t]], 
            Times[ 0.23387232094715985, 
              c[ -18][ t]], 
            Times[ 0.14938649372796345, 
              c[ -17][ t]], 
            Times[ 0.070907514257657622, 
              c[ -16][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -15][ t]], 
            Times[ -0.062044074975450475, 
              c[ -14][ t]], 
            Times[ -0.11423673049785445, 
              c[ -13][ t]], 
            Times[ -0.15591488063143982, 
              c[ -12][ t]], 
            Times[ -0.18675027222298607, 
              c[ -11][ t]], 
            Times[ -0.20674833578317206, 
              c[ -10][ t]], 
            Times[ -0.21623620818304484, 
              c[ -9][ t]], 
            Times[ -0.21584055771952013, 
              c[ -8][ t]], 
            Times[ -0.20645618564475834, 
              c[ -7][ t]], 
            Times[ -0.18920668216016426, 
              c[ -6][ t]], 
            Times[ -0.1653986686265376, 
              c[ -5][ t]], 
            Times[ -0.13647135277833605, 
              c[ -4][ t]], 
            Times[ -0.10394325375429328, 
              c[ -3][ t]], 
            Times[ -0.069358014945125918, 
              c[ -2][ t]], 
            Times[ -0.034231213779558949, 
              c[ -1][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 0][ t]], 
            Times[ 0.032022748374426029, 
              c[ 1][ t]], 
            Times[ 0.060688263076985105, 
              c[ 2][ t]], 
            Times[ 0.085044480344421705, 
              c[ 3][ t]], 
            Times[ 0.10436044624225692, 
              c[ 4][ t]], 
            Times[ 0.11814190616181255, 
              c[ 5][ t]], 
            Times[ 0.12613778810677614, 
              c[ 6][ t]], 
            Times[ 0.12833762891430928, 
              c[ 7][ t]], 
            Times[ 0.12496032289024853, 
              c[ 8][ t]], 
            Times[ 0.11643488132933186, 
              c[ 9][ t]], 
            Times[ 0.10337416789158609, 
              c[ 10][ t]], 
            Times[ 0.086542809078944891, 
              c[ 11][ t]], 
            Times[ 0.066820663127759972, 
              c[ 12][ t]], 
            Times[ 0.045163358568919301, 
              c[ 13][ t]], 
            Times[ 0.022561481809254869, 
              c[ 14][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 15][ t]], 
            Times[ -0.021580547817547879, 
              c[ 16][ t]], 
            Times[ -0.04131966847794722, 
              c[ 17][ t]], 
            Times[ -0.058468080236789913, 
              c[ 18][ t]], 
            Times[ -0.072413370861974122, 
              c[ 19][ t]], 
            Times[ -0.082699334313268744, 
              c[ 20][ t]], 
            Times[ -0.089038438663606695, 
              c[ 21][ t]], 
            Times[ -0.091317159035181589, 
              c[ 22][ t]], 
            Times[ -0.089594193770366884, 
              c[ 23][ t]], 
            Times[ -0.084091858737850814, 
              c[ 24][ t]], 
            Times[ -0.075181213012062598, 
              c[ 25][ t]], 
            Times[ -0.063361699504227528, 
              c[ 26][ t]], 
            Times[ -0.049236278094138941, 
              c[ 27][ t]], 
            Times[ -0.033483179628681567, 
              c[ 28][ t]], 
            Times[ -0.016825511857749401, 
              c[ 29][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 30][ t]], 
            Times[ 0.016273855731265604, 
              c[ 31][ t]], 
            Times[ 0.031322974491347078, 
              c[ 32][ t]], 
            Times[ 0.044547108751839919, 
              c[ 33][ t]], 
            Times[ 0.055441487066198933, 
              c[ 34][ t]], 
            Times[ 0.063614872548668253, 
              c[ 35][ t]], 
            Times[ 0.068802429876423349, 
              c[ 36][ t]], 
            Times[ 0.070873018952678238, 
              c[ 37][ t]], 
            Times[ 0.069830768673962415, 
              c[ 38][ t]], 
            Times[ 0.065811019881796273, 
              c[ 39][ t]], 
            Times[ 0.059070953080906326, 
              c[ 40][ t]], 
            Times[ 0.049975424961080865, 
              c[ 41][ t]], 
            Times[ 0.03897872015785999, 
              c[ 42][ t]], 
            Times[ 0.026603074225527826, 
              c[ 43][ t]], 
            Times[ 0.013414935129827233, 
              c[ 44][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 45][ t]], 
            Times[ -0.013061910521147383, 
              c[ 46][ t]], 
            Times[ -0.025221096343682053, 
              c[ 47][ t]], 
            Times[ -0.035980357068793781, 
              c[ 48][ t]], 
            Times[ -0.044914622433376419, 
              c[ 49][ t]], 
            Times[ -0.05168708394579296, 
              c[ 50][ t]], 
            Times[ -0.056061239158567186, 
              c[ 51][ t]], 
            Times[ -0.057908442314993203, 
              c[ 52][ t]], 
            Times[ -0.057210750238908967, 
              c[ 53][ t]], 
            Times[ -0.054059052045761224, 
              c[ 54][ t]], 
            Times[ -0.048646667243099281, 
              c[ 55][ t]], 
            Times[ -0.041258781072520248, 
              c[ 56][ t]], 
            Times[ -0.032258251165125519, 
              c[ 57][ t]], 
            Times[ -0.022068459300722043, 
              c[ 58][ t]], 
            Times[ -0.011153991006822649, 
              c[ 59][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-29\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-29\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.03202274837442603`\ \(c[\(-60\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-59\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-58\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-57\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-56\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-55\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-54\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-53\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-52\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-51\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-50\)]\)[t] - 
            0.206748335783172`\ \(c[\(-49\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-48\)]\)[t] - 
            0.15591488063143966`\ \(c[\(-47\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-46\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-45\)]\)[t] + 
            3.216976900108398`*^-16\ \(c[\(-44\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-43\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-42\)]\)[t] + 
            0.23387232094716018`\ \(c[\(-41\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-40\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-39\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-38\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-37\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-36\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-35\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-34\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-33\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-32\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-31\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-30\)]\)[t] + 
            19.445194002924776`\ \(c[\(-29\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-28\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-27\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-26\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-25\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-24\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-23\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-22\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-21\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-20\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-19\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-18\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-17\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-16\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-15\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-14\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-13\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-12\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-11\)]\)[t] - 
            0.186750272222986`\ \(c[\(-10\)]\)[t] - 
            0.206748335783172`\ \(c[\(-9\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-8\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-7\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-6\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-5\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-4\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-3\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-2\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-1\)]\)[t] - 
            0.03423121377955895`\ \(c[0]\)[t] - 
            3.898171832519376`*^-17\ \(c[1]\)[t] + 
            0.032022748374425904`\ \(c[2]\)[t] + 
            0.060688263076985105`\ \(c[3]\)[t] + 
            0.0850444803444217`\ \(c[4]\)[t] + 
            0.10436044624225685`\ \(c[5]\)[t] + 
            0.11814190616181255`\ \(c[6]\)[t] + 
            0.12613778810677614`\ \(c[7]\)[t] + 
            0.12833762891430928`\ \(c[8]\)[t] + 
            0.12496032289024853`\ \(c[9]\)[t] + 
            0.11643488132933186`\ \(c[10]\)[t] + 
            0.10337416789158609`\ \(c[11]\)[t] + 
            0.08654280907894489`\ \(c[12]\)[t] + 
            0.06682066312775997`\ \(c[13]\)[t] + 
            0.0451633585689193`\ \(c[14]\)[t] + 
            0.02256148180925487`\ \(c[15]\)[t] + 
            3.8981718325193755`*^-17\ \(c[16]\)[t] - 
            0.02158054781754788`\ \(c[17]\)[t] - 
            0.04131966847794722`\ \(c[18]\)[t] - 
            0.05846808023678991`\ \(c[19]\)[t] - 
            0.07241337086197412`\ \(c[20]\)[t] - 
            0.08269933431326874`\ \(c[21]\)[t] - 
            0.0890384386636067`\ \(c[22]\)[t] - 
            0.09131715903518159`\ \(c[23]\)[t] - 
            0.08959419377036688`\ \(c[24]\)[t] - 
            0.08409185873785081`\ \(c[25]\)[t] - 
            0.0751812130120626`\ \(c[26]\)[t] - 
            0.06336169950422753`\ \(c[27]\)[t] - 
            0.04923627809413894`\ \(c[28]\)[t] - 
            0.03348317962868157`\ \(c[29]\)[t] - 
            0.0168255118577494`\ \(c[30]\)[t] - 
            3.898171832519376`*^-17\ \(c[31]\)[t] + 
            0.016273855731265604`\ \(c[32]\)[t] + 
            0.03132297449134708`\ \(c[33]\)[t] + 
            0.04454710875183992`\ \(c[34]\)[t] + 
            0.05544148706619893`\ \(c[35]\)[t] + 
            0.06361487254866825`\ \(c[36]\)[t] + 
            0.06880242987642335`\ \(c[37]\)[t] + 
            0.07087301895267824`\ \(c[38]\)[t] + 
            0.06983076867396242`\ \(c[39]\)[t] + 
            0.06581101988179627`\ \(c[40]\)[t] + 
            0.0590709530809064`\ \(c[41]\)[t] + 
            0.049975424961080865`\ \(c[42]\)[t] + 
            0.03897872015785999`\ \(c[43]\)[t] + 
            0.026603074225527937`\ \(c[44]\)[t] + 
            0.013414935129827233`\ \(c[45]\)[t] + 
            3.898171832519376`*^-17\ \(c[46]\)[t] - 
            0.013061910521147276`\ \(c[47]\)[t] - 
            0.025221096343682053`\ \(c[48]\)[t] - 
            0.03598035706879378`\ \(c[49]\)[t] - 
            0.04491462243337629`\ \(c[50]\)[t] - 
            0.05168708394579296`\ \(c[51]\)[t] - 
            0.056061239158567186`\ \(c[52]\)[t] - 
            0.0579084423149932`\ \(c[53]\)[t] - 
            0.05721075023890897`\ \(c[54]\)[t] - 
            0.054059052045761224`\ \(c[55]\)[t] - 
            0.0486466672430994`\ \(c[56]\)[t] - 
            0.04125878107252025`\ \(c[57]\)[t] - 
            0.03225825116512552`\ \(c[58]\)[t] - 
            0.022068459300722043`\ \(c[59]\)[t] - 
            0.011153991006822649`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -29, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -29]][ t]], 
          Plus[ 
            Times[ 0.032022748374426029, 
              c[ -60][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -59][ t]], 
            Times[ -0.034231213779558949, 
              c[ -58][ t]], 
            Times[ -0.069358014945125918, 
              c[ -57][ t]], 
            Times[ -0.1039432537542934, 
              c[ -56][ t]], 
            Times[ -0.13647135277833605, 
              c[ -55][ t]], 
            Times[ -0.1653986686265376, 
              c[ -54][ t]], 
            Times[ -0.18920668216016434, 
              c[ -53][ t]], 
            Times[ -0.20645618564475843, 
              c[ -52][ t]], 
            Times[ -0.21584055771952013, 
              c[ -51][ t]], 
            Times[ -0.21623620818304481, 
              c[ -50][ t]], 
            Times[ -0.206748335783172, 
              c[ -49][ t]], 
            Times[ -0.18675027222298607, 
              c[ -48][ t]], 
            Times[ -0.15591488063143966, 
              c[ -47][ t]], 
            Times[ -0.11423673049785436, 
              c[ -46][ t]], 
            Times[ -0.062044074975450475, 
              c[ -45][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ -44][ t]], 
            Times[ 0.070907514257657775, 
              c[ -43][ t]], 
            Times[ 0.14938649372796345, 
              c[ -42][ t]], 
            Times[ 0.23387232094716018, 
              c[ -41][ t]], 
            Times[ 0.32256865202152157, 
              c[ -40][ t]], 
            Times[ 0.41349667156634395, 
              c[ -39][ t]], 
            Times[ 0.50455115242710469, 
              c[ -38][ t]], 
            Times[ 0.59356153372868059, 
              c[ -37][ t]], 
            Times[ 0.67835603854706317, 
              c[ -36][ t]], 
            Times[ 0.75682672864065692, 
              c[ -35][ t]], 
            Times[ 0.82699334313268813, 
              c[ -34][ t]], 
            Times[ 0.88706379305918381, 
              c[ -33][ t]], 
            Times[ 0.93548928378863916, 
              c[ -32][ t]], 
            Times[ 0.9710122092317629, 
              c[ -31][ t]], 
            Times[ 0.99270519960720671, 
              c[ -30][ t]], 
            Times[ 19.445194002924776, 
              c[ -29][ t]], 
            Times[ 0.99270519960720671, 
              c[ -28][ t]], 
            Times[ 0.9710122092317629, 
              c[ -27][ t]], 
            Times[ 0.93548928378863916, 
              c[ -26][ t]], 
            Times[ 0.88706379305918381, 
              c[ -25][ t]], 
            Times[ 0.82699334313268813, 
              c[ -24][ t]], 
            Times[ 0.75682672864065692, 
              c[ -23][ t]], 
            Times[ 0.67835603854706317, 
              c[ -22][ t]], 
            Times[ 0.59356153372868059, 
              c[ -21][ t]], 
            Times[ 0.50455115242710469, 
              c[ -20][ t]], 
            Times[ 0.41349667156634418, 
              c[ -19][ t]], 
            Times[ 0.32256865202152157, 
              c[ -18][ t]], 
            Times[ 0.23387232094715985, 
              c[ -17][ t]], 
            Times[ 0.14938649372796362, 
              c[ -16][ t]], 
            Times[ 0.070907514257657775, 
              c[ -15][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -14][ t]], 
            Times[ -0.062044074975450343, 
              c[ -13][ t]], 
            Times[ -0.11423673049785436, 
              c[ -12][ t]], 
            Times[ -0.15591488063143982, 
              c[ -11][ t]], 
            Times[ -0.18675027222298601, 
              c[ -10][ t]], 
            Times[ -0.206748335783172, 
              c[ -9][ t]], 
            Times[ -0.21623620818304484, 
              c[ -8][ t]], 
            Times[ -0.21584055771952015, 
              c[ -7][ t]], 
            Times[ -0.20645618564475843, 
              c[ -6][ t]], 
            Times[ -0.18920668216016426, 
              c[ -5][ t]], 
            Times[ -0.16539866862653771, 
              c[ -4][ t]], 
            Times[ -0.13647135277833605, 
              c[ -3][ t]], 
            Times[ -0.10394325375429328, 
              c[ -2][ t]], 
            Times[ -0.06935801494512607, 
              c[ -1][ t]], 
            Times[ -0.034231213779558949, 
              c[ 0][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 1][ t]], 
            Times[ 0.032022748374425904, 
              c[ 2][ t]], 
            Times[ 0.060688263076985105, 
              c[ 3][ t]], 
            Times[ 0.085044480344421705, 
              c[ 4][ t]], 
            Times[ 0.10436044624225685, 
              c[ 5][ t]], 
            Times[ 0.11814190616181255, 
              c[ 6][ t]], 
            Times[ 0.12613778810677614, 
              c[ 7][ t]], 
            Times[ 0.12833762891430928, 
              c[ 8][ t]], 
            Times[ 0.12496032289024853, 
              c[ 9][ t]], 
            Times[ 0.11643488132933186, 
              c[ 10][ t]], 
            Times[ 0.10337416789158609, 
              c[ 11][ t]], 
            Times[ 0.086542809078944891, 
              c[ 12][ t]], 
            Times[ 0.066820663127759972, 
              c[ 13][ t]], 
            Times[ 0.045163358568919301, 
              c[ 14][ t]], 
            Times[ 0.022561481809254869, 
              c[ 15][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 16][ t]], 
            Times[ -0.021580547817547879, 
              c[ 17][ t]], 
            Times[ -0.04131966847794722, 
              c[ 18][ t]], 
            Times[ -0.058468080236789913, 
              c[ 19][ t]], 
            Times[ -0.072413370861974122, 
              c[ 20][ t]], 
            Times[ -0.082699334313268744, 
              c[ 21][ t]], 
            Times[ -0.089038438663606695, 
              c[ 22][ t]], 
            Times[ -0.091317159035181589, 
              c[ 23][ t]], 
            Times[ -0.089594193770366884, 
              c[ 24][ t]], 
            Times[ -0.084091858737850814, 
              c[ 25][ t]], 
            Times[ -0.075181213012062598, 
              c[ 26][ t]], 
            Times[ -0.063361699504227528, 
              c[ 27][ t]], 
            Times[ -0.049236278094138941, 
              c[ 28][ t]], 
            Times[ -0.033483179628681567, 
              c[ 29][ t]], 
            Times[ -0.016825511857749401, 
              c[ 30][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 31][ t]], 
            Times[ 0.016273855731265604, 
              c[ 32][ t]], 
            Times[ 0.031322974491347078, 
              c[ 33][ t]], 
            Times[ 0.044547108751839919, 
              c[ 34][ t]], 
            Times[ 0.055441487066198933, 
              c[ 35][ t]], 
            Times[ 0.063614872548668253, 
              c[ 36][ t]], 
            Times[ 0.068802429876423349, 
              c[ 37][ t]], 
            Times[ 0.070873018952678238, 
              c[ 38][ t]], 
            Times[ 0.069830768673962415, 
              c[ 39][ t]], 
            Times[ 0.065811019881796273, 
              c[ 40][ t]], 
            Times[ 0.059070953080906402, 
              c[ 41][ t]], 
            Times[ 0.049975424961080865, 
              c[ 42][ t]], 
            Times[ 0.03897872015785999, 
              c[ 43][ t]], 
            Times[ 0.026603074225527937, 
              c[ 44][ t]], 
            Times[ 0.013414935129827233, 
              c[ 45][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 46][ t]], 
            Times[ -0.013061910521147276, 
              c[ 47][ t]], 
            Times[ -0.025221096343682053, 
              c[ 48][ t]], 
            Times[ -0.035980357068793781, 
              c[ 49][ t]], 
            Times[ -0.044914622433376288, 
              c[ 50][ t]], 
            Times[ -0.05168708394579296, 
              c[ 51][ t]], 
            Times[ -0.056061239158567186, 
              c[ 52][ t]], 
            Times[ -0.057908442314993203, 
              c[ 53][ t]], 
            Times[ -0.057210750238908967, 
              c[ 54][ t]], 
            Times[ -0.054059052045761224, 
              c[ 55][ t]], 
            Times[ -0.048646667243099399, 
              c[ 56][ t]], 
            Times[ -0.041258781072520248, 
              c[ 57][ t]], 
            Times[ -0.032258251165125519, 
              c[ 58][ t]], 
            Times[ -0.022068459300722043, 
              c[ 59][ t]], 
            Times[ -0.011153991006822649, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-28\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-28\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.06068826307698522`\ \(c[\(-60\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-59\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-58\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-57\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-56\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-55\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-54\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-53\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-52\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-51\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-50\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-49\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-48\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-47\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-46\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-45\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-44\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-43\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-42\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-41\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-40\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-39\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-38\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-37\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-36\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-35\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-34\)]\)[t] + 
            0.826993343132688`\ \(c[\(-33\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-32\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-31\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-30\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-29\)]\)[t] + 
            18.195044112120122`\ \(c[\(-28\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-27\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-26\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-25\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-24\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-23\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-22\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-21\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-20\)]\)[t] + 
            0.5045511524271049`\ \(c[\(-19\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-18\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-17\)]\)[t] + 
            0.23387232094715998`\ \(c[\(-16\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-15\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-14\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-13\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-12\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-11\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-10\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-9\)]\)[t] - 
            0.206748335783172`\ \(c[\(-8\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-7\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-6\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-5\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-4\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-3\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-2\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-1\)]\)[t] - 
            0.06935801494512607`\ \(c[0]\)[t] - 
            0.03423121377955895`\ \(c[1]\)[t] - 
            1.8033970416801674`*^-16\ \(c[2]\)[t] + 
            0.032022748374425904`\ \(c[3]\)[t] + 
            0.060688263076985105`\ \(c[4]\)[t] + 
            0.08504448034442161`\ \(c[5]\)[t] + 
            0.10436044624225685`\ \(c[6]\)[t] + 
            0.11814190616181253`\ \(c[7]\)[t] + 
            0.12613778810677612`\ \(c[8]\)[t] + 
            0.12833762891430928`\ \(c[9]\)[t] + 
            0.12496032289024853`\ \(c[10]\)[t] + 
            0.11643488132933186`\ \(c[11]\)[t] + 
            0.10337416789158609`\ \(c[12]\)[t] + 
            0.08654280907894489`\ \(c[13]\)[t] + 
            0.06682066312775997`\ \(c[14]\)[t] + 
            0.0451633585689193`\ \(c[15]\)[t] + 
            0.02256148180925487`\ \(c[16]\)[t] + 
            3.8981718325193755`*^-17\ \(c[17]\)[t] - 
            0.02158054781754788`\ \(c[18]\)[t] - 
            0.04131966847794722`\ \(c[19]\)[t] - 
            0.05846808023678991`\ \(c[20]\)[t] - 
            0.07241337086197412`\ \(c[21]\)[t] - 
            0.08269933431326874`\ \(c[22]\)[t] - 
            0.0890384386636067`\ \(c[23]\)[t] - 
            0.09131715903518159`\ \(c[24]\)[t] - 
            0.08959419377036688`\ \(c[25]\)[t] - 
            0.08409185873785081`\ \(c[26]\)[t] - 
            0.0751812130120626`\ \(c[27]\)[t] - 
            0.06336169950422753`\ \(c[28]\)[t] - 
            0.04923627809413894`\ \(c[29]\)[t] - 
            0.03348317962868157`\ \(c[30]\)[t] - 
            0.0168255118577494`\ \(c[31]\)[t] - 
            3.898171832519376`*^-17\ \(c[32]\)[t] + 
            0.016273855731265604`\ \(c[33]\)[t] + 
            0.03132297449134708`\ \(c[34]\)[t] + 
            0.04454710875183992`\ \(c[35]\)[t] + 
            0.05544148706619893`\ \(c[36]\)[t] + 
            0.06361487254866825`\ \(c[37]\)[t] + 
            0.06880242987642335`\ \(c[38]\)[t] + 
            0.07087301895267824`\ \(c[39]\)[t] + 
            0.06983076867396242`\ \(c[40]\)[t] + 
            0.06581101988179631`\ \(c[41]\)[t] + 
            0.059070953080906326`\ \(c[42]\)[t] + 
            0.049975424961080865`\ \(c[43]\)[t] + 
            0.03897872015786009`\ \(c[44]\)[t] + 
            0.026603074225527826`\ \(c[45]\)[t] + 
            0.013414935129827233`\ \(c[46]\)[t] + 
            1.5206810699945212`*^-16\ \(c[47]\)[t] - 
            0.013061910521147383`\ \(c[48]\)[t] - 
            0.025221096343682053`\ \(c[49]\)[t] - 
            0.03598035706879378`\ \(c[50]\)[t] - 
            0.04491462243337642`\ \(c[51]\)[t] - 
            0.05168708394579296`\ \(c[52]\)[t] - 
            0.05606123915856713`\ \(c[53]\)[t] - 
            0.0579084423149932`\ \(c[54]\)[t] - 
            0.05721075023890897`\ \(c[55]\)[t] - 
            0.054059052045761224`\ \(c[56]\)[t] - 
            0.04864666724309928`\ \(c[57]\)[t] - 
            0.04125878107252025`\ \(c[58]\)[t] - 
            0.03225825116512568`\ \(c[59]\)[t] - 
            0.022068459300722043`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -28, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -28]][ t]], 
          Plus[ 
            Times[ 0.060688263076985223, 
              c[ -60][ t]], 
            Times[ 0.032022748374425904, 
              c[ -59][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -58][ t]], 
            Times[ -0.034231213779558796, 
              c[ -57][ t]], 
            Times[ -0.06935801494512607, 
              c[ -56][ t]], 
            Times[ -0.10394325375429328, 
              c[ -55][ t]], 
            Times[ -0.13647135277833591, 
              c[ -54][ t]], 
            Times[ -0.16539866862653771, 
              c[ -53][ t]], 
            Times[ -0.18920668216016426, 
              c[ -52][ t]], 
            Times[ -0.20645618564475834, 
              c[ -51][ t]], 
            Times[ -0.21584055771952015, 
              c[ -50][ t]], 
            Times[ -0.21623620818304484, 
              c[ -49][ t]], 
            Times[ -0.20674833578317206, 
              c[ -48][ t]], 
            Times[ -0.18675027222298593, 
              c[ -47][ t]], 
            Times[ -0.15591488063143982, 
              c[ -46][ t]], 
            Times[ -0.11423673049785459, 
              c[ -45][ t]], 
            Times[ -0.062044074975450239, 
              c[ -44][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -43][ t]], 
            Times[ 0.070907514257657456, 
              c[ -42][ t]], 
            Times[ 0.14938649372796384, 
              c[ -41][ t]], 
            Times[ 0.23387232094715985, 
              c[ -40][ t]], 
            Times[ 0.32256865202152113, 
              c[ -39][ t]], 
            Times[ 0.41349667156634395, 
              c[ -38][ t]], 
            Times[ 0.50455115242710469, 
              c[ -37][ t]], 
            Times[ 0.59356153372868015, 
              c[ -36][ t]], 
            Times[ 0.67835603854706317, 
              c[ -35][ t]], 
            Times[ 0.75682672864065692, 
              c[ -34][ t]], 
            Times[ 0.82699334313268802, 
              c[ -33][ t]], 
            Times[ 0.88706379305918381, 
              c[ -32][ t]], 
            Times[ 0.93548928378863916, 
              c[ -31][ t]], 
            Times[ 0.9710122092317629, 
              c[ -30][ t]], 
            Times[ 0.99270519960720671, 
              c[ -29][ t]], 
            Times[ 18.195044112120122, 
              c[ -28][ t]], 
            Times[ 0.99270519960720693, 
              c[ -27][ t]], 
            Times[ 0.9710122092317629, 
              c[ -26][ t]], 
            Times[ 0.93548928378863916, 
              c[ -25][ t]], 
            Times[ 0.88706379305918392, 
              c[ -24][ t]], 
            Times[ 0.82699334313268813, 
              c[ -23][ t]], 
            Times[ 0.75682672864065692, 
              c[ -22][ t]], 
            Times[ 0.67835603854706361, 
              c[ -21][ t]], 
            Times[ 0.59356153372868059, 
              c[ -20][ t]], 
            Times[ 0.50455115242710491, 
              c[ -19][ t]], 
            Times[ 0.41349667156634429, 
              c[ -18][ t]], 
            Times[ 0.32256865202152157, 
              c[ -17][ t]], 
            Times[ 0.23387232094715998, 
              c[ -16][ t]], 
            Times[ 0.14938649372796384, 
              c[ -15][ t]], 
            Times[ 0.070907514257657775, 
              c[ -14][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -13][ t]], 
            Times[ -0.062044074975450239, 
              c[ -12][ t]], 
            Times[ -0.11423673049785436, 
              c[ -11][ t]], 
            Times[ -0.15591488063143974, 
              c[ -10][ t]], 
            Times[ -0.18675027222298593, 
              c[ -9][ t]], 
            Times[ -0.206748335783172, 
              c[ -8][ t]], 
            Times[ -0.21623620818304484, 
              c[ -7][ t]], 
            Times[ -0.21584055771952015, 
              c[ -6][ t]], 
            Times[ -0.20645618564475843, 
              c[ -5][ t]], 
            Times[ -0.18920668216016434, 
              c[ -4][ t]], 
            Times[ -0.16539866862653771, 
              c[ -3][ t]], 
            Times[ -0.13647135277833605, 
              c[ -2][ t]], 
            Times[ -0.1039432537542934, 
              c[ -1][ t]], 
            Times[ -0.06935801494512607, 
              c[ 0][ t]], 
            Times[ -0.034231213779558949, 
              c[ 1][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 2][ t]], 
            Times[ 0.032022748374425904, 
              c[ 3][ t]], 
            Times[ 0.060688263076985105, 
              c[ 4][ t]], 
            Times[ 0.085044480344421608, 
              c[ 5][ t]], 
            Times[ 0.10436044624225685, 
              c[ 6][ t]], 
            Times[ 0.11814190616181253, 
              c[ 7][ t]], 
            Times[ 0.12613778810677612, 
              c[ 8][ t]], 
            Times[ 0.12833762891430928, 
              c[ 9][ t]], 
            Times[ 0.12496032289024853, 
              c[ 10][ t]], 
            Times[ 0.11643488132933186, 
              c[ 11][ t]], 
            Times[ 0.10337416789158609, 
              c[ 12][ t]], 
            Times[ 0.086542809078944891, 
              c[ 13][ t]], 
            Times[ 0.066820663127759972, 
              c[ 14][ t]], 
            Times[ 0.045163358568919301, 
              c[ 15][ t]], 
            Times[ 0.022561481809254869, 
              c[ 16][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 17][ t]], 
            Times[ -0.021580547817547879, 
              c[ 18][ t]], 
            Times[ -0.04131966847794722, 
              c[ 19][ t]], 
            Times[ -0.058468080236789913, 
              c[ 20][ t]], 
            Times[ -0.072413370861974122, 
              c[ 21][ t]], 
            Times[ -0.082699334313268744, 
              c[ 22][ t]], 
            Times[ -0.089038438663606695, 
              c[ 23][ t]], 
            Times[ -0.091317159035181589, 
              c[ 24][ t]], 
            Times[ -0.089594193770366884, 
              c[ 25][ t]], 
            Times[ -0.084091858737850814, 
              c[ 26][ t]], 
            Times[ -0.075181213012062598, 
              c[ 27][ t]], 
            Times[ -0.063361699504227528, 
              c[ 28][ t]], 
            Times[ -0.049236278094138941, 
              c[ 29][ t]], 
            Times[ -0.033483179628681567, 
              c[ 30][ t]], 
            Times[ -0.016825511857749401, 
              c[ 31][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 32][ t]], 
            Times[ 0.016273855731265604, 
              c[ 33][ t]], 
            Times[ 0.031322974491347078, 
              c[ 34][ t]], 
            Times[ 0.044547108751839919, 
              c[ 35][ t]], 
            Times[ 0.055441487066198933, 
              c[ 36][ t]], 
            Times[ 0.063614872548668253, 
              c[ 37][ t]], 
            Times[ 0.068802429876423349, 
              c[ 38][ t]], 
            Times[ 0.070873018952678238, 
              c[ 39][ t]], 
            Times[ 0.069830768673962415, 
              c[ 40][ t]], 
            Times[ 0.065811019881796315, 
              c[ 41][ t]], 
            Times[ 0.059070953080906326, 
              c[ 42][ t]], 
            Times[ 0.049975424961080865, 
              c[ 43][ t]], 
            Times[ 0.038978720157860088, 
              c[ 44][ t]], 
            Times[ 0.026603074225527826, 
              c[ 45][ t]], 
            Times[ 0.013414935129827233, 
              c[ 46][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ 47][ t]], 
            Times[ -0.013061910521147383, 
              c[ 48][ t]], 
            Times[ -0.025221096343682053, 
              c[ 49][ t]], 
            Times[ -0.035980357068793781, 
              c[ 50][ t]], 
            Times[ -0.044914622433376419, 
              c[ 51][ t]], 
            Times[ -0.05168708394579296, 
              c[ 52][ t]], 
            Times[ -0.05606123915856713, 
              c[ 53][ t]], 
            Times[ -0.057908442314993203, 
              c[ 54][ t]], 
            Times[ -0.057210750238908967, 
              c[ 55][ t]], 
            Times[ -0.054059052045761224, 
              c[ 56][ t]], 
            Times[ -0.048646667243099281, 
              c[ 57][ t]], 
            Times[ -0.041258781072520248, 
              c[ 58][ t]], 
            Times[ -0.032258251165125679, 
              c[ 59][ t]], 
            Times[ -0.022068459300722043, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-27\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-27\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.0850444803444217`\ \(c[\(-60\)]\)[t] + 
            0.060688263076985`\ \(c[\(-59\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-58\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-57\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-56\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-55\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-54\)]\)[t] - 
            0.13647135277833616`\ \(c[\(-53\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-52\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-51\)]\)[t] - 
            0.20645618564475848`\ \(c[\(-50\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-49\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-48\)]\)[t] - 
            0.2067483357831719`\ \(c[\(-47\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-46\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-45\)]\)[t] - 
            0.11423673049785416`\ \(c[\(-44\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-43\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-42\)]\)[t] + 
            0.0709075142576581`\ \(c[\(-41\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-40\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-39\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-38\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-37\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-36\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-35\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-34\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-33\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-32\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-31\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-30\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-29\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-28\)]\)[t] + 
            16.98875912976476`\ \(c[\(-27\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-26\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-25\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-24\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-23\)]\)[t] + 
            0.826993343132688`\ \(c[\(-22\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-21\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-20\)]\)[t] + 
            0.5935615337286803`\ \(c[\(-19\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-18\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-17\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-16\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-15\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-14\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-13\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-12\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-11\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-10\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-9\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-8\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-7\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-6\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-5\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-4\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-3\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-2\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-1\)]\)[t] - 
            0.10394325375429328`\ \(c[0]\)[t] - 
            0.06935801494512592`\ \(c[1]\)[t] - 
            0.03423121377955895`\ \(c[2]\)[t] - 
            3.898171832519376`*^-17\ \(c[3]\)[t] + 
            0.03202274837442603`\ \(c[4]\)[t] + 
            0.060688263076985105`\ \(c[5]\)[t] + 
            0.0850444803444217`\ \(c[6]\)[t] + 
            0.10436044624225685`\ \(c[7]\)[t] + 
            0.11814190616181255`\ \(c[8]\)[t] + 
            0.12613778810677614`\ \(c[9]\)[t] + 
            0.12833762891430928`\ \(c[10]\)[t] + 
            0.12496032289024853`\ \(c[11]\)[t] + 
            0.11643488132933186`\ \(c[12]\)[t] + 
            0.10337416789158609`\ \(c[13]\)[t] + 
            0.08654280907894489`\ \(c[14]\)[t] + 
            0.06682066312775997`\ \(c[15]\)[t] + 
            0.0451633585689193`\ \(c[16]\)[t] + 
            0.02256148180925487`\ \(c[17]\)[t] + 
            3.8981718325193755`*^-17\ \(c[18]\)[t] - 
            0.02158054781754788`\ \(c[19]\)[t] - 
            0.04131966847794722`\ \(c[20]\)[t] - 
            0.05846808023678991`\ \(c[21]\)[t] - 
            0.07241337086197412`\ \(c[22]\)[t] - 
            0.08269933431326874`\ \(c[23]\)[t] - 
            0.0890384386636067`\ \(c[24]\)[t] - 
            0.09131715903518159`\ \(c[25]\)[t] - 
            0.08959419377036688`\ \(c[26]\)[t] - 
            0.08409185873785081`\ \(c[27]\)[t] - 
            0.0751812130120626`\ \(c[28]\)[t] - 
            0.06336169950422753`\ \(c[29]\)[t] - 
            0.04923627809413894`\ \(c[30]\)[t] - 
            0.03348317962868157`\ \(c[31]\)[t] - 
            0.0168255118577494`\ \(c[32]\)[t] - 
            3.898171832519376`*^-17\ \(c[33]\)[t] + 
            0.016273855731265604`\ \(c[34]\)[t] + 
            0.03132297449134708`\ \(c[35]\)[t] + 
            0.04454710875183992`\ \(c[36]\)[t] + 
            0.05544148706619893`\ \(c[37]\)[t] + 
            0.06361487254866825`\ \(c[38]\)[t] + 
            0.06880242987642335`\ \(c[39]\)[t] + 
            0.07087301895267824`\ \(c[40]\)[t] + 
            0.06983076867396242`\ \(c[41]\)[t] + 
            0.06581101988179627`\ \(c[42]\)[t] + 
            0.059070953080906326`\ \(c[43]\)[t] + 
            0.049975424961080865`\ \(c[44]\)[t] + 
            0.03897872015785999`\ \(c[45]\)[t] + 
            0.026603074225527826`\ \(c[46]\)[t] + 
            0.013414935129827233`\ \(c[47]\)[t] + 
            3.898171832519376`*^-17\ \(c[48]\)[t] - 
            0.013061910521147383`\ \(c[49]\)[t] - 
            0.025221096343682053`\ \(c[50]\)[t] - 
            0.03598035706879378`\ \(c[51]\)[t] - 
            0.04491462243337642`\ \(c[52]\)[t] - 
            0.05168708394579296`\ \(c[53]\)[t] - 
            0.056061239158567186`\ \(c[54]\)[t] - 
            0.0579084423149932`\ \(c[55]\)[t] - 
            0.05721075023890897`\ \(c[56]\)[t] - 
            0.054059052045761224`\ \(c[57]\)[t] - 
            0.04864666724309928`\ \(c[58]\)[t] - 
            0.04125878107252025`\ \(c[59]\)[t] - 
            0.03225825116512552`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -27, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -27]][ t]], 
          Plus[ 
            Times[ 0.085044480344421705, 
              c[ -60][ t]], 
            Times[ 0.060688263076985001, 
              c[ -59][ t]], 
            Times[ 0.032022748374425904, 
              c[ -58][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -57][ t]], 
            Times[ -0.034231213779559094, 
              c[ -56][ t]], 
            Times[ -0.06935801494512607, 
              c[ -55][ t]], 
            Times[ -0.10394325375429328, 
              c[ -54][ t]], 
            Times[ -0.13647135277833616, 
              c[ -53][ t]], 
            Times[ -0.16539866862653771, 
              c[ -52][ t]], 
            Times[ -0.18920668216016426, 
              c[ -51][ t]], 
            Times[ -0.20645618564475848, 
              c[ -50][ t]], 
            Times[ -0.21584055771952015, 
              c[ -49][ t]], 
            Times[ -0.21623620818304484, 
              c[ -48][ t]], 
            Times[ -0.20674833578317189, 
              c[ -47][ t]], 
            Times[ -0.18675027222298593, 
              c[ -46][ t]], 
            Times[ -0.15591488063143982, 
              c[ -45][ t]], 
            Times[ -0.11423673049785416, 
              c[ -44][ t]], 
            Times[ -0.062044074975450239, 
              c[ -43][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -42][ t]], 
            Times[ 0.070907514257658094, 
              c[ -41][ t]], 
            Times[ 0.14938649372796384, 
              c[ -40][ t]], 
            Times[ 0.23387232094715985, 
              c[ -39][ t]], 
            Times[ 0.32256865202152157, 
              c[ -38][ t]], 
            Times[ 0.41349667156634429, 
              c[ -37][ t]], 
            Times[ 0.50455115242710469, 
              c[ -36][ t]], 
            Times[ 0.59356153372868059, 
              c[ -35][ t]], 
            Times[ 0.67835603854706361, 
              c[ -34][ t]], 
            Times[ 0.75682672864065692, 
              c[ -33][ t]], 
            Times[ 0.82699334313268813, 
              c[ -32][ t]], 
            Times[ 0.88706379305918392, 
              c[ -31][ t]], 
            Times[ 0.93548928378863916, 
              c[ -30][ t]], 
            Times[ 0.9710122092317629, 
              c[ -29][ t]], 
            Times[ 0.99270519960720693, 
              c[ -28][ t]], 
            Times[ 16.988759129764759, 
              c[ -27][ t]], 
            Times[ 0.99270519960720671, 
              c[ -26][ t]], 
            Times[ 0.9710122092317629, 
              c[ -25][ t]], 
            Times[ 0.93548928378863916, 
              c[ -24][ t]], 
            Times[ 0.88706379305918381, 
              c[ -23][ t]], 
            Times[ 0.82699334313268802, 
              c[ -22][ t]], 
            Times[ 0.75682672864065692, 
              c[ -21][ t]], 
            Times[ 0.67835603854706317, 
              c[ -20][ t]], 
            Times[ 0.59356153372868026, 
              c[ -19][ t]], 
            Times[ 0.50455115242710469, 
              c[ -18][ t]], 
            Times[ 0.41349667156634395, 
              c[ -17][ t]], 
            Times[ 0.32256865202152135, 
              c[ -16][ t]], 
            Times[ 0.23387232094715985, 
              c[ -15][ t]], 
            Times[ 0.14938649372796345, 
              c[ -14][ t]], 
            Times[ 0.070907514257657622, 
              c[ -13][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -12][ t]], 
            Times[ -0.062044074975450475, 
              c[ -11][ t]], 
            Times[ -0.11423673049785445, 
              c[ -10][ t]], 
            Times[ -0.15591488063143982, 
              c[ -9][ t]], 
            Times[ -0.18675027222298607, 
              c[ -8][ t]], 
            Times[ -0.20674833578317206, 
              c[ -7][ t]], 
            Times[ -0.21623620818304484, 
              c[ -6][ t]], 
            Times[ -0.21584055771952013, 
              c[ -5][ t]], 
            Times[ -0.20645618564475843, 
              c[ -4][ t]], 
            Times[ -0.18920668216016426, 
              c[ -3][ t]], 
            Times[ -0.1653986686265376, 
              c[ -2][ t]], 
            Times[ -0.13647135277833605, 
              c[ -1][ t]], 
            Times[ -0.10394325375429328, 
              c[ 0][ t]], 
            Times[ -0.069358014945125918, 
              c[ 1][ t]], 
            Times[ -0.034231213779558949, 
              c[ 2][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 3][ t]], 
            Times[ 0.032022748374426029, 
              c[ 4][ t]], 
            Times[ 0.060688263076985105, 
              c[ 5][ t]], 
            Times[ 0.085044480344421705, 
              c[ 6][ t]], 
            Times[ 0.10436044624225685, 
              c[ 7][ t]], 
            Times[ 0.11814190616181255, 
              c[ 8][ t]], 
            Times[ 0.12613778810677614, 
              c[ 9][ t]], 
            Times[ 0.12833762891430928, 
              c[ 10][ t]], 
            Times[ 0.12496032289024853, 
              c[ 11][ t]], 
            Times[ 0.11643488132933186, 
              c[ 12][ t]], 
            Times[ 0.10337416789158609, 
              c[ 13][ t]], 
            Times[ 0.086542809078944891, 
              c[ 14][ t]], 
            Times[ 0.066820663127759972, 
              c[ 15][ t]], 
            Times[ 0.045163358568919301, 
              c[ 16][ t]], 
            Times[ 0.022561481809254869, 
              c[ 17][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 18][ t]], 
            Times[ -0.021580547817547879, 
              c[ 19][ t]], 
            Times[ -0.04131966847794722, 
              c[ 20][ t]], 
            Times[ -0.058468080236789913, 
              c[ 21][ t]], 
            Times[ -0.072413370861974122, 
              c[ 22][ t]], 
            Times[ -0.082699334313268744, 
              c[ 23][ t]], 
            Times[ -0.089038438663606695, 
              c[ 24][ t]], 
            Times[ -0.091317159035181589, 
              c[ 25][ t]], 
            Times[ -0.089594193770366884, 
              c[ 26][ t]], 
            Times[ -0.084091858737850814, 
              c[ 27][ t]], 
            Times[ -0.075181213012062598, 
              c[ 28][ t]], 
            Times[ -0.063361699504227528, 
              c[ 29][ t]], 
            Times[ -0.049236278094138941, 
              c[ 30][ t]], 
            Times[ -0.033483179628681567, 
              c[ 31][ t]], 
            Times[ -0.016825511857749401, 
              c[ 32][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 33][ t]], 
            Times[ 0.016273855731265604, 
              c[ 34][ t]], 
            Times[ 0.031322974491347078, 
              c[ 35][ t]], 
            Times[ 0.044547108751839919, 
              c[ 36][ t]], 
            Times[ 0.055441487066198933, 
              c[ 37][ t]], 
            Times[ 0.063614872548668253, 
              c[ 38][ t]], 
            Times[ 0.068802429876423349, 
              c[ 39][ t]], 
            Times[ 0.070873018952678238, 
              c[ 40][ t]], 
            Times[ 0.069830768673962415, 
              c[ 41][ t]], 
            Times[ 0.065811019881796273, 
              c[ 42][ t]], 
            Times[ 0.059070953080906326, 
              c[ 43][ t]], 
            Times[ 0.049975424961080865, 
              c[ 44][ t]], 
            Times[ 0.03897872015785999, 
              c[ 45][ t]], 
            Times[ 0.026603074225527826, 
              c[ 46][ t]], 
            Times[ 0.013414935129827233, 
              c[ 47][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 48][ t]], 
            Times[ -0.013061910521147383, 
              c[ 49][ t]], 
            Times[ -0.025221096343682053, 
              c[ 50][ t]], 
            Times[ -0.035980357068793781, 
              c[ 51][ t]], 
            Times[ -0.044914622433376419, 
              c[ 52][ t]], 
            Times[ -0.05168708394579296, 
              c[ 53][ t]], 
            Times[ -0.056061239158567186, 
              c[ 54][ t]], 
            Times[ -0.057908442314993203, 
              c[ 55][ t]], 
            Times[ -0.057210750238908967, 
              c[ 56][ t]], 
            Times[ -0.054059052045761224, 
              c[ 57][ t]], 
            Times[ -0.048646667243099281, 
              c[ 58][ t]], 
            Times[ -0.041258781072520248, 
              c[ 59][ t]], 
            Times[ -0.032258251165125519, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-26\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-26\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.10436044624225692`\ \(c[\(-60\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-59\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-58\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-57\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-56\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-55\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-54\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-53\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-52\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-51\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-50\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-49\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-48\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-47\)]\)[t] - 
            0.206748335783172`\ \(c[\(-46\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-45\)]\)[t] - 
            0.15591488063143966`\ \(c[\(-44\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-43\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-42\)]\)[t] + 
            3.216976900108398`*^-16\ \(c[\(-41\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-40\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-39\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-38\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-37\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-36\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-35\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-34\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-33\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-32\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-31\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-30\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-29\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-28\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-27\)]\)[t] + 
            15.826339055858679`\ \(c[\(-26\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-25\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-24\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-23\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-22\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-21\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-20\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-19\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-18\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-17\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-16\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-15\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-14\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-13\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-12\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-11\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-10\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-9\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-8\)]\)[t] - 
            0.186750272222986`\ \(c[\(-7\)]\)[t] - 
            0.206748335783172`\ \(c[\(-6\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-5\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-4\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-3\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-2\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-1\)]\)[t] - 
            0.13647135277833605`\ \(c[0]\)[t] - 
            0.10394325375429328`\ \(c[1]\)[t] - 
            0.06935801494512607`\ \(c[2]\)[t] - 
            0.03423121377955895`\ \(c[3]\)[t] - 
            3.898171832519376`*^-17\ \(c[4]\)[t] + 
            0.032022748374425904`\ \(c[5]\)[t] + 
            0.060688263076985105`\ \(c[6]\)[t] + 
            0.0850444803444217`\ \(c[7]\)[t] + 
            0.10436044624225685`\ \(c[8]\)[t] + 
            0.11814190616181255`\ \(c[9]\)[t] + 
            0.12613778810677614`\ \(c[10]\)[t] + 
            0.12833762891430928`\ \(c[11]\)[t] + 
            0.12496032289024853`\ \(c[12]\)[t] + 
            0.11643488132933186`\ \(c[13]\)[t] + 
            0.10337416789158609`\ \(c[14]\)[t] + 
            0.08654280907894489`\ \(c[15]\)[t] + 
            0.06682066312775997`\ \(c[16]\)[t] + 
            0.0451633585689193`\ \(c[17]\)[t] + 
            0.02256148180925487`\ \(c[18]\)[t] + 
            3.8981718325193755`*^-17\ \(c[19]\)[t] - 
            0.02158054781754788`\ \(c[20]\)[t] - 
            0.04131966847794722`\ \(c[21]\)[t] - 
            0.05846808023678991`\ \(c[22]\)[t] - 
            0.07241337086197412`\ \(c[23]\)[t] - 
            0.08269933431326874`\ \(c[24]\)[t] - 
            0.0890384386636067`\ \(c[25]\)[t] - 
            0.09131715903518159`\ \(c[26]\)[t] - 
            0.08959419377036688`\ \(c[27]\)[t] - 
            0.08409185873785081`\ \(c[28]\)[t] - 
            0.0751812130120626`\ \(c[29]\)[t] - 
            0.06336169950422753`\ \(c[30]\)[t] - 
            0.04923627809413894`\ \(c[31]\)[t] - 
            0.03348317962868157`\ \(c[32]\)[t] - 
            0.0168255118577494`\ \(c[33]\)[t] - 
            3.898171832519376`*^-17\ \(c[34]\)[t] + 
            0.016273855731265604`\ \(c[35]\)[t] + 
            0.03132297449134708`\ \(c[36]\)[t] + 
            0.04454710875183992`\ \(c[37]\)[t] + 
            0.05544148706619893`\ \(c[38]\)[t] + 
            0.06361487254866825`\ \(c[39]\)[t] + 
            0.06880242987642335`\ \(c[40]\)[t] + 
            0.07087301895267824`\ \(c[41]\)[t] + 
            0.06983076867396242`\ \(c[42]\)[t] + 
            0.06581101988179627`\ \(c[43]\)[t] + 
            0.0590709530809064`\ \(c[44]\)[t] + 
            0.049975424961080865`\ \(c[45]\)[t] + 
            0.03897872015785999`\ \(c[46]\)[t] + 
            0.026603074225527937`\ \(c[47]\)[t] + 
            0.013414935129827233`\ \(c[48]\)[t] + 
            3.898171832519376`*^-17\ \(c[49]\)[t] - 
            0.013061910521147276`\ \(c[50]\)[t] - 
            0.025221096343682053`\ \(c[51]\)[t] - 
            0.03598035706879378`\ \(c[52]\)[t] - 
            0.04491462243337629`\ \(c[53]\)[t] - 
            0.05168708394579296`\ \(c[54]\)[t] - 
            0.056061239158567186`\ \(c[55]\)[t] - 
            0.0579084423149932`\ \(c[56]\)[t] - 
            0.05721075023890897`\ \(c[57]\)[t] - 
            0.054059052045761224`\ \(c[58]\)[t] - 
            0.0486466672430994`\ \(c[59]\)[t] - 
            0.04125878107252025`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -26, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -26]][ t]], 
          Plus[ 
            Times[ 0.10436044624225692, 
              c[ -60][ t]], 
            Times[ 0.085044480344421608, 
              c[ -59][ t]], 
            Times[ 0.060688263076985105, 
              c[ -58][ t]], 
            Times[ 0.032022748374426029, 
              c[ -57][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -56][ t]], 
            Times[ -0.034231213779558949, 
              c[ -55][ t]], 
            Times[ -0.069358014945125918, 
              c[ -54][ t]], 
            Times[ -0.1039432537542934, 
              c[ -53][ t]], 
            Times[ -0.13647135277833605, 
              c[ -52][ t]], 
            Times[ -0.1653986686265376, 
              c[ -51][ t]], 
            Times[ -0.18920668216016434, 
              c[ -50][ t]], 
            Times[ -0.20645618564475843, 
              c[ -49][ t]], 
            Times[ -0.21584055771952013, 
              c[ -48][ t]], 
            Times[ -0.21623620818304481, 
              c[ -47][ t]], 
            Times[ -0.206748335783172, 
              c[ -46][ t]], 
            Times[ -0.18675027222298607, 
              c[ -45][ t]], 
            Times[ -0.15591488063143966, 
              c[ -44][ t]], 
            Times[ -0.11423673049785436, 
              c[ -43][ t]], 
            Times[ -0.062044074975450475, 
              c[ -42][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ -41][ t]], 
            Times[ 0.070907514257657775, 
              c[ -40][ t]], 
            Times[ 0.14938649372796345, 
              c[ -39][ t]], 
            Times[ 0.23387232094715985, 
              c[ -38][ t]], 
            Times[ 0.32256865202152157, 
              c[ -37][ t]], 
            Times[ 0.41349667156634395, 
              c[ -36][ t]], 
            Times[ 0.50455115242710469, 
              c[ -35][ t]], 
            Times[ 0.59356153372868059, 
              c[ -34][ t]], 
            Times[ 0.67835603854706317, 
              c[ -33][ t]], 
            Times[ 0.75682672864065692, 
              c[ -32][ t]], 
            Times[ 0.82699334313268813, 
              c[ -31][ t]], 
            Times[ 0.88706379305918381, 
              c[ -30][ t]], 
            Times[ 0.93548928378863916, 
              c[ -29][ t]], 
            Times[ 0.9710122092317629, 
              c[ -28][ t]], 
            Times[ 0.99270519960720671, 
              c[ -27][ t]], 
            Times[ 15.826339055858679, 
              c[ -26][ t]], 
            Times[ 0.99270519960720671, 
              c[ -25][ t]], 
            Times[ 0.9710122092317629, 
              c[ -24][ t]], 
            Times[ 0.93548928378863916, 
              c[ -23][ t]], 
            Times[ 0.88706379305918381, 
              c[ -22][ t]], 
            Times[ 0.82699334313268813, 
              c[ -21][ t]], 
            Times[ 0.75682672864065692, 
              c[ -20][ t]], 
            Times[ 0.67835603854706339, 
              c[ -19][ t]], 
            Times[ 0.59356153372868059, 
              c[ -18][ t]], 
            Times[ 0.50455115242710469, 
              c[ -17][ t]], 
            Times[ 0.41349667156634418, 
              c[ -16][ t]], 
            Times[ 0.32256865202152157, 
              c[ -15][ t]], 
            Times[ 0.23387232094715985, 
              c[ -14][ t]], 
            Times[ 0.14938649372796362, 
              c[ -13][ t]], 
            Times[ 0.070907514257657775, 
              c[ -12][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -11][ t]], 
            Times[ -0.062044074975450343, 
              c[ -10][ t]], 
            Times[ -0.11423673049785436, 
              c[ -9][ t]], 
            Times[ -0.15591488063143982, 
              c[ -8][ t]], 
            Times[ -0.18675027222298601, 
              c[ -7][ t]], 
            Times[ -0.206748335783172, 
              c[ -6][ t]], 
            Times[ -0.21623620818304484, 
              c[ -5][ t]], 
            Times[ -0.21584055771952015, 
              c[ -4][ t]], 
            Times[ -0.20645618564475843, 
              c[ -3][ t]], 
            Times[ -0.18920668216016426, 
              c[ -2][ t]], 
            Times[ -0.16539866862653771, 
              c[ -1][ t]], 
            Times[ -0.13647135277833605, 
              c[ 0][ t]], 
            Times[ -0.10394325375429328, 
              c[ 1][ t]], 
            Times[ -0.06935801494512607, 
              c[ 2][ t]], 
            Times[ -0.034231213779558949, 
              c[ 3][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 4][ t]], 
            Times[ 0.032022748374425904, 
              c[ 5][ t]], 
            Times[ 0.060688263076985105, 
              c[ 6][ t]], 
            Times[ 0.085044480344421705, 
              c[ 7][ t]], 
            Times[ 0.10436044624225685, 
              c[ 8][ t]], 
            Times[ 0.11814190616181255, 
              c[ 9][ t]], 
            Times[ 0.12613778810677614, 
              c[ 10][ t]], 
            Times[ 0.12833762891430928, 
              c[ 11][ t]], 
            Times[ 0.12496032289024853, 
              c[ 12][ t]], 
            Times[ 0.11643488132933186, 
              c[ 13][ t]], 
            Times[ 0.10337416789158609, 
              c[ 14][ t]], 
            Times[ 0.086542809078944891, 
              c[ 15][ t]], 
            Times[ 0.066820663127759972, 
              c[ 16][ t]], 
            Times[ 0.045163358568919301, 
              c[ 17][ t]], 
            Times[ 0.022561481809254869, 
              c[ 18][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 19][ t]], 
            Times[ -0.021580547817547879, 
              c[ 20][ t]], 
            Times[ -0.04131966847794722, 
              c[ 21][ t]], 
            Times[ -0.058468080236789913, 
              c[ 22][ t]], 
            Times[ -0.072413370861974122, 
              c[ 23][ t]], 
            Times[ -0.082699334313268744, 
              c[ 24][ t]], 
            Times[ -0.089038438663606695, 
              c[ 25][ t]], 
            Times[ -0.091317159035181589, 
              c[ 26][ t]], 
            Times[ -0.089594193770366884, 
              c[ 27][ t]], 
            Times[ -0.084091858737850814, 
              c[ 28][ t]], 
            Times[ -0.075181213012062598, 
              c[ 29][ t]], 
            Times[ -0.063361699504227528, 
              c[ 30][ t]], 
            Times[ -0.049236278094138941, 
              c[ 31][ t]], 
            Times[ -0.033483179628681567, 
              c[ 32][ t]], 
            Times[ -0.016825511857749401, 
              c[ 33][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 34][ t]], 
            Times[ 0.016273855731265604, 
              c[ 35][ t]], 
            Times[ 0.031322974491347078, 
              c[ 36][ t]], 
            Times[ 0.044547108751839919, 
              c[ 37][ t]], 
            Times[ 0.055441487066198933, 
              c[ 38][ t]], 
            Times[ 0.063614872548668253, 
              c[ 39][ t]], 
            Times[ 0.068802429876423349, 
              c[ 40][ t]], 
            Times[ 0.070873018952678238, 
              c[ 41][ t]], 
            Times[ 0.069830768673962415, 
              c[ 42][ t]], 
            Times[ 0.065811019881796273, 
              c[ 43][ t]], 
            Times[ 0.059070953080906402, 
              c[ 44][ t]], 
            Times[ 0.049975424961080865, 
              c[ 45][ t]], 
            Times[ 0.03897872015785999, 
              c[ 46][ t]], 
            Times[ 0.026603074225527937, 
              c[ 47][ t]], 
            Times[ 0.013414935129827233, 
              c[ 48][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 49][ t]], 
            Times[ -0.013061910521147276, 
              c[ 50][ t]], 
            Times[ -0.025221096343682053, 
              c[ 51][ t]], 
            Times[ -0.035980357068793781, 
              c[ 52][ t]], 
            Times[ -0.044914622433376288, 
              c[ 53][ t]], 
            Times[ -0.05168708394579296, 
              c[ 54][ t]], 
            Times[ -0.056061239158567186, 
              c[ 55][ t]], 
            Times[ -0.057908442314993203, 
              c[ 56][ t]], 
            Times[ -0.057210750238908967, 
              c[ 57][ t]], 
            Times[ -0.054059052045761224, 
              c[ 58][ t]], 
            Times[ -0.048646667243099399, 
              c[ 59][ t]], 
            Times[ -0.041258781072520248, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-25\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-25\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.1181419061618126`\ \(c[\(-60\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-59\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-58\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-57\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-56\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-55\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-54\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-53\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-52\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-51\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-50\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-49\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-48\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-47\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-46\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-45\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-44\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-43\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-42\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-41\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-40\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-39\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-38\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-37\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-36\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-35\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-34\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-33\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-32\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-31\)]\)[t] + 
            0.826993343132688`\ \(c[\(-30\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-29\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-28\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-27\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-26\)]\)[t] + 
            14.707783890401883`\ \(c[\(-25\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-24\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-23\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-22\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-21\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-20\)]\)[t] + 
            0.7568267286406571`\ \(c[\(-19\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-18\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-17\)]\)[t] + 
            0.5045511524271049`\ \(c[\(-16\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-15\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-14\)]\)[t] + 
            0.23387232094715998`\ \(c[\(-13\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-12\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-11\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-10\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-9\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-8\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-7\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-6\)]\)[t] - 
            0.206748335783172`\ \(c[\(-5\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-4\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-3\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-2\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-1\)]\)[t] - 
            0.1653986686265377`\ \(c[0]\)[t] - 
            0.13647135277833605`\ \(c[1]\)[t] - 
            0.1039432537542934`\ \(c[2]\)[t] - 
            0.06935801494512607`\ \(c[3]\)[t] - 
            0.03423121377955895`\ \(c[4]\)[t] - 
            1.8033970416801674`*^-16\ \(c[5]\)[t] + 
            0.032022748374425904`\ \(c[6]\)[t] + 
            0.060688263076985`\ \(c[7]\)[t] + 
            0.08504448034442161`\ \(c[8]\)[t] + 
            0.10436044624225685`\ \(c[9]\)[t] + 
            0.11814190616181253`\ \(c[10]\)[t] + 
            0.12613778810677612`\ \(c[11]\)[t] + 
            0.12833762891430928`\ \(c[12]\)[t] + 
            0.12496032289024853`\ \(c[13]\)[t] + 
            0.11643488132933186`\ \(c[14]\)[t] + 
            0.10337416789158609`\ \(c[15]\)[t] + 
            0.08654280907894489`\ \(c[16]\)[t] + 
            0.06682066312775997`\ \(c[17]\)[t] + 
            0.0451633585689193`\ \(c[18]\)[t] + 
            0.02256148180925487`\ \(c[19]\)[t] + 
            3.8981718325193755`*^-17\ \(c[20]\)[t] - 
            0.02158054781754788`\ \(c[21]\)[t] - 
            0.04131966847794722`\ \(c[22]\)[t] - 
            0.05846808023678991`\ \(c[23]\)[t] - 
            0.07241337086197412`\ \(c[24]\)[t] - 
            0.08269933431326874`\ \(c[25]\)[t] - 
            0.0890384386636067`\ \(c[26]\)[t] - 
            0.09131715903518159`\ \(c[27]\)[t] - 
            0.08959419377036688`\ \(c[28]\)[t] - 
            0.08409185873785081`\ \(c[29]\)[t] - 
            0.0751812130120626`\ \(c[30]\)[t] - 
            0.06336169950422753`\ \(c[31]\)[t] - 
            0.04923627809413894`\ \(c[32]\)[t] - 
            0.03348317962868157`\ \(c[33]\)[t] - 
            0.0168255118577494`\ \(c[34]\)[t] - 
            3.898171832519376`*^-17\ \(c[35]\)[t] + 
            0.016273855731265604`\ \(c[36]\)[t] + 
            0.03132297449134708`\ \(c[37]\)[t] + 
            0.04454710875183992`\ \(c[38]\)[t] + 
            0.05544148706619893`\ \(c[39]\)[t] + 
            0.06361487254866825`\ \(c[40]\)[t] + 
            0.06880242987642332`\ \(c[41]\)[t] + 
            0.07087301895267824`\ \(c[42]\)[t] + 
            0.06983076867396242`\ \(c[43]\)[t] + 
            0.06581101988179631`\ \(c[44]\)[t] + 
            0.059070953080906326`\ \(c[45]\)[t] + 
            0.049975424961080865`\ \(c[46]\)[t] + 
            0.03897872015786009`\ \(c[47]\)[t] + 
            0.026603074225527826`\ \(c[48]\)[t] + 
            0.013414935129827233`\ \(c[49]\)[t] + 
            1.5206810699945212`*^-16\ \(c[50]\)[t] - 
            0.013061910521147383`\ \(c[51]\)[t] - 
            0.025221096343682053`\ \(c[52]\)[t] - 
            0.03598035706879378`\ \(c[53]\)[t] - 
            0.04491462243337642`\ \(c[54]\)[t] - 
            0.05168708394579296`\ \(c[55]\)[t] - 
            0.05606123915856713`\ \(c[56]\)[t] - 
            0.0579084423149932`\ \(c[57]\)[t] - 
            0.05721075023890897`\ \(c[58]\)[t] - 
            0.054059052045761224`\ \(c[59]\)[t] - 
            0.04864666724309928`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -25, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -25]][ t]], 
          Plus[ 
            Times[ 0.1181419061618126, 
              c[ -60][ t]], 
            Times[ 0.10436044624225685, 
              c[ -59][ t]], 
            Times[ 0.085044480344421705, 
              c[ -58][ t]], 
            Times[ 0.060688263076985223, 
              c[ -57][ t]], 
            Times[ 0.032022748374425904, 
              c[ -56][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -55][ t]], 
            Times[ -0.034231213779558796, 
              c[ -54][ t]], 
            Times[ -0.06935801494512607, 
              c[ -53][ t]], 
            Times[ -0.10394325375429328, 
              c[ -52][ t]], 
            Times[ -0.13647135277833591, 
              c[ -51][ t]], 
            Times[ -0.16539866862653771, 
              c[ -50][ t]], 
            Times[ -0.18920668216016426, 
              c[ -49][ t]], 
            Times[ -0.20645618564475834, 
              c[ -48][ t]], 
            Times[ -0.21584055771952015, 
              c[ -47][ t]], 
            Times[ -0.21623620818304484, 
              c[ -46][ t]], 
            Times[ -0.20674833578317206, 
              c[ -45][ t]], 
            Times[ -0.18675027222298593, 
              c[ -44][ t]], 
            Times[ -0.15591488063143982, 
              c[ -43][ t]], 
            Times[ -0.11423673049785459, 
              c[ -42][ t]], 
            Times[ -0.062044074975450239, 
              c[ -41][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -40][ t]], 
            Times[ 0.070907514257657456, 
              c[ -39][ t]], 
            Times[ 0.14938649372796345, 
              c[ -38][ t]], 
            Times[ 0.23387232094715985, 
              c[ -37][ t]], 
            Times[ 0.32256865202152113, 
              c[ -36][ t]], 
            Times[ 0.41349667156634395, 
              c[ -35][ t]], 
            Times[ 0.50455115242710469, 
              c[ -34][ t]], 
            Times[ 0.59356153372868015, 
              c[ -33][ t]], 
            Times[ 0.67835603854706317, 
              c[ -32][ t]], 
            Times[ 0.75682672864065692, 
              c[ -31][ t]], 
            Times[ 0.82699334313268802, 
              c[ -30][ t]], 
            Times[ 0.88706379305918381, 
              c[ -29][ t]], 
            Times[ 0.93548928378863916, 
              c[ -28][ t]], 
            Times[ 0.9710122092317629, 
              c[ -27][ t]], 
            Times[ 0.99270519960720671, 
              c[ -26][ t]], 
            Times[ 14.707783890401883, 
              c[ -25][ t]], 
            Times[ 0.99270519960720693, 
              c[ -24][ t]], 
            Times[ 0.9710122092317629, 
              c[ -23][ t]], 
            Times[ 0.93548928378863916, 
              c[ -22][ t]], 
            Times[ 0.88706379305918392, 
              c[ -21][ t]], 
            Times[ 0.82699334313268813, 
              c[ -20][ t]], 
            Times[ 0.75682672864065714, 
              c[ -19][ t]], 
            Times[ 0.67835603854706361, 
              c[ -18][ t]], 
            Times[ 0.59356153372868059, 
              c[ -17][ t]], 
            Times[ 0.50455115242710491, 
              c[ -16][ t]], 
            Times[ 0.41349667156634429, 
              c[ -15][ t]], 
            Times[ 0.32256865202152157, 
              c[ -14][ t]], 
            Times[ 0.23387232094715998, 
              c[ -13][ t]], 
            Times[ 0.14938649372796384, 
              c[ -12][ t]], 
            Times[ 0.070907514257657775, 
              c[ -11][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -10][ t]], 
            Times[ -0.062044074975450239, 
              c[ -9][ t]], 
            Times[ -0.11423673049785436, 
              c[ -8][ t]], 
            Times[ -0.15591488063143974, 
              c[ -7][ t]], 
            Times[ -0.18675027222298593, 
              c[ -6][ t]], 
            Times[ -0.206748335783172, 
              c[ -5][ t]], 
            Times[ -0.21623620818304481, 
              c[ -4][ t]], 
            Times[ -0.21584055771952015, 
              c[ -3][ t]], 
            Times[ -0.20645618564475843, 
              c[ -2][ t]], 
            Times[ -0.18920668216016434, 
              c[ -1][ t]], 
            Times[ -0.16539866862653771, 
              c[ 0][ t]], 
            Times[ -0.13647135277833605, 
              c[ 1][ t]], 
            Times[ -0.1039432537542934, 
              c[ 2][ t]], 
            Times[ -0.06935801494512607, 
              c[ 3][ t]], 
            Times[ -0.034231213779558949, 
              c[ 4][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 5][ t]], 
            Times[ 0.032022748374425904, 
              c[ 6][ t]], 
            Times[ 0.060688263076985001, 
              c[ 7][ t]], 
            Times[ 0.085044480344421608, 
              c[ 8][ t]], 
            Times[ 0.10436044624225685, 
              c[ 9][ t]], 
            Times[ 0.11814190616181253, 
              c[ 10][ t]], 
            Times[ 0.12613778810677612, 
              c[ 11][ t]], 
            Times[ 0.12833762891430928, 
              c[ 12][ t]], 
            Times[ 0.12496032289024853, 
              c[ 13][ t]], 
            Times[ 0.11643488132933186, 
              c[ 14][ t]], 
            Times[ 0.10337416789158609, 
              c[ 15][ t]], 
            Times[ 0.086542809078944891, 
              c[ 16][ t]], 
            Times[ 0.066820663127759972, 
              c[ 17][ t]], 
            Times[ 0.045163358568919301, 
              c[ 18][ t]], 
            Times[ 0.022561481809254869, 
              c[ 19][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 20][ t]], 
            Times[ -0.021580547817547879, 
              c[ 21][ t]], 
            Times[ -0.04131966847794722, 
              c[ 22][ t]], 
            Times[ -0.058468080236789913, 
              c[ 23][ t]], 
            Times[ -0.072413370861974122, 
              c[ 24][ t]], 
            Times[ -0.082699334313268744, 
              c[ 25][ t]], 
            Times[ -0.089038438663606695, 
              c[ 26][ t]], 
            Times[ -0.091317159035181589, 
              c[ 27][ t]], 
            Times[ -0.089594193770366884, 
              c[ 28][ t]], 
            Times[ -0.084091858737850814, 
              c[ 29][ t]], 
            Times[ -0.075181213012062598, 
              c[ 30][ t]], 
            Times[ -0.063361699504227528, 
              c[ 31][ t]], 
            Times[ -0.049236278094138941, 
              c[ 32][ t]], 
            Times[ -0.033483179628681567, 
              c[ 33][ t]], 
            Times[ -0.016825511857749401, 
              c[ 34][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 35][ t]], 
            Times[ 0.016273855731265604, 
              c[ 36][ t]], 
            Times[ 0.031322974491347078, 
              c[ 37][ t]], 
            Times[ 0.044547108751839919, 
              c[ 38][ t]], 
            Times[ 0.055441487066198933, 
              c[ 39][ t]], 
            Times[ 0.063614872548668253, 
              c[ 40][ t]], 
            Times[ 0.068802429876423321, 
              c[ 41][ t]], 
            Times[ 0.070873018952678238, 
              c[ 42][ t]], 
            Times[ 0.069830768673962415, 
              c[ 43][ t]], 
            Times[ 0.065811019881796315, 
              c[ 44][ t]], 
            Times[ 0.059070953080906326, 
              c[ 45][ t]], 
            Times[ 0.049975424961080865, 
              c[ 46][ t]], 
            Times[ 0.038978720157860088, 
              c[ 47][ t]], 
            Times[ 0.026603074225527826, 
              c[ 48][ t]], 
            Times[ 0.013414935129827233, 
              c[ 49][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ 50][ t]], 
            Times[ -0.013061910521147383, 
              c[ 51][ t]], 
            Times[ -0.025221096343682053, 
              c[ 52][ t]], 
            Times[ -0.035980357068793781, 
              c[ 53][ t]], 
            Times[ -0.044914622433376419, 
              c[ 54][ t]], 
            Times[ -0.05168708394579296, 
              c[ 55][ t]], 
            Times[ -0.05606123915856713, 
              c[ 56][ t]], 
            Times[ -0.057908442314993203, 
              c[ 57][ t]], 
            Times[ -0.057210750238908967, 
              c[ 58][ t]], 
            Times[ -0.054059052045761224, 
              c[ 59][ t]], 
            Times[ -0.048646667243099281, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-24\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-24\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.12613778810677614`\ \(c[\(-60\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-59\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-58\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-57\)]\)[t] + 
            0.060688263076985`\ \(c[\(-56\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-55\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-54\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-53\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-52\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-51\)]\)[t] - 
            0.13647135277833616`\ \(c[\(-50\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-49\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-48\)]\)[t] - 
            0.20645618564475848`\ \(c[\(-47\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-46\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-45\)]\)[t] - 
            0.2067483357831719`\ \(c[\(-44\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-43\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-42\)]\)[t] - 
            0.11423673049785416`\ \(c[\(-41\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-40\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-39\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-38\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-37\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-36\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-35\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-34\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-33\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-32\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-31\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-30\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-29\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-28\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-27\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-26\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-25\)]\)[t] + 
            13.633093633394378`\ \(c[\(-24\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-23\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-22\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-21\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-20\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-19\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-18\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-17\)]\)[t] + 
            0.5935615337286803`\ \(c[\(-16\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-15\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-14\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-13\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-12\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-11\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-10\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-9\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-8\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-7\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-6\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-5\)]\)[t] - 
            0.206748335783172`\ \(c[\(-4\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-3\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-2\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-1\)]\)[t] - 
            0.18920668216016426`\ \(c[0]\)[t] - 
            0.1653986686265376`\ \(c[1]\)[t] - 
            0.13647135277833605`\ \(c[2]\)[t] - 
            0.10394325375429328`\ \(c[3]\)[t] - 
            0.06935801494512592`\ \(c[4]\)[t] - 
            0.03423121377955895`\ \(c[5]\)[t] - 
            3.898171832519376`*^-17\ \(c[6]\)[t] + 
            0.032022748374425904`\ \(c[7]\)[t] + 
            0.060688263076985105`\ \(c[8]\)[t] + 
            0.0850444803444217`\ \(c[9]\)[t] + 
            0.10436044624225685`\ \(c[10]\)[t] + 
            0.11814190616181255`\ \(c[11]\)[t] + 
            0.12613778810677614`\ \(c[12]\)[t] + 
            0.12833762891430928`\ \(c[13]\)[t] + 
            0.12496032289024853`\ \(c[14]\)[t] + 
            0.11643488132933186`\ \(c[15]\)[t] + 
            0.10337416789158609`\ \(c[16]\)[t] + 
            0.08654280907894489`\ \(c[17]\)[t] + 
            0.06682066312775997`\ \(c[18]\)[t] + 
            0.0451633585689193`\ \(c[19]\)[t] + 
            0.02256148180925487`\ \(c[20]\)[t] + 
            3.8981718325193755`*^-17\ \(c[21]\)[t] - 
            0.02158054781754788`\ \(c[22]\)[t] - 
            0.04131966847794722`\ \(c[23]\)[t] - 
            0.05846808023678991`\ \(c[24]\)[t] - 
            0.07241337086197412`\ \(c[25]\)[t] - 
            0.08269933431326874`\ \(c[26]\)[t] - 
            0.0890384386636067`\ \(c[27]\)[t] - 
            0.09131715903518159`\ \(c[28]\)[t] - 
            0.08959419377036688`\ \(c[29]\)[t] - 
            0.08409185873785081`\ \(c[30]\)[t] - 
            0.0751812130120626`\ \(c[31]\)[t] - 
            0.06336169950422753`\ \(c[32]\)[t] - 
            0.04923627809413894`\ \(c[33]\)[t] - 
            0.03348317962868157`\ \(c[34]\)[t] - 
            0.0168255118577494`\ \(c[35]\)[t] - 
            3.898171832519376`*^-17\ \(c[36]\)[t] + 
            0.016273855731265604`\ \(c[37]\)[t] + 
            0.03132297449134708`\ \(c[38]\)[t] + 
            0.04454710875183992`\ \(c[39]\)[t] + 
            0.05544148706619893`\ \(c[40]\)[t] + 
            0.06361487254866825`\ \(c[41]\)[t] + 
            0.06880242987642335`\ \(c[42]\)[t] + 
            0.07087301895267824`\ \(c[43]\)[t] + 
            0.06983076867396242`\ \(c[44]\)[t] + 
            0.06581101988179627`\ \(c[45]\)[t] + 
            0.059070953080906326`\ \(c[46]\)[t] + 
            0.049975424961080865`\ \(c[47]\)[t] + 
            0.03897872015785999`\ \(c[48]\)[t] + 
            0.026603074225527826`\ \(c[49]\)[t] + 
            0.013414935129827233`\ \(c[50]\)[t] + 
            3.898171832519376`*^-17\ \(c[51]\)[t] - 
            0.013061910521147383`\ \(c[52]\)[t] - 
            0.025221096343682053`\ \(c[53]\)[t] - 
            0.03598035706879378`\ \(c[54]\)[t] - 
            0.04491462243337642`\ \(c[55]\)[t] - 
            0.05168708394579296`\ \(c[56]\)[t] - 
            0.056061239158567186`\ \(c[57]\)[t] - 
            0.0579084423149932`\ \(c[58]\)[t] - 
            0.05721075023890897`\ \(c[59]\)[t] - 
            0.054059052045761224`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -24, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -24]][ t]], 
          Plus[ 
            Times[ 0.12613778810677614, 
              c[ -60][ t]], 
            Times[ 0.11814190616181253, 
              c[ -59][ t]], 
            Times[ 0.10436044624225685, 
              c[ -58][ t]], 
            Times[ 0.085044480344421705, 
              c[ -57][ t]], 
            Times[ 0.060688263076985001, 
              c[ -56][ t]], 
            Times[ 0.032022748374425904, 
              c[ -55][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -54][ t]], 
            Times[ -0.034231213779559094, 
              c[ -53][ t]], 
            Times[ -0.06935801494512607, 
              c[ -52][ t]], 
            Times[ -0.10394325375429328, 
              c[ -51][ t]], 
            Times[ -0.13647135277833616, 
              c[ -50][ t]], 
            Times[ -0.16539866862653771, 
              c[ -49][ t]], 
            Times[ -0.18920668216016426, 
              c[ -48][ t]], 
            Times[ -0.20645618564475848, 
              c[ -47][ t]], 
            Times[ -0.21584055771952015, 
              c[ -46][ t]], 
            Times[ -0.21623620818304484, 
              c[ -45][ t]], 
            Times[ -0.20674833578317189, 
              c[ -44][ t]], 
            Times[ -0.18675027222298593, 
              c[ -43][ t]], 
            Times[ -0.15591488063143982, 
              c[ -42][ t]], 
            Times[ -0.11423673049785416, 
              c[ -41][ t]], 
            Times[ -0.062044074975450239, 
              c[ -40][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -39][ t]], 
            Times[ 0.070907514257657775, 
              c[ -38][ t]], 
            Times[ 0.14938649372796384, 
              c[ -37][ t]], 
            Times[ 0.23387232094715985, 
              c[ -36][ t]], 
            Times[ 0.32256865202152157, 
              c[ -35][ t]], 
            Times[ 0.41349667156634429, 
              c[ -34][ t]], 
            Times[ 0.50455115242710469, 
              c[ -33][ t]], 
            Times[ 0.59356153372868059, 
              c[ -32][ t]], 
            Times[ 0.67835603854706361, 
              c[ -31][ t]], 
            Times[ 0.75682672864065692, 
              c[ -30][ t]], 
            Times[ 0.82699334313268813, 
              c[ -29][ t]], 
            Times[ 0.88706379305918392, 
              c[ -28][ t]], 
            Times[ 0.93548928378863916, 
              c[ -27][ t]], 
            Times[ 0.9710122092317629, 
              c[ -26][ t]], 
            Times[ 0.99270519960720693, 
              c[ -25][ t]], 
            Times[ 13.633093633394378, 
              c[ -24][ t]], 
            Times[ 0.99270519960720671, 
              c[ -23][ t]], 
            Times[ 0.9710122092317629, 
              c[ -22][ t]], 
            Times[ 0.93548928378863916, 
              c[ -21][ t]], 
            Times[ 0.88706379305918381, 
              c[ -20][ t]], 
            Times[ 0.82699334313268813, 
              c[ -19][ t]], 
            Times[ 0.75682672864065692, 
              c[ -18][ t]], 
            Times[ 0.67835603854706317, 
              c[ -17][ t]], 
            Times[ 0.59356153372868026, 
              c[ -16][ t]], 
            Times[ 0.50455115242710469, 
              c[ -15][ t]], 
            Times[ 0.41349667156634395, 
              c[ -14][ t]], 
            Times[ 0.32256865202152135, 
              c[ -13][ t]], 
            Times[ 0.23387232094715985, 
              c[ -12][ t]], 
            Times[ 0.14938649372796345, 
              c[ -11][ t]], 
            Times[ 0.070907514257657622, 
              c[ -10][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -9][ t]], 
            Times[ -0.062044074975450475, 
              c[ -8][ t]], 
            Times[ -0.11423673049785445, 
              c[ -7][ t]], 
            Times[ -0.15591488063143982, 
              c[ -6][ t]], 
            Times[ -0.18675027222298607, 
              c[ -5][ t]], 
            Times[ -0.206748335783172, 
              c[ -4][ t]], 
            Times[ -0.21623620818304484, 
              c[ -3][ t]], 
            Times[ -0.21584055771952013, 
              c[ -2][ t]], 
            Times[ -0.20645618564475843, 
              c[ -1][ t]], 
            Times[ -0.18920668216016426, 
              c[ 0][ t]], 
            Times[ -0.1653986686265376, 
              c[ 1][ t]], 
            Times[ -0.13647135277833605, 
              c[ 2][ t]], 
            Times[ -0.10394325375429328, 
              c[ 3][ t]], 
            Times[ -0.069358014945125918, 
              c[ 4][ t]], 
            Times[ -0.034231213779558949, 
              c[ 5][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 6][ t]], 
            Times[ 0.032022748374425904, 
              c[ 7][ t]], 
            Times[ 0.060688263076985105, 
              c[ 8][ t]], 
            Times[ 0.085044480344421705, 
              c[ 9][ t]], 
            Times[ 0.10436044624225685, 
              c[ 10][ t]], 
            Times[ 0.11814190616181255, 
              c[ 11][ t]], 
            Times[ 0.12613778810677614, 
              c[ 12][ t]], 
            Times[ 0.12833762891430928, 
              c[ 13][ t]], 
            Times[ 0.12496032289024853, 
              c[ 14][ t]], 
            Times[ 0.11643488132933186, 
              c[ 15][ t]], 
            Times[ 0.10337416789158609, 
              c[ 16][ t]], 
            Times[ 0.086542809078944891, 
              c[ 17][ t]], 
            Times[ 0.066820663127759972, 
              c[ 18][ t]], 
            Times[ 0.045163358568919301, 
              c[ 19][ t]], 
            Times[ 0.022561481809254869, 
              c[ 20][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 21][ t]], 
            Times[ -0.021580547817547879, 
              c[ 22][ t]], 
            Times[ -0.04131966847794722, 
              c[ 23][ t]], 
            Times[ -0.058468080236789913, 
              c[ 24][ t]], 
            Times[ -0.072413370861974122, 
              c[ 25][ t]], 
            Times[ -0.082699334313268744, 
              c[ 26][ t]], 
            Times[ -0.089038438663606695, 
              c[ 27][ t]], 
            Times[ -0.091317159035181589, 
              c[ 28][ t]], 
            Times[ -0.089594193770366884, 
              c[ 29][ t]], 
            Times[ -0.084091858737850814, 
              c[ 30][ t]], 
            Times[ -0.075181213012062598, 
              c[ 31][ t]], 
            Times[ -0.063361699504227528, 
              c[ 32][ t]], 
            Times[ -0.049236278094138941, 
              c[ 33][ t]], 
            Times[ -0.033483179628681567, 
              c[ 34][ t]], 
            Times[ -0.016825511857749401, 
              c[ 35][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 36][ t]], 
            Times[ 0.016273855731265604, 
              c[ 37][ t]], 
            Times[ 0.031322974491347078, 
              c[ 38][ t]], 
            Times[ 0.044547108751839919, 
              c[ 39][ t]], 
            Times[ 0.055441487066198933, 
              c[ 40][ t]], 
            Times[ 0.063614872548668253, 
              c[ 41][ t]], 
            Times[ 0.068802429876423349, 
              c[ 42][ t]], 
            Times[ 0.070873018952678238, 
              c[ 43][ t]], 
            Times[ 0.069830768673962415, 
              c[ 44][ t]], 
            Times[ 0.065811019881796273, 
              c[ 45][ t]], 
            Times[ 0.059070953080906326, 
              c[ 46][ t]], 
            Times[ 0.049975424961080865, 
              c[ 47][ t]], 
            Times[ 0.03897872015785999, 
              c[ 48][ t]], 
            Times[ 0.026603074225527826, 
              c[ 49][ t]], 
            Times[ 0.013414935129827233, 
              c[ 50][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 51][ t]], 
            Times[ -0.013061910521147383, 
              c[ 52][ t]], 
            Times[ -0.025221096343682053, 
              c[ 53][ t]], 
            Times[ -0.035980357068793781, 
              c[ 54][ t]], 
            Times[ -0.044914622433376419, 
              c[ 55][ t]], 
            Times[ -0.05168708394579296, 
              c[ 56][ t]], 
            Times[ -0.056061239158567186, 
              c[ 57][ t]], 
            Times[ -0.057908442314993203, 
              c[ 58][ t]], 
            Times[ -0.057210750238908967, 
              c[ 59][ t]], 
            Times[ -0.054059052045761224, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-23\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-23\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.12833762891430925`\ \(c[\(-60\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-59\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-58\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-57\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-56\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-55\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-54\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-53\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-52\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-51\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-50\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-49\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-48\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-47\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-46\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-45\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-44\)]\)[t] - 
            0.206748335783172`\ \(c[\(-43\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-42\)]\)[t] - 
            0.15591488063143966`\ \(c[\(-41\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-40\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-39\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-38\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-37\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-36\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-35\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-34\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-33\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-32\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-31\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-30\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-29\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-28\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-27\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-26\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-25\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-24\)]\)[t] + 
            12.602268284836155`\ \(c[\(-23\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-22\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-21\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-20\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-19\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-18\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-17\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-16\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-15\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-14\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-13\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-12\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-11\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-10\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-9\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-8\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-7\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-6\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-5\)]\)[t] - 
            0.186750272222986`\ \(c[\(-4\)]\)[t] - 
            0.206748335783172`\ \(c[\(-3\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-2\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-1\)]\)[t] - 
            0.20645618564475843`\ \(c[0]\)[t] - 
            0.18920668216016426`\ \(c[1]\)[t] - 
            0.1653986686265377`\ \(c[2]\)[t] - 
            0.13647135277833605`\ \(c[3]\)[t] - 
            0.10394325375429328`\ \(c[4]\)[t] - 
            0.06935801494512607`\ \(c[5]\)[t] - 
            0.03423121377955895`\ \(c[6]\)[t] - 
            3.898171832519376`*^-17\ \(c[7]\)[t] + 
            0.032022748374425904`\ \(c[8]\)[t] + 
            0.060688263076985105`\ \(c[9]\)[t] + 
            0.0850444803444217`\ \(c[10]\)[t] + 
            0.10436044624225685`\ \(c[11]\)[t] + 
            0.11814190616181255`\ \(c[12]\)[t] + 
            0.12613778810677614`\ \(c[13]\)[t] + 
            0.12833762891430928`\ \(c[14]\)[t] + 
            0.12496032289024853`\ \(c[15]\)[t] + 
            0.11643488132933186`\ \(c[16]\)[t] + 
            0.10337416789158609`\ \(c[17]\)[t] + 
            0.08654280907894489`\ \(c[18]\)[t] + 
            0.06682066312775997`\ \(c[19]\)[t] + 
            0.0451633585689193`\ \(c[20]\)[t] + 
            0.02256148180925487`\ \(c[21]\)[t] + 
            3.8981718325193755`*^-17\ \(c[22]\)[t] - 
            0.02158054781754788`\ \(c[23]\)[t] - 
            0.04131966847794722`\ \(c[24]\)[t] - 
            0.05846808023678991`\ \(c[25]\)[t] - 
            0.07241337086197412`\ \(c[26]\)[t] - 
            0.08269933431326874`\ \(c[27]\)[t] - 
            0.0890384386636067`\ \(c[28]\)[t] - 
            0.09131715903518159`\ \(c[29]\)[t] - 
            0.08959419377036688`\ \(c[30]\)[t] - 
            0.08409185873785081`\ \(c[31]\)[t] - 
            0.0751812130120626`\ \(c[32]\)[t] - 
            0.06336169950422753`\ \(c[33]\)[t] - 
            0.04923627809413894`\ \(c[34]\)[t] - 
            0.03348317962868157`\ \(c[35]\)[t] - 
            0.0168255118577494`\ \(c[36]\)[t] - 
            3.898171832519376`*^-17\ \(c[37]\)[t] + 
            0.016273855731265604`\ \(c[38]\)[t] + 
            0.03132297449134708`\ \(c[39]\)[t] + 
            0.04454710875183992`\ \(c[40]\)[t] + 
            0.055441487066198857`\ \(c[41]\)[t] + 
            0.06361487254866825`\ \(c[42]\)[t] + 
            0.06880242987642335`\ \(c[43]\)[t] + 
            0.07087301895267824`\ \(c[44]\)[t] + 
            0.06983076867396242`\ \(c[45]\)[t] + 
            0.06581101988179627`\ \(c[46]\)[t] + 
            0.0590709530809064`\ \(c[47]\)[t] + 
            0.049975424961080865`\ \(c[48]\)[t] + 
            0.03897872015785999`\ \(c[49]\)[t] + 
            0.026603074225527937`\ \(c[50]\)[t] + 
            0.013414935129827233`\ \(c[51]\)[t] + 
            3.898171832519376`*^-17\ \(c[52]\)[t] - 
            0.013061910521147276`\ \(c[53]\)[t] - 
            0.025221096343682053`\ \(c[54]\)[t] - 
            0.03598035706879378`\ \(c[55]\)[t] - 
            0.04491462243337629`\ \(c[56]\)[t] - 
            0.05168708394579296`\ \(c[57]\)[t] - 
            0.056061239158567186`\ \(c[58]\)[t] - 
            0.0579084423149932`\ \(c[59]\)[t] - 
            0.05721075023890897`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -23, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -23]][ t]], 
          Plus[ 
            Times[ 0.12833762891430925, 
              c[ -60][ t]], 
            Times[ 0.12613778810677612, 
              c[ -59][ t]], 
            Times[ 0.11814190616181255, 
              c[ -58][ t]], 
            Times[ 0.10436044624225692, 
              c[ -57][ t]], 
            Times[ 0.085044480344421608, 
              c[ -56][ t]], 
            Times[ 0.060688263076985105, 
              c[ -55][ t]], 
            Times[ 0.032022748374426029, 
              c[ -54][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -53][ t]], 
            Times[ -0.034231213779558949, 
              c[ -52][ t]], 
            Times[ -0.069358014945125918, 
              c[ -51][ t]], 
            Times[ -0.1039432537542934, 
              c[ -50][ t]], 
            Times[ -0.13647135277833605, 
              c[ -49][ t]], 
            Times[ -0.1653986686265376, 
              c[ -48][ t]], 
            Times[ -0.18920668216016434, 
              c[ -47][ t]], 
            Times[ -0.20645618564475843, 
              c[ -46][ t]], 
            Times[ -0.21584055771952013, 
              c[ -45][ t]], 
            Times[ -0.21623620818304481, 
              c[ -44][ t]], 
            Times[ -0.206748335783172, 
              c[ -43][ t]], 
            Times[ -0.18675027222298607, 
              c[ -42][ t]], 
            Times[ -0.15591488063143966, 
              c[ -41][ t]], 
            Times[ -0.11423673049785436, 
              c[ -40][ t]], 
            Times[ -0.062044074975450475, 
              c[ -39][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -38][ t]], 
            Times[ 0.070907514257657775, 
              c[ -37][ t]], 
            Times[ 0.14938649372796345, 
              c[ -36][ t]], 
            Times[ 0.23387232094715985, 
              c[ -35][ t]], 
            Times[ 0.32256865202152157, 
              c[ -34][ t]], 
            Times[ 0.41349667156634395, 
              c[ -33][ t]], 
            Times[ 0.50455115242710469, 
              c[ -32][ t]], 
            Times[ 0.59356153372868059, 
              c[ -31][ t]], 
            Times[ 0.67835603854706317, 
              c[ -30][ t]], 
            Times[ 0.75682672864065692, 
              c[ -29][ t]], 
            Times[ 0.82699334313268813, 
              c[ -28][ t]], 
            Times[ 0.88706379305918381, 
              c[ -27][ t]], 
            Times[ 0.93548928378863916, 
              c[ -26][ t]], 
            Times[ 0.9710122092317629, 
              c[ -25][ t]], 
            Times[ 0.99270519960720671, 
              c[ -24][ t]], 
            Times[ 12.602268284836155, 
              c[ -23][ t]], 
            Times[ 0.99270519960720671, 
              c[ -22][ t]], 
            Times[ 0.9710122092317629, 
              c[ -21][ t]], 
            Times[ 0.93548928378863916, 
              c[ -20][ t]], 
            Times[ 0.88706379305918381, 
              c[ -19][ t]], 
            Times[ 0.82699334313268813, 
              c[ -18][ t]], 
            Times[ 0.75682672864065692, 
              c[ -17][ t]], 
            Times[ 0.67835603854706339, 
              c[ -16][ t]], 
            Times[ 0.59356153372868059, 
              c[ -15][ t]], 
            Times[ 0.50455115242710469, 
              c[ -14][ t]], 
            Times[ 0.41349667156634418, 
              c[ -13][ t]], 
            Times[ 0.32256865202152157, 
              c[ -12][ t]], 
            Times[ 0.23387232094715985, 
              c[ -11][ t]], 
            Times[ 0.14938649372796362, 
              c[ -10][ t]], 
            Times[ 0.070907514257657775, 
              c[ -9][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -8][ t]], 
            Times[ -0.062044074975450343, 
              c[ -7][ t]], 
            Times[ -0.11423673049785436, 
              c[ -6][ t]], 
            Times[ -0.15591488063143982, 
              c[ -5][ t]], 
            Times[ -0.18675027222298601, 
              c[ -4][ t]], 
            Times[ -0.206748335783172, 
              c[ -3][ t]], 
            Times[ -0.21623620818304484, 
              c[ -2][ t]], 
            Times[ -0.21584055771952015, 
              c[ -1][ t]], 
            Times[ -0.20645618564475843, 
              c[ 0][ t]], 
            Times[ -0.18920668216016426, 
              c[ 1][ t]], 
            Times[ -0.16539866862653771, 
              c[ 2][ t]], 
            Times[ -0.13647135277833605, 
              c[ 3][ t]], 
            Times[ -0.10394325375429328, 
              c[ 4][ t]], 
            Times[ -0.06935801494512607, 
              c[ 5][ t]], 
            Times[ -0.034231213779558949, 
              c[ 6][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 7][ t]], 
            Times[ 0.032022748374425904, 
              c[ 8][ t]], 
            Times[ 0.060688263076985105, 
              c[ 9][ t]], 
            Times[ 0.085044480344421705, 
              c[ 10][ t]], 
            Times[ 0.10436044624225685, 
              c[ 11][ t]], 
            Times[ 0.11814190616181255, 
              c[ 12][ t]], 
            Times[ 0.12613778810677614, 
              c[ 13][ t]], 
            Times[ 0.12833762891430928, 
              c[ 14][ t]], 
            Times[ 0.12496032289024853, 
              c[ 15][ t]], 
            Times[ 0.11643488132933186, 
              c[ 16][ t]], 
            Times[ 0.10337416789158609, 
              c[ 17][ t]], 
            Times[ 0.086542809078944891, 
              c[ 18][ t]], 
            Times[ 0.066820663127759972, 
              c[ 19][ t]], 
            Times[ 0.045163358568919301, 
              c[ 20][ t]], 
            Times[ 0.022561481809254869, 
              c[ 21][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 22][ t]], 
            Times[ -0.021580547817547879, 
              c[ 23][ t]], 
            Times[ -0.04131966847794722, 
              c[ 24][ t]], 
            Times[ -0.058468080236789913, 
              c[ 25][ t]], 
            Times[ -0.072413370861974122, 
              c[ 26][ t]], 
            Times[ -0.082699334313268744, 
              c[ 27][ t]], 
            Times[ -0.089038438663606695, 
              c[ 28][ t]], 
            Times[ -0.091317159035181589, 
              c[ 29][ t]], 
            Times[ -0.089594193770366884, 
              c[ 30][ t]], 
            Times[ -0.084091858737850814, 
              c[ 31][ t]], 
            Times[ -0.075181213012062598, 
              c[ 32][ t]], 
            Times[ -0.063361699504227528, 
              c[ 33][ t]], 
            Times[ -0.049236278094138941, 
              c[ 34][ t]], 
            Times[ -0.033483179628681567, 
              c[ 35][ t]], 
            Times[ -0.016825511857749401, 
              c[ 36][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 37][ t]], 
            Times[ 0.016273855731265604, 
              c[ 38][ t]], 
            Times[ 0.031322974491347078, 
              c[ 39][ t]], 
            Times[ 0.044547108751839919, 
              c[ 40][ t]], 
            Times[ 0.055441487066198857, 
              c[ 41][ t]], 
            Times[ 0.063614872548668253, 
              c[ 42][ t]], 
            Times[ 0.068802429876423349, 
              c[ 43][ t]], 
            Times[ 0.070873018952678238, 
              c[ 44][ t]], 
            Times[ 0.069830768673962415, 
              c[ 45][ t]], 
            Times[ 0.065811019881796273, 
              c[ 46][ t]], 
            Times[ 0.059070953080906402, 
              c[ 47][ t]], 
            Times[ 0.049975424961080865, 
              c[ 48][ t]], 
            Times[ 0.03897872015785999, 
              c[ 49][ t]], 
            Times[ 0.026603074225527937, 
              c[ 50][ t]], 
            Times[ 0.013414935129827233, 
              c[ 51][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 52][ t]], 
            Times[ -0.013061910521147276, 
              c[ 53][ t]], 
            Times[ -0.025221096343682053, 
              c[ 54][ t]], 
            Times[ -0.035980357068793781, 
              c[ 55][ t]], 
            Times[ -0.044914622433376288, 
              c[ 56][ t]], 
            Times[ -0.05168708394579296, 
              c[ 57][ t]], 
            Times[ -0.056061239158567186, 
              c[ 58][ t]], 
            Times[ -0.057908442314993203, 
              c[ 59][ t]], 
            Times[ -0.057210750238908967, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-22\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-22\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.12496032289024847`\ \(c[\(-60\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-59\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-58\)]\)[t] + 
            0.1181419061618126`\ \(c[\(-57\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-56\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-55\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-54\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-53\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-52\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-51\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-50\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-49\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-48\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-47\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-46\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-45\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-44\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-43\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-42\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-41\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-40\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-39\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-38\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-37\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-36\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-35\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-34\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-33\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-32\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-31\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-30\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-29\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-28\)]\)[t] + 
            0.826993343132688`\ \(c[\(-27\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-26\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-25\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-24\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-23\)]\)[t] + 
            11.615307844727218`\ \(c[\(-22\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-21\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-20\)]\)[t] + 
            0.9354892837886394`\ \(c[\(-19\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-18\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-17\)]\)[t] + 
            0.7568267286406571`\ \(c[\(-16\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-15\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-14\)]\)[t] + 
            0.5045511524271049`\ \(c[\(-13\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-12\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-11\)]\)[t] + 
            0.23387232094715998`\ \(c[\(-10\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-9\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-8\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-7\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-6\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-5\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-4\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-3\)]\)[t] - 
            0.206748335783172`\ \(c[\(-2\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-1\)]\)[t] - 
            0.21584055771952015`\ \(c[0]\)[t] - 
            0.20645618564475843`\ \(c[1]\)[t] - 
            0.18920668216016434`\ \(c[2]\)[t] - 
            0.1653986686265377`\ \(c[3]\)[t] - 
            0.13647135277833605`\ \(c[4]\)[t] - 
            0.1039432537542934`\ \(c[5]\)[t] - 
            0.06935801494512607`\ \(c[6]\)[t] - 
            0.034231213779559094`\ \(c[7]\)[t] - 
            1.8033970416801674`*^-16\ \(c[8]\)[t] + 
            0.032022748374425904`\ \(c[9]\)[t] + 
            0.060688263076985`\ \(c[10]\)[t] + 
            0.08504448034442161`\ \(c[11]\)[t] + 
            0.10436044624225685`\ \(c[12]\)[t] + 
            0.11814190616181253`\ \(c[13]\)[t] + 
            0.12613778810677612`\ \(c[14]\)[t] + 
            0.12833762891430928`\ \(c[15]\)[t] + 
            0.12496032289024853`\ \(c[16]\)[t] + 
            0.11643488132933186`\ \(c[17]\)[t] + 
            0.10337416789158609`\ \(c[18]\)[t] + 
            0.08654280907894489`\ \(c[19]\)[t] + 
            0.06682066312775997`\ \(c[20]\)[t] + 
            0.0451633585689193`\ \(c[21]\)[t] + 
            0.02256148180925487`\ \(c[22]\)[t] + 
            3.8981718325193755`*^-17\ \(c[23]\)[t] - 
            0.02158054781754788`\ \(c[24]\)[t] - 
            0.04131966847794722`\ \(c[25]\)[t] - 
            0.05846808023678991`\ \(c[26]\)[t] - 
            0.07241337086197412`\ \(c[27]\)[t] - 
            0.08269933431326874`\ \(c[28]\)[t] - 
            0.0890384386636067`\ \(c[29]\)[t] - 
            0.09131715903518159`\ \(c[30]\)[t] - 
            0.08959419377036688`\ \(c[31]\)[t] - 
            0.08409185873785081`\ \(c[32]\)[t] - 
            0.0751812130120626`\ \(c[33]\)[t] - 
            0.06336169950422753`\ \(c[34]\)[t] - 
            0.04923627809413894`\ \(c[35]\)[t] - 
            0.03348317962868157`\ \(c[36]\)[t] - 
            0.0168255118577494`\ \(c[37]\)[t] - 
            3.898171832519376`*^-17\ \(c[38]\)[t] + 
            0.016273855731265604`\ \(c[39]\)[t] + 
            0.03132297449134708`\ \(c[40]\)[t] + 
            0.044547108751839815`\ \(c[41]\)[t] + 
            0.05544148706619893`\ \(c[42]\)[t] + 
            0.06361487254866825`\ \(c[43]\)[t] + 
            0.06880242987642332`\ \(c[44]\)[t] + 
            0.07087301895267824`\ \(c[45]\)[t] + 
            0.06983076867396242`\ \(c[46]\)[t] + 
            0.06581101988179631`\ \(c[47]\)[t] + 
            0.059070953080906326`\ \(c[48]\)[t] + 
            0.049975424961080865`\ \(c[49]\)[t] + 
            0.03897872015786009`\ \(c[50]\)[t] + 
            0.026603074225527826`\ \(c[51]\)[t] + 
            0.013414935129827233`\ \(c[52]\)[t] + 
            1.5206810699945212`*^-16\ \(c[53]\)[t] - 
            0.013061910521147383`\ \(c[54]\)[t] - 
            0.025221096343682053`\ \(c[55]\)[t] - 
            0.03598035706879378`\ \(c[56]\)[t] - 
            0.04491462243337642`\ \(c[57]\)[t] - 
            0.05168708394579296`\ \(c[58]\)[t] - 
            0.05606123915856713`\ \(c[59]\)[t] - 
            0.0579084423149932`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -22, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -22]][ t]], 
          Plus[ 
            Times[ 0.12496032289024847, 
              c[ -60][ t]], 
            Times[ 0.12833762891430928, 
              c[ -59][ t]], 
            Times[ 0.12613778810677614, 
              c[ -58][ t]], 
            Times[ 0.1181419061618126, 
              c[ -57][ t]], 
            Times[ 0.10436044624225685, 
              c[ -56][ t]], 
            Times[ 0.085044480344421705, 
              c[ -55][ t]], 
            Times[ 0.060688263076985223, 
              c[ -54][ t]], 
            Times[ 0.032022748374425904, 
              c[ -53][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -52][ t]], 
            Times[ -0.034231213779558796, 
              c[ -51][ t]], 
            Times[ -0.06935801494512607, 
              c[ -50][ t]], 
            Times[ -0.10394325375429328, 
              c[ -49][ t]], 
            Times[ -0.13647135277833591, 
              c[ -48][ t]], 
            Times[ -0.16539866862653771, 
              c[ -47][ t]], 
            Times[ -0.18920668216016426, 
              c[ -46][ t]], 
            Times[ -0.20645618564475834, 
              c[ -45][ t]], 
            Times[ -0.21584055771952015, 
              c[ -44][ t]], 
            Times[ -0.21623620818304484, 
              c[ -43][ t]], 
            Times[ -0.20674833578317206, 
              c[ -42][ t]], 
            Times[ -0.18675027222298593, 
              c[ -41][ t]], 
            Times[ -0.15591488063143982, 
              c[ -40][ t]], 
            Times[ -0.11423673049785459, 
              c[ -39][ t]], 
            Times[ -0.062044074975450475, 
              c[ -38][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -37][ t]], 
            Times[ 0.070907514257657456, 
              c[ -36][ t]], 
            Times[ 0.14938649372796345, 
              c[ -35][ t]], 
            Times[ 0.23387232094715985, 
              c[ -34][ t]], 
            Times[ 0.32256865202152113, 
              c[ -33][ t]], 
            Times[ 0.41349667156634395, 
              c[ -32][ t]], 
            Times[ 0.50455115242710469, 
              c[ -31][ t]], 
            Times[ 0.59356153372868015, 
              c[ -30][ t]], 
            Times[ 0.67835603854706317, 
              c[ -29][ t]], 
            Times[ 0.75682672864065692, 
              c[ -28][ t]], 
            Times[ 0.82699334313268802, 
              c[ -27][ t]], 
            Times[ 0.88706379305918381, 
              c[ -26][ t]], 
            Times[ 0.93548928378863916, 
              c[ -25][ t]], 
            Times[ 0.9710122092317629, 
              c[ -24][ t]], 
            Times[ 0.99270519960720671, 
              c[ -23][ t]], 
            Times[ 11.615307844727218, 
              c[ -22][ t]], 
            Times[ 0.99270519960720693, 
              c[ -21][ t]], 
            Times[ 0.9710122092317629, 
              c[ -20][ t]], 
            Times[ 0.93548928378863938, 
              c[ -19][ t]], 
            Times[ 0.88706379305918392, 
              c[ -18][ t]], 
            Times[ 0.82699334313268813, 
              c[ -17][ t]], 
            Times[ 0.75682672864065714, 
              c[ -16][ t]], 
            Times[ 0.67835603854706361, 
              c[ -15][ t]], 
            Times[ 0.59356153372868059, 
              c[ -14][ t]], 
            Times[ 0.50455115242710491, 
              c[ -13][ t]], 
            Times[ 0.41349667156634429, 
              c[ -12][ t]], 
            Times[ 0.32256865202152157, 
              c[ -11][ t]], 
            Times[ 0.23387232094715998, 
              c[ -10][ t]], 
            Times[ 0.14938649372796384, 
              c[ -9][ t]], 
            Times[ 0.070907514257657775, 
              c[ -8][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -7][ t]], 
            Times[ -0.062044074975450239, 
              c[ -6][ t]], 
            Times[ -0.11423673049785436, 
              c[ -5][ t]], 
            Times[ -0.15591488063143974, 
              c[ -4][ t]], 
            Times[ -0.18675027222298593, 
              c[ -3][ t]], 
            Times[ -0.206748335783172, 
              c[ -2][ t]], 
            Times[ -0.21623620818304481, 
              c[ -1][ t]], 
            Times[ -0.21584055771952015, 
              c[ 0][ t]], 
            Times[ -0.20645618564475843, 
              c[ 1][ t]], 
            Times[ -0.18920668216016434, 
              c[ 2][ t]], 
            Times[ -0.16539866862653771, 
              c[ 3][ t]], 
            Times[ -0.13647135277833605, 
              c[ 4][ t]], 
            Times[ -0.1039432537542934, 
              c[ 5][ t]], 
            Times[ -0.06935801494512607, 
              c[ 6][ t]], 
            Times[ -0.034231213779559094, 
              c[ 7][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 8][ t]], 
            Times[ 0.032022748374425904, 
              c[ 9][ t]], 
            Times[ 0.060688263076985001, 
              c[ 10][ t]], 
            Times[ 0.085044480344421608, 
              c[ 11][ t]], 
            Times[ 0.10436044624225685, 
              c[ 12][ t]], 
            Times[ 0.11814190616181253, 
              c[ 13][ t]], 
            Times[ 0.12613778810677612, 
              c[ 14][ t]], 
            Times[ 0.12833762891430928, 
              c[ 15][ t]], 
            Times[ 0.12496032289024853, 
              c[ 16][ t]], 
            Times[ 0.11643488132933186, 
              c[ 17][ t]], 
            Times[ 0.10337416789158609, 
              c[ 18][ t]], 
            Times[ 0.086542809078944891, 
              c[ 19][ t]], 
            Times[ 0.066820663127759972, 
              c[ 20][ t]], 
            Times[ 0.045163358568919301, 
              c[ 21][ t]], 
            Times[ 0.022561481809254869, 
              c[ 22][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 23][ t]], 
            Times[ -0.021580547817547879, 
              c[ 24][ t]], 
            Times[ -0.04131966847794722, 
              c[ 25][ t]], 
            Times[ -0.058468080236789913, 
              c[ 26][ t]], 
            Times[ -0.072413370861974122, 
              c[ 27][ t]], 
            Times[ -0.082699334313268744, 
              c[ 28][ t]], 
            Times[ -0.089038438663606695, 
              c[ 29][ t]], 
            Times[ -0.091317159035181589, 
              c[ 30][ t]], 
            Times[ -0.089594193770366884, 
              c[ 31][ t]], 
            Times[ -0.084091858737850814, 
              c[ 32][ t]], 
            Times[ -0.075181213012062598, 
              c[ 33][ t]], 
            Times[ -0.063361699504227528, 
              c[ 34][ t]], 
            Times[ -0.049236278094138941, 
              c[ 35][ t]], 
            Times[ -0.033483179628681567, 
              c[ 36][ t]], 
            Times[ -0.016825511857749401, 
              c[ 37][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 38][ t]], 
            Times[ 0.016273855731265604, 
              c[ 39][ t]], 
            Times[ 0.031322974491347078, 
              c[ 40][ t]], 
            Times[ 0.044547108751839815, 
              c[ 41][ t]], 
            Times[ 0.055441487066198933, 
              c[ 42][ t]], 
            Times[ 0.063614872548668253, 
              c[ 43][ t]], 
            Times[ 0.068802429876423321, 
              c[ 44][ t]], 
            Times[ 0.070873018952678238, 
              c[ 45][ t]], 
            Times[ 0.069830768673962415, 
              c[ 46][ t]], 
            Times[ 0.065811019881796315, 
              c[ 47][ t]], 
            Times[ 0.059070953080906326, 
              c[ 48][ t]], 
            Times[ 0.049975424961080865, 
              c[ 49][ t]], 
            Times[ 0.038978720157860088, 
              c[ 50][ t]], 
            Times[ 0.026603074225527826, 
              c[ 51][ t]], 
            Times[ 0.013414935129827233, 
              c[ 52][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ 53][ t]], 
            Times[ -0.013061910521147383, 
              c[ 54][ t]], 
            Times[ -0.025221096343682053, 
              c[ 55][ t]], 
            Times[ -0.035980357068793781, 
              c[ 56][ t]], 
            Times[ -0.044914622433376419, 
              c[ 57][ t]], 
            Times[ -0.05168708394579296, 
              c[ 58][ t]], 
            Times[ -0.05606123915856713, 
              c[ 59][ t]], 
            Times[ -0.057908442314993203, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-21\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-21\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.11643488132933186`\ \(c[\(-60\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-59\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-58\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-57\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-56\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-55\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-54\)]\)[t] + 
            0.060688263076985`\ \(c[\(-53\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-52\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-51\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-50\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-49\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-48\)]\)[t] - 
            0.13647135277833616`\ \(c[\(-47\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-46\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-45\)]\)[t] - 
            0.20645618564475848`\ \(c[\(-44\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-43\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-42\)]\)[t] - 
            0.2067483357831719`\ \(c[\(-41\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-40\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-39\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-38\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-37\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-36\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-35\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-34\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-33\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-32\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-31\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-30\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-29\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-28\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-27\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-26\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-25\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-24\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-23\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-22\)]\)[t] + 
            10.67221231306757`\ \(c[\(-21\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-20\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-19\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-18\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-17\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-16\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-15\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-14\)]\)[t] + 
            0.5935615337286803`\ \(c[\(-13\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-12\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-11\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-10\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-9\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-8\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-7\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-6\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-5\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-4\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-3\)]\)[t] - 
            0.186750272222986`\ \(c[\(-2\)]\)[t] - 
            0.206748335783172`\ \(c[\(-1\)]\)[t] - 
            0.21623620818304484`\ \(c[0]\)[t] - 
            0.21584055771952013`\ \(c[1]\)[t] - 
            0.20645618564475843`\ \(c[2]\)[t] - 
            0.18920668216016426`\ \(c[3]\)[t] - 
            0.1653986686265376`\ \(c[4]\)[t] - 
            0.13647135277833605`\ \(c[5]\)[t] - 
            0.10394325375429328`\ \(c[6]\)[t] - 
            0.06935801494512607`\ \(c[7]\)[t] - 
            0.03423121377955895`\ \(c[8]\)[t] - 
            3.898171832519376`*^-17\ \(c[9]\)[t] + 
            0.032022748374425904`\ \(c[10]\)[t] + 
            0.060688263076985105`\ \(c[11]\)[t] + 
            0.0850444803444217`\ \(c[12]\)[t] + 
            0.10436044624225685`\ \(c[13]\)[t] + 
            0.11814190616181255`\ \(c[14]\)[t] + 
            0.12613778810677614`\ \(c[15]\)[t] + 
            0.12833762891430928`\ \(c[16]\)[t] + 
            0.12496032289024853`\ \(c[17]\)[t] + 
            0.11643488132933186`\ \(c[18]\)[t] + 
            0.10337416789158609`\ \(c[19]\)[t] + 
            0.08654280907894489`\ \(c[20]\)[t] + 
            0.06682066312775997`\ \(c[21]\)[t] + 
            0.0451633585689193`\ \(c[22]\)[t] + 
            0.02256148180925487`\ \(c[23]\)[t] + 
            3.8981718325193755`*^-17\ \(c[24]\)[t] - 
            0.02158054781754788`\ \(c[25]\)[t] - 
            0.04131966847794722`\ \(c[26]\)[t] - 
            0.05846808023678991`\ \(c[27]\)[t] - 
            0.07241337086197412`\ \(c[28]\)[t] - 
            0.08269933431326874`\ \(c[29]\)[t] - 
            0.0890384386636067`\ \(c[30]\)[t] - 
            0.09131715903518159`\ \(c[31]\)[t] - 
            0.08959419377036688`\ \(c[32]\)[t] - 
            0.08409185873785081`\ \(c[33]\)[t] - 
            0.0751812130120626`\ \(c[34]\)[t] - 
            0.06336169950422753`\ \(c[35]\)[t] - 
            0.04923627809413894`\ \(c[36]\)[t] - 
            0.03348317962868157`\ \(c[37]\)[t] - 
            0.0168255118577494`\ \(c[38]\)[t] - 
            3.898171832519376`*^-17\ \(c[39]\)[t] + 
            0.016273855731265604`\ \(c[40]\)[t] + 
            0.03132297449134708`\ \(c[41]\)[t] + 
            0.04454710875183992`\ \(c[42]\)[t] + 
            0.05544148706619893`\ \(c[43]\)[t] + 
            0.06361487254866825`\ \(c[44]\)[t] + 
            0.06880242987642335`\ \(c[45]\)[t] + 
            0.07087301895267824`\ \(c[46]\)[t] + 
            0.06983076867396242`\ \(c[47]\)[t] + 
            0.06581101988179627`\ \(c[48]\)[t] + 
            0.059070953080906326`\ \(c[49]\)[t] + 
            0.049975424961080865`\ \(c[50]\)[t] + 
            0.03897872015785999`\ \(c[51]\)[t] + 
            0.026603074225527826`\ \(c[52]\)[t] + 
            0.013414935129827233`\ \(c[53]\)[t] + 
            3.898171832519376`*^-17\ \(c[54]\)[t] - 
            0.013061910521147383`\ \(c[55]\)[t] - 
            0.025221096343682053`\ \(c[56]\)[t] - 
            0.03598035706879378`\ \(c[57]\)[t] - 
            0.04491462243337642`\ \(c[58]\)[t] - 
            0.05168708394579296`\ \(c[59]\)[t] - 
            0.056061239158567186`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -21, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -21]][ t]], 
          Plus[ 
            Times[ 0.11643488132933186, 
              c[ -60][ t]], 
            Times[ 0.12496032289024853, 
              c[ -59][ t]], 
            Times[ 0.12833762891430928, 
              c[ -58][ t]], 
            Times[ 0.12613778810677614, 
              c[ -57][ t]], 
            Times[ 0.11814190616181253, 
              c[ -56][ t]], 
            Times[ 0.10436044624225685, 
              c[ -55][ t]], 
            Times[ 0.085044480344421705, 
              c[ -54][ t]], 
            Times[ 0.060688263076985001, 
              c[ -53][ t]], 
            Times[ 0.032022748374425904, 
              c[ -52][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -51][ t]], 
            Times[ -0.034231213779559094, 
              c[ -50][ t]], 
            Times[ -0.06935801494512607, 
              c[ -49][ t]], 
            Times[ -0.10394325375429328, 
              c[ -48][ t]], 
            Times[ -0.13647135277833616, 
              c[ -47][ t]], 
            Times[ -0.16539866862653771, 
              c[ -46][ t]], 
            Times[ -0.18920668216016426, 
              c[ -45][ t]], 
            Times[ -0.20645618564475848, 
              c[ -44][ t]], 
            Times[ -0.21584055771952015, 
              c[ -43][ t]], 
            Times[ -0.21623620818304484, 
              c[ -42][ t]], 
            Times[ -0.20674833578317189, 
              c[ -41][ t]], 
            Times[ -0.18675027222298593, 
              c[ -40][ t]], 
            Times[ -0.15591488063143982, 
              c[ -39][ t]], 
            Times[ -0.11423673049785436, 
              c[ -38][ t]], 
            Times[ -0.062044074975450239, 
              c[ -37][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -36][ t]], 
            Times[ 0.070907514257657775, 
              c[ -35][ t]], 
            Times[ 0.14938649372796384, 
              c[ -34][ t]], 
            Times[ 0.23387232094715985, 
              c[ -33][ t]], 
            Times[ 0.32256865202152157, 
              c[ -32][ t]], 
            Times[ 0.41349667156634429, 
              c[ -31][ t]], 
            Times[ 0.50455115242710469, 
              c[ -30][ t]], 
            Times[ 0.59356153372868059, 
              c[ -29][ t]], 
            Times[ 0.67835603854706361, 
              c[ -28][ t]], 
            Times[ 0.75682672864065692, 
              c[ -27][ t]], 
            Times[ 0.82699334313268813, 
              c[ -26][ t]], 
            Times[ 0.88706379305918392, 
              c[ -25][ t]], 
            Times[ 0.93548928378863916, 
              c[ -24][ t]], 
            Times[ 0.9710122092317629, 
              c[ -23][ t]], 
            Times[ 0.99270519960720693, 
              c[ -22][ t]], 
            Times[ 10.67221231306757, 
              c[ -21][ t]], 
            Times[ 0.99270519960720671, 
              c[ -20][ t]], 
            Times[ 0.9710122092317629, 
              c[ -19][ t]], 
            Times[ 0.93548928378863916, 
              c[ -18][ t]], 
            Times[ 0.88706379305918381, 
              c[ -17][ t]], 
            Times[ 0.82699334313268813, 
              c[ -16][ t]], 
            Times[ 0.75682672864065692, 
              c[ -15][ t]], 
            Times[ 0.67835603854706317, 
              c[ -14][ t]], 
            Times[ 0.59356153372868026, 
              c[ -13][ t]], 
            Times[ 0.50455115242710469, 
              c[ -12][ t]], 
            Times[ 0.41349667156634395, 
              c[ -11][ t]], 
            Times[ 0.32256865202152135, 
              c[ -10][ t]], 
            Times[ 0.23387232094715985, 
              c[ -9][ t]], 
            Times[ 0.14938649372796345, 
              c[ -8][ t]], 
            Times[ 0.070907514257657622, 
              c[ -7][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -6][ t]], 
            Times[ -0.062044074975450475, 
              c[ -5][ t]], 
            Times[ -0.11423673049785445, 
              c[ -4][ t]], 
            Times[ -0.15591488063143982, 
              c[ -3][ t]], 
            Times[ -0.18675027222298601, 
              c[ -2][ t]], 
            Times[ -0.206748335783172, 
              c[ -1][ t]], 
            Times[ -0.21623620818304484, 
              c[ 0][ t]], 
            Times[ -0.21584055771952013, 
              c[ 1][ t]], 
            Times[ -0.20645618564475843, 
              c[ 2][ t]], 
            Times[ -0.18920668216016426, 
              c[ 3][ t]], 
            Times[ -0.1653986686265376, 
              c[ 4][ t]], 
            Times[ -0.13647135277833605, 
              c[ 5][ t]], 
            Times[ -0.10394325375429328, 
              c[ 6][ t]], 
            Times[ -0.06935801494512607, 
              c[ 7][ t]], 
            Times[ -0.034231213779558949, 
              c[ 8][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 9][ t]], 
            Times[ 0.032022748374425904, 
              c[ 10][ t]], 
            Times[ 0.060688263076985105, 
              c[ 11][ t]], 
            Times[ 0.085044480344421705, 
              c[ 12][ t]], 
            Times[ 0.10436044624225685, 
              c[ 13][ t]], 
            Times[ 0.11814190616181255, 
              c[ 14][ t]], 
            Times[ 0.12613778810677614, 
              c[ 15][ t]], 
            Times[ 0.12833762891430928, 
              c[ 16][ t]], 
            Times[ 0.12496032289024853, 
              c[ 17][ t]], 
            Times[ 0.11643488132933186, 
              c[ 18][ t]], 
            Times[ 0.10337416789158609, 
              c[ 19][ t]], 
            Times[ 0.086542809078944891, 
              c[ 20][ t]], 
            Times[ 0.066820663127759972, 
              c[ 21][ t]], 
            Times[ 0.045163358568919301, 
              c[ 22][ t]], 
            Times[ 0.022561481809254869, 
              c[ 23][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 24][ t]], 
            Times[ -0.021580547817547879, 
              c[ 25][ t]], 
            Times[ -0.04131966847794722, 
              c[ 26][ t]], 
            Times[ -0.058468080236789913, 
              c[ 27][ t]], 
            Times[ -0.072413370861974122, 
              c[ 28][ t]], 
            Times[ -0.082699334313268744, 
              c[ 29][ t]], 
            Times[ -0.089038438663606695, 
              c[ 30][ t]], 
            Times[ -0.091317159035181589, 
              c[ 31][ t]], 
            Times[ -0.089594193770366884, 
              c[ 32][ t]], 
            Times[ -0.084091858737850814, 
              c[ 33][ t]], 
            Times[ -0.075181213012062598, 
              c[ 34][ t]], 
            Times[ -0.063361699504227528, 
              c[ 35][ t]], 
            Times[ -0.049236278094138941, 
              c[ 36][ t]], 
            Times[ -0.033483179628681567, 
              c[ 37][ t]], 
            Times[ -0.016825511857749401, 
              c[ 38][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 39][ t]], 
            Times[ 0.016273855731265604, 
              c[ 40][ t]], 
            Times[ 0.031322974491347078, 
              c[ 41][ t]], 
            Times[ 0.044547108751839919, 
              c[ 42][ t]], 
            Times[ 0.055441487066198933, 
              c[ 43][ t]], 
            Times[ 0.063614872548668253, 
              c[ 44][ t]], 
            Times[ 0.068802429876423349, 
              c[ 45][ t]], 
            Times[ 0.070873018952678238, 
              c[ 46][ t]], 
            Times[ 0.069830768673962415, 
              c[ 47][ t]], 
            Times[ 0.065811019881796273, 
              c[ 48][ t]], 
            Times[ 0.059070953080906326, 
              c[ 49][ t]], 
            Times[ 0.049975424961080865, 
              c[ 50][ t]], 
            Times[ 0.03897872015785999, 
              c[ 51][ t]], 
            Times[ 0.026603074225527826, 
              c[ 52][ t]], 
            Times[ 0.013414935129827233, 
              c[ 53][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 54][ t]], 
            Times[ -0.013061910521147383, 
              c[ 55][ t]], 
            Times[ -0.025221096343682053, 
              c[ 56][ t]], 
            Times[ -0.035980357068793781, 
              c[ 57][ t]], 
            Times[ -0.044914622433376419, 
              c[ 58][ t]], 
            Times[ -0.05168708394579296, 
              c[ 59][ t]], 
            Times[ -0.056061239158567186, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-20\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-20\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.10337416789158595`\ \(c[\(-60\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-59\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-58\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-57\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-56\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-55\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-54\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-53\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-52\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-51\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-50\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-49\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-48\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-47\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-46\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-45\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-44\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-43\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-42\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-41\)]\)[t] - 
            0.206748335783172`\ \(c[\(-40\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-39\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-38\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-37\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-36\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-35\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-34\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-33\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-32\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-31\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-30\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-29\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-28\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-27\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-26\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-25\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-24\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-23\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-22\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-21\)]\)[t] + 
            9.772981689857206`\ \(c[\(-20\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-19\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-18\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-17\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-16\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-15\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-14\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-13\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-12\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-11\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-10\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-9\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-8\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-7\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-6\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-5\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-4\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-3\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-2\)]\)[t] - 
            0.186750272222986`\ \(c[\(-1\)]\)[t] - 
            0.206748335783172`\ \(c[0]\)[t] - 
            0.21623620818304484`\ \(c[1]\)[t] - 
            0.21584055771952015`\ \(c[2]\)[t] - 
            0.20645618564475843`\ \(c[3]\)[t] - 
            0.18920668216016426`\ \(c[4]\)[t] - 
            0.1653986686265377`\ \(c[5]\)[t] - 
            0.13647135277833605`\ \(c[6]\)[t] - 
            0.10394325375429328`\ \(c[7]\)[t] - 
            0.06935801494512607`\ \(c[8]\)[t] - 
            0.03423121377955895`\ \(c[9]\)[t] - 
            3.898171832519376`*^-17\ \(c[10]\)[t] + 
            0.032022748374425904`\ \(c[11]\)[t] + 
            0.060688263076985105`\ \(c[12]\)[t] + 
            0.0850444803444217`\ \(c[13]\)[t] + 
            0.10436044624225685`\ \(c[14]\)[t] + 
            0.11814190616181255`\ \(c[15]\)[t] + 
            0.12613778810677614`\ \(c[16]\)[t] + 
            0.12833762891430928`\ \(c[17]\)[t] + 
            0.12496032289024853`\ \(c[18]\)[t] + 
            0.11643488132933186`\ \(c[19]\)[t] + 
            0.10337416789158609`\ \(c[20]\)[t] + 
            0.08654280907894489`\ \(c[21]\)[t] + 
            0.06682066312775997`\ \(c[22]\)[t] + 
            0.0451633585689193`\ \(c[23]\)[t] + 
            0.02256148180925487`\ \(c[24]\)[t] + 
            3.8981718325193755`*^-17\ \(c[25]\)[t] - 
            0.02158054781754788`\ \(c[26]\)[t] - 
            0.04131966847794722`\ \(c[27]\)[t] - 
            0.05846808023678991`\ \(c[28]\)[t] - 
            0.07241337086197412`\ \(c[29]\)[t] - 
            0.08269933431326874`\ \(c[30]\)[t] - 
            0.0890384386636067`\ \(c[31]\)[t] - 
            0.09131715903518159`\ \(c[32]\)[t] - 
            0.08959419377036688`\ \(c[33]\)[t] - 
            0.08409185873785081`\ \(c[34]\)[t] - 
            0.0751812130120626`\ \(c[35]\)[t] - 
            0.06336169950422753`\ \(c[36]\)[t] - 
            0.04923627809413894`\ \(c[37]\)[t] - 
            0.03348317962868157`\ \(c[38]\)[t] - 
            0.0168255118577494`\ \(c[39]\)[t] - 
            3.898171832519376`*^-17\ \(c[40]\)[t] + 
            0.01627385573126547`\ \(c[41]\)[t] + 
            0.03132297449134708`\ \(c[42]\)[t] + 
            0.04454710875183992`\ \(c[43]\)[t] + 
            0.055441487066198857`\ \(c[44]\)[t] + 
            0.06361487254866825`\ \(c[45]\)[t] + 
            0.06880242987642335`\ \(c[46]\)[t] + 
            0.07087301895267824`\ \(c[47]\)[t] + 
            0.06983076867396242`\ \(c[48]\)[t] + 
            0.06581101988179627`\ \(c[49]\)[t] + 
            0.0590709530809064`\ \(c[50]\)[t] + 
            0.049975424961080865`\ \(c[51]\)[t] + 
            0.03897872015785999`\ \(c[52]\)[t] + 
            0.026603074225527937`\ \(c[53]\)[t] + 
            0.013414935129827233`\ \(c[54]\)[t] + 
            3.898171832519376`*^-17\ \(c[55]\)[t] - 
            0.013061910521147276`\ \(c[56]\)[t] - 
            0.025221096343682053`\ \(c[57]\)[t] - 
            0.03598035706879378`\ \(c[58]\)[t] - 
            0.04491462243337629`\ \(c[59]\)[t] - 
            0.05168708394579296`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -20, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -20]][ t]], 
          Plus[ 
            Times[ 0.10337416789158595, 
              c[ -60][ t]], 
            Times[ 0.11643488132933186, 
              c[ -59][ t]], 
            Times[ 0.12496032289024853, 
              c[ -58][ t]], 
            Times[ 0.12833762891430925, 
              c[ -57][ t]], 
            Times[ 0.12613778810677612, 
              c[ -56][ t]], 
            Times[ 0.11814190616181255, 
              c[ -55][ t]], 
            Times[ 0.10436044624225692, 
              c[ -54][ t]], 
            Times[ 0.085044480344421608, 
              c[ -53][ t]], 
            Times[ 0.060688263076985105, 
              c[ -52][ t]], 
            Times[ 0.032022748374426029, 
              c[ -51][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -50][ t]], 
            Times[ -0.034231213779558949, 
              c[ -49][ t]], 
            Times[ -0.069358014945125918, 
              c[ -48][ t]], 
            Times[ -0.1039432537542934, 
              c[ -47][ t]], 
            Times[ -0.13647135277833605, 
              c[ -46][ t]], 
            Times[ -0.1653986686265376, 
              c[ -45][ t]], 
            Times[ -0.18920668216016434, 
              c[ -44][ t]], 
            Times[ -0.20645618564475843, 
              c[ -43][ t]], 
            Times[ -0.21584055771952013, 
              c[ -42][ t]], 
            Times[ -0.21623620818304481, 
              c[ -41][ t]], 
            Times[ -0.206748335783172, 
              c[ -40][ t]], 
            Times[ -0.18675027222298607, 
              c[ -39][ t]], 
            Times[ -0.15591488063143982, 
              c[ -38][ t]], 
            Times[ -0.11423673049785436, 
              c[ -37][ t]], 
            Times[ -0.062044074975450475, 
              c[ -36][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -35][ t]], 
            Times[ 0.070907514257657775, 
              c[ -34][ t]], 
            Times[ 0.14938649372796345, 
              c[ -33][ t]], 
            Times[ 0.23387232094715985, 
              c[ -32][ t]], 
            Times[ 0.32256865202152157, 
              c[ -31][ t]], 
            Times[ 0.41349667156634395, 
              c[ -30][ t]], 
            Times[ 0.50455115242710469, 
              c[ -29][ t]], 
            Times[ 0.59356153372868059, 
              c[ -28][ t]], 
            Times[ 0.67835603854706317, 
              c[ -27][ t]], 
            Times[ 0.75682672864065692, 
              c[ -26][ t]], 
            Times[ 0.82699334313268813, 
              c[ -25][ t]], 
            Times[ 0.88706379305918381, 
              c[ -24][ t]], 
            Times[ 0.93548928378863916, 
              c[ -23][ t]], 
            Times[ 0.9710122092317629, 
              c[ -22][ t]], 
            Times[ 0.99270519960720671, 
              c[ -21][ t]], 
            Times[ 9.7729816898572057, 
              c[ -20][ t]], 
            Times[ 0.99270519960720693, 
              c[ -19][ t]], 
            Times[ 0.9710122092317629, 
              c[ -18][ t]], 
            Times[ 0.93548928378863916, 
              c[ -17][ t]], 
            Times[ 0.88706379305918381, 
              c[ -16][ t]], 
            Times[ 0.82699334313268813, 
              c[ -15][ t]], 
            Times[ 0.75682672864065692, 
              c[ -14][ t]], 
            Times[ 0.67835603854706339, 
              c[ -13][ t]], 
            Times[ 0.59356153372868059, 
              c[ -12][ t]], 
            Times[ 0.50455115242710469, 
              c[ -11][ t]], 
            Times[ 0.41349667156634418, 
              c[ -10][ t]], 
            Times[ 0.32256865202152157, 
              c[ -9][ t]], 
            Times[ 0.23387232094715985, 
              c[ -8][ t]], 
            Times[ 0.14938649372796362, 
              c[ -7][ t]], 
            Times[ 0.070907514257657775, 
              c[ -6][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -5][ t]], 
            Times[ -0.062044074975450343, 
              c[ -4][ t]], 
            Times[ -0.11423673049785436, 
              c[ -3][ t]], 
            Times[ -0.15591488063143974, 
              c[ -2][ t]], 
            Times[ -0.18675027222298601, 
              c[ -1][ t]], 
            Times[ -0.206748335783172, 
              c[ 0][ t]], 
            Times[ -0.21623620818304484, 
              c[ 1][ t]], 
            Times[ -0.21584055771952015, 
              c[ 2][ t]], 
            Times[ -0.20645618564475843, 
              c[ 3][ t]], 
            Times[ -0.18920668216016426, 
              c[ 4][ t]], 
            Times[ -0.16539866862653771, 
              c[ 5][ t]], 
            Times[ -0.13647135277833605, 
              c[ 6][ t]], 
            Times[ -0.10394325375429328, 
              c[ 7][ t]], 
            Times[ -0.06935801494512607, 
              c[ 8][ t]], 
            Times[ -0.034231213779558949, 
              c[ 9][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 10][ t]], 
            Times[ 0.032022748374425904, 
              c[ 11][ t]], 
            Times[ 0.060688263076985105, 
              c[ 12][ t]], 
            Times[ 0.085044480344421705, 
              c[ 13][ t]], 
            Times[ 0.10436044624225685, 
              c[ 14][ t]], 
            Times[ 0.11814190616181255, 
              c[ 15][ t]], 
            Times[ 0.12613778810677614, 
              c[ 16][ t]], 
            Times[ 0.12833762891430928, 
              c[ 17][ t]], 
            Times[ 0.12496032289024853, 
              c[ 18][ t]], 
            Times[ 0.11643488132933186, 
              c[ 19][ t]], 
            Times[ 0.10337416789158609, 
              c[ 20][ t]], 
            Times[ 0.086542809078944891, 
              c[ 21][ t]], 
            Times[ 0.066820663127759972, 
              c[ 22][ t]], 
            Times[ 0.045163358568919301, 
              c[ 23][ t]], 
            Times[ 0.022561481809254869, 
              c[ 24][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 25][ t]], 
            Times[ -0.021580547817547879, 
              c[ 26][ t]], 
            Times[ -0.04131966847794722, 
              c[ 27][ t]], 
            Times[ -0.058468080236789913, 
              c[ 28][ t]], 
            Times[ -0.072413370861974122, 
              c[ 29][ t]], 
            Times[ -0.082699334313268744, 
              c[ 30][ t]], 
            Times[ -0.089038438663606695, 
              c[ 31][ t]], 
            Times[ -0.091317159035181589, 
              c[ 32][ t]], 
            Times[ -0.089594193770366884, 
              c[ 33][ t]], 
            Times[ -0.084091858737850814, 
              c[ 34][ t]], 
            Times[ -0.075181213012062598, 
              c[ 35][ t]], 
            Times[ -0.063361699504227528, 
              c[ 36][ t]], 
            Times[ -0.049236278094138941, 
              c[ 37][ t]], 
            Times[ -0.033483179628681567, 
              c[ 38][ t]], 
            Times[ -0.016825511857749401, 
              c[ 39][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 40][ t]], 
            Times[ 0.016273855731265469, 
              c[ 41][ t]], 
            Times[ 0.031322974491347078, 
              c[ 42][ t]], 
            Times[ 0.044547108751839919, 
              c[ 43][ t]], 
            Times[ 0.055441487066198857, 
              c[ 44][ t]], 
            Times[ 0.063614872548668253, 
              c[ 45][ t]], 
            Times[ 0.068802429876423349, 
              c[ 46][ t]], 
            Times[ 0.070873018952678238, 
              c[ 47][ t]], 
            Times[ 0.069830768673962415, 
              c[ 48][ t]], 
            Times[ 0.065811019881796273, 
              c[ 49][ t]], 
            Times[ 0.059070953080906402, 
              c[ 50][ t]], 
            Times[ 0.049975424961080865, 
              c[ 51][ t]], 
            Times[ 0.03897872015785999, 
              c[ 52][ t]], 
            Times[ 0.026603074225527937, 
              c[ 53][ t]], 
            Times[ 0.013414935129827233, 
              c[ 54][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 55][ t]], 
            Times[ -0.013061910521147276, 
              c[ 56][ t]], 
            Times[ -0.025221096343682053, 
              c[ 57][ t]], 
            Times[ -0.035980357068793781, 
              c[ 58][ t]], 
            Times[ -0.044914622433376288, 
              c[ 59][ t]], 
            Times[ -0.05168708394579296, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-19\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-19\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.08654280907894475`\ \(c[\(-60\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-59\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-58\)]\)[t] + 
            0.12496032289024847`\ \(c[\(-57\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-56\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-55\)]\)[t] + 
            0.1181419061618126`\ \(c[\(-54\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-53\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-52\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-51\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-50\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-49\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-48\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-47\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-46\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-45\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-44\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-43\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-42\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-41\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-40\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-39\)]\)[t] - 
            0.186750272222986`\ \(c[\(-38\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-37\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-36\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-35\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-34\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-33\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-32\)]\)[t] + 
            0.23387232094715998`\ \(c[\(-31\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-30\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-29\)]\)[t] + 
            0.5045511524271049`\ \(c[\(-28\)]\)[t] + 
            0.5935615337286803`\ \(c[\(-27\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-26\)]\)[t] + 
            0.7568267286406571`\ \(c[\(-25\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-24\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-23\)]\)[t] + 
            0.9354892837886394`\ \(c[\(-22\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-21\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-20\)]\)[t] + 
            8.91761597509613`\ \(c[\(-19\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-18\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-17\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-16\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-15\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-14\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-13\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-12\)]\)[t] + 
            0.5935615337286803`\ \(c[\(-11\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-10\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-9\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-8\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-7\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-6\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-5\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-4\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-3\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-2\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-1\)]\)[t] - 
            0.186750272222986`\ \(c[0]\)[t] - 
            0.206748335783172`\ \(c[1]\)[t] - 
            0.21623620818304484`\ \(c[2]\)[t] - 
            0.21584055771952015`\ \(c[3]\)[t] - 
            0.20645618564475843`\ \(c[4]\)[t] - 
            0.18920668216016426`\ \(c[5]\)[t] - 
            0.1653986686265377`\ \(c[6]\)[t] - 
            0.13647135277833605`\ \(c[7]\)[t] - 
            0.10394325375429328`\ \(c[8]\)[t] - 
            0.06935801494512607`\ \(c[9]\)[t] - 
            0.03423121377955895`\ \(c[10]\)[t] - 
            3.898171832519376`*^-17\ \(c[11]\)[t] + 
            0.032022748374425904`\ \(c[12]\)[t] + 
            0.060688263076985105`\ \(c[13]\)[t] + 
            0.0850444803444217`\ \(c[14]\)[t] + 
            0.10436044624225685`\ \(c[15]\)[t] + 
            0.11814190616181255`\ \(c[16]\)[t] + 
            0.12613778810677614`\ \(c[17]\)[t] + 
            0.12833762891430928`\ \(c[18]\)[t] + 
            0.12496032289024853`\ \(c[19]\)[t] + 
            0.11643488132933186`\ \(c[20]\)[t] + 
            0.10337416789158609`\ \(c[21]\)[t] + 
            0.08654280907894489`\ \(c[22]\)[t] + 
            0.06682066312775997`\ \(c[23]\)[t] + 
            0.0451633585689193`\ \(c[24]\)[t] + 
            0.02256148180925487`\ \(c[25]\)[t] + 
            3.8981718325193755`*^-17\ \(c[26]\)[t] - 
            0.02158054781754788`\ \(c[27]\)[t] - 
            0.04131966847794722`\ \(c[28]\)[t] - 
            0.05846808023678991`\ \(c[29]\)[t] - 
            0.07241337086197412`\ \(c[30]\)[t] - 
            0.08269933431326874`\ \(c[31]\)[t] - 
            0.0890384386636067`\ \(c[32]\)[t] - 
            0.09131715903518159`\ \(c[33]\)[t] - 
            0.08959419377036688`\ \(c[34]\)[t] - 
            0.08409185873785081`\ \(c[35]\)[t] - 
            0.0751812130120626`\ \(c[36]\)[t] - 
            0.06336169950422753`\ \(c[37]\)[t] - 
            0.04923627809413894`\ \(c[38]\)[t] - 
            0.03348317962868157`\ \(c[39]\)[t] - 
            0.0168255118577494`\ \(c[40]\)[t] - 
            1.8033970416801674`*^-16\ \(c[41]\)[t] + 
            0.016273855731265604`\ \(c[42]\)[t] + 
            0.03132297449134708`\ \(c[43]\)[t] + 
            0.044547108751839815`\ \(c[44]\)[t] + 
            0.05544148706619893`\ \(c[45]\)[t] + 
            0.06361487254866825`\ \(c[46]\)[t] + 
            0.06880242987642332`\ \(c[47]\)[t] + 
            0.07087301895267824`\ \(c[48]\)[t] + 
            0.06983076867396242`\ \(c[49]\)[t] + 
            0.06581101988179631`\ \(c[50]\)[t] + 
            0.059070953080906326`\ \(c[51]\)[t] + 
            0.049975424961080865`\ \(c[52]\)[t] + 
            0.03897872015786009`\ \(c[53]\)[t] + 
            0.026603074225527826`\ \(c[54]\)[t] + 
            0.013414935129827233`\ \(c[55]\)[t] + 
            1.5206810699945212`*^-16\ \(c[56]\)[t] - 
            0.013061910521147383`\ \(c[57]\)[t] - 
            0.025221096343682053`\ \(c[58]\)[t] - 
            0.03598035706879378`\ \(c[59]\)[t] - 
            0.04491462243337642`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -19, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -19]][ t]], 
          Plus[ 
            Times[ 0.086542809078944752, 
              c[ -60][ t]], 
            Times[ 0.10337416789158609, 
              c[ -59][ t]], 
            Times[ 0.11643488132933186, 
              c[ -58][ t]], 
            Times[ 0.12496032289024847, 
              c[ -57][ t]], 
            Times[ 0.12833762891430928, 
              c[ -56][ t]], 
            Times[ 0.12613778810677614, 
              c[ -55][ t]], 
            Times[ 0.1181419061618126, 
              c[ -54][ t]], 
            Times[ 0.10436044624225685, 
              c[ -53][ t]], 
            Times[ 0.085044480344421705, 
              c[ -52][ t]], 
            Times[ 0.060688263076985223, 
              c[ -51][ t]], 
            Times[ 0.032022748374425904, 
              c[ -50][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -49][ t]], 
            Times[ -0.034231213779558796, 
              c[ -48][ t]], 
            Times[ -0.06935801494512607, 
              c[ -47][ t]], 
            Times[ -0.10394325375429328, 
              c[ -46][ t]], 
            Times[ -0.13647135277833591, 
              c[ -45][ t]], 
            Times[ -0.16539866862653771, 
              c[ -44][ t]], 
            Times[ -0.18920668216016426, 
              c[ -43][ t]], 
            Times[ -0.20645618564475834, 
              c[ -42][ t]], 
            Times[ -0.21584055771952015, 
              c[ -41][ t]], 
            Times[ -0.21623620818304484, 
              c[ -40][ t]], 
            Times[ -0.20674833578317206, 
              c[ -39][ t]], 
            Times[ -0.18675027222298601, 
              c[ -38][ t]], 
            Times[ -0.15591488063143974, 
              c[ -37][ t]], 
            Times[ -0.11423673049785445, 
              c[ -36][ t]], 
            Times[ -0.062044074975450343, 
              c[ -35][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -34][ t]], 
            Times[ 0.070907514257657622, 
              c[ -33][ t]], 
            Times[ 0.14938649372796362, 
              c[ -32][ t]], 
            Times[ 0.23387232094715998, 
              c[ -31][ t]], 
            Times[ 0.32256865202152135, 
              c[ -30][ t]], 
            Times[ 0.41349667156634418, 
              c[ -29][ t]], 
            Times[ 0.50455115242710491, 
              c[ -28][ t]], 
            Times[ 0.59356153372868026, 
              c[ -27][ t]], 
            Times[ 0.67835603854706339, 
              c[ -26][ t]], 
            Times[ 0.75682672864065714, 
              c[ -25][ t]], 
            Times[ 0.82699334313268813, 
              c[ -24][ t]], 
            Times[ 0.88706379305918381, 
              c[ -23][ t]], 
            Times[ 0.93548928378863938, 
              c[ -22][ t]], 
            Times[ 0.9710122092317629, 
              c[ -21][ t]], 
            Times[ 0.99270519960720693, 
              c[ -20][ t]], 
            Times[ 8.9176159750961297, 
              c[ -19][ t]], 
            Times[ 0.99270519960720693, 
              c[ -18][ t]], 
            Times[ 0.9710122092317629, 
              c[ -17][ t]], 
            Times[ 0.93548928378863916, 
              c[ -16][ t]], 
            Times[ 0.88706379305918381, 
              c[ -15][ t]], 
            Times[ 0.82699334313268813, 
              c[ -14][ t]], 
            Times[ 0.75682672864065692, 
              c[ -13][ t]], 
            Times[ 0.67835603854706339, 
              c[ -12][ t]], 
            Times[ 0.59356153372868026, 
              c[ -11][ t]], 
            Times[ 0.50455115242710469, 
              c[ -10][ t]], 
            Times[ 0.41349667156634418, 
              c[ -9][ t]], 
            Times[ 0.32256865202152157, 
              c[ -8][ t]], 
            Times[ 0.23387232094715985, 
              c[ -7][ t]], 
            Times[ 0.14938649372796362, 
              c[ -6][ t]], 
            Times[ 0.070907514257657775, 
              c[ -5][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -4][ t]], 
            Times[ -0.062044074975450343, 
              c[ -3][ t]], 
            Times[ -0.11423673049785436, 
              c[ -2][ t]], 
            Times[ -0.15591488063143982, 
              c[ -1][ t]], 
            Times[ -0.18675027222298601, 
              c[ 0][ t]], 
            Times[ -0.206748335783172, 
              c[ 1][ t]], 
            Times[ -0.21623620818304484, 
              c[ 2][ t]], 
            Times[ -0.21584055771952015, 
              c[ 3][ t]], 
            Times[ -0.20645618564475843, 
              c[ 4][ t]], 
            Times[ -0.18920668216016426, 
              c[ 5][ t]], 
            Times[ -0.16539866862653771, 
              c[ 6][ t]], 
            Times[ -0.13647135277833605, 
              c[ 7][ t]], 
            Times[ -0.10394325375429328, 
              c[ 8][ t]], 
            Times[ -0.06935801494512607, 
              c[ 9][ t]], 
            Times[ -0.034231213779558949, 
              c[ 10][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 11][ t]], 
            Times[ 0.032022748374425904, 
              c[ 12][ t]], 
            Times[ 0.060688263076985105, 
              c[ 13][ t]], 
            Times[ 0.085044480344421705, 
              c[ 14][ t]], 
            Times[ 0.10436044624225685, 
              c[ 15][ t]], 
            Times[ 0.11814190616181255, 
              c[ 16][ t]], 
            Times[ 0.12613778810677614, 
              c[ 17][ t]], 
            Times[ 0.12833762891430928, 
              c[ 18][ t]], 
            Times[ 0.12496032289024853, 
              c[ 19][ t]], 
            Times[ 0.11643488132933186, 
              c[ 20][ t]], 
            Times[ 0.10337416789158609, 
              c[ 21][ t]], 
            Times[ 0.086542809078944891, 
              c[ 22][ t]], 
            Times[ 0.066820663127759972, 
              c[ 23][ t]], 
            Times[ 0.045163358568919301, 
              c[ 24][ t]], 
            Times[ 0.022561481809254869, 
              c[ 25][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 26][ t]], 
            Times[ -0.021580547817547879, 
              c[ 27][ t]], 
            Times[ -0.04131966847794722, 
              c[ 28][ t]], 
            Times[ -0.058468080236789913, 
              c[ 29][ t]], 
            Times[ -0.072413370861974122, 
              c[ 30][ t]], 
            Times[ -0.082699334313268744, 
              c[ 31][ t]], 
            Times[ -0.089038438663606695, 
              c[ 32][ t]], 
            Times[ -0.091317159035181589, 
              c[ 33][ t]], 
            Times[ -0.089594193770366884, 
              c[ 34][ t]], 
            Times[ -0.084091858737850814, 
              c[ 35][ t]], 
            Times[ -0.075181213012062598, 
              c[ 36][ t]], 
            Times[ -0.063361699504227528, 
              c[ 37][ t]], 
            Times[ -0.049236278094138941, 
              c[ 38][ t]], 
            Times[ -0.033483179628681567, 
              c[ 39][ t]], 
            Times[ -0.016825511857749401, 
              c[ 40][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 41][ t]], 
            Times[ 0.016273855731265604, 
              c[ 42][ t]], 
            Times[ 0.031322974491347078, 
              c[ 43][ t]], 
            Times[ 0.044547108751839815, 
              c[ 44][ t]], 
            Times[ 0.055441487066198933, 
              c[ 45][ t]], 
            Times[ 0.063614872548668253, 
              c[ 46][ t]], 
            Times[ 0.068802429876423321, 
              c[ 47][ t]], 
            Times[ 0.070873018952678238, 
              c[ 48][ t]], 
            Times[ 0.069830768673962415, 
              c[ 49][ t]], 
            Times[ 0.065811019881796315, 
              c[ 50][ t]], 
            Times[ 0.059070953080906326, 
              c[ 51][ t]], 
            Times[ 0.049975424961080865, 
              c[ 52][ t]], 
            Times[ 0.038978720157860088, 
              c[ 53][ t]], 
            Times[ 0.026603074225527826, 
              c[ 54][ t]], 
            Times[ 0.013414935129827233, 
              c[ 55][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ 56][ t]], 
            Times[ -0.013061910521147383, 
              c[ 57][ t]], 
            Times[ -0.025221096343682053, 
              c[ 58][ t]], 
            Times[ -0.035980357068793781, 
              c[ 59][ t]], 
            Times[ -0.044914622433376419, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-18\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-18\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.06682066312775997`\ \(c[\(-60\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-59\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-58\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-57\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-56\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-55\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-54\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-53\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-52\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-51\)]\)[t] + 
            0.060688263076985`\ \(c[\(-50\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-49\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-48\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-47\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-46\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-45\)]\)[t] - 
            0.13647135277833616`\ \(c[\(-44\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-43\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-42\)]\)[t] - 
            0.20645618564475848`\ \(c[\(-41\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-40\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-39\)]\)[t] - 
            0.206748335783172`\ \(c[\(-38\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-37\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-36\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-35\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-34\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-33\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-32\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-31\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-30\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-29\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-28\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-27\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-26\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-25\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-24\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-23\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-22\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-21\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-20\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-19\)]\)[t] + 
            8.106115168784338`\ \(c[\(-18\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-17\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-16\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-15\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-14\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-13\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-12\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-11\)]\)[t] + 
            0.5935615337286803`\ \(c[\(-10\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-9\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-8\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-7\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-6\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-5\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-4\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-3\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-2\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-1\)]\)[t] - 
            0.15591488063143982`\ \(c[0]\)[t] - 
            0.186750272222986`\ \(c[1]\)[t] - 
            0.206748335783172`\ \(c[2]\)[t] - 
            0.21623620818304484`\ \(c[3]\)[t] - 
            0.21584055771952013`\ \(c[4]\)[t] - 
            0.20645618564475843`\ \(c[5]\)[t] - 
            0.18920668216016426`\ \(c[6]\)[t] - 
            0.1653986686265377`\ \(c[7]\)[t] - 
            0.13647135277833605`\ \(c[8]\)[t] - 
            0.10394325375429328`\ \(c[9]\)[t] - 
            0.06935801494512607`\ \(c[10]\)[t] - 
            0.03423121377955895`\ \(c[11]\)[t] - 
            3.898171832519376`*^-17\ \(c[12]\)[t] + 
            0.032022748374425904`\ \(c[13]\)[t] + 
            0.060688263076985105`\ \(c[14]\)[t] + 
            0.0850444803444217`\ \(c[15]\)[t] + 
            0.10436044624225685`\ \(c[16]\)[t] + 
            0.11814190616181255`\ \(c[17]\)[t] + 
            0.12613778810677614`\ \(c[18]\)[t] + 
            0.12833762891430928`\ \(c[19]\)[t] + 
            0.12496032289024853`\ \(c[20]\)[t] + 
            0.11643488132933186`\ \(c[21]\)[t] + 
            0.10337416789158609`\ \(c[22]\)[t] + 
            0.08654280907894489`\ \(c[23]\)[t] + 
            0.06682066312775997`\ \(c[24]\)[t] + 
            0.0451633585689193`\ \(c[25]\)[t] + 
            0.02256148180925487`\ \(c[26]\)[t] + 
            3.8981718325193755`*^-17\ \(c[27]\)[t] - 
            0.02158054781754788`\ \(c[28]\)[t] - 
            0.04131966847794722`\ \(c[29]\)[t] - 
            0.05846808023678991`\ \(c[30]\)[t] - 
            0.07241337086197412`\ \(c[31]\)[t] - 
            0.08269933431326874`\ \(c[32]\)[t] - 
            0.0890384386636067`\ \(c[33]\)[t] - 
            0.09131715903518159`\ \(c[34]\)[t] - 
            0.08959419377036688`\ \(c[35]\)[t] - 
            0.08409185873785081`\ \(c[36]\)[t] - 
            0.0751812130120626`\ \(c[37]\)[t] - 
            0.06336169950422753`\ \(c[38]\)[t] - 
            0.04923627809413894`\ \(c[39]\)[t] - 
            0.03348317962868157`\ \(c[40]\)[t] - 
            0.0168255118577494`\ \(c[41]\)[t] - 
            3.898171832519376`*^-17\ \(c[42]\)[t] + 
            0.016273855731265604`\ \(c[43]\)[t] + 
            0.03132297449134708`\ \(c[44]\)[t] + 
            0.04454710875183992`\ \(c[45]\)[t] + 
            0.05544148706619893`\ \(c[46]\)[t] + 
            0.06361487254866825`\ \(c[47]\)[t] + 
            0.06880242987642335`\ \(c[48]\)[t] + 
            0.07087301895267824`\ \(c[49]\)[t] + 
            0.06983076867396242`\ \(c[50]\)[t] + 
            0.06581101988179627`\ \(c[51]\)[t] + 
            0.059070953080906326`\ \(c[52]\)[t] + 
            0.049975424961080865`\ \(c[53]\)[t] + 
            0.03897872015785999`\ \(c[54]\)[t] + 
            0.026603074225527826`\ \(c[55]\)[t] + 
            0.013414935129827233`\ \(c[56]\)[t] + 
            3.898171832519376`*^-17\ \(c[57]\)[t] - 
            0.013061910521147383`\ \(c[58]\)[t] - 
            0.025221096343682053`\ \(c[59]\)[t] - 
            0.03598035706879378`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -18, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -18]][ t]], 
          Plus[ 
            Times[ 0.066820663127759972, 
              c[ -60][ t]], 
            Times[ 0.086542809078944891, 
              c[ -59][ t]], 
            Times[ 0.10337416789158609, 
              c[ -58][ t]], 
            Times[ 0.11643488132933186, 
              c[ -57][ t]], 
            Times[ 0.12496032289024853, 
              c[ -56][ t]], 
            Times[ 0.12833762891430928, 
              c[ -55][ t]], 
            Times[ 0.12613778810677614, 
              c[ -54][ t]], 
            Times[ 0.11814190616181253, 
              c[ -53][ t]], 
            Times[ 0.10436044624225685, 
              c[ -52][ t]], 
            Times[ 0.085044480344421705, 
              c[ -51][ t]], 
            Times[ 0.060688263076985001, 
              c[ -50][ t]], 
            Times[ 0.032022748374425904, 
              c[ -49][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -48][ t]], 
            Times[ -0.034231213779559094, 
              c[ -47][ t]], 
            Times[ -0.06935801494512607, 
              c[ -46][ t]], 
            Times[ -0.10394325375429328, 
              c[ -45][ t]], 
            Times[ -0.13647135277833616, 
              c[ -44][ t]], 
            Times[ -0.16539866862653771, 
              c[ -43][ t]], 
            Times[ -0.18920668216016426, 
              c[ -42][ t]], 
            Times[ -0.20645618564475848, 
              c[ -41][ t]], 
            Times[ -0.21584055771952015, 
              c[ -40][ t]], 
            Times[ -0.21623620818304484, 
              c[ -39][ t]], 
            Times[ -0.206748335783172, 
              c[ -38][ t]], 
            Times[ -0.18675027222298593, 
              c[ -37][ t]], 
            Times[ -0.15591488063143982, 
              c[ -36][ t]], 
            Times[ -0.11423673049785436, 
              c[ -35][ t]], 
            Times[ -0.062044074975450239, 
              c[ -34][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -33][ t]], 
            Times[ 0.070907514257657775, 
              c[ -32][ t]], 
            Times[ 0.14938649372796384, 
              c[ -31][ t]], 
            Times[ 0.23387232094715985, 
              c[ -30][ t]], 
            Times[ 0.32256865202152157, 
              c[ -29][ t]], 
            Times[ 0.41349667156634429, 
              c[ -28][ t]], 
            Times[ 0.50455115242710469, 
              c[ -27][ t]], 
            Times[ 0.59356153372868059, 
              c[ -26][ t]], 
            Times[ 0.67835603854706361, 
              c[ -25][ t]], 
            Times[ 0.75682672864065692, 
              c[ -24][ t]], 
            Times[ 0.82699334313268813, 
              c[ -23][ t]], 
            Times[ 0.88706379305918392, 
              c[ -22][ t]], 
            Times[ 0.93548928378863916, 
              c[ -21][ t]], 
            Times[ 0.9710122092317629, 
              c[ -20][ t]], 
            Times[ 0.99270519960720693, 
              c[ -19][ t]], 
            Times[ 8.1061151687843385, 
              c[ -18][ t]], 
            Times[ 0.99270519960720671, 
              c[ -17][ t]], 
            Times[ 0.9710122092317629, 
              c[ -16][ t]], 
            Times[ 0.93548928378863916, 
              c[ -15][ t]], 
            Times[ 0.88706379305918381, 
              c[ -14][ t]], 
            Times[ 0.82699334313268813, 
              c[ -13][ t]], 
            Times[ 0.75682672864065692, 
              c[ -12][ t]], 
            Times[ 0.67835603854706317, 
              c[ -11][ t]], 
            Times[ 0.59356153372868026, 
              c[ -10][ t]], 
            Times[ 0.50455115242710469, 
              c[ -9][ t]], 
            Times[ 0.41349667156634395, 
              c[ -8][ t]], 
            Times[ 0.32256865202152135, 
              c[ -7][ t]], 
            Times[ 0.23387232094715985, 
              c[ -6][ t]], 
            Times[ 0.14938649372796345, 
              c[ -5][ t]], 
            Times[ 0.070907514257657622, 
              c[ -4][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -3][ t]], 
            Times[ -0.062044074975450343, 
              c[ -2][ t]], 
            Times[ -0.11423673049785445, 
              c[ -1][ t]], 
            Times[ -0.15591488063143982, 
              c[ 0][ t]], 
            Times[ -0.18675027222298601, 
              c[ 1][ t]], 
            Times[ -0.206748335783172, 
              c[ 2][ t]], 
            Times[ -0.21623620818304484, 
              c[ 3][ t]], 
            Times[ -0.21584055771952013, 
              c[ 4][ t]], 
            Times[ -0.20645618564475843, 
              c[ 5][ t]], 
            Times[ -0.18920668216016426, 
              c[ 6][ t]], 
            Times[ -0.16539866862653771, 
              c[ 7][ t]], 
            Times[ -0.13647135277833605, 
              c[ 8][ t]], 
            Times[ -0.10394325375429328, 
              c[ 9][ t]], 
            Times[ -0.06935801494512607, 
              c[ 10][ t]], 
            Times[ -0.034231213779558949, 
              c[ 11][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 12][ t]], 
            Times[ 0.032022748374425904, 
              c[ 13][ t]], 
            Times[ 0.060688263076985105, 
              c[ 14][ t]], 
            Times[ 0.085044480344421705, 
              c[ 15][ t]], 
            Times[ 0.10436044624225685, 
              c[ 16][ t]], 
            Times[ 0.11814190616181255, 
              c[ 17][ t]], 
            Times[ 0.12613778810677614, 
              c[ 18][ t]], 
            Times[ 0.12833762891430928, 
              c[ 19][ t]], 
            Times[ 0.12496032289024853, 
              c[ 20][ t]], 
            Times[ 0.11643488132933186, 
              c[ 21][ t]], 
            Times[ 0.10337416789158609, 
              c[ 22][ t]], 
            Times[ 0.086542809078944891, 
              c[ 23][ t]], 
            Times[ 0.066820663127759972, 
              c[ 24][ t]], 
            Times[ 0.045163358568919301, 
              c[ 25][ t]], 
            Times[ 0.022561481809254869, 
              c[ 26][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 27][ t]], 
            Times[ -0.021580547817547879, 
              c[ 28][ t]], 
            Times[ -0.04131966847794722, 
              c[ 29][ t]], 
            Times[ -0.058468080236789913, 
              c[ 30][ t]], 
            Times[ -0.072413370861974122, 
              c[ 31][ t]], 
            Times[ -0.082699334313268744, 
              c[ 32][ t]], 
            Times[ -0.089038438663606695, 
              c[ 33][ t]], 
            Times[ -0.091317159035181589, 
              c[ 34][ t]], 
            Times[ -0.089594193770366884, 
              c[ 35][ t]], 
            Times[ -0.084091858737850814, 
              c[ 36][ t]], 
            Times[ -0.075181213012062598, 
              c[ 37][ t]], 
            Times[ -0.063361699504227528, 
              c[ 38][ t]], 
            Times[ -0.049236278094138941, 
              c[ 39][ t]], 
            Times[ -0.033483179628681567, 
              c[ 40][ t]], 
            Times[ -0.016825511857749401, 
              c[ 41][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 42][ t]], 
            Times[ 0.016273855731265604, 
              c[ 43][ t]], 
            Times[ 0.031322974491347078, 
              c[ 44][ t]], 
            Times[ 0.044547108751839919, 
              c[ 45][ t]], 
            Times[ 0.055441487066198933, 
              c[ 46][ t]], 
            Times[ 0.063614872548668253, 
              c[ 47][ t]], 
            Times[ 0.068802429876423349, 
              c[ 48][ t]], 
            Times[ 0.070873018952678238, 
              c[ 49][ t]], 
            Times[ 0.069830768673962415, 
              c[ 50][ t]], 
            Times[ 0.065811019881796273, 
              c[ 51][ t]], 
            Times[ 0.059070953080906326, 
              c[ 52][ t]], 
            Times[ 0.049975424961080865, 
              c[ 53][ t]], 
            Times[ 0.03897872015785999, 
              c[ 54][ t]], 
            Times[ 0.026603074225527826, 
              c[ 55][ t]], 
            Times[ 0.013414935129827233, 
              c[ 56][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 57][ t]], 
            Times[ -0.013061910521147383, 
              c[ 58][ t]], 
            Times[ -0.025221096343682053, 
              c[ 59][ t]], 
            Times[ -0.035980357068793781, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-17\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-17\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.045163358568919114`\ \(c[\(-60\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-59\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-58\)]\)[t] + 
            0.10337416789158595`\ \(c[\(-57\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-56\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-55\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-54\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-53\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-52\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-51\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-50\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-49\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-48\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-47\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-46\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-45\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-44\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-43\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-42\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-41\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-40\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-39\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-38\)]\)[t] - 
            0.206748335783172`\ \(c[\(-37\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-36\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-35\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-34\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-33\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-32\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-31\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-30\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-29\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-28\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-27\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-26\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-25\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-24\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-23\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-22\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-21\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-20\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-19\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-18\)]\)[t] + 
            7.338479270921831`\ \(c[\(-17\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-16\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-15\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-14\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-13\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-12\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-11\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-10\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-9\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-8\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-7\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-6\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-5\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-4\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-3\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-2\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-1\)]\)[t] - 
            0.11423673049785436`\ \(c[0]\)[t] - 
            0.15591488063143974`\ \(c[1]\)[t] - 
            0.186750272222986`\ \(c[2]\)[t] - 
            0.206748335783172`\ \(c[3]\)[t] - 
            0.21623620818304484`\ \(c[4]\)[t] - 
            0.21584055771952015`\ \(c[5]\)[t] - 
            0.20645618564475843`\ \(c[6]\)[t] - 
            0.18920668216016426`\ \(c[7]\)[t] - 
            0.1653986686265377`\ \(c[8]\)[t] - 
            0.13647135277833605`\ \(c[9]\)[t] - 
            0.10394325375429328`\ \(c[10]\)[t] - 
            0.06935801494512607`\ \(c[11]\)[t] - 
            0.03423121377955895`\ \(c[12]\)[t] - 
            3.898171832519376`*^-17\ \(c[13]\)[t] + 
            0.032022748374425904`\ \(c[14]\)[t] + 
            0.060688263076985105`\ \(c[15]\)[t] + 
            0.0850444803444217`\ \(c[16]\)[t] + 
            0.10436044624225685`\ \(c[17]\)[t] + 
            0.11814190616181255`\ \(c[18]\)[t] + 
            0.12613778810677614`\ \(c[19]\)[t] + 
            0.12833762891430928`\ \(c[20]\)[t] + 
            0.12496032289024853`\ \(c[21]\)[t] + 
            0.11643488132933186`\ \(c[22]\)[t] + 
            0.10337416789158609`\ \(c[23]\)[t] + 
            0.08654280907894489`\ \(c[24]\)[t] + 
            0.06682066312775997`\ \(c[25]\)[t] + 
            0.0451633585689193`\ \(c[26]\)[t] + 
            0.02256148180925487`\ \(c[27]\)[t] + 
            3.8981718325193755`*^-17\ \(c[28]\)[t] - 
            0.02158054781754788`\ \(c[29]\)[t] - 
            0.04131966847794722`\ \(c[30]\)[t] - 
            0.05846808023678991`\ \(c[31]\)[t] - 
            0.07241337086197412`\ \(c[32]\)[t] - 
            0.08269933431326874`\ \(c[33]\)[t] - 
            0.0890384386636067`\ \(c[34]\)[t] - 
            0.09131715903518159`\ \(c[35]\)[t] - 
            0.08959419377036688`\ \(c[36]\)[t] - 
            0.08409185873785081`\ \(c[37]\)[t] - 
            0.0751812130120626`\ \(c[38]\)[t] - 
            0.06336169950422753`\ \(c[39]\)[t] - 
            0.04923627809413894`\ \(c[40]\)[t] - 
            0.033483179628681706`\ \(c[41]\)[t] - 
            0.0168255118577494`\ \(c[42]\)[t] - 
            3.898171832519376`*^-17\ \(c[43]\)[t] + 
            0.01627385573126547`\ \(c[44]\)[t] + 
            0.03132297449134708`\ \(c[45]\)[t] + 
            0.04454710875183992`\ \(c[46]\)[t] + 
            0.055441487066198857`\ \(c[47]\)[t] + 
            0.06361487254866825`\ \(c[48]\)[t] + 
            0.06880242987642335`\ \(c[49]\)[t] + 
            0.07087301895267824`\ \(c[50]\)[t] + 
            0.06983076867396242`\ \(c[51]\)[t] + 
            0.06581101988179627`\ \(c[52]\)[t] + 
            0.0590709530809064`\ \(c[53]\)[t] + 
            0.049975424961080865`\ \(c[54]\)[t] + 
            0.03897872015785999`\ \(c[55]\)[t] + 
            0.026603074225527937`\ \(c[56]\)[t] + 
            0.013414935129827233`\ \(c[57]\)[t] + 
            3.898171832519376`*^-17\ \(c[58]\)[t] - 
            0.013061910521147276`\ \(c[59]\)[t] - 
            0.025221096343682053`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -17, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -17]][ t]], 
          Plus[ 
            Times[ 0.045163358568919114, 
              c[ -60][ t]], 
            Times[ 0.066820663127759972, 
              c[ -59][ t]], 
            Times[ 0.086542809078944891, 
              c[ -58][ t]], 
            Times[ 0.10337416789158595, 
              c[ -57][ t]], 
            Times[ 0.11643488132933186, 
              c[ -56][ t]], 
            Times[ 0.12496032289024853, 
              c[ -55][ t]], 
            Times[ 0.12833762891430925, 
              c[ -54][ t]], 
            Times[ 0.12613778810677612, 
              c[ -53][ t]], 
            Times[ 0.11814190616181255, 
              c[ -52][ t]], 
            Times[ 0.10436044624225692, 
              c[ -51][ t]], 
            Times[ 0.085044480344421608, 
              c[ -50][ t]], 
            Times[ 0.060688263076985105, 
              c[ -49][ t]], 
            Times[ 0.032022748374426029, 
              c[ -48][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -47][ t]], 
            Times[ -0.034231213779558949, 
              c[ -46][ t]], 
            Times[ -0.069358014945125918, 
              c[ -45][ t]], 
            Times[ -0.1039432537542934, 
              c[ -44][ t]], 
            Times[ -0.13647135277833605, 
              c[ -43][ t]], 
            Times[ -0.1653986686265376, 
              c[ -42][ t]], 
            Times[ -0.18920668216016434, 
              c[ -41][ t]], 
            Times[ -0.20645618564475843, 
              c[ -40][ t]], 
            Times[ -0.21584055771952013, 
              c[ -39][ t]], 
            Times[ -0.21623620818304484, 
              c[ -38][ t]], 
            Times[ -0.206748335783172, 
              c[ -37][ t]], 
            Times[ -0.18675027222298607, 
              c[ -36][ t]], 
            Times[ -0.15591488063143982, 
              c[ -35][ t]], 
            Times[ -0.11423673049785436, 
              c[ -34][ t]], 
            Times[ -0.062044074975450475, 
              c[ -33][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -32][ t]], 
            Times[ 0.070907514257657775, 
              c[ -31][ t]], 
            Times[ 0.14938649372796345, 
              c[ -30][ t]], 
            Times[ 0.23387232094715985, 
              c[ -29][ t]], 
            Times[ 0.32256865202152157, 
              c[ -28][ t]], 
            Times[ 0.41349667156634395, 
              c[ -27][ t]], 
            Times[ 0.50455115242710469, 
              c[ -26][ t]], 
            Times[ 0.59356153372868059, 
              c[ -25][ t]], 
            Times[ 0.67835603854706317, 
              c[ -24][ t]], 
            Times[ 0.75682672864065692, 
              c[ -23][ t]], 
            Times[ 0.82699334313268813, 
              c[ -22][ t]], 
            Times[ 0.88706379305918381, 
              c[ -21][ t]], 
            Times[ 0.93548928378863916, 
              c[ -20][ t]], 
            Times[ 0.9710122092317629, 
              c[ -19][ t]], 
            Times[ 0.99270519960720671, 
              c[ -18][ t]], 
            Times[ 7.3384792709218312, 
              c[ -17][ t]], 
            Times[ 0.99270519960720693, 
              c[ -16][ t]], 
            Times[ 0.9710122092317629, 
              c[ -15][ t]], 
            Times[ 0.93548928378863916, 
              c[ -14][ t]], 
            Times[ 0.88706379305918381, 
              c[ -13][ t]], 
            Times[ 0.82699334313268813, 
              c[ -12][ t]], 
            Times[ 0.75682672864065692, 
              c[ -11][ t]], 
            Times[ 0.67835603854706339, 
              c[ -10][ t]], 
            Times[ 0.59356153372868059, 
              c[ -9][ t]], 
            Times[ 0.50455115242710469, 
              c[ -8][ t]], 
            Times[ 0.41349667156634418, 
              c[ -7][ t]], 
            Times[ 0.32256865202152157, 
              c[ -6][ t]], 
            Times[ 0.23387232094715985, 
              c[ -5][ t]], 
            Times[ 0.14938649372796362, 
              c[ -4][ t]], 
            Times[ 0.070907514257657775, 
              c[ -3][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -2][ t]], 
            Times[ -0.062044074975450343, 
              c[ -1][ t]], 
            Times[ -0.11423673049785436, 
              c[ 0][ t]], 
            Times[ -0.15591488063143974, 
              c[ 1][ t]], 
            Times[ -0.18675027222298601, 
              c[ 2][ t]], 
            Times[ -0.206748335783172, 
              c[ 3][ t]], 
            Times[ -0.21623620818304484, 
              c[ 4][ t]], 
            Times[ -0.21584055771952015, 
              c[ 5][ t]], 
            Times[ -0.20645618564475843, 
              c[ 6][ t]], 
            Times[ -0.18920668216016426, 
              c[ 7][ t]], 
            Times[ -0.16539866862653771, 
              c[ 8][ t]], 
            Times[ -0.13647135277833605, 
              c[ 9][ t]], 
            Times[ -0.10394325375429328, 
              c[ 10][ t]], 
            Times[ -0.06935801494512607, 
              c[ 11][ t]], 
            Times[ -0.034231213779558949, 
              c[ 12][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 13][ t]], 
            Times[ 0.032022748374425904, 
              c[ 14][ t]], 
            Times[ 0.060688263076985105, 
              c[ 15][ t]], 
            Times[ 0.085044480344421705, 
              c[ 16][ t]], 
            Times[ 0.10436044624225685, 
              c[ 17][ t]], 
            Times[ 0.11814190616181255, 
              c[ 18][ t]], 
            Times[ 0.12613778810677614, 
              c[ 19][ t]], 
            Times[ 0.12833762891430928, 
              c[ 20][ t]], 
            Times[ 0.12496032289024853, 
              c[ 21][ t]], 
            Times[ 0.11643488132933186, 
              c[ 22][ t]], 
            Times[ 0.10337416789158609, 
              c[ 23][ t]], 
            Times[ 0.086542809078944891, 
              c[ 24][ t]], 
            Times[ 0.066820663127759972, 
              c[ 25][ t]], 
            Times[ 0.045163358568919301, 
              c[ 26][ t]], 
            Times[ 0.022561481809254869, 
              c[ 27][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 28][ t]], 
            Times[ -0.021580547817547879, 
              c[ 29][ t]], 
            Times[ -0.04131966847794722, 
              c[ 30][ t]], 
            Times[ -0.058468080236789913, 
              c[ 31][ t]], 
            Times[ -0.072413370861974122, 
              c[ 32][ t]], 
            Times[ -0.082699334313268744, 
              c[ 33][ t]], 
            Times[ -0.089038438663606695, 
              c[ 34][ t]], 
            Times[ -0.091317159035181589, 
              c[ 35][ t]], 
            Times[ -0.089594193770366884, 
              c[ 36][ t]], 
            Times[ -0.084091858737850814, 
              c[ 37][ t]], 
            Times[ -0.075181213012062598, 
              c[ 38][ t]], 
            Times[ -0.063361699504227528, 
              c[ 39][ t]], 
            Times[ -0.049236278094138941, 
              c[ 40][ t]], 
            Times[ -0.033483179628681706, 
              c[ 41][ t]], 
            Times[ -0.016825511857749401, 
              c[ 42][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 43][ t]], 
            Times[ 0.016273855731265469, 
              c[ 44][ t]], 
            Times[ 0.031322974491347078, 
              c[ 45][ t]], 
            Times[ 0.044547108751839919, 
              c[ 46][ t]], 
            Times[ 0.055441487066198857, 
              c[ 47][ t]], 
            Times[ 0.063614872548668253, 
              c[ 48][ t]], 
            Times[ 0.068802429876423349, 
              c[ 49][ t]], 
            Times[ 0.070873018952678238, 
              c[ 50][ t]], 
            Times[ 0.069830768673962415, 
              c[ 51][ t]], 
            Times[ 0.065811019881796273, 
              c[ 52][ t]], 
            Times[ 0.059070953080906402, 
              c[ 53][ t]], 
            Times[ 0.049975424961080865, 
              c[ 54][ t]], 
            Times[ 0.03897872015785999, 
              c[ 55][ t]], 
            Times[ 0.026603074225527937, 
              c[ 56][ t]], 
            Times[ 0.013414935129827233, 
              c[ 57][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 58][ t]], 
            Times[ -0.013061910521147276, 
              c[ 59][ t]], 
            Times[ -0.025221096343682053, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-16\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-16\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.022561481809254675`\ \(c[\(-60\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-59\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-58\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-57\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-56\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-55\)]\)[t] + 
            0.12496032289024847`\ \(c[\(-54\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-53\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-52\)]\)[t] + 
            0.1181419061618126`\ \(c[\(-51\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-50\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-49\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-48\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-47\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-46\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-45\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-44\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-43\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-42\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-41\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-40\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-39\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-38\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-37\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-36\)]\)[t] - 
            0.186750272222986`\ \(c[\(-35\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-34\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-33\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-32\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-31\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-30\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-29\)]\)[t] + 
            0.23387232094715998`\ \(c[\(-28\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-27\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-26\)]\)[t] + 
            0.5045511524271049`\ \(c[\(-25\)]\)[t] + 
            0.5935615337286803`\ \(c[\(-24\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-23\)]\)[t] + 
            0.7568267286406571`\ \(c[\(-22\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-21\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-20\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-19\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-18\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-17\)]\)[t] + 
            6.614708281508612`\ \(c[\(-16\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-15\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-14\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-13\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-12\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-11\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-10\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-9\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-8\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-7\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-6\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-5\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-4\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-3\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-2\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-1\)]\)[t] - 
            0.06204407497545034`\ \(c[0]\)[t] - 
            0.11423673049785436`\ \(c[1]\)[t] - 
            0.15591488063143982`\ \(c[2]\)[t] - 
            0.186750272222986`\ \(c[3]\)[t] - 
            0.206748335783172`\ \(c[4]\)[t] - 
            0.21623620818304484`\ \(c[5]\)[t] - 
            0.21584055771952015`\ \(c[6]\)[t] - 
            0.20645618564475843`\ \(c[7]\)[t] - 
            0.18920668216016426`\ \(c[8]\)[t] - 
            0.1653986686265377`\ \(c[9]\)[t] - 
            0.13647135277833605`\ \(c[10]\)[t] - 
            0.10394325375429328`\ \(c[11]\)[t] - 
            0.06935801494512607`\ \(c[12]\)[t] - 
            0.03423121377955895`\ \(c[13]\)[t] - 
            3.898171832519376`*^-17\ \(c[14]\)[t] + 
            0.032022748374425904`\ \(c[15]\)[t] + 
            0.060688263076985105`\ \(c[16]\)[t] + 
            0.0850444803444217`\ \(c[17]\)[t] + 
            0.10436044624225685`\ \(c[18]\)[t] + 
            0.11814190616181255`\ \(c[19]\)[t] + 
            0.12613778810677614`\ \(c[20]\)[t] + 
            0.12833762891430928`\ \(c[21]\)[t] + 
            0.12496032289024853`\ \(c[22]\)[t] + 
            0.11643488132933186`\ \(c[23]\)[t] + 
            0.10337416789158609`\ \(c[24]\)[t] + 
            0.08654280907894489`\ \(c[25]\)[t] + 
            0.06682066312775997`\ \(c[26]\)[t] + 
            0.0451633585689193`\ \(c[27]\)[t] + 
            0.02256148180925487`\ \(c[28]\)[t] + 
            3.8981718325193755`*^-17\ \(c[29]\)[t] - 
            0.02158054781754788`\ \(c[30]\)[t] - 
            0.04131966847794722`\ \(c[31]\)[t] - 
            0.05846808023678991`\ \(c[32]\)[t] - 
            0.07241337086197412`\ \(c[33]\)[t] - 
            0.08269933431326874`\ \(c[34]\)[t] - 
            0.0890384386636067`\ \(c[35]\)[t] - 
            0.09131715903518159`\ \(c[36]\)[t] - 
            0.08959419377036688`\ \(c[37]\)[t] - 
            0.08409185873785081`\ \(c[38]\)[t] - 
            0.0751812130120626`\ \(c[39]\)[t] - 
            0.06336169950422753`\ \(c[40]\)[t] - 
            0.049236278094139066`\ \(c[41]\)[t] - 
            0.03348317962868157`\ \(c[42]\)[t] - 
            0.0168255118577494`\ \(c[43]\)[t] - 
            1.8033970416801674`*^-16\ \(c[44]\)[t] + 
            0.016273855731265604`\ \(c[45]\)[t] + 
            0.03132297449134708`\ \(c[46]\)[t] + 
            0.044547108751839815`\ \(c[47]\)[t] + 
            0.05544148706619893`\ \(c[48]\)[t] + 
            0.06361487254866825`\ \(c[49]\)[t] + 
            0.06880242987642332`\ \(c[50]\)[t] + 
            0.07087301895267824`\ \(c[51]\)[t] + 
            0.06983076867396242`\ \(c[52]\)[t] + 
            0.06581101988179631`\ \(c[53]\)[t] + 
            0.059070953080906326`\ \(c[54]\)[t] + 
            0.049975424961080865`\ \(c[55]\)[t] + 
            0.03897872015786009`\ \(c[56]\)[t] + 
            0.026603074225527826`\ \(c[57]\)[t] + 
            0.013414935129827233`\ \(c[58]\)[t] + 
            1.5206810699945212`*^-16\ \(c[59]\)[t] - 
            0.013061910521147383`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -16, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -16]][ t]], 
          Plus[ 
            Times[ 0.022561481809254675, 
              c[ -60][ t]], 
            Times[ 0.045163358568919301, 
              c[ -59][ t]], 
            Times[ 0.066820663127759972, 
              c[ -58][ t]], 
            Times[ 0.086542809078944752, 
              c[ -57][ t]], 
            Times[ 0.10337416789158609, 
              c[ -56][ t]], 
            Times[ 0.11643488132933186, 
              c[ -55][ t]], 
            Times[ 0.12496032289024847, 
              c[ -54][ t]], 
            Times[ 0.12833762891430928, 
              c[ -53][ t]], 
            Times[ 0.12613778810677614, 
              c[ -52][ t]], 
            Times[ 0.1181419061618126, 
              c[ -51][ t]], 
            Times[ 0.10436044624225685, 
              c[ -50][ t]], 
            Times[ 0.085044480344421705, 
              c[ -49][ t]], 
            Times[ 0.060688263076985223, 
              c[ -48][ t]], 
            Times[ 0.032022748374425904, 
              c[ -47][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -46][ t]], 
            Times[ -0.034231213779558796, 
              c[ -45][ t]], 
            Times[ -0.06935801494512607, 
              c[ -44][ t]], 
            Times[ -0.10394325375429328, 
              c[ -43][ t]], 
            Times[ -0.13647135277833591, 
              c[ -42][ t]], 
            Times[ -0.16539866862653771, 
              c[ -41][ t]], 
            Times[ -0.18920668216016426, 
              c[ -40][ t]], 
            Times[ -0.20645618564475834, 
              c[ -39][ t]], 
            Times[ -0.21584055771952015, 
              c[ -38][ t]], 
            Times[ -0.21623620818304484, 
              c[ -37][ t]], 
            Times[ -0.20674833578317206, 
              c[ -36][ t]], 
            Times[ -0.18675027222298601, 
              c[ -35][ t]], 
            Times[ -0.15591488063143974, 
              c[ -34][ t]], 
            Times[ -0.11423673049785445, 
              c[ -33][ t]], 
            Times[ -0.062044074975450343, 
              c[ -32][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -31][ t]], 
            Times[ 0.070907514257657622, 
              c[ -30][ t]], 
            Times[ 0.14938649372796362, 
              c[ -29][ t]], 
            Times[ 0.23387232094715998, 
              c[ -28][ t]], 
            Times[ 0.32256865202152135, 
              c[ -27][ t]], 
            Times[ 0.41349667156634418, 
              c[ -26][ t]], 
            Times[ 0.50455115242710491, 
              c[ -25][ t]], 
            Times[ 0.59356153372868026, 
              c[ -24][ t]], 
            Times[ 0.67835603854706339, 
              c[ -23][ t]], 
            Times[ 0.75682672864065714, 
              c[ -22][ t]], 
            Times[ 0.82699334313268813, 
              c[ -21][ t]], 
            Times[ 0.88706379305918381, 
              c[ -20][ t]], 
            Times[ 0.93548928378863916, 
              c[ -19][ t]], 
            Times[ 0.9710122092317629, 
              c[ -18][ t]], 
            Times[ 0.99270519960720693, 
              c[ -17][ t]], 
            Times[ 6.6147082815086122, 
              c[ -16][ t]], 
            Times[ 0.99270519960720693, 
              c[ -15][ t]], 
            Times[ 0.9710122092317629, 
              c[ -14][ t]], 
            Times[ 0.93548928378863916, 
              c[ -13][ t]], 
            Times[ 0.88706379305918381, 
              c[ -12][ t]], 
            Times[ 0.82699334313268813, 
              c[ -11][ t]], 
            Times[ 0.75682672864065692, 
              c[ -10][ t]], 
            Times[ 0.67835603854706339, 
              c[ -9][ t]], 
            Times[ 0.59356153372868048, 
              c[ -8][ t]], 
            Times[ 0.50455115242710469, 
              c[ -7][ t]], 
            Times[ 0.41349667156634418, 
              c[ -6][ t]], 
            Times[ 0.32256865202152157, 
              c[ -5][ t]], 
            Times[ 0.23387232094715985, 
              c[ -4][ t]], 
            Times[ 0.14938649372796362, 
              c[ -3][ t]], 
            Times[ 0.070907514257657775, 
              c[ -2][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -1][ t]], 
            Times[ -0.062044074975450343, 
              c[ 0][ t]], 
            Times[ -0.11423673049785436, 
              c[ 1][ t]], 
            Times[ -0.15591488063143982, 
              c[ 2][ t]], 
            Times[ -0.18675027222298601, 
              c[ 3][ t]], 
            Times[ -0.206748335783172, 
              c[ 4][ t]], 
            Times[ -0.21623620818304484, 
              c[ 5][ t]], 
            Times[ -0.21584055771952015, 
              c[ 6][ t]], 
            Times[ -0.20645618564475843, 
              c[ 7][ t]], 
            Times[ -0.18920668216016426, 
              c[ 8][ t]], 
            Times[ -0.16539866862653771, 
              c[ 9][ t]], 
            Times[ -0.13647135277833605, 
              c[ 10][ t]], 
            Times[ -0.10394325375429328, 
              c[ 11][ t]], 
            Times[ -0.06935801494512607, 
              c[ 12][ t]], 
            Times[ -0.034231213779558949, 
              c[ 13][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 14][ t]], 
            Times[ 0.032022748374425904, 
              c[ 15][ t]], 
            Times[ 0.060688263076985105, 
              c[ 16][ t]], 
            Times[ 0.085044480344421705, 
              c[ 17][ t]], 
            Times[ 0.10436044624225685, 
              c[ 18][ t]], 
            Times[ 0.11814190616181255, 
              c[ 19][ t]], 
            Times[ 0.12613778810677614, 
              c[ 20][ t]], 
            Times[ 0.12833762891430928, 
              c[ 21][ t]], 
            Times[ 0.12496032289024853, 
              c[ 22][ t]], 
            Times[ 0.11643488132933186, 
              c[ 23][ t]], 
            Times[ 0.10337416789158609, 
              c[ 24][ t]], 
            Times[ 0.086542809078944891, 
              c[ 25][ t]], 
            Times[ 0.066820663127759972, 
              c[ 26][ t]], 
            Times[ 0.045163358568919301, 
              c[ 27][ t]], 
            Times[ 0.022561481809254869, 
              c[ 28][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 29][ t]], 
            Times[ -0.021580547817547879, 
              c[ 30][ t]], 
            Times[ -0.04131966847794722, 
              c[ 31][ t]], 
            Times[ -0.058468080236789913, 
              c[ 32][ t]], 
            Times[ -0.072413370861974122, 
              c[ 33][ t]], 
            Times[ -0.082699334313268744, 
              c[ 34][ t]], 
            Times[ -0.089038438663606695, 
              c[ 35][ t]], 
            Times[ -0.091317159035181589, 
              c[ 36][ t]], 
            Times[ -0.089594193770366884, 
              c[ 37][ t]], 
            Times[ -0.084091858737850814, 
              c[ 38][ t]], 
            Times[ -0.075181213012062598, 
              c[ 39][ t]], 
            Times[ -0.063361699504227528, 
              c[ 40][ t]], 
            Times[ -0.049236278094139066, 
              c[ 41][ t]], 
            Times[ -0.033483179628681567, 
              c[ 42][ t]], 
            Times[ -0.016825511857749401, 
              c[ 43][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 44][ t]], 
            Times[ 0.016273855731265604, 
              c[ 45][ t]], 
            Times[ 0.031322974491347078, 
              c[ 46][ t]], 
            Times[ 0.044547108751839815, 
              c[ 47][ t]], 
            Times[ 0.055441487066198933, 
              c[ 48][ t]], 
            Times[ 0.063614872548668253, 
              c[ 49][ t]], 
            Times[ 0.068802429876423321, 
              c[ 50][ t]], 
            Times[ 0.070873018952678238, 
              c[ 51][ t]], 
            Times[ 0.069830768673962415, 
              c[ 52][ t]], 
            Times[ 0.065811019881796315, 
              c[ 53][ t]], 
            Times[ 0.059070953080906326, 
              c[ 54][ t]], 
            Times[ 0.049975424961080865, 
              c[ 55][ t]], 
            Times[ 0.038978720157860088, 
              c[ 56][ t]], 
            Times[ 0.026603074225527826, 
              c[ 57][ t]], 
            Times[ 0.013414935129827233, 
              c[ 58][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ 59][ t]], 
            Times[ -0.013061910521147383, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-15\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-15\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(3.8981718325193755`*^-17\ \(c[\(-60\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-59\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-58\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-57\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-56\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-55\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-54\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-53\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-52\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-51\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-50\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-49\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-48\)]\)[t] + 
            0.060688263076985`\ \(c[\(-47\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-46\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-45\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-44\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-43\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-42\)]\)[t] - 
            0.13647135277833616`\ \(c[\(-41\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-40\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-39\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-38\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-37\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-36\)]\)[t] - 
            0.206748335783172`\ \(c[\(-35\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-34\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-33\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-32\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-31\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-30\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-29\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-28\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-27\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-26\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-25\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-24\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-23\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-22\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-21\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-20\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-19\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-18\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-17\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-16\)]\)[t] + 
            5.934802200544679`\ \(c[\(-15\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-14\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-13\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-12\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-11\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-10\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-9\)]\)[t] + 
            0.6783560385470633`\ \(c[\(-8\)]\)[t] + 
            0.5935615337286803`\ \(c[\(-7\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-6\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-5\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-4\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-3\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-2\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-1\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[0]\)[t] - 
            0.06204407497545034`\ \(c[1]\)[t] - 
            0.11423673049785445`\ \(c[2]\)[t] - 
            0.15591488063143982`\ \(c[3]\)[t] - 
            0.186750272222986`\ \(c[4]\)[t] - 
            0.206748335783172`\ \(c[5]\)[t] - 
            0.21623620818304484`\ \(c[6]\)[t] - 
            0.21584055771952015`\ \(c[7]\)[t] - 
            0.20645618564475843`\ \(c[8]\)[t] - 
            0.18920668216016426`\ \(c[9]\)[t] - 
            0.1653986686265377`\ \(c[10]\)[t] - 
            0.13647135277833605`\ \(c[11]\)[t] - 
            0.10394325375429328`\ \(c[12]\)[t] - 
            0.06935801494512607`\ \(c[13]\)[t] - 
            0.03423121377955895`\ \(c[14]\)[t] - 
            3.898171832519376`*^-17\ \(c[15]\)[t] + 
            0.032022748374425904`\ \(c[16]\)[t] + 
            0.060688263076985105`\ \(c[17]\)[t] + 
            0.0850444803444217`\ \(c[18]\)[t] + 
            0.10436044624225685`\ \(c[19]\)[t] + 
            0.11814190616181255`\ \(c[20]\)[t] + 
            0.12613778810677614`\ \(c[21]\)[t] + 
            0.12833762891430928`\ \(c[22]\)[t] + 
            0.12496032289024853`\ \(c[23]\)[t] + 
            0.11643488132933186`\ \(c[24]\)[t] + 
            0.10337416789158609`\ \(c[25]\)[t] + 
            0.08654280907894489`\ \(c[26]\)[t] + 
            0.06682066312775997`\ \(c[27]\)[t] + 
            0.0451633585689193`\ \(c[28]\)[t] + 
            0.02256148180925487`\ \(c[29]\)[t] + 
            3.8981718325193755`*^-17\ \(c[30]\)[t] - 
            0.02158054781754788`\ \(c[31]\)[t] - 
            0.04131966847794722`\ \(c[32]\)[t] - 
            0.05846808023678991`\ \(c[33]\)[t] - 
            0.07241337086197412`\ \(c[34]\)[t] - 
            0.08269933431326874`\ \(c[35]\)[t] - 
            0.0890384386636067`\ \(c[36]\)[t] - 
            0.09131715903518159`\ \(c[37]\)[t] - 
            0.08959419377036688`\ \(c[38]\)[t] - 
            0.08409185873785081`\ \(c[39]\)[t] - 
            0.0751812130120626`\ \(c[40]\)[t] - 
            0.06336169950422753`\ \(c[41]\)[t] - 
            0.04923627809413894`\ \(c[42]\)[t] - 
            0.03348317962868157`\ \(c[43]\)[t] - 
            0.0168255118577494`\ \(c[44]\)[t] - 
            3.898171832519376`*^-17\ \(c[45]\)[t] + 
            0.016273855731265604`\ \(c[46]\)[t] + 
            0.03132297449134708`\ \(c[47]\)[t] + 
            0.04454710875183992`\ \(c[48]\)[t] + 
            0.05544148706619893`\ \(c[49]\)[t] + 
            0.06361487254866825`\ \(c[50]\)[t] + 
            0.06880242987642335`\ \(c[51]\)[t] + 
            0.07087301895267824`\ \(c[52]\)[t] + 
            0.06983076867396242`\ \(c[53]\)[t] + 
            0.06581101988179627`\ \(c[54]\)[t] + 
            0.059070953080906326`\ \(c[55]\)[t] + 
            0.049975424961080865`\ \(c[56]\)[t] + 
            0.03897872015785999`\ \(c[57]\)[t] + 
            0.026603074225527826`\ \(c[58]\)[t] + 
            0.013414935129827233`\ \(c[59]\)[t] + 
            3.898171832519376`*^-17\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -15, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -15]][ t]], 
          Plus[ 
            Times[ 3.8981718325193755*^-17, 
              c[ -60][ t]], 
            Times[ 0.022561481809254869, 
              c[ -59][ t]], 
            Times[ 0.045163358568919301, 
              c[ -58][ t]], 
            Times[ 0.066820663127759972, 
              c[ -57][ t]], 
            Times[ 0.086542809078944891, 
              c[ -56][ t]], 
            Times[ 0.10337416789158609, 
              c[ -55][ t]], 
            Times[ 0.11643488132933186, 
              c[ -54][ t]], 
            Times[ 0.12496032289024853, 
              c[ -53][ t]], 
            Times[ 0.12833762891430928, 
              c[ -52][ t]], 
            Times[ 0.12613778810677614, 
              c[ -51][ t]], 
            Times[ 0.11814190616181253, 
              c[ -50][ t]], 
            Times[ 0.10436044624225685, 
              c[ -49][ t]], 
            Times[ 0.085044480344421705, 
              c[ -48][ t]], 
            Times[ 0.060688263076985001, 
              c[ -47][ t]], 
            Times[ 0.032022748374425904, 
              c[ -46][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -45][ t]], 
            Times[ -0.034231213779559094, 
              c[ -44][ t]], 
            Times[ -0.06935801494512607, 
              c[ -43][ t]], 
            Times[ -0.10394325375429328, 
              c[ -42][ t]], 
            Times[ -0.13647135277833616, 
              c[ -41][ t]], 
            Times[ -0.16539866862653771, 
              c[ -40][ t]], 
            Times[ -0.18920668216016426, 
              c[ -39][ t]], 
            Times[ -0.20645618564475843, 
              c[ -38][ t]], 
            Times[ -0.21584055771952015, 
              c[ -37][ t]], 
            Times[ -0.21623620818304484, 
              c[ -36][ t]], 
            Times[ -0.206748335783172, 
              c[ -35][ t]], 
            Times[ -0.18675027222298593, 
              c[ -34][ t]], 
            Times[ -0.15591488063143982, 
              c[ -33][ t]], 
            Times[ -0.11423673049785436, 
              c[ -32][ t]], 
            Times[ -0.062044074975450239, 
              c[ -31][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -30][ t]], 
            Times[ 0.070907514257657775, 
              c[ -29][ t]], 
            Times[ 0.14938649372796384, 
              c[ -28][ t]], 
            Times[ 0.23387232094715985, 
              c[ -27][ t]], 
            Times[ 0.32256865202152157, 
              c[ -26][ t]], 
            Times[ 0.41349667156634429, 
              c[ -25][ t]], 
            Times[ 0.50455115242710469, 
              c[ -24][ t]], 
            Times[ 0.59356153372868059, 
              c[ -23][ t]], 
            Times[ 0.67835603854706361, 
              c[ -22][ t]], 
            Times[ 0.75682672864065692, 
              c[ -21][ t]], 
            Times[ 0.82699334313268813, 
              c[ -20][ t]], 
            Times[ 0.88706379305918381, 
              c[ -19][ t]], 
            Times[ 0.93548928378863916, 
              c[ -18][ t]], 
            Times[ 0.9710122092317629, 
              c[ -17][ t]], 
            Times[ 0.99270519960720693, 
              c[ -16][ t]], 
            Times[ 5.934802200544679, 
              c[ -15][ t]], 
            Times[ 0.99270519960720671, 
              c[ -14][ t]], 
            Times[ 0.9710122092317629, 
              c[ -13][ t]], 
            Times[ 0.93548928378863916, 
              c[ -12][ t]], 
            Times[ 0.88706379305918381, 
              c[ -11][ t]], 
            Times[ 0.82699334313268813, 
              c[ -10][ t]], 
            Times[ 0.75682672864065692, 
              c[ -9][ t]], 
            Times[ 0.67835603854706328, 
              c[ -8][ t]], 
            Times[ 0.59356153372868026, 
              c[ -7][ t]], 
            Times[ 0.50455115242710469, 
              c[ -6][ t]], 
            Times[ 0.41349667156634395, 
              c[ -5][ t]], 
            Times[ 0.32256865202152135, 
              c[ -4][ t]], 
            Times[ 0.23387232094715985, 
              c[ -3][ t]], 
            Times[ 0.14938649372796362, 
              c[ -2][ t]], 
            Times[ 0.070907514257657622, 
              c[ -1][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 0][ t]], 
            Times[ -0.062044074975450343, 
              c[ 1][ t]], 
            Times[ -0.11423673049785445, 
              c[ 2][ t]], 
            Times[ -0.15591488063143982, 
              c[ 3][ t]], 
            Times[ -0.18675027222298601, 
              c[ 4][ t]], 
            Times[ -0.206748335783172, 
              c[ 5][ t]], 
            Times[ -0.21623620818304484, 
              c[ 6][ t]], 
            Times[ -0.21584055771952015, 
              c[ 7][ t]], 
            Times[ -0.20645618564475843, 
              c[ 8][ t]], 
            Times[ -0.18920668216016426, 
              c[ 9][ t]], 
            Times[ -0.16539866862653771, 
              c[ 10][ t]], 
            Times[ -0.13647135277833605, 
              c[ 11][ t]], 
            Times[ -0.10394325375429328, 
              c[ 12][ t]], 
            Times[ -0.06935801494512607, 
              c[ 13][ t]], 
            Times[ -0.034231213779558949, 
              c[ 14][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 15][ t]], 
            Times[ 0.032022748374425904, 
              c[ 16][ t]], 
            Times[ 0.060688263076985105, 
              c[ 17][ t]], 
            Times[ 0.085044480344421705, 
              c[ 18][ t]], 
            Times[ 0.10436044624225685, 
              c[ 19][ t]], 
            Times[ 0.11814190616181255, 
              c[ 20][ t]], 
            Times[ 0.12613778810677614, 
              c[ 21][ t]], 
            Times[ 0.12833762891430928, 
              c[ 22][ t]], 
            Times[ 0.12496032289024853, 
              c[ 23][ t]], 
            Times[ 0.11643488132933186, 
              c[ 24][ t]], 
            Times[ 0.10337416789158609, 
              c[ 25][ t]], 
            Times[ 0.086542809078944891, 
              c[ 26][ t]], 
            Times[ 0.066820663127759972, 
              c[ 27][ t]], 
            Times[ 0.045163358568919301, 
              c[ 28][ t]], 
            Times[ 0.022561481809254869, 
              c[ 29][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 30][ t]], 
            Times[ -0.021580547817547879, 
              c[ 31][ t]], 
            Times[ -0.04131966847794722, 
              c[ 32][ t]], 
            Times[ -0.058468080236789913, 
              c[ 33][ t]], 
            Times[ -0.072413370861974122, 
              c[ 34][ t]], 
            Times[ -0.082699334313268744, 
              c[ 35][ t]], 
            Times[ -0.089038438663606695, 
              c[ 36][ t]], 
            Times[ -0.091317159035181589, 
              c[ 37][ t]], 
            Times[ -0.089594193770366884, 
              c[ 38][ t]], 
            Times[ -0.084091858737850814, 
              c[ 39][ t]], 
            Times[ -0.075181213012062598, 
              c[ 40][ t]], 
            Times[ -0.063361699504227528, 
              c[ 41][ t]], 
            Times[ -0.049236278094138941, 
              c[ 42][ t]], 
            Times[ -0.033483179628681567, 
              c[ 43][ t]], 
            Times[ -0.016825511857749401, 
              c[ 44][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 45][ t]], 
            Times[ 0.016273855731265604, 
              c[ 46][ t]], 
            Times[ 0.031322974491347078, 
              c[ 47][ t]], 
            Times[ 0.044547108751839919, 
              c[ 48][ t]], 
            Times[ 0.055441487066198933, 
              c[ 49][ t]], 
            Times[ 0.063614872548668253, 
              c[ 50][ t]], 
            Times[ 0.068802429876423349, 
              c[ 51][ t]], 
            Times[ 0.070873018952678238, 
              c[ 52][ t]], 
            Times[ 0.069830768673962415, 
              c[ 53][ t]], 
            Times[ 0.065811019881796273, 
              c[ 54][ t]], 
            Times[ 0.059070953080906326, 
              c[ 55][ t]], 
            Times[ 0.049975424961080865, 
              c[ 56][ t]], 
            Times[ 0.03897872015785999, 
              c[ 57][ t]], 
            Times[ 0.026603074225527826, 
              c[ 58][ t]], 
            Times[ 0.013414935129827233, 
              c[ 59][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-14\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-14\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.021580547817548056`\)\ \(c[\(-60\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-59\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-58\)]\)[t] + 
            0.045163358568919114`\ \(c[\(-57\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-56\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-55\)]\)[t] + 
            0.10337416789158595`\ \(c[\(-54\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-53\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-52\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-51\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-50\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-49\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-48\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-47\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-46\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-45\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-44\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-43\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-42\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-41\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-40\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-39\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-38\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-37\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-36\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-35\)]\)[t] - 
            0.206748335783172`\ \(c[\(-34\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-33\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-32\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-31\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-30\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-29\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-28\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-27\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-26\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-25\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-24\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-23\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-22\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-21\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-20\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-19\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-18\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-17\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-16\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-15\)]\)[t] + 
            5.298761028030031`\ \(c[\(-14\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-13\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-12\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-11\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-10\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-9\)]\)[t] + 
            0.756826728640657`\ \(c[\(-8\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-7\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-6\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-5\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-4\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-3\)]\)[t] + 
            0.23387232094715998`\ \(c[\(-2\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-1\)]\)[t] + 
            0.07090751425765777`\ \(c[0]\)[t] + 
            1.8033970416801674`*^-16\ \(c[1]\)[t] - 
            0.06204407497545034`\ \(c[2]\)[t] - 
            0.11423673049785436`\ \(c[3]\)[t] - 
            0.15591488063143974`\ \(c[4]\)[t] - 
            0.18675027222298593`\ \(c[5]\)[t] - 
            0.206748335783172`\ \(c[6]\)[t] - 
            0.21623620818304484`\ \(c[7]\)[t] - 
            0.21584055771952015`\ \(c[8]\)[t] - 
            0.20645618564475843`\ \(c[9]\)[t] - 
            0.18920668216016426`\ \(c[10]\)[t] - 
            0.1653986686265377`\ \(c[11]\)[t] - 
            0.13647135277833605`\ \(c[12]\)[t] - 
            0.10394325375429328`\ \(c[13]\)[t] - 
            0.06935801494512607`\ \(c[14]\)[t] - 
            0.03423121377955895`\ \(c[15]\)[t] - 
            3.898171832519376`*^-17\ \(c[16]\)[t] + 
            0.032022748374425904`\ \(c[17]\)[t] + 
            0.060688263076985105`\ \(c[18]\)[t] + 
            0.0850444803444217`\ \(c[19]\)[t] + 
            0.10436044624225685`\ \(c[20]\)[t] + 
            0.11814190616181255`\ \(c[21]\)[t] + 
            0.12613778810677612`\ \(c[22]\)[t] + 
            0.12833762891430928`\ \(c[23]\)[t] + 
            0.12496032289024853`\ \(c[24]\)[t] + 
            0.11643488132933186`\ \(c[25]\)[t] + 
            0.10337416789158609`\ \(c[26]\)[t] + 
            0.08654280907894489`\ \(c[27]\)[t] + 
            0.06682066312775997`\ \(c[28]\)[t] + 
            0.0451633585689193`\ \(c[29]\)[t] + 
            0.02256148180925487`\ \(c[30]\)[t] + 
            3.8981718325193755`*^-17\ \(c[31]\)[t] - 
            0.02158054781754788`\ \(c[32]\)[t] - 
            0.04131966847794722`\ \(c[33]\)[t] - 
            0.05846808023678991`\ \(c[34]\)[t] - 
            0.07241337086197412`\ \(c[35]\)[t] - 
            0.08269933431326874`\ \(c[36]\)[t] - 
            0.0890384386636067`\ \(c[37]\)[t] - 
            0.09131715903518159`\ \(c[38]\)[t] - 
            0.08959419377036688`\ \(c[39]\)[t] - 
            0.08409185873785081`\ \(c[40]\)[t] - 
            0.0751812130120627`\ \(c[41]\)[t] - 
            0.06336169950422753`\ \(c[42]\)[t] - 
            0.04923627809413894`\ \(c[43]\)[t] - 
            0.033483179628681706`\ \(c[44]\)[t] - 
            0.0168255118577494`\ \(c[45]\)[t] - 
            3.898171832519376`*^-17\ \(c[46]\)[t] + 
            0.01627385573126547`\ \(c[47]\)[t] + 
            0.03132297449134708`\ \(c[48]\)[t] + 
            0.04454710875183992`\ \(c[49]\)[t] + 
            0.055441487066198857`\ \(c[50]\)[t] + 
            0.06361487254866825`\ \(c[51]\)[t] + 
            0.06880242987642335`\ \(c[52]\)[t] + 
            0.07087301895267824`\ \(c[53]\)[t] + 
            0.06983076867396242`\ \(c[54]\)[t] + 
            0.06581101988179627`\ \(c[55]\)[t] + 
            0.0590709530809064`\ \(c[56]\)[t] + 
            0.049975424961080865`\ \(c[57]\)[t] + 
            0.03897872015785999`\ \(c[58]\)[t] + 
            0.026603074225527937`\ \(c[59]\)[t] + 
            0.013414935129827233`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -14, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -14]][ t]], 
          Plus[ 
            Times[ -0.021580547817548056, 
              c[ -60][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -59][ t]], 
            Times[ 0.022561481809254869, 
              c[ -58][ t]], 
            Times[ 0.045163358568919114, 
              c[ -57][ t]], 
            Times[ 0.066820663127759972, 
              c[ -56][ t]], 
            Times[ 0.086542809078944891, 
              c[ -55][ t]], 
            Times[ 0.10337416789158595, 
              c[ -54][ t]], 
            Times[ 0.11643488132933186, 
              c[ -53][ t]], 
            Times[ 0.12496032289024853, 
              c[ -52][ t]], 
            Times[ 0.12833762891430925, 
              c[ -51][ t]], 
            Times[ 0.12613778810677612, 
              c[ -50][ t]], 
            Times[ 0.11814190616181255, 
              c[ -49][ t]], 
            Times[ 0.10436044624225692, 
              c[ -48][ t]], 
            Times[ 0.085044480344421608, 
              c[ -47][ t]], 
            Times[ 0.060688263076985105, 
              c[ -46][ t]], 
            Times[ 0.032022748374426029, 
              c[ -45][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -44][ t]], 
            Times[ -0.034231213779558949, 
              c[ -43][ t]], 
            Times[ -0.069358014945125918, 
              c[ -42][ t]], 
            Times[ -0.1039432537542934, 
              c[ -41][ t]], 
            Times[ -0.13647135277833605, 
              c[ -40][ t]], 
            Times[ -0.1653986686265376, 
              c[ -39][ t]], 
            Times[ -0.18920668216016426, 
              c[ -38][ t]], 
            Times[ -0.20645618564475843, 
              c[ -37][ t]], 
            Times[ -0.21584055771952013, 
              c[ -36][ t]], 
            Times[ -0.21623620818304484, 
              c[ -35][ t]], 
            Times[ -0.206748335783172, 
              c[ -34][ t]], 
            Times[ -0.18675027222298607, 
              c[ -33][ t]], 
            Times[ -0.15591488063143982, 
              c[ -32][ t]], 
            Times[ -0.11423673049785436, 
              c[ -31][ t]], 
            Times[ -0.062044074975450475, 
              c[ -30][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -29][ t]], 
            Times[ 0.070907514257657775, 
              c[ -28][ t]], 
            Times[ 0.14938649372796345, 
              c[ -27][ t]], 
            Times[ 0.23387232094715985, 
              c[ -26][ t]], 
            Times[ 0.32256865202152157, 
              c[ -25][ t]], 
            Times[ 0.41349667156634395, 
              c[ -24][ t]], 
            Times[ 0.50455115242710469, 
              c[ -23][ t]], 
            Times[ 0.59356153372868059, 
              c[ -22][ t]], 
            Times[ 0.67835603854706317, 
              c[ -21][ t]], 
            Times[ 0.75682672864065692, 
              c[ -20][ t]], 
            Times[ 0.82699334313268813, 
              c[ -19][ t]], 
            Times[ 0.88706379305918381, 
              c[ -18][ t]], 
            Times[ 0.93548928378863916, 
              c[ -17][ t]], 
            Times[ 0.9710122092317629, 
              c[ -16][ t]], 
            Times[ 0.99270519960720671, 
              c[ -15][ t]], 
            Times[ 5.2987610280300306, 
              c[ -14][ t]], 
            Times[ 0.99270519960720693, 
              c[ -13][ t]], 
            Times[ 0.9710122092317629, 
              c[ -12][ t]], 
            Times[ 0.93548928378863916, 
              c[ -11][ t]], 
            Times[ 0.88706379305918381, 
              c[ -10][ t]], 
            Times[ 0.82699334313268813, 
              c[ -9][ t]], 
            Times[ 0.75682672864065703, 
              c[ -8][ t]], 
            Times[ 0.67835603854706339, 
              c[ -7][ t]], 
            Times[ 0.59356153372868059, 
              c[ -6][ t]], 
            Times[ 0.50455115242710469, 
              c[ -5][ t]], 
            Times[ 0.41349667156634418, 
              c[ -4][ t]], 
            Times[ 0.32256865202152157, 
              c[ -3][ t]], 
            Times[ 0.23387232094715998, 
              c[ -2][ t]], 
            Times[ 0.14938649372796362, 
              c[ -1][ t]], 
            Times[ 0.070907514257657775, 
              c[ 0][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 1][ t]], 
            Times[ -0.062044074975450343, 
              c[ 2][ t]], 
            Times[ -0.11423673049785436, 
              c[ 3][ t]], 
            Times[ -0.15591488063143974, 
              c[ 4][ t]], 
            Times[ -0.18675027222298593, 
              c[ 5][ t]], 
            Times[ -0.206748335783172, 
              c[ 6][ t]], 
            Times[ -0.21623620818304484, 
              c[ 7][ t]], 
            Times[ -0.21584055771952015, 
              c[ 8][ t]], 
            Times[ -0.20645618564475843, 
              c[ 9][ t]], 
            Times[ -0.18920668216016426, 
              c[ 10][ t]], 
            Times[ -0.16539866862653771, 
              c[ 11][ t]], 
            Times[ -0.13647135277833605, 
              c[ 12][ t]], 
            Times[ -0.10394325375429328, 
              c[ 13][ t]], 
            Times[ -0.06935801494512607, 
              c[ 14][ t]], 
            Times[ -0.034231213779558949, 
              c[ 15][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 16][ t]], 
            Times[ 0.032022748374425904, 
              c[ 17][ t]], 
            Times[ 0.060688263076985105, 
              c[ 18][ t]], 
            Times[ 0.085044480344421705, 
              c[ 19][ t]], 
            Times[ 0.10436044624225685, 
              c[ 20][ t]], 
            Times[ 0.11814190616181255, 
              c[ 21][ t]], 
            Times[ 0.12613778810677612, 
              c[ 22][ t]], 
            Times[ 0.12833762891430928, 
              c[ 23][ t]], 
            Times[ 0.12496032289024853, 
              c[ 24][ t]], 
            Times[ 0.11643488132933186, 
              c[ 25][ t]], 
            Times[ 0.10337416789158609, 
              c[ 26][ t]], 
            Times[ 0.086542809078944891, 
              c[ 27][ t]], 
            Times[ 0.066820663127759972, 
              c[ 28][ t]], 
            Times[ 0.045163358568919301, 
              c[ 29][ t]], 
            Times[ 0.022561481809254869, 
              c[ 30][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 31][ t]], 
            Times[ -0.021580547817547879, 
              c[ 32][ t]], 
            Times[ -0.04131966847794722, 
              c[ 33][ t]], 
            Times[ -0.058468080236789913, 
              c[ 34][ t]], 
            Times[ -0.072413370861974122, 
              c[ 35][ t]], 
            Times[ -0.082699334313268744, 
              c[ 36][ t]], 
            Times[ -0.089038438663606695, 
              c[ 37][ t]], 
            Times[ -0.091317159035181589, 
              c[ 38][ t]], 
            Times[ -0.089594193770366884, 
              c[ 39][ t]], 
            Times[ -0.084091858737850814, 
              c[ 40][ t]], 
            Times[ -0.075181213012062695, 
              c[ 41][ t]], 
            Times[ -0.063361699504227528, 
              c[ 42][ t]], 
            Times[ -0.049236278094138941, 
              c[ 43][ t]], 
            Times[ -0.033483179628681706, 
              c[ 44][ t]], 
            Times[ -0.016825511857749401, 
              c[ 45][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 46][ t]], 
            Times[ 0.016273855731265469, 
              c[ 47][ t]], 
            Times[ 0.031322974491347078, 
              c[ 48][ t]], 
            Times[ 0.044547108751839919, 
              c[ 49][ t]], 
            Times[ 0.055441487066198857, 
              c[ 50][ t]], 
            Times[ 0.063614872548668253, 
              c[ 51][ t]], 
            Times[ 0.068802429876423349, 
              c[ 52][ t]], 
            Times[ 0.070873018952678238, 
              c[ 53][ t]], 
            Times[ 0.069830768673962415, 
              c[ 54][ t]], 
            Times[ 0.065811019881796273, 
              c[ 55][ t]], 
            Times[ 0.059070953080906402, 
              c[ 56][ t]], 
            Times[ 0.049975424961080865, 
              c[ 57][ t]], 
            Times[ 0.03897872015785999, 
              c[ 58][ t]], 
            Times[ 0.026603074225527937, 
              c[ 59][ t]], 
            Times[ 0.013414935129827233, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-13\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-13\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.04131966847794737`\)\ \(c[\(-60\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-59\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-58\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-57\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-56\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-55\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-54\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-53\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-52\)]\)[t] + 
            0.12496032289024847`\ \(c[\(-51\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-50\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-49\)]\)[t] + 
            0.1181419061618126`\ \(c[\(-48\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-47\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-46\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-45\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-44\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-43\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-42\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-41\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-40\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-39\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-38\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-37\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-36\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-35\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-34\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-33\)]\)[t] - 
            0.186750272222986`\ \(c[\(-32\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-31\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-30\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-29\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-28\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-27\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-26\)]\)[t] + 
            0.23387232094715998`\ \(c[\(-25\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-24\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-23\)]\)[t] + 
            0.5045511524271049`\ \(c[\(-22\)]\)[t] + 
            0.5935615337286803`\ \(c[\(-21\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-20\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-19\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-18\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-17\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-16\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-15\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-14\)]\)[t] + 
            4.70658476396467`\ \(c[\(-13\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-12\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-11\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-10\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-9\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-8\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-7\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-6\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-5\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-4\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-3\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-2\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-1\)]\)[t] + 
            0.14938649372796362`\ \(c[0]\)[t] + 
            0.07090751425765777`\ \(c[1]\)[t] + 
            3.898171832519376`*^-17\ \(c[2]\)[t] - 
            0.06204407497545034`\ \(c[3]\)[t] - 
            0.11423673049785436`\ \(c[4]\)[t] - 
            0.15591488063143982`\ \(c[5]\)[t] - 
            0.186750272222986`\ \(c[6]\)[t] - 
            0.206748335783172`\ \(c[7]\)[t] - 
            0.21623620818304484`\ \(c[8]\)[t] - 
            0.21584055771952015`\ \(c[9]\)[t] - 
            0.20645618564475843`\ \(c[10]\)[t] - 
            0.18920668216016426`\ \(c[11]\)[t] - 
            0.1653986686265377`\ \(c[12]\)[t] - 
            0.13647135277833605`\ \(c[13]\)[t] - 
            0.10394325375429328`\ \(c[14]\)[t] - 
            0.06935801494512607`\ \(c[15]\)[t] - 
            0.03423121377955895`\ \(c[16]\)[t] - 
            3.898171832519376`*^-17\ \(c[17]\)[t] + 
            0.032022748374425904`\ \(c[18]\)[t] + 
            0.060688263076985105`\ \(c[19]\)[t] + 
            0.0850444803444217`\ \(c[20]\)[t] + 
            0.10436044624225685`\ \(c[21]\)[t] + 
            0.11814190616181253`\ \(c[22]\)[t] + 
            0.12613778810677614`\ \(c[23]\)[t] + 
            0.12833762891430928`\ \(c[24]\)[t] + 
            0.12496032289024853`\ \(c[25]\)[t] + 
            0.11643488132933186`\ \(c[26]\)[t] + 
            0.10337416789158609`\ \(c[27]\)[t] + 
            0.08654280907894489`\ \(c[28]\)[t] + 
            0.06682066312775997`\ \(c[29]\)[t] + 
            0.0451633585689193`\ \(c[30]\)[t] + 
            0.02256148180925487`\ \(c[31]\)[t] + 
            3.8981718325193755`*^-17\ \(c[32]\)[t] - 
            0.02158054781754788`\ \(c[33]\)[t] - 
            0.04131966847794722`\ \(c[34]\)[t] - 
            0.05846808023678991`\ \(c[35]\)[t] - 
            0.07241337086197412`\ \(c[36]\)[t] - 
            0.08269933431326874`\ \(c[37]\)[t] - 
            0.0890384386636067`\ \(c[38]\)[t] - 
            0.09131715903518159`\ \(c[39]\)[t] - 
            0.08959419377036688`\ \(c[40]\)[t] - 
            0.08409185873785086`\ \(c[41]\)[t] - 
            0.0751812130120626`\ \(c[42]\)[t] - 
            0.06336169950422753`\ \(c[43]\)[t] - 
            0.049236278094139066`\ \(c[44]\)[t] - 
            0.03348317962868157`\ \(c[45]\)[t] - 
            0.0168255118577494`\ \(c[46]\)[t] - 
            1.8033970416801674`*^-16\ \(c[47]\)[t] + 
            0.016273855731265604`\ \(c[48]\)[t] + 
            0.03132297449134708`\ \(c[49]\)[t] + 
            0.044547108751839815`\ \(c[50]\)[t] + 
            0.05544148706619893`\ \(c[51]\)[t] + 
            0.06361487254866825`\ \(c[52]\)[t] + 
            0.06880242987642332`\ \(c[53]\)[t] + 
            0.07087301895267824`\ \(c[54]\)[t] + 
            0.06983076867396242`\ \(c[55]\)[t] + 
            0.06581101988179631`\ \(c[56]\)[t] + 
            0.059070953080906326`\ \(c[57]\)[t] + 
            0.049975424961080865`\ \(c[58]\)[t] + 
            0.03897872015786009`\ \(c[59]\)[t] + 
            0.026603074225527826`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -13, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -13]][ t]], 
          Plus[ 
            Times[ -0.041319668477947373, 
              c[ -60][ t]], 
            Times[ -0.021580547817547879, 
              c[ -59][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -58][ t]], 
            Times[ 0.022561481809254675, 
              c[ -57][ t]], 
            Times[ 0.045163358568919301, 
              c[ -56][ t]], 
            Times[ 0.066820663127759972, 
              c[ -55][ t]], 
            Times[ 0.086542809078944752, 
              c[ -54][ t]], 
            Times[ 0.10337416789158609, 
              c[ -53][ t]], 
            Times[ 0.11643488132933186, 
              c[ -52][ t]], 
            Times[ 0.12496032289024847, 
              c[ -51][ t]], 
            Times[ 0.12833762891430928, 
              c[ -50][ t]], 
            Times[ 0.12613778810677614, 
              c[ -49][ t]], 
            Times[ 0.1181419061618126, 
              c[ -48][ t]], 
            Times[ 0.10436044624225685, 
              c[ -47][ t]], 
            Times[ 0.085044480344421705, 
              c[ -46][ t]], 
            Times[ 0.060688263076985223, 
              c[ -45][ t]], 
            Times[ 0.032022748374425904, 
              c[ -44][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -43][ t]], 
            Times[ -0.034231213779558796, 
              c[ -42][ t]], 
            Times[ -0.06935801494512607, 
              c[ -41][ t]], 
            Times[ -0.10394325375429328, 
              c[ -40][ t]], 
            Times[ -0.13647135277833591, 
              c[ -39][ t]], 
            Times[ -0.16539866862653771, 
              c[ -38][ t]], 
            Times[ -0.18920668216016426, 
              c[ -37][ t]], 
            Times[ -0.20645618564475834, 
              c[ -36][ t]], 
            Times[ -0.21584055771952015, 
              c[ -35][ t]], 
            Times[ -0.21623620818304484, 
              c[ -34][ t]], 
            Times[ -0.20674833578317206, 
              c[ -33][ t]], 
            Times[ -0.18675027222298601, 
              c[ -32][ t]], 
            Times[ -0.15591488063143974, 
              c[ -31][ t]], 
            Times[ -0.11423673049785445, 
              c[ -30][ t]], 
            Times[ -0.062044074975450343, 
              c[ -29][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -28][ t]], 
            Times[ 0.070907514257657622, 
              c[ -27][ t]], 
            Times[ 0.14938649372796362, 
              c[ -26][ t]], 
            Times[ 0.23387232094715998, 
              c[ -25][ t]], 
            Times[ 0.32256865202152135, 
              c[ -24][ t]], 
            Times[ 0.41349667156634418, 
              c[ -23][ t]], 
            Times[ 0.50455115242710491, 
              c[ -22][ t]], 
            Times[ 0.59356153372868026, 
              c[ -21][ t]], 
            Times[ 0.67835603854706339, 
              c[ -20][ t]], 
            Times[ 0.75682672864065692, 
              c[ -19][ t]], 
            Times[ 0.82699334313268813, 
              c[ -18][ t]], 
            Times[ 0.88706379305918381, 
              c[ -17][ t]], 
            Times[ 0.93548928378863916, 
              c[ -16][ t]], 
            Times[ 0.9710122092317629, 
              c[ -15][ t]], 
            Times[ 0.99270519960720693, 
              c[ -14][ t]], 
            Times[ 4.7065847639646696, 
              c[ -13][ t]], 
            Times[ 0.99270519960720693, 
              c[ -12][ t]], 
            Times[ 0.9710122092317629, 
              c[ -11][ t]], 
            Times[ 0.93548928378863916, 
              c[ -10][ t]], 
            Times[ 0.88706379305918381, 
              c[ -9][ t]], 
            Times[ 0.82699334313268824, 
              c[ -8][ t]], 
            Times[ 0.75682672864065692, 
              c[ -7][ t]], 
            Times[ 0.67835603854706339, 
              c[ -6][ t]], 
            Times[ 0.59356153372868048, 
              c[ -5][ t]], 
            Times[ 0.50455115242710469, 
              c[ -4][ t]], 
            Times[ 0.41349667156634418, 
              c[ -3][ t]], 
            Times[ 0.32256865202152157, 
              c[ -2][ t]], 
            Times[ 0.23387232094715985, 
              c[ -1][ t]], 
            Times[ 0.14938649372796362, 
              c[ 0][ t]], 
            Times[ 0.070907514257657775, 
              c[ 1][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 2][ t]], 
            Times[ -0.062044074975450343, 
              c[ 3][ t]], 
            Times[ -0.11423673049785436, 
              c[ 4][ t]], 
            Times[ -0.15591488063143982, 
              c[ 5][ t]], 
            Times[ -0.18675027222298601, 
              c[ 6][ t]], 
            Times[ -0.206748335783172, 
              c[ 7][ t]], 
            Times[ -0.21623620818304484, 
              c[ 8][ t]], 
            Times[ -0.21584055771952015, 
              c[ 9][ t]], 
            Times[ -0.20645618564475843, 
              c[ 10][ t]], 
            Times[ -0.18920668216016426, 
              c[ 11][ t]], 
            Times[ -0.16539866862653771, 
              c[ 12][ t]], 
            Times[ -0.13647135277833605, 
              c[ 13][ t]], 
            Times[ -0.10394325375429328, 
              c[ 14][ t]], 
            Times[ -0.06935801494512607, 
              c[ 15][ t]], 
            Times[ -0.034231213779558949, 
              c[ 16][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 17][ t]], 
            Times[ 0.032022748374425904, 
              c[ 18][ t]], 
            Times[ 0.060688263076985105, 
              c[ 19][ t]], 
            Times[ 0.085044480344421705, 
              c[ 20][ t]], 
            Times[ 0.10436044624225685, 
              c[ 21][ t]], 
            Times[ 0.11814190616181253, 
              c[ 22][ t]], 
            Times[ 0.12613778810677614, 
              c[ 23][ t]], 
            Times[ 0.12833762891430928, 
              c[ 24][ t]], 
            Times[ 0.12496032289024853, 
              c[ 25][ t]], 
            Times[ 0.11643488132933186, 
              c[ 26][ t]], 
            Times[ 0.10337416789158609, 
              c[ 27][ t]], 
            Times[ 0.086542809078944891, 
              c[ 28][ t]], 
            Times[ 0.066820663127759972, 
              c[ 29][ t]], 
            Times[ 0.045163358568919301, 
              c[ 30][ t]], 
            Times[ 0.022561481809254869, 
              c[ 31][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 32][ t]], 
            Times[ -0.021580547817547879, 
              c[ 33][ t]], 
            Times[ -0.04131966847794722, 
              c[ 34][ t]], 
            Times[ -0.058468080236789913, 
              c[ 35][ t]], 
            Times[ -0.072413370861974122, 
              c[ 36][ t]], 
            Times[ -0.082699334313268744, 
              c[ 37][ t]], 
            Times[ -0.089038438663606695, 
              c[ 38][ t]], 
            Times[ -0.091317159035181589, 
              c[ 39][ t]], 
            Times[ -0.089594193770366884, 
              c[ 40][ t]], 
            Times[ -0.084091858737850855, 
              c[ 41][ t]], 
            Times[ -0.075181213012062598, 
              c[ 42][ t]], 
            Times[ -0.063361699504227528, 
              c[ 43][ t]], 
            Times[ -0.049236278094139066, 
              c[ 44][ t]], 
            Times[ -0.033483179628681567, 
              c[ 45][ t]], 
            Times[ -0.016825511857749401, 
              c[ 46][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 47][ t]], 
            Times[ 0.016273855731265604, 
              c[ 48][ t]], 
            Times[ 0.031322974491347078, 
              c[ 49][ t]], 
            Times[ 0.044547108751839815, 
              c[ 50][ t]], 
            Times[ 0.055441487066198933, 
              c[ 51][ t]], 
            Times[ 0.063614872548668253, 
              c[ 52][ t]], 
            Times[ 0.068802429876423321, 
              c[ 53][ t]], 
            Times[ 0.070873018952678238, 
              c[ 54][ t]], 
            Times[ 0.069830768673962415, 
              c[ 55][ t]], 
            Times[ 0.065811019881796315, 
              c[ 56][ t]], 
            Times[ 0.059070953080906326, 
              c[ 57][ t]], 
            Times[ 0.049975424961080865, 
              c[ 58][ t]], 
            Times[ 0.038978720157860088, 
              c[ 59][ t]], 
            Times[ 0.026603074225527826, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-12\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-12\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.05846808023678991`\)\ \(c[\(-60\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-59\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-58\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-57\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-56\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-55\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-54\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-53\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-52\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-51\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-50\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-49\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-48\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-47\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-46\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-45\)]\)[t] + 
            0.060688263076985`\ \(c[\(-44\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-43\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-42\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-41\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-40\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-39\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-38\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-37\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-36\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-35\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-34\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-33\)]\)[t] - 
            0.206748335783172`\ \(c[\(-32\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-31\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-30\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-29\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-28\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-27\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-26\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-25\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-24\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-23\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-22\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-21\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-20\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-19\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-18\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-17\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-16\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-15\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-14\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-13\)]\)[t] + 
            4.158273408348594`\ \(c[\(-12\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-11\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-10\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-9\)]\)[t] + 
            0.8870637930591837`\ \(c[\(-8\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-7\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-6\)]\)[t] + 
            0.6783560385470633`\ \(c[\(-5\)]\)[t] + 
            0.5935615337286803`\ \(c[\(-4\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-3\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-2\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-1\)]\)[t] + 
            0.23387232094715985`\ \(c[0]\)[t] + 
            0.14938649372796362`\ \(c[1]\)[t] + 
            0.07090751425765762`\ \(c[2]\)[t] + 
            3.898171832519376`*^-17\ \(c[3]\)[t] - 
            0.06204407497545034`\ \(c[4]\)[t] - 
            0.11423673049785436`\ \(c[5]\)[t] - 
            0.15591488063143982`\ \(c[6]\)[t] - 
            0.186750272222986`\ \(c[7]\)[t] - 
            0.206748335783172`\ \(c[8]\)[t] - 
            0.21623620818304484`\ \(c[9]\)[t] - 
            0.21584055771952015`\ \(c[10]\)[t] - 
            0.20645618564475843`\ \(c[11]\)[t] - 
            0.18920668216016426`\ \(c[12]\)[t] - 
            0.1653986686265377`\ \(c[13]\)[t] - 
            0.13647135277833605`\ \(c[14]\)[t] - 
            0.10394325375429328`\ \(c[15]\)[t] - 
            0.06935801494512607`\ \(c[16]\)[t] - 
            0.03423121377955895`\ \(c[17]\)[t] - 
            3.898171832519376`*^-17\ \(c[18]\)[t] + 
            0.032022748374425904`\ \(c[19]\)[t] + 
            0.060688263076985105`\ \(c[20]\)[t] + 
            0.0850444803444217`\ \(c[21]\)[t] + 
            0.10436044624225685`\ \(c[22]\)[t] + 
            0.11814190616181255`\ \(c[23]\)[t] + 
            0.12613778810677614`\ \(c[24]\)[t] + 
            0.12833762891430928`\ \(c[25]\)[t] + 
            0.12496032289024853`\ \(c[26]\)[t] + 
            0.11643488132933186`\ \(c[27]\)[t] + 
            0.10337416789158609`\ \(c[28]\)[t] + 
            0.08654280907894489`\ \(c[29]\)[t] + 
            0.06682066312775997`\ \(c[30]\)[t] + 
            0.0451633585689193`\ \(c[31]\)[t] + 
            0.02256148180925487`\ \(c[32]\)[t] + 
            3.8981718325193755`*^-17\ \(c[33]\)[t] - 
            0.02158054781754788`\ \(c[34]\)[t] - 
            0.04131966847794722`\ \(c[35]\)[t] - 
            0.05846808023678991`\ \(c[36]\)[t] - 
            0.07241337086197412`\ \(c[37]\)[t] - 
            0.08269933431326874`\ \(c[38]\)[t] - 
            0.0890384386636067`\ \(c[39]\)[t] - 
            0.09131715903518159`\ \(c[40]\)[t] - 
            0.08959419377036688`\ \(c[41]\)[t] - 
            0.08409185873785081`\ \(c[42]\)[t] - 
            0.0751812130120626`\ \(c[43]\)[t] - 
            0.06336169950422753`\ \(c[44]\)[t] - 
            0.04923627809413894`\ \(c[45]\)[t] - 
            0.03348317962868157`\ \(c[46]\)[t] - 
            0.0168255118577494`\ \(c[47]\)[t] - 
            3.898171832519376`*^-17\ \(c[48]\)[t] + 
            0.016273855731265604`\ \(c[49]\)[t] + 
            0.03132297449134708`\ \(c[50]\)[t] + 
            0.04454710875183992`\ \(c[51]\)[t] + 
            0.05544148706619893`\ \(c[52]\)[t] + 
            0.06361487254866825`\ \(c[53]\)[t] + 
            0.06880242987642335`\ \(c[54]\)[t] + 
            0.07087301895267824`\ \(c[55]\)[t] + 
            0.06983076867396242`\ \(c[56]\)[t] + 
            0.06581101988179627`\ \(c[57]\)[t] + 
            0.059070953080906326`\ \(c[58]\)[t] + 
            0.049975424961080865`\ \(c[59]\)[t] + 
            0.03897872015785999`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -12, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -12]][ t]], 
          Plus[ 
            Times[ -0.058468080236789913, 
              c[ -60][ t]], 
            Times[ -0.04131966847794722, 
              c[ -59][ t]], 
            Times[ -0.021580547817547879, 
              c[ -58][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -57][ t]], 
            Times[ 0.022561481809254869, 
              c[ -56][ t]], 
            Times[ 0.045163358568919301, 
              c[ -55][ t]], 
            Times[ 0.066820663127759972, 
              c[ -54][ t]], 
            Times[ 0.086542809078944891, 
              c[ -53][ t]], 
            Times[ 0.10337416789158609, 
              c[ -52][ t]], 
            Times[ 0.11643488132933186, 
              c[ -51][ t]], 
            Times[ 0.12496032289024853, 
              c[ -50][ t]], 
            Times[ 0.12833762891430928, 
              c[ -49][ t]], 
            Times[ 0.12613778810677614, 
              c[ -48][ t]], 
            Times[ 0.11814190616181253, 
              c[ -47][ t]], 
            Times[ 0.10436044624225685, 
              c[ -46][ t]], 
            Times[ 0.085044480344421705, 
              c[ -45][ t]], 
            Times[ 0.060688263076985001, 
              c[ -44][ t]], 
            Times[ 0.032022748374425904, 
              c[ -43][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -42][ t]], 
            Times[ -0.034231213779559094, 
              c[ -41][ t]], 
            Times[ -0.06935801494512607, 
              c[ -40][ t]], 
            Times[ -0.10394325375429328, 
              c[ -39][ t]], 
            Times[ -0.13647135277833605, 
              c[ -38][ t]], 
            Times[ -0.16539866862653771, 
              c[ -37][ t]], 
            Times[ -0.18920668216016426, 
              c[ -36][ t]], 
            Times[ -0.20645618564475843, 
              c[ -35][ t]], 
            Times[ -0.21584055771952015, 
              c[ -34][ t]], 
            Times[ -0.21623620818304484, 
              c[ -33][ t]], 
            Times[ -0.206748335783172, 
              c[ -32][ t]], 
            Times[ -0.18675027222298593, 
              c[ -31][ t]], 
            Times[ -0.15591488063143982, 
              c[ -30][ t]], 
            Times[ -0.11423673049785436, 
              c[ -29][ t]], 
            Times[ -0.062044074975450239, 
              c[ -28][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -27][ t]], 
            Times[ 0.070907514257657775, 
              c[ -26][ t]], 
            Times[ 0.14938649372796384, 
              c[ -25][ t]], 
            Times[ 0.23387232094715985, 
              c[ -24][ t]], 
            Times[ 0.32256865202152157, 
              c[ -23][ t]], 
            Times[ 0.41349667156634429, 
              c[ -22][ t]], 
            Times[ 0.50455115242710469, 
              c[ -21][ t]], 
            Times[ 0.59356153372868059, 
              c[ -20][ t]], 
            Times[ 0.67835603854706339, 
              c[ -19][ t]], 
            Times[ 0.75682672864065692, 
              c[ -18][ t]], 
            Times[ 0.82699334313268813, 
              c[ -17][ t]], 
            Times[ 0.88706379305918381, 
              c[ -16][ t]], 
            Times[ 0.93548928378863916, 
              c[ -15][ t]], 
            Times[ 0.9710122092317629, 
              c[ -14][ t]], 
            Times[ 0.99270519960720693, 
              c[ -13][ t]], 
            Times[ 4.1582734083485944, 
              c[ -12][ t]], 
            Times[ 0.99270519960720671, 
              c[ -11][ t]], 
            Times[ 0.9710122092317629, 
              c[ -10][ t]], 
            Times[ 0.93548928378863916, 
              c[ -9][ t]], 
            Times[ 0.8870637930591837, 
              c[ -8][ t]], 
            Times[ 0.82699334313268813, 
              c[ -7][ t]], 
            Times[ 0.75682672864065692, 
              c[ -6][ t]], 
            Times[ 0.67835603854706328, 
              c[ -5][ t]], 
            Times[ 0.59356153372868026, 
              c[ -4][ t]], 
            Times[ 0.50455115242710469, 
              c[ -3][ t]], 
            Times[ 0.41349667156634418, 
              c[ -2][ t]], 
            Times[ 0.32256865202152135, 
              c[ -1][ t]], 
            Times[ 0.23387232094715985, 
              c[ 0][ t]], 
            Times[ 0.14938649372796362, 
              c[ 1][ t]], 
            Times[ 0.070907514257657622, 
              c[ 2][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 3][ t]], 
            Times[ -0.062044074975450343, 
              c[ 4][ t]], 
            Times[ -0.11423673049785436, 
              c[ 5][ t]], 
            Times[ -0.15591488063143982, 
              c[ 6][ t]], 
            Times[ -0.18675027222298601, 
              c[ 7][ t]], 
            Times[ -0.206748335783172, 
              c[ 8][ t]], 
            Times[ -0.21623620818304484, 
              c[ 9][ t]], 
            Times[ -0.21584055771952015, 
              c[ 10][ t]], 
            Times[ -0.20645618564475843, 
              c[ 11][ t]], 
            Times[ -0.18920668216016426, 
              c[ 12][ t]], 
            Times[ -0.16539866862653771, 
              c[ 13][ t]], 
            Times[ -0.13647135277833605, 
              c[ 14][ t]], 
            Times[ -0.10394325375429328, 
              c[ 15][ t]], 
            Times[ -0.06935801494512607, 
              c[ 16][ t]], 
            Times[ -0.034231213779558949, 
              c[ 17][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 18][ t]], 
            Times[ 0.032022748374425904, 
              c[ 19][ t]], 
            Times[ 0.060688263076985105, 
              c[ 20][ t]], 
            Times[ 0.085044480344421705, 
              c[ 21][ t]], 
            Times[ 0.10436044624225685, 
              c[ 22][ t]], 
            Times[ 0.11814190616181255, 
              c[ 23][ t]], 
            Times[ 0.12613778810677614, 
              c[ 24][ t]], 
            Times[ 0.12833762891430928, 
              c[ 25][ t]], 
            Times[ 0.12496032289024853, 
              c[ 26][ t]], 
            Times[ 0.11643488132933186, 
              c[ 27][ t]], 
            Times[ 0.10337416789158609, 
              c[ 28][ t]], 
            Times[ 0.086542809078944891, 
              c[ 29][ t]], 
            Times[ 0.066820663127759972, 
              c[ 30][ t]], 
            Times[ 0.045163358568919301, 
              c[ 31][ t]], 
            Times[ 0.022561481809254869, 
              c[ 32][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 33][ t]], 
            Times[ -0.021580547817547879, 
              c[ 34][ t]], 
            Times[ -0.04131966847794722, 
              c[ 35][ t]], 
            Times[ -0.058468080236789913, 
              c[ 36][ t]], 
            Times[ -0.072413370861974122, 
              c[ 37][ t]], 
            Times[ -0.082699334313268744, 
              c[ 38][ t]], 
            Times[ -0.089038438663606695, 
              c[ 39][ t]], 
            Times[ -0.091317159035181589, 
              c[ 40][ t]], 
            Times[ -0.089594193770366884, 
              c[ 41][ t]], 
            Times[ -0.084091858737850814, 
              c[ 42][ t]], 
            Times[ -0.075181213012062598, 
              c[ 43][ t]], 
            Times[ -0.063361699504227528, 
              c[ 44][ t]], 
            Times[ -0.049236278094138941, 
              c[ 45][ t]], 
            Times[ -0.033483179628681567, 
              c[ 46][ t]], 
            Times[ -0.016825511857749401, 
              c[ 47][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 48][ t]], 
            Times[ 0.016273855731265604, 
              c[ 49][ t]], 
            Times[ 0.031322974491347078, 
              c[ 50][ t]], 
            Times[ 0.044547108751839919, 
              c[ 51][ t]], 
            Times[ 0.055441487066198933, 
              c[ 52][ t]], 
            Times[ 0.063614872548668253, 
              c[ 53][ t]], 
            Times[ 0.068802429876423349, 
              c[ 54][ t]], 
            Times[ 0.070873018952678238, 
              c[ 55][ t]], 
            Times[ 0.069830768673962415, 
              c[ 56][ t]], 
            Times[ 0.065811019881796273, 
              c[ 57][ t]], 
            Times[ 0.059070953080906326, 
              c[ 58][ t]], 
            Times[ 0.049975424961080865, 
              c[ 59][ t]], 
            Times[ 0.03897872015785999, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-11\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-11\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.07241337086197425`\)\ \(c[\(-60\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-59\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-58\)]\)[t] - 
            0.021580547817548056`\ \(c[\(-57\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-56\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-55\)]\)[t] + 
            0.045163358568919114`\ \(c[\(-54\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-53\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-52\)]\)[t] + 
            0.10337416789158595`\ \(c[\(-51\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-50\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-49\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-48\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-47\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-46\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-45\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-44\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-43\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-42\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-41\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-40\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-39\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-38\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-37\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-36\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-35\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-34\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-33\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-32\)]\)[t] - 
            0.206748335783172`\ \(c[\(-31\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-30\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-29\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-28\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-27\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-26\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-25\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-24\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-23\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-22\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-21\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-20\)]\)[t] + 
            0.5935615337286803`\ \(c[\(-19\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-18\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-17\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-16\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-15\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-14\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-13\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-12\)]\)[t] + 
            3.6538269611818044`\ \(c[\(-11\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-10\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-9\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-8\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-7\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-6\)]\)[t] + 
            0.756826728640657`\ \(c[\(-5\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-4\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-3\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-2\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-1\)]\)[t] + 
            0.3225686520215216`\ \(c[0]\)[t] + 
            0.23387232094715998`\ \(c[1]\)[t] + 
            0.14938649372796362`\ \(c[2]\)[t] + 
            0.07090751425765777`\ \(c[3]\)[t] + 
            1.8033970416801674`*^-16\ \(c[4]\)[t] - 
            0.06204407497545024`\ \(c[5]\)[t] - 
            0.11423673049785436`\ \(c[6]\)[t] - 
            0.15591488063143974`\ \(c[7]\)[t] - 
            0.18675027222298593`\ \(c[8]\)[t] - 
            0.206748335783172`\ \(c[9]\)[t] - 
            0.21623620818304484`\ \(c[10]\)[t] - 
            0.21584055771952015`\ \(c[11]\)[t] - 
            0.20645618564475843`\ \(c[12]\)[t] - 
            0.18920668216016426`\ \(c[13]\)[t] - 
            0.1653986686265377`\ \(c[14]\)[t] - 
            0.13647135277833605`\ \(c[15]\)[t] - 
            0.10394325375429328`\ \(c[16]\)[t] - 
            0.06935801494512607`\ \(c[17]\)[t] - 
            0.03423121377955895`\ \(c[18]\)[t] - 
            3.898171832519376`*^-17\ \(c[19]\)[t] + 
            0.032022748374425904`\ \(c[20]\)[t] + 
            0.060688263076985105`\ \(c[21]\)[t] + 
            0.08504448034442161`\ \(c[22]\)[t] + 
            0.10436044624225685`\ \(c[23]\)[t] + 
            0.11814190616181255`\ \(c[24]\)[t] + 
            0.12613778810677612`\ \(c[25]\)[t] + 
            0.12833762891430928`\ \(c[26]\)[t] + 
            0.12496032289024853`\ \(c[27]\)[t] + 
            0.11643488132933186`\ \(c[28]\)[t] + 
            0.10337416789158609`\ \(c[29]\)[t] + 
            0.08654280907894489`\ \(c[30]\)[t] + 
            0.06682066312775997`\ \(c[31]\)[t] + 
            0.0451633585689193`\ \(c[32]\)[t] + 
            0.02256148180925487`\ \(c[33]\)[t] + 
            3.8981718325193755`*^-17\ \(c[34]\)[t] - 
            0.02158054781754788`\ \(c[35]\)[t] - 
            0.04131966847794722`\ \(c[36]\)[t] - 
            0.05846808023678991`\ \(c[37]\)[t] - 
            0.07241337086197412`\ \(c[38]\)[t] - 
            0.08269933431326874`\ \(c[39]\)[t] - 
            0.0890384386636067`\ \(c[40]\)[t] - 
            0.0913171590351816`\ \(c[41]\)[t] - 
            0.08959419377036688`\ \(c[42]\)[t] - 
            0.08409185873785081`\ \(c[43]\)[t] - 
            0.0751812130120627`\ \(c[44]\)[t] - 
            0.06336169950422753`\ \(c[45]\)[t] - 
            0.04923627809413894`\ \(c[46]\)[t] - 
            0.033483179628681706`\ \(c[47]\)[t] - 
            0.0168255118577494`\ \(c[48]\)[t] - 
            3.898171832519376`*^-17\ \(c[49]\)[t] + 
            0.01627385573126547`\ \(c[50]\)[t] + 
            0.03132297449134708`\ \(c[51]\)[t] + 
            0.04454710875183992`\ \(c[52]\)[t] + 
            0.055441487066198857`\ \(c[53]\)[t] + 
            0.06361487254866825`\ \(c[54]\)[t] + 
            0.06880242987642335`\ \(c[55]\)[t] + 
            0.07087301895267824`\ \(c[56]\)[t] + 
            0.06983076867396242`\ \(c[57]\)[t] + 
            0.06581101988179627`\ \(c[58]\)[t] + 
            0.0590709530809064`\ \(c[59]\)[t] + 
            0.049975424961080865`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -11, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -11]][ t]], 
          Plus[ 
            Times[ -0.072413370861974247, 
              c[ -60][ t]], 
            Times[ -0.058468080236789913, 
              c[ -59][ t]], 
            Times[ -0.04131966847794722, 
              c[ -58][ t]], 
            Times[ -0.021580547817548056, 
              c[ -57][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -56][ t]], 
            Times[ 0.022561481809254869, 
              c[ -55][ t]], 
            Times[ 0.045163358568919114, 
              c[ -54][ t]], 
            Times[ 0.066820663127759972, 
              c[ -53][ t]], 
            Times[ 0.086542809078944891, 
              c[ -52][ t]], 
            Times[ 0.10337416789158595, 
              c[ -51][ t]], 
            Times[ 0.11643488132933186, 
              c[ -50][ t]], 
            Times[ 0.12496032289024853, 
              c[ -49][ t]], 
            Times[ 0.12833762891430925, 
              c[ -48][ t]], 
            Times[ 0.12613778810677612, 
              c[ -47][ t]], 
            Times[ 0.11814190616181255, 
              c[ -46][ t]], 
            Times[ 0.10436044624225692, 
              c[ -45][ t]], 
            Times[ 0.085044480344421608, 
              c[ -44][ t]], 
            Times[ 0.060688263076985105, 
              c[ -43][ t]], 
            Times[ 0.032022748374426029, 
              c[ -42][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -41][ t]], 
            Times[ -0.034231213779558949, 
              c[ -40][ t]], 
            Times[ -0.069358014945125918, 
              c[ -39][ t]], 
            Times[ -0.10394325375429328, 
              c[ -38][ t]], 
            Times[ -0.13647135277833605, 
              c[ -37][ t]], 
            Times[ -0.1653986686265376, 
              c[ -36][ t]], 
            Times[ -0.18920668216016426, 
              c[ -35][ t]], 
            Times[ -0.20645618564475843, 
              c[ -34][ t]], 
            Times[ -0.21584055771952013, 
              c[ -33][ t]], 
            Times[ -0.21623620818304484, 
              c[ -32][ t]], 
            Times[ -0.206748335783172, 
              c[ -31][ t]], 
            Times[ -0.18675027222298607, 
              c[ -30][ t]], 
            Times[ -0.15591488063143982, 
              c[ -29][ t]], 
            Times[ -0.11423673049785436, 
              c[ -28][ t]], 
            Times[ -0.062044074975450475, 
              c[ -27][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -26][ t]], 
            Times[ 0.070907514257657775, 
              c[ -25][ t]], 
            Times[ 0.14938649372796345, 
              c[ -24][ t]], 
            Times[ 0.23387232094715985, 
              c[ -23][ t]], 
            Times[ 0.32256865202152157, 
              c[ -22][ t]], 
            Times[ 0.41349667156634395, 
              c[ -21][ t]], 
            Times[ 0.50455115242710469, 
              c[ -20][ t]], 
            Times[ 0.59356153372868026, 
              c[ -19][ t]], 
            Times[ 0.67835603854706317, 
              c[ -18][ t]], 
            Times[ 0.75682672864065692, 
              c[ -17][ t]], 
            Times[ 0.82699334313268813, 
              c[ -16][ t]], 
            Times[ 0.88706379305918381, 
              c[ -15][ t]], 
            Times[ 0.93548928378863916, 
              c[ -14][ t]], 
            Times[ 0.9710122092317629, 
              c[ -13][ t]], 
            Times[ 0.99270519960720671, 
              c[ -12][ t]], 
            Times[ 3.6538269611818044, 
              c[ -11][ t]], 
            Times[ 0.99270519960720693, 
              c[ -10][ t]], 
            Times[ 0.9710122092317629, 
              c[ -9][ t]], 
            Times[ 0.93548928378863916, 
              c[ -8][ t]], 
            Times[ 0.88706379305918381, 
              c[ -7][ t]], 
            Times[ 0.82699334313268813, 
              c[ -6][ t]], 
            Times[ 0.75682672864065703, 
              c[ -5][ t]], 
            Times[ 0.67835603854706339, 
              c[ -4][ t]], 
            Times[ 0.59356153372868059, 
              c[ -3][ t]], 
            Times[ 0.50455115242710469, 
              c[ -2][ t]], 
            Times[ 0.41349667156634418, 
              c[ -1][ t]], 
            Times[ 0.32256865202152157, 
              c[ 0][ t]], 
            Times[ 0.23387232094715998, 
              c[ 1][ t]], 
            Times[ 0.14938649372796362, 
              c[ 2][ t]], 
            Times[ 0.070907514257657775, 
              c[ 3][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 4][ t]], 
            Times[ -0.062044074975450239, 
              c[ 5][ t]], 
            Times[ -0.11423673049785436, 
              c[ 6][ t]], 
            Times[ -0.15591488063143974, 
              c[ 7][ t]], 
            Times[ -0.18675027222298593, 
              c[ 8][ t]], 
            Times[ -0.206748335783172, 
              c[ 9][ t]], 
            Times[ -0.21623620818304484, 
              c[ 10][ t]], 
            Times[ -0.21584055771952015, 
              c[ 11][ t]], 
            Times[ -0.20645618564475843, 
              c[ 12][ t]], 
            Times[ -0.18920668216016426, 
              c[ 13][ t]], 
            Times[ -0.16539866862653771, 
              c[ 14][ t]], 
            Times[ -0.13647135277833605, 
              c[ 15][ t]], 
            Times[ -0.10394325375429328, 
              c[ 16][ t]], 
            Times[ -0.06935801494512607, 
              c[ 17][ t]], 
            Times[ -0.034231213779558949, 
              c[ 18][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 19][ t]], 
            Times[ 0.032022748374425904, 
              c[ 20][ t]], 
            Times[ 0.060688263076985105, 
              c[ 21][ t]], 
            Times[ 0.085044480344421608, 
              c[ 22][ t]], 
            Times[ 0.10436044624225685, 
              c[ 23][ t]], 
            Times[ 0.11814190616181255, 
              c[ 24][ t]], 
            Times[ 0.12613778810677612, 
              c[ 25][ t]], 
            Times[ 0.12833762891430928, 
              c[ 26][ t]], 
            Times[ 0.12496032289024853, 
              c[ 27][ t]], 
            Times[ 0.11643488132933186, 
              c[ 28][ t]], 
            Times[ 0.10337416789158609, 
              c[ 29][ t]], 
            Times[ 0.086542809078944891, 
              c[ 30][ t]], 
            Times[ 0.066820663127759972, 
              c[ 31][ t]], 
            Times[ 0.045163358568919301, 
              c[ 32][ t]], 
            Times[ 0.022561481809254869, 
              c[ 33][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 34][ t]], 
            Times[ -0.021580547817547879, 
              c[ 35][ t]], 
            Times[ -0.04131966847794722, 
              c[ 36][ t]], 
            Times[ -0.058468080236789913, 
              c[ 37][ t]], 
            Times[ -0.072413370861974122, 
              c[ 38][ t]], 
            Times[ -0.082699334313268744, 
              c[ 39][ t]], 
            Times[ -0.089038438663606695, 
              c[ 40][ t]], 
            Times[ -0.091317159035181603, 
              c[ 41][ t]], 
            Times[ -0.089594193770366884, 
              c[ 42][ t]], 
            Times[ -0.084091858737850814, 
              c[ 43][ t]], 
            Times[ -0.075181213012062695, 
              c[ 44][ t]], 
            Times[ -0.063361699504227528, 
              c[ 45][ t]], 
            Times[ -0.049236278094138941, 
              c[ 46][ t]], 
            Times[ -0.033483179628681706, 
              c[ 47][ t]], 
            Times[ -0.016825511857749401, 
              c[ 48][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 49][ t]], 
            Times[ 0.016273855731265469, 
              c[ 50][ t]], 
            Times[ 0.031322974491347078, 
              c[ 51][ t]], 
            Times[ 0.044547108751839919, 
              c[ 52][ t]], 
            Times[ 0.055441487066198857, 
              c[ 53][ t]], 
            Times[ 0.063614872548668253, 
              c[ 54][ t]], 
            Times[ 0.068802429876423349, 
              c[ 55][ t]], 
            Times[ 0.070873018952678238, 
              c[ 56][ t]], 
            Times[ 0.069830768673962415, 
              c[ 57][ t]], 
            Times[ 0.065811019881796273, 
              c[ 58][ t]], 
            Times[ 0.059070953080906402, 
              c[ 59][ t]], 
            Times[ 0.049975424961080865, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-10\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-10\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.08269933431326881`\)\ \(c[\(-60\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-59\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-58\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-57\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-56\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-55\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-54\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-53\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-52\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-51\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-50\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-49\)]\)[t] + 
            0.12496032289024847`\ \(c[\(-48\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-47\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-46\)]\)[t] + 
            0.1181419061618126`\ \(c[\(-45\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-44\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-43\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-42\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-41\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-40\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-39\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-38\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-37\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-36\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-35\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-34\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-33\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-32\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-31\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-30\)]\)[t] - 
            0.186750272222986`\ \(c[\(-29\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-28\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-27\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-26\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-25\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-24\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-23\)]\)[t] + 
            0.23387232094715998`\ \(c[\(-22\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-21\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-20\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-19\)]\)[t] + 
            0.5935615337286803`\ \(c[\(-18\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-17\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-16\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-15\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-14\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-13\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-12\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-11\)]\)[t] + 
            3.1932454224643014`\ \(c[\(-10\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-9\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-8\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-7\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-6\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-5\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-4\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-3\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-2\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-1\)]\)[t] + 
            0.4134966715663442`\ \(c[0]\)[t] + 
            0.3225686520215216`\ \(c[1]\)[t] + 
            0.23387232094715985`\ \(c[2]\)[t] + 
            0.14938649372796362`\ \(c[3]\)[t] + 
            0.07090751425765777`\ \(c[4]\)[t] + 
            3.898171832519376`*^-17\ \(c[5]\)[t] - 
            0.06204407497545034`\ \(c[6]\)[t] - 
            0.11423673049785436`\ \(c[7]\)[t] - 
            0.15591488063143982`\ \(c[8]\)[t] - 
            0.186750272222986`\ \(c[9]\)[t] - 
            0.206748335783172`\ \(c[10]\)[t] - 
            0.21623620818304484`\ \(c[11]\)[t] - 
            0.21584055771952015`\ \(c[12]\)[t] - 
            0.20645618564475843`\ \(c[13]\)[t] - 
            0.18920668216016426`\ \(c[14]\)[t] - 
            0.1653986686265377`\ \(c[15]\)[t] - 
            0.13647135277833605`\ \(c[16]\)[t] - 
            0.10394325375429328`\ \(c[17]\)[t] - 
            0.06935801494512607`\ \(c[18]\)[t] - 
            0.03423121377955895`\ \(c[19]\)[t] - 
            3.898171832519376`*^-17\ \(c[20]\)[t] + 
            0.032022748374425904`\ \(c[21]\)[t] + 
            0.060688263076985`\ \(c[22]\)[t] + 
            0.0850444803444217`\ \(c[23]\)[t] + 
            0.10436044624225685`\ \(c[24]\)[t] + 
            0.11814190616181253`\ \(c[25]\)[t] + 
            0.12613778810677614`\ \(c[26]\)[t] + 
            0.12833762891430928`\ \(c[27]\)[t] + 
            0.12496032289024853`\ \(c[28]\)[t] + 
            0.11643488132933186`\ \(c[29]\)[t] + 
            0.10337416789158609`\ \(c[30]\)[t] + 
            0.08654280907894489`\ \(c[31]\)[t] + 
            0.06682066312775997`\ \(c[32]\)[t] + 
            0.0451633585689193`\ \(c[33]\)[t] + 
            0.02256148180925487`\ \(c[34]\)[t] + 
            3.8981718325193755`*^-17\ \(c[35]\)[t] - 
            0.02158054781754788`\ \(c[36]\)[t] - 
            0.04131966847794722`\ \(c[37]\)[t] - 
            0.05846808023678991`\ \(c[38]\)[t] - 
            0.07241337086197412`\ \(c[39]\)[t] - 
            0.08269933431326874`\ \(c[40]\)[t] - 
            0.08903843866360665`\ \(c[41]\)[t] - 
            0.09131715903518159`\ \(c[42]\)[t] - 
            0.08959419377036688`\ \(c[43]\)[t] - 
            0.08409185873785086`\ \(c[44]\)[t] - 
            0.0751812130120626`\ \(c[45]\)[t] - 
            0.06336169950422753`\ \(c[46]\)[t] - 
            0.049236278094139066`\ \(c[47]\)[t] - 
            0.03348317962868157`\ \(c[48]\)[t] - 
            0.0168255118577494`\ \(c[49]\)[t] - 
            1.8033970416801674`*^-16\ \(c[50]\)[t] + 
            0.016273855731265604`\ \(c[51]\)[t] + 
            0.03132297449134708`\ \(c[52]\)[t] + 
            0.044547108751839815`\ \(c[53]\)[t] + 
            0.05544148706619893`\ \(c[54]\)[t] + 
            0.06361487254866825`\ \(c[55]\)[t] + 
            0.06880242987642332`\ \(c[56]\)[t] + 
            0.07087301895267824`\ \(c[57]\)[t] + 
            0.06983076867396242`\ \(c[58]\)[t] + 
            0.06581101988179631`\ \(c[59]\)[t] + 
            0.059070953080906326`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -10, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -10]][ t]], 
          Plus[ 
            Times[ -0.082699334313268813, 
              c[ -60][ t]], 
            Times[ -0.072413370861974122, 
              c[ -59][ t]], 
            Times[ -0.058468080236789913, 
              c[ -58][ t]], 
            Times[ -0.041319668477947373, 
              c[ -57][ t]], 
            Times[ -0.021580547817547879, 
              c[ -56][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -55][ t]], 
            Times[ 0.022561481809254675, 
              c[ -54][ t]], 
            Times[ 0.045163358568919301, 
              c[ -53][ t]], 
            Times[ 0.066820663127759972, 
              c[ -52][ t]], 
            Times[ 0.086542809078944752, 
              c[ -51][ t]], 
            Times[ 0.10337416789158609, 
              c[ -50][ t]], 
            Times[ 0.11643488132933186, 
              c[ -49][ t]], 
            Times[ 0.12496032289024847, 
              c[ -48][ t]], 
            Times[ 0.12833762891430928, 
              c[ -47][ t]], 
            Times[ 0.12613778810677614, 
              c[ -46][ t]], 
            Times[ 0.1181419061618126, 
              c[ -45][ t]], 
            Times[ 0.10436044624225685, 
              c[ -44][ t]], 
            Times[ 0.085044480344421705, 
              c[ -43][ t]], 
            Times[ 0.060688263076985223, 
              c[ -42][ t]], 
            Times[ 0.032022748374425904, 
              c[ -41][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -40][ t]], 
            Times[ -0.034231213779558796, 
              c[ -39][ t]], 
            Times[ -0.06935801494512607, 
              c[ -38][ t]], 
            Times[ -0.10394325375429328, 
              c[ -37][ t]], 
            Times[ -0.13647135277833591, 
              c[ -36][ t]], 
            Times[ -0.16539866862653771, 
              c[ -35][ t]], 
            Times[ -0.18920668216016426, 
              c[ -34][ t]], 
            Times[ -0.20645618564475834, 
              c[ -33][ t]], 
            Times[ -0.21584055771952015, 
              c[ -32][ t]], 
            Times[ -0.21623620818304484, 
              c[ -31][ t]], 
            Times[ -0.20674833578317206, 
              c[ -30][ t]], 
            Times[ -0.18675027222298601, 
              c[ -29][ t]], 
            Times[ -0.15591488063143974, 
              c[ -28][ t]], 
            Times[ -0.11423673049785445, 
              c[ -27][ t]], 
            Times[ -0.062044074975450343, 
              c[ -26][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -25][ t]], 
            Times[ 0.070907514257657622, 
              c[ -24][ t]], 
            Times[ 0.14938649372796362, 
              c[ -23][ t]], 
            Times[ 0.23387232094715998, 
              c[ -22][ t]], 
            Times[ 0.32256865202152135, 
              c[ -21][ t]], 
            Times[ 0.41349667156634418, 
              c[ -20][ t]], 
            Times[ 0.50455115242710469, 
              c[ -19][ t]], 
            Times[ 0.59356153372868026, 
              c[ -18][ t]], 
            Times[ 0.67835603854706339, 
              c[ -17][ t]], 
            Times[ 0.75682672864065692, 
              c[ -16][ t]], 
            Times[ 0.82699334313268813, 
              c[ -15][ t]], 
            Times[ 0.88706379305918381, 
              c[ -14][ t]], 
            Times[ 0.93548928378863916, 
              c[ -13][ t]], 
            Times[ 0.9710122092317629, 
              c[ -12][ t]], 
            Times[ 0.99270519960720693, 
              c[ -11][ t]], 
            Times[ 3.1932454224643014, 
              c[ -10][ t]], 
            Times[ 0.99270519960720693, 
              c[ -9][ t]], 
            Times[ 0.9710122092317629, 
              c[ -8][ t]], 
            Times[ 0.93548928378863916, 
              c[ -7][ t]], 
            Times[ 0.88706379305918381, 
              c[ -6][ t]], 
            Times[ 0.82699334313268824, 
              c[ -5][ t]], 
            Times[ 0.75682672864065692, 
              c[ -4][ t]], 
            Times[ 0.67835603854706339, 
              c[ -3][ t]], 
            Times[ 0.59356153372868048, 
              c[ -2][ t]], 
            Times[ 0.50455115242710469, 
              c[ -1][ t]], 
            Times[ 0.41349667156634418, 
              c[ 0][ t]], 
            Times[ 0.32256865202152157, 
              c[ 1][ t]], 
            Times[ 0.23387232094715985, 
              c[ 2][ t]], 
            Times[ 0.14938649372796362, 
              c[ 3][ t]], 
            Times[ 0.070907514257657775, 
              c[ 4][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 5][ t]], 
            Times[ -0.062044074975450343, 
              c[ 6][ t]], 
            Times[ -0.11423673049785436, 
              c[ 7][ t]], 
            Times[ -0.15591488063143982, 
              c[ 8][ t]], 
            Times[ -0.18675027222298601, 
              c[ 9][ t]], 
            Times[ -0.206748335783172, 
              c[ 10][ t]], 
            Times[ -0.21623620818304484, 
              c[ 11][ t]], 
            Times[ -0.21584055771952015, 
              c[ 12][ t]], 
            Times[ -0.20645618564475843, 
              c[ 13][ t]], 
            Times[ -0.18920668216016426, 
              c[ 14][ t]], 
            Times[ -0.16539866862653771, 
              c[ 15][ t]], 
            Times[ -0.13647135277833605, 
              c[ 16][ t]], 
            Times[ -0.10394325375429328, 
              c[ 17][ t]], 
            Times[ -0.06935801494512607, 
              c[ 18][ t]], 
            Times[ -0.034231213779558949, 
              c[ 19][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 20][ t]], 
            Times[ 0.032022748374425904, 
              c[ 21][ t]], 
            Times[ 0.060688263076985001, 
              c[ 22][ t]], 
            Times[ 0.085044480344421705, 
              c[ 23][ t]], 
            Times[ 0.10436044624225685, 
              c[ 24][ t]], 
            Times[ 0.11814190616181253, 
              c[ 25][ t]], 
            Times[ 0.12613778810677614, 
              c[ 26][ t]], 
            Times[ 0.12833762891430928, 
              c[ 27][ t]], 
            Times[ 0.12496032289024853, 
              c[ 28][ t]], 
            Times[ 0.11643488132933186, 
              c[ 29][ t]], 
            Times[ 0.10337416789158609, 
              c[ 30][ t]], 
            Times[ 0.086542809078944891, 
              c[ 31][ t]], 
            Times[ 0.066820663127759972, 
              c[ 32][ t]], 
            Times[ 0.045163358568919301, 
              c[ 33][ t]], 
            Times[ 0.022561481809254869, 
              c[ 34][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 35][ t]], 
            Times[ -0.021580547817547879, 
              c[ 36][ t]], 
            Times[ -0.04131966847794722, 
              c[ 37][ t]], 
            Times[ -0.058468080236789913, 
              c[ 38][ t]], 
            Times[ -0.072413370861974122, 
              c[ 39][ t]], 
            Times[ -0.082699334313268744, 
              c[ 40][ t]], 
            Times[ -0.089038438663606653, 
              c[ 41][ t]], 
            Times[ -0.091317159035181589, 
              c[ 42][ t]], 
            Times[ -0.089594193770366884, 
              c[ 43][ t]], 
            Times[ -0.084091858737850855, 
              c[ 44][ t]], 
            Times[ -0.075181213012062598, 
              c[ 45][ t]], 
            Times[ -0.063361699504227528, 
              c[ 46][ t]], 
            Times[ -0.049236278094139066, 
              c[ 47][ t]], 
            Times[ -0.033483179628681567, 
              c[ 48][ t]], 
            Times[ -0.016825511857749401, 
              c[ 49][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 50][ t]], 
            Times[ 0.016273855731265604, 
              c[ 51][ t]], 
            Times[ 0.031322974491347078, 
              c[ 52][ t]], 
            Times[ 0.044547108751839815, 
              c[ 53][ t]], 
            Times[ 0.055441487066198933, 
              c[ 54][ t]], 
            Times[ 0.063614872548668253, 
              c[ 55][ t]], 
            Times[ 0.068802429876423321, 
              c[ 56][ t]], 
            Times[ 0.070873018952678238, 
              c[ 57][ t]], 
            Times[ 0.069830768673962415, 
              c[ 58][ t]], 
            Times[ 0.065811019881796315, 
              c[ 59][ t]], 
            Times[ 0.059070953080906326, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-9\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-9\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.0890384386636067`\)\ \(c[\(-60\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-59\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-58\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-57\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-56\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-55\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-54\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-53\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-52\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-51\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-50\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-49\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-48\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-47\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-46\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-45\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-44\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-43\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-42\)]\)[t] + 
            0.060688263076985`\ \(c[\(-41\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-40\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-39\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-38\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-37\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-36\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-35\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-34\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-33\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-32\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-31\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-30\)]\)[t] - 
            0.206748335783172`\ \(c[\(-29\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-28\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-27\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-26\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-25\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-24\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-23\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-22\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-21\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-20\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-19\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-18\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-17\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-16\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-15\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-14\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-13\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-12\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-11\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-10\)]\)[t] + 
            2.7765287921960846`\ \(c[\(-9\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-8\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-7\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-6\)]\)[t] + 
            0.8870637930591837`\ \(c[\(-5\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-4\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-3\)]\)[t] + 
            0.6783560385470633`\ \(c[\(-2\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-1\)]\)[t] + 
            0.5045511524271047`\ \(c[0]\)[t] + 
            0.4134966715663442`\ \(c[1]\)[t] + 
            0.32256865202152135`\ \(c[2]\)[t] + 
            0.23387232094715985`\ \(c[3]\)[t] + 
            0.14938649372796362`\ \(c[4]\)[t] + 
            0.07090751425765777`\ \(c[5]\)[t] + 
            3.898171832519376`*^-17\ \(c[6]\)[t] - 
            0.06204407497545034`\ \(c[7]\)[t] - 
            0.11423673049785436`\ \(c[8]\)[t] - 
            0.15591488063143982`\ \(c[9]\)[t] - 
            0.186750272222986`\ \(c[10]\)[t] - 
            0.206748335783172`\ \(c[11]\)[t] - 
            0.21623620818304484`\ \(c[12]\)[t] - 
            0.21584055771952015`\ \(c[13]\)[t] - 
            0.20645618564475843`\ \(c[14]\)[t] - 
            0.18920668216016426`\ \(c[15]\)[t] - 
            0.1653986686265377`\ \(c[16]\)[t] - 
            0.13647135277833605`\ \(c[17]\)[t] - 
            0.10394325375429328`\ \(c[18]\)[t] - 
            0.06935801494512607`\ \(c[19]\)[t] - 
            0.03423121377955895`\ \(c[20]\)[t] - 
            3.898171832519376`*^-17\ \(c[21]\)[t] + 
            0.032022748374425904`\ \(c[22]\)[t] + 
            0.060688263076985105`\ \(c[23]\)[t] + 
            0.0850444803444217`\ \(c[24]\)[t] + 
            0.10436044624225685`\ \(c[25]\)[t] + 
            0.11814190616181255`\ \(c[26]\)[t] + 
            0.12613778810677614`\ \(c[27]\)[t] + 
            0.12833762891430928`\ \(c[28]\)[t] + 
            0.12496032289024853`\ \(c[29]\)[t] + 
            0.11643488132933186`\ \(c[30]\)[t] + 
            0.10337416789158609`\ \(c[31]\)[t] + 
            0.08654280907894489`\ \(c[32]\)[t] + 
            0.06682066312775997`\ \(c[33]\)[t] + 
            0.0451633585689193`\ \(c[34]\)[t] + 
            0.02256148180925487`\ \(c[35]\)[t] + 
            3.8981718325193755`*^-17\ \(c[36]\)[t] - 
            0.02158054781754788`\ \(c[37]\)[t] - 
            0.04131966847794722`\ \(c[38]\)[t] - 
            0.05846808023678991`\ \(c[39]\)[t] - 
            0.07241337086197412`\ \(c[40]\)[t] - 
            0.08269933431326874`\ \(c[41]\)[t] - 
            0.0890384386636067`\ \(c[42]\)[t] - 
            0.09131715903518159`\ \(c[43]\)[t] - 
            0.08959419377036688`\ \(c[44]\)[t] - 
            0.08409185873785081`\ \(c[45]\)[t] - 
            0.0751812130120626`\ \(c[46]\)[t] - 
            0.06336169950422753`\ \(c[47]\)[t] - 
            0.04923627809413894`\ \(c[48]\)[t] - 
            0.03348317962868157`\ \(c[49]\)[t] - 
            0.0168255118577494`\ \(c[50]\)[t] - 
            3.898171832519376`*^-17\ \(c[51]\)[t] + 
            0.016273855731265604`\ \(c[52]\)[t] + 
            0.03132297449134708`\ \(c[53]\)[t] + 
            0.04454710875183992`\ \(c[54]\)[t] + 
            0.05544148706619893`\ \(c[55]\)[t] + 
            0.06361487254866825`\ \(c[56]\)[t] + 
            0.06880242987642335`\ \(c[57]\)[t] + 
            0.07087301895267824`\ \(c[58]\)[t] + 
            0.06983076867396242`\ \(c[59]\)[t] + 
            0.06581101988179627`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -9, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -9]][ t]], 
          Plus[ 
            Times[ -0.089038438663606695, 
              c[ -60][ t]], 
            Times[ -0.082699334313268744, 
              c[ -59][ t]], 
            Times[ -0.072413370861974122, 
              c[ -58][ t]], 
            Times[ -0.058468080236789913, 
              c[ -57][ t]], 
            Times[ -0.04131966847794722, 
              c[ -56][ t]], 
            Times[ -0.021580547817547879, 
              c[ -55][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -54][ t]], 
            Times[ 0.022561481809254869, 
              c[ -53][ t]], 
            Times[ 0.045163358568919301, 
              c[ -52][ t]], 
            Times[ 0.066820663127759972, 
              c[ -51][ t]], 
            Times[ 0.086542809078944891, 
              c[ -50][ t]], 
            Times[ 0.10337416789158609, 
              c[ -49][ t]], 
            Times[ 0.11643488132933186, 
              c[ -48][ t]], 
            Times[ 0.12496032289024853, 
              c[ -47][ t]], 
            Times[ 0.12833762891430928, 
              c[ -46][ t]], 
            Times[ 0.12613778810677614, 
              c[ -45][ t]], 
            Times[ 0.11814190616181253, 
              c[ -44][ t]], 
            Times[ 0.10436044624225685, 
              c[ -43][ t]], 
            Times[ 0.085044480344421705, 
              c[ -42][ t]], 
            Times[ 0.060688263076985001, 
              c[ -41][ t]], 
            Times[ 0.032022748374425904, 
              c[ -40][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -39][ t]], 
            Times[ -0.034231213779558949, 
              c[ -38][ t]], 
            Times[ -0.06935801494512607, 
              c[ -37][ t]], 
            Times[ -0.10394325375429328, 
              c[ -36][ t]], 
            Times[ -0.13647135277833605, 
              c[ -35][ t]], 
            Times[ -0.16539866862653771, 
              c[ -34][ t]], 
            Times[ -0.18920668216016426, 
              c[ -33][ t]], 
            Times[ -0.20645618564475843, 
              c[ -32][ t]], 
            Times[ -0.21584055771952015, 
              c[ -31][ t]], 
            Times[ -0.21623620818304484, 
              c[ -30][ t]], 
            Times[ -0.206748335783172, 
              c[ -29][ t]], 
            Times[ -0.18675027222298593, 
              c[ -28][ t]], 
            Times[ -0.15591488063143982, 
              c[ -27][ t]], 
            Times[ -0.11423673049785436, 
              c[ -26][ t]], 
            Times[ -0.062044074975450239, 
              c[ -25][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -24][ t]], 
            Times[ 0.070907514257657775, 
              c[ -23][ t]], 
            Times[ 0.14938649372796384, 
              c[ -22][ t]], 
            Times[ 0.23387232094715985, 
              c[ -21][ t]], 
            Times[ 0.32256865202152157, 
              c[ -20][ t]], 
            Times[ 0.41349667156634418, 
              c[ -19][ t]], 
            Times[ 0.50455115242710469, 
              c[ -18][ t]], 
            Times[ 0.59356153372868059, 
              c[ -17][ t]], 
            Times[ 0.67835603854706339, 
              c[ -16][ t]], 
            Times[ 0.75682672864065692, 
              c[ -15][ t]], 
            Times[ 0.82699334313268813, 
              c[ -14][ t]], 
            Times[ 0.88706379305918381, 
              c[ -13][ t]], 
            Times[ 0.93548928378863916, 
              c[ -12][ t]], 
            Times[ 0.9710122092317629, 
              c[ -11][ t]], 
            Times[ 0.99270519960720693, 
              c[ -10][ t]], 
            Times[ 2.7765287921960846, 
              c[ -9][ t]], 
            Times[ 0.99270519960720671, 
              c[ -8][ t]], 
            Times[ 0.9710122092317629, 
              c[ -7][ t]], 
            Times[ 0.93548928378863916, 
              c[ -6][ t]], 
            Times[ 0.8870637930591837, 
              c[ -5][ t]], 
            Times[ 0.82699334313268813, 
              c[ -4][ t]], 
            Times[ 0.75682672864065692, 
              c[ -3][ t]], 
            Times[ 0.67835603854706328, 
              c[ -2][ t]], 
            Times[ 0.59356153372868048, 
              c[ -1][ t]], 
            Times[ 0.50455115242710469, 
              c[ 0][ t]], 
            Times[ 0.41349667156634418, 
              c[ 1][ t]], 
            Times[ 0.32256865202152135, 
              c[ 2][ t]], 
            Times[ 0.23387232094715985, 
              c[ 3][ t]], 
            Times[ 0.14938649372796362, 
              c[ 4][ t]], 
            Times[ 0.070907514257657775, 
              c[ 5][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 6][ t]], 
            Times[ -0.062044074975450343, 
              c[ 7][ t]], 
            Times[ -0.11423673049785436, 
              c[ 8][ t]], 
            Times[ -0.15591488063143982, 
              c[ 9][ t]], 
            Times[ -0.18675027222298601, 
              c[ 10][ t]], 
            Times[ -0.206748335783172, 
              c[ 11][ t]], 
            Times[ -0.21623620818304484, 
              c[ 12][ t]], 
            Times[ -0.21584055771952015, 
              c[ 13][ t]], 
            Times[ -0.20645618564475843, 
              c[ 14][ t]], 
            Times[ -0.18920668216016426, 
              c[ 15][ t]], 
            Times[ -0.16539866862653771, 
              c[ 16][ t]], 
            Times[ -0.13647135277833605, 
              c[ 17][ t]], 
            Times[ -0.10394325375429328, 
              c[ 18][ t]], 
            Times[ -0.06935801494512607, 
              c[ 19][ t]], 
            Times[ -0.034231213779558949, 
              c[ 20][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 21][ t]], 
            Times[ 0.032022748374425904, 
              c[ 22][ t]], 
            Times[ 0.060688263076985105, 
              c[ 23][ t]], 
            Times[ 0.085044480344421705, 
              c[ 24][ t]], 
            Times[ 0.10436044624225685, 
              c[ 25][ t]], 
            Times[ 0.11814190616181255, 
              c[ 26][ t]], 
            Times[ 0.12613778810677614, 
              c[ 27][ t]], 
            Times[ 0.12833762891430928, 
              c[ 28][ t]], 
            Times[ 0.12496032289024853, 
              c[ 29][ t]], 
            Times[ 0.11643488132933186, 
              c[ 30][ t]], 
            Times[ 0.10337416789158609, 
              c[ 31][ t]], 
            Times[ 0.086542809078944891, 
              c[ 32][ t]], 
            Times[ 0.066820663127759972, 
              c[ 33][ t]], 
            Times[ 0.045163358568919301, 
              c[ 34][ t]], 
            Times[ 0.022561481809254869, 
              c[ 35][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 36][ t]], 
            Times[ -0.021580547817547879, 
              c[ 37][ t]], 
            Times[ -0.04131966847794722, 
              c[ 38][ t]], 
            Times[ -0.058468080236789913, 
              c[ 39][ t]], 
            Times[ -0.072413370861974122, 
              c[ 40][ t]], 
            Times[ -0.082699334313268744, 
              c[ 41][ t]], 
            Times[ -0.089038438663606695, 
              c[ 42][ t]], 
            Times[ -0.091317159035181589, 
              c[ 43][ t]], 
            Times[ -0.089594193770366884, 
              c[ 44][ t]], 
            Times[ -0.084091858737850814, 
              c[ 45][ t]], 
            Times[ -0.075181213012062598, 
              c[ 46][ t]], 
            Times[ -0.063361699504227528, 
              c[ 47][ t]], 
            Times[ -0.049236278094138941, 
              c[ 48][ t]], 
            Times[ -0.033483179628681567, 
              c[ 49][ t]], 
            Times[ -0.016825511857749401, 
              c[ 50][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 51][ t]], 
            Times[ 0.016273855731265604, 
              c[ 52][ t]], 
            Times[ 0.031322974491347078, 
              c[ 53][ t]], 
            Times[ 0.044547108751839919, 
              c[ 54][ t]], 
            Times[ 0.055441487066198933, 
              c[ 55][ t]], 
            Times[ 0.063614872548668253, 
              c[ 56][ t]], 
            Times[ 0.068802429876423349, 
              c[ 57][ t]], 
            Times[ 0.070873018952678238, 
              c[ 58][ t]], 
            Times[ 0.069830768673962415, 
              c[ 59][ t]], 
            Times[ 0.065811019881796273, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-8\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-8\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.09131715903518159`\)\ \(c[\(-60\)]\)[t] - 
            0.08903843866360665`\ \(c[\(-59\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-58\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-57\)]\)[t] - 
            0.058468080236789774`\ \(c[\(-56\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-55\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-54\)]\)[t] + 
            2.274590327822911`*^-16\ \(c[\(-53\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-52\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-51\)]\)[t] + 
            0.06682066312776015`\ \(c[\(-50\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-49\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-48\)]\)[t] + 
            0.11643488132933195`\ \(c[\(-47\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-46\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-45\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-44\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-43\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-42\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-41\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-40\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-39\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-38\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-37\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-36\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-35\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-34\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-33\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-32\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-31\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-30\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-29\)]\)[t] - 
            0.206748335783172`\ \(c[\(-28\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-27\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-26\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-25\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-24\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-23\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-22\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-21\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-20\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-19\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-18\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-17\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-16\)]\)[t] + 
            0.6783560385470633`\ \(c[\(-15\)]\)[t] + 
            0.756826728640657`\ \(c[\(-14\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-13\)]\)[t] + 
            0.8870637930591837`\ \(c[\(-12\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-11\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-10\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-9\)]\)[t] + 
            2.403677070377153`\ \(c[\(-8\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-7\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-6\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-5\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-4\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-3\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-2\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-1\)]\)[t] + 
            0.5935615337286805`\ \(c[0]\)[t] + 
            0.5045511524271047`\ \(c[1]\)[t] + 
            0.4134966715663442`\ \(c[2]\)[t] + 
            0.3225686520215216`\ \(c[3]\)[t] + 
            0.23387232094715985`\ \(c[4]\)[t] + 
            0.14938649372796362`\ \(c[5]\)[t] + 
            0.07090751425765777`\ \(c[6]\)[t] + 
            3.898171832519376`*^-17\ \(c[7]\)[t] - 
            0.06204407497545034`\ \(c[8]\)[t] - 
            0.11423673049785436`\ \(c[9]\)[t] - 
            0.15591488063143982`\ \(c[10]\)[t] - 
            0.18675027222298593`\ \(c[11]\)[t] - 
            0.206748335783172`\ \(c[12]\)[t] - 
            0.21623620818304484`\ \(c[13]\)[t] - 
            0.21584055771952015`\ \(c[14]\)[t] - 
            0.20645618564475843`\ \(c[15]\)[t] - 
            0.18920668216016426`\ \(c[16]\)[t] - 
            0.1653986686265377`\ \(c[17]\)[t] - 
            0.13647135277833605`\ \(c[18]\)[t] - 
            0.10394325375429328`\ \(c[19]\)[t] - 
            0.06935801494512607`\ \(c[20]\)[t] - 
            0.03423121377955895`\ \(c[21]\)[t] - 
            1.8033970416801674`*^-16\ \(c[22]\)[t] + 
            0.032022748374425904`\ \(c[23]\)[t] + 
            0.060688263076985105`\ \(c[24]\)[t] + 
            0.08504448034442161`\ \(c[25]\)[t] + 
            0.10436044624225685`\ \(c[26]\)[t] + 
            0.11814190616181255`\ \(c[27]\)[t] + 
            0.12613778810677612`\ \(c[28]\)[t] + 
            0.12833762891430928`\ \(c[29]\)[t] + 
            0.12496032289024853`\ \(c[30]\)[t] + 
            0.11643488132933186`\ \(c[31]\)[t] + 
            0.10337416789158609`\ \(c[32]\)[t] + 
            0.08654280907894475`\ \(c[33]\)[t] + 
            0.06682066312775997`\ \(c[34]\)[t] + 
            0.0451633585689193`\ \(c[35]\)[t] + 
            0.022561481809254675`\ \(c[36]\)[t] + 
            3.8981718325193755`*^-17\ \(c[37]\)[t] - 
            0.02158054781754788`\ \(c[38]\)[t] - 
            0.04131966847794737`\ \(c[39]\)[t] - 
            0.05846808023678991`\ \(c[40]\)[t] - 
            0.07241337086197412`\ \(c[41]\)[t] - 
            0.08269933431326881`\ \(c[42]\)[t] - 
            0.0890384386636067`\ \(c[43]\)[t] - 
            0.09131715903518159`\ \(c[44]\)[t] - 
            0.08959419377036684`\ \(c[45]\)[t] - 
            0.08409185873785081`\ \(c[46]\)[t] - 
            0.0751812130120626`\ \(c[47]\)[t] - 
            0.0633616995042274`\ \(c[48]\)[t] - 
            0.04923627809413894`\ \(c[49]\)[t] - 
            0.03348317962868157`\ \(c[50]\)[t] - 
            0.016825511857749262`\ \(c[51]\)[t] - 
            3.898171832519376`*^-17\ \(c[52]\)[t] + 
            0.016273855731265604`\ \(c[53]\)[t] + 
            0.0313229744913472`\ \(c[54]\)[t] + 
            0.04454710875183992`\ \(c[55]\)[t] + 
            0.05544148706619893`\ \(c[56]\)[t] + 
            0.06361487254866832`\ \(c[57]\)[t] + 
            0.06880242987642335`\ \(c[58]\)[t] + 
            0.07087301895267824`\ \(c[59]\)[t] + 
            0.06983076867396239`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -8, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -8]][ t]], 
          Plus[ 
            Times[ -0.091317159035181589, 
              c[ -60][ t]], 
            Times[ -0.089038438663606653, 
              c[ -59][ t]], 
            Times[ -0.082699334313268744, 
              c[ -58][ t]], 
            Times[ -0.072413370861974122, 
              c[ -57][ t]], 
            Times[ -0.058468080236789774, 
              c[ -56][ t]], 
            Times[ -0.04131966847794722, 
              c[ -55][ t]], 
            Times[ -0.021580547817547879, 
              c[ -54][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ -53][ t]], 
            Times[ 0.022561481809254869, 
              c[ -52][ t]], 
            Times[ 0.045163358568919301, 
              c[ -51][ t]], 
            Times[ 0.066820663127760152, 
              c[ -50][ t]], 
            Times[ 0.086542809078944891, 
              c[ -49][ t]], 
            Times[ 0.10337416789158609, 
              c[ -48][ t]], 
            Times[ 0.11643488132933195, 
              c[ -47][ t]], 
            Times[ 0.12496032289024853, 
              c[ -46][ t]], 
            Times[ 0.12833762891430925, 
              c[ -45][ t]], 
            Times[ 0.12613778810677612, 
              c[ -44][ t]], 
            Times[ 0.11814190616181255, 
              c[ -43][ t]], 
            Times[ 0.10436044624225692, 
              c[ -42][ t]], 
            Times[ 0.085044480344421608, 
              c[ -41][ t]], 
            Times[ 0.060688263076985105, 
              c[ -40][ t]], 
            Times[ 0.032022748374426029, 
              c[ -39][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -38][ t]], 
            Times[ -0.034231213779558949, 
              c[ -37][ t]], 
            Times[ -0.069358014945125918, 
              c[ -36][ t]], 
            Times[ -0.10394325375429328, 
              c[ -35][ t]], 
            Times[ -0.13647135277833605, 
              c[ -34][ t]], 
            Times[ -0.1653986686265376, 
              c[ -33][ t]], 
            Times[ -0.18920668216016426, 
              c[ -32][ t]], 
            Times[ -0.20645618564475843, 
              c[ -31][ t]], 
            Times[ -0.21584055771952013, 
              c[ -30][ t]], 
            Times[ -0.21623620818304484, 
              c[ -29][ t]], 
            Times[ -0.206748335783172, 
              c[ -28][ t]], 
            Times[ -0.18675027222298607, 
              c[ -27][ t]], 
            Times[ -0.15591488063143982, 
              c[ -26][ t]], 
            Times[ -0.11423673049785436, 
              c[ -25][ t]], 
            Times[ -0.062044074975450475, 
              c[ -24][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -23][ t]], 
            Times[ 0.070907514257657775, 
              c[ -22][ t]], 
            Times[ 0.14938649372796345, 
              c[ -21][ t]], 
            Times[ 0.23387232094715985, 
              c[ -20][ t]], 
            Times[ 0.32256865202152157, 
              c[ -19][ t]], 
            Times[ 0.41349667156634395, 
              c[ -18][ t]], 
            Times[ 0.50455115242710469, 
              c[ -17][ t]], 
            Times[ 0.59356153372868048, 
              c[ -16][ t]], 
            Times[ 0.67835603854706328, 
              c[ -15][ t]], 
            Times[ 0.75682672864065703, 
              c[ -14][ t]], 
            Times[ 0.82699334313268824, 
              c[ -13][ t]], 
            Times[ 0.8870637930591837, 
              c[ -12][ t]], 
            Times[ 0.93548928378863916, 
              c[ -11][ t]], 
            Times[ 0.9710122092317629, 
              c[ -10][ t]], 
            Times[ 0.99270519960720671, 
              c[ -9][ t]], 
            Times[ 2.4036770703771531, 
              c[ -8][ t]], 
            Times[ 0.99270519960720671, 
              c[ -7][ t]], 
            Times[ 0.9710122092317629, 
              c[ -6][ t]], 
            Times[ 0.93548928378863916, 
              c[ -5][ t]], 
            Times[ 0.88706379305918381, 
              c[ -4][ t]], 
            Times[ 0.82699334313268824, 
              c[ -3][ t]], 
            Times[ 0.75682672864065692, 
              c[ -2][ t]], 
            Times[ 0.67835603854706339, 
              c[ -1][ t]], 
            Times[ 0.59356153372868048, 
              c[ 0][ t]], 
            Times[ 0.50455115242710469, 
              c[ 1][ t]], 
            Times[ 0.41349667156634418, 
              c[ 2][ t]], 
            Times[ 0.32256865202152157, 
              c[ 3][ t]], 
            Times[ 0.23387232094715985, 
              c[ 4][ t]], 
            Times[ 0.14938649372796362, 
              c[ 5][ t]], 
            Times[ 0.070907514257657775, 
              c[ 6][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 7][ t]], 
            Times[ -0.062044074975450343, 
              c[ 8][ t]], 
            Times[ -0.11423673049785436, 
              c[ 9][ t]], 
            Times[ -0.15591488063143982, 
              c[ 10][ t]], 
            Times[ -0.18675027222298593, 
              c[ 11][ t]], 
            Times[ -0.206748335783172, 
              c[ 12][ t]], 
            Times[ -0.21623620818304484, 
              c[ 13][ t]], 
            Times[ -0.21584055771952015, 
              c[ 14][ t]], 
            Times[ -0.20645618564475843, 
              c[ 15][ t]], 
            Times[ -0.18920668216016426, 
              c[ 16][ t]], 
            Times[ -0.16539866862653771, 
              c[ 17][ t]], 
            Times[ -0.13647135277833605, 
              c[ 18][ t]], 
            Times[ -0.10394325375429328, 
              c[ 19][ t]], 
            Times[ -0.06935801494512607, 
              c[ 20][ t]], 
            Times[ -0.034231213779558949, 
              c[ 21][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 22][ t]], 
            Times[ 0.032022748374425904, 
              c[ 23][ t]], 
            Times[ 0.060688263076985105, 
              c[ 24][ t]], 
            Times[ 0.085044480344421608, 
              c[ 25][ t]], 
            Times[ 0.10436044624225685, 
              c[ 26][ t]], 
            Times[ 0.11814190616181255, 
              c[ 27][ t]], 
            Times[ 0.12613778810677612, 
              c[ 28][ t]], 
            Times[ 0.12833762891430928, 
              c[ 29][ t]], 
            Times[ 0.12496032289024853, 
              c[ 30][ t]], 
            Times[ 0.11643488132933186, 
              c[ 31][ t]], 
            Times[ 0.10337416789158609, 
              c[ 32][ t]], 
            Times[ 0.086542809078944752, 
              c[ 33][ t]], 
            Times[ 0.066820663127759972, 
              c[ 34][ t]], 
            Times[ 0.045163358568919301, 
              c[ 35][ t]], 
            Times[ 0.022561481809254675, 
              c[ 36][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 37][ t]], 
            Times[ -0.021580547817547879, 
              c[ 38][ t]], 
            Times[ -0.041319668477947373, 
              c[ 39][ t]], 
            Times[ -0.058468080236789913, 
              c[ 40][ t]], 
            Times[ -0.072413370861974122, 
              c[ 41][ t]], 
            Times[ -0.082699334313268813, 
              c[ 42][ t]], 
            Times[ -0.089038438663606695, 
              c[ 43][ t]], 
            Times[ -0.091317159035181589, 
              c[ 44][ t]], 
            Times[ -0.089594193770366842, 
              c[ 45][ t]], 
            Times[ -0.084091858737850814, 
              c[ 46][ t]], 
            Times[ -0.075181213012062598, 
              c[ 47][ t]], 
            Times[ -0.063361699504227403, 
              c[ 48][ t]], 
            Times[ -0.049236278094138941, 
              c[ 49][ t]], 
            Times[ -0.033483179628681567, 
              c[ 50][ t]], 
            Times[ -0.016825511857749262, 
              c[ 51][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 52][ t]], 
            Times[ 0.016273855731265604, 
              c[ 53][ t]], 
            Times[ 0.031322974491347202, 
              c[ 54][ t]], 
            Times[ 0.044547108751839919, 
              c[ 55][ t]], 
            Times[ 0.055441487066198933, 
              c[ 56][ t]], 
            Times[ 0.063614872548668322, 
              c[ 57][ t]], 
            Times[ 0.068802429876423349, 
              c[ 58][ t]], 
            Times[ 0.070873018952678238, 
              c[ 59][ t]], 
            Times[ 0.069830768673962387, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-7\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-7\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.08959419377036684`\)\ \(c[\(-60\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-59\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-58\)]\)[t] - 
            0.08269933431326881`\ \(c[\(-57\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-56\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-55\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-54\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-53\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-52\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-51\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-50\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-49\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-48\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-47\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-46\)]\)[t] + 
            0.12496032289024847`\ \(c[\(-45\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-44\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-43\)]\)[t] + 
            0.1181419061618126`\ \(c[\(-42\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-41\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-40\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-39\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-38\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-37\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-36\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-35\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-34\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-33\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-32\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-31\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-30\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-29\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-28\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-27\)]\)[t] - 
            0.186750272222986`\ \(c[\(-26\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-25\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-24\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-23\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-22\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-21\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-20\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-19\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-18\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-17\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-16\)]\)[t] + 
            0.5935615337286803`\ \(c[\(-15\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-14\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-13\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-12\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-11\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-10\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-9\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-8\)]\)[t] + 
            2.0746902570075076`\ \(c[\(-7\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-6\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-5\)]\)[t] + 
            0.935489283788639`\ \(c[\(-4\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-3\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-2\)]\)[t] + 
            0.756826728640657`\ \(c[\(-1\)]\)[t] + 
            0.6783560385470634`\ \(c[0]\)[t] + 
            0.5935615337286805`\ \(c[1]\)[t] + 
            0.5045511524271047`\ \(c[2]\)[t] + 
            0.4134966715663442`\ \(c[3]\)[t] + 
            0.3225686520215216`\ \(c[4]\)[t] + 
            0.23387232094715985`\ \(c[5]\)[t] + 
            0.14938649372796362`\ \(c[6]\)[t] + 
            0.07090751425765777`\ \(c[7]\)[t] + 
            3.898171832519376`*^-17\ \(c[8]\)[t] - 
            0.06204407497545034`\ \(c[9]\)[t] - 
            0.11423673049785436`\ \(c[10]\)[t] - 
            0.15591488063143974`\ \(c[11]\)[t] - 
            0.186750272222986`\ \(c[12]\)[t] - 
            0.206748335783172`\ \(c[13]\)[t] - 
            0.21623620818304484`\ \(c[14]\)[t] - 
            0.21584055771952015`\ \(c[15]\)[t] - 
            0.20645618564475843`\ \(c[16]\)[t] - 
            0.18920668216016426`\ \(c[17]\)[t] - 
            0.1653986686265377`\ \(c[18]\)[t] - 
            0.13647135277833605`\ \(c[19]\)[t] - 
            0.10394325375429328`\ \(c[20]\)[t] - 
            0.06935801494512607`\ \(c[21]\)[t] - 
            0.034231213779559094`\ \(c[22]\)[t] - 
            3.898171832519376`*^-17\ \(c[23]\)[t] + 
            0.032022748374425904`\ \(c[24]\)[t] + 
            0.060688263076985`\ \(c[25]\)[t] + 
            0.0850444803444217`\ \(c[26]\)[t] + 
            0.10436044624225685`\ \(c[27]\)[t] + 
            0.11814190616181253`\ \(c[28]\)[t] + 
            0.12613778810677614`\ \(c[29]\)[t] + 
            0.12833762891430928`\ \(c[30]\)[t] + 
            0.12496032289024853`\ \(c[31]\)[t] + 
            0.11643488132933186`\ \(c[32]\)[t] + 
            0.10337416789158609`\ \(c[33]\)[t] + 
            0.08654280907894489`\ \(c[34]\)[t] + 
            0.06682066312775997`\ \(c[35]\)[t] + 
            0.0451633585689193`\ \(c[36]\)[t] + 
            0.02256148180925487`\ \(c[37]\)[t] + 
            3.8981718325193755`*^-17\ \(c[38]\)[t] - 
            0.02158054781754788`\ \(c[39]\)[t] - 
            0.04131966847794722`\ \(c[40]\)[t] - 
            0.058468080236789774`\ \(c[41]\)[t] - 
            0.07241337086197412`\ \(c[42]\)[t] - 
            0.08269933431326874`\ \(c[43]\)[t] - 
            0.08903843866360665`\ \(c[44]\)[t] - 
            0.09131715903518159`\ \(c[45]\)[t] - 
            0.08959419377036688`\ \(c[46]\)[t] - 
            0.08409185873785086`\ \(c[47]\)[t] - 
            0.0751812130120626`\ \(c[48]\)[t] - 
            0.06336169950422753`\ \(c[49]\)[t] - 
            0.049236278094139066`\ \(c[50]\)[t] - 
            0.03348317962868157`\ \(c[51]\)[t] - 
            0.0168255118577494`\ \(c[52]\)[t] - 
            1.8033970416801674`*^-16\ \(c[53]\)[t] + 
            0.016273855731265604`\ \(c[54]\)[t] + 
            0.03132297449134708`\ \(c[55]\)[t] + 
            0.044547108751839815`\ \(c[56]\)[t] + 
            0.05544148706619893`\ \(c[57]\)[t] + 
            0.06361487254866825`\ \(c[58]\)[t] + 
            0.06880242987642332`\ \(c[59]\)[t] + 
            0.07087301895267824`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -7, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -7]][ t]], 
          Plus[ 
            Times[ -0.089594193770366842, 
              c[ -60][ t]], 
            Times[ -0.091317159035181589, 
              c[ -59][ t]], 
            Times[ -0.089038438663606695, 
              c[ -58][ t]], 
            Times[ -0.082699334313268813, 
              c[ -57][ t]], 
            Times[ -0.072413370861974122, 
              c[ -56][ t]], 
            Times[ -0.058468080236789913, 
              c[ -55][ t]], 
            Times[ -0.041319668477947373, 
              c[ -54][ t]], 
            Times[ -0.021580547817547879, 
              c[ -53][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -52][ t]], 
            Times[ 0.022561481809254675, 
              c[ -51][ t]], 
            Times[ 0.045163358568919301, 
              c[ -50][ t]], 
            Times[ 0.066820663127759972, 
              c[ -49][ t]], 
            Times[ 0.086542809078944752, 
              c[ -48][ t]], 
            Times[ 0.10337416789158609, 
              c[ -47][ t]], 
            Times[ 0.11643488132933186, 
              c[ -46][ t]], 
            Times[ 0.12496032289024847, 
              c[ -45][ t]], 
            Times[ 0.12833762891430928, 
              c[ -44][ t]], 
            Times[ 0.12613778810677614, 
              c[ -43][ t]], 
            Times[ 0.1181419061618126, 
              c[ -42][ t]], 
            Times[ 0.10436044624225685, 
              c[ -41][ t]], 
            Times[ 0.085044480344421705, 
              c[ -40][ t]], 
            Times[ 0.060688263076985223, 
              c[ -39][ t]], 
            Times[ 0.032022748374425904, 
              c[ -38][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -37][ t]], 
            Times[ -0.034231213779558796, 
              c[ -36][ t]], 
            Times[ -0.06935801494512607, 
              c[ -35][ t]], 
            Times[ -0.10394325375429328, 
              c[ -34][ t]], 
            Times[ -0.13647135277833591, 
              c[ -33][ t]], 
            Times[ -0.16539866862653771, 
              c[ -32][ t]], 
            Times[ -0.18920668216016426, 
              c[ -31][ t]], 
            Times[ -0.20645618564475834, 
              c[ -30][ t]], 
            Times[ -0.21584055771952015, 
              c[ -29][ t]], 
            Times[ -0.21623620818304484, 
              c[ -28][ t]], 
            Times[ -0.20674833578317206, 
              c[ -27][ t]], 
            Times[ -0.18675027222298601, 
              c[ -26][ t]], 
            Times[ -0.15591488063143974, 
              c[ -25][ t]], 
            Times[ -0.11423673049785445, 
              c[ -24][ t]], 
            Times[ -0.062044074975450343, 
              c[ -23][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -22][ t]], 
            Times[ 0.070907514257657622, 
              c[ -21][ t]], 
            Times[ 0.14938649372796362, 
              c[ -20][ t]], 
            Times[ 0.23387232094715985, 
              c[ -19][ t]], 
            Times[ 0.32256865202152135, 
              c[ -18][ t]], 
            Times[ 0.41349667156634418, 
              c[ -17][ t]], 
            Times[ 0.50455115242710469, 
              c[ -16][ t]], 
            Times[ 0.59356153372868026, 
              c[ -15][ t]], 
            Times[ 0.67835603854706339, 
              c[ -14][ t]], 
            Times[ 0.75682672864065692, 
              c[ -13][ t]], 
            Times[ 0.82699334313268813, 
              c[ -12][ t]], 
            Times[ 0.88706379305918381, 
              c[ -11][ t]], 
            Times[ 0.93548928378863916, 
              c[ -10][ t]], 
            Times[ 0.9710122092317629, 
              c[ -9][ t]], 
            Times[ 0.99270519960720671, 
              c[ -8][ t]], 
            Times[ 2.0746902570075076, 
              c[ -7][ t]], 
            Times[ 0.99270519960720693, 
              c[ -6][ t]], 
            Times[ 0.9710122092317629, 
              c[ -5][ t]], 
            Times[ 0.93548928378863905, 
              c[ -4][ t]], 
            Times[ 0.88706379305918381, 
              c[ -3][ t]], 
            Times[ 0.82699334313268824, 
              c[ -2][ t]], 
            Times[ 0.75682672864065703, 
              c[ -1][ t]], 
            Times[ 0.67835603854706339, 
              c[ 0][ t]], 
            Times[ 0.59356153372868048, 
              c[ 1][ t]], 
            Times[ 0.50455115242710469, 
              c[ 2][ t]], 
            Times[ 0.41349667156634418, 
              c[ 3][ t]], 
            Times[ 0.32256865202152157, 
              c[ 4][ t]], 
            Times[ 0.23387232094715985, 
              c[ 5][ t]], 
            Times[ 0.14938649372796362, 
              c[ 6][ t]], 
            Times[ 0.070907514257657775, 
              c[ 7][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 8][ t]], 
            Times[ -0.062044074975450343, 
              c[ 9][ t]], 
            Times[ -0.11423673049785436, 
              c[ 10][ t]], 
            Times[ -0.15591488063143974, 
              c[ 11][ t]], 
            Times[ -0.18675027222298601, 
              c[ 12][ t]], 
            Times[ -0.206748335783172, 
              c[ 13][ t]], 
            Times[ -0.21623620818304484, 
              c[ 14][ t]], 
            Times[ -0.21584055771952015, 
              c[ 15][ t]], 
            Times[ -0.20645618564475843, 
              c[ 16][ t]], 
            Times[ -0.18920668216016426, 
              c[ 17][ t]], 
            Times[ -0.16539866862653771, 
              c[ 18][ t]], 
            Times[ -0.13647135277833605, 
              c[ 19][ t]], 
            Times[ -0.10394325375429328, 
              c[ 20][ t]], 
            Times[ -0.06935801494512607, 
              c[ 21][ t]], 
            Times[ -0.034231213779559094, 
              c[ 22][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 23][ t]], 
            Times[ 0.032022748374425904, 
              c[ 24][ t]], 
            Times[ 0.060688263076985001, 
              c[ 25][ t]], 
            Times[ 0.085044480344421705, 
              c[ 26][ t]], 
            Times[ 0.10436044624225685, 
              c[ 27][ t]], 
            Times[ 0.11814190616181253, 
              c[ 28][ t]], 
            Times[ 0.12613778810677614, 
              c[ 29][ t]], 
            Times[ 0.12833762891430928, 
              c[ 30][ t]], 
            Times[ 0.12496032289024853, 
              c[ 31][ t]], 
            Times[ 0.11643488132933186, 
              c[ 32][ t]], 
            Times[ 0.10337416789158609, 
              c[ 33][ t]], 
            Times[ 0.086542809078944891, 
              c[ 34][ t]], 
            Times[ 0.066820663127759972, 
              c[ 35][ t]], 
            Times[ 0.045163358568919301, 
              c[ 36][ t]], 
            Times[ 0.022561481809254869, 
              c[ 37][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 38][ t]], 
            Times[ -0.021580547817547879, 
              c[ 39][ t]], 
            Times[ -0.04131966847794722, 
              c[ 40][ t]], 
            Times[ -0.058468080236789774, 
              c[ 41][ t]], 
            Times[ -0.072413370861974122, 
              c[ 42][ t]], 
            Times[ -0.082699334313268744, 
              c[ 43][ t]], 
            Times[ -0.089038438663606653, 
              c[ 44][ t]], 
            Times[ -0.091317159035181589, 
              c[ 45][ t]], 
            Times[ -0.089594193770366884, 
              c[ 46][ t]], 
            Times[ -0.084091858737850855, 
              c[ 47][ t]], 
            Times[ -0.075181213012062598, 
              c[ 48][ t]], 
            Times[ -0.063361699504227528, 
              c[ 49][ t]], 
            Times[ -0.049236278094139066, 
              c[ 50][ t]], 
            Times[ -0.033483179628681567, 
              c[ 51][ t]], 
            Times[ -0.016825511857749401, 
              c[ 52][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 53][ t]], 
            Times[ 0.016273855731265604, 
              c[ 54][ t]], 
            Times[ 0.031322974491347078, 
              c[ 55][ t]], 
            Times[ 0.044547108751839815, 
              c[ 56][ t]], 
            Times[ 0.055441487066198933, 
              c[ 57][ t]], 
            Times[ 0.063614872548668253, 
              c[ 58][ t]], 
            Times[ 0.068802429876423321, 
              c[ 59][ t]], 
            Times[ 0.070873018952678238, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-6\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-6\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.08409185873785081`\)\ \(c[\(-60\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-59\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-58\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-57\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-56\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-55\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-54\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-53\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-52\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-51\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-50\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-49\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-48\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-47\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-46\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-45\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-44\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-43\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-42\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-41\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-40\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-39\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-38\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-37\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-36\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-35\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-34\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-33\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-32\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-31\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-30\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-29\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-28\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-27\)]\)[t] - 
            0.206748335783172`\ \(c[\(-26\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-25\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-24\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-23\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-22\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-21\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-20\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-19\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-18\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-17\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-16\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-15\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-14\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-13\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-12\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-11\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-10\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-9\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-8\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-7\)]\)[t] + 
            1.7895683520871486`\ \(c[\(-6\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-5\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-4\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-3\)]\)[t] + 
            0.8870637930591837`\ \(c[\(-2\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-1\)]\)[t] + 
            0.7568267286406569`\ \(c[0]\)[t] + 
            0.6783560385470633`\ \(c[1]\)[t] + 
            0.5935615337286805`\ \(c[2]\)[t] + 
            0.5045511524271047`\ \(c[3]\)[t] + 
            0.4134966715663442`\ \(c[4]\)[t] + 
            0.3225686520215216`\ \(c[5]\)[t] + 
            0.23387232094715985`\ \(c[6]\)[t] + 
            0.14938649372796362`\ \(c[7]\)[t] + 
            0.07090751425765777`\ \(c[8]\)[t] + 
            3.898171832519376`*^-17\ \(c[9]\)[t] - 
            0.06204407497545034`\ \(c[10]\)[t] - 
            0.11423673049785436`\ \(c[11]\)[t] - 
            0.15591488063143982`\ \(c[12]\)[t] - 
            0.186750272222986`\ \(c[13]\)[t] - 
            0.206748335783172`\ \(c[14]\)[t] - 
            0.21623620818304484`\ \(c[15]\)[t] - 
            0.21584055771952015`\ \(c[16]\)[t] - 
            0.20645618564475843`\ \(c[17]\)[t] - 
            0.18920668216016426`\ \(c[18]\)[t] - 
            0.1653986686265377`\ \(c[19]\)[t] - 
            0.13647135277833605`\ \(c[20]\)[t] - 
            0.10394325375429328`\ \(c[21]\)[t] - 
            0.06935801494512607`\ \(c[22]\)[t] - 
            0.03423121377955895`\ \(c[23]\)[t] - 
            3.898171832519376`*^-17\ \(c[24]\)[t] + 
            0.032022748374425904`\ \(c[25]\)[t] + 
            0.060688263076985105`\ \(c[26]\)[t] + 
            0.0850444803444217`\ \(c[27]\)[t] + 
            0.10436044624225685`\ \(c[28]\)[t] + 
            0.11814190616181255`\ \(c[29]\)[t] + 
            0.12613778810677614`\ \(c[30]\)[t] + 
            0.12833762891430928`\ \(c[31]\)[t] + 
            0.12496032289024853`\ \(c[32]\)[t] + 
            0.11643488132933186`\ \(c[33]\)[t] + 
            0.10337416789158609`\ \(c[34]\)[t] + 
            0.08654280907894489`\ \(c[35]\)[t] + 
            0.06682066312775997`\ \(c[36]\)[t] + 
            0.0451633585689193`\ \(c[37]\)[t] + 
            0.02256148180925487`\ \(c[38]\)[t] + 
            3.8981718325193755`*^-17\ \(c[39]\)[t] - 
            0.02158054781754788`\ \(c[40]\)[t] - 
            0.04131966847794722`\ \(c[41]\)[t] - 
            0.05846808023678991`\ \(c[42]\)[t] - 
            0.07241337086197412`\ \(c[43]\)[t] - 
            0.08269933431326874`\ \(c[44]\)[t] - 
            0.0890384386636067`\ \(c[45]\)[t] - 
            0.09131715903518159`\ \(c[46]\)[t] - 
            0.08959419377036688`\ \(c[47]\)[t] - 
            0.08409185873785081`\ \(c[48]\)[t] - 
            0.0751812130120626`\ \(c[49]\)[t] - 
            0.06336169950422753`\ \(c[50]\)[t] - 
            0.04923627809413894`\ \(c[51]\)[t] - 
            0.03348317962868157`\ \(c[52]\)[t] - 
            0.0168255118577494`\ \(c[53]\)[t] - 
            3.898171832519376`*^-17\ \(c[54]\)[t] + 
            0.016273855731265604`\ \(c[55]\)[t] + 
            0.03132297449134708`\ \(c[56]\)[t] + 
            0.04454710875183992`\ \(c[57]\)[t] + 
            0.05544148706619893`\ \(c[58]\)[t] + 
            0.06361487254866825`\ \(c[59]\)[t] + 
            0.06880242987642335`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -6, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -6]][ t]], 
          Plus[ 
            Times[ -0.084091858737850814, 
              c[ -60][ t]], 
            Times[ -0.089594193770366884, 
              c[ -59][ t]], 
            Times[ -0.091317159035181589, 
              c[ -58][ t]], 
            Times[ -0.089038438663606695, 
              c[ -57][ t]], 
            Times[ -0.082699334313268744, 
              c[ -56][ t]], 
            Times[ -0.072413370861974122, 
              c[ -55][ t]], 
            Times[ -0.058468080236789913, 
              c[ -54][ t]], 
            Times[ -0.04131966847794722, 
              c[ -53][ t]], 
            Times[ -0.021580547817547879, 
              c[ -52][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -51][ t]], 
            Times[ 0.022561481809254869, 
              c[ -50][ t]], 
            Times[ 0.045163358568919301, 
              c[ -49][ t]], 
            Times[ 0.066820663127759972, 
              c[ -48][ t]], 
            Times[ 0.086542809078944891, 
              c[ -47][ t]], 
            Times[ 0.10337416789158609, 
              c[ -46][ t]], 
            Times[ 0.11643488132933186, 
              c[ -45][ t]], 
            Times[ 0.12496032289024853, 
              c[ -44][ t]], 
            Times[ 0.12833762891430928, 
              c[ -43][ t]], 
            Times[ 0.12613778810677614, 
              c[ -42][ t]], 
            Times[ 0.11814190616181253, 
              c[ -41][ t]], 
            Times[ 0.10436044624225685, 
              c[ -40][ t]], 
            Times[ 0.085044480344421705, 
              c[ -39][ t]], 
            Times[ 0.060688263076985105, 
              c[ -38][ t]], 
            Times[ 0.032022748374425904, 
              c[ -37][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -36][ t]], 
            Times[ -0.034231213779558949, 
              c[ -35][ t]], 
            Times[ -0.06935801494512607, 
              c[ -34][ t]], 
            Times[ -0.10394325375429328, 
              c[ -33][ t]], 
            Times[ -0.13647135277833605, 
              c[ -32][ t]], 
            Times[ -0.16539866862653771, 
              c[ -31][ t]], 
            Times[ -0.18920668216016426, 
              c[ -30][ t]], 
            Times[ -0.20645618564475843, 
              c[ -29][ t]], 
            Times[ -0.21584055771952015, 
              c[ -28][ t]], 
            Times[ -0.21623620818304484, 
              c[ -27][ t]], 
            Times[ -0.206748335783172, 
              c[ -26][ t]], 
            Times[ -0.18675027222298593, 
              c[ -25][ t]], 
            Times[ -0.15591488063143982, 
              c[ -24][ t]], 
            Times[ -0.11423673049785436, 
              c[ -23][ t]], 
            Times[ -0.062044074975450239, 
              c[ -22][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -21][ t]], 
            Times[ 0.070907514257657775, 
              c[ -20][ t]], 
            Times[ 0.14938649372796362, 
              c[ -19][ t]], 
            Times[ 0.23387232094715985, 
              c[ -18][ t]], 
            Times[ 0.32256865202152157, 
              c[ -17][ t]], 
            Times[ 0.41349667156634418, 
              c[ -16][ t]], 
            Times[ 0.50455115242710469, 
              c[ -15][ t]], 
            Times[ 0.59356153372868059, 
              c[ -14][ t]], 
            Times[ 0.67835603854706339, 
              c[ -13][ t]], 
            Times[ 0.75682672864065692, 
              c[ -12][ t]], 
            Times[ 0.82699334313268813, 
              c[ -11][ t]], 
            Times[ 0.88706379305918381, 
              c[ -10][ t]], 
            Times[ 0.93548928378863916, 
              c[ -9][ t]], 
            Times[ 0.9710122092317629, 
              c[ -8][ t]], 
            Times[ 0.99270519960720693, 
              c[ -7][ t]], 
            Times[ 1.7895683520871486, 
              c[ -6][ t]], 
            Times[ 0.99270519960720671, 
              c[ -5][ t]], 
            Times[ 0.9710122092317629, 
              c[ -4][ t]], 
            Times[ 0.93548928378863916, 
              c[ -3][ t]], 
            Times[ 0.8870637930591837, 
              c[ -2][ t]], 
            Times[ 0.82699334313268824, 
              c[ -1][ t]], 
            Times[ 0.75682672864065692, 
              c[ 0][ t]], 
            Times[ 0.67835603854706328, 
              c[ 1][ t]], 
            Times[ 0.59356153372868048, 
              c[ 2][ t]], 
            Times[ 0.50455115242710469, 
              c[ 3][ t]], 
            Times[ 0.41349667156634418, 
              c[ 4][ t]], 
            Times[ 0.32256865202152157, 
              c[ 5][ t]], 
            Times[ 0.23387232094715985, 
              c[ 6][ t]], 
            Times[ 0.14938649372796362, 
              c[ 7][ t]], 
            Times[ 0.070907514257657775, 
              c[ 8][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 9][ t]], 
            Times[ -0.062044074975450343, 
              c[ 10][ t]], 
            Times[ -0.11423673049785436, 
              c[ 11][ t]], 
            Times[ -0.15591488063143982, 
              c[ 12][ t]], 
            Times[ -0.18675027222298601, 
              c[ 13][ t]], 
            Times[ -0.206748335783172, 
              c[ 14][ t]], 
            Times[ -0.21623620818304484, 
              c[ 15][ t]], 
            Times[ -0.21584055771952015, 
              c[ 16][ t]], 
            Times[ -0.20645618564475843, 
              c[ 17][ t]], 
            Times[ -0.18920668216016426, 
              c[ 18][ t]], 
            Times[ -0.16539866862653771, 
              c[ 19][ t]], 
            Times[ -0.13647135277833605, 
              c[ 20][ t]], 
            Times[ -0.10394325375429328, 
              c[ 21][ t]], 
            Times[ -0.06935801494512607, 
              c[ 22][ t]], 
            Times[ -0.034231213779558949, 
              c[ 23][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 24][ t]], 
            Times[ 0.032022748374425904, 
              c[ 25][ t]], 
            Times[ 0.060688263076985105, 
              c[ 26][ t]], 
            Times[ 0.085044480344421705, 
              c[ 27][ t]], 
            Times[ 0.10436044624225685, 
              c[ 28][ t]], 
            Times[ 0.11814190616181255, 
              c[ 29][ t]], 
            Times[ 0.12613778810677614, 
              c[ 30][ t]], 
            Times[ 0.12833762891430928, 
              c[ 31][ t]], 
            Times[ 0.12496032289024853, 
              c[ 32][ t]], 
            Times[ 0.11643488132933186, 
              c[ 33][ t]], 
            Times[ 0.10337416789158609, 
              c[ 34][ t]], 
            Times[ 0.086542809078944891, 
              c[ 35][ t]], 
            Times[ 0.066820663127759972, 
              c[ 36][ t]], 
            Times[ 0.045163358568919301, 
              c[ 37][ t]], 
            Times[ 0.022561481809254869, 
              c[ 38][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 39][ t]], 
            Times[ -0.021580547817547879, 
              c[ 40][ t]], 
            Times[ -0.04131966847794722, 
              c[ 41][ t]], 
            Times[ -0.058468080236789913, 
              c[ 42][ t]], 
            Times[ -0.072413370861974122, 
              c[ 43][ t]], 
            Times[ -0.082699334313268744, 
              c[ 44][ t]], 
            Times[ -0.089038438663606695, 
              c[ 45][ t]], 
            Times[ -0.091317159035181589, 
              c[ 46][ t]], 
            Times[ -0.089594193770366884, 
              c[ 47][ t]], 
            Times[ -0.084091858737850814, 
              c[ 48][ t]], 
            Times[ -0.075181213012062598, 
              c[ 49][ t]], 
            Times[ -0.063361699504227528, 
              c[ 50][ t]], 
            Times[ -0.049236278094138941, 
              c[ 51][ t]], 
            Times[ -0.033483179628681567, 
              c[ 52][ t]], 
            Times[ -0.016825511857749401, 
              c[ 53][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 54][ t]], 
            Times[ 0.016273855731265604, 
              c[ 55][ t]], 
            Times[ 0.031322974491347078, 
              c[ 56][ t]], 
            Times[ 0.044547108751839919, 
              c[ 57][ t]], 
            Times[ 0.055441487066198933, 
              c[ 58][ t]], 
            Times[ 0.063614872548668253, 
              c[ 59][ t]], 
            Times[ 0.068802429876423349, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-5\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-5\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.0751812130120626`\)\ \(c[\(-60\)]\)[t] - 
            0.08409185873785086`\ \(c[\(-59\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-58\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-57\)]\)[t] - 
            0.08903843866360665`\ \(c[\(-56\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-55\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-54\)]\)[t] - 
            0.058468080236789774`\ \(c[\(-53\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-52\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-51\)]\)[t] + 
            2.274590327822911`*^-16\ \(c[\(-50\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-49\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-48\)]\)[t] + 
            0.06682066312776015`\ \(c[\(-47\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-46\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-45\)]\)[t] + 
            0.11643488132933195`\ \(c[\(-44\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-43\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-42\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-41\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-40\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-39\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-38\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-37\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-36\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-35\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-34\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-33\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-32\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-31\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-30\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-29\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-28\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-27\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-26\)]\)[t] - 
            0.206748335783172`\ \(c[\(-25\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-24\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-23\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-22\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-21\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-20\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-19\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-18\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-17\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-16\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-15\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-14\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-13\)]\)[t] + 
            0.6783560385470633`\ \(c[\(-12\)]\)[t] + 
            0.756826728640657`\ \(c[\(-11\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-10\)]\)[t] + 
            0.8870637930591837`\ \(c[\(-9\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-8\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-7\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-6\)]\)[t] + 
            1.5483113556160752`\ \(c[\(-5\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-4\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-3\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-2\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-1\)]\)[t] + 
            0.8269933431326882`\ \(c[0]\)[t] + 
            0.7568267286406569`\ \(c[1]\)[t] + 
            0.6783560385470634`\ \(c[2]\)[t] + 
            0.5935615337286805`\ \(c[3]\)[t] + 
            0.5045511524271047`\ \(c[4]\)[t] + 
            0.4134966715663442`\ \(c[5]\)[t] + 
            0.3225686520215216`\ \(c[6]\)[t] + 
            0.23387232094715985`\ \(c[7]\)[t] + 
            0.14938649372796362`\ \(c[8]\)[t] + 
            0.07090751425765777`\ \(c[9]\)[t] + 
            3.898171832519376`*^-17\ \(c[10]\)[t] - 
            0.06204407497545024`\ \(c[11]\)[t] - 
            0.11423673049785436`\ \(c[12]\)[t] - 
            0.15591488063143982`\ \(c[13]\)[t] - 
            0.18675027222298593`\ \(c[14]\)[t] - 
            0.206748335783172`\ \(c[15]\)[t] - 
            0.21623620818304484`\ \(c[16]\)[t] - 
            0.21584055771952015`\ \(c[17]\)[t] - 
            0.20645618564475843`\ \(c[18]\)[t] - 
            0.18920668216016426`\ \(c[19]\)[t] - 
            0.1653986686265377`\ \(c[20]\)[t] - 
            0.13647135277833605`\ \(c[21]\)[t] - 
            0.1039432537542934`\ \(c[22]\)[t] - 
            0.06935801494512607`\ \(c[23]\)[t] - 
            0.03423121377955895`\ \(c[24]\)[t] - 
            1.8033970416801674`*^-16\ \(c[25]\)[t] + 
            0.032022748374425904`\ \(c[26]\)[t] + 
            0.060688263076985105`\ \(c[27]\)[t] + 
            0.08504448034442161`\ \(c[28]\)[t] + 
            0.10436044624225685`\ \(c[29]\)[t] + 
            0.11814190616181255`\ \(c[30]\)[t] + 
            0.12613778810677612`\ \(c[31]\)[t] + 
            0.12833762891430928`\ \(c[32]\)[t] + 
            0.12496032289024853`\ \(c[33]\)[t] + 
            0.11643488132933186`\ \(c[34]\)[t] + 
            0.10337416789158609`\ \(c[35]\)[t] + 
            0.08654280907894475`\ \(c[36]\)[t] + 
            0.06682066312775997`\ \(c[37]\)[t] + 
            0.0451633585689193`\ \(c[38]\)[t] + 
            0.022561481809254675`\ \(c[39]\)[t] + 
            3.8981718325193755`*^-17\ \(c[40]\)[t] - 
            0.02158054781754788`\ \(c[41]\)[t] - 
            0.04131966847794737`\ \(c[42]\)[t] - 
            0.05846808023678991`\ \(c[43]\)[t] - 
            0.07241337086197412`\ \(c[44]\)[t] - 
            0.08269933431326881`\ \(c[45]\)[t] - 
            0.0890384386636067`\ \(c[46]\)[t] - 
            0.09131715903518159`\ \(c[47]\)[t] - 
            0.08959419377036684`\ \(c[48]\)[t] - 
            0.08409185873785081`\ \(c[49]\)[t] - 
            0.0751812130120626`\ \(c[50]\)[t] - 
            0.0633616995042274`\ \(c[51]\)[t] - 
            0.04923627809413894`\ \(c[52]\)[t] - 
            0.03348317962868157`\ \(c[53]\)[t] - 
            0.016825511857749262`\ \(c[54]\)[t] - 
            3.898171832519376`*^-17\ \(c[55]\)[t] + 
            0.016273855731265604`\ \(c[56]\)[t] + 
            0.0313229744913472`\ \(c[57]\)[t] + 
            0.04454710875183992`\ \(c[58]\)[t] + 
            0.05544148706619893`\ \(c[59]\)[t] + 
            0.06361487254866832`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -5, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -5]][ t]], 
          Plus[ 
            Times[ -0.075181213012062598, 
              c[ -60][ t]], 
            Times[ -0.084091858737850855, 
              c[ -59][ t]], 
            Times[ -0.089594193770366884, 
              c[ -58][ t]], 
            Times[ -0.091317159035181589, 
              c[ -57][ t]], 
            Times[ -0.089038438663606653, 
              c[ -56][ t]], 
            Times[ -0.082699334313268744, 
              c[ -55][ t]], 
            Times[ -0.072413370861974122, 
              c[ -54][ t]], 
            Times[ -0.058468080236789774, 
              c[ -53][ t]], 
            Times[ -0.04131966847794722, 
              c[ -52][ t]], 
            Times[ -0.021580547817547879, 
              c[ -51][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ -50][ t]], 
            Times[ 0.022561481809254869, 
              c[ -49][ t]], 
            Times[ 0.045163358568919301, 
              c[ -48][ t]], 
            Times[ 0.066820663127760152, 
              c[ -47][ t]], 
            Times[ 0.086542809078944891, 
              c[ -46][ t]], 
            Times[ 0.10337416789158609, 
              c[ -45][ t]], 
            Times[ 0.11643488132933195, 
              c[ -44][ t]], 
            Times[ 0.12496032289024853, 
              c[ -43][ t]], 
            Times[ 0.12833762891430925, 
              c[ -42][ t]], 
            Times[ 0.12613778810677612, 
              c[ -41][ t]], 
            Times[ 0.11814190616181255, 
              c[ -40][ t]], 
            Times[ 0.10436044624225692, 
              c[ -39][ t]], 
            Times[ 0.085044480344421705, 
              c[ -38][ t]], 
            Times[ 0.060688263076985105, 
              c[ -37][ t]], 
            Times[ 0.032022748374426029, 
              c[ -36][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -35][ t]], 
            Times[ -0.034231213779558949, 
              c[ -34][ t]], 
            Times[ -0.069358014945125918, 
              c[ -33][ t]], 
            Times[ -0.10394325375429328, 
              c[ -32][ t]], 
            Times[ -0.13647135277833605, 
              c[ -31][ t]], 
            Times[ -0.1653986686265376, 
              c[ -30][ t]], 
            Times[ -0.18920668216016426, 
              c[ -29][ t]], 
            Times[ -0.20645618564475843, 
              c[ -28][ t]], 
            Times[ -0.21584055771952013, 
              c[ -27][ t]], 
            Times[ -0.21623620818304484, 
              c[ -26][ t]], 
            Times[ -0.206748335783172, 
              c[ -25][ t]], 
            Times[ -0.18675027222298607, 
              c[ -24][ t]], 
            Times[ -0.15591488063143982, 
              c[ -23][ t]], 
            Times[ -0.11423673049785436, 
              c[ -22][ t]], 
            Times[ -0.062044074975450475, 
              c[ -21][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -20][ t]], 
            Times[ 0.070907514257657775, 
              c[ -19][ t]], 
            Times[ 0.14938649372796345, 
              c[ -18][ t]], 
            Times[ 0.23387232094715985, 
              c[ -17][ t]], 
            Times[ 0.32256865202152157, 
              c[ -16][ t]], 
            Times[ 0.41349667156634395, 
              c[ -15][ t]], 
            Times[ 0.50455115242710469, 
              c[ -14][ t]], 
            Times[ 0.59356153372868048, 
              c[ -13][ t]], 
            Times[ 0.67835603854706328, 
              c[ -12][ t]], 
            Times[ 0.75682672864065703, 
              c[ -11][ t]], 
            Times[ 0.82699334313268824, 
              c[ -10][ t]], 
            Times[ 0.8870637930591837, 
              c[ -9][ t]], 
            Times[ 0.93548928378863916, 
              c[ -8][ t]], 
            Times[ 0.9710122092317629, 
              c[ -7][ t]], 
            Times[ 0.99270519960720671, 
              c[ -6][ t]], 
            Times[ 1.5483113556160752, 
              c[ -5][ t]], 
            Times[ 0.99270519960720693, 
              c[ -4][ t]], 
            Times[ 0.9710122092317629, 
              c[ -3][ t]], 
            Times[ 0.93548928378863916, 
              c[ -2][ t]], 
            Times[ 0.88706379305918381, 
              c[ -1][ t]], 
            Times[ 0.82699334313268824, 
              c[ 0][ t]], 
            Times[ 0.75682672864065692, 
              c[ 1][ t]], 
            Times[ 0.67835603854706339, 
              c[ 2][ t]], 
            Times[ 0.59356153372868048, 
              c[ 3][ t]], 
            Times[ 0.50455115242710469, 
              c[ 4][ t]], 
            Times[ 0.41349667156634418, 
              c[ 5][ t]], 
            Times[ 0.32256865202152157, 
              c[ 6][ t]], 
            Times[ 0.23387232094715985, 
              c[ 7][ t]], 
            Times[ 0.14938649372796362, 
              c[ 8][ t]], 
            Times[ 0.070907514257657775, 
              c[ 9][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 10][ t]], 
            Times[ -0.062044074975450239, 
              c[ 11][ t]], 
            Times[ -0.11423673049785436, 
              c[ 12][ t]], 
            Times[ -0.15591488063143982, 
              c[ 13][ t]], 
            Times[ -0.18675027222298593, 
              c[ 14][ t]], 
            Times[ -0.206748335783172, 
              c[ 15][ t]], 
            Times[ -0.21623620818304484, 
              c[ 16][ t]], 
            Times[ -0.21584055771952015, 
              c[ 17][ t]], 
            Times[ -0.20645618564475843, 
              c[ 18][ t]], 
            Times[ -0.18920668216016426, 
              c[ 19][ t]], 
            Times[ -0.16539866862653771, 
              c[ 20][ t]], 
            Times[ -0.13647135277833605, 
              c[ 21][ t]], 
            Times[ -0.1039432537542934, 
              c[ 22][ t]], 
            Times[ -0.06935801494512607, 
              c[ 23][ t]], 
            Times[ -0.034231213779558949, 
              c[ 24][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 25][ t]], 
            Times[ 0.032022748374425904, 
              c[ 26][ t]], 
            Times[ 0.060688263076985105, 
              c[ 27][ t]], 
            Times[ 0.085044480344421608, 
              c[ 28][ t]], 
            Times[ 0.10436044624225685, 
              c[ 29][ t]], 
            Times[ 0.11814190616181255, 
              c[ 30][ t]], 
            Times[ 0.12613778810677612, 
              c[ 31][ t]], 
            Times[ 0.12833762891430928, 
              c[ 32][ t]], 
            Times[ 0.12496032289024853, 
              c[ 33][ t]], 
            Times[ 0.11643488132933186, 
              c[ 34][ t]], 
            Times[ 0.10337416789158609, 
              c[ 35][ t]], 
            Times[ 0.086542809078944752, 
              c[ 36][ t]], 
            Times[ 0.066820663127759972, 
              c[ 37][ t]], 
            Times[ 0.045163358568919301, 
              c[ 38][ t]], 
            Times[ 0.022561481809254675, 
              c[ 39][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 40][ t]], 
            Times[ -0.021580547817547879, 
              c[ 41][ t]], 
            Times[ -0.041319668477947373, 
              c[ 42][ t]], 
            Times[ -0.058468080236789913, 
              c[ 43][ t]], 
            Times[ -0.072413370861974122, 
              c[ 44][ t]], 
            Times[ -0.082699334313268813, 
              c[ 45][ t]], 
            Times[ -0.089038438663606695, 
              c[ 46][ t]], 
            Times[ -0.091317159035181589, 
              c[ 47][ t]], 
            Times[ -0.089594193770366842, 
              c[ 48][ t]], 
            Times[ -0.084091858737850814, 
              c[ 49][ t]], 
            Times[ -0.075181213012062598, 
              c[ 50][ t]], 
            Times[ -0.063361699504227403, 
              c[ 51][ t]], 
            Times[ -0.049236278094138941, 
              c[ 52][ t]], 
            Times[ -0.033483179628681567, 
              c[ 53][ t]], 
            Times[ -0.016825511857749262, 
              c[ 54][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 55][ t]], 
            Times[ 0.016273855731265604, 
              c[ 56][ t]], 
            Times[ 0.031322974491347202, 
              c[ 57][ t]], 
            Times[ 0.044547108751839919, 
              c[ 58][ t]], 
            Times[ 0.055441487066198933, 
              c[ 59][ t]], 
            Times[ 0.063614872548668322, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-4\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-4\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.0633616995042274`\)\ \(c[\(-60\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-59\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-58\)]\)[t] - 
            0.08959419377036684`\ \(c[\(-57\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-56\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-55\)]\)[t] - 
            0.08269933431326881`\ \(c[\(-54\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-53\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-52\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-51\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-50\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-49\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-48\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-47\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-46\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-45\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-44\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-43\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-42\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-41\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-40\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-39\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-38\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-37\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-36\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-35\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-34\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-33\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-32\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-31\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-30\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-29\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-28\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-27\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-26\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-25\)]\)[t] - 
            0.206748335783172`\ \(c[\(-24\)]\)[t] - 
            0.186750272222986`\ \(c[\(-23\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-22\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-21\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-20\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-19\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-18\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-17\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-16\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-15\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-14\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-13\)]\)[t] + 
            0.5935615337286803`\ \(c[\(-12\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-11\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-10\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-9\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-8\)]\)[t] + 
            0.935489283788639`\ \(c[\(-7\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-6\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-5\)]\)[t] + 
            1.3509192675942883`\ \(c[\(-4\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-3\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-2\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-1\)]\)[t] + 
            0.8870637930591838`\ \(c[0]\)[t] + 
            0.8269933431326882`\ \(c[1]\)[t] + 
            0.7568267286406569`\ \(c[2]\)[t] + 
            0.6783560385470634`\ \(c[3]\)[t] + 
            0.5935615337286805`\ \(c[4]\)[t] + 
            0.5045511524271047`\ \(c[5]\)[t] + 
            0.4134966715663442`\ \(c[6]\)[t] + 
            0.3225686520215216`\ \(c[7]\)[t] + 
            0.23387232094715985`\ \(c[8]\)[t] + 
            0.14938649372796362`\ \(c[9]\)[t] + 
            0.07090751425765777`\ \(c[10]\)[t] + 
            1.8033970416801674`*^-16\ \(c[11]\)[t] - 
            0.06204407497545034`\ \(c[12]\)[t] - 
            0.11423673049785436`\ \(c[13]\)[t] - 
            0.15591488063143974`\ \(c[14]\)[t] - 
            0.186750272222986`\ \(c[15]\)[t] - 
            0.206748335783172`\ \(c[16]\)[t] - 
            0.21623620818304484`\ \(c[17]\)[t] - 
            0.21584055771952013`\ \(c[18]\)[t] - 
            0.20645618564475843`\ \(c[19]\)[t] - 
            0.18920668216016426`\ \(c[20]\)[t] - 
            0.1653986686265376`\ \(c[21]\)[t] - 
            0.13647135277833605`\ \(c[22]\)[t] - 
            0.10394325375429328`\ \(c[23]\)[t] - 
            0.06935801494512592`\ \(c[24]\)[t] - 
            0.03423121377955895`\ \(c[25]\)[t] - 
            3.898171832519376`*^-17\ \(c[26]\)[t] + 
            0.03202274837442603`\ \(c[27]\)[t] + 
            0.060688263076985105`\ \(c[28]\)[t] + 
            0.0850444803444217`\ \(c[29]\)[t] + 
            0.10436044624225692`\ \(c[30]\)[t] + 
            0.11814190616181255`\ \(c[31]\)[t] + 
            0.12613778810677614`\ \(c[32]\)[t] + 
            0.12833762891430925`\ \(c[33]\)[t] + 
            0.12496032289024853`\ \(c[34]\)[t] + 
            0.11643488132933186`\ \(c[35]\)[t] + 
            0.10337416789158609`\ \(c[36]\)[t] + 
            0.08654280907894489`\ \(c[37]\)[t] + 
            0.06682066312775997`\ \(c[38]\)[t] + 
            0.0451633585689193`\ \(c[39]\)[t] + 
            0.02256148180925487`\ \(c[40]\)[t] + 
            2.274590327822911`*^-16\ \(c[41]\)[t] - 
            0.02158054781754788`\ \(c[42]\)[t] - 
            0.04131966847794722`\ \(c[43]\)[t] - 
            0.058468080236789774`\ \(c[44]\)[t] - 
            0.07241337086197412`\ \(c[45]\)[t] - 
            0.08269933431326874`\ \(c[46]\)[t] - 
            0.08903843866360665`\ \(c[47]\)[t] - 
            0.09131715903518159`\ \(c[48]\)[t] - 
            0.08959419377036688`\ \(c[49]\)[t] - 
            0.08409185873785086`\ \(c[50]\)[t] - 
            0.0751812130120626`\ \(c[51]\)[t] - 
            0.06336169950422753`\ \(c[52]\)[t] - 
            0.049236278094139066`\ \(c[53]\)[t] - 
            0.03348317962868157`\ \(c[54]\)[t] - 
            0.0168255118577494`\ \(c[55]\)[t] - 
            1.8033970416801674`*^-16\ \(c[56]\)[t] + 
            0.016273855731265604`\ \(c[57]\)[t] + 
            0.03132297449134708`\ \(c[58]\)[t] + 
            0.044547108751839815`\ \(c[59]\)[t] + 
            0.05544148706619893`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -4, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -4]][ t]], 
          Plus[ 
            Times[ -0.063361699504227403, 
              c[ -60][ t]], 
            Times[ -0.075181213012062598, 
              c[ -59][ t]], 
            Times[ -0.084091858737850814, 
              c[ -58][ t]], 
            Times[ -0.089594193770366842, 
              c[ -57][ t]], 
            Times[ -0.091317159035181589, 
              c[ -56][ t]], 
            Times[ -0.089038438663606695, 
              c[ -55][ t]], 
            Times[ -0.082699334313268813, 
              c[ -54][ t]], 
            Times[ -0.072413370861974122, 
              c[ -53][ t]], 
            Times[ -0.058468080236789913, 
              c[ -52][ t]], 
            Times[ -0.041319668477947373, 
              c[ -51][ t]], 
            Times[ -0.021580547817547879, 
              c[ -50][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -49][ t]], 
            Times[ 0.022561481809254675, 
              c[ -48][ t]], 
            Times[ 0.045163358568919301, 
              c[ -47][ t]], 
            Times[ 0.066820663127759972, 
              c[ -46][ t]], 
            Times[ 0.086542809078944752, 
              c[ -45][ t]], 
            Times[ 0.10337416789158609, 
              c[ -44][ t]], 
            Times[ 0.11643488132933186, 
              c[ -43][ t]], 
            Times[ 0.12496032289024853, 
              c[ -42][ t]], 
            Times[ 0.12833762891430925, 
              c[ -41][ t]], 
            Times[ 0.12613778810677612, 
              c[ -40][ t]], 
            Times[ 0.11814190616181255, 
              c[ -39][ t]], 
            Times[ 0.10436044624225685, 
              c[ -38][ t]], 
            Times[ 0.085044480344421608, 
              c[ -37][ t]], 
            Times[ 0.060688263076985105, 
              c[ -36][ t]], 
            Times[ 0.032022748374425904, 
              c[ -35][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -34][ t]], 
            Times[ -0.034231213779558949, 
              c[ -33][ t]], 
            Times[ -0.06935801494512607, 
              c[ -32][ t]], 
            Times[ -0.1039432537542934, 
              c[ -31][ t]], 
            Times[ -0.13647135277833605, 
              c[ -30][ t]], 
            Times[ -0.16539866862653771, 
              c[ -29][ t]], 
            Times[ -0.18920668216016434, 
              c[ -28][ t]], 
            Times[ -0.20645618564475843, 
              c[ -27][ t]], 
            Times[ -0.21584055771952015, 
              c[ -26][ t]], 
            Times[ -0.21623620818304481, 
              c[ -25][ t]], 
            Times[ -0.206748335783172, 
              c[ -24][ t]], 
            Times[ -0.18675027222298601, 
              c[ -23][ t]], 
            Times[ -0.15591488063143974, 
              c[ -22][ t]], 
            Times[ -0.11423673049785445, 
              c[ -21][ t]], 
            Times[ -0.062044074975450343, 
              c[ -20][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -19][ t]], 
            Times[ 0.070907514257657622, 
              c[ -18][ t]], 
            Times[ 0.14938649372796362, 
              c[ -17][ t]], 
            Times[ 0.23387232094715985, 
              c[ -16][ t]], 
            Times[ 0.32256865202152135, 
              c[ -15][ t]], 
            Times[ 0.41349667156634418, 
              c[ -14][ t]], 
            Times[ 0.50455115242710469, 
              c[ -13][ t]], 
            Times[ 0.59356153372868026, 
              c[ -12][ t]], 
            Times[ 0.67835603854706339, 
              c[ -11][ t]], 
            Times[ 0.75682672864065692, 
              c[ -10][ t]], 
            Times[ 0.82699334313268813, 
              c[ -9][ t]], 
            Times[ 0.88706379305918381, 
              c[ -8][ t]], 
            Times[ 0.93548928378863905, 
              c[ -7][ t]], 
            Times[ 0.9710122092317629, 
              c[ -6][ t]], 
            Times[ 0.99270519960720693, 
              c[ -5][ t]], 
            Times[ 1.3509192675942883, 
              c[ -4][ t]], 
            Times[ 0.99270519960720693, 
              c[ -3][ t]], 
            Times[ 0.9710122092317629, 
              c[ -2][ t]], 
            Times[ 0.93548928378863916, 
              c[ -1][ t]], 
            Times[ 0.88706379305918381, 
              c[ 0][ t]], 
            Times[ 0.82699334313268824, 
              c[ 1][ t]], 
            Times[ 0.75682672864065692, 
              c[ 2][ t]], 
            Times[ 0.67835603854706339, 
              c[ 3][ t]], 
            Times[ 0.59356153372868048, 
              c[ 4][ t]], 
            Times[ 0.50455115242710469, 
              c[ 5][ t]], 
            Times[ 0.41349667156634418, 
              c[ 6][ t]], 
            Times[ 0.32256865202152157, 
              c[ 7][ t]], 
            Times[ 0.23387232094715985, 
              c[ 8][ t]], 
            Times[ 0.14938649372796362, 
              c[ 9][ t]], 
            Times[ 0.070907514257657775, 
              c[ 10][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 11][ t]], 
            Times[ -0.062044074975450343, 
              c[ 12][ t]], 
            Times[ -0.11423673049785436, 
              c[ 13][ t]], 
            Times[ -0.15591488063143974, 
              c[ 14][ t]], 
            Times[ -0.18675027222298601, 
              c[ 15][ t]], 
            Times[ -0.206748335783172, 
              c[ 16][ t]], 
            Times[ -0.21623620818304484, 
              c[ 17][ t]], 
            Times[ -0.21584055771952013, 
              c[ 18][ t]], 
            Times[ -0.20645618564475843, 
              c[ 19][ t]], 
            Times[ -0.18920668216016426, 
              c[ 20][ t]], 
            Times[ -0.1653986686265376, 
              c[ 21][ t]], 
            Times[ -0.13647135277833605, 
              c[ 22][ t]], 
            Times[ -0.10394325375429328, 
              c[ 23][ t]], 
            Times[ -0.069358014945125918, 
              c[ 24][ t]], 
            Times[ -0.034231213779558949, 
              c[ 25][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 26][ t]], 
            Times[ 0.032022748374426029, 
              c[ 27][ t]], 
            Times[ 0.060688263076985105, 
              c[ 28][ t]], 
            Times[ 0.085044480344421705, 
              c[ 29][ t]], 
            Times[ 0.10436044624225692, 
              c[ 30][ t]], 
            Times[ 0.11814190616181255, 
              c[ 31][ t]], 
            Times[ 0.12613778810677614, 
              c[ 32][ t]], 
            Times[ 0.12833762891430925, 
              c[ 33][ t]], 
            Times[ 0.12496032289024853, 
              c[ 34][ t]], 
            Times[ 0.11643488132933186, 
              c[ 35][ t]], 
            Times[ 0.10337416789158609, 
              c[ 36][ t]], 
            Times[ 0.086542809078944891, 
              c[ 37][ t]], 
            Times[ 0.066820663127759972, 
              c[ 38][ t]], 
            Times[ 0.045163358568919301, 
              c[ 39][ t]], 
            Times[ 0.022561481809254869, 
              c[ 40][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ 41][ t]], 
            Times[ -0.021580547817547879, 
              c[ 42][ t]], 
            Times[ -0.04131966847794722, 
              c[ 43][ t]], 
            Times[ -0.058468080236789774, 
              c[ 44][ t]], 
            Times[ -0.072413370861974122, 
              c[ 45][ t]], 
            Times[ -0.082699334313268744, 
              c[ 46][ t]], 
            Times[ -0.089038438663606653, 
              c[ 47][ t]], 
            Times[ -0.091317159035181589, 
              c[ 48][ t]], 
            Times[ -0.089594193770366884, 
              c[ 49][ t]], 
            Times[ -0.084091858737850855, 
              c[ 50][ t]], 
            Times[ -0.075181213012062598, 
              c[ 51][ t]], 
            Times[ -0.063361699504227528, 
              c[ 52][ t]], 
            Times[ -0.049236278094139066, 
              c[ 53][ t]], 
            Times[ -0.033483179628681567, 
              c[ 54][ t]], 
            Times[ -0.016825511857749401, 
              c[ 55][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 56][ t]], 
            Times[ 0.016273855731265604, 
              c[ 57][ t]], 
            Times[ 0.031322974491347078, 
              c[ 58][ t]], 
            Times[ 0.044547108751839815, 
              c[ 59][ t]], 
            Times[ 0.055441487066198933, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-3\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-3\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.04923627809413894`\)\ \(c[\(-60\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-59\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-58\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-57\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-56\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-55\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-54\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-53\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-52\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-51\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-50\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-49\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-48\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-47\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-46\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-45\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-44\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-43\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-42\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-41\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-40\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-39\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-38\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-37\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-36\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-35\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-34\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-33\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-32\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-31\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-30\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-29\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-28\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-27\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-26\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-25\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-24\)]\)[t] - 
            0.206748335783172`\ \(c[\(-23\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-22\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-21\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-20\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-19\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-18\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-17\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-16\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-15\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-14\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-13\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-12\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-11\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-10\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-9\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-8\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-7\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-6\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-5\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-4\)]\)[t] + 
            1.1973920880217872`\ \(c[\(-3\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-2\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-1\)]\)[t] + 
            0.9354892837886392`\ \(c[0]\)[t] + 
            0.8870637930591838`\ \(c[1]\)[t] + 
            0.8269933431326882`\ \(c[2]\)[t] + 
            0.7568267286406569`\ \(c[3]\)[t] + 
            0.6783560385470634`\ \(c[4]\)[t] + 
            0.5935615337286805`\ \(c[5]\)[t] + 
            0.5045511524271047`\ \(c[6]\)[t] + 
            0.4134966715663442`\ \(c[7]\)[t] + 
            0.3225686520215216`\ \(c[8]\)[t] + 
            0.23387232094715985`\ \(c[9]\)[t] + 
            0.14938649372796362`\ \(c[10]\)[t] + 
            0.07090751425765777`\ \(c[11]\)[t] + 
            3.898171832519376`*^-17\ \(c[12]\)[t] - 
            0.06204407497545034`\ \(c[13]\)[t] - 
            0.11423673049785436`\ \(c[14]\)[t] - 
            0.15591488063143982`\ \(c[15]\)[t] - 
            0.186750272222986`\ \(c[16]\)[t] - 
            0.206748335783172`\ \(c[17]\)[t] - 
            0.21623620818304484`\ \(c[18]\)[t] - 
            0.21584055771952015`\ \(c[19]\)[t] - 
            0.20645618564475843`\ \(c[20]\)[t] - 
            0.18920668216016426`\ \(c[21]\)[t] - 
            0.1653986686265377`\ \(c[22]\)[t] - 
            0.13647135277833605`\ \(c[23]\)[t] - 
            0.10394325375429328`\ \(c[24]\)[t] - 
            0.06935801494512607`\ \(c[25]\)[t] - 
            0.03423121377955895`\ \(c[26]\)[t] - 
            3.898171832519376`*^-17\ \(c[27]\)[t] + 
            0.032022748374425904`\ \(c[28]\)[t] + 
            0.060688263076985105`\ \(c[29]\)[t] + 
            0.0850444803444217`\ \(c[30]\)[t] + 
            0.10436044624225685`\ \(c[31]\)[t] + 
            0.11814190616181255`\ \(c[32]\)[t] + 
            0.12613778810677614`\ \(c[33]\)[t] + 
            0.12833762891430928`\ \(c[34]\)[t] + 
            0.12496032289024853`\ \(c[35]\)[t] + 
            0.11643488132933186`\ \(c[36]\)[t] + 
            0.10337416789158609`\ \(c[37]\)[t] + 
            0.08654280907894489`\ \(c[38]\)[t] + 
            0.06682066312775997`\ \(c[39]\)[t] + 
            0.0451633585689193`\ \(c[40]\)[t] + 
            0.02256148180925487`\ \(c[41]\)[t] + 
            3.8981718325193755`*^-17\ \(c[42]\)[t] - 
            0.02158054781754788`\ \(c[43]\)[t] - 
            0.04131966847794722`\ \(c[44]\)[t] - 
            0.05846808023678991`\ \(c[45]\)[t] - 
            0.07241337086197412`\ \(c[46]\)[t] - 
            0.08269933431326874`\ \(c[47]\)[t] - 
            0.0890384386636067`\ \(c[48]\)[t] - 
            0.09131715903518159`\ \(c[49]\)[t] - 
            0.08959419377036688`\ \(c[50]\)[t] - 
            0.08409185873785081`\ \(c[51]\)[t] - 
            0.0751812130120626`\ \(c[52]\)[t] - 
            0.06336169950422753`\ \(c[53]\)[t] - 
            0.04923627809413894`\ \(c[54]\)[t] - 
            0.03348317962868157`\ \(c[55]\)[t] - 
            0.0168255118577494`\ \(c[56]\)[t] - 
            3.898171832519376`*^-17\ \(c[57]\)[t] + 
            0.016273855731265604`\ \(c[58]\)[t] + 
            0.03132297449134708`\ \(c[59]\)[t] + 
            0.04454710875183992`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -3, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -3]][ t]], 
          Plus[ 
            Times[ -0.049236278094138941, 
              c[ -60][ t]], 
            Times[ -0.063361699504227528, 
              c[ -59][ t]], 
            Times[ -0.075181213012062598, 
              c[ -58][ t]], 
            Times[ -0.084091858737850814, 
              c[ -57][ t]], 
            Times[ -0.089594193770366884, 
              c[ -56][ t]], 
            Times[ -0.091317159035181589, 
              c[ -55][ t]], 
            Times[ -0.089038438663606695, 
              c[ -54][ t]], 
            Times[ -0.082699334313268744, 
              c[ -53][ t]], 
            Times[ -0.072413370861974122, 
              c[ -52][ t]], 
            Times[ -0.058468080236789913, 
              c[ -51][ t]], 
            Times[ -0.04131966847794722, 
              c[ -50][ t]], 
            Times[ -0.021580547817547879, 
              c[ -49][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -48][ t]], 
            Times[ 0.022561481809254869, 
              c[ -47][ t]], 
            Times[ 0.045163358568919301, 
              c[ -46][ t]], 
            Times[ 0.066820663127759972, 
              c[ -45][ t]], 
            Times[ 0.086542809078944891, 
              c[ -44][ t]], 
            Times[ 0.10337416789158609, 
              c[ -43][ t]], 
            Times[ 0.11643488132933186, 
              c[ -42][ t]], 
            Times[ 0.12496032289024853, 
              c[ -41][ t]], 
            Times[ 0.12833762891430928, 
              c[ -40][ t]], 
            Times[ 0.12613778810677614, 
              c[ -39][ t]], 
            Times[ 0.11814190616181255, 
              c[ -38][ t]], 
            Times[ 0.10436044624225685, 
              c[ -37][ t]], 
            Times[ 0.085044480344421705, 
              c[ -36][ t]], 
            Times[ 0.060688263076985105, 
              c[ -35][ t]], 
            Times[ 0.032022748374425904, 
              c[ -34][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -33][ t]], 
            Times[ -0.034231213779558949, 
              c[ -32][ t]], 
            Times[ -0.06935801494512607, 
              c[ -31][ t]], 
            Times[ -0.10394325375429328, 
              c[ -30][ t]], 
            Times[ -0.13647135277833605, 
              c[ -29][ t]], 
            Times[ -0.16539866862653771, 
              c[ -28][ t]], 
            Times[ -0.18920668216016426, 
              c[ -27][ t]], 
            Times[ -0.20645618564475843, 
              c[ -26][ t]], 
            Times[ -0.21584055771952015, 
              c[ -25][ t]], 
            Times[ -0.21623620818304484, 
              c[ -24][ t]], 
            Times[ -0.206748335783172, 
              c[ -23][ t]], 
            Times[ -0.18675027222298593, 
              c[ -22][ t]], 
            Times[ -0.15591488063143982, 
              c[ -21][ t]], 
            Times[ -0.11423673049785436, 
              c[ -20][ t]], 
            Times[ -0.062044074975450343, 
              c[ -19][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -18][ t]], 
            Times[ 0.070907514257657775, 
              c[ -17][ t]], 
            Times[ 0.14938649372796362, 
              c[ -16][ t]], 
            Times[ 0.23387232094715985, 
              c[ -15][ t]], 
            Times[ 0.32256865202152157, 
              c[ -14][ t]], 
            Times[ 0.41349667156634418, 
              c[ -13][ t]], 
            Times[ 0.50455115242710469, 
              c[ -12][ t]], 
            Times[ 0.59356153372868059, 
              c[ -11][ t]], 
            Times[ 0.67835603854706339, 
              c[ -10][ t]], 
            Times[ 0.75682672864065692, 
              c[ -9][ t]], 
            Times[ 0.82699334313268824, 
              c[ -8][ t]], 
            Times[ 0.88706379305918381, 
              c[ -7][ t]], 
            Times[ 0.93548928378863916, 
              c[ -6][ t]], 
            Times[ 0.9710122092317629, 
              c[ -5][ t]], 
            Times[ 0.99270519960720693, 
              c[ -4][ t]], 
            Times[ 1.1973920880217872, 
              c[ -3][ t]], 
            Times[ 0.99270519960720671, 
              c[ -2][ t]], 
            Times[ 0.9710122092317629, 
              c[ -1][ t]], 
            Times[ 0.93548928378863916, 
              c[ 0][ t]], 
            Times[ 0.88706379305918381, 
              c[ 1][ t]], 
            Times[ 0.82699334313268824, 
              c[ 2][ t]], 
            Times[ 0.75682672864065692, 
              c[ 3][ t]], 
            Times[ 0.67835603854706339, 
              c[ 4][ t]], 
            Times[ 0.59356153372868048, 
              c[ 5][ t]], 
            Times[ 0.50455115242710469, 
              c[ 6][ t]], 
            Times[ 0.41349667156634418, 
              c[ 7][ t]], 
            Times[ 0.32256865202152157, 
              c[ 8][ t]], 
            Times[ 0.23387232094715985, 
              c[ 9][ t]], 
            Times[ 0.14938649372796362, 
              c[ 10][ t]], 
            Times[ 0.070907514257657775, 
              c[ 11][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 12][ t]], 
            Times[ -0.062044074975450343, 
              c[ 13][ t]], 
            Times[ -0.11423673049785436, 
              c[ 14][ t]], 
            Times[ -0.15591488063143982, 
              c[ 15][ t]], 
            Times[ -0.18675027222298601, 
              c[ 16][ t]], 
            Times[ -0.206748335783172, 
              c[ 17][ t]], 
            Times[ -0.21623620818304484, 
              c[ 18][ t]], 
            Times[ -0.21584055771952015, 
              c[ 19][ t]], 
            Times[ -0.20645618564475843, 
              c[ 20][ t]], 
            Times[ -0.18920668216016426, 
              c[ 21][ t]], 
            Times[ -0.16539866862653771, 
              c[ 22][ t]], 
            Times[ -0.13647135277833605, 
              c[ 23][ t]], 
            Times[ -0.10394325375429328, 
              c[ 24][ t]], 
            Times[ -0.06935801494512607, 
              c[ 25][ t]], 
            Times[ -0.034231213779558949, 
              c[ 26][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 27][ t]], 
            Times[ 0.032022748374425904, 
              c[ 28][ t]], 
            Times[ 0.060688263076985105, 
              c[ 29][ t]], 
            Times[ 0.085044480344421705, 
              c[ 30][ t]], 
            Times[ 0.10436044624225685, 
              c[ 31][ t]], 
            Times[ 0.11814190616181255, 
              c[ 32][ t]], 
            Times[ 0.12613778810677614, 
              c[ 33][ t]], 
            Times[ 0.12833762891430928, 
              c[ 34][ t]], 
            Times[ 0.12496032289024853, 
              c[ 35][ t]], 
            Times[ 0.11643488132933186, 
              c[ 36][ t]], 
            Times[ 0.10337416789158609, 
              c[ 37][ t]], 
            Times[ 0.086542809078944891, 
              c[ 38][ t]], 
            Times[ 0.066820663127759972, 
              c[ 39][ t]], 
            Times[ 0.045163358568919301, 
              c[ 40][ t]], 
            Times[ 0.022561481809254869, 
              c[ 41][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 42][ t]], 
            Times[ -0.021580547817547879, 
              c[ 43][ t]], 
            Times[ -0.04131966847794722, 
              c[ 44][ t]], 
            Times[ -0.058468080236789913, 
              c[ 45][ t]], 
            Times[ -0.072413370861974122, 
              c[ 46][ t]], 
            Times[ -0.082699334313268744, 
              c[ 47][ t]], 
            Times[ -0.089038438663606695, 
              c[ 48][ t]], 
            Times[ -0.091317159035181589, 
              c[ 49][ t]], 
            Times[ -0.089594193770366884, 
              c[ 50][ t]], 
            Times[ -0.084091858737850814, 
              c[ 51][ t]], 
            Times[ -0.075181213012062598, 
              c[ 52][ t]], 
            Times[ -0.063361699504227528, 
              c[ 53][ t]], 
            Times[ -0.049236278094138941, 
              c[ 54][ t]], 
            Times[ -0.033483179628681567, 
              c[ 55][ t]], 
            Times[ -0.016825511857749401, 
              c[ 56][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 57][ t]], 
            Times[ 0.016273855731265604, 
              c[ 58][ t]], 
            Times[ 0.031322974491347078, 
              c[ 59][ t]], 
            Times[ 0.044547108751839919, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-2\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-2\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.03348317962868157`\)\ \(c[\(-60\)]\)[t] - 
            0.049236278094139066`\ \(c[\(-59\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-58\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-57\)]\)[t] - 
            0.08409185873785086`\ \(c[\(-56\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-55\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-54\)]\)[t] - 
            0.08903843866360665`\ \(c[\(-53\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-52\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-51\)]\)[t] - 
            0.058468080236789774`\ \(c[\(-50\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-49\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-48\)]\)[t] + 
            2.274590327822911`*^-16\ \(c[\(-47\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-46\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-45\)]\)[t] + 
            0.06682066312776015`\ \(c[\(-44\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-43\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-42\)]\)[t] + 
            0.11643488132933195`\ \(c[\(-41\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-40\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-39\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-38\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-37\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-36\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-35\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-34\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-33\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-32\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-31\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-30\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-29\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-28\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-27\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-26\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-25\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-24\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-23\)]\)[t] - 
            0.206748335783172`\ \(c[\(-22\)]\)[t] - 
            0.186750272222986`\ \(c[\(-21\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-20\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-19\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-18\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-17\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-16\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-15\)]\)[t] + 
            0.23387232094715998`\ \(c[\(-14\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-13\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-12\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-11\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-10\)]\)[t] + 
            0.6783560385470633`\ \(c[\(-9\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-8\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-7\)]\)[t] + 
            0.8870637930591837`\ \(c[\(-6\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-5\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-4\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-3\)]\)[t] + 
            1.087729816898572`\ \(c[\(-2\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-1\)]\)[t] + 
            0.9710122092317629`\ \(c[0]\)[t] + 
            0.9354892837886392`\ \(c[1]\)[t] + 
            0.8870637930591838`\ \(c[2]\)[t] + 
            0.8269933431326882`\ \(c[3]\)[t] + 
            0.7568267286406569`\ \(c[4]\)[t] + 
            0.6783560385470634`\ \(c[5]\)[t] + 
            0.5935615337286805`\ \(c[6]\)[t] + 
            0.5045511524271047`\ \(c[7]\)[t] + 
            0.4134966715663442`\ \(c[8]\)[t] + 
            0.32256865202152135`\ \(c[9]\)[t] + 
            0.23387232094715985`\ \(c[10]\)[t] + 
            0.14938649372796362`\ \(c[11]\)[t] + 
            0.07090751425765762`\ \(c[12]\)[t] + 
            3.898171832519376`*^-17\ \(c[13]\)[t] - 
            0.06204407497545034`\ \(c[14]\)[t] - 
            0.11423673049785445`\ \(c[15]\)[t] - 
            0.15591488063143982`\ \(c[16]\)[t] - 
            0.186750272222986`\ \(c[17]\)[t] - 
            0.206748335783172`\ \(c[18]\)[t] - 
            0.21623620818304484`\ \(c[19]\)[t] - 
            0.21584055771952015`\ \(c[20]\)[t] - 
            0.20645618564475843`\ \(c[21]\)[t] - 
            0.18920668216016434`\ \(c[22]\)[t] - 
            0.1653986686265377`\ \(c[23]\)[t] - 
            0.13647135277833605`\ \(c[24]\)[t] - 
            0.1039432537542934`\ \(c[25]\)[t] - 
            0.06935801494512607`\ \(c[26]\)[t] - 
            0.03423121377955895`\ \(c[27]\)[t] - 
            1.8033970416801674`*^-16\ \(c[28]\)[t] + 
            0.032022748374425904`\ \(c[29]\)[t] + 
            0.060688263076985105`\ \(c[30]\)[t] + 
            0.08504448034442161`\ \(c[31]\)[t] + 
            0.10436044624225685`\ \(c[32]\)[t] + 
            0.11814190616181255`\ \(c[33]\)[t] + 
            0.12613778810677612`\ \(c[34]\)[t] + 
            0.12833762891430928`\ \(c[35]\)[t] + 
            0.12496032289024853`\ \(c[36]\)[t] + 
            0.11643488132933186`\ \(c[37]\)[t] + 
            0.10337416789158609`\ \(c[38]\)[t] + 
            0.08654280907894475`\ \(c[39]\)[t] + 
            0.06682066312775997`\ \(c[40]\)[t] + 
            0.0451633585689193`\ \(c[41]\)[t] + 
            0.022561481809254675`\ \(c[42]\)[t] + 
            3.8981718325193755`*^-17\ \(c[43]\)[t] - 
            0.02158054781754788`\ \(c[44]\)[t] - 
            0.04131966847794737`\ \(c[45]\)[t] - 
            0.05846808023678991`\ \(c[46]\)[t] - 
            0.07241337086197412`\ \(c[47]\)[t] - 
            0.08269933431326881`\ \(c[48]\)[t] - 
            0.0890384386636067`\ \(c[49]\)[t] - 
            0.09131715903518159`\ \(c[50]\)[t] - 
            0.08959419377036684`\ \(c[51]\)[t] - 
            0.08409185873785081`\ \(c[52]\)[t] - 
            0.0751812130120626`\ \(c[53]\)[t] - 
            0.0633616995042274`\ \(c[54]\)[t] - 
            0.04923627809413894`\ \(c[55]\)[t] - 
            0.03348317962868157`\ \(c[56]\)[t] - 
            0.016825511857749262`\ \(c[57]\)[t] - 
            3.898171832519376`*^-17\ \(c[58]\)[t] + 
            0.016273855731265604`\ \(c[59]\)[t] + 
            0.0313229744913472`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -2, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -2]][ t]], 
          Plus[ 
            Times[ -0.033483179628681567, 
              c[ -60][ t]], 
            Times[ -0.049236278094139066, 
              c[ -59][ t]], 
            Times[ -0.063361699504227528, 
              c[ -58][ t]], 
            Times[ -0.075181213012062598, 
              c[ -57][ t]], 
            Times[ -0.084091858737850855, 
              c[ -56][ t]], 
            Times[ -0.089594193770366884, 
              c[ -55][ t]], 
            Times[ -0.091317159035181589, 
              c[ -54][ t]], 
            Times[ -0.089038438663606653, 
              c[ -53][ t]], 
            Times[ -0.082699334313268744, 
              c[ -52][ t]], 
            Times[ -0.072413370861974122, 
              c[ -51][ t]], 
            Times[ -0.058468080236789774, 
              c[ -50][ t]], 
            Times[ -0.04131966847794722, 
              c[ -49][ t]], 
            Times[ -0.021580547817547879, 
              c[ -48][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ -47][ t]], 
            Times[ 0.022561481809254869, 
              c[ -46][ t]], 
            Times[ 0.045163358568919301, 
              c[ -45][ t]], 
            Times[ 0.066820663127760152, 
              c[ -44][ t]], 
            Times[ 0.086542809078944891, 
              c[ -43][ t]], 
            Times[ 0.10337416789158609, 
              c[ -42][ t]], 
            Times[ 0.11643488132933195, 
              c[ -41][ t]], 
            Times[ 0.12496032289024853, 
              c[ -40][ t]], 
            Times[ 0.12833762891430925, 
              c[ -39][ t]], 
            Times[ 0.12613778810677614, 
              c[ -38][ t]], 
            Times[ 0.11814190616181255, 
              c[ -37][ t]], 
            Times[ 0.10436044624225692, 
              c[ -36][ t]], 
            Times[ 0.085044480344421705, 
              c[ -35][ t]], 
            Times[ 0.060688263076985105, 
              c[ -34][ t]], 
            Times[ 0.032022748374426029, 
              c[ -33][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -32][ t]], 
            Times[ -0.034231213779558949, 
              c[ -31][ t]], 
            Times[ -0.069358014945125918, 
              c[ -30][ t]], 
            Times[ -0.10394325375429328, 
              c[ -29][ t]], 
            Times[ -0.13647135277833605, 
              c[ -28][ t]], 
            Times[ -0.1653986686265376, 
              c[ -27][ t]], 
            Times[ -0.18920668216016426, 
              c[ -26][ t]], 
            Times[ -0.20645618564475843, 
              c[ -25][ t]], 
            Times[ -0.21584055771952013, 
              c[ -24][ t]], 
            Times[ -0.21623620818304484, 
              c[ -23][ t]], 
            Times[ -0.206748335783172, 
              c[ -22][ t]], 
            Times[ -0.18675027222298601, 
              c[ -21][ t]], 
            Times[ -0.15591488063143974, 
              c[ -20][ t]], 
            Times[ -0.11423673049785436, 
              c[ -19][ t]], 
            Times[ -0.062044074975450343, 
              c[ -18][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -17][ t]], 
            Times[ 0.070907514257657775, 
              c[ -16][ t]], 
            Times[ 0.14938649372796362, 
              c[ -15][ t]], 
            Times[ 0.23387232094715998, 
              c[ -14][ t]], 
            Times[ 0.32256865202152157, 
              c[ -13][ t]], 
            Times[ 0.41349667156634418, 
              c[ -12][ t]], 
            Times[ 0.50455115242710469, 
              c[ -11][ t]], 
            Times[ 0.59356153372868048, 
              c[ -10][ t]], 
            Times[ 0.67835603854706328, 
              c[ -9][ t]], 
            Times[ 0.75682672864065692, 
              c[ -8][ t]], 
            Times[ 0.82699334313268824, 
              c[ -7][ t]], 
            Times[ 0.8870637930591837, 
              c[ -6][ t]], 
            Times[ 0.93548928378863916, 
              c[ -5][ t]], 
            Times[ 0.9710122092317629, 
              c[ -4][ t]], 
            Times[ 0.99270519960720671, 
              c[ -3][ t]], 
            Times[ 1.0877298168985721, 
              c[ -2][ t]], 
            Times[ 0.99270519960720693, 
              c[ -1][ t]], 
            Times[ 0.9710122092317629, 
              c[ 0][ t]], 
            Times[ 0.93548928378863916, 
              c[ 1][ t]], 
            Times[ 0.88706379305918381, 
              c[ 2][ t]], 
            Times[ 0.82699334313268824, 
              c[ 3][ t]], 
            Times[ 0.75682672864065692, 
              c[ 4][ t]], 
            Times[ 0.67835603854706339, 
              c[ 5][ t]], 
            Times[ 0.59356153372868048, 
              c[ 6][ t]], 
            Times[ 0.50455115242710469, 
              c[ 7][ t]], 
            Times[ 0.41349667156634418, 
              c[ 8][ t]], 
            Times[ 0.32256865202152135, 
              c[ 9][ t]], 
            Times[ 0.23387232094715985, 
              c[ 10][ t]], 
            Times[ 0.14938649372796362, 
              c[ 11][ t]], 
            Times[ 0.070907514257657622, 
              c[ 12][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 13][ t]], 
            Times[ -0.062044074975450343, 
              c[ 14][ t]], 
            Times[ -0.11423673049785445, 
              c[ 15][ t]], 
            Times[ -0.15591488063143982, 
              c[ 16][ t]], 
            Times[ -0.18675027222298601, 
              c[ 17][ t]], 
            Times[ -0.206748335783172, 
              c[ 18][ t]], 
            Times[ -0.21623620818304484, 
              c[ 19][ t]], 
            Times[ -0.21584055771952015, 
              c[ 20][ t]], 
            Times[ -0.20645618564475843, 
              c[ 21][ t]], 
            Times[ -0.18920668216016434, 
              c[ 22][ t]], 
            Times[ -0.16539866862653771, 
              c[ 23][ t]], 
            Times[ -0.13647135277833605, 
              c[ 24][ t]], 
            Times[ -0.1039432537542934, 
              c[ 25][ t]], 
            Times[ -0.06935801494512607, 
              c[ 26][ t]], 
            Times[ -0.034231213779558949, 
              c[ 27][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 28][ t]], 
            Times[ 0.032022748374425904, 
              c[ 29][ t]], 
            Times[ 0.060688263076985105, 
              c[ 30][ t]], 
            Times[ 0.085044480344421608, 
              c[ 31][ t]], 
            Times[ 0.10436044624225685, 
              c[ 32][ t]], 
            Times[ 0.11814190616181255, 
              c[ 33][ t]], 
            Times[ 0.12613778810677612, 
              c[ 34][ t]], 
            Times[ 0.12833762891430928, 
              c[ 35][ t]], 
            Times[ 0.12496032289024853, 
              c[ 36][ t]], 
            Times[ 0.11643488132933186, 
              c[ 37][ t]], 
            Times[ 0.10337416789158609, 
              c[ 38][ t]], 
            Times[ 0.086542809078944752, 
              c[ 39][ t]], 
            Times[ 0.066820663127759972, 
              c[ 40][ t]], 
            Times[ 0.045163358568919301, 
              c[ 41][ t]], 
            Times[ 0.022561481809254675, 
              c[ 42][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 43][ t]], 
            Times[ -0.021580547817547879, 
              c[ 44][ t]], 
            Times[ -0.041319668477947373, 
              c[ 45][ t]], 
            Times[ -0.058468080236789913, 
              c[ 46][ t]], 
            Times[ -0.072413370861974122, 
              c[ 47][ t]], 
            Times[ -0.082699334313268813, 
              c[ 48][ t]], 
            Times[ -0.089038438663606695, 
              c[ 49][ t]], 
            Times[ -0.091317159035181589, 
              c[ 50][ t]], 
            Times[ -0.089594193770366842, 
              c[ 51][ t]], 
            Times[ -0.084091858737850814, 
              c[ 52][ t]], 
            Times[ -0.075181213012062598, 
              c[ 53][ t]], 
            Times[ -0.063361699504227403, 
              c[ 54][ t]], 
            Times[ -0.049236278094138941, 
              c[ 55][ t]], 
            Times[ -0.033483179628681567, 
              c[ 56][ t]], 
            Times[ -0.016825511857749262, 
              c[ 57][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 58][ t]], 
            Times[ 0.016273855731265604, 
              c[ 59][ t]], 
            Times[ 0.031322974491347202, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-1\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-1\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.016825511857749262`\)\ \(c[\(-60\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-59\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-58\)]\)[t] - 
            0.0633616995042274`\ \(c[\(-57\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-56\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-55\)]\)[t] - 
            0.08959419377036684`\ \(c[\(-54\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-53\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-52\)]\)[t] - 
            0.08269933431326881`\ \(c[\(-51\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-50\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-49\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-48\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-47\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-46\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-45\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-44\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-43\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-42\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-41\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-40\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-39\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-38\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-37\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-36\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-35\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-34\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-33\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-32\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-31\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-30\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-29\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-28\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-27\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-26\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-25\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-24\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-23\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-22\)]\)[t] - 
            0.206748335783172`\ \(c[\(-21\)]\)[t] - 
            0.186750272222986`\ \(c[\(-20\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-19\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-18\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-17\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-16\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-15\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-14\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-13\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-12\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-11\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-10\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-9\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-8\)]\)[t] + 
            0.756826728640657`\ \(c[\(-7\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-6\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-5\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-4\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-3\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-2\)]\)[t] + 
            1.021932454224643`\ \(c[\(-1\)]\)[t] + 
            0.9927051996072069`\ \(c[0]\)[t] + 
            0.9710122092317629`\ \(c[1]\)[t] + 
            0.9354892837886392`\ \(c[2]\)[t] + 
            0.8870637930591838`\ \(c[3]\)[t] + 
            0.8269933431326882`\ \(c[4]\)[t] + 
            0.7568267286406569`\ \(c[5]\)[t] + 
            0.6783560385470633`\ \(c[6]\)[t] + 
            0.5935615337286805`\ \(c[7]\)[t] + 
            0.5045511524271047`\ \(c[8]\)[t] + 
            0.4134966715663442`\ \(c[9]\)[t] + 
            0.3225686520215216`\ \(c[10]\)[t] + 
            0.23387232094715998`\ \(c[11]\)[t] + 
            0.14938649372796362`\ \(c[12]\)[t] + 
            0.07090751425765777`\ \(c[13]\)[t] + 
            1.8033970416801674`*^-16\ \(c[14]\)[t] - 
            0.06204407497545034`\ \(c[15]\)[t] - 
            0.11423673049785436`\ \(c[16]\)[t] - 
            0.15591488063143974`\ \(c[17]\)[t] - 
            0.186750272222986`\ \(c[18]\)[t] - 
            0.206748335783172`\ \(c[19]\)[t] - 
            0.21623620818304484`\ \(c[20]\)[t] - 
            0.21584055771952013`\ \(c[21]\)[t] - 
            0.20645618564475843`\ \(c[22]\)[t] - 
            0.18920668216016426`\ \(c[23]\)[t] - 
            0.1653986686265376`\ \(c[24]\)[t] - 
            0.13647135277833605`\ \(c[25]\)[t] - 
            0.10394325375429328`\ \(c[26]\)[t] - 
            0.06935801494512592`\ \(c[27]\)[t] - 
            0.03423121377955895`\ \(c[28]\)[t] - 
            3.898171832519376`*^-17\ \(c[29]\)[t] + 
            0.03202274837442603`\ \(c[30]\)[t] + 
            0.060688263076985105`\ \(c[31]\)[t] + 
            0.0850444803444217`\ \(c[32]\)[t] + 
            0.10436044624225692`\ \(c[33]\)[t] + 
            0.11814190616181255`\ \(c[34]\)[t] + 
            0.12613778810677614`\ \(c[35]\)[t] + 
            0.12833762891430925`\ \(c[36]\)[t] + 
            0.12496032289024853`\ \(c[37]\)[t] + 
            0.11643488132933186`\ \(c[38]\)[t] + 
            0.10337416789158609`\ \(c[39]\)[t] + 
            0.08654280907894489`\ \(c[40]\)[t] + 
            0.06682066312776015`\ \(c[41]\)[t] + 
            0.0451633585689193`\ \(c[42]\)[t] + 
            0.02256148180925487`\ \(c[43]\)[t] + 
            2.274590327822911`*^-16\ \(c[44]\)[t] - 
            0.02158054781754788`\ \(c[45]\)[t] - 
            0.04131966847794722`\ \(c[46]\)[t] - 
            0.058468080236789774`\ \(c[47]\)[t] - 
            0.07241337086197412`\ \(c[48]\)[t] - 
            0.08269933431326874`\ \(c[49]\)[t] - 
            0.08903843866360665`\ \(c[50]\)[t] - 
            0.09131715903518159`\ \(c[51]\)[t] - 
            0.08959419377036688`\ \(c[52]\)[t] - 
            0.08409185873785086`\ \(c[53]\)[t] - 
            0.0751812130120626`\ \(c[54]\)[t] - 
            0.06336169950422753`\ \(c[55]\)[t] - 
            0.049236278094139066`\ \(c[56]\)[t] - 
            0.03348317962868157`\ \(c[57]\)[t] - 
            0.0168255118577494`\ \(c[58]\)[t] - 
            1.8033970416801674`*^-16\ \(c[59]\)[t] + 
            0.016273855731265604`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -1, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -1]][ t]], 
          Plus[ 
            Times[ -0.016825511857749262, 
              c[ -60][ t]], 
            Times[ -0.033483179628681567, 
              c[ -59][ t]], 
            Times[ -0.049236278094138941, 
              c[ -58][ t]], 
            Times[ -0.063361699504227403, 
              c[ -57][ t]], 
            Times[ -0.075181213012062598, 
              c[ -56][ t]], 
            Times[ -0.084091858737850814, 
              c[ -55][ t]], 
            Times[ -0.089594193770366842, 
              c[ -54][ t]], 
            Times[ -0.091317159035181589, 
              c[ -53][ t]], 
            Times[ -0.089038438663606695, 
              c[ -52][ t]], 
            Times[ -0.082699334313268813, 
              c[ -51][ t]], 
            Times[ -0.072413370861974122, 
              c[ -50][ t]], 
            Times[ -0.058468080236789913, 
              c[ -49][ t]], 
            Times[ -0.041319668477947373, 
              c[ -48][ t]], 
            Times[ -0.021580547817547879, 
              c[ -47][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -46][ t]], 
            Times[ 0.022561481809254675, 
              c[ -45][ t]], 
            Times[ 0.045163358568919301, 
              c[ -44][ t]], 
            Times[ 0.066820663127759972, 
              c[ -43][ t]], 
            Times[ 0.086542809078944752, 
              c[ -42][ t]], 
            Times[ 0.10337416789158609, 
              c[ -41][ t]], 
            Times[ 0.11643488132933186, 
              c[ -40][ t]], 
            Times[ 0.12496032289024853, 
              c[ -39][ t]], 
            Times[ 0.12833762891430928, 
              c[ -38][ t]], 
            Times[ 0.12613778810677612, 
              c[ -37][ t]], 
            Times[ 0.11814190616181255, 
              c[ -36][ t]], 
            Times[ 0.10436044624225685, 
              c[ -35][ t]], 
            Times[ 0.085044480344421608, 
              c[ -34][ t]], 
            Times[ 0.060688263076985105, 
              c[ -33][ t]], 
            Times[ 0.032022748374425904, 
              c[ -32][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -31][ t]], 
            Times[ -0.034231213779558949, 
              c[ -30][ t]], 
            Times[ -0.06935801494512607, 
              c[ -29][ t]], 
            Times[ -0.1039432537542934, 
              c[ -28][ t]], 
            Times[ -0.13647135277833605, 
              c[ -27][ t]], 
            Times[ -0.16539866862653771, 
              c[ -26][ t]], 
            Times[ -0.18920668216016434, 
              c[ -25][ t]], 
            Times[ -0.20645618564475843, 
              c[ -24][ t]], 
            Times[ -0.21584055771952015, 
              c[ -23][ t]], 
            Times[ -0.21623620818304481, 
              c[ -22][ t]], 
            Times[ -0.206748335783172, 
              c[ -21][ t]], 
            Times[ -0.18675027222298601, 
              c[ -20][ t]], 
            Times[ -0.15591488063143982, 
              c[ -19][ t]], 
            Times[ -0.11423673049785445, 
              c[ -18][ t]], 
            Times[ -0.062044074975450343, 
              c[ -17][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -16][ t]], 
            Times[ 0.070907514257657622, 
              c[ -15][ t]], 
            Times[ 0.14938649372796362, 
              c[ -14][ t]], 
            Times[ 0.23387232094715985, 
              c[ -13][ t]], 
            Times[ 0.32256865202152135, 
              c[ -12][ t]], 
            Times[ 0.41349667156634418, 
              c[ -11][ t]], 
            Times[ 0.50455115242710469, 
              c[ -10][ t]], 
            Times[ 0.59356153372868048, 
              c[ -9][ t]], 
            Times[ 0.67835603854706339, 
              c[ -8][ t]], 
            Times[ 0.75682672864065703, 
              c[ -7][ t]], 
            Times[ 0.82699334313268824, 
              c[ -6][ t]], 
            Times[ 0.88706379305918381, 
              c[ -5][ t]], 
            Times[ 0.93548928378863916, 
              c[ -4][ t]], 
            Times[ 0.9710122092317629, 
              c[ -3][ t]], 
            Times[ 0.99270519960720693, 
              c[ -2][ t]], 
            Times[ 1.0219324542246431, 
              c[ -1][ t]], 
            Times[ 0.99270519960720693, 
              c[ 0][ t]], 
            Times[ 0.9710122092317629, 
              c[ 1][ t]], 
            Times[ 0.93548928378863916, 
              c[ 2][ t]], 
            Times[ 0.88706379305918381, 
              c[ 3][ t]], 
            Times[ 0.82699334313268824, 
              c[ 4][ t]], 
            Times[ 0.75682672864065692, 
              c[ 5][ t]], 
            Times[ 0.67835603854706328, 
              c[ 6][ t]], 
            Times[ 0.59356153372868048, 
              c[ 7][ t]], 
            Times[ 0.50455115242710469, 
              c[ 8][ t]], 
            Times[ 0.41349667156634418, 
              c[ 9][ t]], 
            Times[ 0.32256865202152157, 
              c[ 10][ t]], 
            Times[ 0.23387232094715998, 
              c[ 11][ t]], 
            Times[ 0.14938649372796362, 
              c[ 12][ t]], 
            Times[ 0.070907514257657775, 
              c[ 13][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 14][ t]], 
            Times[ -0.062044074975450343, 
              c[ 15][ t]], 
            Times[ -0.11423673049785436, 
              c[ 16][ t]], 
            Times[ -0.15591488063143974, 
              c[ 17][ t]], 
            Times[ -0.18675027222298601, 
              c[ 18][ t]], 
            Times[ -0.206748335783172, 
              c[ 19][ t]], 
            Times[ -0.21623620818304484, 
              c[ 20][ t]], 
            Times[ -0.21584055771952013, 
              c[ 21][ t]], 
            Times[ -0.20645618564475843, 
              c[ 22][ t]], 
            Times[ -0.18920668216016426, 
              c[ 23][ t]], 
            Times[ -0.1653986686265376, 
              c[ 24][ t]], 
            Times[ -0.13647135277833605, 
              c[ 25][ t]], 
            Times[ -0.10394325375429328, 
              c[ 26][ t]], 
            Times[ -0.069358014945125918, 
              c[ 27][ t]], 
            Times[ -0.034231213779558949, 
              c[ 28][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 29][ t]], 
            Times[ 0.032022748374426029, 
              c[ 30][ t]], 
            Times[ 0.060688263076985105, 
              c[ 31][ t]], 
            Times[ 0.085044480344421705, 
              c[ 32][ t]], 
            Times[ 0.10436044624225692, 
              c[ 33][ t]], 
            Times[ 0.11814190616181255, 
              c[ 34][ t]], 
            Times[ 0.12613778810677614, 
              c[ 35][ t]], 
            Times[ 0.12833762891430925, 
              c[ 36][ t]], 
            Times[ 0.12496032289024853, 
              c[ 37][ t]], 
            Times[ 0.11643488132933186, 
              c[ 38][ t]], 
            Times[ 0.10337416789158609, 
              c[ 39][ t]], 
            Times[ 0.086542809078944891, 
              c[ 40][ t]], 
            Times[ 0.066820663127760152, 
              c[ 41][ t]], 
            Times[ 0.045163358568919301, 
              c[ 42][ t]], 
            Times[ 0.022561481809254869, 
              c[ 43][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ 44][ t]], 
            Times[ -0.021580547817547879, 
              c[ 45][ t]], 
            Times[ -0.04131966847794722, 
              c[ 46][ t]], 
            Times[ -0.058468080236789774, 
              c[ 47][ t]], 
            Times[ -0.072413370861974122, 
              c[ 48][ t]], 
            Times[ -0.082699334313268744, 
              c[ 49][ t]], 
            Times[ -0.089038438663606653, 
              c[ 50][ t]], 
            Times[ -0.091317159035181589, 
              c[ 51][ t]], 
            Times[ -0.089594193770366884, 
              c[ 52][ t]], 
            Times[ -0.084091858737850855, 
              c[ 53][ t]], 
            Times[ -0.075181213012062598, 
              c[ 54][ t]], 
            Times[ -0.063361699504227528, 
              c[ 55][ t]], 
            Times[ -0.049236278094139066, 
              c[ 56][ t]], 
            Times[ -0.033483179628681567, 
              c[ 57][ t]], 
            Times[ -0.016825511857749401, 
              c[ 58][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 59][ t]], 
            Times[ 0.016273855731265604, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "0", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[0]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-3.898171832519376`*^-17\)\ \(c[\(-60\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-59\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-58\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-57\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-56\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-55\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-54\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-53\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-52\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-51\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-50\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-49\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-48\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-47\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-46\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-45\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-44\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-43\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-42\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-41\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-40\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-39\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-38\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-37\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-36\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-35\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-34\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-33\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-32\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-31\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-30\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-29\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-28\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-27\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-26\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-25\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-24\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-23\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-22\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-21\)]\)[t] - 
            0.206748335783172`\ \(c[\(-20\)]\)[t] - 
            0.186750272222986`\ \(c[\(-19\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-18\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-17\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-16\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-15\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-14\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-13\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-12\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-11\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-10\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-9\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-8\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-7\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-6\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-5\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-4\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-3\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-2\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-1\)]\)[t] + 1.`\ \(c[0]\)[t] + 
            0.9927051996072069`\ \(c[1]\)[t] + 
            0.9710122092317629`\ \(c[2]\)[t] + 
            0.9354892837886392`\ \(c[3]\)[t] + 
            0.8870637930591838`\ \(c[4]\)[t] + 
            0.8269933431326882`\ \(c[5]\)[t] + 
            0.7568267286406569`\ \(c[6]\)[t] + 
            0.6783560385470634`\ \(c[7]\)[t] + 
            0.5935615337286805`\ \(c[8]\)[t] + 
            0.5045511524271047`\ \(c[9]\)[t] + 
            0.4134966715663442`\ \(c[10]\)[t] + 
            0.3225686520215216`\ \(c[11]\)[t] + 
            0.23387232094715985`\ \(c[12]\)[t] + 
            0.14938649372796362`\ \(c[13]\)[t] + 
            0.07090751425765777`\ \(c[14]\)[t] + 
            3.898171832519376`*^-17\ \(c[15]\)[t] - 
            0.06204407497545034`\ \(c[16]\)[t] - 
            0.11423673049785436`\ \(c[17]\)[t] - 
            0.15591488063143982`\ \(c[18]\)[t] - 
            0.186750272222986`\ \(c[19]\)[t] - 
            0.206748335783172`\ \(c[20]\)[t] - 
            0.21623620818304484`\ \(c[21]\)[t] - 
            0.21584055771952015`\ \(c[22]\)[t] - 
            0.20645618564475843`\ \(c[23]\)[t] - 
            0.18920668216016426`\ \(c[24]\)[t] - 
            0.1653986686265377`\ \(c[25]\)[t] - 
            0.13647135277833605`\ \(c[26]\)[t] - 
            0.10394325375429328`\ \(c[27]\)[t] - 
            0.06935801494512607`\ \(c[28]\)[t] - 
            0.03423121377955895`\ \(c[29]\)[t] - 
            3.898171832519376`*^-17\ \(c[30]\)[t] + 
            0.032022748374425904`\ \(c[31]\)[t] + 
            0.060688263076985105`\ \(c[32]\)[t] + 
            0.0850444803444217`\ \(c[33]\)[t] + 
            0.10436044624225685`\ \(c[34]\)[t] + 
            0.11814190616181255`\ \(c[35]\)[t] + 
            0.12613778810677614`\ \(c[36]\)[t] + 
            0.12833762891430928`\ \(c[37]\)[t] + 
            0.12496032289024853`\ \(c[38]\)[t] + 
            0.11643488132933186`\ \(c[39]\)[t] + 
            0.10337416789158609`\ \(c[40]\)[t] + 
            0.08654280907894489`\ \(c[41]\)[t] + 
            0.06682066312775997`\ \(c[42]\)[t] + 
            0.0451633585689193`\ \(c[43]\)[t] + 
            0.02256148180925487`\ \(c[44]\)[t] + 
            3.8981718325193755`*^-17\ \(c[45]\)[t] - 
            0.02158054781754788`\ \(c[46]\)[t] - 
            0.04131966847794722`\ \(c[47]\)[t] - 
            0.05846808023678991`\ \(c[48]\)[t] - 
            0.07241337086197412`\ \(c[49]\)[t] - 
            0.08269933431326874`\ \(c[50]\)[t] - 
            0.0890384386636067`\ \(c[51]\)[t] - 
            0.09131715903518159`\ \(c[52]\)[t] - 
            0.08959419377036688`\ \(c[53]\)[t] - 
            0.08409185873785081`\ \(c[54]\)[t] - 
            0.0751812130120626`\ \(c[55]\)[t] - 
            0.06336169950422753`\ \(c[56]\)[t] - 
            0.04923627809413894`\ \(c[57]\)[t] - 
            0.03348317962868157`\ \(c[58]\)[t] - 
            0.0168255118577494`\ \(c[59]\)[t] - 
            3.898171832519376`*^-17\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 0, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 0]][ t]], 
          Plus[ 
            Times[ -3.8981718325193761*^-17, 
              c[ -60][ t]], 
            Times[ -0.016825511857749401, 
              c[ -59][ t]], 
            Times[ -0.033483179628681567, 
              c[ -58][ t]], 
            Times[ -0.049236278094138941, 
              c[ -57][ t]], 
            Times[ -0.063361699504227528, 
              c[ -56][ t]], 
            Times[ -0.075181213012062598, 
              c[ -55][ t]], 
            Times[ -0.084091858737850814, 
              c[ -54][ t]], 
            Times[ -0.089594193770366884, 
              c[ -53][ t]], 
            Times[ -0.091317159035181589, 
              c[ -52][ t]], 
            Times[ -0.089038438663606695, 
              c[ -51][ t]], 
            Times[ -0.082699334313268744, 
              c[ -50][ t]], 
            Times[ -0.072413370861974122, 
              c[ -49][ t]], 
            Times[ -0.058468080236789913, 
              c[ -48][ t]], 
            Times[ -0.04131966847794722, 
              c[ -47][ t]], 
            Times[ -0.021580547817547879, 
              c[ -46][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -45][ t]], 
            Times[ 0.022561481809254869, 
              c[ -44][ t]], 
            Times[ 0.045163358568919301, 
              c[ -43][ t]], 
            Times[ 0.066820663127759972, 
              c[ -42][ t]], 
            Times[ 0.086542809078944891, 
              c[ -41][ t]], 
            Times[ 0.10337416789158609, 
              c[ -40][ t]], 
            Times[ 0.11643488132933186, 
              c[ -39][ t]], 
            Times[ 0.12496032289024853, 
              c[ -38][ t]], 
            Times[ 0.12833762891430928, 
              c[ -37][ t]], 
            Times[ 0.12613778810677614, 
              c[ -36][ t]], 
            Times[ 0.11814190616181255, 
              c[ -35][ t]], 
            Times[ 0.10436044624225685, 
              c[ -34][ t]], 
            Times[ 0.085044480344421705, 
              c[ -33][ t]], 
            Times[ 0.060688263076985105, 
              c[ -32][ t]], 
            Times[ 0.032022748374425904, 
              c[ -31][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -30][ t]], 
            Times[ -0.034231213779558949, 
              c[ -29][ t]], 
            Times[ -0.06935801494512607, 
              c[ -28][ t]], 
            Times[ -0.10394325375429328, 
              c[ -27][ t]], 
            Times[ -0.13647135277833605, 
              c[ -26][ t]], 
            Times[ -0.16539866862653771, 
              c[ -25][ t]], 
            Times[ -0.18920668216016426, 
              c[ -24][ t]], 
            Times[ -0.20645618564475843, 
              c[ -23][ t]], 
            Times[ -0.21584055771952015, 
              c[ -22][ t]], 
            Times[ -0.21623620818304484, 
              c[ -21][ t]], 
            Times[ -0.206748335783172, 
              c[ -20][ t]], 
            Times[ -0.18675027222298601, 
              c[ -19][ t]], 
            Times[ -0.15591488063143982, 
              c[ -18][ t]], 
            Times[ -0.11423673049785436, 
              c[ -17][ t]], 
            Times[ -0.062044074975450343, 
              c[ -16][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -15][ t]], 
            Times[ 0.070907514257657775, 
              c[ -14][ t]], 
            Times[ 0.14938649372796362, 
              c[ -13][ t]], 
            Times[ 0.23387232094715985, 
              c[ -12][ t]], 
            Times[ 0.32256865202152157, 
              c[ -11][ t]], 
            Times[ 0.41349667156634418, 
              c[ -10][ t]], 
            Times[ 0.50455115242710469, 
              c[ -9][ t]], 
            Times[ 0.59356153372868048, 
              c[ -8][ t]], 
            Times[ 0.67835603854706339, 
              c[ -7][ t]], 
            Times[ 0.75682672864065692, 
              c[ -6][ t]], 
            Times[ 0.82699334313268824, 
              c[ -5][ t]], 
            Times[ 0.88706379305918381, 
              c[ -4][ t]], 
            Times[ 0.93548928378863916, 
              c[ -3][ t]], 
            Times[ 0.9710122092317629, 
              c[ -2][ t]], 
            Times[ 0.99270519960720693, 
              c[ -1][ t]], 
            Times[ 1.0, 
              c[ 0][ t]], 
            Times[ 0.99270519960720693, 
              c[ 1][ t]], 
            Times[ 0.9710122092317629, 
              c[ 2][ t]], 
            Times[ 0.93548928378863916, 
              c[ 3][ t]], 
            Times[ 0.88706379305918381, 
              c[ 4][ t]], 
            Times[ 0.82699334313268824, 
              c[ 5][ t]], 
            Times[ 0.75682672864065692, 
              c[ 6][ t]], 
            Times[ 0.67835603854706339, 
              c[ 7][ t]], 
            Times[ 0.59356153372868048, 
              c[ 8][ t]], 
            Times[ 0.50455115242710469, 
              c[ 9][ t]], 
            Times[ 0.41349667156634418, 
              c[ 10][ t]], 
            Times[ 0.32256865202152157, 
              c[ 11][ t]], 
            Times[ 0.23387232094715985, 
              c[ 12][ t]], 
            Times[ 0.14938649372796362, 
              c[ 13][ t]], 
            Times[ 0.070907514257657775, 
              c[ 14][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 15][ t]], 
            Times[ -0.062044074975450343, 
              c[ 16][ t]], 
            Times[ -0.11423673049785436, 
              c[ 17][ t]], 
            Times[ -0.15591488063143982, 
              c[ 18][ t]], 
            Times[ -0.18675027222298601, 
              c[ 19][ t]], 
            Times[ -0.206748335783172, 
              c[ 20][ t]], 
            Times[ -0.21623620818304484, 
              c[ 21][ t]], 
            Times[ -0.21584055771952015, 
              c[ 22][ t]], 
            Times[ -0.20645618564475843, 
              c[ 23][ t]], 
            Times[ -0.18920668216016426, 
              c[ 24][ t]], 
            Times[ -0.16539866862653771, 
              c[ 25][ t]], 
            Times[ -0.13647135277833605, 
              c[ 26][ t]], 
            Times[ -0.10394325375429328, 
              c[ 27][ t]], 
            Times[ -0.06935801494512607, 
              c[ 28][ t]], 
            Times[ -0.034231213779558949, 
              c[ 29][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 30][ t]], 
            Times[ 0.032022748374425904, 
              c[ 31][ t]], 
            Times[ 0.060688263076985105, 
              c[ 32][ t]], 
            Times[ 0.085044480344421705, 
              c[ 33][ t]], 
            Times[ 0.10436044624225685, 
              c[ 34][ t]], 
            Times[ 0.11814190616181255, 
              c[ 35][ t]], 
            Times[ 0.12613778810677614, 
              c[ 36][ t]], 
            Times[ 0.12833762891430928, 
              c[ 37][ t]], 
            Times[ 0.12496032289024853, 
              c[ 38][ t]], 
            Times[ 0.11643488132933186, 
              c[ 39][ t]], 
            Times[ 0.10337416789158609, 
              c[ 40][ t]], 
            Times[ 0.086542809078944891, 
              c[ 41][ t]], 
            Times[ 0.066820663127759972, 
              c[ 42][ t]], 
            Times[ 0.045163358568919301, 
              c[ 43][ t]], 
            Times[ 0.022561481809254869, 
              c[ 44][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 45][ t]], 
            Times[ -0.021580547817547879, 
              c[ 46][ t]], 
            Times[ -0.04131966847794722, 
              c[ 47][ t]], 
            Times[ -0.058468080236789913, 
              c[ 48][ t]], 
            Times[ -0.072413370861974122, 
              c[ 49][ t]], 
            Times[ -0.082699334313268744, 
              c[ 50][ t]], 
            Times[ -0.089038438663606695, 
              c[ 51][ t]], 
            Times[ -0.091317159035181589, 
              c[ 52][ t]], 
            Times[ -0.089594193770366884, 
              c[ 53][ t]], 
            Times[ -0.084091858737850814, 
              c[ 54][ t]], 
            Times[ -0.075181213012062598, 
              c[ 55][ t]], 
            Times[ -0.063361699504227528, 
              c[ 56][ t]], 
            Times[ -0.049236278094138941, 
              c[ 57][ t]], 
            Times[ -0.033483179628681567, 
              c[ 58][ t]], 
            Times[ -0.016825511857749401, 
              c[ 59][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "1", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[1]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.016273855731265604`\ \(c[\(-60\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-59\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-58\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-57\)]\)[t] - 
            0.049236278094139066`\ \(c[\(-56\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-55\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-54\)]\)[t] - 
            0.08409185873785086`\ \(c[\(-53\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-52\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-51\)]\)[t] - 
            0.08903843866360665`\ \(c[\(-50\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-49\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-48\)]\)[t] - 
            0.058468080236789774`\ \(c[\(-47\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-46\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-45\)]\)[t] + 
            2.274590327822911`*^-16\ \(c[\(-44\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-43\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-42\)]\)[t] + 
            0.06682066312776015`\ \(c[\(-41\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-40\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-39\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-38\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-37\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-36\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-35\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-34\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-33\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-32\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-31\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-30\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-29\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-28\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-27\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-26\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-25\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-24\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-23\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-22\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-21\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-20\)]\)[t] - 
            0.206748335783172`\ \(c[\(-19\)]\)[t] - 
            0.186750272222986`\ \(c[\(-18\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-17\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-16\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-15\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-14\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-13\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-12\)]\)[t] + 
            0.23387232094715998`\ \(c[\(-11\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-10\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-9\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-8\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-7\)]\)[t] + 
            0.6783560385470633`\ \(c[\(-6\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-5\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-4\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-3\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-2\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-1\)]\)[t] + 
            0.9927051996072069`\ \(c[0]\)[t] + 
            1.021932454224643`\ \(c[1]\)[t] + 
            0.9927051996072069`\ \(c[2]\)[t] + 
            0.9710122092317629`\ \(c[3]\)[t] + 
            0.9354892837886392`\ \(c[4]\)[t] + 
            0.8870637930591838`\ \(c[5]\)[t] + 
            0.8269933431326882`\ \(c[6]\)[t] + 
            0.756826728640657`\ \(c[7]\)[t] + 
            0.6783560385470634`\ \(c[8]\)[t] + 
            0.5935615337286805`\ \(c[9]\)[t] + 
            0.5045511524271047`\ \(c[10]\)[t] + 
            0.4134966715663442`\ \(c[11]\)[t] + 
            0.32256865202152135`\ \(c[12]\)[t] + 
            0.23387232094715985`\ \(c[13]\)[t] + 
            0.14938649372796362`\ \(c[14]\)[t] + 
            0.07090751425765762`\ \(c[15]\)[t] + 
            3.898171832519376`*^-17\ \(c[16]\)[t] - 
            0.06204407497545034`\ \(c[17]\)[t] - 
            0.11423673049785445`\ \(c[18]\)[t] - 
            0.15591488063143982`\ \(c[19]\)[t] - 
            0.186750272222986`\ \(c[20]\)[t] - 
            0.206748335783172`\ \(c[21]\)[t] - 
            0.21623620818304481`\ \(c[22]\)[t] - 
            0.21584055771952015`\ \(c[23]\)[t] - 
            0.20645618564475843`\ \(c[24]\)[t] - 
            0.18920668216016434`\ \(c[25]\)[t] - 
            0.1653986686265377`\ \(c[26]\)[t] - 
            0.13647135277833605`\ \(c[27]\)[t] - 
            0.1039432537542934`\ \(c[28]\)[t] - 
            0.06935801494512607`\ \(c[29]\)[t] - 
            0.03423121377955895`\ \(c[30]\)[t] - 
            1.8033970416801674`*^-16\ \(c[31]\)[t] + 
            0.032022748374425904`\ \(c[32]\)[t] + 
            0.060688263076985105`\ \(c[33]\)[t] + 
            0.08504448034442161`\ \(c[34]\)[t] + 
            0.10436044624225685`\ \(c[35]\)[t] + 
            0.11814190616181255`\ \(c[36]\)[t] + 
            0.12613778810677612`\ \(c[37]\)[t] + 
            0.12833762891430928`\ \(c[38]\)[t] + 
            0.12496032289024853`\ \(c[39]\)[t] + 
            0.11643488132933186`\ \(c[40]\)[t] + 
            0.10337416789158609`\ \(c[41]\)[t] + 
            0.08654280907894475`\ \(c[42]\)[t] + 
            0.06682066312775997`\ \(c[43]\)[t] + 
            0.0451633585689193`\ \(c[44]\)[t] + 
            0.022561481809254675`\ \(c[45]\)[t] + 
            3.8981718325193755`*^-17\ \(c[46]\)[t] - 
            0.02158054781754788`\ \(c[47]\)[t] - 
            0.04131966847794737`\ \(c[48]\)[t] - 
            0.05846808023678991`\ \(c[49]\)[t] - 
            0.07241337086197412`\ \(c[50]\)[t] - 
            0.08269933431326881`\ \(c[51]\)[t] - 
            0.0890384386636067`\ \(c[52]\)[t] - 
            0.09131715903518159`\ \(c[53]\)[t] - 
            0.08959419377036684`\ \(c[54]\)[t] - 
            0.08409185873785081`\ \(c[55]\)[t] - 
            0.0751812130120626`\ \(c[56]\)[t] - 
            0.0633616995042274`\ \(c[57]\)[t] - 
            0.04923627809413894`\ \(c[58]\)[t] - 
            0.03348317962868157`\ \(c[59]\)[t] - 
            0.016825511857749262`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 1, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 1]][ t]], 
          Plus[ 
            Times[ 0.016273855731265604, 
              c[ -60][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -59][ t]], 
            Times[ -0.016825511857749401, 
              c[ -58][ t]], 
            Times[ -0.033483179628681567, 
              c[ -57][ t]], 
            Times[ -0.049236278094139066, 
              c[ -56][ t]], 
            Times[ -0.063361699504227528, 
              c[ -55][ t]], 
            Times[ -0.075181213012062598, 
              c[ -54][ t]], 
            Times[ -0.084091858737850855, 
              c[ -53][ t]], 
            Times[ -0.089594193770366884, 
              c[ -52][ t]], 
            Times[ -0.091317159035181589, 
              c[ -51][ t]], 
            Times[ -0.089038438663606653, 
              c[ -50][ t]], 
            Times[ -0.082699334313268744, 
              c[ -49][ t]], 
            Times[ -0.072413370861974122, 
              c[ -48][ t]], 
            Times[ -0.058468080236789774, 
              c[ -47][ t]], 
            Times[ -0.04131966847794722, 
              c[ -46][ t]], 
            Times[ -0.021580547817547879, 
              c[ -45][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ -44][ t]], 
            Times[ 0.022561481809254869, 
              c[ -43][ t]], 
            Times[ 0.045163358568919301, 
              c[ -42][ t]], 
            Times[ 0.066820663127760152, 
              c[ -41][ t]], 
            Times[ 0.086542809078944891, 
              c[ -40][ t]], 
            Times[ 0.10337416789158609, 
              c[ -39][ t]], 
            Times[ 0.11643488132933186, 
              c[ -38][ t]], 
            Times[ 0.12496032289024853, 
              c[ -37][ t]], 
            Times[ 0.12833762891430925, 
              c[ -36][ t]], 
            Times[ 0.12613778810677614, 
              c[ -35][ t]], 
            Times[ 0.11814190616181255, 
              c[ -34][ t]], 
            Times[ 0.10436044624225692, 
              c[ -33][ t]], 
            Times[ 0.085044480344421705, 
              c[ -32][ t]], 
            Times[ 0.060688263076985105, 
              c[ -31][ t]], 
            Times[ 0.032022748374426029, 
              c[ -30][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -29][ t]], 
            Times[ -0.034231213779558949, 
              c[ -28][ t]], 
            Times[ -0.069358014945125918, 
              c[ -27][ t]], 
            Times[ -0.10394325375429328, 
              c[ -26][ t]], 
            Times[ -0.13647135277833605, 
              c[ -25][ t]], 
            Times[ -0.1653986686265376, 
              c[ -24][ t]], 
            Times[ -0.18920668216016426, 
              c[ -23][ t]], 
            Times[ -0.20645618564475843, 
              c[ -22][ t]], 
            Times[ -0.21584055771952013, 
              c[ -21][ t]], 
            Times[ -0.21623620818304484, 
              c[ -20][ t]], 
            Times[ -0.206748335783172, 
              c[ -19][ t]], 
            Times[ -0.18675027222298601, 
              c[ -18][ t]], 
            Times[ -0.15591488063143974, 
              c[ -17][ t]], 
            Times[ -0.11423673049785436, 
              c[ -16][ t]], 
            Times[ -0.062044074975450343, 
              c[ -15][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -14][ t]], 
            Times[ 0.070907514257657775, 
              c[ -13][ t]], 
            Times[ 0.14938649372796362, 
              c[ -12][ t]], 
            Times[ 0.23387232094715998, 
              c[ -11][ t]], 
            Times[ 0.32256865202152157, 
              c[ -10][ t]], 
            Times[ 0.41349667156634418, 
              c[ -9][ t]], 
            Times[ 0.50455115242710469, 
              c[ -8][ t]], 
            Times[ 0.59356153372868048, 
              c[ -7][ t]], 
            Times[ 0.67835603854706328, 
              c[ -6][ t]], 
            Times[ 0.75682672864065692, 
              c[ -5][ t]], 
            Times[ 0.82699334313268824, 
              c[ -4][ t]], 
            Times[ 0.88706379305918381, 
              c[ -3][ t]], 
            Times[ 0.93548928378863916, 
              c[ -2][ t]], 
            Times[ 0.9710122092317629, 
              c[ -1][ t]], 
            Times[ 0.99270519960720693, 
              c[ 0][ t]], 
            Times[ 1.0219324542246431, 
              c[ 1][ t]], 
            Times[ 0.99270519960720693, 
              c[ 2][ t]], 
            Times[ 0.9710122092317629, 
              c[ 3][ t]], 
            Times[ 0.93548928378863916, 
              c[ 4][ t]], 
            Times[ 0.88706379305918381, 
              c[ 5][ t]], 
            Times[ 0.82699334313268824, 
              c[ 6][ t]], 
            Times[ 0.75682672864065703, 
              c[ 7][ t]], 
            Times[ 0.67835603854706339, 
              c[ 8][ t]], 
            Times[ 0.59356153372868048, 
              c[ 9][ t]], 
            Times[ 0.50455115242710469, 
              c[ 10][ t]], 
            Times[ 0.41349667156634418, 
              c[ 11][ t]], 
            Times[ 0.32256865202152135, 
              c[ 12][ t]], 
            Times[ 0.23387232094715985, 
              c[ 13][ t]], 
            Times[ 0.14938649372796362, 
              c[ 14][ t]], 
            Times[ 0.070907514257657622, 
              c[ 15][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 16][ t]], 
            Times[ -0.062044074975450343, 
              c[ 17][ t]], 
            Times[ -0.11423673049785445, 
              c[ 18][ t]], 
            Times[ -0.15591488063143982, 
              c[ 19][ t]], 
            Times[ -0.18675027222298601, 
              c[ 20][ t]], 
            Times[ -0.206748335783172, 
              c[ 21][ t]], 
            Times[ -0.21623620818304481, 
              c[ 22][ t]], 
            Times[ -0.21584055771952015, 
              c[ 23][ t]], 
            Times[ -0.20645618564475843, 
              c[ 24][ t]], 
            Times[ -0.18920668216016434, 
              c[ 25][ t]], 
            Times[ -0.16539866862653771, 
              c[ 26][ t]], 
            Times[ -0.13647135277833605, 
              c[ 27][ t]], 
            Times[ -0.1039432537542934, 
              c[ 28][ t]], 
            Times[ -0.06935801494512607, 
              c[ 29][ t]], 
            Times[ -0.034231213779558949, 
              c[ 30][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 31][ t]], 
            Times[ 0.032022748374425904, 
              c[ 32][ t]], 
            Times[ 0.060688263076985105, 
              c[ 33][ t]], 
            Times[ 0.085044480344421608, 
              c[ 34][ t]], 
            Times[ 0.10436044624225685, 
              c[ 35][ t]], 
            Times[ 0.11814190616181255, 
              c[ 36][ t]], 
            Times[ 0.12613778810677612, 
              c[ 37][ t]], 
            Times[ 0.12833762891430928, 
              c[ 38][ t]], 
            Times[ 0.12496032289024853, 
              c[ 39][ t]], 
            Times[ 0.11643488132933186, 
              c[ 40][ t]], 
            Times[ 0.10337416789158609, 
              c[ 41][ t]], 
            Times[ 0.086542809078944752, 
              c[ 42][ t]], 
            Times[ 0.066820663127759972, 
              c[ 43][ t]], 
            Times[ 0.045163358568919301, 
              c[ 44][ t]], 
            Times[ 0.022561481809254675, 
              c[ 45][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 46][ t]], 
            Times[ -0.021580547817547879, 
              c[ 47][ t]], 
            Times[ -0.041319668477947373, 
              c[ 48][ t]], 
            Times[ -0.058468080236789913, 
              c[ 49][ t]], 
            Times[ -0.072413370861974122, 
              c[ 50][ t]], 
            Times[ -0.082699334313268813, 
              c[ 51][ t]], 
            Times[ -0.089038438663606695, 
              c[ 52][ t]], 
            Times[ -0.091317159035181589, 
              c[ 53][ t]], 
            Times[ -0.089594193770366842, 
              c[ 54][ t]], 
            Times[ -0.084091858737850814, 
              c[ 55][ t]], 
            Times[ -0.075181213012062598, 
              c[ 56][ t]], 
            Times[ -0.063361699504227403, 
              c[ 57][ t]], 
            Times[ -0.049236278094138941, 
              c[ 58][ t]], 
            Times[ -0.033483179628681567, 
              c[ 59][ t]], 
            Times[ -0.016825511857749262, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "2", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[2]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.0313229744913472`\ \(c[\(-60\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-59\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-58\)]\)[t] - 
            0.016825511857749262`\ \(c[\(-57\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-56\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-55\)]\)[t] - 
            0.0633616995042274`\ \(c[\(-54\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-53\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-52\)]\)[t] - 
            0.08959419377036684`\ \(c[\(-51\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-50\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-49\)]\)[t] - 
            0.08269933431326881`\ \(c[\(-48\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-47\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-46\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-45\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-44\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-43\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-42\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-41\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-40\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-39\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-38\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-37\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-36\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-35\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-34\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-33\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-32\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-31\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-30\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-29\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-28\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-27\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-26\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-25\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-24\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-23\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-22\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-21\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-20\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-19\)]\)[t] - 
            0.206748335783172`\ \(c[\(-18\)]\)[t] - 
            0.186750272222986`\ \(c[\(-17\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-16\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-15\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-14\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-13\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-12\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-11\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-10\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-9\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-8\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-7\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-6\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-5\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-4\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-3\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-2\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-1\)]\)[t] + 
            0.9710122092317629`\ \(c[0]\)[t] + 
            0.9927051996072069`\ \(c[1]\)[t] + 
            1.087729816898572`\ \(c[2]\)[t] + 
            0.9927051996072067`\ \(c[3]\)[t] + 
            0.9710122092317629`\ \(c[4]\)[t] + 
            0.9354892837886392`\ \(c[5]\)[t] + 
            0.8870637930591837`\ \(c[6]\)[t] + 
            0.8269933431326882`\ \(c[7]\)[t] + 
            0.7568267286406569`\ \(c[8]\)[t] + 
            0.6783560385470633`\ \(c[9]\)[t] + 
            0.5935615337286805`\ \(c[10]\)[t] + 
            0.5045511524271047`\ \(c[11]\)[t] + 
            0.4134966715663442`\ \(c[12]\)[t] + 
            0.3225686520215216`\ \(c[13]\)[t] + 
            0.23387232094715998`\ \(c[14]\)[t] + 
            0.14938649372796362`\ \(c[15]\)[t] + 
            0.07090751425765777`\ \(c[16]\)[t] + 
            1.8033970416801674`*^-16\ \(c[17]\)[t] - 
            0.06204407497545034`\ \(c[18]\)[t] - 
            0.11423673049785436`\ \(c[19]\)[t] - 
            0.15591488063143974`\ \(c[20]\)[t] - 
            0.186750272222986`\ \(c[21]\)[t] - 
            0.206748335783172`\ \(c[22]\)[t] - 
            0.21623620818304484`\ \(c[23]\)[t] - 
            0.21584055771952013`\ \(c[24]\)[t] - 
            0.20645618564475843`\ \(c[25]\)[t] - 
            0.18920668216016426`\ \(c[26]\)[t] - 
            0.1653986686265376`\ \(c[27]\)[t] - 
            0.13647135277833605`\ \(c[28]\)[t] - 
            0.10394325375429328`\ \(c[29]\)[t] - 
            0.06935801494512592`\ \(c[30]\)[t] - 
            0.03423121377955895`\ \(c[31]\)[t] - 
            3.898171832519376`*^-17\ \(c[32]\)[t] + 
            0.03202274837442603`\ \(c[33]\)[t] + 
            0.060688263076985105`\ \(c[34]\)[t] + 
            0.0850444803444217`\ \(c[35]\)[t] + 
            0.10436044624225692`\ \(c[36]\)[t] + 
            0.11814190616181255`\ \(c[37]\)[t] + 
            0.12613778810677614`\ \(c[38]\)[t] + 
            0.12833762891430925`\ \(c[39]\)[t] + 
            0.12496032289024853`\ \(c[40]\)[t] + 
            0.11643488132933195`\ \(c[41]\)[t] + 
            0.10337416789158609`\ \(c[42]\)[t] + 
            0.08654280907894489`\ \(c[43]\)[t] + 
            0.06682066312776015`\ \(c[44]\)[t] + 
            0.0451633585689193`\ \(c[45]\)[t] + 
            0.02256148180925487`\ \(c[46]\)[t] + 
            2.274590327822911`*^-16\ \(c[47]\)[t] - 
            0.02158054781754788`\ \(c[48]\)[t] - 
            0.04131966847794722`\ \(c[49]\)[t] - 
            0.058468080236789774`\ \(c[50]\)[t] - 
            0.07241337086197412`\ \(c[51]\)[t] - 
            0.08269933431326874`\ \(c[52]\)[t] - 
            0.08903843866360665`\ \(c[53]\)[t] - 
            0.09131715903518159`\ \(c[54]\)[t] - 
            0.08959419377036688`\ \(c[55]\)[t] - 
            0.08409185873785086`\ \(c[56]\)[t] - 
            0.0751812130120626`\ \(c[57]\)[t] - 
            0.06336169950422753`\ \(c[58]\)[t] - 
            0.049236278094139066`\ \(c[59]\)[t] - 
            0.03348317962868157`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 2, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 2]][ t]], 
          Plus[ 
            Times[ 0.031322974491347202, 
              c[ -60][ t]], 
            Times[ 0.016273855731265604, 
              c[ -59][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -58][ t]], 
            Times[ -0.016825511857749262, 
              c[ -57][ t]], 
            Times[ -0.033483179628681567, 
              c[ -56][ t]], 
            Times[ -0.049236278094138941, 
              c[ -55][ t]], 
            Times[ -0.063361699504227403, 
              c[ -54][ t]], 
            Times[ -0.075181213012062598, 
              c[ -53][ t]], 
            Times[ -0.084091858737850814, 
              c[ -52][ t]], 
            Times[ -0.089594193770366842, 
              c[ -51][ t]], 
            Times[ -0.091317159035181589, 
              c[ -50][ t]], 
            Times[ -0.089038438663606695, 
              c[ -49][ t]], 
            Times[ -0.082699334313268813, 
              c[ -48][ t]], 
            Times[ -0.072413370861974122, 
              c[ -47][ t]], 
            Times[ -0.058468080236789913, 
              c[ -46][ t]], 
            Times[ -0.041319668477947373, 
              c[ -45][ t]], 
            Times[ -0.021580547817547879, 
              c[ -44][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -43][ t]], 
            Times[ 0.022561481809254675, 
              c[ -42][ t]], 
            Times[ 0.045163358568919301, 
              c[ -41][ t]], 
            Times[ 0.066820663127759972, 
              c[ -40][ t]], 
            Times[ 0.086542809078944752, 
              c[ -39][ t]], 
            Times[ 0.10337416789158609, 
              c[ -38][ t]], 
            Times[ 0.11643488132933186, 
              c[ -37][ t]], 
            Times[ 0.12496032289024853, 
              c[ -36][ t]], 
            Times[ 0.12833762891430928, 
              c[ -35][ t]], 
            Times[ 0.12613778810677612, 
              c[ -34][ t]], 
            Times[ 0.11814190616181255, 
              c[ -33][ t]], 
            Times[ 0.10436044624225685, 
              c[ -32][ t]], 
            Times[ 0.085044480344421608, 
              c[ -31][ t]], 
            Times[ 0.060688263076985105, 
              c[ -30][ t]], 
            Times[ 0.032022748374425904, 
              c[ -29][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -28][ t]], 
            Times[ -0.034231213779558949, 
              c[ -27][ t]], 
            Times[ -0.06935801494512607, 
              c[ -26][ t]], 
            Times[ -0.1039432537542934, 
              c[ -25][ t]], 
            Times[ -0.13647135277833605, 
              c[ -24][ t]], 
            Times[ -0.16539866862653771, 
              c[ -23][ t]], 
            Times[ -0.18920668216016434, 
              c[ -22][ t]], 
            Times[ -0.20645618564475843, 
              c[ -21][ t]], 
            Times[ -0.21584055771952015, 
              c[ -20][ t]], 
            Times[ -0.21623620818304484, 
              c[ -19][ t]], 
            Times[ -0.206748335783172, 
              c[ -18][ t]], 
            Times[ -0.18675027222298601, 
              c[ -17][ t]], 
            Times[ -0.15591488063143982, 
              c[ -16][ t]], 
            Times[ -0.11423673049785445, 
              c[ -15][ t]], 
            Times[ -0.062044074975450343, 
              c[ -14][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -13][ t]], 
            Times[ 0.070907514257657622, 
              c[ -12][ t]], 
            Times[ 0.14938649372796362, 
              c[ -11][ t]], 
            Times[ 0.23387232094715985, 
              c[ -10][ t]], 
            Times[ 0.32256865202152135, 
              c[ -9][ t]], 
            Times[ 0.41349667156634418, 
              c[ -8][ t]], 
            Times[ 0.50455115242710469, 
              c[ -7][ t]], 
            Times[ 0.59356153372868048, 
              c[ -6][ t]], 
            Times[ 0.67835603854706339, 
              c[ -5][ t]], 
            Times[ 0.75682672864065692, 
              c[ -4][ t]], 
            Times[ 0.82699334313268824, 
              c[ -3][ t]], 
            Times[ 0.88706379305918381, 
              c[ -2][ t]], 
            Times[ 0.93548928378863916, 
              c[ -1][ t]], 
            Times[ 0.9710122092317629, 
              c[ 0][ t]], 
            Times[ 0.99270519960720693, 
              c[ 1][ t]], 
            Times[ 1.0877298168985721, 
              c[ 2][ t]], 
            Times[ 0.99270519960720671, 
              c[ 3][ t]], 
            Times[ 0.9710122092317629, 
              c[ 4][ t]], 
            Times[ 0.93548928378863916, 
              c[ 5][ t]], 
            Times[ 0.8870637930591837, 
              c[ 6][ t]], 
            Times[ 0.82699334313268824, 
              c[ 7][ t]], 
            Times[ 0.75682672864065692, 
              c[ 8][ t]], 
            Times[ 0.67835603854706328, 
              c[ 9][ t]], 
            Times[ 0.59356153372868048, 
              c[ 10][ t]], 
            Times[ 0.50455115242710469, 
              c[ 11][ t]], 
            Times[ 0.41349667156634418, 
              c[ 12][ t]], 
            Times[ 0.32256865202152157, 
              c[ 13][ t]], 
            Times[ 0.23387232094715998, 
              c[ 14][ t]], 
            Times[ 0.14938649372796362, 
              c[ 15][ t]], 
            Times[ 0.070907514257657775, 
              c[ 16][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 17][ t]], 
            Times[ -0.062044074975450343, 
              c[ 18][ t]], 
            Times[ -0.11423673049785436, 
              c[ 19][ t]], 
            Times[ -0.15591488063143974, 
              c[ 20][ t]], 
            Times[ -0.18675027222298601, 
              c[ 21][ t]], 
            Times[ -0.206748335783172, 
              c[ 22][ t]], 
            Times[ -0.21623620818304484, 
              c[ 23][ t]], 
            Times[ -0.21584055771952013, 
              c[ 24][ t]], 
            Times[ -0.20645618564475843, 
              c[ 25][ t]], 
            Times[ -0.18920668216016426, 
              c[ 26][ t]], 
            Times[ -0.1653986686265376, 
              c[ 27][ t]], 
            Times[ -0.13647135277833605, 
              c[ 28][ t]], 
            Times[ -0.10394325375429328, 
              c[ 29][ t]], 
            Times[ -0.069358014945125918, 
              c[ 30][ t]], 
            Times[ -0.034231213779558949, 
              c[ 31][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 32][ t]], 
            Times[ 0.032022748374426029, 
              c[ 33][ t]], 
            Times[ 0.060688263076985105, 
              c[ 34][ t]], 
            Times[ 0.085044480344421705, 
              c[ 35][ t]], 
            Times[ 0.10436044624225692, 
              c[ 36][ t]], 
            Times[ 0.11814190616181255, 
              c[ 37][ t]], 
            Times[ 0.12613778810677614, 
              c[ 38][ t]], 
            Times[ 0.12833762891430925, 
              c[ 39][ t]], 
            Times[ 0.12496032289024853, 
              c[ 40][ t]], 
            Times[ 0.11643488132933195, 
              c[ 41][ t]], 
            Times[ 0.10337416789158609, 
              c[ 42][ t]], 
            Times[ 0.086542809078944891, 
              c[ 43][ t]], 
            Times[ 0.066820663127760152, 
              c[ 44][ t]], 
            Times[ 0.045163358568919301, 
              c[ 45][ t]], 
            Times[ 0.022561481809254869, 
              c[ 46][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ 47][ t]], 
            Times[ -0.021580547817547879, 
              c[ 48][ t]], 
            Times[ -0.04131966847794722, 
              c[ 49][ t]], 
            Times[ -0.058468080236789774, 
              c[ 50][ t]], 
            Times[ -0.072413370861974122, 
              c[ 51][ t]], 
            Times[ -0.082699334313268744, 
              c[ 52][ t]], 
            Times[ -0.089038438663606653, 
              c[ 53][ t]], 
            Times[ -0.091317159035181589, 
              c[ 54][ t]], 
            Times[ -0.089594193770366884, 
              c[ 55][ t]], 
            Times[ -0.084091858737850855, 
              c[ 56][ t]], 
            Times[ -0.075181213012062598, 
              c[ 57][ t]], 
            Times[ -0.063361699504227528, 
              c[ 58][ t]], 
            Times[ -0.049236278094139066, 
              c[ 59][ t]], 
            Times[ -0.033483179628681567, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "3", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[3]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.04454710875183992`\ \(c[\(-60\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-59\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-58\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-57\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-56\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-55\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-54\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-53\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-52\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-51\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-50\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-49\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-48\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-47\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-46\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-45\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-44\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-43\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-42\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-41\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-40\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-39\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-38\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-37\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-36\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-35\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-34\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-33\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-32\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-31\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-30\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-29\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-28\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-27\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-26\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-25\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-24\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-23\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-22\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-21\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-20\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-19\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-18\)]\)[t] - 
            0.206748335783172`\ \(c[\(-17\)]\)[t] - 
            0.186750272222986`\ \(c[\(-16\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-15\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-14\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-13\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-12\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-11\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-10\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-9\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-8\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-7\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-6\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-5\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-4\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-3\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-2\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-1\)]\)[t] + 
            0.9354892837886392`\ \(c[0]\)[t] + 
            0.9710122092317629`\ \(c[1]\)[t] + 
            0.9927051996072067`\ \(c[2]\)[t] + 
            1.1973920880217872`\ \(c[3]\)[t] + 
            0.9927051996072069`\ \(c[4]\)[t] + 
            0.9710122092317629`\ \(c[5]\)[t] + 
            0.9354892837886392`\ \(c[6]\)[t] + 
            0.8870637930591838`\ \(c[7]\)[t] + 
            0.8269933431326882`\ \(c[8]\)[t] + 
            0.7568267286406569`\ \(c[9]\)[t] + 
            0.6783560385470634`\ \(c[10]\)[t] + 
            0.5935615337286806`\ \(c[11]\)[t] + 
            0.5045511524271047`\ \(c[12]\)[t] + 
            0.4134966715663442`\ \(c[13]\)[t] + 
            0.3225686520215216`\ \(c[14]\)[t] + 
            0.23387232094715985`\ \(c[15]\)[t] + 
            0.14938649372796362`\ \(c[16]\)[t] + 
            0.07090751425765777`\ \(c[17]\)[t] + 
            3.898171832519376`*^-17\ \(c[18]\)[t] - 
            0.06204407497545034`\ \(c[19]\)[t] - 
            0.11423673049785436`\ \(c[20]\)[t] - 
            0.15591488063143982`\ \(c[21]\)[t] - 
            0.18675027222298593`\ \(c[22]\)[t] - 
            0.206748335783172`\ \(c[23]\)[t] - 
            0.21623620818304484`\ \(c[24]\)[t] - 
            0.21584055771952015`\ \(c[25]\)[t] - 
            0.20645618564475843`\ \(c[26]\)[t] - 
            0.18920668216016426`\ \(c[27]\)[t] - 
            0.1653986686265377`\ \(c[28]\)[t] - 
            0.13647135277833605`\ \(c[29]\)[t] - 
            0.10394325375429328`\ \(c[30]\)[t] - 
            0.06935801494512607`\ \(c[31]\)[t] - 
            0.03423121377955895`\ \(c[32]\)[t] - 
            3.898171832519376`*^-17\ \(c[33]\)[t] + 
            0.032022748374425904`\ \(c[34]\)[t] + 
            0.060688263076985105`\ \(c[35]\)[t] + 
            0.0850444803444217`\ \(c[36]\)[t] + 
            0.10436044624225685`\ \(c[37]\)[t] + 
            0.11814190616181255`\ \(c[38]\)[t] + 
            0.12613778810677614`\ \(c[39]\)[t] + 
            0.12833762891430928`\ \(c[40]\)[t] + 
            0.12496032289024853`\ \(c[41]\)[t] + 
            0.11643488132933186`\ \(c[42]\)[t] + 
            0.10337416789158609`\ \(c[43]\)[t] + 
            0.08654280907894489`\ \(c[44]\)[t] + 
            0.06682066312775997`\ \(c[45]\)[t] + 
            0.0451633585689193`\ \(c[46]\)[t] + 
            0.02256148180925487`\ \(c[47]\)[t] + 
            3.8981718325193755`*^-17\ \(c[48]\)[t] - 
            0.02158054781754788`\ \(c[49]\)[t] - 
            0.04131966847794722`\ \(c[50]\)[t] - 
            0.05846808023678991`\ \(c[51]\)[t] - 
            0.07241337086197412`\ \(c[52]\)[t] - 
            0.08269933431326874`\ \(c[53]\)[t] - 
            0.0890384386636067`\ \(c[54]\)[t] - 
            0.09131715903518159`\ \(c[55]\)[t] - 
            0.08959419377036688`\ \(c[56]\)[t] - 
            0.08409185873785081`\ \(c[57]\)[t] - 
            0.0751812130120626`\ \(c[58]\)[t] - 
            0.06336169950422753`\ \(c[59]\)[t] - 
            0.04923627809413894`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 3, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 3]][ t]], 
          Plus[ 
            Times[ 0.044547108751839919, 
              c[ -60][ t]], 
            Times[ 0.031322974491347078, 
              c[ -59][ t]], 
            Times[ 0.016273855731265604, 
              c[ -58][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -57][ t]], 
            Times[ -0.016825511857749401, 
              c[ -56][ t]], 
            Times[ -0.033483179628681567, 
              c[ -55][ t]], 
            Times[ -0.049236278094138941, 
              c[ -54][ t]], 
            Times[ -0.063361699504227528, 
              c[ -53][ t]], 
            Times[ -0.075181213012062598, 
              c[ -52][ t]], 
            Times[ -0.084091858737850814, 
              c[ -51][ t]], 
            Times[ -0.089594193770366884, 
              c[ -50][ t]], 
            Times[ -0.091317159035181589, 
              c[ -49][ t]], 
            Times[ -0.089038438663606695, 
              c[ -48][ t]], 
            Times[ -0.082699334313268744, 
              c[ -47][ t]], 
            Times[ -0.072413370861974122, 
              c[ -46][ t]], 
            Times[ -0.058468080236789913, 
              c[ -45][ t]], 
            Times[ -0.04131966847794722, 
              c[ -44][ t]], 
            Times[ -0.021580547817547879, 
              c[ -43][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -42][ t]], 
            Times[ 0.022561481809254869, 
              c[ -41][ t]], 
            Times[ 0.045163358568919301, 
              c[ -40][ t]], 
            Times[ 0.066820663127759972, 
              c[ -39][ t]], 
            Times[ 0.086542809078944891, 
              c[ -38][ t]], 
            Times[ 0.10337416789158609, 
              c[ -37][ t]], 
            Times[ 0.11643488132933186, 
              c[ -36][ t]], 
            Times[ 0.12496032289024853, 
              c[ -35][ t]], 
            Times[ 0.12833762891430928, 
              c[ -34][ t]], 
            Times[ 0.12613778810677614, 
              c[ -33][ t]], 
            Times[ 0.11814190616181255, 
              c[ -32][ t]], 
            Times[ 0.10436044624225685, 
              c[ -31][ t]], 
            Times[ 0.085044480344421705, 
              c[ -30][ t]], 
            Times[ 0.060688263076985105, 
              c[ -29][ t]], 
            Times[ 0.032022748374425904, 
              c[ -28][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -27][ t]], 
            Times[ -0.034231213779558949, 
              c[ -26][ t]], 
            Times[ -0.06935801494512607, 
              c[ -25][ t]], 
            Times[ -0.10394325375429328, 
              c[ -24][ t]], 
            Times[ -0.13647135277833605, 
              c[ -23][ t]], 
            Times[ -0.16539866862653771, 
              c[ -22][ t]], 
            Times[ -0.18920668216016426, 
              c[ -21][ t]], 
            Times[ -0.20645618564475843, 
              c[ -20][ t]], 
            Times[ -0.21584055771952015, 
              c[ -19][ t]], 
            Times[ -0.21623620818304484, 
              c[ -18][ t]], 
            Times[ -0.206748335783172, 
              c[ -17][ t]], 
            Times[ -0.18675027222298601, 
              c[ -16][ t]], 
            Times[ -0.15591488063143982, 
              c[ -15][ t]], 
            Times[ -0.11423673049785436, 
              c[ -14][ t]], 
            Times[ -0.062044074975450343, 
              c[ -13][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -12][ t]], 
            Times[ 0.070907514257657775, 
              c[ -11][ t]], 
            Times[ 0.14938649372796362, 
              c[ -10][ t]], 
            Times[ 0.23387232094715985, 
              c[ -9][ t]], 
            Times[ 0.32256865202152157, 
              c[ -8][ t]], 
            Times[ 0.41349667156634418, 
              c[ -7][ t]], 
            Times[ 0.50455115242710469, 
              c[ -6][ t]], 
            Times[ 0.59356153372868048, 
              c[ -5][ t]], 
            Times[ 0.67835603854706339, 
              c[ -4][ t]], 
            Times[ 0.75682672864065692, 
              c[ -3][ t]], 
            Times[ 0.82699334313268824, 
              c[ -2][ t]], 
            Times[ 0.88706379305918381, 
              c[ -1][ t]], 
            Times[ 0.93548928378863916, 
              c[ 0][ t]], 
            Times[ 0.9710122092317629, 
              c[ 1][ t]], 
            Times[ 0.99270519960720671, 
              c[ 2][ t]], 
            Times[ 1.1973920880217872, 
              c[ 3][ t]], 
            Times[ 0.99270519960720693, 
              c[ 4][ t]], 
            Times[ 0.9710122092317629, 
              c[ 5][ t]], 
            Times[ 0.93548928378863916, 
              c[ 6][ t]], 
            Times[ 0.88706379305918381, 
              c[ 7][ t]], 
            Times[ 0.82699334313268824, 
              c[ 8][ t]], 
            Times[ 0.75682672864065692, 
              c[ 9][ t]], 
            Times[ 0.67835603854706339, 
              c[ 10][ t]], 
            Times[ 0.59356153372868059, 
              c[ 11][ t]], 
            Times[ 0.50455115242710469, 
              c[ 12][ t]], 
            Times[ 0.41349667156634418, 
              c[ 13][ t]], 
            Times[ 0.32256865202152157, 
              c[ 14][ t]], 
            Times[ 0.23387232094715985, 
              c[ 15][ t]], 
            Times[ 0.14938649372796362, 
              c[ 16][ t]], 
            Times[ 0.070907514257657775, 
              c[ 17][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 18][ t]], 
            Times[ -0.062044074975450343, 
              c[ 19][ t]], 
            Times[ -0.11423673049785436, 
              c[ 20][ t]], 
            Times[ -0.15591488063143982, 
              c[ 21][ t]], 
            Times[ -0.18675027222298593, 
              c[ 22][ t]], 
            Times[ -0.206748335783172, 
              c[ 23][ t]], 
            Times[ -0.21623620818304484, 
              c[ 24][ t]], 
            Times[ -0.21584055771952015, 
              c[ 25][ t]], 
            Times[ -0.20645618564475843, 
              c[ 26][ t]], 
            Times[ -0.18920668216016426, 
              c[ 27][ t]], 
            Times[ -0.16539866862653771, 
              c[ 28][ t]], 
            Times[ -0.13647135277833605, 
              c[ 29][ t]], 
            Times[ -0.10394325375429328, 
              c[ 30][ t]], 
            Times[ -0.06935801494512607, 
              c[ 31][ t]], 
            Times[ -0.034231213779558949, 
              c[ 32][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 33][ t]], 
            Times[ 0.032022748374425904, 
              c[ 34][ t]], 
            Times[ 0.060688263076985105, 
              c[ 35][ t]], 
            Times[ 0.085044480344421705, 
              c[ 36][ t]], 
            Times[ 0.10436044624225685, 
              c[ 37][ t]], 
            Times[ 0.11814190616181255, 
              c[ 38][ t]], 
            Times[ 0.12613778810677614, 
              c[ 39][ t]], 
            Times[ 0.12833762891430928, 
              c[ 40][ t]], 
            Times[ 0.12496032289024853, 
              c[ 41][ t]], 
            Times[ 0.11643488132933186, 
              c[ 42][ t]], 
            Times[ 0.10337416789158609, 
              c[ 43][ t]], 
            Times[ 0.086542809078944891, 
              c[ 44][ t]], 
            Times[ 0.066820663127759972, 
              c[ 45][ t]], 
            Times[ 0.045163358568919301, 
              c[ 46][ t]], 
            Times[ 0.022561481809254869, 
              c[ 47][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 48][ t]], 
            Times[ -0.021580547817547879, 
              c[ 49][ t]], 
            Times[ -0.04131966847794722, 
              c[ 50][ t]], 
            Times[ -0.058468080236789913, 
              c[ 51][ t]], 
            Times[ -0.072413370861974122, 
              c[ 52][ t]], 
            Times[ -0.082699334313268744, 
              c[ 53][ t]], 
            Times[ -0.089038438663606695, 
              c[ 54][ t]], 
            Times[ -0.091317159035181589, 
              c[ 55][ t]], 
            Times[ -0.089594193770366884, 
              c[ 56][ t]], 
            Times[ -0.084091858737850814, 
              c[ 57][ t]], 
            Times[ -0.075181213012062598, 
              c[ 58][ t]], 
            Times[ -0.063361699504227528, 
              c[ 59][ t]], 
            Times[ -0.049236278094138941, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "4", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[4]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.05544148706619893`\ \(c[\(-60\)]\)[t] + 
            0.044547108751839815`\ \(c[\(-59\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-58\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-57\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-56\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-55\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-54\)]\)[t] - 
            0.049236278094139066`\ \(c[\(-53\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-52\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-51\)]\)[t] - 
            0.08409185873785086`\ \(c[\(-50\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-49\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-48\)]\)[t] - 
            0.08903843866360665`\ \(c[\(-47\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-46\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-45\)]\)[t] - 
            0.058468080236789774`\ \(c[\(-44\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-43\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-42\)]\)[t] + 
            2.274590327822911`*^-16\ \(c[\(-41\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-40\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-39\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-38\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-37\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-36\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-35\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-34\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-33\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-32\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-31\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-30\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-29\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-28\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-27\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-26\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-25\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-24\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-23\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-22\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-21\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-20\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-19\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-18\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-17\)]\)[t] - 
            0.206748335783172`\ \(c[\(-16\)]\)[t] - 
            0.186750272222986`\ \(c[\(-15\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-14\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-13\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-12\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-11\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-10\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-9\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-8\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-7\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-6\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-5\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-4\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-3\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-2\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-1\)]\)[t] + 
            0.8870637930591838`\ \(c[0]\)[t] + 
            0.9354892837886392`\ \(c[1]\)[t] + 
            0.9710122092317629`\ \(c[2]\)[t] + 
            0.9927051996072069`\ \(c[3]\)[t] + 
            1.3509192675942883`\ \(c[4]\)[t] + 
            0.9927051996072069`\ \(c[5]\)[t] + 
            0.9710122092317629`\ \(c[6]\)[t] + 
            0.935489283788639`\ \(c[7]\)[t] + 
            0.8870637930591838`\ \(c[8]\)[t] + 
            0.8269933431326881`\ \(c[9]\)[t] + 
            0.7568267286406569`\ \(c[10]\)[t] + 
            0.6783560385470634`\ \(c[11]\)[t] + 
            0.5935615337286803`\ \(c[12]\)[t] + 
            0.5045511524271047`\ \(c[13]\)[t] + 
            0.4134966715663442`\ \(c[14]\)[t] + 
            0.32256865202152135`\ \(c[15]\)[t] + 
            0.23387232094715985`\ \(c[16]\)[t] + 
            0.14938649372796362`\ \(c[17]\)[t] + 
            0.07090751425765762`\ \(c[18]\)[t] + 
            3.898171832519376`*^-17\ \(c[19]\)[t] - 
            0.06204407497545034`\ \(c[20]\)[t] - 
            0.11423673049785445`\ \(c[21]\)[t] - 
            0.15591488063143974`\ \(c[22]\)[t] - 
            0.186750272222986`\ \(c[23]\)[t] - 
            0.206748335783172`\ \(c[24]\)[t] - 
            0.21623620818304481`\ \(c[25]\)[t] - 
            0.21584055771952015`\ \(c[26]\)[t] - 
            0.20645618564475843`\ \(c[27]\)[t] - 
            0.18920668216016434`\ \(c[28]\)[t] - 
            0.1653986686265377`\ \(c[29]\)[t] - 
            0.13647135277833605`\ \(c[30]\)[t] - 
            0.1039432537542934`\ \(c[31]\)[t] - 
            0.06935801494512607`\ \(c[32]\)[t] - 
            0.03423121377955895`\ \(c[33]\)[t] - 
            1.8033970416801674`*^-16\ \(c[34]\)[t] + 
            0.032022748374425904`\ \(c[35]\)[t] + 
            0.060688263076985105`\ \(c[36]\)[t] + 
            0.08504448034442161`\ \(c[37]\)[t] + 
            0.10436044624225685`\ \(c[38]\)[t] + 
            0.11814190616181255`\ \(c[39]\)[t] + 
            0.12613778810677612`\ \(c[40]\)[t] + 
            0.12833762891430925`\ \(c[41]\)[t] + 
            0.12496032289024853`\ \(c[42]\)[t] + 
            0.11643488132933186`\ \(c[43]\)[t] + 
            0.10337416789158609`\ \(c[44]\)[t] + 
            0.08654280907894475`\ \(c[45]\)[t] + 
            0.06682066312775997`\ \(c[46]\)[t] + 
            0.0451633585689193`\ \(c[47]\)[t] + 
            0.022561481809254675`\ \(c[48]\)[t] + 
            3.8981718325193755`*^-17\ \(c[49]\)[t] - 
            0.02158054781754788`\ \(c[50]\)[t] - 
            0.04131966847794737`\ \(c[51]\)[t] - 
            0.05846808023678991`\ \(c[52]\)[t] - 
            0.07241337086197412`\ \(c[53]\)[t] - 
            0.08269933431326881`\ \(c[54]\)[t] - 
            0.0890384386636067`\ \(c[55]\)[t] - 
            0.09131715903518159`\ \(c[56]\)[t] - 
            0.08959419377036684`\ \(c[57]\)[t] - 
            0.08409185873785081`\ \(c[58]\)[t] - 
            0.0751812130120626`\ \(c[59]\)[t] - 
            0.0633616995042274`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 4, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 4]][ t]], 
          Plus[ 
            Times[ 0.055441487066198933, 
              c[ -60][ t]], 
            Times[ 0.044547108751839815, 
              c[ -59][ t]], 
            Times[ 0.031322974491347078, 
              c[ -58][ t]], 
            Times[ 0.016273855731265604, 
              c[ -57][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -56][ t]], 
            Times[ -0.016825511857749401, 
              c[ -55][ t]], 
            Times[ -0.033483179628681567, 
              c[ -54][ t]], 
            Times[ -0.049236278094139066, 
              c[ -53][ t]], 
            Times[ -0.063361699504227528, 
              c[ -52][ t]], 
            Times[ -0.075181213012062598, 
              c[ -51][ t]], 
            Times[ -0.084091858737850855, 
              c[ -50][ t]], 
            Times[ -0.089594193770366884, 
              c[ -49][ t]], 
            Times[ -0.091317159035181589, 
              c[ -48][ t]], 
            Times[ -0.089038438663606653, 
              c[ -47][ t]], 
            Times[ -0.082699334313268744, 
              c[ -46][ t]], 
            Times[ -0.072413370861974122, 
              c[ -45][ t]], 
            Times[ -0.058468080236789774, 
              c[ -44][ t]], 
            Times[ -0.04131966847794722, 
              c[ -43][ t]], 
            Times[ -0.021580547817547879, 
              c[ -42][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ -41][ t]], 
            Times[ 0.022561481809254869, 
              c[ -40][ t]], 
            Times[ 0.045163358568919301, 
              c[ -39][ t]], 
            Times[ 0.066820663127759972, 
              c[ -38][ t]], 
            Times[ 0.086542809078944891, 
              c[ -37][ t]], 
            Times[ 0.10337416789158609, 
              c[ -36][ t]], 
            Times[ 0.11643488132933186, 
              c[ -35][ t]], 
            Times[ 0.12496032289024853, 
              c[ -34][ t]], 
            Times[ 0.12833762891430925, 
              c[ -33][ t]], 
            Times[ 0.12613778810677614, 
              c[ -32][ t]], 
            Times[ 0.11814190616181255, 
              c[ -31][ t]], 
            Times[ 0.10436044624225692, 
              c[ -30][ t]], 
            Times[ 0.085044480344421705, 
              c[ -29][ t]], 
            Times[ 0.060688263076985105, 
              c[ -28][ t]], 
            Times[ 0.032022748374426029, 
              c[ -27][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -26][ t]], 
            Times[ -0.034231213779558949, 
              c[ -25][ t]], 
            Times[ -0.069358014945125918, 
              c[ -24][ t]], 
            Times[ -0.10394325375429328, 
              c[ -23][ t]], 
            Times[ -0.13647135277833605, 
              c[ -22][ t]], 
            Times[ -0.1653986686265376, 
              c[ -21][ t]], 
            Times[ -0.18920668216016426, 
              c[ -20][ t]], 
            Times[ -0.20645618564475843, 
              c[ -19][ t]], 
            Times[ -0.21584055771952013, 
              c[ -18][ t]], 
            Times[ -0.21623620818304484, 
              c[ -17][ t]], 
            Times[ -0.206748335783172, 
              c[ -16][ t]], 
            Times[ -0.18675027222298601, 
              c[ -15][ t]], 
            Times[ -0.15591488063143974, 
              c[ -14][ t]], 
            Times[ -0.11423673049785436, 
              c[ -13][ t]], 
            Times[ -0.062044074975450343, 
              c[ -12][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -11][ t]], 
            Times[ 0.070907514257657775, 
              c[ -10][ t]], 
            Times[ 0.14938649372796362, 
              c[ -9][ t]], 
            Times[ 0.23387232094715985, 
              c[ -8][ t]], 
            Times[ 0.32256865202152157, 
              c[ -7][ t]], 
            Times[ 0.41349667156634418, 
              c[ -6][ t]], 
            Times[ 0.50455115242710469, 
              c[ -5][ t]], 
            Times[ 0.59356153372868048, 
              c[ -4][ t]], 
            Times[ 0.67835603854706339, 
              c[ -3][ t]], 
            Times[ 0.75682672864065692, 
              c[ -2][ t]], 
            Times[ 0.82699334313268824, 
              c[ -1][ t]], 
            Times[ 0.88706379305918381, 
              c[ 0][ t]], 
            Times[ 0.93548928378863916, 
              c[ 1][ t]], 
            Times[ 0.9710122092317629, 
              c[ 2][ t]], 
            Times[ 0.99270519960720693, 
              c[ 3][ t]], 
            Times[ 1.3509192675942883, 
              c[ 4][ t]], 
            Times[ 0.99270519960720693, 
              c[ 5][ t]], 
            Times[ 0.9710122092317629, 
              c[ 6][ t]], 
            Times[ 0.93548928378863905, 
              c[ 7][ t]], 
            Times[ 0.88706379305918381, 
              c[ 8][ t]], 
            Times[ 0.82699334313268813, 
              c[ 9][ t]], 
            Times[ 0.75682672864065692, 
              c[ 10][ t]], 
            Times[ 0.67835603854706339, 
              c[ 11][ t]], 
            Times[ 0.59356153372868026, 
              c[ 12][ t]], 
            Times[ 0.50455115242710469, 
              c[ 13][ t]], 
            Times[ 0.41349667156634418, 
              c[ 14][ t]], 
            Times[ 0.32256865202152135, 
              c[ 15][ t]], 
            Times[ 0.23387232094715985, 
              c[ 16][ t]], 
            Times[ 0.14938649372796362, 
              c[ 17][ t]], 
            Times[ 0.070907514257657622, 
              c[ 18][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 19][ t]], 
            Times[ -0.062044074975450343, 
              c[ 20][ t]], 
            Times[ -0.11423673049785445, 
              c[ 21][ t]], 
            Times[ -0.15591488063143974, 
              c[ 22][ t]], 
            Times[ -0.18675027222298601, 
              c[ 23][ t]], 
            Times[ -0.206748335783172, 
              c[ 24][ t]], 
            Times[ -0.21623620818304481, 
              c[ 25][ t]], 
            Times[ -0.21584055771952015, 
              c[ 26][ t]], 
            Times[ -0.20645618564475843, 
              c[ 27][ t]], 
            Times[ -0.18920668216016434, 
              c[ 28][ t]], 
            Times[ -0.16539866862653771, 
              c[ 29][ t]], 
            Times[ -0.13647135277833605, 
              c[ 30][ t]], 
            Times[ -0.1039432537542934, 
              c[ 31][ t]], 
            Times[ -0.06935801494512607, 
              c[ 32][ t]], 
            Times[ -0.034231213779558949, 
              c[ 33][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 34][ t]], 
            Times[ 0.032022748374425904, 
              c[ 35][ t]], 
            Times[ 0.060688263076985105, 
              c[ 36][ t]], 
            Times[ 0.085044480344421608, 
              c[ 37][ t]], 
            Times[ 0.10436044624225685, 
              c[ 38][ t]], 
            Times[ 0.11814190616181255, 
              c[ 39][ t]], 
            Times[ 0.12613778810677612, 
              c[ 40][ t]], 
            Times[ 0.12833762891430925, 
              c[ 41][ t]], 
            Times[ 0.12496032289024853, 
              c[ 42][ t]], 
            Times[ 0.11643488132933186, 
              c[ 43][ t]], 
            Times[ 0.10337416789158609, 
              c[ 44][ t]], 
            Times[ 0.086542809078944752, 
              c[ 45][ t]], 
            Times[ 0.066820663127759972, 
              c[ 46][ t]], 
            Times[ 0.045163358568919301, 
              c[ 47][ t]], 
            Times[ 0.022561481809254675, 
              c[ 48][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 49][ t]], 
            Times[ -0.021580547817547879, 
              c[ 50][ t]], 
            Times[ -0.041319668477947373, 
              c[ 51][ t]], 
            Times[ -0.058468080236789913, 
              c[ 52][ t]], 
            Times[ -0.072413370861974122, 
              c[ 53][ t]], 
            Times[ -0.082699334313268813, 
              c[ 54][ t]], 
            Times[ -0.089038438663606695, 
              c[ 55][ t]], 
            Times[ -0.091317159035181589, 
              c[ 56][ t]], 
            Times[ -0.089594193770366842, 
              c[ 57][ t]], 
            Times[ -0.084091858737850814, 
              c[ 58][ t]], 
            Times[ -0.075181213012062598, 
              c[ 59][ t]], 
            Times[ -0.063361699504227403, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "5", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[5]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.06361487254866832`\ \(c[\(-60\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-59\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-58\)]\)[t] + 
            0.0313229744913472`\ \(c[\(-57\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-56\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-55\)]\)[t] - 
            0.016825511857749262`\ \(c[\(-54\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-53\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-52\)]\)[t] - 
            0.0633616995042274`\ \(c[\(-51\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-50\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-49\)]\)[t] - 
            0.08959419377036684`\ \(c[\(-48\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-47\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-46\)]\)[t] - 
            0.08269933431326881`\ \(c[\(-45\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-44\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-43\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-42\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-41\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-40\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-39\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-38\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-37\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-36\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-35\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-34\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-33\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-32\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-31\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-30\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-29\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-28\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-27\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-26\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-25\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-24\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-23\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-22\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-21\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-20\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-19\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-18\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-17\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-16\)]\)[t] - 
            0.206748335783172`\ \(c[\(-15\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-14\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-13\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-12\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-11\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-10\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-9\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-8\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-7\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-6\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-5\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-4\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-3\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-2\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-1\)]\)[t] + 
            0.8269933431326882`\ \(c[0]\)[t] + 
            0.8870637930591838`\ \(c[1]\)[t] + 
            0.9354892837886392`\ \(c[2]\)[t] + 
            0.9710122092317629`\ \(c[3]\)[t] + 
            0.9927051996072069`\ \(c[4]\)[t] + 
            1.5483113556160752`\ \(c[5]\)[t] + 
            0.9927051996072067`\ \(c[6]\)[t] + 
            0.9710122092317629`\ \(c[7]\)[t] + 
            0.9354892837886392`\ \(c[8]\)[t] + 
            0.8870637930591837`\ \(c[9]\)[t] + 
            0.8269933431326882`\ \(c[10]\)[t] + 
            0.756826728640657`\ \(c[11]\)[t] + 
            0.6783560385470633`\ \(c[12]\)[t] + 
            0.5935615337286805`\ \(c[13]\)[t] + 
            0.5045511524271047`\ \(c[14]\)[t] + 
            0.41349667156634395`\ \(c[15]\)[t] + 
            0.3225686520215216`\ \(c[16]\)[t] + 
            0.23387232094715985`\ \(c[17]\)[t] + 
            0.14938649372796345`\ \(c[18]\)[t] + 
            0.07090751425765777`\ \(c[19]\)[t] + 
            3.898171832519376`*^-17\ \(c[20]\)[t] - 
            0.062044074975450475`\ \(c[21]\)[t] - 
            0.11423673049785436`\ \(c[22]\)[t] - 
            0.15591488063143982`\ \(c[23]\)[t] - 
            0.18675027222298607`\ \(c[24]\)[t] - 
            0.206748335783172`\ \(c[25]\)[t] - 
            0.21623620818304484`\ \(c[26]\)[t] - 
            0.21584055771952013`\ \(c[27]\)[t] - 
            0.20645618564475843`\ \(c[28]\)[t] - 
            0.18920668216016426`\ \(c[29]\)[t] - 
            0.1653986686265376`\ \(c[30]\)[t] - 
            0.13647135277833605`\ \(c[31]\)[t] - 
            0.10394325375429328`\ \(c[32]\)[t] - 
            0.06935801494512592`\ \(c[33]\)[t] - 
            0.03423121377955895`\ \(c[34]\)[t] - 
            3.898171832519376`*^-17\ \(c[35]\)[t] + 
            0.03202274837442603`\ \(c[36]\)[t] + 
            0.060688263076985105`\ \(c[37]\)[t] + 
            0.0850444803444217`\ \(c[38]\)[t] + 
            0.10436044624225692`\ \(c[39]\)[t] + 
            0.11814190616181255`\ \(c[40]\)[t] + 
            0.12613778810677612`\ \(c[41]\)[t] + 
            0.12833762891430925`\ \(c[42]\)[t] + 
            0.12496032289024853`\ \(c[43]\)[t] + 
            0.11643488132933195`\ \(c[44]\)[t] + 
            0.10337416789158609`\ \(c[45]\)[t] + 
            0.08654280907894489`\ \(c[46]\)[t] + 
            0.06682066312776015`\ \(c[47]\)[t] + 
            0.0451633585689193`\ \(c[48]\)[t] + 
            0.02256148180925487`\ \(c[49]\)[t] + 
            2.274590327822911`*^-16\ \(c[50]\)[t] - 
            0.02158054781754788`\ \(c[51]\)[t] - 
            0.04131966847794722`\ \(c[52]\)[t] - 
            0.058468080236789774`\ \(c[53]\)[t] - 
            0.07241337086197412`\ \(c[54]\)[t] - 
            0.08269933431326874`\ \(c[55]\)[t] - 
            0.08903843866360665`\ \(c[56]\)[t] - 
            0.09131715903518159`\ \(c[57]\)[t] - 
            0.08959419377036688`\ \(c[58]\)[t] - 
            0.08409185873785086`\ \(c[59]\)[t] - 
            0.0751812130120626`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 5, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 5]][ t]], 
          Plus[ 
            Times[ 0.063614872548668322, 
              c[ -60][ t]], 
            Times[ 0.055441487066198933, 
              c[ -59][ t]], 
            Times[ 0.044547108751839919, 
              c[ -58][ t]], 
            Times[ 0.031322974491347202, 
              c[ -57][ t]], 
            Times[ 0.016273855731265604, 
              c[ -56][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -55][ t]], 
            Times[ -0.016825511857749262, 
              c[ -54][ t]], 
            Times[ -0.033483179628681567, 
              c[ -53][ t]], 
            Times[ -0.049236278094138941, 
              c[ -52][ t]], 
            Times[ -0.063361699504227403, 
              c[ -51][ t]], 
            Times[ -0.075181213012062598, 
              c[ -50][ t]], 
            Times[ -0.084091858737850814, 
              c[ -49][ t]], 
            Times[ -0.089594193770366842, 
              c[ -48][ t]], 
            Times[ -0.091317159035181589, 
              c[ -47][ t]], 
            Times[ -0.089038438663606695, 
              c[ -46][ t]], 
            Times[ -0.082699334313268813, 
              c[ -45][ t]], 
            Times[ -0.072413370861974122, 
              c[ -44][ t]], 
            Times[ -0.058468080236789913, 
              c[ -43][ t]], 
            Times[ -0.041319668477947373, 
              c[ -42][ t]], 
            Times[ -0.021580547817547879, 
              c[ -41][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -40][ t]], 
            Times[ 0.022561481809254675, 
              c[ -39][ t]], 
            Times[ 0.045163358568919301, 
              c[ -38][ t]], 
            Times[ 0.066820663127759972, 
              c[ -37][ t]], 
            Times[ 0.086542809078944752, 
              c[ -36][ t]], 
            Times[ 0.10337416789158609, 
              c[ -35][ t]], 
            Times[ 0.11643488132933186, 
              c[ -34][ t]], 
            Times[ 0.12496032289024853, 
              c[ -33][ t]], 
            Times[ 0.12833762891430928, 
              c[ -32][ t]], 
            Times[ 0.12613778810677612, 
              c[ -31][ t]], 
            Times[ 0.11814190616181255, 
              c[ -30][ t]], 
            Times[ 0.10436044624225685, 
              c[ -29][ t]], 
            Times[ 0.085044480344421608, 
              c[ -28][ t]], 
            Times[ 0.060688263076985105, 
              c[ -27][ t]], 
            Times[ 0.032022748374425904, 
              c[ -26][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -25][ t]], 
            Times[ -0.034231213779558949, 
              c[ -24][ t]], 
            Times[ -0.06935801494512607, 
              c[ -23][ t]], 
            Times[ -0.1039432537542934, 
              c[ -22][ t]], 
            Times[ -0.13647135277833605, 
              c[ -21][ t]], 
            Times[ -0.16539866862653771, 
              c[ -20][ t]], 
            Times[ -0.18920668216016426, 
              c[ -19][ t]], 
            Times[ -0.20645618564475843, 
              c[ -18][ t]], 
            Times[ -0.21584055771952015, 
              c[ -17][ t]], 
            Times[ -0.21623620818304484, 
              c[ -16][ t]], 
            Times[ -0.206748335783172, 
              c[ -15][ t]], 
            Times[ -0.18675027222298593, 
              c[ -14][ t]], 
            Times[ -0.15591488063143982, 
              c[ -13][ t]], 
            Times[ -0.11423673049785436, 
              c[ -12][ t]], 
            Times[ -0.062044074975450239, 
              c[ -11][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -10][ t]], 
            Times[ 0.070907514257657775, 
              c[ -9][ t]], 
            Times[ 0.14938649372796362, 
              c[ -8][ t]], 
            Times[ 0.23387232094715985, 
              c[ -7][ t]], 
            Times[ 0.32256865202152157, 
              c[ -6][ t]], 
            Times[ 0.41349667156634418, 
              c[ -5][ t]], 
            Times[ 0.50455115242710469, 
              c[ -4][ t]], 
            Times[ 0.59356153372868048, 
              c[ -3][ t]], 
            Times[ 0.67835603854706339, 
              c[ -2][ t]], 
            Times[ 0.75682672864065692, 
              c[ -1][ t]], 
            Times[ 0.82699334313268824, 
              c[ 0][ t]], 
            Times[ 0.88706379305918381, 
              c[ 1][ t]], 
            Times[ 0.93548928378863916, 
              c[ 2][ t]], 
            Times[ 0.9710122092317629, 
              c[ 3][ t]], 
            Times[ 0.99270519960720693, 
              c[ 4][ t]], 
            Times[ 1.5483113556160752, 
              c[ 5][ t]], 
            Times[ 0.99270519960720671, 
              c[ 6][ t]], 
            Times[ 0.9710122092317629, 
              c[ 7][ t]], 
            Times[ 0.93548928378863916, 
              c[ 8][ t]], 
            Times[ 0.8870637930591837, 
              c[ 9][ t]], 
            Times[ 0.82699334313268824, 
              c[ 10][ t]], 
            Times[ 0.75682672864065703, 
              c[ 11][ t]], 
            Times[ 0.67835603854706328, 
              c[ 12][ t]], 
            Times[ 0.59356153372868048, 
              c[ 13][ t]], 
            Times[ 0.50455115242710469, 
              c[ 14][ t]], 
            Times[ 0.41349667156634395, 
              c[ 15][ t]], 
            Times[ 0.32256865202152157, 
              c[ 16][ t]], 
            Times[ 0.23387232094715985, 
              c[ 17][ t]], 
            Times[ 0.14938649372796345, 
              c[ 18][ t]], 
            Times[ 0.070907514257657775, 
              c[ 19][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 20][ t]], 
            Times[ -0.062044074975450475, 
              c[ 21][ t]], 
            Times[ -0.11423673049785436, 
              c[ 22][ t]], 
            Times[ -0.15591488063143982, 
              c[ 23][ t]], 
            Times[ -0.18675027222298607, 
              c[ 24][ t]], 
            Times[ -0.206748335783172, 
              c[ 25][ t]], 
            Times[ -0.21623620818304484, 
              c[ 26][ t]], 
            Times[ -0.21584055771952013, 
              c[ 27][ t]], 
            Times[ -0.20645618564475843, 
              c[ 28][ t]], 
            Times[ -0.18920668216016426, 
              c[ 29][ t]], 
            Times[ -0.1653986686265376, 
              c[ 30][ t]], 
            Times[ -0.13647135277833605, 
              c[ 31][ t]], 
            Times[ -0.10394325375429328, 
              c[ 32][ t]], 
            Times[ -0.069358014945125918, 
              c[ 33][ t]], 
            Times[ -0.034231213779558949, 
              c[ 34][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 35][ t]], 
            Times[ 0.032022748374426029, 
              c[ 36][ t]], 
            Times[ 0.060688263076985105, 
              c[ 37][ t]], 
            Times[ 0.085044480344421705, 
              c[ 38][ t]], 
            Times[ 0.10436044624225692, 
              c[ 39][ t]], 
            Times[ 0.11814190616181255, 
              c[ 40][ t]], 
            Times[ 0.12613778810677612, 
              c[ 41][ t]], 
            Times[ 0.12833762891430925, 
              c[ 42][ t]], 
            Times[ 0.12496032289024853, 
              c[ 43][ t]], 
            Times[ 0.11643488132933195, 
              c[ 44][ t]], 
            Times[ 0.10337416789158609, 
              c[ 45][ t]], 
            Times[ 0.086542809078944891, 
              c[ 46][ t]], 
            Times[ 0.066820663127760152, 
              c[ 47][ t]], 
            Times[ 0.045163358568919301, 
              c[ 48][ t]], 
            Times[ 0.022561481809254869, 
              c[ 49][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ 50][ t]], 
            Times[ -0.021580547817547879, 
              c[ 51][ t]], 
            Times[ -0.04131966847794722, 
              c[ 52][ t]], 
            Times[ -0.058468080236789774, 
              c[ 53][ t]], 
            Times[ -0.072413370861974122, 
              c[ 54][ t]], 
            Times[ -0.082699334313268744, 
              c[ 55][ t]], 
            Times[ -0.089038438663606653, 
              c[ 56][ t]], 
            Times[ -0.091317159035181589, 
              c[ 57][ t]], 
            Times[ -0.089594193770366884, 
              c[ 58][ t]], 
            Times[ -0.084091858737850855, 
              c[ 59][ t]], 
            Times[ -0.075181213012062598, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "6", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[6]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.06880242987642335`\ \(c[\(-60\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-59\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-58\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-57\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-56\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-55\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-54\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-53\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-52\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-51\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-50\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-49\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-48\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-47\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-46\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-45\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-44\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-43\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-42\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-41\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-40\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-39\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-38\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-37\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-36\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-35\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-34\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-33\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-32\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-31\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-30\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-29\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-28\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-27\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-26\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-25\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-24\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-23\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-22\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-21\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-20\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-19\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-18\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-17\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-16\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-15\)]\)[t] - 
            0.206748335783172`\ \(c[\(-14\)]\)[t] - 
            0.186750272222986`\ \(c[\(-13\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-12\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-11\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-10\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-9\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-8\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-7\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-6\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-5\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-4\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-3\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-2\)]\)[t] + 
            0.6783560385470633`\ \(c[\(-1\)]\)[t] + 
            0.7568267286406569`\ \(c[0]\)[t] + 
            0.8269933431326882`\ \(c[1]\)[t] + 
            0.8870637930591837`\ \(c[2]\)[t] + 
            0.9354892837886392`\ \(c[3]\)[t] + 
            0.9710122092317629`\ \(c[4]\)[t] + 
            0.9927051996072067`\ \(c[5]\)[t] + 
            1.7895683520871486`\ \(c[6]\)[t] + 
            0.9927051996072069`\ \(c[7]\)[t] + 
            0.9710122092317629`\ \(c[8]\)[t] + 
            0.9354892837886392`\ \(c[9]\)[t] + 
            0.8870637930591838`\ \(c[10]\)[t] + 
            0.8269933431326881`\ \(c[11]\)[t] + 
            0.7568267286406569`\ \(c[12]\)[t] + 
            0.6783560385470634`\ \(c[13]\)[t] + 
            0.5935615337286806`\ \(c[14]\)[t] + 
            0.5045511524271047`\ \(c[15]\)[t] + 
            0.4134966715663442`\ \(c[16]\)[t] + 
            0.3225686520215216`\ \(c[17]\)[t] + 
            0.23387232094715985`\ \(c[18]\)[t] + 
            0.14938649372796362`\ \(c[19]\)[t] + 
            0.07090751425765777`\ \(c[20]\)[t] + 
            3.898171832519376`*^-17\ \(c[21]\)[t] - 
            0.06204407497545024`\ \(c[22]\)[t] - 
            0.11423673049785436`\ \(c[23]\)[t] - 
            0.15591488063143982`\ \(c[24]\)[t] - 
            0.18675027222298593`\ \(c[25]\)[t] - 
            0.206748335783172`\ \(c[26]\)[t] - 
            0.21623620818304484`\ \(c[27]\)[t] - 
            0.21584055771952015`\ \(c[28]\)[t] - 
            0.20645618564475843`\ \(c[29]\)[t] - 
            0.18920668216016426`\ \(c[30]\)[t] - 
            0.1653986686265377`\ \(c[31]\)[t] - 
            0.13647135277833605`\ \(c[32]\)[t] - 
            0.10394325375429328`\ \(c[33]\)[t] - 
            0.06935801494512607`\ \(c[34]\)[t] - 
            0.03423121377955895`\ \(c[35]\)[t] - 
            3.898171832519376`*^-17\ \(c[36]\)[t] + 
            0.032022748374425904`\ \(c[37]\)[t] + 
            0.060688263076985105`\ \(c[38]\)[t] + 
            0.0850444803444217`\ \(c[39]\)[t] + 
            0.10436044624225685`\ \(c[40]\)[t] + 
            0.11814190616181253`\ \(c[41]\)[t] + 
            0.12613778810677614`\ \(c[42]\)[t] + 
            0.12833762891430928`\ \(c[43]\)[t] + 
            0.12496032289024853`\ \(c[44]\)[t] + 
            0.11643488132933186`\ \(c[45]\)[t] + 
            0.10337416789158609`\ \(c[46]\)[t] + 
            0.08654280907894489`\ \(c[47]\)[t] + 
            0.06682066312775997`\ \(c[48]\)[t] + 
            0.0451633585689193`\ \(c[49]\)[t] + 
            0.02256148180925487`\ \(c[50]\)[t] + 
            3.8981718325193755`*^-17\ \(c[51]\)[t] - 
            0.02158054781754788`\ \(c[52]\)[t] - 
            0.04131966847794722`\ \(c[53]\)[t] - 
            0.05846808023678991`\ \(c[54]\)[t] - 
            0.07241337086197412`\ \(c[55]\)[t] - 
            0.08269933431326874`\ \(c[56]\)[t] - 
            0.0890384386636067`\ \(c[57]\)[t] - 
            0.09131715903518159`\ \(c[58]\)[t] - 
            0.08959419377036688`\ \(c[59]\)[t] - 
            0.08409185873785081`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 6, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 6]][ t]], 
          Plus[ 
            Times[ 0.068802429876423349, 
              c[ -60][ t]], 
            Times[ 0.063614872548668253, 
              c[ -59][ t]], 
            Times[ 0.055441487066198933, 
              c[ -58][ t]], 
            Times[ 0.044547108751839919, 
              c[ -57][ t]], 
            Times[ 0.031322974491347078, 
              c[ -56][ t]], 
            Times[ 0.016273855731265604, 
              c[ -55][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -54][ t]], 
            Times[ -0.016825511857749401, 
              c[ -53][ t]], 
            Times[ -0.033483179628681567, 
              c[ -52][ t]], 
            Times[ -0.049236278094138941, 
              c[ -51][ t]], 
            Times[ -0.063361699504227528, 
              c[ -50][ t]], 
            Times[ -0.075181213012062598, 
              c[ -49][ t]], 
            Times[ -0.084091858737850814, 
              c[ -48][ t]], 
            Times[ -0.089594193770366884, 
              c[ -47][ t]], 
            Times[ -0.091317159035181589, 
              c[ -46][ t]], 
            Times[ -0.089038438663606695, 
              c[ -45][ t]], 
            Times[ -0.082699334313268744, 
              c[ -44][ t]], 
            Times[ -0.072413370861974122, 
              c[ -43][ t]], 
            Times[ -0.058468080236789913, 
              c[ -42][ t]], 
            Times[ -0.04131966847794722, 
              c[ -41][ t]], 
            Times[ -0.021580547817547879, 
              c[ -40][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -39][ t]], 
            Times[ 0.022561481809254869, 
              c[ -38][ t]], 
            Times[ 0.045163358568919301, 
              c[ -37][ t]], 
            Times[ 0.066820663127759972, 
              c[ -36][ t]], 
            Times[ 0.086542809078944891, 
              c[ -35][ t]], 
            Times[ 0.10337416789158609, 
              c[ -34][ t]], 
            Times[ 0.11643488132933186, 
              c[ -33][ t]], 
            Times[ 0.12496032289024853, 
              c[ -32][ t]], 
            Times[ 0.12833762891430928, 
              c[ -31][ t]], 
            Times[ 0.12613778810677614, 
              c[ -30][ t]], 
            Times[ 0.11814190616181255, 
              c[ -29][ t]], 
            Times[ 0.10436044624225685, 
              c[ -28][ t]], 
            Times[ 0.085044480344421705, 
              c[ -27][ t]], 
            Times[ 0.060688263076985105, 
              c[ -26][ t]], 
            Times[ 0.032022748374425904, 
              c[ -25][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -24][ t]], 
            Times[ -0.034231213779558949, 
              c[ -23][ t]], 
            Times[ -0.06935801494512607, 
              c[ -22][ t]], 
            Times[ -0.10394325375429328, 
              c[ -21][ t]], 
            Times[ -0.13647135277833605, 
              c[ -20][ t]], 
            Times[ -0.16539866862653771, 
              c[ -19][ t]], 
            Times[ -0.18920668216016426, 
              c[ -18][ t]], 
            Times[ -0.20645618564475843, 
              c[ -17][ t]], 
            Times[ -0.21584055771952015, 
              c[ -16][ t]], 
            Times[ -0.21623620818304484, 
              c[ -15][ t]], 
            Times[ -0.206748335783172, 
              c[ -14][ t]], 
            Times[ -0.18675027222298601, 
              c[ -13][ t]], 
            Times[ -0.15591488063143982, 
              c[ -12][ t]], 
            Times[ -0.11423673049785436, 
              c[ -11][ t]], 
            Times[ -0.062044074975450343, 
              c[ -10][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -9][ t]], 
            Times[ 0.070907514257657775, 
              c[ -8][ t]], 
            Times[ 0.14938649372796362, 
              c[ -7][ t]], 
            Times[ 0.23387232094715985, 
              c[ -6][ t]], 
            Times[ 0.32256865202152157, 
              c[ -5][ t]], 
            Times[ 0.41349667156634418, 
              c[ -4][ t]], 
            Times[ 0.50455115242710469, 
              c[ -3][ t]], 
            Times[ 0.59356153372868048, 
              c[ -2][ t]], 
            Times[ 0.67835603854706328, 
              c[ -1][ t]], 
            Times[ 0.75682672864065692, 
              c[ 0][ t]], 
            Times[ 0.82699334313268824, 
              c[ 1][ t]], 
            Times[ 0.8870637930591837, 
              c[ 2][ t]], 
            Times[ 0.93548928378863916, 
              c[ 3][ t]], 
            Times[ 0.9710122092317629, 
              c[ 4][ t]], 
            Times[ 0.99270519960720671, 
              c[ 5][ t]], 
            Times[ 1.7895683520871486, 
              c[ 6][ t]], 
            Times[ 0.99270519960720693, 
              c[ 7][ t]], 
            Times[ 0.9710122092317629, 
              c[ 8][ t]], 
            Times[ 0.93548928378863916, 
              c[ 9][ t]], 
            Times[ 0.88706379305918381, 
              c[ 10][ t]], 
            Times[ 0.82699334313268813, 
              c[ 11][ t]], 
            Times[ 0.75682672864065692, 
              c[ 12][ t]], 
            Times[ 0.67835603854706339, 
              c[ 13][ t]], 
            Times[ 0.59356153372868059, 
              c[ 14][ t]], 
            Times[ 0.50455115242710469, 
              c[ 15][ t]], 
            Times[ 0.41349667156634418, 
              c[ 16][ t]], 
            Times[ 0.32256865202152157, 
              c[ 17][ t]], 
            Times[ 0.23387232094715985, 
              c[ 18][ t]], 
            Times[ 0.14938649372796362, 
              c[ 19][ t]], 
            Times[ 0.070907514257657775, 
              c[ 20][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 21][ t]], 
            Times[ -0.062044074975450239, 
              c[ 22][ t]], 
            Times[ -0.11423673049785436, 
              c[ 23][ t]], 
            Times[ -0.15591488063143982, 
              c[ 24][ t]], 
            Times[ -0.18675027222298593, 
              c[ 25][ t]], 
            Times[ -0.206748335783172, 
              c[ 26][ t]], 
            Times[ -0.21623620818304484, 
              c[ 27][ t]], 
            Times[ -0.21584055771952015, 
              c[ 28][ t]], 
            Times[ -0.20645618564475843, 
              c[ 29][ t]], 
            Times[ -0.18920668216016426, 
              c[ 30][ t]], 
            Times[ -0.16539866862653771, 
              c[ 31][ t]], 
            Times[ -0.13647135277833605, 
              c[ 32][ t]], 
            Times[ -0.10394325375429328, 
              c[ 33][ t]], 
            Times[ -0.06935801494512607, 
              c[ 34][ t]], 
            Times[ -0.034231213779558949, 
              c[ 35][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 36][ t]], 
            Times[ 0.032022748374425904, 
              c[ 37][ t]], 
            Times[ 0.060688263076985105, 
              c[ 38][ t]], 
            Times[ 0.085044480344421705, 
              c[ 39][ t]], 
            Times[ 0.10436044624225685, 
              c[ 40][ t]], 
            Times[ 0.11814190616181253, 
              c[ 41][ t]], 
            Times[ 0.12613778810677614, 
              c[ 42][ t]], 
            Times[ 0.12833762891430928, 
              c[ 43][ t]], 
            Times[ 0.12496032289024853, 
              c[ 44][ t]], 
            Times[ 0.11643488132933186, 
              c[ 45][ t]], 
            Times[ 0.10337416789158609, 
              c[ 46][ t]], 
            Times[ 0.086542809078944891, 
              c[ 47][ t]], 
            Times[ 0.066820663127759972, 
              c[ 48][ t]], 
            Times[ 0.045163358568919301, 
              c[ 49][ t]], 
            Times[ 0.022561481809254869, 
              c[ 50][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 51][ t]], 
            Times[ -0.021580547817547879, 
              c[ 52][ t]], 
            Times[ -0.04131966847794722, 
              c[ 53][ t]], 
            Times[ -0.058468080236789913, 
              c[ 54][ t]], 
            Times[ -0.072413370861974122, 
              c[ 55][ t]], 
            Times[ -0.082699334313268744, 
              c[ 56][ t]], 
            Times[ -0.089038438663606695, 
              c[ 57][ t]], 
            Times[ -0.091317159035181589, 
              c[ 58][ t]], 
            Times[ -0.089594193770366884, 
              c[ 59][ t]], 
            Times[ -0.084091858737850814, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "7", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[7]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.07087301895267824`\ \(c[\(-60\)]\)[t] + 
            0.06880242987642332`\ \(c[\(-59\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-58\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-57\)]\)[t] + 
            0.044547108751839815`\ \(c[\(-56\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-55\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-54\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-53\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-52\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-51\)]\)[t] - 
            0.049236278094139066`\ \(c[\(-50\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-49\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-48\)]\)[t] - 
            0.08409185873785086`\ \(c[\(-47\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-46\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-45\)]\)[t] - 
            0.08903843866360665`\ \(c[\(-44\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-43\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-42\)]\)[t] - 
            0.058468080236789774`\ \(c[\(-41\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-40\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-39\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-38\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-37\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-36\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-35\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-34\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-33\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-32\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-31\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-30\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-29\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-28\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-27\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-26\)]\)[t] + 
            0.060688263076985`\ \(c[\(-25\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-24\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-23\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-22\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-21\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-20\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-19\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-18\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-17\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-16\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-15\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-14\)]\)[t] - 
            0.206748335783172`\ \(c[\(-13\)]\)[t] - 
            0.186750272222986`\ \(c[\(-12\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-11\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-10\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-9\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-8\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-7\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-6\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-5\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-4\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-3\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-2\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-1\)]\)[t] + 
            0.6783560385470634`\ \(c[0]\)[t] + 
            0.756826728640657`\ \(c[1]\)[t] + 
            0.8269933431326882`\ \(c[2]\)[t] + 
            0.8870637930591838`\ \(c[3]\)[t] + 
            0.935489283788639`\ \(c[4]\)[t] + 
            0.9710122092317629`\ \(c[5]\)[t] + 
            0.9927051996072069`\ \(c[6]\)[t] + 
            2.0746902570075076`\ \(c[7]\)[t] + 
            0.9927051996072067`\ \(c[8]\)[t] + 
            0.9710122092317629`\ \(c[9]\)[t] + 
            0.9354892837886392`\ \(c[10]\)[t] + 
            0.8870637930591838`\ \(c[11]\)[t] + 
            0.8269933431326881`\ \(c[12]\)[t] + 
            0.7568267286406569`\ \(c[13]\)[t] + 
            0.6783560385470634`\ \(c[14]\)[t] + 
            0.5935615337286803`\ \(c[15]\)[t] + 
            0.5045511524271047`\ \(c[16]\)[t] + 
            0.4134966715663442`\ \(c[17]\)[t] + 
            0.32256865202152135`\ \(c[18]\)[t] + 
            0.23387232094715985`\ \(c[19]\)[t] + 
            0.14938649372796362`\ \(c[20]\)[t] + 
            0.07090751425765762`\ \(c[21]\)[t] + 
            1.8033970416801674`*^-16\ \(c[22]\)[t] - 
            0.06204407497545034`\ \(c[23]\)[t] - 
            0.11423673049785445`\ \(c[24]\)[t] - 
            0.15591488063143974`\ \(c[25]\)[t] - 
            0.186750272222986`\ \(c[26]\)[t] - 
            0.20674833578317206`\ \(c[27]\)[t] - 
            0.21623620818304484`\ \(c[28]\)[t] - 
            0.21584055771952015`\ \(c[29]\)[t] - 
            0.20645618564475834`\ \(c[30]\)[t] - 
            0.18920668216016426`\ \(c[31]\)[t] - 
            0.1653986686265377`\ \(c[32]\)[t] - 
            0.1364713527783359`\ \(c[33]\)[t] - 
            0.10394325375429328`\ \(c[34]\)[t] - 
            0.06935801494512607`\ \(c[35]\)[t] - 
            0.034231213779558796`\ \(c[36]\)[t] - 
            3.898171832519376`*^-17\ \(c[37]\)[t] + 
            0.032022748374425904`\ \(c[38]\)[t] + 
            0.06068826307698522`\ \(c[39]\)[t] + 
            0.0850444803444217`\ \(c[40]\)[t] + 
            0.10436044624225685`\ \(c[41]\)[t] + 
            0.1181419061618126`\ \(c[42]\)[t] + 
            0.12613778810677614`\ \(c[43]\)[t] + 
            0.12833762891430928`\ \(c[44]\)[t] + 
            0.12496032289024847`\ \(c[45]\)[t] + 
            0.11643488132933186`\ \(c[46]\)[t] + 
            0.10337416789158609`\ \(c[47]\)[t] + 
            0.08654280907894475`\ \(c[48]\)[t] + 
            0.06682066312775997`\ \(c[49]\)[t] + 
            0.0451633585689193`\ \(c[50]\)[t] + 
            0.022561481809254675`\ \(c[51]\)[t] + 
            3.8981718325193755`*^-17\ \(c[52]\)[t] - 
            0.02158054781754788`\ \(c[53]\)[t] - 
            0.04131966847794737`\ \(c[54]\)[t] - 
            0.05846808023678991`\ \(c[55]\)[t] - 
            0.07241337086197412`\ \(c[56]\)[t] - 
            0.08269933431326881`\ \(c[57]\)[t] - 
            0.0890384386636067`\ \(c[58]\)[t] - 
            0.09131715903518159`\ \(c[59]\)[t] - 
            0.08959419377036684`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 7, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 7]][ t]], 
          Plus[ 
            Times[ 0.070873018952678238, 
              c[ -60][ t]], 
            Times[ 0.068802429876423321, 
              c[ -59][ t]], 
            Times[ 0.063614872548668253, 
              c[ -58][ t]], 
            Times[ 0.055441487066198933, 
              c[ -57][ t]], 
            Times[ 0.044547108751839815, 
              c[ -56][ t]], 
            Times[ 0.031322974491347078, 
              c[ -55][ t]], 
            Times[ 0.016273855731265604, 
              c[ -54][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -53][ t]], 
            Times[ -0.016825511857749401, 
              c[ -52][ t]], 
            Times[ -0.033483179628681567, 
              c[ -51][ t]], 
            Times[ -0.049236278094139066, 
              c[ -50][ t]], 
            Times[ -0.063361699504227528, 
              c[ -49][ t]], 
            Times[ -0.075181213012062598, 
              c[ -48][ t]], 
            Times[ -0.084091858737850855, 
              c[ -47][ t]], 
            Times[ -0.089594193770366884, 
              c[ -46][ t]], 
            Times[ -0.091317159035181589, 
              c[ -45][ t]], 
            Times[ -0.089038438663606653, 
              c[ -44][ t]], 
            Times[ -0.082699334313268744, 
              c[ -43][ t]], 
            Times[ -0.072413370861974122, 
              c[ -42][ t]], 
            Times[ -0.058468080236789774, 
              c[ -41][ t]], 
            Times[ -0.04131966847794722, 
              c[ -40][ t]], 
            Times[ -0.021580547817547879, 
              c[ -39][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -38][ t]], 
            Times[ 0.022561481809254869, 
              c[ -37][ t]], 
            Times[ 0.045163358568919301, 
              c[ -36][ t]], 
            Times[ 0.066820663127759972, 
              c[ -35][ t]], 
            Times[ 0.086542809078944891, 
              c[ -34][ t]], 
            Times[ 0.10337416789158609, 
              c[ -33][ t]], 
            Times[ 0.11643488132933186, 
              c[ -32][ t]], 
            Times[ 0.12496032289024853, 
              c[ -31][ t]], 
            Times[ 0.12833762891430928, 
              c[ -30][ t]], 
            Times[ 0.12613778810677614, 
              c[ -29][ t]], 
            Times[ 0.11814190616181253, 
              c[ -28][ t]], 
            Times[ 0.10436044624225685, 
              c[ -27][ t]], 
            Times[ 0.085044480344421705, 
              c[ -26][ t]], 
            Times[ 0.060688263076985001, 
              c[ -25][ t]], 
            Times[ 0.032022748374425904, 
              c[ -24][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -23][ t]], 
            Times[ -0.034231213779559094, 
              c[ -22][ t]], 
            Times[ -0.06935801494512607, 
              c[ -21][ t]], 
            Times[ -0.10394325375429328, 
              c[ -20][ t]], 
            Times[ -0.13647135277833605, 
              c[ -19][ t]], 
            Times[ -0.16539866862653771, 
              c[ -18][ t]], 
            Times[ -0.18920668216016426, 
              c[ -17][ t]], 
            Times[ -0.20645618564475843, 
              c[ -16][ t]], 
            Times[ -0.21584055771952015, 
              c[ -15][ t]], 
            Times[ -0.21623620818304484, 
              c[ -14][ t]], 
            Times[ -0.206748335783172, 
              c[ -13][ t]], 
            Times[ -0.18675027222298601, 
              c[ -12][ t]], 
            Times[ -0.15591488063143974, 
              c[ -11][ t]], 
            Times[ -0.11423673049785436, 
              c[ -10][ t]], 
            Times[ -0.062044074975450343, 
              c[ -9][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -8][ t]], 
            Times[ 0.070907514257657775, 
              c[ -7][ t]], 
            Times[ 0.14938649372796362, 
              c[ -6][ t]], 
            Times[ 0.23387232094715985, 
              c[ -5][ t]], 
            Times[ 0.32256865202152157, 
              c[ -4][ t]], 
            Times[ 0.41349667156634418, 
              c[ -3][ t]], 
            Times[ 0.50455115242710469, 
              c[ -2][ t]], 
            Times[ 0.59356153372868048, 
              c[ -1][ t]], 
            Times[ 0.67835603854706339, 
              c[ 0][ t]], 
            Times[ 0.75682672864065703, 
              c[ 1][ t]], 
            Times[ 0.82699334313268824, 
              c[ 2][ t]], 
            Times[ 0.88706379305918381, 
              c[ 3][ t]], 
            Times[ 0.93548928378863905, 
              c[ 4][ t]], 
            Times[ 0.9710122092317629, 
              c[ 5][ t]], 
            Times[ 0.99270519960720693, 
              c[ 6][ t]], 
            Times[ 2.0746902570075076, 
              c[ 7][ t]], 
            Times[ 0.99270519960720671, 
              c[ 8][ t]], 
            Times[ 0.9710122092317629, 
              c[ 9][ t]], 
            Times[ 0.93548928378863916, 
              c[ 10][ t]], 
            Times[ 0.88706379305918381, 
              c[ 11][ t]], 
            Times[ 0.82699334313268813, 
              c[ 12][ t]], 
            Times[ 0.75682672864065692, 
              c[ 13][ t]], 
            Times[ 0.67835603854706339, 
              c[ 14][ t]], 
            Times[ 0.59356153372868026, 
              c[ 15][ t]], 
            Times[ 0.50455115242710469, 
              c[ 16][ t]], 
            Times[ 0.41349667156634418, 
              c[ 17][ t]], 
            Times[ 0.32256865202152135, 
              c[ 18][ t]], 
            Times[ 0.23387232094715985, 
              c[ 19][ t]], 
            Times[ 0.14938649372796362, 
              c[ 20][ t]], 
            Times[ 0.070907514257657622, 
              c[ 21][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 22][ t]], 
            Times[ -0.062044074975450343, 
              c[ 23][ t]], 
            Times[ -0.11423673049785445, 
              c[ 24][ t]], 
            Times[ -0.15591488063143974, 
              c[ 25][ t]], 
            Times[ -0.18675027222298601, 
              c[ 26][ t]], 
            Times[ -0.20674833578317206, 
              c[ 27][ t]], 
            Times[ -0.21623620818304484, 
              c[ 28][ t]], 
            Times[ -0.21584055771952015, 
              c[ 29][ t]], 
            Times[ -0.20645618564475834, 
              c[ 30][ t]], 
            Times[ -0.18920668216016426, 
              c[ 31][ t]], 
            Times[ -0.16539866862653771, 
              c[ 32][ t]], 
            Times[ -0.13647135277833591, 
              c[ 33][ t]], 
            Times[ -0.10394325375429328, 
              c[ 34][ t]], 
            Times[ -0.06935801494512607, 
              c[ 35][ t]], 
            Times[ -0.034231213779558796, 
              c[ 36][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 37][ t]], 
            Times[ 0.032022748374425904, 
              c[ 38][ t]], 
            Times[ 0.060688263076985223, 
              c[ 39][ t]], 
            Times[ 0.085044480344421705, 
              c[ 40][ t]], 
            Times[ 0.10436044624225685, 
              c[ 41][ t]], 
            Times[ 0.1181419061618126, 
              c[ 42][ t]], 
            Times[ 0.12613778810677614, 
              c[ 43][ t]], 
            Times[ 0.12833762891430928, 
              c[ 44][ t]], 
            Times[ 0.12496032289024847, 
              c[ 45][ t]], 
            Times[ 0.11643488132933186, 
              c[ 46][ t]], 
            Times[ 0.10337416789158609, 
              c[ 47][ t]], 
            Times[ 0.086542809078944752, 
              c[ 48][ t]], 
            Times[ 0.066820663127759972, 
              c[ 49][ t]], 
            Times[ 0.045163358568919301, 
              c[ 50][ t]], 
            Times[ 0.022561481809254675, 
              c[ 51][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 52][ t]], 
            Times[ -0.021580547817547879, 
              c[ 53][ t]], 
            Times[ -0.041319668477947373, 
              c[ 54][ t]], 
            Times[ -0.058468080236789913, 
              c[ 55][ t]], 
            Times[ -0.072413370861974122, 
              c[ 56][ t]], 
            Times[ -0.082699334313268813, 
              c[ 57][ t]], 
            Times[ -0.089038438663606695, 
              c[ 58][ t]], 
            Times[ -0.091317159035181589, 
              c[ 59][ t]], 
            Times[ -0.089594193770366842, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "8", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[8]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.06983076867396239`\ \(c[\(-60\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-59\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-58\)]\)[t] + 
            0.06361487254866832`\ \(c[\(-57\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-56\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-55\)]\)[t] + 
            0.0313229744913472`\ \(c[\(-54\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-53\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-52\)]\)[t] - 
            0.016825511857749262`\ \(c[\(-51\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-50\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-49\)]\)[t] - 
            0.0633616995042274`\ \(c[\(-48\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-47\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-46\)]\)[t] - 
            0.08959419377036684`\ \(c[\(-45\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-44\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-43\)]\)[t] - 
            0.08269933431326881`\ \(c[\(-42\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-41\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-40\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-39\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-38\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-37\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-36\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-35\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-34\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-33\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-32\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-31\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-30\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-29\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-28\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-27\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-26\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-25\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-24\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-23\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-22\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-21\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-20\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-19\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-18\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-17\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-16\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-15\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-14\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-13\)]\)[t] - 
            0.206748335783172`\ \(c[\(-12\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-11\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-10\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-9\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-8\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-7\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-6\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-5\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-4\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-3\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-2\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-1\)]\)[t] + 
            0.5935615337286805`\ \(c[0]\)[t] + 
            0.6783560385470634`\ \(c[1]\)[t] + 
            0.7568267286406569`\ \(c[2]\)[t] + 
            0.8269933431326882`\ \(c[3]\)[t] + 
            0.8870637930591838`\ \(c[4]\)[t] + 
            0.9354892837886392`\ \(c[5]\)[t] + 
            0.9710122092317629`\ \(c[6]\)[t] + 
            0.9927051996072067`\ \(c[7]\)[t] + 
            2.403677070377153`\ \(c[8]\)[t] + 
            0.9927051996072067`\ \(c[9]\)[t] + 
            0.9710122092317629`\ \(c[10]\)[t] + 
            0.9354892837886392`\ \(c[11]\)[t] + 
            0.8870637930591837`\ \(c[12]\)[t] + 
            0.8269933431326882`\ \(c[13]\)[t] + 
            0.756826728640657`\ \(c[14]\)[t] + 
            0.6783560385470633`\ \(c[15]\)[t] + 
            0.5935615337286805`\ \(c[16]\)[t] + 
            0.5045511524271047`\ \(c[17]\)[t] + 
            0.41349667156634395`\ \(c[18]\)[t] + 
            0.3225686520215216`\ \(c[19]\)[t] + 
            0.23387232094715985`\ \(c[20]\)[t] + 
            0.14938649372796345`\ \(c[21]\)[t] + 
            0.07090751425765777`\ \(c[22]\)[t] + 
            3.898171832519376`*^-17\ \(c[23]\)[t] - 
            0.062044074975450475`\ \(c[24]\)[t] - 
            0.11423673049785436`\ \(c[25]\)[t] - 
            0.15591488063143982`\ \(c[26]\)[t] - 
            0.18675027222298607`\ \(c[27]\)[t] - 
            0.206748335783172`\ \(c[28]\)[t] - 
            0.21623620818304484`\ \(c[29]\)[t] - 
            0.21584055771952013`\ \(c[30]\)[t] - 
            0.20645618564475843`\ \(c[31]\)[t] - 
            0.18920668216016426`\ \(c[32]\)[t] - 
            0.1653986686265376`\ \(c[33]\)[t] - 
            0.13647135277833605`\ \(c[34]\)[t] - 
            0.10394325375429328`\ \(c[35]\)[t] - 
            0.06935801494512592`\ \(c[36]\)[t] - 
            0.03423121377955895`\ \(c[37]\)[t] - 
            3.898171832519376`*^-17\ \(c[38]\)[t] + 
            0.03202274837442603`\ \(c[39]\)[t] + 
            0.060688263076985105`\ \(c[40]\)[t] + 
            0.08504448034442161`\ \(c[41]\)[t] + 
            0.10436044624225692`\ \(c[42]\)[t] + 
            0.11814190616181255`\ \(c[43]\)[t] + 
            0.12613778810677612`\ \(c[44]\)[t] + 
            0.12833762891430925`\ \(c[45]\)[t] + 
            0.12496032289024853`\ \(c[46]\)[t] + 
            0.11643488132933195`\ \(c[47]\)[t] + 
            0.10337416789158609`\ \(c[48]\)[t] + 
            0.08654280907894489`\ \(c[49]\)[t] + 
            0.06682066312776015`\ \(c[50]\)[t] + 
            0.0451633585689193`\ \(c[51]\)[t] + 
            0.02256148180925487`\ \(c[52]\)[t] + 
            2.274590327822911`*^-16\ \(c[53]\)[t] - 
            0.02158054781754788`\ \(c[54]\)[t] - 
            0.04131966847794722`\ \(c[55]\)[t] - 
            0.058468080236789774`\ \(c[56]\)[t] - 
            0.07241337086197412`\ \(c[57]\)[t] - 
            0.08269933431326874`\ \(c[58]\)[t] - 
            0.08903843866360665`\ \(c[59]\)[t] - 
            0.09131715903518159`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 8, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 8]][ t]], 
          Plus[ 
            Times[ 0.069830768673962387, 
              c[ -60][ t]], 
            Times[ 0.070873018952678238, 
              c[ -59][ t]], 
            Times[ 0.068802429876423349, 
              c[ -58][ t]], 
            Times[ 0.063614872548668322, 
              c[ -57][ t]], 
            Times[ 0.055441487066198933, 
              c[ -56][ t]], 
            Times[ 0.044547108751839919, 
              c[ -55][ t]], 
            Times[ 0.031322974491347202, 
              c[ -54][ t]], 
            Times[ 0.016273855731265604, 
              c[ -53][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -52][ t]], 
            Times[ -0.016825511857749262, 
              c[ -51][ t]], 
            Times[ -0.033483179628681567, 
              c[ -50][ t]], 
            Times[ -0.049236278094138941, 
              c[ -49][ t]], 
            Times[ -0.063361699504227403, 
              c[ -48][ t]], 
            Times[ -0.075181213012062598, 
              c[ -47][ t]], 
            Times[ -0.084091858737850814, 
              c[ -46][ t]], 
            Times[ -0.089594193770366842, 
              c[ -45][ t]], 
            Times[ -0.091317159035181589, 
              c[ -44][ t]], 
            Times[ -0.089038438663606695, 
              c[ -43][ t]], 
            Times[ -0.082699334313268813, 
              c[ -42][ t]], 
            Times[ -0.072413370861974122, 
              c[ -41][ t]], 
            Times[ -0.058468080236789913, 
              c[ -40][ t]], 
            Times[ -0.041319668477947373, 
              c[ -39][ t]], 
            Times[ -0.021580547817547879, 
              c[ -38][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -37][ t]], 
            Times[ 0.022561481809254675, 
              c[ -36][ t]], 
            Times[ 0.045163358568919301, 
              c[ -35][ t]], 
            Times[ 0.066820663127759972, 
              c[ -34][ t]], 
            Times[ 0.086542809078944752, 
              c[ -33][ t]], 
            Times[ 0.10337416789158609, 
              c[ -32][ t]], 
            Times[ 0.11643488132933186, 
              c[ -31][ t]], 
            Times[ 0.12496032289024853, 
              c[ -30][ t]], 
            Times[ 0.12833762891430928, 
              c[ -29][ t]], 
            Times[ 0.12613778810677612, 
              c[ -28][ t]], 
            Times[ 0.11814190616181255, 
              c[ -27][ t]], 
            Times[ 0.10436044624225685, 
              c[ -26][ t]], 
            Times[ 0.085044480344421608, 
              c[ -25][ t]], 
            Times[ 0.060688263076985105, 
              c[ -24][ t]], 
            Times[ 0.032022748374425904, 
              c[ -23][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -22][ t]], 
            Times[ -0.034231213779558949, 
              c[ -21][ t]], 
            Times[ -0.06935801494512607, 
              c[ -20][ t]], 
            Times[ -0.10394325375429328, 
              c[ -19][ t]], 
            Times[ -0.13647135277833605, 
              c[ -18][ t]], 
            Times[ -0.16539866862653771, 
              c[ -17][ t]], 
            Times[ -0.18920668216016426, 
              c[ -16][ t]], 
            Times[ -0.20645618564475843, 
              c[ -15][ t]], 
            Times[ -0.21584055771952015, 
              c[ -14][ t]], 
            Times[ -0.21623620818304484, 
              c[ -13][ t]], 
            Times[ -0.206748335783172, 
              c[ -12][ t]], 
            Times[ -0.18675027222298593, 
              c[ -11][ t]], 
            Times[ -0.15591488063143982, 
              c[ -10][ t]], 
            Times[ -0.11423673049785436, 
              c[ -9][ t]], 
            Times[ -0.062044074975450343, 
              c[ -8][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -7][ t]], 
            Times[ 0.070907514257657775, 
              c[ -6][ t]], 
            Times[ 0.14938649372796362, 
              c[ -5][ t]], 
            Times[ 0.23387232094715985, 
              c[ -4][ t]], 
            Times[ 0.32256865202152157, 
              c[ -3][ t]], 
            Times[ 0.41349667156634418, 
              c[ -2][ t]], 
            Times[ 0.50455115242710469, 
              c[ -1][ t]], 
            Times[ 0.59356153372868048, 
              c[ 0][ t]], 
            Times[ 0.67835603854706339, 
              c[ 1][ t]], 
            Times[ 0.75682672864065692, 
              c[ 2][ t]], 
            Times[ 0.82699334313268824, 
              c[ 3][ t]], 
            Times[ 0.88706379305918381, 
              c[ 4][ t]], 
            Times[ 0.93548928378863916, 
              c[ 5][ t]], 
            Times[ 0.9710122092317629, 
              c[ 6][ t]], 
            Times[ 0.99270519960720671, 
              c[ 7][ t]], 
            Times[ 2.4036770703771531, 
              c[ 8][ t]], 
            Times[ 0.99270519960720671, 
              c[ 9][ t]], 
            Times[ 0.9710122092317629, 
              c[ 10][ t]], 
            Times[ 0.93548928378863916, 
              c[ 11][ t]], 
            Times[ 0.8870637930591837, 
              c[ 12][ t]], 
            Times[ 0.82699334313268824, 
              c[ 13][ t]], 
            Times[ 0.75682672864065703, 
              c[ 14][ t]], 
            Times[ 0.67835603854706328, 
              c[ 15][ t]], 
            Times[ 0.59356153372868048, 
              c[ 16][ t]], 
            Times[ 0.50455115242710469, 
              c[ 17][ t]], 
            Times[ 0.41349667156634395, 
              c[ 18][ t]], 
            Times[ 0.32256865202152157, 
              c[ 19][ t]], 
            Times[ 0.23387232094715985, 
              c[ 20][ t]], 
            Times[ 0.14938649372796345, 
              c[ 21][ t]], 
            Times[ 0.070907514257657775, 
              c[ 22][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 23][ t]], 
            Times[ -0.062044074975450475, 
              c[ 24][ t]], 
            Times[ -0.11423673049785436, 
              c[ 25][ t]], 
            Times[ -0.15591488063143982, 
              c[ 26][ t]], 
            Times[ -0.18675027222298607, 
              c[ 27][ t]], 
            Times[ -0.206748335783172, 
              c[ 28][ t]], 
            Times[ -0.21623620818304484, 
              c[ 29][ t]], 
            Times[ -0.21584055771952013, 
              c[ 30][ t]], 
            Times[ -0.20645618564475843, 
              c[ 31][ t]], 
            Times[ -0.18920668216016426, 
              c[ 32][ t]], 
            Times[ -0.1653986686265376, 
              c[ 33][ t]], 
            Times[ -0.13647135277833605, 
              c[ 34][ t]], 
            Times[ -0.10394325375429328, 
              c[ 35][ t]], 
            Times[ -0.069358014945125918, 
              c[ 36][ t]], 
            Times[ -0.034231213779558949, 
              c[ 37][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 38][ t]], 
            Times[ 0.032022748374426029, 
              c[ 39][ t]], 
            Times[ 0.060688263076985105, 
              c[ 40][ t]], 
            Times[ 0.085044480344421608, 
              c[ 41][ t]], 
            Times[ 0.10436044624225692, 
              c[ 42][ t]], 
            Times[ 0.11814190616181255, 
              c[ 43][ t]], 
            Times[ 0.12613778810677612, 
              c[ 44][ t]], 
            Times[ 0.12833762891430925, 
              c[ 45][ t]], 
            Times[ 0.12496032289024853, 
              c[ 46][ t]], 
            Times[ 0.11643488132933195, 
              c[ 47][ t]], 
            Times[ 0.10337416789158609, 
              c[ 48][ t]], 
            Times[ 0.086542809078944891, 
              c[ 49][ t]], 
            Times[ 0.066820663127760152, 
              c[ 50][ t]], 
            Times[ 0.045163358568919301, 
              c[ 51][ t]], 
            Times[ 0.022561481809254869, 
              c[ 52][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ 53][ t]], 
            Times[ -0.021580547817547879, 
              c[ 54][ t]], 
            Times[ -0.04131966847794722, 
              c[ 55][ t]], 
            Times[ -0.058468080236789774, 
              c[ 56][ t]], 
            Times[ -0.072413370861974122, 
              c[ 57][ t]], 
            Times[ -0.082699334313268744, 
              c[ 58][ t]], 
            Times[ -0.089038438663606653, 
              c[ 59][ t]], 
            Times[ -0.091317159035181589, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "9", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[9]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.06581101988179627`\ \(c[\(-60\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-59\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-58\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-57\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-56\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-55\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-54\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-53\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-52\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-51\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-50\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-49\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-48\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-47\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-46\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-45\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-44\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-43\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-42\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-41\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-40\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-39\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-38\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-37\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-36\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-35\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-34\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-33\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-32\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-31\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-30\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-29\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-28\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-27\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-26\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-25\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-24\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-23\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-22\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-21\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-20\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-19\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-18\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-17\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-16\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-15\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-14\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-13\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-12\)]\)[t] - 
            0.206748335783172`\ \(c[\(-11\)]\)[t] - 
            0.186750272222986`\ \(c[\(-10\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-9\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-8\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-7\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-6\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-5\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-4\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-3\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-2\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-1\)]\)[t] + 
            0.5045511524271047`\ \(c[0]\)[t] + 
            0.5935615337286805`\ \(c[1]\)[t] + 
            0.6783560385470633`\ \(c[2]\)[t] + 
            0.7568267286406569`\ \(c[3]\)[t] + 
            0.8269933431326881`\ \(c[4]\)[t] + 
            0.8870637930591837`\ \(c[5]\)[t] + 
            0.9354892837886392`\ \(c[6]\)[t] + 
            0.9710122092317629`\ \(c[7]\)[t] + 
            0.9927051996072067`\ \(c[8]\)[t] + 
            2.7765287921960846`\ \(c[9]\)[t] + 
            0.9927051996072069`\ \(c[10]\)[t] + 
            0.9710122092317629`\ \(c[11]\)[t] + 
            0.9354892837886392`\ \(c[12]\)[t] + 
            0.8870637930591838`\ \(c[13]\)[t] + 
            0.8269933431326881`\ \(c[14]\)[t] + 
            0.7568267286406569`\ \(c[15]\)[t] + 
            0.6783560385470634`\ \(c[16]\)[t] + 
            0.5935615337286806`\ \(c[17]\)[t] + 
            0.5045511524271047`\ \(c[18]\)[t] + 
            0.4134966715663442`\ \(c[19]\)[t] + 
            0.3225686520215216`\ \(c[20]\)[t] + 
            0.23387232094715985`\ \(c[21]\)[t] + 
            0.14938649372796384`\ \(c[22]\)[t] + 
            0.07090751425765777`\ \(c[23]\)[t] + 
            3.898171832519376`*^-17\ \(c[24]\)[t] - 
            0.06204407497545024`\ \(c[25]\)[t] - 
            0.11423673049785436`\ \(c[26]\)[t] - 
            0.15591488063143982`\ \(c[27]\)[t] - 
            0.18675027222298593`\ \(c[28]\)[t] - 
            0.206748335783172`\ \(c[29]\)[t] - 
            0.21623620818304484`\ \(c[30]\)[t] - 
            0.21584055771952015`\ \(c[31]\)[t] - 
            0.20645618564475843`\ \(c[32]\)[t] - 
            0.18920668216016426`\ \(c[33]\)[t] - 
            0.1653986686265377`\ \(c[34]\)[t] - 
            0.13647135277833605`\ \(c[35]\)[t] - 
            0.10394325375429328`\ \(c[36]\)[t] - 
            0.06935801494512607`\ \(c[37]\)[t] - 
            0.03423121377955895`\ \(c[38]\)[t] - 
            3.898171832519376`*^-17\ \(c[39]\)[t] + 
            0.032022748374425904`\ \(c[40]\)[t] + 
            0.060688263076985`\ \(c[41]\)[t] + 
            0.0850444803444217`\ \(c[42]\)[t] + 
            0.10436044624225685`\ \(c[43]\)[t] + 
            0.11814190616181253`\ \(c[44]\)[t] + 
            0.12613778810677614`\ \(c[45]\)[t] + 
            0.12833762891430928`\ \(c[46]\)[t] + 
            0.12496032289024853`\ \(c[47]\)[t] + 
            0.11643488132933186`\ \(c[48]\)[t] + 
            0.10337416789158609`\ \(c[49]\)[t] + 
            0.08654280907894489`\ \(c[50]\)[t] + 
            0.06682066312775997`\ \(c[51]\)[t] + 
            0.0451633585689193`\ \(c[52]\)[t] + 
            0.02256148180925487`\ \(c[53]\)[t] + 
            3.8981718325193755`*^-17\ \(c[54]\)[t] - 
            0.02158054781754788`\ \(c[55]\)[t] - 
            0.04131966847794722`\ \(c[56]\)[t] - 
            0.05846808023678991`\ \(c[57]\)[t] - 
            0.07241337086197412`\ \(c[58]\)[t] - 
            0.08269933431326874`\ \(c[59]\)[t] - 
            0.0890384386636067`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 9, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 9]][ t]], 
          Plus[ 
            Times[ 0.065811019881796273, 
              c[ -60][ t]], 
            Times[ 0.069830768673962415, 
              c[ -59][ t]], 
            Times[ 0.070873018952678238, 
              c[ -58][ t]], 
            Times[ 0.068802429876423349, 
              c[ -57][ t]], 
            Times[ 0.063614872548668253, 
              c[ -56][ t]], 
            Times[ 0.055441487066198933, 
              c[ -55][ t]], 
            Times[ 0.044547108751839919, 
              c[ -54][ t]], 
            Times[ 0.031322974491347078, 
              c[ -53][ t]], 
            Times[ 0.016273855731265604, 
              c[ -52][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -51][ t]], 
            Times[ -0.016825511857749401, 
              c[ -50][ t]], 
            Times[ -0.033483179628681567, 
              c[ -49][ t]], 
            Times[ -0.049236278094138941, 
              c[ -48][ t]], 
            Times[ -0.063361699504227528, 
              c[ -47][ t]], 
            Times[ -0.075181213012062598, 
              c[ -46][ t]], 
            Times[ -0.084091858737850814, 
              c[ -45][ t]], 
            Times[ -0.089594193770366884, 
              c[ -44][ t]], 
            Times[ -0.091317159035181589, 
              c[ -43][ t]], 
            Times[ -0.089038438663606695, 
              c[ -42][ t]], 
            Times[ -0.082699334313268744, 
              c[ -41][ t]], 
            Times[ -0.072413370861974122, 
              c[ -40][ t]], 
            Times[ -0.058468080236789913, 
              c[ -39][ t]], 
            Times[ -0.04131966847794722, 
              c[ -38][ t]], 
            Times[ -0.021580547817547879, 
              c[ -37][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -36][ t]], 
            Times[ 0.022561481809254869, 
              c[ -35][ t]], 
            Times[ 0.045163358568919301, 
              c[ -34][ t]], 
            Times[ 0.066820663127759972, 
              c[ -33][ t]], 
            Times[ 0.086542809078944891, 
              c[ -32][ t]], 
            Times[ 0.10337416789158609, 
              c[ -31][ t]], 
            Times[ 0.11643488132933186, 
              c[ -30][ t]], 
            Times[ 0.12496032289024853, 
              c[ -29][ t]], 
            Times[ 0.12833762891430928, 
              c[ -28][ t]], 
            Times[ 0.12613778810677614, 
              c[ -27][ t]], 
            Times[ 0.11814190616181255, 
              c[ -26][ t]], 
            Times[ 0.10436044624225685, 
              c[ -25][ t]], 
            Times[ 0.085044480344421705, 
              c[ -24][ t]], 
            Times[ 0.060688263076985105, 
              c[ -23][ t]], 
            Times[ 0.032022748374425904, 
              c[ -22][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -21][ t]], 
            Times[ -0.034231213779558949, 
              c[ -20][ t]], 
            Times[ -0.06935801494512607, 
              c[ -19][ t]], 
            Times[ -0.10394325375429328, 
              c[ -18][ t]], 
            Times[ -0.13647135277833605, 
              c[ -17][ t]], 
            Times[ -0.16539866862653771, 
              c[ -16][ t]], 
            Times[ -0.18920668216016426, 
              c[ -15][ t]], 
            Times[ -0.20645618564475843, 
              c[ -14][ t]], 
            Times[ -0.21584055771952015, 
              c[ -13][ t]], 
            Times[ -0.21623620818304484, 
              c[ -12][ t]], 
            Times[ -0.206748335783172, 
              c[ -11][ t]], 
            Times[ -0.18675027222298601, 
              c[ -10][ t]], 
            Times[ -0.15591488063143982, 
              c[ -9][ t]], 
            Times[ -0.11423673049785436, 
              c[ -8][ t]], 
            Times[ -0.062044074975450343, 
              c[ -7][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -6][ t]], 
            Times[ 0.070907514257657775, 
              c[ -5][ t]], 
            Times[ 0.14938649372796362, 
              c[ -4][ t]], 
            Times[ 0.23387232094715985, 
              c[ -3][ t]], 
            Times[ 0.32256865202152135, 
              c[ -2][ t]], 
            Times[ 0.41349667156634418, 
              c[ -1][ t]], 
            Times[ 0.50455115242710469, 
              c[ 0][ t]], 
            Times[ 0.59356153372868048, 
              c[ 1][ t]], 
            Times[ 0.67835603854706328, 
              c[ 2][ t]], 
            Times[ 0.75682672864065692, 
              c[ 3][ t]], 
            Times[ 0.82699334313268813, 
              c[ 4][ t]], 
            Times[ 0.8870637930591837, 
              c[ 5][ t]], 
            Times[ 0.93548928378863916, 
              c[ 6][ t]], 
            Times[ 0.9710122092317629, 
              c[ 7][ t]], 
            Times[ 0.99270519960720671, 
              c[ 8][ t]], 
            Times[ 2.7765287921960846, 
              c[ 9][ t]], 
            Times[ 0.99270519960720693, 
              c[ 10][ t]], 
            Times[ 0.9710122092317629, 
              c[ 11][ t]], 
            Times[ 0.93548928378863916, 
              c[ 12][ t]], 
            Times[ 0.88706379305918381, 
              c[ 13][ t]], 
            Times[ 0.82699334313268813, 
              c[ 14][ t]], 
            Times[ 0.75682672864065692, 
              c[ 15][ t]], 
            Times[ 0.67835603854706339, 
              c[ 16][ t]], 
            Times[ 0.59356153372868059, 
              c[ 17][ t]], 
            Times[ 0.50455115242710469, 
              c[ 18][ t]], 
            Times[ 0.41349667156634418, 
              c[ 19][ t]], 
            Times[ 0.32256865202152157, 
              c[ 20][ t]], 
            Times[ 0.23387232094715985, 
              c[ 21][ t]], 
            Times[ 0.14938649372796384, 
              c[ 22][ t]], 
            Times[ 0.070907514257657775, 
              c[ 23][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 24][ t]], 
            Times[ -0.062044074975450239, 
              c[ 25][ t]], 
            Times[ -0.11423673049785436, 
              c[ 26][ t]], 
            Times[ -0.15591488063143982, 
              c[ 27][ t]], 
            Times[ -0.18675027222298593, 
              c[ 28][ t]], 
            Times[ -0.206748335783172, 
              c[ 29][ t]], 
            Times[ -0.21623620818304484, 
              c[ 30][ t]], 
            Times[ -0.21584055771952015, 
              c[ 31][ t]], 
            Times[ -0.20645618564475843, 
              c[ 32][ t]], 
            Times[ -0.18920668216016426, 
              c[ 33][ t]], 
            Times[ -0.16539866862653771, 
              c[ 34][ t]], 
            Times[ -0.13647135277833605, 
              c[ 35][ t]], 
            Times[ -0.10394325375429328, 
              c[ 36][ t]], 
            Times[ -0.06935801494512607, 
              c[ 37][ t]], 
            Times[ -0.034231213779558949, 
              c[ 38][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 39][ t]], 
            Times[ 0.032022748374425904, 
              c[ 40][ t]], 
            Times[ 0.060688263076985001, 
              c[ 41][ t]], 
            Times[ 0.085044480344421705, 
              c[ 42][ t]], 
            Times[ 0.10436044624225685, 
              c[ 43][ t]], 
            Times[ 0.11814190616181253, 
              c[ 44][ t]], 
            Times[ 0.12613778810677614, 
              c[ 45][ t]], 
            Times[ 0.12833762891430928, 
              c[ 46][ t]], 
            Times[ 0.12496032289024853, 
              c[ 47][ t]], 
            Times[ 0.11643488132933186, 
              c[ 48][ t]], 
            Times[ 0.10337416789158609, 
              c[ 49][ t]], 
            Times[ 0.086542809078944891, 
              c[ 50][ t]], 
            Times[ 0.066820663127759972, 
              c[ 51][ t]], 
            Times[ 0.045163358568919301, 
              c[ 52][ t]], 
            Times[ 0.022561481809254869, 
              c[ 53][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 54][ t]], 
            Times[ -0.021580547817547879, 
              c[ 55][ t]], 
            Times[ -0.04131966847794722, 
              c[ 56][ t]], 
            Times[ -0.058468080236789913, 
              c[ 57][ t]], 
            Times[ -0.072413370861974122, 
              c[ 58][ t]], 
            Times[ -0.082699334313268744, 
              c[ 59][ t]], 
            Times[ -0.089038438663606695, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "10", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[10]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.059070953080906326`\ \(c[\(-60\)]\)[t] + 
            0.06581101988179631`\ \(c[\(-59\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-58\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-57\)]\)[t] + 
            0.06880242987642332`\ \(c[\(-56\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-55\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-54\)]\)[t] + 
            0.044547108751839815`\ \(c[\(-53\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-52\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-51\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-50\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-49\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-48\)]\)[t] - 
            0.049236278094139066`\ \(c[\(-47\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-46\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-45\)]\)[t] - 
            0.08409185873785086`\ \(c[\(-44\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-43\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-42\)]\)[t] - 
            0.08903843866360665`\ \(c[\(-41\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-40\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-39\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-38\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-37\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-36\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-35\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-34\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-33\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-32\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-31\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-30\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-29\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-28\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-27\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-26\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-25\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-24\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-23\)]\)[t] + 
            0.060688263076985`\ \(c[\(-22\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-21\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-20\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-19\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-18\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-17\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-16\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-15\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-14\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-13\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-12\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-11\)]\)[t] - 
            0.206748335783172`\ \(c[\(-10\)]\)[t] - 
            0.186750272222986`\ \(c[\(-9\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-8\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-7\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-6\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-5\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-4\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-3\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-2\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-1\)]\)[t] + 
            0.4134966715663442`\ \(c[0]\)[t] + 
            0.5045511524271047`\ \(c[1]\)[t] + 
            0.5935615337286805`\ \(c[2]\)[t] + 
            0.6783560385470634`\ \(c[3]\)[t] + 
            0.7568267286406569`\ \(c[4]\)[t] + 
            0.8269933431326882`\ \(c[5]\)[t] + 
            0.8870637930591838`\ \(c[6]\)[t] + 
            0.9354892837886392`\ \(c[7]\)[t] + 
            0.9710122092317629`\ \(c[8]\)[t] + 
            0.9927051996072069`\ \(c[9]\)[t] + 
            3.1932454224643014`\ \(c[10]\)[t] + 
            0.9927051996072069`\ \(c[11]\)[t] + 
            0.9710122092317629`\ \(c[12]\)[t] + 
            0.9354892837886392`\ \(c[13]\)[t] + 
            0.8870637930591838`\ \(c[14]\)[t] + 
            0.8269933431326881`\ \(c[15]\)[t] + 
            0.7568267286406569`\ \(c[16]\)[t] + 
            0.6783560385470634`\ \(c[17]\)[t] + 
            0.5935615337286803`\ \(c[18]\)[t] + 
            0.5045511524271047`\ \(c[19]\)[t] + 
            0.4134966715663442`\ \(c[20]\)[t] + 
            0.32256865202152135`\ \(c[21]\)[t] + 
            0.23387232094715998`\ \(c[22]\)[t] + 
            0.14938649372796362`\ \(c[23]\)[t] + 
            0.07090751425765762`\ \(c[24]\)[t] + 
            1.8033970416801674`*^-16\ \(c[25]\)[t] - 
            0.06204407497545034`\ \(c[26]\)[t] - 
            0.11423673049785445`\ \(c[27]\)[t] - 
            0.15591488063143974`\ \(c[28]\)[t] - 
            0.186750272222986`\ \(c[29]\)[t] - 
            0.20674833578317206`\ \(c[30]\)[t] - 
            0.21623620818304484`\ \(c[31]\)[t] - 
            0.21584055771952015`\ \(c[32]\)[t] - 
            0.20645618564475834`\ \(c[33]\)[t] - 
            0.18920668216016426`\ \(c[34]\)[t] - 
            0.1653986686265377`\ \(c[35]\)[t] - 
            0.1364713527783359`\ \(c[36]\)[t] - 
            0.10394325375429328`\ \(c[37]\)[t] - 
            0.06935801494512607`\ \(c[38]\)[t] - 
            0.034231213779558796`\ \(c[39]\)[t] - 
            3.898171832519376`*^-17\ \(c[40]\)[t] + 
            0.032022748374425904`\ \(c[41]\)[t] + 
            0.06068826307698522`\ \(c[42]\)[t] + 
            0.0850444803444217`\ \(c[43]\)[t] + 
            0.10436044624225685`\ \(c[44]\)[t] + 
            0.1181419061618126`\ \(c[45]\)[t] + 
            0.12613778810677614`\ \(c[46]\)[t] + 
            0.12833762891430928`\ \(c[47]\)[t] + 
            0.12496032289024847`\ \(c[48]\)[t] + 
            0.11643488132933186`\ \(c[49]\)[t] + 
            0.10337416789158609`\ \(c[50]\)[t] + 
            0.08654280907894475`\ \(c[51]\)[t] + 
            0.06682066312775997`\ \(c[52]\)[t] + 
            0.0451633585689193`\ \(c[53]\)[t] + 
            0.022561481809254675`\ \(c[54]\)[t] + 
            3.8981718325193755`*^-17\ \(c[55]\)[t] - 
            0.02158054781754788`\ \(c[56]\)[t] - 
            0.04131966847794737`\ \(c[57]\)[t] - 
            0.05846808023678991`\ \(c[58]\)[t] - 
            0.07241337086197412`\ \(c[59]\)[t] - 
            0.08269933431326881`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 10, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 10]][ t]], 
          Plus[ 
            Times[ 0.059070953080906326, 
              c[ -60][ t]], 
            Times[ 0.065811019881796315, 
              c[ -59][ t]], 
            Times[ 0.069830768673962415, 
              c[ -58][ t]], 
            Times[ 0.070873018952678238, 
              c[ -57][ t]], 
            Times[ 0.068802429876423321, 
              c[ -56][ t]], 
            Times[ 0.063614872548668253, 
              c[ -55][ t]], 
            Times[ 0.055441487066198933, 
              c[ -54][ t]], 
            Times[ 0.044547108751839815, 
              c[ -53][ t]], 
            Times[ 0.031322974491347078, 
              c[ -52][ t]], 
            Times[ 0.016273855731265604, 
              c[ -51][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -50][ t]], 
            Times[ -0.016825511857749401, 
              c[ -49][ t]], 
            Times[ -0.033483179628681567, 
              c[ -48][ t]], 
            Times[ -0.049236278094139066, 
              c[ -47][ t]], 
            Times[ -0.063361699504227528, 
              c[ -46][ t]], 
            Times[ -0.075181213012062598, 
              c[ -45][ t]], 
            Times[ -0.084091858737850855, 
              c[ -44][ t]], 
            Times[ -0.089594193770366884, 
              c[ -43][ t]], 
            Times[ -0.091317159035181589, 
              c[ -42][ t]], 
            Times[ -0.089038438663606653, 
              c[ -41][ t]], 
            Times[ -0.082699334313268744, 
              c[ -40][ t]], 
            Times[ -0.072413370861974122, 
              c[ -39][ t]], 
            Times[ -0.058468080236789913, 
              c[ -38][ t]], 
            Times[ -0.04131966847794722, 
              c[ -37][ t]], 
            Times[ -0.021580547817547879, 
              c[ -36][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -35][ t]], 
            Times[ 0.022561481809254869, 
              c[ -34][ t]], 
            Times[ 0.045163358568919301, 
              c[ -33][ t]], 
            Times[ 0.066820663127759972, 
              c[ -32][ t]], 
            Times[ 0.086542809078944891, 
              c[ -31][ t]], 
            Times[ 0.10337416789158609, 
              c[ -30][ t]], 
            Times[ 0.11643488132933186, 
              c[ -29][ t]], 
            Times[ 0.12496032289024853, 
              c[ -28][ t]], 
            Times[ 0.12833762891430928, 
              c[ -27][ t]], 
            Times[ 0.12613778810677614, 
              c[ -26][ t]], 
            Times[ 0.11814190616181253, 
              c[ -25][ t]], 
            Times[ 0.10436044624225685, 
              c[ -24][ t]], 
            Times[ 0.085044480344421705, 
              c[ -23][ t]], 
            Times[ 0.060688263076985001, 
              c[ -22][ t]], 
            Times[ 0.032022748374425904, 
              c[ -21][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -20][ t]], 
            Times[ -0.034231213779558949, 
              c[ -19][ t]], 
            Times[ -0.06935801494512607, 
              c[ -18][ t]], 
            Times[ -0.10394325375429328, 
              c[ -17][ t]], 
            Times[ -0.13647135277833605, 
              c[ -16][ t]], 
            Times[ -0.16539866862653771, 
              c[ -15][ t]], 
            Times[ -0.18920668216016426, 
              c[ -14][ t]], 
            Times[ -0.20645618564475843, 
              c[ -13][ t]], 
            Times[ -0.21584055771952015, 
              c[ -12][ t]], 
            Times[ -0.21623620818304484, 
              c[ -11][ t]], 
            Times[ -0.206748335783172, 
              c[ -10][ t]], 
            Times[ -0.18675027222298601, 
              c[ -9][ t]], 
            Times[ -0.15591488063143982, 
              c[ -8][ t]], 
            Times[ -0.11423673049785436, 
              c[ -7][ t]], 
            Times[ -0.062044074975450343, 
              c[ -6][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -5][ t]], 
            Times[ 0.070907514257657775, 
              c[ -4][ t]], 
            Times[ 0.14938649372796362, 
              c[ -3][ t]], 
            Times[ 0.23387232094715985, 
              c[ -2][ t]], 
            Times[ 0.32256865202152157, 
              c[ -1][ t]], 
            Times[ 0.41349667156634418, 
              c[ 0][ t]], 
            Times[ 0.50455115242710469, 
              c[ 1][ t]], 
            Times[ 0.59356153372868048, 
              c[ 2][ t]], 
            Times[ 0.67835603854706339, 
              c[ 3][ t]], 
            Times[ 0.75682672864065692, 
              c[ 4][ t]], 
            Times[ 0.82699334313268824, 
              c[ 5][ t]], 
            Times[ 0.88706379305918381, 
              c[ 6][ t]], 
            Times[ 0.93548928378863916, 
              c[ 7][ t]], 
            Times[ 0.9710122092317629, 
              c[ 8][ t]], 
            Times[ 0.99270519960720693, 
              c[ 9][ t]], 
            Times[ 3.1932454224643014, 
              c[ 10][ t]], 
            Times[ 0.99270519960720693, 
              c[ 11][ t]], 
            Times[ 0.9710122092317629, 
              c[ 12][ t]], 
            Times[ 0.93548928378863916, 
              c[ 13][ t]], 
            Times[ 0.88706379305918381, 
              c[ 14][ t]], 
            Times[ 0.82699334313268813, 
              c[ 15][ t]], 
            Times[ 0.75682672864065692, 
              c[ 16][ t]], 
            Times[ 0.67835603854706339, 
              c[ 17][ t]], 
            Times[ 0.59356153372868026, 
              c[ 18][ t]], 
            Times[ 0.50455115242710469, 
              c[ 19][ t]], 
            Times[ 0.41349667156634418, 
              c[ 20][ t]], 
            Times[ 0.32256865202152135, 
              c[ 21][ t]], 
            Times[ 0.23387232094715998, 
              c[ 22][ t]], 
            Times[ 0.14938649372796362, 
              c[ 23][ t]], 
            Times[ 0.070907514257657622, 
              c[ 24][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 25][ t]], 
            Times[ -0.062044074975450343, 
              c[ 26][ t]], 
            Times[ -0.11423673049785445, 
              c[ 27][ t]], 
            Times[ -0.15591488063143974, 
              c[ 28][ t]], 
            Times[ -0.18675027222298601, 
              c[ 29][ t]], 
            Times[ -0.20674833578317206, 
              c[ 30][ t]], 
            Times[ -0.21623620818304484, 
              c[ 31][ t]], 
            Times[ -0.21584055771952015, 
              c[ 32][ t]], 
            Times[ -0.20645618564475834, 
              c[ 33][ t]], 
            Times[ -0.18920668216016426, 
              c[ 34][ t]], 
            Times[ -0.16539866862653771, 
              c[ 35][ t]], 
            Times[ -0.13647135277833591, 
              c[ 36][ t]], 
            Times[ -0.10394325375429328, 
              c[ 37][ t]], 
            Times[ -0.06935801494512607, 
              c[ 38][ t]], 
            Times[ -0.034231213779558796, 
              c[ 39][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 40][ t]], 
            Times[ 0.032022748374425904, 
              c[ 41][ t]], 
            Times[ 0.060688263076985223, 
              c[ 42][ t]], 
            Times[ 0.085044480344421705, 
              c[ 43][ t]], 
            Times[ 0.10436044624225685, 
              c[ 44][ t]], 
            Times[ 0.1181419061618126, 
              c[ 45][ t]], 
            Times[ 0.12613778810677614, 
              c[ 46][ t]], 
            Times[ 0.12833762891430928, 
              c[ 47][ t]], 
            Times[ 0.12496032289024847, 
              c[ 48][ t]], 
            Times[ 0.11643488132933186, 
              c[ 49][ t]], 
            Times[ 0.10337416789158609, 
              c[ 50][ t]], 
            Times[ 0.086542809078944752, 
              c[ 51][ t]], 
            Times[ 0.066820663127759972, 
              c[ 52][ t]], 
            Times[ 0.045163358568919301, 
              c[ 53][ t]], 
            Times[ 0.022561481809254675, 
              c[ 54][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 55][ t]], 
            Times[ -0.021580547817547879, 
              c[ 56][ t]], 
            Times[ -0.041319668477947373, 
              c[ 57][ t]], 
            Times[ -0.058468080236789913, 
              c[ 58][ t]], 
            Times[ -0.072413370861974122, 
              c[ 59][ t]], 
            Times[ -0.082699334313268813, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "11", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[11]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.049975424961080865`\ \(c[\(-60\)]\)[t] + 
            0.0590709530809064`\ \(c[\(-59\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-58\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-57\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-56\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-55\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-54\)]\)[t] + 
            0.055441487066198857`\ \(c[\(-53\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-52\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-51\)]\)[t] + 
            0.01627385573126547`\ \(c[\(-50\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-49\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-48\)]\)[t] - 
            0.033483179628681706`\ \(c[\(-47\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-46\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-45\)]\)[t] - 
            0.0751812130120627`\ \(c[\(-44\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-43\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-42\)]\)[t] - 
            0.0913171590351816`\ \(c[\(-41\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-40\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-39\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-38\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-37\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-36\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-35\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-34\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-33\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-32\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-31\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-30\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-29\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-28\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-27\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-26\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-25\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-24\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-23\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-22\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-21\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-20\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-19\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-18\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-17\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-16\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-15\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-14\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-13\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-12\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-11\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-10\)]\)[t] - 
            0.206748335783172`\ \(c[\(-9\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-8\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-7\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-6\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-5\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-4\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-3\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-2\)]\)[t] + 
            0.23387232094715998`\ \(c[\(-1\)]\)[t] + 
            0.3225686520215216`\ \(c[0]\)[t] + 
            0.4134966715663442`\ \(c[1]\)[t] + 
            0.5045511524271047`\ \(c[2]\)[t] + 
            0.5935615337286806`\ \(c[3]\)[t] + 
            0.6783560385470634`\ \(c[4]\)[t] + 
            0.756826728640657`\ \(c[5]\)[t] + 
            0.8269933431326881`\ \(c[6]\)[t] + 
            0.8870637930591838`\ \(c[7]\)[t] + 
            0.9354892837886392`\ \(c[8]\)[t] + 
            0.9710122092317629`\ \(c[9]\)[t] + 
            0.9927051996072069`\ \(c[10]\)[t] + 
            3.6538269611818044`\ \(c[11]\)[t] + 
            0.9927051996072067`\ \(c[12]\)[t] + 
            0.9710122092317629`\ \(c[13]\)[t] + 
            0.9354892837886392`\ \(c[14]\)[t] + 
            0.8870637930591838`\ \(c[15]\)[t] + 
            0.8269933431326881`\ \(c[16]\)[t] + 
            0.7568267286406569`\ \(c[17]\)[t] + 
            0.6783560385470632`\ \(c[18]\)[t] + 
            0.5935615337286803`\ \(c[19]\)[t] + 
            0.5045511524271047`\ \(c[20]\)[t] + 
            0.41349667156634395`\ \(c[21]\)[t] + 
            0.3225686520215216`\ \(c[22]\)[t] + 
            0.23387232094715985`\ \(c[23]\)[t] + 
            0.14938649372796345`\ \(c[24]\)[t] + 
            0.07090751425765777`\ \(c[25]\)[t] + 
            3.898171832519376`*^-17\ \(c[26]\)[t] - 
            0.062044074975450475`\ \(c[27]\)[t] - 
            0.11423673049785436`\ \(c[28]\)[t] - 
            0.15591488063143982`\ \(c[29]\)[t] - 
            0.18675027222298607`\ \(c[30]\)[t] - 
            0.206748335783172`\ \(c[31]\)[t] - 
            0.21623620818304484`\ \(c[32]\)[t] - 
            0.21584055771952013`\ \(c[33]\)[t] - 
            0.20645618564475843`\ \(c[34]\)[t] - 
            0.18920668216016426`\ \(c[35]\)[t] - 
            0.1653986686265376`\ \(c[36]\)[t] - 
            0.13647135277833605`\ \(c[37]\)[t] - 
            0.10394325375429328`\ \(c[38]\)[t] - 
            0.06935801494512592`\ \(c[39]\)[t] - 
            0.03423121377955895`\ \(c[40]\)[t] - 
            1.8033970416801674`*^-16\ \(c[41]\)[t] + 
            0.03202274837442603`\ \(c[42]\)[t] + 
            0.060688263076985105`\ \(c[43]\)[t] + 
            0.08504448034442161`\ \(c[44]\)[t] + 
            0.10436044624225692`\ \(c[45]\)[t] + 
            0.11814190616181255`\ \(c[46]\)[t] + 
            0.12613778810677612`\ \(c[47]\)[t] + 
            0.12833762891430925`\ \(c[48]\)[t] + 
            0.12496032289024853`\ \(c[49]\)[t] + 
            0.11643488132933186`\ \(c[50]\)[t] + 
            0.10337416789158595`\ \(c[51]\)[t] + 
            0.08654280907894489`\ \(c[52]\)[t] + 
            0.06682066312775997`\ \(c[53]\)[t] + 
            0.045163358568919114`\ \(c[54]\)[t] + 
            0.02256148180925487`\ \(c[55]\)[t] + 
            3.8981718325193755`*^-17\ \(c[56]\)[t] - 
            0.021580547817548056`\ \(c[57]\)[t] - 
            0.04131966847794722`\ \(c[58]\)[t] - 
            0.05846808023678991`\ \(c[59]\)[t] - 
            0.07241337086197425`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 11, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 11]][ t]], 
          Plus[ 
            Times[ 0.049975424961080865, 
              c[ -60][ t]], 
            Times[ 0.059070953080906402, 
              c[ -59][ t]], 
            Times[ 0.065811019881796273, 
              c[ -58][ t]], 
            Times[ 0.069830768673962415, 
              c[ -57][ t]], 
            Times[ 0.070873018952678238, 
              c[ -56][ t]], 
            Times[ 0.068802429876423349, 
              c[ -55][ t]], 
            Times[ 0.063614872548668253, 
              c[ -54][ t]], 
            Times[ 0.055441487066198857, 
              c[ -53][ t]], 
            Times[ 0.044547108751839919, 
              c[ -52][ t]], 
            Times[ 0.031322974491347078, 
              c[ -51][ t]], 
            Times[ 0.016273855731265469, 
              c[ -50][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -49][ t]], 
            Times[ -0.016825511857749401, 
              c[ -48][ t]], 
            Times[ -0.033483179628681706, 
              c[ -47][ t]], 
            Times[ -0.049236278094138941, 
              c[ -46][ t]], 
            Times[ -0.063361699504227528, 
              c[ -45][ t]], 
            Times[ -0.075181213012062695, 
              c[ -44][ t]], 
            Times[ -0.084091858737850814, 
              c[ -43][ t]], 
            Times[ -0.089594193770366884, 
              c[ -42][ t]], 
            Times[ -0.091317159035181603, 
              c[ -41][ t]], 
            Times[ -0.089038438663606695, 
              c[ -40][ t]], 
            Times[ -0.082699334313268744, 
              c[ -39][ t]], 
            Times[ -0.072413370861974122, 
              c[ -38][ t]], 
            Times[ -0.058468080236789913, 
              c[ -37][ t]], 
            Times[ -0.04131966847794722, 
              c[ -36][ t]], 
            Times[ -0.021580547817547879, 
              c[ -35][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -34][ t]], 
            Times[ 0.022561481809254869, 
              c[ -33][ t]], 
            Times[ 0.045163358568919301, 
              c[ -32][ t]], 
            Times[ 0.066820663127759972, 
              c[ -31][ t]], 
            Times[ 0.086542809078944891, 
              c[ -30][ t]], 
            Times[ 0.10337416789158609, 
              c[ -29][ t]], 
            Times[ 0.11643488132933186, 
              c[ -28][ t]], 
            Times[ 0.12496032289024853, 
              c[ -27][ t]], 
            Times[ 0.12833762891430928, 
              c[ -26][ t]], 
            Times[ 0.12613778810677612, 
              c[ -25][ t]], 
            Times[ 0.11814190616181255, 
              c[ -24][ t]], 
            Times[ 0.10436044624225685, 
              c[ -23][ t]], 
            Times[ 0.085044480344421608, 
              c[ -22][ t]], 
            Times[ 0.060688263076985105, 
              c[ -21][ t]], 
            Times[ 0.032022748374425904, 
              c[ -20][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -19][ t]], 
            Times[ -0.034231213779558949, 
              c[ -18][ t]], 
            Times[ -0.06935801494512607, 
              c[ -17][ t]], 
            Times[ -0.10394325375429328, 
              c[ -16][ t]], 
            Times[ -0.13647135277833605, 
              c[ -15][ t]], 
            Times[ -0.16539866862653771, 
              c[ -14][ t]], 
            Times[ -0.18920668216016426, 
              c[ -13][ t]], 
            Times[ -0.20645618564475843, 
              c[ -12][ t]], 
            Times[ -0.21584055771952015, 
              c[ -11][ t]], 
            Times[ -0.21623620818304484, 
              c[ -10][ t]], 
            Times[ -0.206748335783172, 
              c[ -9][ t]], 
            Times[ -0.18675027222298593, 
              c[ -8][ t]], 
            Times[ -0.15591488063143974, 
              c[ -7][ t]], 
            Times[ -0.11423673049785436, 
              c[ -6][ t]], 
            Times[ -0.062044074975450239, 
              c[ -5][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -4][ t]], 
            Times[ 0.070907514257657775, 
              c[ -3][ t]], 
            Times[ 0.14938649372796362, 
              c[ -2][ t]], 
            Times[ 0.23387232094715998, 
              c[ -1][ t]], 
            Times[ 0.32256865202152157, 
              c[ 0][ t]], 
            Times[ 0.41349667156634418, 
              c[ 1][ t]], 
            Times[ 0.50455115242710469, 
              c[ 2][ t]], 
            Times[ 0.59356153372868059, 
              c[ 3][ t]], 
            Times[ 0.67835603854706339, 
              c[ 4][ t]], 
            Times[ 0.75682672864065703, 
              c[ 5][ t]], 
            Times[ 0.82699334313268813, 
              c[ 6][ t]], 
            Times[ 0.88706379305918381, 
              c[ 7][ t]], 
            Times[ 0.93548928378863916, 
              c[ 8][ t]], 
            Times[ 0.9710122092317629, 
              c[ 9][ t]], 
            Times[ 0.99270519960720693, 
              c[ 10][ t]], 
            Times[ 3.6538269611818044, 
              c[ 11][ t]], 
            Times[ 0.99270519960720671, 
              c[ 12][ t]], 
            Times[ 0.9710122092317629, 
              c[ 13][ t]], 
            Times[ 0.93548928378863916, 
              c[ 14][ t]], 
            Times[ 0.88706379305918381, 
              c[ 15][ t]], 
            Times[ 0.82699334313268813, 
              c[ 16][ t]], 
            Times[ 0.75682672864065692, 
              c[ 17][ t]], 
            Times[ 0.67835603854706317, 
              c[ 18][ t]], 
            Times[ 0.59356153372868026, 
              c[ 19][ t]], 
            Times[ 0.50455115242710469, 
              c[ 20][ t]], 
            Times[ 0.41349667156634395, 
              c[ 21][ t]], 
            Times[ 0.32256865202152157, 
              c[ 22][ t]], 
            Times[ 0.23387232094715985, 
              c[ 23][ t]], 
            Times[ 0.14938649372796345, 
              c[ 24][ t]], 
            Times[ 0.070907514257657775, 
              c[ 25][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 26][ t]], 
            Times[ -0.062044074975450475, 
              c[ 27][ t]], 
            Times[ -0.11423673049785436, 
              c[ 28][ t]], 
            Times[ -0.15591488063143982, 
              c[ 29][ t]], 
            Times[ -0.18675027222298607, 
              c[ 30][ t]], 
            Times[ -0.206748335783172, 
              c[ 31][ t]], 
            Times[ -0.21623620818304484, 
              c[ 32][ t]], 
            Times[ -0.21584055771952013, 
              c[ 33][ t]], 
            Times[ -0.20645618564475843, 
              c[ 34][ t]], 
            Times[ -0.18920668216016426, 
              c[ 35][ t]], 
            Times[ -0.1653986686265376, 
              c[ 36][ t]], 
            Times[ -0.13647135277833605, 
              c[ 37][ t]], 
            Times[ -0.10394325375429328, 
              c[ 38][ t]], 
            Times[ -0.069358014945125918, 
              c[ 39][ t]], 
            Times[ -0.034231213779558949, 
              c[ 40][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 41][ t]], 
            Times[ 0.032022748374426029, 
              c[ 42][ t]], 
            Times[ 0.060688263076985105, 
              c[ 43][ t]], 
            Times[ 0.085044480344421608, 
              c[ 44][ t]], 
            Times[ 0.10436044624225692, 
              c[ 45][ t]], 
            Times[ 0.11814190616181255, 
              c[ 46][ t]], 
            Times[ 0.12613778810677612, 
              c[ 47][ t]], 
            Times[ 0.12833762891430925, 
              c[ 48][ t]], 
            Times[ 0.12496032289024853, 
              c[ 49][ t]], 
            Times[ 0.11643488132933186, 
              c[ 50][ t]], 
            Times[ 0.10337416789158595, 
              c[ 51][ t]], 
            Times[ 0.086542809078944891, 
              c[ 52][ t]], 
            Times[ 0.066820663127759972, 
              c[ 53][ t]], 
            Times[ 0.045163358568919114, 
              c[ 54][ t]], 
            Times[ 0.022561481809254869, 
              c[ 55][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 56][ t]], 
            Times[ -0.021580547817548056, 
              c[ 57][ t]], 
            Times[ -0.04131966847794722, 
              c[ 58][ t]], 
            Times[ -0.058468080236789913, 
              c[ 59][ t]], 
            Times[ -0.072413370861974247, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "12", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[12]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.03897872015785999`\ \(c[\(-60\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-59\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-58\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-57\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-56\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-55\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-54\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-53\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-52\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-51\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-50\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-49\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-48\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-47\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-46\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-45\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-44\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-43\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-42\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-41\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-40\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-39\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-38\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-37\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-36\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-35\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-34\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-33\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-32\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-31\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-30\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-29\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-28\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-27\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-26\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-25\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-24\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-23\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-22\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-21\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-20\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-19\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-18\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-17\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-16\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-15\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-14\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-13\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-12\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-11\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-10\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-9\)]\)[t] - 
            0.206748335783172`\ \(c[\(-8\)]\)[t] - 
            0.186750272222986`\ \(c[\(-7\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-6\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-5\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-4\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-3\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-2\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-1\)]\)[t] + 
            0.23387232094715985`\ \(c[0]\)[t] + 
            0.32256865202152135`\ \(c[1]\)[t] + 
            0.4134966715663442`\ \(c[2]\)[t] + 
            0.5045511524271047`\ \(c[3]\)[t] + 
            0.5935615337286803`\ \(c[4]\)[t] + 
            0.6783560385470633`\ \(c[5]\)[t] + 
            0.7568267286406569`\ \(c[6]\)[t] + 
            0.8269933431326881`\ \(c[7]\)[t] + 
            0.8870637930591837`\ \(c[8]\)[t] + 
            0.9354892837886392`\ \(c[9]\)[t] + 
            0.9710122092317629`\ \(c[10]\)[t] + 
            0.9927051996072067`\ \(c[11]\)[t] + 
            4.158273408348594`\ \(c[12]\)[t] + 
            0.9927051996072069`\ \(c[13]\)[t] + 
            0.9710122092317629`\ \(c[14]\)[t] + 
            0.9354892837886392`\ \(c[15]\)[t] + 
            0.8870637930591838`\ \(c[16]\)[t] + 
            0.8269933431326881`\ \(c[17]\)[t] + 
            0.7568267286406569`\ \(c[18]\)[t] + 
            0.6783560385470634`\ \(c[19]\)[t] + 
            0.5935615337286806`\ \(c[20]\)[t] + 
            0.5045511524271047`\ \(c[21]\)[t] + 
            0.4134966715663443`\ \(c[22]\)[t] + 
            0.3225686520215216`\ \(c[23]\)[t] + 
            0.23387232094715985`\ \(c[24]\)[t] + 
            0.14938649372796384`\ \(c[25]\)[t] + 
            0.07090751425765777`\ \(c[26]\)[t] + 
            3.898171832519376`*^-17\ \(c[27]\)[t] - 
            0.06204407497545024`\ \(c[28]\)[t] - 
            0.11423673049785436`\ \(c[29]\)[t] - 
            0.15591488063143982`\ \(c[30]\)[t] - 
            0.18675027222298593`\ \(c[31]\)[t] - 
            0.206748335783172`\ \(c[32]\)[t] - 
            0.21623620818304484`\ \(c[33]\)[t] - 
            0.21584055771952015`\ \(c[34]\)[t] - 
            0.20645618564475843`\ \(c[35]\)[t] - 
            0.18920668216016426`\ \(c[36]\)[t] - 
            0.1653986686265377`\ \(c[37]\)[t] - 
            0.13647135277833605`\ \(c[38]\)[t] - 
            0.10394325375429328`\ \(c[39]\)[t] - 
            0.06935801494512607`\ \(c[40]\)[t] - 
            0.034231213779559094`\ \(c[41]\)[t] - 
            3.898171832519376`*^-17\ \(c[42]\)[t] + 
            0.032022748374425904`\ \(c[43]\)[t] + 
            0.060688263076985`\ \(c[44]\)[t] + 
            0.0850444803444217`\ \(c[45]\)[t] + 
            0.10436044624225685`\ \(c[46]\)[t] + 
            0.11814190616181253`\ \(c[47]\)[t] + 
            0.12613778810677614`\ \(c[48]\)[t] + 
            0.12833762891430928`\ \(c[49]\)[t] + 
            0.12496032289024853`\ \(c[50]\)[t] + 
            0.11643488132933186`\ \(c[51]\)[t] + 
            0.10337416789158609`\ \(c[52]\)[t] + 
            0.08654280907894489`\ \(c[53]\)[t] + 
            0.06682066312775997`\ \(c[54]\)[t] + 
            0.0451633585689193`\ \(c[55]\)[t] + 
            0.02256148180925487`\ \(c[56]\)[t] + 
            3.8981718325193755`*^-17\ \(c[57]\)[t] - 
            0.02158054781754788`\ \(c[58]\)[t] - 
            0.04131966847794722`\ \(c[59]\)[t] - 
            0.05846808023678991`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 12, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 12]][ t]], 
          Plus[ 
            Times[ 0.03897872015785999, 
              c[ -60][ t]], 
            Times[ 0.049975424961080865, 
              c[ -59][ t]], 
            Times[ 0.059070953080906326, 
              c[ -58][ t]], 
            Times[ 0.065811019881796273, 
              c[ -57][ t]], 
            Times[ 0.069830768673962415, 
              c[ -56][ t]], 
            Times[ 0.070873018952678238, 
              c[ -55][ t]], 
            Times[ 0.068802429876423349, 
              c[ -54][ t]], 
            Times[ 0.063614872548668253, 
              c[ -53][ t]], 
            Times[ 0.055441487066198933, 
              c[ -52][ t]], 
            Times[ 0.044547108751839919, 
              c[ -51][ t]], 
            Times[ 0.031322974491347078, 
              c[ -50][ t]], 
            Times[ 0.016273855731265604, 
              c[ -49][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -48][ t]], 
            Times[ -0.016825511857749401, 
              c[ -47][ t]], 
            Times[ -0.033483179628681567, 
              c[ -46][ t]], 
            Times[ -0.049236278094138941, 
              c[ -45][ t]], 
            Times[ -0.063361699504227528, 
              c[ -44][ t]], 
            Times[ -0.075181213012062598, 
              c[ -43][ t]], 
            Times[ -0.084091858737850814, 
              c[ -42][ t]], 
            Times[ -0.089594193770366884, 
              c[ -41][ t]], 
            Times[ -0.091317159035181589, 
              c[ -40][ t]], 
            Times[ -0.089038438663606695, 
              c[ -39][ t]], 
            Times[ -0.082699334313268744, 
              c[ -38][ t]], 
            Times[ -0.072413370861974122, 
              c[ -37][ t]], 
            Times[ -0.058468080236789913, 
              c[ -36][ t]], 
            Times[ -0.04131966847794722, 
              c[ -35][ t]], 
            Times[ -0.021580547817547879, 
              c[ -34][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -33][ t]], 
            Times[ 0.022561481809254869, 
              c[ -32][ t]], 
            Times[ 0.045163358568919301, 
              c[ -31][ t]], 
            Times[ 0.066820663127759972, 
              c[ -30][ t]], 
            Times[ 0.086542809078944891, 
              c[ -29][ t]], 
            Times[ 0.10337416789158609, 
              c[ -28][ t]], 
            Times[ 0.11643488132933186, 
              c[ -27][ t]], 
            Times[ 0.12496032289024853, 
              c[ -26][ t]], 
            Times[ 0.12833762891430928, 
              c[ -25][ t]], 
            Times[ 0.12613778810677614, 
              c[ -24][ t]], 
            Times[ 0.11814190616181255, 
              c[ -23][ t]], 
            Times[ 0.10436044624225685, 
              c[ -22][ t]], 
            Times[ 0.085044480344421705, 
              c[ -21][ t]], 
            Times[ 0.060688263076985105, 
              c[ -20][ t]], 
            Times[ 0.032022748374425904, 
              c[ -19][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -18][ t]], 
            Times[ -0.034231213779558949, 
              c[ -17][ t]], 
            Times[ -0.06935801494512607, 
              c[ -16][ t]], 
            Times[ -0.10394325375429328, 
              c[ -15][ t]], 
            Times[ -0.13647135277833605, 
              c[ -14][ t]], 
            Times[ -0.16539866862653771, 
              c[ -13][ t]], 
            Times[ -0.18920668216016426, 
              c[ -12][ t]], 
            Times[ -0.20645618564475843, 
              c[ -11][ t]], 
            Times[ -0.21584055771952015, 
              c[ -10][ t]], 
            Times[ -0.21623620818304484, 
              c[ -9][ t]], 
            Times[ -0.206748335783172, 
              c[ -8][ t]], 
            Times[ -0.18675027222298601, 
              c[ -7][ t]], 
            Times[ -0.15591488063143982, 
              c[ -6][ t]], 
            Times[ -0.11423673049785436, 
              c[ -5][ t]], 
            Times[ -0.062044074975450343, 
              c[ -4][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -3][ t]], 
            Times[ 0.070907514257657622, 
              c[ -2][ t]], 
            Times[ 0.14938649372796362, 
              c[ -1][ t]], 
            Times[ 0.23387232094715985, 
              c[ 0][ t]], 
            Times[ 0.32256865202152135, 
              c[ 1][ t]], 
            Times[ 0.41349667156634418, 
              c[ 2][ t]], 
            Times[ 0.50455115242710469, 
              c[ 3][ t]], 
            Times[ 0.59356153372868026, 
              c[ 4][ t]], 
            Times[ 0.67835603854706328, 
              c[ 5][ t]], 
            Times[ 0.75682672864065692, 
              c[ 6][ t]], 
            Times[ 0.82699334313268813, 
              c[ 7][ t]], 
            Times[ 0.8870637930591837, 
              c[ 8][ t]], 
            Times[ 0.93548928378863916, 
              c[ 9][ t]], 
            Times[ 0.9710122092317629, 
              c[ 10][ t]], 
            Times[ 0.99270519960720671, 
              c[ 11][ t]], 
            Times[ 4.1582734083485944, 
              c[ 12][ t]], 
            Times[ 0.99270519960720693, 
              c[ 13][ t]], 
            Times[ 0.9710122092317629, 
              c[ 14][ t]], 
            Times[ 0.93548928378863916, 
              c[ 15][ t]], 
            Times[ 0.88706379305918381, 
              c[ 16][ t]], 
            Times[ 0.82699334313268813, 
              c[ 17][ t]], 
            Times[ 0.75682672864065692, 
              c[ 18][ t]], 
            Times[ 0.67835603854706339, 
              c[ 19][ t]], 
            Times[ 0.59356153372868059, 
              c[ 20][ t]], 
            Times[ 0.50455115242710469, 
              c[ 21][ t]], 
            Times[ 0.41349667156634429, 
              c[ 22][ t]], 
            Times[ 0.32256865202152157, 
              c[ 23][ t]], 
            Times[ 0.23387232094715985, 
              c[ 24][ t]], 
            Times[ 0.14938649372796384, 
              c[ 25][ t]], 
            Times[ 0.070907514257657775, 
              c[ 26][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 27][ t]], 
            Times[ -0.062044074975450239, 
              c[ 28][ t]], 
            Times[ -0.11423673049785436, 
              c[ 29][ t]], 
            Times[ -0.15591488063143982, 
              c[ 30][ t]], 
            Times[ -0.18675027222298593, 
              c[ 31][ t]], 
            Times[ -0.206748335783172, 
              c[ 32][ t]], 
            Times[ -0.21623620818304484, 
              c[ 33][ t]], 
            Times[ -0.21584055771952015, 
              c[ 34][ t]], 
            Times[ -0.20645618564475843, 
              c[ 35][ t]], 
            Times[ -0.18920668216016426, 
              c[ 36][ t]], 
            Times[ -0.16539866862653771, 
              c[ 37][ t]], 
            Times[ -0.13647135277833605, 
              c[ 38][ t]], 
            Times[ -0.10394325375429328, 
              c[ 39][ t]], 
            Times[ -0.06935801494512607, 
              c[ 40][ t]], 
            Times[ -0.034231213779559094, 
              c[ 41][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 42][ t]], 
            Times[ 0.032022748374425904, 
              c[ 43][ t]], 
            Times[ 0.060688263076985001, 
              c[ 44][ t]], 
            Times[ 0.085044480344421705, 
              c[ 45][ t]], 
            Times[ 0.10436044624225685, 
              c[ 46][ t]], 
            Times[ 0.11814190616181253, 
              c[ 47][ t]], 
            Times[ 0.12613778810677614, 
              c[ 48][ t]], 
            Times[ 0.12833762891430928, 
              c[ 49][ t]], 
            Times[ 0.12496032289024853, 
              c[ 50][ t]], 
            Times[ 0.11643488132933186, 
              c[ 51][ t]], 
            Times[ 0.10337416789158609, 
              c[ 52][ t]], 
            Times[ 0.086542809078944891, 
              c[ 53][ t]], 
            Times[ 0.066820663127759972, 
              c[ 54][ t]], 
            Times[ 0.045163358568919301, 
              c[ 55][ t]], 
            Times[ 0.022561481809254869, 
              c[ 56][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 57][ t]], 
            Times[ -0.021580547817547879, 
              c[ 58][ t]], 
            Times[ -0.04131966847794722, 
              c[ 59][ t]], 
            Times[ -0.058468080236789913, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "13", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[13]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.026603074225527826`\ \(c[\(-60\)]\)[t] + 
            0.03897872015786009`\ \(c[\(-59\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-58\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-57\)]\)[t] + 
            0.06581101988179631`\ \(c[\(-56\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-55\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-54\)]\)[t] + 
            0.06880242987642332`\ \(c[\(-53\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-52\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-51\)]\)[t] + 
            0.044547108751839815`\ \(c[\(-50\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-49\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-48\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-47\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-46\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-45\)]\)[t] - 
            0.049236278094139066`\ \(c[\(-44\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-43\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-42\)]\)[t] - 
            0.08409185873785086`\ \(c[\(-41\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-40\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-39\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-38\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-37\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-36\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-35\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-34\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-33\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-32\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-31\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-30\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-29\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-28\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-27\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-26\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-25\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-24\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-23\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-22\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-21\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-20\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-19\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-18\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-17\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-16\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-15\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-14\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-13\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-12\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-11\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-10\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-9\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-8\)]\)[t] - 
            0.206748335783172`\ \(c[\(-7\)]\)[t] - 
            0.186750272222986`\ \(c[\(-6\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-5\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-4\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-3\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-2\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-1\)]\)[t] + 
            0.14938649372796362`\ \(c[0]\)[t] + 
            0.23387232094715985`\ \(c[1]\)[t] + 
            0.3225686520215216`\ \(c[2]\)[t] + 
            0.4134966715663442`\ \(c[3]\)[t] + 
            0.5045511524271047`\ \(c[4]\)[t] + 
            0.5935615337286805`\ \(c[5]\)[t] + 
            0.6783560385470634`\ \(c[6]\)[t] + 
            0.7568267286406569`\ \(c[7]\)[t] + 
            0.8269933431326882`\ \(c[8]\)[t] + 
            0.8870637930591838`\ \(c[9]\)[t] + 
            0.9354892837886392`\ \(c[10]\)[t] + 
            0.9710122092317629`\ \(c[11]\)[t] + 
            0.9927051996072069`\ \(c[12]\)[t] + 
            4.70658476396467`\ \(c[13]\)[t] + 
            0.9927051996072069`\ \(c[14]\)[t] + 
            0.9710122092317629`\ \(c[15]\)[t] + 
            0.9354892837886392`\ \(c[16]\)[t] + 
            0.8870637930591838`\ \(c[17]\)[t] + 
            0.8269933431326881`\ \(c[18]\)[t] + 
            0.7568267286406569`\ \(c[19]\)[t] + 
            0.6783560385470634`\ \(c[20]\)[t] + 
            0.5935615337286803`\ \(c[21]\)[t] + 
            0.5045511524271049`\ \(c[22]\)[t] + 
            0.4134966715663442`\ \(c[23]\)[t] + 
            0.32256865202152135`\ \(c[24]\)[t] + 
            0.23387232094715998`\ \(c[25]\)[t] + 
            0.14938649372796362`\ \(c[26]\)[t] + 
            0.07090751425765762`\ \(c[27]\)[t] + 
            1.8033970416801674`*^-16\ \(c[28]\)[t] - 
            0.06204407497545034`\ \(c[29]\)[t] - 
            0.11423673049785445`\ \(c[30]\)[t] - 
            0.15591488063143974`\ \(c[31]\)[t] - 
            0.186750272222986`\ \(c[32]\)[t] - 
            0.20674833578317206`\ \(c[33]\)[t] - 
            0.21623620818304484`\ \(c[34]\)[t] - 
            0.21584055771952015`\ \(c[35]\)[t] - 
            0.20645618564475834`\ \(c[36]\)[t] - 
            0.18920668216016426`\ \(c[37]\)[t] - 
            0.1653986686265377`\ \(c[38]\)[t] - 
            0.1364713527783359`\ \(c[39]\)[t] - 
            0.10394325375429328`\ \(c[40]\)[t] - 
            0.06935801494512607`\ \(c[41]\)[t] - 
            0.034231213779558796`\ \(c[42]\)[t] - 
            3.898171832519376`*^-17\ \(c[43]\)[t] + 
            0.032022748374425904`\ \(c[44]\)[t] + 
            0.06068826307698522`\ \(c[45]\)[t] + 
            0.0850444803444217`\ \(c[46]\)[t] + 
            0.10436044624225685`\ \(c[47]\)[t] + 
            0.1181419061618126`\ \(c[48]\)[t] + 
            0.12613778810677614`\ \(c[49]\)[t] + 
            0.12833762891430928`\ \(c[50]\)[t] + 
            0.12496032289024847`\ \(c[51]\)[t] + 
            0.11643488132933186`\ \(c[52]\)[t] + 
            0.10337416789158609`\ \(c[53]\)[t] + 
            0.08654280907894475`\ \(c[54]\)[t] + 
            0.06682066312775997`\ \(c[55]\)[t] + 
            0.0451633585689193`\ \(c[56]\)[t] + 
            0.022561481809254675`\ \(c[57]\)[t] + 
            3.8981718325193755`*^-17\ \(c[58]\)[t] - 
            0.02158054781754788`\ \(c[59]\)[t] - 
            0.04131966847794737`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 13, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 13]][ t]], 
          Plus[ 
            Times[ 0.026603074225527826, 
              c[ -60][ t]], 
            Times[ 0.038978720157860088, 
              c[ -59][ t]], 
            Times[ 0.049975424961080865, 
              c[ -58][ t]], 
            Times[ 0.059070953080906326, 
              c[ -57][ t]], 
            Times[ 0.065811019881796315, 
              c[ -56][ t]], 
            Times[ 0.069830768673962415, 
              c[ -55][ t]], 
            Times[ 0.070873018952678238, 
              c[ -54][ t]], 
            Times[ 0.068802429876423321, 
              c[ -53][ t]], 
            Times[ 0.063614872548668253, 
              c[ -52][ t]], 
            Times[ 0.055441487066198933, 
              c[ -51][ t]], 
            Times[ 0.044547108751839815, 
              c[ -50][ t]], 
            Times[ 0.031322974491347078, 
              c[ -49][ t]], 
            Times[ 0.016273855731265604, 
              c[ -48][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -47][ t]], 
            Times[ -0.016825511857749401, 
              c[ -46][ t]], 
            Times[ -0.033483179628681567, 
              c[ -45][ t]], 
            Times[ -0.049236278094139066, 
              c[ -44][ t]], 
            Times[ -0.063361699504227528, 
              c[ -43][ t]], 
            Times[ -0.075181213012062598, 
              c[ -42][ t]], 
            Times[ -0.084091858737850855, 
              c[ -41][ t]], 
            Times[ -0.089594193770366884, 
              c[ -40][ t]], 
            Times[ -0.091317159035181589, 
              c[ -39][ t]], 
            Times[ -0.089038438663606695, 
              c[ -38][ t]], 
            Times[ -0.082699334313268744, 
              c[ -37][ t]], 
            Times[ -0.072413370861974122, 
              c[ -36][ t]], 
            Times[ -0.058468080236789913, 
              c[ -35][ t]], 
            Times[ -0.04131966847794722, 
              c[ -34][ t]], 
            Times[ -0.021580547817547879, 
              c[ -33][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -32][ t]], 
            Times[ 0.022561481809254869, 
              c[ -31][ t]], 
            Times[ 0.045163358568919301, 
              c[ -30][ t]], 
            Times[ 0.066820663127759972, 
              c[ -29][ t]], 
            Times[ 0.086542809078944891, 
              c[ -28][ t]], 
            Times[ 0.10337416789158609, 
              c[ -27][ t]], 
            Times[ 0.11643488132933186, 
              c[ -26][ t]], 
            Times[ 0.12496032289024853, 
              c[ -25][ t]], 
            Times[ 0.12833762891430928, 
              c[ -24][ t]], 
            Times[ 0.12613778810677614, 
              c[ -23][ t]], 
            Times[ 0.11814190616181253, 
              c[ -22][ t]], 
            Times[ 0.10436044624225685, 
              c[ -21][ t]], 
            Times[ 0.085044480344421705, 
              c[ -20][ t]], 
            Times[ 0.060688263076985105, 
              c[ -19][ t]], 
            Times[ 0.032022748374425904, 
              c[ -18][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -17][ t]], 
            Times[ -0.034231213779558949, 
              c[ -16][ t]], 
            Times[ -0.06935801494512607, 
              c[ -15][ t]], 
            Times[ -0.10394325375429328, 
              c[ -14][ t]], 
            Times[ -0.13647135277833605, 
              c[ -13][ t]], 
            Times[ -0.16539866862653771, 
              c[ -12][ t]], 
            Times[ -0.18920668216016426, 
              c[ -11][ t]], 
            Times[ -0.20645618564475843, 
              c[ -10][ t]], 
            Times[ -0.21584055771952015, 
              c[ -9][ t]], 
            Times[ -0.21623620818304484, 
              c[ -8][ t]], 
            Times[ -0.206748335783172, 
              c[ -7][ t]], 
            Times[ -0.18675027222298601, 
              c[ -6][ t]], 
            Times[ -0.15591488063143982, 
              c[ -5][ t]], 
            Times[ -0.11423673049785436, 
              c[ -4][ t]], 
            Times[ -0.062044074975450343, 
              c[ -3][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -2][ t]], 
            Times[ 0.070907514257657775, 
              c[ -1][ t]], 
            Times[ 0.14938649372796362, 
              c[ 0][ t]], 
            Times[ 0.23387232094715985, 
              c[ 1][ t]], 
            Times[ 0.32256865202152157, 
              c[ 2][ t]], 
            Times[ 0.41349667156634418, 
              c[ 3][ t]], 
            Times[ 0.50455115242710469, 
              c[ 4][ t]], 
            Times[ 0.59356153372868048, 
              c[ 5][ t]], 
            Times[ 0.67835603854706339, 
              c[ 6][ t]], 
            Times[ 0.75682672864065692, 
              c[ 7][ t]], 
            Times[ 0.82699334313268824, 
              c[ 8][ t]], 
            Times[ 0.88706379305918381, 
              c[ 9][ t]], 
            Times[ 0.93548928378863916, 
              c[ 10][ t]], 
            Times[ 0.9710122092317629, 
              c[ 11][ t]], 
            Times[ 0.99270519960720693, 
              c[ 12][ t]], 
            Times[ 4.7065847639646696, 
              c[ 13][ t]], 
            Times[ 0.99270519960720693, 
              c[ 14][ t]], 
            Times[ 0.9710122092317629, 
              c[ 15][ t]], 
            Times[ 0.93548928378863916, 
              c[ 16][ t]], 
            Times[ 0.88706379305918381, 
              c[ 17][ t]], 
            Times[ 0.82699334313268813, 
              c[ 18][ t]], 
            Times[ 0.75682672864065692, 
              c[ 19][ t]], 
            Times[ 0.67835603854706339, 
              c[ 20][ t]], 
            Times[ 0.59356153372868026, 
              c[ 21][ t]], 
            Times[ 0.50455115242710491, 
              c[ 22][ t]], 
            Times[ 0.41349667156634418, 
              c[ 23][ t]], 
            Times[ 0.32256865202152135, 
              c[ 24][ t]], 
            Times[ 0.23387232094715998, 
              c[ 25][ t]], 
            Times[ 0.14938649372796362, 
              c[ 26][ t]], 
            Times[ 0.070907514257657622, 
              c[ 27][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 28][ t]], 
            Times[ -0.062044074975450343, 
              c[ 29][ t]], 
            Times[ -0.11423673049785445, 
              c[ 30][ t]], 
            Times[ -0.15591488063143974, 
              c[ 31][ t]], 
            Times[ -0.18675027222298601, 
              c[ 32][ t]], 
            Times[ -0.20674833578317206, 
              c[ 33][ t]], 
            Times[ -0.21623620818304484, 
              c[ 34][ t]], 
            Times[ -0.21584055771952015, 
              c[ 35][ t]], 
            Times[ -0.20645618564475834, 
              c[ 36][ t]], 
            Times[ -0.18920668216016426, 
              c[ 37][ t]], 
            Times[ -0.16539866862653771, 
              c[ 38][ t]], 
            Times[ -0.13647135277833591, 
              c[ 39][ t]], 
            Times[ -0.10394325375429328, 
              c[ 40][ t]], 
            Times[ -0.06935801494512607, 
              c[ 41][ t]], 
            Times[ -0.034231213779558796, 
              c[ 42][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 43][ t]], 
            Times[ 0.032022748374425904, 
              c[ 44][ t]], 
            Times[ 0.060688263076985223, 
              c[ 45][ t]], 
            Times[ 0.085044480344421705, 
              c[ 46][ t]], 
            Times[ 0.10436044624225685, 
              c[ 47][ t]], 
            Times[ 0.1181419061618126, 
              c[ 48][ t]], 
            Times[ 0.12613778810677614, 
              c[ 49][ t]], 
            Times[ 0.12833762891430928, 
              c[ 50][ t]], 
            Times[ 0.12496032289024847, 
              c[ 51][ t]], 
            Times[ 0.11643488132933186, 
              c[ 52][ t]], 
            Times[ 0.10337416789158609, 
              c[ 53][ t]], 
            Times[ 0.086542809078944752, 
              c[ 54][ t]], 
            Times[ 0.066820663127759972, 
              c[ 55][ t]], 
            Times[ 0.045163358568919301, 
              c[ 56][ t]], 
            Times[ 0.022561481809254675, 
              c[ 57][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 58][ t]], 
            Times[ -0.021580547817547879, 
              c[ 59][ t]], 
            Times[ -0.041319668477947373, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "14", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[14]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.013414935129827233`\ \(c[\(-60\)]\)[t] + 
            0.026603074225527937`\ \(c[\(-59\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-58\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-57\)]\)[t] + 
            0.0590709530809064`\ \(c[\(-56\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-55\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-54\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-53\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-52\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-51\)]\)[t] + 
            0.055441487066198857`\ \(c[\(-50\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-49\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-48\)]\)[t] + 
            0.01627385573126547`\ \(c[\(-47\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-46\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-45\)]\)[t] - 
            0.033483179628681706`\ \(c[\(-44\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-43\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-42\)]\)[t] - 
            0.0751812130120627`\ \(c[\(-41\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-40\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-39\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-38\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-37\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-36\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-35\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-34\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-33\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-32\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-31\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-30\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-29\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-28\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-27\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-26\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-25\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-24\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-23\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-22\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-21\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-20\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-19\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-18\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-17\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-16\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-15\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-14\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-13\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-12\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-11\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-10\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-9\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-8\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-7\)]\)[t] - 
            0.206748335783172`\ \(c[\(-6\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-5\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-4\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-3\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-2\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-1\)]\)[t] + 
            0.07090751425765777`\ \(c[0]\)[t] + 
            0.14938649372796362`\ \(c[1]\)[t] + 
            0.23387232094715998`\ \(c[2]\)[t] + 
            0.3225686520215216`\ \(c[3]\)[t] + 
            0.4134966715663442`\ \(c[4]\)[t] + 
            0.5045511524271047`\ \(c[5]\)[t] + 
            0.5935615337286806`\ \(c[6]\)[t] + 
            0.6783560385470634`\ \(c[7]\)[t] + 
            0.756826728640657`\ \(c[8]\)[t] + 
            0.8269933431326881`\ \(c[9]\)[t] + 
            0.8870637930591838`\ \(c[10]\)[t] + 
            0.9354892837886392`\ \(c[11]\)[t] + 
            0.9710122092317629`\ \(c[12]\)[t] + 
            0.9927051996072069`\ \(c[13]\)[t] + 
            5.298761028030031`\ \(c[14]\)[t] + 
            0.9927051996072067`\ \(c[15]\)[t] + 
            0.9710122092317629`\ \(c[16]\)[t] + 
            0.9354892837886392`\ \(c[17]\)[t] + 
            0.8870637930591838`\ \(c[18]\)[t] + 
            0.8269933431326881`\ \(c[19]\)[t] + 
            0.7568267286406569`\ \(c[20]\)[t] + 
            0.6783560385470632`\ \(c[21]\)[t] + 
            0.5935615337286806`\ \(c[22]\)[t] + 
            0.5045511524271047`\ \(c[23]\)[t] + 
            0.41349667156634395`\ \(c[24]\)[t] + 
            0.3225686520215216`\ \(c[25]\)[t] + 
            0.23387232094715985`\ \(c[26]\)[t] + 
            0.14938649372796345`\ \(c[27]\)[t] + 
            0.07090751425765777`\ \(c[28]\)[t] + 
            3.898171832519376`*^-17\ \(c[29]\)[t] - 
            0.062044074975450475`\ \(c[30]\)[t] - 
            0.11423673049785436`\ \(c[31]\)[t] - 
            0.15591488063143982`\ \(c[32]\)[t] - 
            0.18675027222298607`\ \(c[33]\)[t] - 
            0.206748335783172`\ \(c[34]\)[t] - 
            0.21623620818304484`\ \(c[35]\)[t] - 
            0.21584055771952013`\ \(c[36]\)[t] - 
            0.20645618564475843`\ \(c[37]\)[t] - 
            0.18920668216016426`\ \(c[38]\)[t] - 
            0.1653986686265376`\ \(c[39]\)[t] - 
            0.13647135277833605`\ \(c[40]\)[t] - 
            0.1039432537542934`\ \(c[41]\)[t] - 
            0.06935801494512592`\ \(c[42]\)[t] - 
            0.03423121377955895`\ \(c[43]\)[t] - 
            1.8033970416801674`*^-16\ \(c[44]\)[t] + 
            0.03202274837442603`\ \(c[45]\)[t] + 
            0.060688263076985105`\ \(c[46]\)[t] + 
            0.08504448034442161`\ \(c[47]\)[t] + 
            0.10436044624225692`\ \(c[48]\)[t] + 
            0.11814190616181255`\ \(c[49]\)[t] + 
            0.12613778810677612`\ \(c[50]\)[t] + 
            0.12833762891430925`\ \(c[51]\)[t] + 
            0.12496032289024853`\ \(c[52]\)[t] + 
            0.11643488132933186`\ \(c[53]\)[t] + 
            0.10337416789158595`\ \(c[54]\)[t] + 
            0.08654280907894489`\ \(c[55]\)[t] + 
            0.06682066312775997`\ \(c[56]\)[t] + 
            0.045163358568919114`\ \(c[57]\)[t] + 
            0.02256148180925487`\ \(c[58]\)[t] + 
            3.8981718325193755`*^-17\ \(c[59]\)[t] - 
            0.021580547817548056`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 14, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 14]][ t]], 
          Plus[ 
            Times[ 0.013414935129827233, 
              c[ -60][ t]], 
            Times[ 0.026603074225527937, 
              c[ -59][ t]], 
            Times[ 0.03897872015785999, 
              c[ -58][ t]], 
            Times[ 0.049975424961080865, 
              c[ -57][ t]], 
            Times[ 0.059070953080906402, 
              c[ -56][ t]], 
            Times[ 0.065811019881796273, 
              c[ -55][ t]], 
            Times[ 0.069830768673962415, 
              c[ -54][ t]], 
            Times[ 0.070873018952678238, 
              c[ -53][ t]], 
            Times[ 0.068802429876423349, 
              c[ -52][ t]], 
            Times[ 0.063614872548668253, 
              c[ -51][ t]], 
            Times[ 0.055441487066198857, 
              c[ -50][ t]], 
            Times[ 0.044547108751839919, 
              c[ -49][ t]], 
            Times[ 0.031322974491347078, 
              c[ -48][ t]], 
            Times[ 0.016273855731265469, 
              c[ -47][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -46][ t]], 
            Times[ -0.016825511857749401, 
              c[ -45][ t]], 
            Times[ -0.033483179628681706, 
              c[ -44][ t]], 
            Times[ -0.049236278094138941, 
              c[ -43][ t]], 
            Times[ -0.063361699504227528, 
              c[ -42][ t]], 
            Times[ -0.075181213012062695, 
              c[ -41][ t]], 
            Times[ -0.084091858737850814, 
              c[ -40][ t]], 
            Times[ -0.089594193770366884, 
              c[ -39][ t]], 
            Times[ -0.091317159035181589, 
              c[ -38][ t]], 
            Times[ -0.089038438663606695, 
              c[ -37][ t]], 
            Times[ -0.082699334313268744, 
              c[ -36][ t]], 
            Times[ -0.072413370861974122, 
              c[ -35][ t]], 
            Times[ -0.058468080236789913, 
              c[ -34][ t]], 
            Times[ -0.04131966847794722, 
              c[ -33][ t]], 
            Times[ -0.021580547817547879, 
              c[ -32][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -31][ t]], 
            Times[ 0.022561481809254869, 
              c[ -30][ t]], 
            Times[ 0.045163358568919301, 
              c[ -29][ t]], 
            Times[ 0.066820663127759972, 
              c[ -28][ t]], 
            Times[ 0.086542809078944891, 
              c[ -27][ t]], 
            Times[ 0.10337416789158609, 
              c[ -26][ t]], 
            Times[ 0.11643488132933186, 
              c[ -25][ t]], 
            Times[ 0.12496032289024853, 
              c[ -24][ t]], 
            Times[ 0.12833762891430928, 
              c[ -23][ t]], 
            Times[ 0.12613778810677612, 
              c[ -22][ t]], 
            Times[ 0.11814190616181255, 
              c[ -21][ t]], 
            Times[ 0.10436044624225685, 
              c[ -20][ t]], 
            Times[ 0.085044480344421705, 
              c[ -19][ t]], 
            Times[ 0.060688263076985105, 
              c[ -18][ t]], 
            Times[ 0.032022748374425904, 
              c[ -17][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -16][ t]], 
            Times[ -0.034231213779558949, 
              c[ -15][ t]], 
            Times[ -0.06935801494512607, 
              c[ -14][ t]], 
            Times[ -0.10394325375429328, 
              c[ -13][ t]], 
            Times[ -0.13647135277833605, 
              c[ -12][ t]], 
            Times[ -0.16539866862653771, 
              c[ -11][ t]], 
            Times[ -0.18920668216016426, 
              c[ -10][ t]], 
            Times[ -0.20645618564475843, 
              c[ -9][ t]], 
            Times[ -0.21584055771952015, 
              c[ -8][ t]], 
            Times[ -0.21623620818304484, 
              c[ -7][ t]], 
            Times[ -0.206748335783172, 
              c[ -6][ t]], 
            Times[ -0.18675027222298593, 
              c[ -5][ t]], 
            Times[ -0.15591488063143974, 
              c[ -4][ t]], 
            Times[ -0.11423673049785436, 
              c[ -3][ t]], 
            Times[ -0.062044074975450343, 
              c[ -2][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -1][ t]], 
            Times[ 0.070907514257657775, 
              c[ 0][ t]], 
            Times[ 0.14938649372796362, 
              c[ 1][ t]], 
            Times[ 0.23387232094715998, 
              c[ 2][ t]], 
            Times[ 0.32256865202152157, 
              c[ 3][ t]], 
            Times[ 0.41349667156634418, 
              c[ 4][ t]], 
            Times[ 0.50455115242710469, 
              c[ 5][ t]], 
            Times[ 0.59356153372868059, 
              c[ 6][ t]], 
            Times[ 0.67835603854706339, 
              c[ 7][ t]], 
            Times[ 0.75682672864065703, 
              c[ 8][ t]], 
            Times[ 0.82699334313268813, 
              c[ 9][ t]], 
            Times[ 0.88706379305918381, 
              c[ 10][ t]], 
            Times[ 0.93548928378863916, 
              c[ 11][ t]], 
            Times[ 0.9710122092317629, 
              c[ 12][ t]], 
            Times[ 0.99270519960720693, 
              c[ 13][ t]], 
            Times[ 5.2987610280300306, 
              c[ 14][ t]], 
            Times[ 0.99270519960720671, 
              c[ 15][ t]], 
            Times[ 0.9710122092317629, 
              c[ 16][ t]], 
            Times[ 0.93548928378863916, 
              c[ 17][ t]], 
            Times[ 0.88706379305918381, 
              c[ 18][ t]], 
            Times[ 0.82699334313268813, 
              c[ 19][ t]], 
            Times[ 0.75682672864065692, 
              c[ 20][ t]], 
            Times[ 0.67835603854706317, 
              c[ 21][ t]], 
            Times[ 0.59356153372868059, 
              c[ 22][ t]], 
            Times[ 0.50455115242710469, 
              c[ 23][ t]], 
            Times[ 0.41349667156634395, 
              c[ 24][ t]], 
            Times[ 0.32256865202152157, 
              c[ 25][ t]], 
            Times[ 0.23387232094715985, 
              c[ 26][ t]], 
            Times[ 0.14938649372796345, 
              c[ 27][ t]], 
            Times[ 0.070907514257657775, 
              c[ 28][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 29][ t]], 
            Times[ -0.062044074975450475, 
              c[ 30][ t]], 
            Times[ -0.11423673049785436, 
              c[ 31][ t]], 
            Times[ -0.15591488063143982, 
              c[ 32][ t]], 
            Times[ -0.18675027222298607, 
              c[ 33][ t]], 
            Times[ -0.206748335783172, 
              c[ 34][ t]], 
            Times[ -0.21623620818304484, 
              c[ 35][ t]], 
            Times[ -0.21584055771952013, 
              c[ 36][ t]], 
            Times[ -0.20645618564475843, 
              c[ 37][ t]], 
            Times[ -0.18920668216016426, 
              c[ 38][ t]], 
            Times[ -0.1653986686265376, 
              c[ 39][ t]], 
            Times[ -0.13647135277833605, 
              c[ 40][ t]], 
            Times[ -0.1039432537542934, 
              c[ 41][ t]], 
            Times[ -0.069358014945125918, 
              c[ 42][ t]], 
            Times[ -0.034231213779558949, 
              c[ 43][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 44][ t]], 
            Times[ 0.032022748374426029, 
              c[ 45][ t]], 
            Times[ 0.060688263076985105, 
              c[ 46][ t]], 
            Times[ 0.085044480344421608, 
              c[ 47][ t]], 
            Times[ 0.10436044624225692, 
              c[ 48][ t]], 
            Times[ 0.11814190616181255, 
              c[ 49][ t]], 
            Times[ 0.12613778810677612, 
              c[ 50][ t]], 
            Times[ 0.12833762891430925, 
              c[ 51][ t]], 
            Times[ 0.12496032289024853, 
              c[ 52][ t]], 
            Times[ 0.11643488132933186, 
              c[ 53][ t]], 
            Times[ 0.10337416789158595, 
              c[ 54][ t]], 
            Times[ 0.086542809078944891, 
              c[ 55][ t]], 
            Times[ 0.066820663127759972, 
              c[ 56][ t]], 
            Times[ 0.045163358568919114, 
              c[ 57][ t]], 
            Times[ 0.022561481809254869, 
              c[ 58][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 59][ t]], 
            Times[ -0.021580547817548056, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "15", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[15]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(3.898171832519376`*^-17\ \(c[\(-60\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-59\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-58\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-57\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-56\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-55\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-54\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-53\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-52\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-51\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-50\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-49\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-48\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-47\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-46\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-45\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-44\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-43\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-42\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-41\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-40\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-39\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-38\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-37\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-36\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-35\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-34\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-33\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-32\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-31\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-30\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-29\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-28\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-27\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-26\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-25\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-24\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-23\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-22\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-21\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-20\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-19\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-18\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-17\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-16\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-15\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-14\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-13\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-12\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-11\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-10\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-9\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-8\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-7\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-6\)]\)[t] - 
            0.206748335783172`\ \(c[\(-5\)]\)[t] - 
            0.186750272222986`\ \(c[\(-4\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-3\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-2\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-1\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[0]\)[t] + 
            0.07090751425765762`\ \(c[1]\)[t] + 
            0.14938649372796362`\ \(c[2]\)[t] + 
            0.23387232094715985`\ \(c[3]\)[t] + 
            0.32256865202152135`\ \(c[4]\)[t] + 
            0.41349667156634395`\ \(c[5]\)[t] + 
            0.5045511524271047`\ \(c[6]\)[t] + 
            0.5935615337286803`\ \(c[7]\)[t] + 
            0.6783560385470633`\ \(c[8]\)[t] + 
            0.7568267286406569`\ \(c[9]\)[t] + 
            0.8269933431326881`\ \(c[10]\)[t] + 
            0.8870637930591838`\ \(c[11]\)[t] + 
            0.9354892837886392`\ \(c[12]\)[t] + 
            0.9710122092317629`\ \(c[13]\)[t] + 
            0.9927051996072067`\ \(c[14]\)[t] + 
            5.934802200544679`\ \(c[15]\)[t] + 
            0.9927051996072069`\ \(c[16]\)[t] + 
            0.9710122092317629`\ \(c[17]\)[t] + 
            0.9354892837886392`\ \(c[18]\)[t] + 
            0.8870637930591838`\ \(c[19]\)[t] + 
            0.8269933431326881`\ \(c[20]\)[t] + 
            0.7568267286406569`\ \(c[21]\)[t] + 
            0.6783560385470636`\ \(c[22]\)[t] + 
            0.5935615337286806`\ \(c[23]\)[t] + 
            0.5045511524271047`\ \(c[24]\)[t] + 
            0.4134966715663443`\ \(c[25]\)[t] + 
            0.3225686520215216`\ \(c[26]\)[t] + 
            0.23387232094715985`\ \(c[27]\)[t] + 
            0.14938649372796384`\ \(c[28]\)[t] + 
            0.07090751425765777`\ \(c[29]\)[t] + 
            3.898171832519376`*^-17\ \(c[30]\)[t] - 
            0.06204407497545024`\ \(c[31]\)[t] - 
            0.11423673049785436`\ \(c[32]\)[t] - 
            0.15591488063143982`\ \(c[33]\)[t] - 
            0.18675027222298593`\ \(c[34]\)[t] - 
            0.206748335783172`\ \(c[35]\)[t] - 
            0.21623620818304484`\ \(c[36]\)[t] - 
            0.21584055771952015`\ \(c[37]\)[t] - 
            0.20645618564475843`\ \(c[38]\)[t] - 
            0.18920668216016426`\ \(c[39]\)[t] - 
            0.1653986686265377`\ \(c[40]\)[t] - 
            0.13647135277833616`\ \(c[41]\)[t] - 
            0.10394325375429328`\ \(c[42]\)[t] - 
            0.06935801494512607`\ \(c[43]\)[t] - 
            0.034231213779559094`\ \(c[44]\)[t] - 
            3.898171832519376`*^-17\ \(c[45]\)[t] + 
            0.032022748374425904`\ \(c[46]\)[t] + 
            0.060688263076985`\ \(c[47]\)[t] + 
            0.0850444803444217`\ \(c[48]\)[t] + 
            0.10436044624225685`\ \(c[49]\)[t] + 
            0.11814190616181253`\ \(c[50]\)[t] + 
            0.12613778810677614`\ \(c[51]\)[t] + 
            0.12833762891430928`\ \(c[52]\)[t] + 
            0.12496032289024853`\ \(c[53]\)[t] + 
            0.11643488132933186`\ \(c[54]\)[t] + 
            0.10337416789158609`\ \(c[55]\)[t] + 
            0.08654280907894489`\ \(c[56]\)[t] + 
            0.06682066312775997`\ \(c[57]\)[t] + 
            0.0451633585689193`\ \(c[58]\)[t] + 
            0.02256148180925487`\ \(c[59]\)[t] + 
            3.8981718325193755`*^-17\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 15, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 15]][ t]], 
          Plus[ 
            Times[ 3.8981718325193761*^-17, 
              c[ -60][ t]], 
            Times[ 0.013414935129827233, 
              c[ -59][ t]], 
            Times[ 0.026603074225527826, 
              c[ -58][ t]], 
            Times[ 0.03897872015785999, 
              c[ -57][ t]], 
            Times[ 0.049975424961080865, 
              c[ -56][ t]], 
            Times[ 0.059070953080906326, 
              c[ -55][ t]], 
            Times[ 0.065811019881796273, 
              c[ -54][ t]], 
            Times[ 0.069830768673962415, 
              c[ -53][ t]], 
            Times[ 0.070873018952678238, 
              c[ -52][ t]], 
            Times[ 0.068802429876423349, 
              c[ -51][ t]], 
            Times[ 0.063614872548668253, 
              c[ -50][ t]], 
            Times[ 0.055441487066198933, 
              c[ -49][ t]], 
            Times[ 0.044547108751839919, 
              c[ -48][ t]], 
            Times[ 0.031322974491347078, 
              c[ -47][ t]], 
            Times[ 0.016273855731265604, 
              c[ -46][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -45][ t]], 
            Times[ -0.016825511857749401, 
              c[ -44][ t]], 
            Times[ -0.033483179628681567, 
              c[ -43][ t]], 
            Times[ -0.049236278094138941, 
              c[ -42][ t]], 
            Times[ -0.063361699504227528, 
              c[ -41][ t]], 
            Times[ -0.075181213012062598, 
              c[ -40][ t]], 
            Times[ -0.084091858737850814, 
              c[ -39][ t]], 
            Times[ -0.089594193770366884, 
              c[ -38][ t]], 
            Times[ -0.091317159035181589, 
              c[ -37][ t]], 
            Times[ -0.089038438663606695, 
              c[ -36][ t]], 
            Times[ -0.082699334313268744, 
              c[ -35][ t]], 
            Times[ -0.072413370861974122, 
              c[ -34][ t]], 
            Times[ -0.058468080236789913, 
              c[ -33][ t]], 
            Times[ -0.04131966847794722, 
              c[ -32][ t]], 
            Times[ -0.021580547817547879, 
              c[ -31][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -30][ t]], 
            Times[ 0.022561481809254869, 
              c[ -29][ t]], 
            Times[ 0.045163358568919301, 
              c[ -28][ t]], 
            Times[ 0.066820663127759972, 
              c[ -27][ t]], 
            Times[ 0.086542809078944891, 
              c[ -26][ t]], 
            Times[ 0.10337416789158609, 
              c[ -25][ t]], 
            Times[ 0.11643488132933186, 
              c[ -24][ t]], 
            Times[ 0.12496032289024853, 
              c[ -23][ t]], 
            Times[ 0.12833762891430928, 
              c[ -22][ t]], 
            Times[ 0.12613778810677614, 
              c[ -21][ t]], 
            Times[ 0.11814190616181255, 
              c[ -20][ t]], 
            Times[ 0.10436044624225685, 
              c[ -19][ t]], 
            Times[ 0.085044480344421705, 
              c[ -18][ t]], 
            Times[ 0.060688263076985105, 
              c[ -17][ t]], 
            Times[ 0.032022748374425904, 
              c[ -16][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -15][ t]], 
            Times[ -0.034231213779558949, 
              c[ -14][ t]], 
            Times[ -0.06935801494512607, 
              c[ -13][ t]], 
            Times[ -0.10394325375429328, 
              c[ -12][ t]], 
            Times[ -0.13647135277833605, 
              c[ -11][ t]], 
            Times[ -0.16539866862653771, 
              c[ -10][ t]], 
            Times[ -0.18920668216016426, 
              c[ -9][ t]], 
            Times[ -0.20645618564475843, 
              c[ -8][ t]], 
            Times[ -0.21584055771952015, 
              c[ -7][ t]], 
            Times[ -0.21623620818304484, 
              c[ -6][ t]], 
            Times[ -0.206748335783172, 
              c[ -5][ t]], 
            Times[ -0.18675027222298601, 
              c[ -4][ t]], 
            Times[ -0.15591488063143982, 
              c[ -3][ t]], 
            Times[ -0.11423673049785445, 
              c[ -2][ t]], 
            Times[ -0.062044074975450343, 
              c[ -1][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 0][ t]], 
            Times[ 0.070907514257657622, 
              c[ 1][ t]], 
            Times[ 0.14938649372796362, 
              c[ 2][ t]], 
            Times[ 0.23387232094715985, 
              c[ 3][ t]], 
            Times[ 0.32256865202152135, 
              c[ 4][ t]], 
            Times[ 0.41349667156634395, 
              c[ 5][ t]], 
            Times[ 0.50455115242710469, 
              c[ 6][ t]], 
            Times[ 0.59356153372868026, 
              c[ 7][ t]], 
            Times[ 0.67835603854706328, 
              c[ 8][ t]], 
            Times[ 0.75682672864065692, 
              c[ 9][ t]], 
            Times[ 0.82699334313268813, 
              c[ 10][ t]], 
            Times[ 0.88706379305918381, 
              c[ 11][ t]], 
            Times[ 0.93548928378863916, 
              c[ 12][ t]], 
            Times[ 0.9710122092317629, 
              c[ 13][ t]], 
            Times[ 0.99270519960720671, 
              c[ 14][ t]], 
            Times[ 5.934802200544679, 
              c[ 15][ t]], 
            Times[ 0.99270519960720693, 
              c[ 16][ t]], 
            Times[ 0.9710122092317629, 
              c[ 17][ t]], 
            Times[ 0.93548928378863916, 
              c[ 18][ t]], 
            Times[ 0.88706379305918381, 
              c[ 19][ t]], 
            Times[ 0.82699334313268813, 
              c[ 20][ t]], 
            Times[ 0.75682672864065692, 
              c[ 21][ t]], 
            Times[ 0.67835603854706361, 
              c[ 22][ t]], 
            Times[ 0.59356153372868059, 
              c[ 23][ t]], 
            Times[ 0.50455115242710469, 
              c[ 24][ t]], 
            Times[ 0.41349667156634429, 
              c[ 25][ t]], 
            Times[ 0.32256865202152157, 
              c[ 26][ t]], 
            Times[ 0.23387232094715985, 
              c[ 27][ t]], 
            Times[ 0.14938649372796384, 
              c[ 28][ t]], 
            Times[ 0.070907514257657775, 
              c[ 29][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 30][ t]], 
            Times[ -0.062044074975450239, 
              c[ 31][ t]], 
            Times[ -0.11423673049785436, 
              c[ 32][ t]], 
            Times[ -0.15591488063143982, 
              c[ 33][ t]], 
            Times[ -0.18675027222298593, 
              c[ 34][ t]], 
            Times[ -0.206748335783172, 
              c[ 35][ t]], 
            Times[ -0.21623620818304484, 
              c[ 36][ t]], 
            Times[ -0.21584055771952015, 
              c[ 37][ t]], 
            Times[ -0.20645618564475843, 
              c[ 38][ t]], 
            Times[ -0.18920668216016426, 
              c[ 39][ t]], 
            Times[ -0.16539866862653771, 
              c[ 40][ t]], 
            Times[ -0.13647135277833616, 
              c[ 41][ t]], 
            Times[ -0.10394325375429328, 
              c[ 42][ t]], 
            Times[ -0.06935801494512607, 
              c[ 43][ t]], 
            Times[ -0.034231213779559094, 
              c[ 44][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 45][ t]], 
            Times[ 0.032022748374425904, 
              c[ 46][ t]], 
            Times[ 0.060688263076985001, 
              c[ 47][ t]], 
            Times[ 0.085044480344421705, 
              c[ 48][ t]], 
            Times[ 0.10436044624225685, 
              c[ 49][ t]], 
            Times[ 0.11814190616181253, 
              c[ 50][ t]], 
            Times[ 0.12613778810677614, 
              c[ 51][ t]], 
            Times[ 0.12833762891430928, 
              c[ 52][ t]], 
            Times[ 0.12496032289024853, 
              c[ 53][ t]], 
            Times[ 0.11643488132933186, 
              c[ 54][ t]], 
            Times[ 0.10337416789158609, 
              c[ 55][ t]], 
            Times[ 0.086542809078944891, 
              c[ 56][ t]], 
            Times[ 0.066820663127759972, 
              c[ 57][ t]], 
            Times[ 0.045163358568919301, 
              c[ 58][ t]], 
            Times[ 0.022561481809254869, 
              c[ 59][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "16", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[16]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.013061910521147383`\)\ \(c[\(-60\)]\)[t] + 
            1.5206810699945212`*^-16\ \(c[\(-59\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-58\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-57\)]\)[t] + 
            0.03897872015786009`\ \(c[\(-56\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-55\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-54\)]\)[t] + 
            0.06581101988179631`\ \(c[\(-53\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-52\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-51\)]\)[t] + 
            0.06880242987642332`\ \(c[\(-50\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-49\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-48\)]\)[t] + 
            0.044547108751839815`\ \(c[\(-47\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-46\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-45\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-44\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-43\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-42\)]\)[t] - 
            0.049236278094139066`\ \(c[\(-41\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-40\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-39\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-38\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-37\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-36\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-35\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-34\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-33\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-32\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-31\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-30\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-29\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-28\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-27\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-26\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-25\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-24\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-23\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-22\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-21\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-20\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-19\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-18\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-17\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-16\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-15\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-14\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-13\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-12\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-11\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-10\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-9\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-8\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-7\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-6\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-5\)]\)[t] - 
            0.206748335783172`\ \(c[\(-4\)]\)[t] - 
            0.186750272222986`\ \(c[\(-3\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-2\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-1\)]\)[t] - 
            0.06204407497545034`\ \(c[0]\)[t] + 
            3.898171832519376`*^-17\ \(c[1]\)[t] + 
            0.07090751425765777`\ \(c[2]\)[t] + 
            0.14938649372796362`\ \(c[3]\)[t] + 
            0.23387232094715985`\ \(c[4]\)[t] + 
            0.3225686520215216`\ \(c[5]\)[t] + 
            0.4134966715663442`\ \(c[6]\)[t] + 
            0.5045511524271047`\ \(c[7]\)[t] + 
            0.5935615337286805`\ \(c[8]\)[t] + 
            0.6783560385470634`\ \(c[9]\)[t] + 
            0.7568267286406569`\ \(c[10]\)[t] + 
            0.8269933431326881`\ \(c[11]\)[t] + 
            0.8870637930591838`\ \(c[12]\)[t] + 
            0.9354892837886392`\ \(c[13]\)[t] + 
            0.9710122092317629`\ \(c[14]\)[t] + 
            0.9927051996072069`\ \(c[15]\)[t] + 
            6.614708281508612`\ \(c[16]\)[t] + 
            0.9927051996072069`\ \(c[17]\)[t] + 
            0.9710122092317629`\ \(c[18]\)[t] + 
            0.9354892837886392`\ \(c[19]\)[t] + 
            0.8870637930591838`\ \(c[20]\)[t] + 
            0.8269933431326881`\ \(c[21]\)[t] + 
            0.7568267286406571`\ \(c[22]\)[t] + 
            0.6783560385470634`\ \(c[23]\)[t] + 
            0.5935615337286803`\ \(c[24]\)[t] + 
            0.5045511524271049`\ \(c[25]\)[t] + 
            0.4134966715663442`\ \(c[26]\)[t] + 
            0.32256865202152135`\ \(c[27]\)[t] + 
            0.23387232094715998`\ \(c[28]\)[t] + 
            0.14938649372796362`\ \(c[29]\)[t] + 
            0.07090751425765762`\ \(c[30]\)[t] + 
            1.8033970416801674`*^-16\ \(c[31]\)[t] - 
            0.06204407497545034`\ \(c[32]\)[t] - 
            0.11423673049785445`\ \(c[33]\)[t] - 
            0.15591488063143974`\ \(c[34]\)[t] - 
            0.186750272222986`\ \(c[35]\)[t] - 
            0.20674833578317206`\ \(c[36]\)[t] - 
            0.21623620818304484`\ \(c[37]\)[t] - 
            0.21584055771952015`\ \(c[38]\)[t] - 
            0.20645618564475834`\ \(c[39]\)[t] - 
            0.18920668216016426`\ \(c[40]\)[t] - 
            0.1653986686265377`\ \(c[41]\)[t] - 
            0.1364713527783359`\ \(c[42]\)[t] - 
            0.10394325375429328`\ \(c[43]\)[t] - 
            0.06935801494512607`\ \(c[44]\)[t] - 
            0.034231213779558796`\ \(c[45]\)[t] - 
            3.898171832519376`*^-17\ \(c[46]\)[t] + 
            0.032022748374425904`\ \(c[47]\)[t] + 
            0.06068826307698522`\ \(c[48]\)[t] + 
            0.0850444803444217`\ \(c[49]\)[t] + 
            0.10436044624225685`\ \(c[50]\)[t] + 
            0.1181419061618126`\ \(c[51]\)[t] + 
            0.12613778810677614`\ \(c[52]\)[t] + 
            0.12833762891430928`\ \(c[53]\)[t] + 
            0.12496032289024847`\ \(c[54]\)[t] + 
            0.11643488132933186`\ \(c[55]\)[t] + 
            0.10337416789158609`\ \(c[56]\)[t] + 
            0.08654280907894475`\ \(c[57]\)[t] + 
            0.06682066312775997`\ \(c[58]\)[t] + 
            0.0451633585689193`\ \(c[59]\)[t] + 
            0.022561481809254675`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 16, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 16]][ t]], 
          Plus[ 
            Times[ -0.013061910521147383, 
              c[ -60][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ -59][ t]], 
            Times[ 0.013414935129827233, 
              c[ -58][ t]], 
            Times[ 0.026603074225527826, 
              c[ -57][ t]], 
            Times[ 0.038978720157860088, 
              c[ -56][ t]], 
            Times[ 0.049975424961080865, 
              c[ -55][ t]], 
            Times[ 0.059070953080906326, 
              c[ -54][ t]], 
            Times[ 0.065811019881796315, 
              c[ -53][ t]], 
            Times[ 0.069830768673962415, 
              c[ -52][ t]], 
            Times[ 0.070873018952678238, 
              c[ -51][ t]], 
            Times[ 0.068802429876423321, 
              c[ -50][ t]], 
            Times[ 0.063614872548668253, 
              c[ -49][ t]], 
            Times[ 0.055441487066198933, 
              c[ -48][ t]], 
            Times[ 0.044547108751839815, 
              c[ -47][ t]], 
            Times[ 0.031322974491347078, 
              c[ -46][ t]], 
            Times[ 0.016273855731265604, 
              c[ -45][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -44][ t]], 
            Times[ -0.016825511857749401, 
              c[ -43][ t]], 
            Times[ -0.033483179628681567, 
              c[ -42][ t]], 
            Times[ -0.049236278094139066, 
              c[ -41][ t]], 
            Times[ -0.063361699504227528, 
              c[ -40][ t]], 
            Times[ -0.075181213012062598, 
              c[ -39][ t]], 
            Times[ -0.084091858737850814, 
              c[ -38][ t]], 
            Times[ -0.089594193770366884, 
              c[ -37][ t]], 
            Times[ -0.091317159035181589, 
              c[ -36][ t]], 
            Times[ -0.089038438663606695, 
              c[ -35][ t]], 
            Times[ -0.082699334313268744, 
              c[ -34][ t]], 
            Times[ -0.072413370861974122, 
              c[ -33][ t]], 
            Times[ -0.058468080236789913, 
              c[ -32][ t]], 
            Times[ -0.04131966847794722, 
              c[ -31][ t]], 
            Times[ -0.021580547817547879, 
              c[ -30][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -29][ t]], 
            Times[ 0.022561481809254869, 
              c[ -28][ t]], 
            Times[ 0.045163358568919301, 
              c[ -27][ t]], 
            Times[ 0.066820663127759972, 
              c[ -26][ t]], 
            Times[ 0.086542809078944891, 
              c[ -25][ t]], 
            Times[ 0.10337416789158609, 
              c[ -24][ t]], 
            Times[ 0.11643488132933186, 
              c[ -23][ t]], 
            Times[ 0.12496032289024853, 
              c[ -22][ t]], 
            Times[ 0.12833762891430928, 
              c[ -21][ t]], 
            Times[ 0.12613778810677614, 
              c[ -20][ t]], 
            Times[ 0.11814190616181255, 
              c[ -19][ t]], 
            Times[ 0.10436044624225685, 
              c[ -18][ t]], 
            Times[ 0.085044480344421705, 
              c[ -17][ t]], 
            Times[ 0.060688263076985105, 
              c[ -16][ t]], 
            Times[ 0.032022748374425904, 
              c[ -15][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -14][ t]], 
            Times[ -0.034231213779558949, 
              c[ -13][ t]], 
            Times[ -0.06935801494512607, 
              c[ -12][ t]], 
            Times[ -0.10394325375429328, 
              c[ -11][ t]], 
            Times[ -0.13647135277833605, 
              c[ -10][ t]], 
            Times[ -0.16539866862653771, 
              c[ -9][ t]], 
            Times[ -0.18920668216016426, 
              c[ -8][ t]], 
            Times[ -0.20645618564475843, 
              c[ -7][ t]], 
            Times[ -0.21584055771952015, 
              c[ -6][ t]], 
            Times[ -0.21623620818304484, 
              c[ -5][ t]], 
            Times[ -0.206748335783172, 
              c[ -4][ t]], 
            Times[ -0.18675027222298601, 
              c[ -3][ t]], 
            Times[ -0.15591488063143982, 
              c[ -2][ t]], 
            Times[ -0.11423673049785436, 
              c[ -1][ t]], 
            Times[ -0.062044074975450343, 
              c[ 0][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 1][ t]], 
            Times[ 0.070907514257657775, 
              c[ 2][ t]], 
            Times[ 0.14938649372796362, 
              c[ 3][ t]], 
            Times[ 0.23387232094715985, 
              c[ 4][ t]], 
            Times[ 0.32256865202152157, 
              c[ 5][ t]], 
            Times[ 0.41349667156634418, 
              c[ 6][ t]], 
            Times[ 0.50455115242710469, 
              c[ 7][ t]], 
            Times[ 0.59356153372868048, 
              c[ 8][ t]], 
            Times[ 0.67835603854706339, 
              c[ 9][ t]], 
            Times[ 0.75682672864065692, 
              c[ 10][ t]], 
            Times[ 0.82699334313268813, 
              c[ 11][ t]], 
            Times[ 0.88706379305918381, 
              c[ 12][ t]], 
            Times[ 0.93548928378863916, 
              c[ 13][ t]], 
            Times[ 0.9710122092317629, 
              c[ 14][ t]], 
            Times[ 0.99270519960720693, 
              c[ 15][ t]], 
            Times[ 6.6147082815086122, 
              c[ 16][ t]], 
            Times[ 0.99270519960720693, 
              c[ 17][ t]], 
            Times[ 0.9710122092317629, 
              c[ 18][ t]], 
            Times[ 0.93548928378863916, 
              c[ 19][ t]], 
            Times[ 0.88706379305918381, 
              c[ 20][ t]], 
            Times[ 0.82699334313268813, 
              c[ 21][ t]], 
            Times[ 0.75682672864065714, 
              c[ 22][ t]], 
            Times[ 0.67835603854706339, 
              c[ 23][ t]], 
            Times[ 0.59356153372868026, 
              c[ 24][ t]], 
            Times[ 0.50455115242710491, 
              c[ 25][ t]], 
            Times[ 0.41349667156634418, 
              c[ 26][ t]], 
            Times[ 0.32256865202152135, 
              c[ 27][ t]], 
            Times[ 0.23387232094715998, 
              c[ 28][ t]], 
            Times[ 0.14938649372796362, 
              c[ 29][ t]], 
            Times[ 0.070907514257657622, 
              c[ 30][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 31][ t]], 
            Times[ -0.062044074975450343, 
              c[ 32][ t]], 
            Times[ -0.11423673049785445, 
              c[ 33][ t]], 
            Times[ -0.15591488063143974, 
              c[ 34][ t]], 
            Times[ -0.18675027222298601, 
              c[ 35][ t]], 
            Times[ -0.20674833578317206, 
              c[ 36][ t]], 
            Times[ -0.21623620818304484, 
              c[ 37][ t]], 
            Times[ -0.21584055771952015, 
              c[ 38][ t]], 
            Times[ -0.20645618564475834, 
              c[ 39][ t]], 
            Times[ -0.18920668216016426, 
              c[ 40][ t]], 
            Times[ -0.16539866862653771, 
              c[ 41][ t]], 
            Times[ -0.13647135277833591, 
              c[ 42][ t]], 
            Times[ -0.10394325375429328, 
              c[ 43][ t]], 
            Times[ -0.06935801494512607, 
              c[ 44][ t]], 
            Times[ -0.034231213779558796, 
              c[ 45][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 46][ t]], 
            Times[ 0.032022748374425904, 
              c[ 47][ t]], 
            Times[ 0.060688263076985223, 
              c[ 48][ t]], 
            Times[ 0.085044480344421705, 
              c[ 49][ t]], 
            Times[ 0.10436044624225685, 
              c[ 50][ t]], 
            Times[ 0.1181419061618126, 
              c[ 51][ t]], 
            Times[ 0.12613778810677614, 
              c[ 52][ t]], 
            Times[ 0.12833762891430928, 
              c[ 53][ t]], 
            Times[ 0.12496032289024847, 
              c[ 54][ t]], 
            Times[ 0.11643488132933186, 
              c[ 55][ t]], 
            Times[ 0.10337416789158609, 
              c[ 56][ t]], 
            Times[ 0.086542809078944752, 
              c[ 57][ t]], 
            Times[ 0.066820663127759972, 
              c[ 58][ t]], 
            Times[ 0.045163358568919301, 
              c[ 59][ t]], 
            Times[ 0.022561481809254675, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "17", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[17]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.025221096343682053`\)\ \(c[\(-60\)]\)[t] - 
            0.013061910521147276`\ \(c[\(-59\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-58\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-57\)]\)[t] + 
            0.026603074225527937`\ \(c[\(-56\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-55\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-54\)]\)[t] + 
            0.0590709530809064`\ \(c[\(-53\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-52\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-51\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-50\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-49\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-48\)]\)[t] + 
            0.055441487066198857`\ \(c[\(-47\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-46\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-45\)]\)[t] + 
            0.01627385573126547`\ \(c[\(-44\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-43\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-42\)]\)[t] - 
            0.033483179628681706`\ \(c[\(-41\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-40\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-39\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-38\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-37\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-36\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-35\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-34\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-33\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-32\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-31\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-30\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-29\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-28\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-27\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-26\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-25\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-24\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-23\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-22\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-21\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-20\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-19\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-18\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-17\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-16\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-15\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-14\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-13\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-12\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-11\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-10\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-9\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-8\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-7\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-6\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-5\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-4\)]\)[t] - 
            0.206748335783172`\ \(c[\(-3\)]\)[t] - 
            0.186750272222986`\ \(c[\(-2\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-1\)]\)[t] - 
            0.11423673049785436`\ \(c[0]\)[t] - 
            0.06204407497545034`\ \(c[1]\)[t] + 
            1.8033970416801674`*^-16\ \(c[2]\)[t] + 
            0.07090751425765777`\ \(c[3]\)[t] + 
            0.14938649372796362`\ \(c[4]\)[t] + 
            0.23387232094715985`\ \(c[5]\)[t] + 
            0.3225686520215216`\ \(c[6]\)[t] + 
            0.4134966715663442`\ \(c[7]\)[t] + 
            0.5045511524271047`\ \(c[8]\)[t] + 
            0.5935615337286806`\ \(c[9]\)[t] + 
            0.6783560385470634`\ \(c[10]\)[t] + 
            0.7568267286406569`\ \(c[11]\)[t] + 
            0.8269933431326881`\ \(c[12]\)[t] + 
            0.8870637930591838`\ \(c[13]\)[t] + 
            0.9354892837886392`\ \(c[14]\)[t] + 
            0.9710122092317629`\ \(c[15]\)[t] + 
            0.9927051996072069`\ \(c[16]\)[t] + 
            7.338479270921831`\ \(c[17]\)[t] + 
            0.9927051996072067`\ \(c[18]\)[t] + 
            0.9710122092317629`\ \(c[19]\)[t] + 
            0.9354892837886392`\ \(c[20]\)[t] + 
            0.8870637930591838`\ \(c[21]\)[t] + 
            0.8269933431326881`\ \(c[22]\)[t] + 
            0.7568267286406569`\ \(c[23]\)[t] + 
            0.6783560385470632`\ \(c[24]\)[t] + 
            0.5935615337286806`\ \(c[25]\)[t] + 
            0.5045511524271047`\ \(c[26]\)[t] + 
            0.41349667156634395`\ \(c[27]\)[t] + 
            0.3225686520215216`\ \(c[28]\)[t] + 
            0.23387232094715985`\ \(c[29]\)[t] + 
            0.14938649372796345`\ \(c[30]\)[t] + 
            0.07090751425765777`\ \(c[31]\)[t] + 
            3.898171832519376`*^-17\ \(c[32]\)[t] - 
            0.062044074975450475`\ \(c[33]\)[t] - 
            0.11423673049785436`\ \(c[34]\)[t] - 
            0.15591488063143982`\ \(c[35]\)[t] - 
            0.18675027222298607`\ \(c[36]\)[t] - 
            0.206748335783172`\ \(c[37]\)[t] - 
            0.21623620818304484`\ \(c[38]\)[t] - 
            0.21584055771952013`\ \(c[39]\)[t] - 
            0.20645618564475843`\ \(c[40]\)[t] - 
            0.18920668216016434`\ \(c[41]\)[t] - 
            0.1653986686265376`\ \(c[42]\)[t] - 
            0.13647135277833605`\ \(c[43]\)[t] - 
            0.1039432537542934`\ \(c[44]\)[t] - 
            0.06935801494512592`\ \(c[45]\)[t] - 
            0.03423121377955895`\ \(c[46]\)[t] - 
            1.8033970416801674`*^-16\ \(c[47]\)[t] + 
            0.03202274837442603`\ \(c[48]\)[t] + 
            0.060688263076985105`\ \(c[49]\)[t] + 
            0.08504448034442161`\ \(c[50]\)[t] + 
            0.10436044624225692`\ \(c[51]\)[t] + 
            0.11814190616181255`\ \(c[52]\)[t] + 
            0.12613778810677612`\ \(c[53]\)[t] + 
            0.12833762891430925`\ \(c[54]\)[t] + 
            0.12496032289024853`\ \(c[55]\)[t] + 
            0.11643488132933186`\ \(c[56]\)[t] + 
            0.10337416789158595`\ \(c[57]\)[t] + 
            0.08654280907894489`\ \(c[58]\)[t] + 
            0.06682066312775997`\ \(c[59]\)[t] + 
            0.045163358568919114`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 17, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 17]][ t]], 
          Plus[ 
            Times[ -0.025221096343682053, 
              c[ -60][ t]], 
            Times[ -0.013061910521147276, 
              c[ -59][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -58][ t]], 
            Times[ 0.013414935129827233, 
              c[ -57][ t]], 
            Times[ 0.026603074225527937, 
              c[ -56][ t]], 
            Times[ 0.03897872015785999, 
              c[ -55][ t]], 
            Times[ 0.049975424961080865, 
              c[ -54][ t]], 
            Times[ 0.059070953080906402, 
              c[ -53][ t]], 
            Times[ 0.065811019881796273, 
              c[ -52][ t]], 
            Times[ 0.069830768673962415, 
              c[ -51][ t]], 
            Times[ 0.070873018952678238, 
              c[ -50][ t]], 
            Times[ 0.068802429876423349, 
              c[ -49][ t]], 
            Times[ 0.063614872548668253, 
              c[ -48][ t]], 
            Times[ 0.055441487066198857, 
              c[ -47][ t]], 
            Times[ 0.044547108751839919, 
              c[ -46][ t]], 
            Times[ 0.031322974491347078, 
              c[ -45][ t]], 
            Times[ 0.016273855731265469, 
              c[ -44][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -43][ t]], 
            Times[ -0.016825511857749401, 
              c[ -42][ t]], 
            Times[ -0.033483179628681706, 
              c[ -41][ t]], 
            Times[ -0.049236278094138941, 
              c[ -40][ t]], 
            Times[ -0.063361699504227528, 
              c[ -39][ t]], 
            Times[ -0.075181213012062598, 
              c[ -38][ t]], 
            Times[ -0.084091858737850814, 
              c[ -37][ t]], 
            Times[ -0.089594193770366884, 
              c[ -36][ t]], 
            Times[ -0.091317159035181589, 
              c[ -35][ t]], 
            Times[ -0.089038438663606695, 
              c[ -34][ t]], 
            Times[ -0.082699334313268744, 
              c[ -33][ t]], 
            Times[ -0.072413370861974122, 
              c[ -32][ t]], 
            Times[ -0.058468080236789913, 
              c[ -31][ t]], 
            Times[ -0.04131966847794722, 
              c[ -30][ t]], 
            Times[ -0.021580547817547879, 
              c[ -29][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -28][ t]], 
            Times[ 0.022561481809254869, 
              c[ -27][ t]], 
            Times[ 0.045163358568919301, 
              c[ -26][ t]], 
            Times[ 0.066820663127759972, 
              c[ -25][ t]], 
            Times[ 0.086542809078944891, 
              c[ -24][ t]], 
            Times[ 0.10337416789158609, 
              c[ -23][ t]], 
            Times[ 0.11643488132933186, 
              c[ -22][ t]], 
            Times[ 0.12496032289024853, 
              c[ -21][ t]], 
            Times[ 0.12833762891430928, 
              c[ -20][ t]], 
            Times[ 0.12613778810677614, 
              c[ -19][ t]], 
            Times[ 0.11814190616181255, 
              c[ -18][ t]], 
            Times[ 0.10436044624225685, 
              c[ -17][ t]], 
            Times[ 0.085044480344421705, 
              c[ -16][ t]], 
            Times[ 0.060688263076985105, 
              c[ -15][ t]], 
            Times[ 0.032022748374425904, 
              c[ -14][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -13][ t]], 
            Times[ -0.034231213779558949, 
              c[ -12][ t]], 
            Times[ -0.06935801494512607, 
              c[ -11][ t]], 
            Times[ -0.10394325375429328, 
              c[ -10][ t]], 
            Times[ -0.13647135277833605, 
              c[ -9][ t]], 
            Times[ -0.16539866862653771, 
              c[ -8][ t]], 
            Times[ -0.18920668216016426, 
              c[ -7][ t]], 
            Times[ -0.20645618564475843, 
              c[ -6][ t]], 
            Times[ -0.21584055771952015, 
              c[ -5][ t]], 
            Times[ -0.21623620818304484, 
              c[ -4][ t]], 
            Times[ -0.206748335783172, 
              c[ -3][ t]], 
            Times[ -0.18675027222298601, 
              c[ -2][ t]], 
            Times[ -0.15591488063143974, 
              c[ -1][ t]], 
            Times[ -0.11423673049785436, 
              c[ 0][ t]], 
            Times[ -0.062044074975450343, 
              c[ 1][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 2][ t]], 
            Times[ 0.070907514257657775, 
              c[ 3][ t]], 
            Times[ 0.14938649372796362, 
              c[ 4][ t]], 
            Times[ 0.23387232094715985, 
              c[ 5][ t]], 
            Times[ 0.32256865202152157, 
              c[ 6][ t]], 
            Times[ 0.41349667156634418, 
              c[ 7][ t]], 
            Times[ 0.50455115242710469, 
              c[ 8][ t]], 
            Times[ 0.59356153372868059, 
              c[ 9][ t]], 
            Times[ 0.67835603854706339, 
              c[ 10][ t]], 
            Times[ 0.75682672864065692, 
              c[ 11][ t]], 
            Times[ 0.82699334313268813, 
              c[ 12][ t]], 
            Times[ 0.88706379305918381, 
              c[ 13][ t]], 
            Times[ 0.93548928378863916, 
              c[ 14][ t]], 
            Times[ 0.9710122092317629, 
              c[ 15][ t]], 
            Times[ 0.99270519960720693, 
              c[ 16][ t]], 
            Times[ 7.3384792709218312, 
              c[ 17][ t]], 
            Times[ 0.99270519960720671, 
              c[ 18][ t]], 
            Times[ 0.9710122092317629, 
              c[ 19][ t]], 
            Times[ 0.93548928378863916, 
              c[ 20][ t]], 
            Times[ 0.88706379305918381, 
              c[ 21][ t]], 
            Times[ 0.82699334313268813, 
              c[ 22][ t]], 
            Times[ 0.75682672864065692, 
              c[ 23][ t]], 
            Times[ 0.67835603854706317, 
              c[ 24][ t]], 
            Times[ 0.59356153372868059, 
              c[ 25][ t]], 
            Times[ 0.50455115242710469, 
              c[ 26][ t]], 
            Times[ 0.41349667156634395, 
              c[ 27][ t]], 
            Times[ 0.32256865202152157, 
              c[ 28][ t]], 
            Times[ 0.23387232094715985, 
              c[ 29][ t]], 
            Times[ 0.14938649372796345, 
              c[ 30][ t]], 
            Times[ 0.070907514257657775, 
              c[ 31][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 32][ t]], 
            Times[ -0.062044074975450475, 
              c[ 33][ t]], 
            Times[ -0.11423673049785436, 
              c[ 34][ t]], 
            Times[ -0.15591488063143982, 
              c[ 35][ t]], 
            Times[ -0.18675027222298607, 
              c[ 36][ t]], 
            Times[ -0.206748335783172, 
              c[ 37][ t]], 
            Times[ -0.21623620818304484, 
              c[ 38][ t]], 
            Times[ -0.21584055771952013, 
              c[ 39][ t]], 
            Times[ -0.20645618564475843, 
              c[ 40][ t]], 
            Times[ -0.18920668216016434, 
              c[ 41][ t]], 
            Times[ -0.1653986686265376, 
              c[ 42][ t]], 
            Times[ -0.13647135277833605, 
              c[ 43][ t]], 
            Times[ -0.1039432537542934, 
              c[ 44][ t]], 
            Times[ -0.069358014945125918, 
              c[ 45][ t]], 
            Times[ -0.034231213779558949, 
              c[ 46][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 47][ t]], 
            Times[ 0.032022748374426029, 
              c[ 48][ t]], 
            Times[ 0.060688263076985105, 
              c[ 49][ t]], 
            Times[ 0.085044480344421608, 
              c[ 50][ t]], 
            Times[ 0.10436044624225692, 
              c[ 51][ t]], 
            Times[ 0.11814190616181255, 
              c[ 52][ t]], 
            Times[ 0.12613778810677612, 
              c[ 53][ t]], 
            Times[ 0.12833762891430925, 
              c[ 54][ t]], 
            Times[ 0.12496032289024853, 
              c[ 55][ t]], 
            Times[ 0.11643488132933186, 
              c[ 56][ t]], 
            Times[ 0.10337416789158595, 
              c[ 57][ t]], 
            Times[ 0.086542809078944891, 
              c[ 58][ t]], 
            Times[ 0.066820663127759972, 
              c[ 59][ t]], 
            Times[ 0.045163358568919114, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "18", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[18]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.03598035706879378`\)\ \(c[\(-60\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-59\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-58\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-57\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-56\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-55\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-54\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-53\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-52\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-51\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-50\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-49\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-48\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-47\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-46\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-45\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-44\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-43\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-42\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-41\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-40\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-39\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-38\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-37\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-36\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-35\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-34\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-33\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-32\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-31\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-30\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-29\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-28\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-27\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-26\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-25\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-24\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-23\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-22\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-21\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-20\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-19\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-18\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-17\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-16\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-15\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-14\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-13\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-12\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-11\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-10\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-9\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-8\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-7\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-6\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-5\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-4\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-3\)]\)[t] - 
            0.206748335783172`\ \(c[\(-2\)]\)[t] - 
            0.186750272222986`\ \(c[\(-1\)]\)[t] - 
            0.15591488063143982`\ \(c[0]\)[t] - 
            0.11423673049785445`\ \(c[1]\)[t] - 
            0.06204407497545034`\ \(c[2]\)[t] + 
            3.898171832519376`*^-17\ \(c[3]\)[t] + 
            0.07090751425765762`\ \(c[4]\)[t] + 
            0.14938649372796345`\ \(c[5]\)[t] + 
            0.23387232094715985`\ \(c[6]\)[t] + 
            0.32256865202152135`\ \(c[7]\)[t] + 
            0.41349667156634395`\ \(c[8]\)[t] + 
            0.5045511524271047`\ \(c[9]\)[t] + 
            0.5935615337286803`\ \(c[10]\)[t] + 
            0.6783560385470632`\ \(c[11]\)[t] + 
            0.7568267286406569`\ \(c[12]\)[t] + 
            0.8269933431326881`\ \(c[13]\)[t] + 
            0.8870637930591838`\ \(c[14]\)[t] + 
            0.9354892837886392`\ \(c[15]\)[t] + 
            0.9710122092317629`\ \(c[16]\)[t] + 
            0.9927051996072067`\ \(c[17]\)[t] + 
            8.106115168784338`\ \(c[18]\)[t] + 
            0.9927051996072069`\ \(c[19]\)[t] + 
            0.9710122092317629`\ \(c[20]\)[t] + 
            0.9354892837886392`\ \(c[21]\)[t] + 
            0.8870637930591839`\ \(c[22]\)[t] + 
            0.8269933431326881`\ \(c[23]\)[t] + 
            0.7568267286406569`\ \(c[24]\)[t] + 
            0.6783560385470636`\ \(c[25]\)[t] + 
            0.5935615337286806`\ \(c[26]\)[t] + 
            0.5045511524271047`\ \(c[27]\)[t] + 
            0.4134966715663443`\ \(c[28]\)[t] + 
            0.3225686520215216`\ \(c[29]\)[t] + 
            0.23387232094715985`\ \(c[30]\)[t] + 
            0.14938649372796384`\ \(c[31]\)[t] + 
            0.07090751425765777`\ \(c[32]\)[t] + 
            3.898171832519376`*^-17\ \(c[33]\)[t] - 
            0.06204407497545024`\ \(c[34]\)[t] - 
            0.11423673049785436`\ \(c[35]\)[t] - 
            0.15591488063143982`\ \(c[36]\)[t] - 
            0.18675027222298593`\ \(c[37]\)[t] - 
            0.206748335783172`\ \(c[38]\)[t] - 
            0.21623620818304484`\ \(c[39]\)[t] - 
            0.21584055771952015`\ \(c[40]\)[t] - 
            0.20645618564475848`\ \(c[41]\)[t] - 
            0.18920668216016426`\ \(c[42]\)[t] - 
            0.1653986686265377`\ \(c[43]\)[t] - 
            0.13647135277833616`\ \(c[44]\)[t] - 
            0.10394325375429328`\ \(c[45]\)[t] - 
            0.06935801494512607`\ \(c[46]\)[t] - 
            0.034231213779559094`\ \(c[47]\)[t] - 
            3.898171832519376`*^-17\ \(c[48]\)[t] + 
            0.032022748374425904`\ \(c[49]\)[t] + 
            0.060688263076985`\ \(c[50]\)[t] + 
            0.0850444803444217`\ \(c[51]\)[t] + 
            0.10436044624225685`\ \(c[52]\)[t] + 
            0.11814190616181253`\ \(c[53]\)[t] + 
            0.12613778810677614`\ \(c[54]\)[t] + 
            0.12833762891430928`\ \(c[55]\)[t] + 
            0.12496032289024853`\ \(c[56]\)[t] + 
            0.11643488132933186`\ \(c[57]\)[t] + 
            0.10337416789158609`\ \(c[58]\)[t] + 
            0.08654280907894489`\ \(c[59]\)[t] + 
            0.06682066312775997`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 18, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 18]][ t]], 
          Plus[ 
            Times[ -0.035980357068793781, 
              c[ -60][ t]], 
            Times[ -0.025221096343682053, 
              c[ -59][ t]], 
            Times[ -0.013061910521147383, 
              c[ -58][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -57][ t]], 
            Times[ 0.013414935129827233, 
              c[ -56][ t]], 
            Times[ 0.026603074225527826, 
              c[ -55][ t]], 
            Times[ 0.03897872015785999, 
              c[ -54][ t]], 
            Times[ 0.049975424961080865, 
              c[ -53][ t]], 
            Times[ 0.059070953080906326, 
              c[ -52][ t]], 
            Times[ 0.065811019881796273, 
              c[ -51][ t]], 
            Times[ 0.069830768673962415, 
              c[ -50][ t]], 
            Times[ 0.070873018952678238, 
              c[ -49][ t]], 
            Times[ 0.068802429876423349, 
              c[ -48][ t]], 
            Times[ 0.063614872548668253, 
              c[ -47][ t]], 
            Times[ 0.055441487066198933, 
              c[ -46][ t]], 
            Times[ 0.044547108751839919, 
              c[ -45][ t]], 
            Times[ 0.031322974491347078, 
              c[ -44][ t]], 
            Times[ 0.016273855731265604, 
              c[ -43][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -42][ t]], 
            Times[ -0.016825511857749401, 
              c[ -41][ t]], 
            Times[ -0.033483179628681567, 
              c[ -40][ t]], 
            Times[ -0.049236278094138941, 
              c[ -39][ t]], 
            Times[ -0.063361699504227528, 
              c[ -38][ t]], 
            Times[ -0.075181213012062598, 
              c[ -37][ t]], 
            Times[ -0.084091858737850814, 
              c[ -36][ t]], 
            Times[ -0.089594193770366884, 
              c[ -35][ t]], 
            Times[ -0.091317159035181589, 
              c[ -34][ t]], 
            Times[ -0.089038438663606695, 
              c[ -33][ t]], 
            Times[ -0.082699334313268744, 
              c[ -32][ t]], 
            Times[ -0.072413370861974122, 
              c[ -31][ t]], 
            Times[ -0.058468080236789913, 
              c[ -30][ t]], 
            Times[ -0.04131966847794722, 
              c[ -29][ t]], 
            Times[ -0.021580547817547879, 
              c[ -28][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -27][ t]], 
            Times[ 0.022561481809254869, 
              c[ -26][ t]], 
            Times[ 0.045163358568919301, 
              c[ -25][ t]], 
            Times[ 0.066820663127759972, 
              c[ -24][ t]], 
            Times[ 0.086542809078944891, 
              c[ -23][ t]], 
            Times[ 0.10337416789158609, 
              c[ -22][ t]], 
            Times[ 0.11643488132933186, 
              c[ -21][ t]], 
            Times[ 0.12496032289024853, 
              c[ -20][ t]], 
            Times[ 0.12833762891430928, 
              c[ -19][ t]], 
            Times[ 0.12613778810677614, 
              c[ -18][ t]], 
            Times[ 0.11814190616181255, 
              c[ -17][ t]], 
            Times[ 0.10436044624225685, 
              c[ -16][ t]], 
            Times[ 0.085044480344421705, 
              c[ -15][ t]], 
            Times[ 0.060688263076985105, 
              c[ -14][ t]], 
            Times[ 0.032022748374425904, 
              c[ -13][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -12][ t]], 
            Times[ -0.034231213779558949, 
              c[ -11][ t]], 
            Times[ -0.06935801494512607, 
              c[ -10][ t]], 
            Times[ -0.10394325375429328, 
              c[ -9][ t]], 
            Times[ -0.13647135277833605, 
              c[ -8][ t]], 
            Times[ -0.16539866862653771, 
              c[ -7][ t]], 
            Times[ -0.18920668216016426, 
              c[ -6][ t]], 
            Times[ -0.20645618564475843, 
              c[ -5][ t]], 
            Times[ -0.21584055771952013, 
              c[ -4][ t]], 
            Times[ -0.21623620818304484, 
              c[ -3][ t]], 
            Times[ -0.206748335783172, 
              c[ -2][ t]], 
            Times[ -0.18675027222298601, 
              c[ -1][ t]], 
            Times[ -0.15591488063143982, 
              c[ 0][ t]], 
            Times[ -0.11423673049785445, 
              c[ 1][ t]], 
            Times[ -0.062044074975450343, 
              c[ 2][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 3][ t]], 
            Times[ 0.070907514257657622, 
              c[ 4][ t]], 
            Times[ 0.14938649372796345, 
              c[ 5][ t]], 
            Times[ 0.23387232094715985, 
              c[ 6][ t]], 
            Times[ 0.32256865202152135, 
              c[ 7][ t]], 
            Times[ 0.41349667156634395, 
              c[ 8][ t]], 
            Times[ 0.50455115242710469, 
              c[ 9][ t]], 
            Times[ 0.59356153372868026, 
              c[ 10][ t]], 
            Times[ 0.67835603854706317, 
              c[ 11][ t]], 
            Times[ 0.75682672864065692, 
              c[ 12][ t]], 
            Times[ 0.82699334313268813, 
              c[ 13][ t]], 
            Times[ 0.88706379305918381, 
              c[ 14][ t]], 
            Times[ 0.93548928378863916, 
              c[ 15][ t]], 
            Times[ 0.9710122092317629, 
              c[ 16][ t]], 
            Times[ 0.99270519960720671, 
              c[ 17][ t]], 
            Times[ 8.1061151687843385, 
              c[ 18][ t]], 
            Times[ 0.99270519960720693, 
              c[ 19][ t]], 
            Times[ 0.9710122092317629, 
              c[ 20][ t]], 
            Times[ 0.93548928378863916, 
              c[ 21][ t]], 
            Times[ 0.88706379305918392, 
              c[ 22][ t]], 
            Times[ 0.82699334313268813, 
              c[ 23][ t]], 
            Times[ 0.75682672864065692, 
              c[ 24][ t]], 
            Times[ 0.67835603854706361, 
              c[ 25][ t]], 
            Times[ 0.59356153372868059, 
              c[ 26][ t]], 
            Times[ 0.50455115242710469, 
              c[ 27][ t]], 
            Times[ 0.41349667156634429, 
              c[ 28][ t]], 
            Times[ 0.32256865202152157, 
              c[ 29][ t]], 
            Times[ 0.23387232094715985, 
              c[ 30][ t]], 
            Times[ 0.14938649372796384, 
              c[ 31][ t]], 
            Times[ 0.070907514257657775, 
              c[ 32][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 33][ t]], 
            Times[ -0.062044074975450239, 
              c[ 34][ t]], 
            Times[ -0.11423673049785436, 
              c[ 35][ t]], 
            Times[ -0.15591488063143982, 
              c[ 36][ t]], 
            Times[ -0.18675027222298593, 
              c[ 37][ t]], 
            Times[ -0.206748335783172, 
              c[ 38][ t]], 
            Times[ -0.21623620818304484, 
              c[ 39][ t]], 
            Times[ -0.21584055771952015, 
              c[ 40][ t]], 
            Times[ -0.20645618564475848, 
              c[ 41][ t]], 
            Times[ -0.18920668216016426, 
              c[ 42][ t]], 
            Times[ -0.16539866862653771, 
              c[ 43][ t]], 
            Times[ -0.13647135277833616, 
              c[ 44][ t]], 
            Times[ -0.10394325375429328, 
              c[ 45][ t]], 
            Times[ -0.06935801494512607, 
              c[ 46][ t]], 
            Times[ -0.034231213779559094, 
              c[ 47][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 48][ t]], 
            Times[ 0.032022748374425904, 
              c[ 49][ t]], 
            Times[ 0.060688263076985001, 
              c[ 50][ t]], 
            Times[ 0.085044480344421705, 
              c[ 51][ t]], 
            Times[ 0.10436044624225685, 
              c[ 52][ t]], 
            Times[ 0.11814190616181253, 
              c[ 53][ t]], 
            Times[ 0.12613778810677614, 
              c[ 54][ t]], 
            Times[ 0.12833762891430928, 
              c[ 55][ t]], 
            Times[ 0.12496032289024853, 
              c[ 56][ t]], 
            Times[ 0.11643488132933186, 
              c[ 57][ t]], 
            Times[ 0.10337416789158609, 
              c[ 58][ t]], 
            Times[ 0.086542809078944891, 
              c[ 59][ t]], 
            Times[ 0.066820663127759972, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "19", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[19]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.04491462243337642`\)\ \(c[\(-60\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-59\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-58\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-57\)]\)[t] + 
            1.5206810699945212`*^-16\ \(c[\(-56\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-55\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-54\)]\)[t] + 
            0.03897872015786009`\ \(c[\(-53\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-52\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-51\)]\)[t] + 
            0.06581101988179631`\ \(c[\(-50\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-49\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-48\)]\)[t] + 
            0.06880242987642332`\ \(c[\(-47\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-46\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-45\)]\)[t] + 
            0.044547108751839815`\ \(c[\(-44\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-43\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-42\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-41\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-40\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-39\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-38\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-37\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-36\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-35\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-34\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-33\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-32\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-31\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-30\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-29\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-28\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-27\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-26\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-25\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-24\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-23\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-22\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-21\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-20\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-19\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-18\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-17\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-16\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-15\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-14\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-13\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-12\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-11\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-10\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-9\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-8\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-7\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-6\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-5\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-4\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-3\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-2\)]\)[t] - 
            0.206748335783172`\ \(c[\(-1\)]\)[t] - 
            0.186750272222986`\ \(c[0]\)[t] - 
            0.15591488063143982`\ \(c[1]\)[t] - 
            0.11423673049785436`\ \(c[2]\)[t] - 
            0.06204407497545034`\ \(c[3]\)[t] + 
            3.898171832519376`*^-17\ \(c[4]\)[t] + 
            0.07090751425765777`\ \(c[5]\)[t] + 
            0.14938649372796362`\ \(c[6]\)[t] + 
            0.23387232094715985`\ \(c[7]\)[t] + 
            0.3225686520215216`\ \(c[8]\)[t] + 
            0.4134966715663442`\ \(c[9]\)[t] + 
            0.5045511524271047`\ \(c[10]\)[t] + 
            0.5935615337286803`\ \(c[11]\)[t] + 
            0.6783560385470634`\ \(c[12]\)[t] + 
            0.7568267286406569`\ \(c[13]\)[t] + 
            0.8269933431326881`\ \(c[14]\)[t] + 
            0.8870637930591838`\ \(c[15]\)[t] + 
            0.9354892837886392`\ \(c[16]\)[t] + 
            0.9710122092317629`\ \(c[17]\)[t] + 
            0.9927051996072069`\ \(c[18]\)[t] + 
            8.91761597509613`\ \(c[19]\)[t] + 
            0.9927051996072069`\ \(c[20]\)[t] + 
            0.9710122092317629`\ \(c[21]\)[t] + 
            0.9354892837886394`\ \(c[22]\)[t] + 
            0.8870637930591838`\ \(c[23]\)[t] + 
            0.8269933431326881`\ \(c[24]\)[t] + 
            0.7568267286406571`\ \(c[25]\)[t] + 
            0.6783560385470634`\ \(c[26]\)[t] + 
            0.5935615337286803`\ \(c[27]\)[t] + 
            0.5045511524271049`\ \(c[28]\)[t] + 
            0.4134966715663442`\ \(c[29]\)[t] + 
            0.32256865202152135`\ \(c[30]\)[t] + 
            0.23387232094715998`\ \(c[31]\)[t] + 
            0.14938649372796362`\ \(c[32]\)[t] + 
            0.07090751425765762`\ \(c[33]\)[t] + 
            1.8033970416801674`*^-16\ \(c[34]\)[t] - 
            0.06204407497545034`\ \(c[35]\)[t] - 
            0.11423673049785445`\ \(c[36]\)[t] - 
            0.15591488063143974`\ \(c[37]\)[t] - 
            0.186750272222986`\ \(c[38]\)[t] - 
            0.20674833578317206`\ \(c[39]\)[t] - 
            0.21623620818304484`\ \(c[40]\)[t] - 
            0.21584055771952015`\ \(c[41]\)[t] - 
            0.20645618564475834`\ \(c[42]\)[t] - 
            0.18920668216016426`\ \(c[43]\)[t] - 
            0.1653986686265377`\ \(c[44]\)[t] - 
            0.1364713527783359`\ \(c[45]\)[t] - 
            0.10394325375429328`\ \(c[46]\)[t] - 
            0.06935801494512607`\ \(c[47]\)[t] - 
            0.034231213779558796`\ \(c[48]\)[t] - 
            3.898171832519376`*^-17\ \(c[49]\)[t] + 
            0.032022748374425904`\ \(c[50]\)[t] + 
            0.06068826307698522`\ \(c[51]\)[t] + 
            0.0850444803444217`\ \(c[52]\)[t] + 
            0.10436044624225685`\ \(c[53]\)[t] + 
            0.1181419061618126`\ \(c[54]\)[t] + 
            0.12613778810677614`\ \(c[55]\)[t] + 
            0.12833762891430928`\ \(c[56]\)[t] + 
            0.12496032289024847`\ \(c[57]\)[t] + 
            0.11643488132933186`\ \(c[58]\)[t] + 
            0.10337416789158609`\ \(c[59]\)[t] + 
            0.08654280907894475`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 19, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 19]][ t]], 
          Plus[ 
            Times[ -0.044914622433376419, 
              c[ -60][ t]], 
            Times[ -0.035980357068793781, 
              c[ -59][ t]], 
            Times[ -0.025221096343682053, 
              c[ -58][ t]], 
            Times[ -0.013061910521147383, 
              c[ -57][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ -56][ t]], 
            Times[ 0.013414935129827233, 
              c[ -55][ t]], 
            Times[ 0.026603074225527826, 
              c[ -54][ t]], 
            Times[ 0.038978720157860088, 
              c[ -53][ t]], 
            Times[ 0.049975424961080865, 
              c[ -52][ t]], 
            Times[ 0.059070953080906326, 
              c[ -51][ t]], 
            Times[ 0.065811019881796315, 
              c[ -50][ t]], 
            Times[ 0.069830768673962415, 
              c[ -49][ t]], 
            Times[ 0.070873018952678238, 
              c[ -48][ t]], 
            Times[ 0.068802429876423321, 
              c[ -47][ t]], 
            Times[ 0.063614872548668253, 
              c[ -46][ t]], 
            Times[ 0.055441487066198933, 
              c[ -45][ t]], 
            Times[ 0.044547108751839815, 
              c[ -44][ t]], 
            Times[ 0.031322974491347078, 
              c[ -43][ t]], 
            Times[ 0.016273855731265604, 
              c[ -42][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -41][ t]], 
            Times[ -0.016825511857749401, 
              c[ -40][ t]], 
            Times[ -0.033483179628681567, 
              c[ -39][ t]], 
            Times[ -0.049236278094138941, 
              c[ -38][ t]], 
            Times[ -0.063361699504227528, 
              c[ -37][ t]], 
            Times[ -0.075181213012062598, 
              c[ -36][ t]], 
            Times[ -0.084091858737850814, 
              c[ -35][ t]], 
            Times[ -0.089594193770366884, 
              c[ -34][ t]], 
            Times[ -0.091317159035181589, 
              c[ -33][ t]], 
            Times[ -0.089038438663606695, 
              c[ -32][ t]], 
            Times[ -0.082699334313268744, 
              c[ -31][ t]], 
            Times[ -0.072413370861974122, 
              c[ -30][ t]], 
            Times[ -0.058468080236789913, 
              c[ -29][ t]], 
            Times[ -0.04131966847794722, 
              c[ -28][ t]], 
            Times[ -0.021580547817547879, 
              c[ -27][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -26][ t]], 
            Times[ 0.022561481809254869, 
              c[ -25][ t]], 
            Times[ 0.045163358568919301, 
              c[ -24][ t]], 
            Times[ 0.066820663127759972, 
              c[ -23][ t]], 
            Times[ 0.086542809078944891, 
              c[ -22][ t]], 
            Times[ 0.10337416789158609, 
              c[ -21][ t]], 
            Times[ 0.11643488132933186, 
              c[ -20][ t]], 
            Times[ 0.12496032289024853, 
              c[ -19][ t]], 
            Times[ 0.12833762891430928, 
              c[ -18][ t]], 
            Times[ 0.12613778810677614, 
              c[ -17][ t]], 
            Times[ 0.11814190616181255, 
              c[ -16][ t]], 
            Times[ 0.10436044624225685, 
              c[ -15][ t]], 
            Times[ 0.085044480344421705, 
              c[ -14][ t]], 
            Times[ 0.060688263076985105, 
              c[ -13][ t]], 
            Times[ 0.032022748374425904, 
              c[ -12][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -11][ t]], 
            Times[ -0.034231213779558949, 
              c[ -10][ t]], 
            Times[ -0.06935801494512607, 
              c[ -9][ t]], 
            Times[ -0.10394325375429328, 
              c[ -8][ t]], 
            Times[ -0.13647135277833605, 
              c[ -7][ t]], 
            Times[ -0.16539866862653771, 
              c[ -6][ t]], 
            Times[ -0.18920668216016426, 
              c[ -5][ t]], 
            Times[ -0.20645618564475843, 
              c[ -4][ t]], 
            Times[ -0.21584055771952015, 
              c[ -3][ t]], 
            Times[ -0.21623620818304484, 
              c[ -2][ t]], 
            Times[ -0.206748335783172, 
              c[ -1][ t]], 
            Times[ -0.18675027222298601, 
              c[ 0][ t]], 
            Times[ -0.15591488063143982, 
              c[ 1][ t]], 
            Times[ -0.11423673049785436, 
              c[ 2][ t]], 
            Times[ -0.062044074975450343, 
              c[ 3][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 4][ t]], 
            Times[ 0.070907514257657775, 
              c[ 5][ t]], 
            Times[ 0.14938649372796362, 
              c[ 6][ t]], 
            Times[ 0.23387232094715985, 
              c[ 7][ t]], 
            Times[ 0.32256865202152157, 
              c[ 8][ t]], 
            Times[ 0.41349667156634418, 
              c[ 9][ t]], 
            Times[ 0.50455115242710469, 
              c[ 10][ t]], 
            Times[ 0.59356153372868026, 
              c[ 11][ t]], 
            Times[ 0.67835603854706339, 
              c[ 12][ t]], 
            Times[ 0.75682672864065692, 
              c[ 13][ t]], 
            Times[ 0.82699334313268813, 
              c[ 14][ t]], 
            Times[ 0.88706379305918381, 
              c[ 15][ t]], 
            Times[ 0.93548928378863916, 
              c[ 16][ t]], 
            Times[ 0.9710122092317629, 
              c[ 17][ t]], 
            Times[ 0.99270519960720693, 
              c[ 18][ t]], 
            Times[ 8.9176159750961297, 
              c[ 19][ t]], 
            Times[ 0.99270519960720693, 
              c[ 20][ t]], 
            Times[ 0.9710122092317629, 
              c[ 21][ t]], 
            Times[ 0.93548928378863938, 
              c[ 22][ t]], 
            Times[ 0.88706379305918381, 
              c[ 23][ t]], 
            Times[ 0.82699334313268813, 
              c[ 24][ t]], 
            Times[ 0.75682672864065714, 
              c[ 25][ t]], 
            Times[ 0.67835603854706339, 
              c[ 26][ t]], 
            Times[ 0.59356153372868026, 
              c[ 27][ t]], 
            Times[ 0.50455115242710491, 
              c[ 28][ t]], 
            Times[ 0.41349667156634418, 
              c[ 29][ t]], 
            Times[ 0.32256865202152135, 
              c[ 30][ t]], 
            Times[ 0.23387232094715998, 
              c[ 31][ t]], 
            Times[ 0.14938649372796362, 
              c[ 32][ t]], 
            Times[ 0.070907514257657622, 
              c[ 33][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 34][ t]], 
            Times[ -0.062044074975450343, 
              c[ 35][ t]], 
            Times[ -0.11423673049785445, 
              c[ 36][ t]], 
            Times[ -0.15591488063143974, 
              c[ 37][ t]], 
            Times[ -0.18675027222298601, 
              c[ 38][ t]], 
            Times[ -0.20674833578317206, 
              c[ 39][ t]], 
            Times[ -0.21623620818304484, 
              c[ 40][ t]], 
            Times[ -0.21584055771952015, 
              c[ 41][ t]], 
            Times[ -0.20645618564475834, 
              c[ 42][ t]], 
            Times[ -0.18920668216016426, 
              c[ 43][ t]], 
            Times[ -0.16539866862653771, 
              c[ 44][ t]], 
            Times[ -0.13647135277833591, 
              c[ 45][ t]], 
            Times[ -0.10394325375429328, 
              c[ 46][ t]], 
            Times[ -0.06935801494512607, 
              c[ 47][ t]], 
            Times[ -0.034231213779558796, 
              c[ 48][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 49][ t]], 
            Times[ 0.032022748374425904, 
              c[ 50][ t]], 
            Times[ 0.060688263076985223, 
              c[ 51][ t]], 
            Times[ 0.085044480344421705, 
              c[ 52][ t]], 
            Times[ 0.10436044624225685, 
              c[ 53][ t]], 
            Times[ 0.1181419061618126, 
              c[ 54][ t]], 
            Times[ 0.12613778810677614, 
              c[ 55][ t]], 
            Times[ 0.12833762891430928, 
              c[ 56][ t]], 
            Times[ 0.12496032289024847, 
              c[ 57][ t]], 
            Times[ 0.11643488132933186, 
              c[ 58][ t]], 
            Times[ 0.10337416789158609, 
              c[ 59][ t]], 
            Times[ 0.086542809078944752, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "20", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[20]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.05168708394579296`\)\ \(c[\(-60\)]\)[t] - 
            0.04491462243337629`\ \(c[\(-59\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-58\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-57\)]\)[t] - 
            0.013061910521147276`\ \(c[\(-56\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-55\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-54\)]\)[t] + 
            0.026603074225527937`\ \(c[\(-53\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-52\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-51\)]\)[t] + 
            0.0590709530809064`\ \(c[\(-50\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-49\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-48\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-47\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-46\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-45\)]\)[t] + 
            0.055441487066198857`\ \(c[\(-44\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-43\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-42\)]\)[t] + 
            0.01627385573126547`\ \(c[\(-41\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-40\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-39\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-38\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-37\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-36\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-35\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-34\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-33\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-32\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-31\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-30\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-29\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-28\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-27\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-26\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-25\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-24\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-23\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-22\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-21\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-20\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-19\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-18\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-17\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-16\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-15\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-14\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-13\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-12\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-11\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-10\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-9\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-8\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-7\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-6\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-5\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-4\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-3\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-2\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-1\)]\)[t] - 
            0.206748335783172`\ \(c[0]\)[t] - 
            0.186750272222986`\ \(c[1]\)[t] - 
            0.15591488063143974`\ \(c[2]\)[t] - 
            0.11423673049785436`\ \(c[3]\)[t] - 
            0.06204407497545034`\ \(c[4]\)[t] + 
            3.898171832519376`*^-17\ \(c[5]\)[t] + 
            0.07090751425765777`\ \(c[6]\)[t] + 
            0.14938649372796362`\ \(c[7]\)[t] + 
            0.23387232094715985`\ \(c[8]\)[t] + 
            0.3225686520215216`\ \(c[9]\)[t] + 
            0.4134966715663442`\ \(c[10]\)[t] + 
            0.5045511524271047`\ \(c[11]\)[t] + 
            0.5935615337286806`\ \(c[12]\)[t] + 
            0.6783560385470634`\ \(c[13]\)[t] + 
            0.7568267286406569`\ \(c[14]\)[t] + 
            0.8269933431326881`\ \(c[15]\)[t] + 
            0.8870637930591838`\ \(c[16]\)[t] + 
            0.9354892837886392`\ \(c[17]\)[t] + 
            0.9710122092317629`\ \(c[18]\)[t] + 
            0.9927051996072069`\ \(c[19]\)[t] + 
            9.772981689857206`\ \(c[20]\)[t] + 
            0.9927051996072067`\ \(c[21]\)[t] + 
            0.9710122092317629`\ \(c[22]\)[t] + 
            0.9354892837886392`\ \(c[23]\)[t] + 
            0.8870637930591838`\ \(c[24]\)[t] + 
            0.8269933431326881`\ \(c[25]\)[t] + 
            0.7568267286406569`\ \(c[26]\)[t] + 
            0.6783560385470632`\ \(c[27]\)[t] + 
            0.5935615337286806`\ \(c[28]\)[t] + 
            0.5045511524271047`\ \(c[29]\)[t] + 
            0.41349667156634395`\ \(c[30]\)[t] + 
            0.3225686520215216`\ \(c[31]\)[t] + 
            0.23387232094715985`\ \(c[32]\)[t] + 
            0.14938649372796345`\ \(c[33]\)[t] + 
            0.07090751425765777`\ \(c[34]\)[t] + 
            3.898171832519376`*^-17\ \(c[35]\)[t] - 
            0.062044074975450475`\ \(c[36]\)[t] - 
            0.11423673049785436`\ \(c[37]\)[t] - 
            0.15591488063143982`\ \(c[38]\)[t] - 
            0.18675027222298607`\ \(c[39]\)[t] - 
            0.206748335783172`\ \(c[40]\)[t] - 
            0.21623620818304481`\ \(c[41]\)[t] - 
            0.21584055771952013`\ \(c[42]\)[t] - 
            0.20645618564475843`\ \(c[43]\)[t] - 
            0.18920668216016434`\ \(c[44]\)[t] - 
            0.1653986686265376`\ \(c[45]\)[t] - 
            0.13647135277833605`\ \(c[46]\)[t] - 
            0.1039432537542934`\ \(c[47]\)[t] - 
            0.06935801494512592`\ \(c[48]\)[t] - 
            0.03423121377955895`\ \(c[49]\)[t] - 
            1.8033970416801674`*^-16\ \(c[50]\)[t] + 
            0.03202274837442603`\ \(c[51]\)[t] + 
            0.060688263076985105`\ \(c[52]\)[t] + 
            0.08504448034442161`\ \(c[53]\)[t] + 
            0.10436044624225692`\ \(c[54]\)[t] + 
            0.11814190616181255`\ \(c[55]\)[t] + 
            0.12613778810677612`\ \(c[56]\)[t] + 
            0.12833762891430925`\ \(c[57]\)[t] + 
            0.12496032289024853`\ \(c[58]\)[t] + 
            0.11643488132933186`\ \(c[59]\)[t] + 
            0.10337416789158595`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 20, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 20]][ t]], 
          Plus[ 
            Times[ -0.05168708394579296, 
              c[ -60][ t]], 
            Times[ -0.044914622433376288, 
              c[ -59][ t]], 
            Times[ -0.035980357068793781, 
              c[ -58][ t]], 
            Times[ -0.025221096343682053, 
              c[ -57][ t]], 
            Times[ -0.013061910521147276, 
              c[ -56][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -55][ t]], 
            Times[ 0.013414935129827233, 
              c[ -54][ t]], 
            Times[ 0.026603074225527937, 
              c[ -53][ t]], 
            Times[ 0.03897872015785999, 
              c[ -52][ t]], 
            Times[ 0.049975424961080865, 
              c[ -51][ t]], 
            Times[ 0.059070953080906402, 
              c[ -50][ t]], 
            Times[ 0.065811019881796273, 
              c[ -49][ t]], 
            Times[ 0.069830768673962415, 
              c[ -48][ t]], 
            Times[ 0.070873018952678238, 
              c[ -47][ t]], 
            Times[ 0.068802429876423349, 
              c[ -46][ t]], 
            Times[ 0.063614872548668253, 
              c[ -45][ t]], 
            Times[ 0.055441487066198857, 
              c[ -44][ t]], 
            Times[ 0.044547108751839919, 
              c[ -43][ t]], 
            Times[ 0.031322974491347078, 
              c[ -42][ t]], 
            Times[ 0.016273855731265469, 
              c[ -41][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -40][ t]], 
            Times[ -0.016825511857749401, 
              c[ -39][ t]], 
            Times[ -0.033483179628681567, 
              c[ -38][ t]], 
            Times[ -0.049236278094138941, 
              c[ -37][ t]], 
            Times[ -0.063361699504227528, 
              c[ -36][ t]], 
            Times[ -0.075181213012062598, 
              c[ -35][ t]], 
            Times[ -0.084091858737850814, 
              c[ -34][ t]], 
            Times[ -0.089594193770366884, 
              c[ -33][ t]], 
            Times[ -0.091317159035181589, 
              c[ -32][ t]], 
            Times[ -0.089038438663606695, 
              c[ -31][ t]], 
            Times[ -0.082699334313268744, 
              c[ -30][ t]], 
            Times[ -0.072413370861974122, 
              c[ -29][ t]], 
            Times[ -0.058468080236789913, 
              c[ -28][ t]], 
            Times[ -0.04131966847794722, 
              c[ -27][ t]], 
            Times[ -0.021580547817547879, 
              c[ -26][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -25][ t]], 
            Times[ 0.022561481809254869, 
              c[ -24][ t]], 
            Times[ 0.045163358568919301, 
              c[ -23][ t]], 
            Times[ 0.066820663127759972, 
              c[ -22][ t]], 
            Times[ 0.086542809078944891, 
              c[ -21][ t]], 
            Times[ 0.10337416789158609, 
              c[ -20][ t]], 
            Times[ 0.11643488132933186, 
              c[ -19][ t]], 
            Times[ 0.12496032289024853, 
              c[ -18][ t]], 
            Times[ 0.12833762891430928, 
              c[ -17][ t]], 
            Times[ 0.12613778810677614, 
              c[ -16][ t]], 
            Times[ 0.11814190616181255, 
              c[ -15][ t]], 
            Times[ 0.10436044624225685, 
              c[ -14][ t]], 
            Times[ 0.085044480344421705, 
              c[ -13][ t]], 
            Times[ 0.060688263076985105, 
              c[ -12][ t]], 
            Times[ 0.032022748374425904, 
              c[ -11][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -10][ t]], 
            Times[ -0.034231213779558949, 
              c[ -9][ t]], 
            Times[ -0.06935801494512607, 
              c[ -8][ t]], 
            Times[ -0.10394325375429328, 
              c[ -7][ t]], 
            Times[ -0.13647135277833605, 
              c[ -6][ t]], 
            Times[ -0.16539866862653771, 
              c[ -5][ t]], 
            Times[ -0.18920668216016426, 
              c[ -4][ t]], 
            Times[ -0.20645618564475843, 
              c[ -3][ t]], 
            Times[ -0.21584055771952015, 
              c[ -2][ t]], 
            Times[ -0.21623620818304484, 
              c[ -1][ t]], 
            Times[ -0.206748335783172, 
              c[ 0][ t]], 
            Times[ -0.18675027222298601, 
              c[ 1][ t]], 
            Times[ -0.15591488063143974, 
              c[ 2][ t]], 
            Times[ -0.11423673049785436, 
              c[ 3][ t]], 
            Times[ -0.062044074975450343, 
              c[ 4][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 5][ t]], 
            Times[ 0.070907514257657775, 
              c[ 6][ t]], 
            Times[ 0.14938649372796362, 
              c[ 7][ t]], 
            Times[ 0.23387232094715985, 
              c[ 8][ t]], 
            Times[ 0.32256865202152157, 
              c[ 9][ t]], 
            Times[ 0.41349667156634418, 
              c[ 10][ t]], 
            Times[ 0.50455115242710469, 
              c[ 11][ t]], 
            Times[ 0.59356153372868059, 
              c[ 12][ t]], 
            Times[ 0.67835603854706339, 
              c[ 13][ t]], 
            Times[ 0.75682672864065692, 
              c[ 14][ t]], 
            Times[ 0.82699334313268813, 
              c[ 15][ t]], 
            Times[ 0.88706379305918381, 
              c[ 16][ t]], 
            Times[ 0.93548928378863916, 
              c[ 17][ t]], 
            Times[ 0.9710122092317629, 
              c[ 18][ t]], 
            Times[ 0.99270519960720693, 
              c[ 19][ t]], 
            Times[ 9.7729816898572057, 
              c[ 20][ t]], 
            Times[ 0.99270519960720671, 
              c[ 21][ t]], 
            Times[ 0.9710122092317629, 
              c[ 22][ t]], 
            Times[ 0.93548928378863916, 
              c[ 23][ t]], 
            Times[ 0.88706379305918381, 
              c[ 24][ t]], 
            Times[ 0.82699334313268813, 
              c[ 25][ t]], 
            Times[ 0.75682672864065692, 
              c[ 26][ t]], 
            Times[ 0.67835603854706317, 
              c[ 27][ t]], 
            Times[ 0.59356153372868059, 
              c[ 28][ t]], 
            Times[ 0.50455115242710469, 
              c[ 29][ t]], 
            Times[ 0.41349667156634395, 
              c[ 30][ t]], 
            Times[ 0.32256865202152157, 
              c[ 31][ t]], 
            Times[ 0.23387232094715985, 
              c[ 32][ t]], 
            Times[ 0.14938649372796345, 
              c[ 33][ t]], 
            Times[ 0.070907514257657775, 
              c[ 34][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 35][ t]], 
            Times[ -0.062044074975450475, 
              c[ 36][ t]], 
            Times[ -0.11423673049785436, 
              c[ 37][ t]], 
            Times[ -0.15591488063143982, 
              c[ 38][ t]], 
            Times[ -0.18675027222298607, 
              c[ 39][ t]], 
            Times[ -0.206748335783172, 
              c[ 40][ t]], 
            Times[ -0.21623620818304481, 
              c[ 41][ t]], 
            Times[ -0.21584055771952013, 
              c[ 42][ t]], 
            Times[ -0.20645618564475843, 
              c[ 43][ t]], 
            Times[ -0.18920668216016434, 
              c[ 44][ t]], 
            Times[ -0.1653986686265376, 
              c[ 45][ t]], 
            Times[ -0.13647135277833605, 
              c[ 46][ t]], 
            Times[ -0.1039432537542934, 
              c[ 47][ t]], 
            Times[ -0.069358014945125918, 
              c[ 48][ t]], 
            Times[ -0.034231213779558949, 
              c[ 49][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 50][ t]], 
            Times[ 0.032022748374426029, 
              c[ 51][ t]], 
            Times[ 0.060688263076985105, 
              c[ 52][ t]], 
            Times[ 0.085044480344421608, 
              c[ 53][ t]], 
            Times[ 0.10436044624225692, 
              c[ 54][ t]], 
            Times[ 0.11814190616181255, 
              c[ 55][ t]], 
            Times[ 0.12613778810677612, 
              c[ 56][ t]], 
            Times[ 0.12833762891430925, 
              c[ 57][ t]], 
            Times[ 0.12496032289024853, 
              c[ 58][ t]], 
            Times[ 0.11643488132933186, 
              c[ 59][ t]], 
            Times[ 0.10337416789158595, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "21", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[21]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.056061239158567186`\)\ \(c[\(-60\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-59\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-58\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-57\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-56\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-55\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-54\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-53\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-52\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-51\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-50\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-49\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-48\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-47\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-46\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-45\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-44\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-43\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-42\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-41\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-40\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-39\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-38\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-37\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-36\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-35\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-34\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-33\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-32\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-31\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-30\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-29\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-28\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-27\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-26\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-25\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-24\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-23\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-22\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-21\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-20\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-19\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-18\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-17\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-16\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-15\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-14\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-13\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-12\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-11\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-10\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-9\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-8\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-7\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-6\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-5\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-4\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-3\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-2\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-1\)]\)[t] - 
            0.21623620818304484`\ \(c[0]\)[t] - 
            0.206748335783172`\ \(c[1]\)[t] - 
            0.186750272222986`\ \(c[2]\)[t] - 
            0.15591488063143982`\ \(c[3]\)[t] - 
            0.11423673049785445`\ \(c[4]\)[t] - 
            0.062044074975450475`\ \(c[5]\)[t] + 
            3.898171832519376`*^-17\ \(c[6]\)[t] + 
            0.07090751425765762`\ \(c[7]\)[t] + 
            0.14938649372796345`\ \(c[8]\)[t] + 
            0.23387232094715985`\ \(c[9]\)[t] + 
            0.32256865202152135`\ \(c[10]\)[t] + 
            0.41349667156634395`\ \(c[11]\)[t] + 
            0.5045511524271047`\ \(c[12]\)[t] + 
            0.5935615337286803`\ \(c[13]\)[t] + 
            0.6783560385470632`\ \(c[14]\)[t] + 
            0.7568267286406569`\ \(c[15]\)[t] + 
            0.8269933431326881`\ \(c[16]\)[t] + 
            0.8870637930591838`\ \(c[17]\)[t] + 
            0.9354892837886392`\ \(c[18]\)[t] + 
            0.9710122092317629`\ \(c[19]\)[t] + 
            0.9927051996072067`\ \(c[20]\)[t] + 
            10.67221231306757`\ \(c[21]\)[t] + 
            0.9927051996072069`\ \(c[22]\)[t] + 
            0.9710122092317629`\ \(c[23]\)[t] + 
            0.9354892837886392`\ \(c[24]\)[t] + 
            0.8870637930591839`\ \(c[25]\)[t] + 
            0.8269933431326881`\ \(c[26]\)[t] + 
            0.7568267286406569`\ \(c[27]\)[t] + 
            0.6783560385470636`\ \(c[28]\)[t] + 
            0.5935615337286806`\ \(c[29]\)[t] + 
            0.5045511524271047`\ \(c[30]\)[t] + 
            0.4134966715663443`\ \(c[31]\)[t] + 
            0.3225686520215216`\ \(c[32]\)[t] + 
            0.23387232094715985`\ \(c[33]\)[t] + 
            0.14938649372796384`\ \(c[34]\)[t] + 
            0.07090751425765777`\ \(c[35]\)[t] + 
            3.898171832519376`*^-17\ \(c[36]\)[t] - 
            0.06204407497545024`\ \(c[37]\)[t] - 
            0.11423673049785436`\ \(c[38]\)[t] - 
            0.15591488063143982`\ \(c[39]\)[t] - 
            0.18675027222298593`\ \(c[40]\)[t] - 
            0.2067483357831719`\ \(c[41]\)[t] - 
            0.21623620818304484`\ \(c[42]\)[t] - 
            0.21584055771952015`\ \(c[43]\)[t] - 
            0.20645618564475848`\ \(c[44]\)[t] - 
            0.18920668216016426`\ \(c[45]\)[t] - 
            0.1653986686265377`\ \(c[46]\)[t] - 
            0.13647135277833616`\ \(c[47]\)[t] - 
            0.10394325375429328`\ \(c[48]\)[t] - 
            0.06935801494512607`\ \(c[49]\)[t] - 
            0.034231213779559094`\ \(c[50]\)[t] - 
            3.898171832519376`*^-17\ \(c[51]\)[t] + 
            0.032022748374425904`\ \(c[52]\)[t] + 
            0.060688263076985`\ \(c[53]\)[t] + 
            0.0850444803444217`\ \(c[54]\)[t] + 
            0.10436044624225685`\ \(c[55]\)[t] + 
            0.11814190616181253`\ \(c[56]\)[t] + 
            0.12613778810677614`\ \(c[57]\)[t] + 
            0.12833762891430928`\ \(c[58]\)[t] + 
            0.12496032289024853`\ \(c[59]\)[t] + 
            0.11643488132933186`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 21, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 21]][ t]], 
          Plus[ 
            Times[ -0.056061239158567186, 
              c[ -60][ t]], 
            Times[ -0.05168708394579296, 
              c[ -59][ t]], 
            Times[ -0.044914622433376419, 
              c[ -58][ t]], 
            Times[ -0.035980357068793781, 
              c[ -57][ t]], 
            Times[ -0.025221096343682053, 
              c[ -56][ t]], 
            Times[ -0.013061910521147383, 
              c[ -55][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -54][ t]], 
            Times[ 0.013414935129827233, 
              c[ -53][ t]], 
            Times[ 0.026603074225527826, 
              c[ -52][ t]], 
            Times[ 0.03897872015785999, 
              c[ -51][ t]], 
            Times[ 0.049975424961080865, 
              c[ -50][ t]], 
            Times[ 0.059070953080906326, 
              c[ -49][ t]], 
            Times[ 0.065811019881796273, 
              c[ -48][ t]], 
            Times[ 0.069830768673962415, 
              c[ -47][ t]], 
            Times[ 0.070873018952678238, 
              c[ -46][ t]], 
            Times[ 0.068802429876423349, 
              c[ -45][ t]], 
            Times[ 0.063614872548668253, 
              c[ -44][ t]], 
            Times[ 0.055441487066198933, 
              c[ -43][ t]], 
            Times[ 0.044547108751839919, 
              c[ -42][ t]], 
            Times[ 0.031322974491347078, 
              c[ -41][ t]], 
            Times[ 0.016273855731265604, 
              c[ -40][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -39][ t]], 
            Times[ -0.016825511857749401, 
              c[ -38][ t]], 
            Times[ -0.033483179628681567, 
              c[ -37][ t]], 
            Times[ -0.049236278094138941, 
              c[ -36][ t]], 
            Times[ -0.063361699504227528, 
              c[ -35][ t]], 
            Times[ -0.075181213012062598, 
              c[ -34][ t]], 
            Times[ -0.084091858737850814, 
              c[ -33][ t]], 
            Times[ -0.089594193770366884, 
              c[ -32][ t]], 
            Times[ -0.091317159035181589, 
              c[ -31][ t]], 
            Times[ -0.089038438663606695, 
              c[ -30][ t]], 
            Times[ -0.082699334313268744, 
              c[ -29][ t]], 
            Times[ -0.072413370861974122, 
              c[ -28][ t]], 
            Times[ -0.058468080236789913, 
              c[ -27][ t]], 
            Times[ -0.04131966847794722, 
              c[ -26][ t]], 
            Times[ -0.021580547817547879, 
              c[ -25][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -24][ t]], 
            Times[ 0.022561481809254869, 
              c[ -23][ t]], 
            Times[ 0.045163358568919301, 
              c[ -22][ t]], 
            Times[ 0.066820663127759972, 
              c[ -21][ t]], 
            Times[ 0.086542809078944891, 
              c[ -20][ t]], 
            Times[ 0.10337416789158609, 
              c[ -19][ t]], 
            Times[ 0.11643488132933186, 
              c[ -18][ t]], 
            Times[ 0.12496032289024853, 
              c[ -17][ t]], 
            Times[ 0.12833762891430928, 
              c[ -16][ t]], 
            Times[ 0.12613778810677614, 
              c[ -15][ t]], 
            Times[ 0.11814190616181255, 
              c[ -14][ t]], 
            Times[ 0.10436044624225685, 
              c[ -13][ t]], 
            Times[ 0.085044480344421705, 
              c[ -12][ t]], 
            Times[ 0.060688263076985105, 
              c[ -11][ t]], 
            Times[ 0.032022748374425904, 
              c[ -10][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -9][ t]], 
            Times[ -0.034231213779558949, 
              c[ -8][ t]], 
            Times[ -0.06935801494512607, 
              c[ -7][ t]], 
            Times[ -0.10394325375429328, 
              c[ -6][ t]], 
            Times[ -0.13647135277833605, 
              c[ -5][ t]], 
            Times[ -0.1653986686265376, 
              c[ -4][ t]], 
            Times[ -0.18920668216016426, 
              c[ -3][ t]], 
            Times[ -0.20645618564475843, 
              c[ -2][ t]], 
            Times[ -0.21584055771952013, 
              c[ -1][ t]], 
            Times[ -0.21623620818304484, 
              c[ 0][ t]], 
            Times[ -0.206748335783172, 
              c[ 1][ t]], 
            Times[ -0.18675027222298601, 
              c[ 2][ t]], 
            Times[ -0.15591488063143982, 
              c[ 3][ t]], 
            Times[ -0.11423673049785445, 
              c[ 4][ t]], 
            Times[ -0.062044074975450475, 
              c[ 5][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 6][ t]], 
            Times[ 0.070907514257657622, 
              c[ 7][ t]], 
            Times[ 0.14938649372796345, 
              c[ 8][ t]], 
            Times[ 0.23387232094715985, 
              c[ 9][ t]], 
            Times[ 0.32256865202152135, 
              c[ 10][ t]], 
            Times[ 0.41349667156634395, 
              c[ 11][ t]], 
            Times[ 0.50455115242710469, 
              c[ 12][ t]], 
            Times[ 0.59356153372868026, 
              c[ 13][ t]], 
            Times[ 0.67835603854706317, 
              c[ 14][ t]], 
            Times[ 0.75682672864065692, 
              c[ 15][ t]], 
            Times[ 0.82699334313268813, 
              c[ 16][ t]], 
            Times[ 0.88706379305918381, 
              c[ 17][ t]], 
            Times[ 0.93548928378863916, 
              c[ 18][ t]], 
            Times[ 0.9710122092317629, 
              c[ 19][ t]], 
            Times[ 0.99270519960720671, 
              c[ 20][ t]], 
            Times[ 10.67221231306757, 
              c[ 21][ t]], 
            Times[ 0.99270519960720693, 
              c[ 22][ t]], 
            Times[ 0.9710122092317629, 
              c[ 23][ t]], 
            Times[ 0.93548928378863916, 
              c[ 24][ t]], 
            Times[ 0.88706379305918392, 
              c[ 25][ t]], 
            Times[ 0.82699334313268813, 
              c[ 26][ t]], 
            Times[ 0.75682672864065692, 
              c[ 27][ t]], 
            Times[ 0.67835603854706361, 
              c[ 28][ t]], 
            Times[ 0.59356153372868059, 
              c[ 29][ t]], 
            Times[ 0.50455115242710469, 
              c[ 30][ t]], 
            Times[ 0.41349667156634429, 
              c[ 31][ t]], 
            Times[ 0.32256865202152157, 
              c[ 32][ t]], 
            Times[ 0.23387232094715985, 
              c[ 33][ t]], 
            Times[ 0.14938649372796384, 
              c[ 34][ t]], 
            Times[ 0.070907514257657775, 
              c[ 35][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 36][ t]], 
            Times[ -0.062044074975450239, 
              c[ 37][ t]], 
            Times[ -0.11423673049785436, 
              c[ 38][ t]], 
            Times[ -0.15591488063143982, 
              c[ 39][ t]], 
            Times[ -0.18675027222298593, 
              c[ 40][ t]], 
            Times[ -0.20674833578317189, 
              c[ 41][ t]], 
            Times[ -0.21623620818304484, 
              c[ 42][ t]], 
            Times[ -0.21584055771952015, 
              c[ 43][ t]], 
            Times[ -0.20645618564475848, 
              c[ 44][ t]], 
            Times[ -0.18920668216016426, 
              c[ 45][ t]], 
            Times[ -0.16539866862653771, 
              c[ 46][ t]], 
            Times[ -0.13647135277833616, 
              c[ 47][ t]], 
            Times[ -0.10394325375429328, 
              c[ 48][ t]], 
            Times[ -0.06935801494512607, 
              c[ 49][ t]], 
            Times[ -0.034231213779559094, 
              c[ 50][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 51][ t]], 
            Times[ 0.032022748374425904, 
              c[ 52][ t]], 
            Times[ 0.060688263076985001, 
              c[ 53][ t]], 
            Times[ 0.085044480344421705, 
              c[ 54][ t]], 
            Times[ 0.10436044624225685, 
              c[ 55][ t]], 
            Times[ 0.11814190616181253, 
              c[ 56][ t]], 
            Times[ 0.12613778810677614, 
              c[ 57][ t]], 
            Times[ 0.12833762891430928, 
              c[ 58][ t]], 
            Times[ 0.12496032289024853, 
              c[ 59][ t]], 
            Times[ 0.11643488132933186, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "22", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[22]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.0579084423149932`\)\ \(c[\(-60\)]\)[t] - 
            0.05606123915856713`\ \(c[\(-59\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-58\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-57\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-56\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-55\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-54\)]\)[t] + 
            1.5206810699945212`*^-16\ \(c[\(-53\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-52\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-51\)]\)[t] + 
            0.03897872015786009`\ \(c[\(-50\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-49\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-48\)]\)[t] + 
            0.06581101988179631`\ \(c[\(-47\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-46\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-45\)]\)[t] + 
            0.06880242987642332`\ \(c[\(-44\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-43\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-42\)]\)[t] + 
            0.044547108751839815`\ \(c[\(-41\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-40\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-39\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-38\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-37\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-36\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-35\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-34\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-33\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-32\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-31\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-30\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-29\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-28\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-27\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-26\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-25\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-24\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-23\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-22\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-21\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-20\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-19\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-18\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-17\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-16\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-15\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-14\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-13\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-12\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-11\)]\)[t] + 
            0.060688263076985`\ \(c[\(-10\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-9\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-8\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-7\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-6\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-5\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-4\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-3\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-2\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-1\)]\)[t] - 
            0.21584055771952015`\ \(c[0]\)[t] - 
            0.21623620818304481`\ \(c[1]\)[t] - 
            0.206748335783172`\ \(c[2]\)[t] - 
            0.18675027222298593`\ \(c[3]\)[t] - 
            0.15591488063143974`\ \(c[4]\)[t] - 
            0.11423673049785436`\ \(c[5]\)[t] - 
            0.06204407497545024`\ \(c[6]\)[t] + 
            1.8033970416801674`*^-16\ \(c[7]\)[t] + 
            0.07090751425765777`\ \(c[8]\)[t] + 
            0.14938649372796384`\ \(c[9]\)[t] + 
            0.23387232094715998`\ \(c[10]\)[t] + 
            0.3225686520215216`\ \(c[11]\)[t] + 
            0.4134966715663443`\ \(c[12]\)[t] + 
            0.5045511524271049`\ \(c[13]\)[t] + 
            0.5935615337286806`\ \(c[14]\)[t] + 
            0.6783560385470636`\ \(c[15]\)[t] + 
            0.7568267286406571`\ \(c[16]\)[t] + 
            0.8269933431326881`\ \(c[17]\)[t] + 
            0.8870637930591839`\ \(c[18]\)[t] + 
            0.9354892837886394`\ \(c[19]\)[t] + 
            0.9710122092317629`\ \(c[20]\)[t] + 
            0.9927051996072069`\ \(c[21]\)[t] + 
            11.615307844727218`\ \(c[22]\)[t] + 
            0.9927051996072067`\ \(c[23]\)[t] + 
            0.9710122092317629`\ \(c[24]\)[t] + 
            0.9354892837886392`\ \(c[25]\)[t] + 
            0.8870637930591838`\ \(c[26]\)[t] + 
            0.826993343132688`\ \(c[27]\)[t] + 
            0.7568267286406569`\ \(c[28]\)[t] + 
            0.6783560385470632`\ \(c[29]\)[t] + 
            0.5935615337286801`\ \(c[30]\)[t] + 
            0.5045511524271047`\ \(c[31]\)[t] + 
            0.41349667156634395`\ \(c[32]\)[t] + 
            0.32256865202152113`\ \(c[33]\)[t] + 
            0.23387232094715985`\ \(c[34]\)[t] + 
            0.14938649372796345`\ \(c[35]\)[t] + 
            0.07090751425765746`\ \(c[36]\)[t] + 
            3.898171832519376`*^-17\ \(c[37]\)[t] - 
            0.062044074975450475`\ \(c[38]\)[t] - 
            0.11423673049785459`\ \(c[39]\)[t] - 
            0.15591488063143982`\ \(c[40]\)[t] - 
            0.18675027222298593`\ \(c[41]\)[t] - 
            0.20674833578317206`\ \(c[42]\)[t] - 
            0.21623620818304484`\ \(c[43]\)[t] - 
            0.21584055771952015`\ \(c[44]\)[t] - 
            0.20645618564475834`\ \(c[45]\)[t] - 
            0.18920668216016426`\ \(c[46]\)[t] - 
            0.1653986686265377`\ \(c[47]\)[t] - 
            0.1364713527783359`\ \(c[48]\)[t] - 
            0.10394325375429328`\ \(c[49]\)[t] - 
            0.06935801494512607`\ \(c[50]\)[t] - 
            0.034231213779558796`\ \(c[51]\)[t] - 
            3.898171832519376`*^-17\ \(c[52]\)[t] + 
            0.032022748374425904`\ \(c[53]\)[t] + 
            0.06068826307698522`\ \(c[54]\)[t] + 
            0.0850444803444217`\ \(c[55]\)[t] + 
            0.10436044624225685`\ \(c[56]\)[t] + 
            0.1181419061618126`\ \(c[57]\)[t] + 
            0.12613778810677614`\ \(c[58]\)[t] + 
            0.12833762891430928`\ \(c[59]\)[t] + 
            0.12496032289024847`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 22, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 22]][ t]], 
          Plus[ 
            Times[ -0.057908442314993203, 
              c[ -60][ t]], 
            Times[ -0.05606123915856713, 
              c[ -59][ t]], 
            Times[ -0.05168708394579296, 
              c[ -58][ t]], 
            Times[ -0.044914622433376419, 
              c[ -57][ t]], 
            Times[ -0.035980357068793781, 
              c[ -56][ t]], 
            Times[ -0.025221096343682053, 
              c[ -55][ t]], 
            Times[ -0.013061910521147383, 
              c[ -54][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ -53][ t]], 
            Times[ 0.013414935129827233, 
              c[ -52][ t]], 
            Times[ 0.026603074225527826, 
              c[ -51][ t]], 
            Times[ 0.038978720157860088, 
              c[ -50][ t]], 
            Times[ 0.049975424961080865, 
              c[ -49][ t]], 
            Times[ 0.059070953080906326, 
              c[ -48][ t]], 
            Times[ 0.065811019881796315, 
              c[ -47][ t]], 
            Times[ 0.069830768673962415, 
              c[ -46][ t]], 
            Times[ 0.070873018952678238, 
              c[ -45][ t]], 
            Times[ 0.068802429876423321, 
              c[ -44][ t]], 
            Times[ 0.063614872548668253, 
              c[ -43][ t]], 
            Times[ 0.055441487066198933, 
              c[ -42][ t]], 
            Times[ 0.044547108751839815, 
              c[ -41][ t]], 
            Times[ 0.031322974491347078, 
              c[ -40][ t]], 
            Times[ 0.016273855731265604, 
              c[ -39][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -38][ t]], 
            Times[ -0.016825511857749401, 
              c[ -37][ t]], 
            Times[ -0.033483179628681567, 
              c[ -36][ t]], 
            Times[ -0.049236278094138941, 
              c[ -35][ t]], 
            Times[ -0.063361699504227528, 
              c[ -34][ t]], 
            Times[ -0.075181213012062598, 
              c[ -33][ t]], 
            Times[ -0.084091858737850814, 
              c[ -32][ t]], 
            Times[ -0.089594193770366884, 
              c[ -31][ t]], 
            Times[ -0.091317159035181589, 
              c[ -30][ t]], 
            Times[ -0.089038438663606695, 
              c[ -29][ t]], 
            Times[ -0.082699334313268744, 
              c[ -28][ t]], 
            Times[ -0.072413370861974122, 
              c[ -27][ t]], 
            Times[ -0.058468080236789913, 
              c[ -26][ t]], 
            Times[ -0.04131966847794722, 
              c[ -25][ t]], 
            Times[ -0.021580547817547879, 
              c[ -24][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -23][ t]], 
            Times[ 0.022561481809254869, 
              c[ -22][ t]], 
            Times[ 0.045163358568919301, 
              c[ -21][ t]], 
            Times[ 0.066820663127759972, 
              c[ -20][ t]], 
            Times[ 0.086542809078944891, 
              c[ -19][ t]], 
            Times[ 0.10337416789158609, 
              c[ -18][ t]], 
            Times[ 0.11643488132933186, 
              c[ -17][ t]], 
            Times[ 0.12496032289024853, 
              c[ -16][ t]], 
            Times[ 0.12833762891430928, 
              c[ -15][ t]], 
            Times[ 0.12613778810677612, 
              c[ -14][ t]], 
            Times[ 0.11814190616181253, 
              c[ -13][ t]], 
            Times[ 0.10436044624225685, 
              c[ -12][ t]], 
            Times[ 0.085044480344421608, 
              c[ -11][ t]], 
            Times[ 0.060688263076985001, 
              c[ -10][ t]], 
            Times[ 0.032022748374425904, 
              c[ -9][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -8][ t]], 
            Times[ -0.034231213779559094, 
              c[ -7][ t]], 
            Times[ -0.06935801494512607, 
              c[ -6][ t]], 
            Times[ -0.1039432537542934, 
              c[ -5][ t]], 
            Times[ -0.13647135277833605, 
              c[ -4][ t]], 
            Times[ -0.16539866862653771, 
              c[ -3][ t]], 
            Times[ -0.18920668216016434, 
              c[ -2][ t]], 
            Times[ -0.20645618564475843, 
              c[ -1][ t]], 
            Times[ -0.21584055771952015, 
              c[ 0][ t]], 
            Times[ -0.21623620818304481, 
              c[ 1][ t]], 
            Times[ -0.206748335783172, 
              c[ 2][ t]], 
            Times[ -0.18675027222298593, 
              c[ 3][ t]], 
            Times[ -0.15591488063143974, 
              c[ 4][ t]], 
            Times[ -0.11423673049785436, 
              c[ 5][ t]], 
            Times[ -0.062044074975450239, 
              c[ 6][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 7][ t]], 
            Times[ 0.070907514257657775, 
              c[ 8][ t]], 
            Times[ 0.14938649372796384, 
              c[ 9][ t]], 
            Times[ 0.23387232094715998, 
              c[ 10][ t]], 
            Times[ 0.32256865202152157, 
              c[ 11][ t]], 
            Times[ 0.41349667156634429, 
              c[ 12][ t]], 
            Times[ 0.50455115242710491, 
              c[ 13][ t]], 
            Times[ 0.59356153372868059, 
              c[ 14][ t]], 
            Times[ 0.67835603854706361, 
              c[ 15][ t]], 
            Times[ 0.75682672864065714, 
              c[ 16][ t]], 
            Times[ 0.82699334313268813, 
              c[ 17][ t]], 
            Times[ 0.88706379305918392, 
              c[ 18][ t]], 
            Times[ 0.93548928378863938, 
              c[ 19][ t]], 
            Times[ 0.9710122092317629, 
              c[ 20][ t]], 
            Times[ 0.99270519960720693, 
              c[ 21][ t]], 
            Times[ 11.615307844727218, 
              c[ 22][ t]], 
            Times[ 0.99270519960720671, 
              c[ 23][ t]], 
            Times[ 0.9710122092317629, 
              c[ 24][ t]], 
            Times[ 0.93548928378863916, 
              c[ 25][ t]], 
            Times[ 0.88706379305918381, 
              c[ 26][ t]], 
            Times[ 0.82699334313268802, 
              c[ 27][ t]], 
            Times[ 0.75682672864065692, 
              c[ 28][ t]], 
            Times[ 0.67835603854706317, 
              c[ 29][ t]], 
            Times[ 0.59356153372868015, 
              c[ 30][ t]], 
            Times[ 0.50455115242710469, 
              c[ 31][ t]], 
            Times[ 0.41349667156634395, 
              c[ 32][ t]], 
            Times[ 0.32256865202152113, 
              c[ 33][ t]], 
            Times[ 0.23387232094715985, 
              c[ 34][ t]], 
            Times[ 0.14938649372796345, 
              c[ 35][ t]], 
            Times[ 0.070907514257657456, 
              c[ 36][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 37][ t]], 
            Times[ -0.062044074975450475, 
              c[ 38][ t]], 
            Times[ -0.11423673049785459, 
              c[ 39][ t]], 
            Times[ -0.15591488063143982, 
              c[ 40][ t]], 
            Times[ -0.18675027222298593, 
              c[ 41][ t]], 
            Times[ -0.20674833578317206, 
              c[ 42][ t]], 
            Times[ -0.21623620818304484, 
              c[ 43][ t]], 
            Times[ -0.21584055771952015, 
              c[ 44][ t]], 
            Times[ -0.20645618564475834, 
              c[ 45][ t]], 
            Times[ -0.18920668216016426, 
              c[ 46][ t]], 
            Times[ -0.16539866862653771, 
              c[ 47][ t]], 
            Times[ -0.13647135277833591, 
              c[ 48][ t]], 
            Times[ -0.10394325375429328, 
              c[ 49][ t]], 
            Times[ -0.06935801494512607, 
              c[ 50][ t]], 
            Times[ -0.034231213779558796, 
              c[ 51][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 52][ t]], 
            Times[ 0.032022748374425904, 
              c[ 53][ t]], 
            Times[ 0.060688263076985223, 
              c[ 54][ t]], 
            Times[ 0.085044480344421705, 
              c[ 55][ t]], 
            Times[ 0.10436044624225685, 
              c[ 56][ t]], 
            Times[ 0.1181419061618126, 
              c[ 57][ t]], 
            Times[ 0.12613778810677614, 
              c[ 58][ t]], 
            Times[ 0.12833762891430928, 
              c[ 59][ t]], 
            Times[ 0.12496032289024847, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "23", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[23]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.05721075023890897`\)\ \(c[\(-60\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-59\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-58\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-57\)]\)[t] - 
            0.04491462243337629`\ \(c[\(-56\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-55\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-54\)]\)[t] - 
            0.013061910521147276`\ \(c[\(-53\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-52\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-51\)]\)[t] + 
            0.026603074225527937`\ \(c[\(-50\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-49\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-48\)]\)[t] + 
            0.0590709530809064`\ \(c[\(-47\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-46\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-45\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-44\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-43\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-42\)]\)[t] + 
            0.055441487066198857`\ \(c[\(-41\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-40\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-39\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-38\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-37\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-36\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-35\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-34\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-33\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-32\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-31\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-30\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-29\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-28\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-27\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-26\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-25\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-24\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-23\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-22\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-21\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-20\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-19\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-18\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-17\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-16\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-15\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-14\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-13\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-12\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-11\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-10\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-9\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-8\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-7\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-6\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-5\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-4\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-3\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-2\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-1\)]\)[t] - 
            0.20645618564475843`\ \(c[0]\)[t] - 
            0.21584055771952015`\ \(c[1]\)[t] - 
            0.21623620818304484`\ \(c[2]\)[t] - 
            0.206748335783172`\ \(c[3]\)[t] - 
            0.186750272222986`\ \(c[4]\)[t] - 
            0.15591488063143982`\ \(c[5]\)[t] - 
            0.11423673049785436`\ \(c[6]\)[t] - 
            0.06204407497545034`\ \(c[7]\)[t] + 
            3.898171832519376`*^-17\ \(c[8]\)[t] + 
            0.07090751425765777`\ \(c[9]\)[t] + 
            0.14938649372796362`\ \(c[10]\)[t] + 
            0.23387232094715985`\ \(c[11]\)[t] + 
            0.3225686520215216`\ \(c[12]\)[t] + 
            0.4134966715663442`\ \(c[13]\)[t] + 
            0.5045511524271047`\ \(c[14]\)[t] + 
            0.5935615337286806`\ \(c[15]\)[t] + 
            0.6783560385470634`\ \(c[16]\)[t] + 
            0.7568267286406569`\ \(c[17]\)[t] + 
            0.8269933431326881`\ \(c[18]\)[t] + 
            0.8870637930591838`\ \(c[19]\)[t] + 
            0.9354892837886392`\ \(c[20]\)[t] + 
            0.9710122092317629`\ \(c[21]\)[t] + 
            0.9927051996072067`\ \(c[22]\)[t] + 
            12.602268284836155`\ \(c[23]\)[t] + 
            0.9927051996072067`\ \(c[24]\)[t] + 
            0.9710122092317629`\ \(c[25]\)[t] + 
            0.9354892837886392`\ \(c[26]\)[t] + 
            0.8870637930591838`\ \(c[27]\)[t] + 
            0.8269933431326881`\ \(c[28]\)[t] + 
            0.7568267286406569`\ \(c[29]\)[t] + 
            0.6783560385470632`\ \(c[30]\)[t] + 
            0.5935615337286806`\ \(c[31]\)[t] + 
            0.5045511524271047`\ \(c[32]\)[t] + 
            0.41349667156634395`\ \(c[33]\)[t] + 
            0.3225686520215216`\ \(c[34]\)[t] + 
            0.23387232094715985`\ \(c[35]\)[t] + 
            0.14938649372796345`\ \(c[36]\)[t] + 
            0.07090751425765777`\ \(c[37]\)[t] + 
            3.898171832519376`*^-17\ \(c[38]\)[t] - 
            0.062044074975450475`\ \(c[39]\)[t] - 
            0.11423673049785436`\ \(c[40]\)[t] - 
            0.15591488063143966`\ \(c[41]\)[t] - 
            0.18675027222298607`\ \(c[42]\)[t] - 
            0.206748335783172`\ \(c[43]\)[t] - 
            0.21623620818304481`\ \(c[44]\)[t] - 
            0.21584055771952013`\ \(c[45]\)[t] - 
            0.20645618564475843`\ \(c[46]\)[t] - 
            0.18920668216016434`\ \(c[47]\)[t] - 
            0.1653986686265376`\ \(c[48]\)[t] - 
            0.13647135277833605`\ \(c[49]\)[t] - 
            0.1039432537542934`\ \(c[50]\)[t] - 
            0.06935801494512592`\ \(c[51]\)[t] - 
            0.03423121377955895`\ \(c[52]\)[t] - 
            1.8033970416801674`*^-16\ \(c[53]\)[t] + 
            0.03202274837442603`\ \(c[54]\)[t] + 
            0.060688263076985105`\ \(c[55]\)[t] + 
            0.08504448034442161`\ \(c[56]\)[t] + 
            0.10436044624225692`\ \(c[57]\)[t] + 
            0.11814190616181255`\ \(c[58]\)[t] + 
            0.12613778810677612`\ \(c[59]\)[t] + 
            0.12833762891430925`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 23, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 23]][ t]], 
          Plus[ 
            Times[ -0.057210750238908967, 
              c[ -60][ t]], 
            Times[ -0.057908442314993203, 
              c[ -59][ t]], 
            Times[ -0.056061239158567186, 
              c[ -58][ t]], 
            Times[ -0.05168708394579296, 
              c[ -57][ t]], 
            Times[ -0.044914622433376288, 
              c[ -56][ t]], 
            Times[ -0.035980357068793781, 
              c[ -55][ t]], 
            Times[ -0.025221096343682053, 
              c[ -54][ t]], 
            Times[ -0.013061910521147276, 
              c[ -53][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -52][ t]], 
            Times[ 0.013414935129827233, 
              c[ -51][ t]], 
            Times[ 0.026603074225527937, 
              c[ -50][ t]], 
            Times[ 0.03897872015785999, 
              c[ -49][ t]], 
            Times[ 0.049975424961080865, 
              c[ -48][ t]], 
            Times[ 0.059070953080906402, 
              c[ -47][ t]], 
            Times[ 0.065811019881796273, 
              c[ -46][ t]], 
            Times[ 0.069830768673962415, 
              c[ -45][ t]], 
            Times[ 0.070873018952678238, 
              c[ -44][ t]], 
            Times[ 0.068802429876423349, 
              c[ -43][ t]], 
            Times[ 0.063614872548668253, 
              c[ -42][ t]], 
            Times[ 0.055441487066198857, 
              c[ -41][ t]], 
            Times[ 0.044547108751839919, 
              c[ -40][ t]], 
            Times[ 0.031322974491347078, 
              c[ -39][ t]], 
            Times[ 0.016273855731265604, 
              c[ -38][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -37][ t]], 
            Times[ -0.016825511857749401, 
              c[ -36][ t]], 
            Times[ -0.033483179628681567, 
              c[ -35][ t]], 
            Times[ -0.049236278094138941, 
              c[ -34][ t]], 
            Times[ -0.063361699504227528, 
              c[ -33][ t]], 
            Times[ -0.075181213012062598, 
              c[ -32][ t]], 
            Times[ -0.084091858737850814, 
              c[ -31][ t]], 
            Times[ -0.089594193770366884, 
              c[ -30][ t]], 
            Times[ -0.091317159035181589, 
              c[ -29][ t]], 
            Times[ -0.089038438663606695, 
              c[ -28][ t]], 
            Times[ -0.082699334313268744, 
              c[ -27][ t]], 
            Times[ -0.072413370861974122, 
              c[ -26][ t]], 
            Times[ -0.058468080236789913, 
              c[ -25][ t]], 
            Times[ -0.04131966847794722, 
              c[ -24][ t]], 
            Times[ -0.021580547817547879, 
              c[ -23][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -22][ t]], 
            Times[ 0.022561481809254869, 
              c[ -21][ t]], 
            Times[ 0.045163358568919301, 
              c[ -20][ t]], 
            Times[ 0.066820663127759972, 
              c[ -19][ t]], 
            Times[ 0.086542809078944891, 
              c[ -18][ t]], 
            Times[ 0.10337416789158609, 
              c[ -17][ t]], 
            Times[ 0.11643488132933186, 
              c[ -16][ t]], 
            Times[ 0.12496032289024853, 
              c[ -15][ t]], 
            Times[ 0.12833762891430928, 
              c[ -14][ t]], 
            Times[ 0.12613778810677614, 
              c[ -13][ t]], 
            Times[ 0.11814190616181255, 
              c[ -12][ t]], 
            Times[ 0.10436044624225685, 
              c[ -11][ t]], 
            Times[ 0.085044480344421705, 
              c[ -10][ t]], 
            Times[ 0.060688263076985105, 
              c[ -9][ t]], 
            Times[ 0.032022748374425904, 
              c[ -8][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -7][ t]], 
            Times[ -0.034231213779558949, 
              c[ -6][ t]], 
            Times[ -0.06935801494512607, 
              c[ -5][ t]], 
            Times[ -0.10394325375429328, 
              c[ -4][ t]], 
            Times[ -0.13647135277833605, 
              c[ -3][ t]], 
            Times[ -0.16539866862653771, 
              c[ -2][ t]], 
            Times[ -0.18920668216016426, 
              c[ -1][ t]], 
            Times[ -0.20645618564475843, 
              c[ 0][ t]], 
            Times[ -0.21584055771952015, 
              c[ 1][ t]], 
            Times[ -0.21623620818304484, 
              c[ 2][ t]], 
            Times[ -0.206748335783172, 
              c[ 3][ t]], 
            Times[ -0.18675027222298601, 
              c[ 4][ t]], 
            Times[ -0.15591488063143982, 
              c[ 5][ t]], 
            Times[ -0.11423673049785436, 
              c[ 6][ t]], 
            Times[ -0.062044074975450343, 
              c[ 7][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 8][ t]], 
            Times[ 0.070907514257657775, 
              c[ 9][ t]], 
            Times[ 0.14938649372796362, 
              c[ 10][ t]], 
            Times[ 0.23387232094715985, 
              c[ 11][ t]], 
            Times[ 0.32256865202152157, 
              c[ 12][ t]], 
            Times[ 0.41349667156634418, 
              c[ 13][ t]], 
            Times[ 0.50455115242710469, 
              c[ 14][ t]], 
            Times[ 0.59356153372868059, 
              c[ 15][ t]], 
            Times[ 0.67835603854706339, 
              c[ 16][ t]], 
            Times[ 0.75682672864065692, 
              c[ 17][ t]], 
            Times[ 0.82699334313268813, 
              c[ 18][ t]], 
            Times[ 0.88706379305918381, 
              c[ 19][ t]], 
            Times[ 0.93548928378863916, 
              c[ 20][ t]], 
            Times[ 0.9710122092317629, 
              c[ 21][ t]], 
            Times[ 0.99270519960720671, 
              c[ 22][ t]], 
            Times[ 12.602268284836155, 
              c[ 23][ t]], 
            Times[ 0.99270519960720671, 
              c[ 24][ t]], 
            Times[ 0.9710122092317629, 
              c[ 25][ t]], 
            Times[ 0.93548928378863916, 
              c[ 26][ t]], 
            Times[ 0.88706379305918381, 
              c[ 27][ t]], 
            Times[ 0.82699334313268813, 
              c[ 28][ t]], 
            Times[ 0.75682672864065692, 
              c[ 29][ t]], 
            Times[ 0.67835603854706317, 
              c[ 30][ t]], 
            Times[ 0.59356153372868059, 
              c[ 31][ t]], 
            Times[ 0.50455115242710469, 
              c[ 32][ t]], 
            Times[ 0.41349667156634395, 
              c[ 33][ t]], 
            Times[ 0.32256865202152157, 
              c[ 34][ t]], 
            Times[ 0.23387232094715985, 
              c[ 35][ t]], 
            Times[ 0.14938649372796345, 
              c[ 36][ t]], 
            Times[ 0.070907514257657775, 
              c[ 37][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 38][ t]], 
            Times[ -0.062044074975450475, 
              c[ 39][ t]], 
            Times[ -0.11423673049785436, 
              c[ 40][ t]], 
            Times[ -0.15591488063143966, 
              c[ 41][ t]], 
            Times[ -0.18675027222298607, 
              c[ 42][ t]], 
            Times[ -0.206748335783172, 
              c[ 43][ t]], 
            Times[ -0.21623620818304481, 
              c[ 44][ t]], 
            Times[ -0.21584055771952013, 
              c[ 45][ t]], 
            Times[ -0.20645618564475843, 
              c[ 46][ t]], 
            Times[ -0.18920668216016434, 
              c[ 47][ t]], 
            Times[ -0.1653986686265376, 
              c[ 48][ t]], 
            Times[ -0.13647135277833605, 
              c[ 49][ t]], 
            Times[ -0.1039432537542934, 
              c[ 50][ t]], 
            Times[ -0.069358014945125918, 
              c[ 51][ t]], 
            Times[ -0.034231213779558949, 
              c[ 52][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 53][ t]], 
            Times[ 0.032022748374426029, 
              c[ 54][ t]], 
            Times[ 0.060688263076985105, 
              c[ 55][ t]], 
            Times[ 0.085044480344421608, 
              c[ 56][ t]], 
            Times[ 0.10436044624225692, 
              c[ 57][ t]], 
            Times[ 0.11814190616181255, 
              c[ 58][ t]], 
            Times[ 0.12613778810677612, 
              c[ 59][ t]], 
            Times[ 0.12833762891430925, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "24", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[24]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.054059052045761224`\)\ \(c[\(-60\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-59\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-58\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-57\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-56\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-55\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-54\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-53\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-52\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-51\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-50\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-49\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-48\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-47\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-46\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-45\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-44\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-43\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-42\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-41\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-40\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-39\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-38\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-37\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-36\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-35\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-34\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-33\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-32\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-31\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-30\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-29\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-28\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-27\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-26\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-25\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-24\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-23\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-22\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-21\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-20\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-19\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-18\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-17\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-16\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-15\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-14\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-13\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-12\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-11\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-10\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-9\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-8\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-7\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-6\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-5\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-4\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-3\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-2\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-1\)]\)[t] - 
            0.18920668216016426`\ \(c[0]\)[t] - 
            0.20645618564475843`\ \(c[1]\)[t] - 
            0.21584055771952013`\ \(c[2]\)[t] - 
            0.21623620818304484`\ \(c[3]\)[t] - 
            0.206748335783172`\ \(c[4]\)[t] - 
            0.18675027222298607`\ \(c[5]\)[t] - 
            0.15591488063143982`\ \(c[6]\)[t] - 
            0.11423673049785445`\ \(c[7]\)[t] - 
            0.062044074975450475`\ \(c[8]\)[t] + 
            3.898171832519376`*^-17\ \(c[9]\)[t] + 
            0.07090751425765762`\ \(c[10]\)[t] + 
            0.14938649372796345`\ \(c[11]\)[t] + 
            0.23387232094715985`\ \(c[12]\)[t] + 
            0.32256865202152135`\ \(c[13]\)[t] + 
            0.41349667156634395`\ \(c[14]\)[t] + 
            0.5045511524271047`\ \(c[15]\)[t] + 
            0.5935615337286803`\ \(c[16]\)[t] + 
            0.6783560385470632`\ \(c[17]\)[t] + 
            0.7568267286406569`\ \(c[18]\)[t] + 
            0.8269933431326881`\ \(c[19]\)[t] + 
            0.8870637930591838`\ \(c[20]\)[t] + 
            0.9354892837886392`\ \(c[21]\)[t] + 
            0.9710122092317629`\ \(c[22]\)[t] + 
            0.9927051996072067`\ \(c[23]\)[t] + 
            13.633093633394378`\ \(c[24]\)[t] + 
            0.9927051996072069`\ \(c[25]\)[t] + 
            0.9710122092317629`\ \(c[26]\)[t] + 
            0.9354892837886392`\ \(c[27]\)[t] + 
            0.8870637930591839`\ \(c[28]\)[t] + 
            0.8269933431326881`\ \(c[29]\)[t] + 
            0.7568267286406569`\ \(c[30]\)[t] + 
            0.6783560385470636`\ \(c[31]\)[t] + 
            0.5935615337286806`\ \(c[32]\)[t] + 
            0.5045511524271047`\ \(c[33]\)[t] + 
            0.4134966715663443`\ \(c[34]\)[t] + 
            0.3225686520215216`\ \(c[35]\)[t] + 
            0.23387232094715985`\ \(c[36]\)[t] + 
            0.14938649372796384`\ \(c[37]\)[t] + 
            0.07090751425765777`\ \(c[38]\)[t] + 
            3.898171832519376`*^-17\ \(c[39]\)[t] - 
            0.06204407497545024`\ \(c[40]\)[t] - 
            0.11423673049785416`\ \(c[41]\)[t] - 
            0.15591488063143982`\ \(c[42]\)[t] - 
            0.18675027222298593`\ \(c[43]\)[t] - 
            0.2067483357831719`\ \(c[44]\)[t] - 
            0.21623620818304484`\ \(c[45]\)[t] - 
            0.21584055771952015`\ \(c[46]\)[t] - 
            0.20645618564475848`\ \(c[47]\)[t] - 
            0.18920668216016426`\ \(c[48]\)[t] - 
            0.1653986686265377`\ \(c[49]\)[t] - 
            0.13647135277833616`\ \(c[50]\)[t] - 
            0.10394325375429328`\ \(c[51]\)[t] - 
            0.06935801494512607`\ \(c[52]\)[t] - 
            0.034231213779559094`\ \(c[53]\)[t] - 
            3.898171832519376`*^-17\ \(c[54]\)[t] + 
            0.032022748374425904`\ \(c[55]\)[t] + 
            0.060688263076985`\ \(c[56]\)[t] + 
            0.0850444803444217`\ \(c[57]\)[t] + 
            0.10436044624225685`\ \(c[58]\)[t] + 
            0.11814190616181253`\ \(c[59]\)[t] + 
            0.12613778810677614`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 24, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 24]][ t]], 
          Plus[ 
            Times[ -0.054059052045761224, 
              c[ -60][ t]], 
            Times[ -0.057210750238908967, 
              c[ -59][ t]], 
            Times[ -0.057908442314993203, 
              c[ -58][ t]], 
            Times[ -0.056061239158567186, 
              c[ -57][ t]], 
            Times[ -0.05168708394579296, 
              c[ -56][ t]], 
            Times[ -0.044914622433376419, 
              c[ -55][ t]], 
            Times[ -0.035980357068793781, 
              c[ -54][ t]], 
            Times[ -0.025221096343682053, 
              c[ -53][ t]], 
            Times[ -0.013061910521147383, 
              c[ -52][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -51][ t]], 
            Times[ 0.013414935129827233, 
              c[ -50][ t]], 
            Times[ 0.026603074225527826, 
              c[ -49][ t]], 
            Times[ 0.03897872015785999, 
              c[ -48][ t]], 
            Times[ 0.049975424961080865, 
              c[ -47][ t]], 
            Times[ 0.059070953080906326, 
              c[ -46][ t]], 
            Times[ 0.065811019881796273, 
              c[ -45][ t]], 
            Times[ 0.069830768673962415, 
              c[ -44][ t]], 
            Times[ 0.070873018952678238, 
              c[ -43][ t]], 
            Times[ 0.068802429876423349, 
              c[ -42][ t]], 
            Times[ 0.063614872548668253, 
              c[ -41][ t]], 
            Times[ 0.055441487066198933, 
              c[ -40][ t]], 
            Times[ 0.044547108751839919, 
              c[ -39][ t]], 
            Times[ 0.031322974491347078, 
              c[ -38][ t]], 
            Times[ 0.016273855731265604, 
              c[ -37][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -36][ t]], 
            Times[ -0.016825511857749401, 
              c[ -35][ t]], 
            Times[ -0.033483179628681567, 
              c[ -34][ t]], 
            Times[ -0.049236278094138941, 
              c[ -33][ t]], 
            Times[ -0.063361699504227528, 
              c[ -32][ t]], 
            Times[ -0.075181213012062598, 
              c[ -31][ t]], 
            Times[ -0.084091858737850814, 
              c[ -30][ t]], 
            Times[ -0.089594193770366884, 
              c[ -29][ t]], 
            Times[ -0.091317159035181589, 
              c[ -28][ t]], 
            Times[ -0.089038438663606695, 
              c[ -27][ t]], 
            Times[ -0.082699334313268744, 
              c[ -26][ t]], 
            Times[ -0.072413370861974122, 
              c[ -25][ t]], 
            Times[ -0.058468080236789913, 
              c[ -24][ t]], 
            Times[ -0.04131966847794722, 
              c[ -23][ t]], 
            Times[ -0.021580547817547879, 
              c[ -22][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -21][ t]], 
            Times[ 0.022561481809254869, 
              c[ -20][ t]], 
            Times[ 0.045163358568919301, 
              c[ -19][ t]], 
            Times[ 0.066820663127759972, 
              c[ -18][ t]], 
            Times[ 0.086542809078944891, 
              c[ -17][ t]], 
            Times[ 0.10337416789158609, 
              c[ -16][ t]], 
            Times[ 0.11643488132933186, 
              c[ -15][ t]], 
            Times[ 0.12496032289024853, 
              c[ -14][ t]], 
            Times[ 0.12833762891430928, 
              c[ -13][ t]], 
            Times[ 0.12613778810677614, 
              c[ -12][ t]], 
            Times[ 0.11814190616181255, 
              c[ -11][ t]], 
            Times[ 0.10436044624225685, 
              c[ -10][ t]], 
            Times[ 0.085044480344421705, 
              c[ -9][ t]], 
            Times[ 0.060688263076985105, 
              c[ -8][ t]], 
            Times[ 0.032022748374425904, 
              c[ -7][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -6][ t]], 
            Times[ -0.034231213779558949, 
              c[ -5][ t]], 
            Times[ -0.069358014945125918, 
              c[ -4][ t]], 
            Times[ -0.10394325375429328, 
              c[ -3][ t]], 
            Times[ -0.13647135277833605, 
              c[ -2][ t]], 
            Times[ -0.1653986686265376, 
              c[ -1][ t]], 
            Times[ -0.18920668216016426, 
              c[ 0][ t]], 
            Times[ -0.20645618564475843, 
              c[ 1][ t]], 
            Times[ -0.21584055771952013, 
              c[ 2][ t]], 
            Times[ -0.21623620818304484, 
              c[ 3][ t]], 
            Times[ -0.206748335783172, 
              c[ 4][ t]], 
            Times[ -0.18675027222298607, 
              c[ 5][ t]], 
            Times[ -0.15591488063143982, 
              c[ 6][ t]], 
            Times[ -0.11423673049785445, 
              c[ 7][ t]], 
            Times[ -0.062044074975450475, 
              c[ 8][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 9][ t]], 
            Times[ 0.070907514257657622, 
              c[ 10][ t]], 
            Times[ 0.14938649372796345, 
              c[ 11][ t]], 
            Times[ 0.23387232094715985, 
              c[ 12][ t]], 
            Times[ 0.32256865202152135, 
              c[ 13][ t]], 
            Times[ 0.41349667156634395, 
              c[ 14][ t]], 
            Times[ 0.50455115242710469, 
              c[ 15][ t]], 
            Times[ 0.59356153372868026, 
              c[ 16][ t]], 
            Times[ 0.67835603854706317, 
              c[ 17][ t]], 
            Times[ 0.75682672864065692, 
              c[ 18][ t]], 
            Times[ 0.82699334313268813, 
              c[ 19][ t]], 
            Times[ 0.88706379305918381, 
              c[ 20][ t]], 
            Times[ 0.93548928378863916, 
              c[ 21][ t]], 
            Times[ 0.9710122092317629, 
              c[ 22][ t]], 
            Times[ 0.99270519960720671, 
              c[ 23][ t]], 
            Times[ 13.633093633394378, 
              c[ 24][ t]], 
            Times[ 0.99270519960720693, 
              c[ 25][ t]], 
            Times[ 0.9710122092317629, 
              c[ 26][ t]], 
            Times[ 0.93548928378863916, 
              c[ 27][ t]], 
            Times[ 0.88706379305918392, 
              c[ 28][ t]], 
            Times[ 0.82699334313268813, 
              c[ 29][ t]], 
            Times[ 0.75682672864065692, 
              c[ 30][ t]], 
            Times[ 0.67835603854706361, 
              c[ 31][ t]], 
            Times[ 0.59356153372868059, 
              c[ 32][ t]], 
            Times[ 0.50455115242710469, 
              c[ 33][ t]], 
            Times[ 0.41349667156634429, 
              c[ 34][ t]], 
            Times[ 0.32256865202152157, 
              c[ 35][ t]], 
            Times[ 0.23387232094715985, 
              c[ 36][ t]], 
            Times[ 0.14938649372796384, 
              c[ 37][ t]], 
            Times[ 0.070907514257657775, 
              c[ 38][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 39][ t]], 
            Times[ -0.062044074975450239, 
              c[ 40][ t]], 
            Times[ -0.11423673049785416, 
              c[ 41][ t]], 
            Times[ -0.15591488063143982, 
              c[ 42][ t]], 
            Times[ -0.18675027222298593, 
              c[ 43][ t]], 
            Times[ -0.20674833578317189, 
              c[ 44][ t]], 
            Times[ -0.21623620818304484, 
              c[ 45][ t]], 
            Times[ -0.21584055771952015, 
              c[ 46][ t]], 
            Times[ -0.20645618564475848, 
              c[ 47][ t]], 
            Times[ -0.18920668216016426, 
              c[ 48][ t]], 
            Times[ -0.16539866862653771, 
              c[ 49][ t]], 
            Times[ -0.13647135277833616, 
              c[ 50][ t]], 
            Times[ -0.10394325375429328, 
              c[ 51][ t]], 
            Times[ -0.06935801494512607, 
              c[ 52][ t]], 
            Times[ -0.034231213779559094, 
              c[ 53][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 54][ t]], 
            Times[ 0.032022748374425904, 
              c[ 55][ t]], 
            Times[ 0.060688263076985001, 
              c[ 56][ t]], 
            Times[ 0.085044480344421705, 
              c[ 57][ t]], 
            Times[ 0.10436044624225685, 
              c[ 58][ t]], 
            Times[ 0.11814190616181253, 
              c[ 59][ t]], 
            Times[ 0.12613778810677614, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "25", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[25]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.04864666724309928`\)\ \(c[\(-60\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-59\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-58\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-57\)]\)[t] - 
            0.05606123915856713`\ \(c[\(-56\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-55\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-54\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-53\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-52\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-51\)]\)[t] + 
            1.5206810699945212`*^-16\ \(c[\(-50\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-49\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-48\)]\)[t] + 
            0.03897872015786009`\ \(c[\(-47\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-46\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-45\)]\)[t] + 
            0.06581101988179631`\ \(c[\(-44\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-43\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-42\)]\)[t] + 
            0.06880242987642332`\ \(c[\(-41\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-40\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-39\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-38\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-37\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-36\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-35\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-34\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-33\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-32\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-31\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-30\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-29\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-28\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-27\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-26\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-25\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-24\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-23\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-22\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-21\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-20\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-19\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-18\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-17\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-16\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-15\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-14\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-13\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-12\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-11\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-10\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-9\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-8\)]\)[t] + 
            0.060688263076985`\ \(c[\(-7\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-6\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-5\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-4\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-3\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-2\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-1\)]\)[t] - 
            0.1653986686265377`\ \(c[0]\)[t] - 
            0.18920668216016434`\ \(c[1]\)[t] - 
            0.20645618564475843`\ \(c[2]\)[t] - 
            0.21584055771952015`\ \(c[3]\)[t] - 
            0.21623620818304481`\ \(c[4]\)[t] - 
            0.206748335783172`\ \(c[5]\)[t] - 
            0.18675027222298593`\ \(c[6]\)[t] - 
            0.15591488063143974`\ \(c[7]\)[t] - 
            0.11423673049785436`\ \(c[8]\)[t] - 
            0.06204407497545024`\ \(c[9]\)[t] + 
            1.8033970416801674`*^-16\ \(c[10]\)[t] + 
            0.07090751425765777`\ \(c[11]\)[t] + 
            0.14938649372796384`\ \(c[12]\)[t] + 
            0.23387232094715998`\ \(c[13]\)[t] + 
            0.3225686520215216`\ \(c[14]\)[t] + 
            0.4134966715663443`\ \(c[15]\)[t] + 
            0.5045511524271049`\ \(c[16]\)[t] + 
            0.5935615337286806`\ \(c[17]\)[t] + 
            0.6783560385470636`\ \(c[18]\)[t] + 
            0.7568267286406571`\ \(c[19]\)[t] + 
            0.8269933431326881`\ \(c[20]\)[t] + 
            0.8870637930591839`\ \(c[21]\)[t] + 
            0.9354892837886392`\ \(c[22]\)[t] + 
            0.9710122092317629`\ \(c[23]\)[t] + 
            0.9927051996072069`\ \(c[24]\)[t] + 
            14.707783890401883`\ \(c[25]\)[t] + 
            0.9927051996072067`\ \(c[26]\)[t] + 
            0.9710122092317629`\ \(c[27]\)[t] + 
            0.9354892837886392`\ \(c[28]\)[t] + 
            0.8870637930591838`\ \(c[29]\)[t] + 
            0.826993343132688`\ \(c[30]\)[t] + 
            0.7568267286406569`\ \(c[31]\)[t] + 
            0.6783560385470632`\ \(c[32]\)[t] + 
            0.5935615337286801`\ \(c[33]\)[t] + 
            0.5045511524271047`\ \(c[34]\)[t] + 
            0.41349667156634395`\ \(c[35]\)[t] + 
            0.32256865202152113`\ \(c[36]\)[t] + 
            0.23387232094715985`\ \(c[37]\)[t] + 
            0.14938649372796345`\ \(c[38]\)[t] + 
            0.07090751425765746`\ \(c[39]\)[t] + 
            3.898171832519376`*^-17\ \(c[40]\)[t] - 
            0.06204407497545024`\ \(c[41]\)[t] - 
            0.11423673049785459`\ \(c[42]\)[t] - 
            0.15591488063143982`\ \(c[43]\)[t] - 
            0.18675027222298593`\ \(c[44]\)[t] - 
            0.20674833578317206`\ \(c[45]\)[t] - 
            0.21623620818304484`\ \(c[46]\)[t] - 
            0.21584055771952015`\ \(c[47]\)[t] - 
            0.20645618564475834`\ \(c[48]\)[t] - 
            0.18920668216016426`\ \(c[49]\)[t] - 
            0.1653986686265377`\ \(c[50]\)[t] - 
            0.1364713527783359`\ \(c[51]\)[t] - 
            0.10394325375429328`\ \(c[52]\)[t] - 
            0.06935801494512607`\ \(c[53]\)[t] - 
            0.034231213779558796`\ \(c[54]\)[t] - 
            3.898171832519376`*^-17\ \(c[55]\)[t] + 
            0.032022748374425904`\ \(c[56]\)[t] + 
            0.06068826307698522`\ \(c[57]\)[t] + 
            0.0850444803444217`\ \(c[58]\)[t] + 
            0.10436044624225685`\ \(c[59]\)[t] + 
            0.1181419061618126`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 25, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 25]][ t]], 
          Plus[ 
            Times[ -0.048646667243099281, 
              c[ -60][ t]], 
            Times[ -0.054059052045761224, 
              c[ -59][ t]], 
            Times[ -0.057210750238908967, 
              c[ -58][ t]], 
            Times[ -0.057908442314993203, 
              c[ -57][ t]], 
            Times[ -0.05606123915856713, 
              c[ -56][ t]], 
            Times[ -0.05168708394579296, 
              c[ -55][ t]], 
            Times[ -0.044914622433376419, 
              c[ -54][ t]], 
            Times[ -0.035980357068793781, 
              c[ -53][ t]], 
            Times[ -0.025221096343682053, 
              c[ -52][ t]], 
            Times[ -0.013061910521147383, 
              c[ -51][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ -50][ t]], 
            Times[ 0.013414935129827233, 
              c[ -49][ t]], 
            Times[ 0.026603074225527826, 
              c[ -48][ t]], 
            Times[ 0.038978720157860088, 
              c[ -47][ t]], 
            Times[ 0.049975424961080865, 
              c[ -46][ t]], 
            Times[ 0.059070953080906326, 
              c[ -45][ t]], 
            Times[ 0.065811019881796315, 
              c[ -44][ t]], 
            Times[ 0.069830768673962415, 
              c[ -43][ t]], 
            Times[ 0.070873018952678238, 
              c[ -42][ t]], 
            Times[ 0.068802429876423321, 
              c[ -41][ t]], 
            Times[ 0.063614872548668253, 
              c[ -40][ t]], 
            Times[ 0.055441487066198933, 
              c[ -39][ t]], 
            Times[ 0.044547108751839919, 
              c[ -38][ t]], 
            Times[ 0.031322974491347078, 
              c[ -37][ t]], 
            Times[ 0.016273855731265604, 
              c[ -36][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -35][ t]], 
            Times[ -0.016825511857749401, 
              c[ -34][ t]], 
            Times[ -0.033483179628681567, 
              c[ -33][ t]], 
            Times[ -0.049236278094138941, 
              c[ -32][ t]], 
            Times[ -0.063361699504227528, 
              c[ -31][ t]], 
            Times[ -0.075181213012062598, 
              c[ -30][ t]], 
            Times[ -0.084091858737850814, 
              c[ -29][ t]], 
            Times[ -0.089594193770366884, 
              c[ -28][ t]], 
            Times[ -0.091317159035181589, 
              c[ -27][ t]], 
            Times[ -0.089038438663606695, 
              c[ -26][ t]], 
            Times[ -0.082699334313268744, 
              c[ -25][ t]], 
            Times[ -0.072413370861974122, 
              c[ -24][ t]], 
            Times[ -0.058468080236789913, 
              c[ -23][ t]], 
            Times[ -0.04131966847794722, 
              c[ -22][ t]], 
            Times[ -0.021580547817547879, 
              c[ -21][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -20][ t]], 
            Times[ 0.022561481809254869, 
              c[ -19][ t]], 
            Times[ 0.045163358568919301, 
              c[ -18][ t]], 
            Times[ 0.066820663127759972, 
              c[ -17][ t]], 
            Times[ 0.086542809078944891, 
              c[ -16][ t]], 
            Times[ 0.10337416789158609, 
              c[ -15][ t]], 
            Times[ 0.11643488132933186, 
              c[ -14][ t]], 
            Times[ 0.12496032289024853, 
              c[ -13][ t]], 
            Times[ 0.12833762891430928, 
              c[ -12][ t]], 
            Times[ 0.12613778810677612, 
              c[ -11][ t]], 
            Times[ 0.11814190616181253, 
              c[ -10][ t]], 
            Times[ 0.10436044624225685, 
              c[ -9][ t]], 
            Times[ 0.085044480344421608, 
              c[ -8][ t]], 
            Times[ 0.060688263076985001, 
              c[ -7][ t]], 
            Times[ 0.032022748374425904, 
              c[ -6][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -5][ t]], 
            Times[ -0.034231213779558949, 
              c[ -4][ t]], 
            Times[ -0.06935801494512607, 
              c[ -3][ t]], 
            Times[ -0.1039432537542934, 
              c[ -2][ t]], 
            Times[ -0.13647135277833605, 
              c[ -1][ t]], 
            Times[ -0.16539866862653771, 
              c[ 0][ t]], 
            Times[ -0.18920668216016434, 
              c[ 1][ t]], 
            Times[ -0.20645618564475843, 
              c[ 2][ t]], 
            Times[ -0.21584055771952015, 
              c[ 3][ t]], 
            Times[ -0.21623620818304481, 
              c[ 4][ t]], 
            Times[ -0.206748335783172, 
              c[ 5][ t]], 
            Times[ -0.18675027222298593, 
              c[ 6][ t]], 
            Times[ -0.15591488063143974, 
              c[ 7][ t]], 
            Times[ -0.11423673049785436, 
              c[ 8][ t]], 
            Times[ -0.062044074975450239, 
              c[ 9][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 10][ t]], 
            Times[ 0.070907514257657775, 
              c[ 11][ t]], 
            Times[ 0.14938649372796384, 
              c[ 12][ t]], 
            Times[ 0.23387232094715998, 
              c[ 13][ t]], 
            Times[ 0.32256865202152157, 
              c[ 14][ t]], 
            Times[ 0.41349667156634429, 
              c[ 15][ t]], 
            Times[ 0.50455115242710491, 
              c[ 16][ t]], 
            Times[ 0.59356153372868059, 
              c[ 17][ t]], 
            Times[ 0.67835603854706361, 
              c[ 18][ t]], 
            Times[ 0.75682672864065714, 
              c[ 19][ t]], 
            Times[ 0.82699334313268813, 
              c[ 20][ t]], 
            Times[ 0.88706379305918392, 
              c[ 21][ t]], 
            Times[ 0.93548928378863916, 
              c[ 22][ t]], 
            Times[ 0.9710122092317629, 
              c[ 23][ t]], 
            Times[ 0.99270519960720693, 
              c[ 24][ t]], 
            Times[ 14.707783890401883, 
              c[ 25][ t]], 
            Times[ 0.99270519960720671, 
              c[ 26][ t]], 
            Times[ 0.9710122092317629, 
              c[ 27][ t]], 
            Times[ 0.93548928378863916, 
              c[ 28][ t]], 
            Times[ 0.88706379305918381, 
              c[ 29][ t]], 
            Times[ 0.82699334313268802, 
              c[ 30][ t]], 
            Times[ 0.75682672864065692, 
              c[ 31][ t]], 
            Times[ 0.67835603854706317, 
              c[ 32][ t]], 
            Times[ 0.59356153372868015, 
              c[ 33][ t]], 
            Times[ 0.50455115242710469, 
              c[ 34][ t]], 
            Times[ 0.41349667156634395, 
              c[ 35][ t]], 
            Times[ 0.32256865202152113, 
              c[ 36][ t]], 
            Times[ 0.23387232094715985, 
              c[ 37][ t]], 
            Times[ 0.14938649372796345, 
              c[ 38][ t]], 
            Times[ 0.070907514257657456, 
              c[ 39][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 40][ t]], 
            Times[ -0.062044074975450239, 
              c[ 41][ t]], 
            Times[ -0.11423673049785459, 
              c[ 42][ t]], 
            Times[ -0.15591488063143982, 
              c[ 43][ t]], 
            Times[ -0.18675027222298593, 
              c[ 44][ t]], 
            Times[ -0.20674833578317206, 
              c[ 45][ t]], 
            Times[ -0.21623620818304484, 
              c[ 46][ t]], 
            Times[ -0.21584055771952015, 
              c[ 47][ t]], 
            Times[ -0.20645618564475834, 
              c[ 48][ t]], 
            Times[ -0.18920668216016426, 
              c[ 49][ t]], 
            Times[ -0.16539866862653771, 
              c[ 50][ t]], 
            Times[ -0.13647135277833591, 
              c[ 51][ t]], 
            Times[ -0.10394325375429328, 
              c[ 52][ t]], 
            Times[ -0.06935801494512607, 
              c[ 53][ t]], 
            Times[ -0.034231213779558796, 
              c[ 54][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 55][ t]], 
            Times[ 0.032022748374425904, 
              c[ 56][ t]], 
            Times[ 0.060688263076985223, 
              c[ 57][ t]], 
            Times[ 0.085044480344421705, 
              c[ 58][ t]], 
            Times[ 0.10436044624225685, 
              c[ 59][ t]], 
            Times[ 0.1181419061618126, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "26", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[26]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.04125878107252025`\)\ \(c[\(-60\)]\)[t] - 
            0.0486466672430994`\ \(c[\(-59\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-58\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-57\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-56\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-55\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-54\)]\)[t] - 
            0.04491462243337629`\ \(c[\(-53\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-52\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-51\)]\)[t] - 
            0.013061910521147276`\ \(c[\(-50\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-49\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-48\)]\)[t] + 
            0.026603074225527937`\ \(c[\(-47\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-46\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-45\)]\)[t] + 
            0.0590709530809064`\ \(c[\(-44\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-43\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-42\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-41\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-40\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-39\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-38\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-37\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-36\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-35\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-34\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-33\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-32\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-31\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-30\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-29\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-28\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-27\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-26\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-25\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-24\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-23\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-22\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-21\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-20\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-19\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-18\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-17\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-16\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-15\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-14\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-13\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-12\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-11\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-10\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-9\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-8\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-7\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-6\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-5\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-4\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-3\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-2\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-1\)]\)[t] - 
            0.13647135277833605`\ \(c[0]\)[t] - 
            0.1653986686265377`\ \(c[1]\)[t] - 
            0.18920668216016426`\ \(c[2]\)[t] - 
            0.20645618564475843`\ \(c[3]\)[t] - 
            0.21584055771952015`\ \(c[4]\)[t] - 
            0.21623620818304484`\ \(c[5]\)[t] - 
            0.206748335783172`\ \(c[6]\)[t] - 
            0.186750272222986`\ \(c[7]\)[t] - 
            0.15591488063143982`\ \(c[8]\)[t] - 
            0.11423673049785436`\ \(c[9]\)[t] - 
            0.06204407497545034`\ \(c[10]\)[t] + 
            3.898171832519376`*^-17\ \(c[11]\)[t] + 
            0.07090751425765777`\ \(c[12]\)[t] + 
            0.14938649372796362`\ \(c[13]\)[t] + 
            0.23387232094715985`\ \(c[14]\)[t] + 
            0.3225686520215216`\ \(c[15]\)[t] + 
            0.4134966715663442`\ \(c[16]\)[t] + 
            0.5045511524271047`\ \(c[17]\)[t] + 
            0.5935615337286806`\ \(c[18]\)[t] + 
            0.6783560385470634`\ \(c[19]\)[t] + 
            0.7568267286406569`\ \(c[20]\)[t] + 
            0.8269933431326881`\ \(c[21]\)[t] + 
            0.8870637930591838`\ \(c[22]\)[t] + 
            0.9354892837886392`\ \(c[23]\)[t] + 
            0.9710122092317629`\ \(c[24]\)[t] + 
            0.9927051996072067`\ \(c[25]\)[t] + 
            15.826339055858679`\ \(c[26]\)[t] + 
            0.9927051996072067`\ \(c[27]\)[t] + 
            0.9710122092317629`\ \(c[28]\)[t] + 
            0.9354892837886392`\ \(c[29]\)[t] + 
            0.8870637930591838`\ \(c[30]\)[t] + 
            0.8269933431326881`\ \(c[31]\)[t] + 
            0.7568267286406569`\ \(c[32]\)[t] + 
            0.6783560385470632`\ \(c[33]\)[t] + 
            0.5935615337286806`\ \(c[34]\)[t] + 
            0.5045511524271047`\ \(c[35]\)[t] + 
            0.41349667156634395`\ \(c[36]\)[t] + 
            0.3225686520215216`\ \(c[37]\)[t] + 
            0.23387232094715985`\ \(c[38]\)[t] + 
            0.14938649372796345`\ \(c[39]\)[t] + 
            0.07090751425765777`\ \(c[40]\)[t] + 
            3.216976900108398`*^-16\ \(c[41]\)[t] - 
            0.062044074975450475`\ \(c[42]\)[t] - 
            0.11423673049785436`\ \(c[43]\)[t] - 
            0.15591488063143966`\ \(c[44]\)[t] - 
            0.18675027222298607`\ \(c[45]\)[t] - 
            0.206748335783172`\ \(c[46]\)[t] - 
            0.21623620818304481`\ \(c[47]\)[t] - 
            0.21584055771952013`\ \(c[48]\)[t] - 
            0.20645618564475843`\ \(c[49]\)[t] - 
            0.18920668216016434`\ \(c[50]\)[t] - 
            0.1653986686265376`\ \(c[51]\)[t] - 
            0.13647135277833605`\ \(c[52]\)[t] - 
            0.1039432537542934`\ \(c[53]\)[t] - 
            0.06935801494512592`\ \(c[54]\)[t] - 
            0.03423121377955895`\ \(c[55]\)[t] - 
            1.8033970416801674`*^-16\ \(c[56]\)[t] + 
            0.03202274837442603`\ \(c[57]\)[t] + 
            0.060688263076985105`\ \(c[58]\)[t] + 
            0.08504448034442161`\ \(c[59]\)[t] + 
            0.10436044624225692`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 26, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 26]][ t]], 
          Plus[ 
            Times[ -0.041258781072520248, 
              c[ -60][ t]], 
            Times[ -0.048646667243099399, 
              c[ -59][ t]], 
            Times[ -0.054059052045761224, 
              c[ -58][ t]], 
            Times[ -0.057210750238908967, 
              c[ -57][ t]], 
            Times[ -0.057908442314993203, 
              c[ -56][ t]], 
            Times[ -0.056061239158567186, 
              c[ -55][ t]], 
            Times[ -0.05168708394579296, 
              c[ -54][ t]], 
            Times[ -0.044914622433376288, 
              c[ -53][ t]], 
            Times[ -0.035980357068793781, 
              c[ -52][ t]], 
            Times[ -0.025221096343682053, 
              c[ -51][ t]], 
            Times[ -0.013061910521147276, 
              c[ -50][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -49][ t]], 
            Times[ 0.013414935129827233, 
              c[ -48][ t]], 
            Times[ 0.026603074225527937, 
              c[ -47][ t]], 
            Times[ 0.03897872015785999, 
              c[ -46][ t]], 
            Times[ 0.049975424961080865, 
              c[ -45][ t]], 
            Times[ 0.059070953080906402, 
              c[ -44][ t]], 
            Times[ 0.065811019881796273, 
              c[ -43][ t]], 
            Times[ 0.069830768673962415, 
              c[ -42][ t]], 
            Times[ 0.070873018952678238, 
              c[ -41][ t]], 
            Times[ 0.068802429876423349, 
              c[ -40][ t]], 
            Times[ 0.063614872548668253, 
              c[ -39][ t]], 
            Times[ 0.055441487066198933, 
              c[ -38][ t]], 
            Times[ 0.044547108751839919, 
              c[ -37][ t]], 
            Times[ 0.031322974491347078, 
              c[ -36][ t]], 
            Times[ 0.016273855731265604, 
              c[ -35][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -34][ t]], 
            Times[ -0.016825511857749401, 
              c[ -33][ t]], 
            Times[ -0.033483179628681567, 
              c[ -32][ t]], 
            Times[ -0.049236278094138941, 
              c[ -31][ t]], 
            Times[ -0.063361699504227528, 
              c[ -30][ t]], 
            Times[ -0.075181213012062598, 
              c[ -29][ t]], 
            Times[ -0.084091858737850814, 
              c[ -28][ t]], 
            Times[ -0.089594193770366884, 
              c[ -27][ t]], 
            Times[ -0.091317159035181589, 
              c[ -26][ t]], 
            Times[ -0.089038438663606695, 
              c[ -25][ t]], 
            Times[ -0.082699334313268744, 
              c[ -24][ t]], 
            Times[ -0.072413370861974122, 
              c[ -23][ t]], 
            Times[ -0.058468080236789913, 
              c[ -22][ t]], 
            Times[ -0.04131966847794722, 
              c[ -21][ t]], 
            Times[ -0.021580547817547879, 
              c[ -20][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -19][ t]], 
            Times[ 0.022561481809254869, 
              c[ -18][ t]], 
            Times[ 0.045163358568919301, 
              c[ -17][ t]], 
            Times[ 0.066820663127759972, 
              c[ -16][ t]], 
            Times[ 0.086542809078944891, 
              c[ -15][ t]], 
            Times[ 0.10337416789158609, 
              c[ -14][ t]], 
            Times[ 0.11643488132933186, 
              c[ -13][ t]], 
            Times[ 0.12496032289024853, 
              c[ -12][ t]], 
            Times[ 0.12833762891430928, 
              c[ -11][ t]], 
            Times[ 0.12613778810677614, 
              c[ -10][ t]], 
            Times[ 0.11814190616181255, 
              c[ -9][ t]], 
            Times[ 0.10436044624225685, 
              c[ -8][ t]], 
            Times[ 0.085044480344421705, 
              c[ -7][ t]], 
            Times[ 0.060688263076985105, 
              c[ -6][ t]], 
            Times[ 0.032022748374425904, 
              c[ -5][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -4][ t]], 
            Times[ -0.034231213779558949, 
              c[ -3][ t]], 
            Times[ -0.06935801494512607, 
              c[ -2][ t]], 
            Times[ -0.10394325375429328, 
              c[ -1][ t]], 
            Times[ -0.13647135277833605, 
              c[ 0][ t]], 
            Times[ -0.16539866862653771, 
              c[ 1][ t]], 
            Times[ -0.18920668216016426, 
              c[ 2][ t]], 
            Times[ -0.20645618564475843, 
              c[ 3][ t]], 
            Times[ -0.21584055771952015, 
              c[ 4][ t]], 
            Times[ -0.21623620818304484, 
              c[ 5][ t]], 
            Times[ -0.206748335783172, 
              c[ 6][ t]], 
            Times[ -0.18675027222298601, 
              c[ 7][ t]], 
            Times[ -0.15591488063143982, 
              c[ 8][ t]], 
            Times[ -0.11423673049785436, 
              c[ 9][ t]], 
            Times[ -0.062044074975450343, 
              c[ 10][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 11][ t]], 
            Times[ 0.070907514257657775, 
              c[ 12][ t]], 
            Times[ 0.14938649372796362, 
              c[ 13][ t]], 
            Times[ 0.23387232094715985, 
              c[ 14][ t]], 
            Times[ 0.32256865202152157, 
              c[ 15][ t]], 
            Times[ 0.41349667156634418, 
              c[ 16][ t]], 
            Times[ 0.50455115242710469, 
              c[ 17][ t]], 
            Times[ 0.59356153372868059, 
              c[ 18][ t]], 
            Times[ 0.67835603854706339, 
              c[ 19][ t]], 
            Times[ 0.75682672864065692, 
              c[ 20][ t]], 
            Times[ 0.82699334313268813, 
              c[ 21][ t]], 
            Times[ 0.88706379305918381, 
              c[ 22][ t]], 
            Times[ 0.93548928378863916, 
              c[ 23][ t]], 
            Times[ 0.9710122092317629, 
              c[ 24][ t]], 
            Times[ 0.99270519960720671, 
              c[ 25][ t]], 
            Times[ 15.826339055858679, 
              c[ 26][ t]], 
            Times[ 0.99270519960720671, 
              c[ 27][ t]], 
            Times[ 0.9710122092317629, 
              c[ 28][ t]], 
            Times[ 0.93548928378863916, 
              c[ 29][ t]], 
            Times[ 0.88706379305918381, 
              c[ 30][ t]], 
            Times[ 0.82699334313268813, 
              c[ 31][ t]], 
            Times[ 0.75682672864065692, 
              c[ 32][ t]], 
            Times[ 0.67835603854706317, 
              c[ 33][ t]], 
            Times[ 0.59356153372868059, 
              c[ 34][ t]], 
            Times[ 0.50455115242710469, 
              c[ 35][ t]], 
            Times[ 0.41349667156634395, 
              c[ 36][ t]], 
            Times[ 0.32256865202152157, 
              c[ 37][ t]], 
            Times[ 0.23387232094715985, 
              c[ 38][ t]], 
            Times[ 0.14938649372796345, 
              c[ 39][ t]], 
            Times[ 0.070907514257657775, 
              c[ 40][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ 41][ t]], 
            Times[ -0.062044074975450475, 
              c[ 42][ t]], 
            Times[ -0.11423673049785436, 
              c[ 43][ t]], 
            Times[ -0.15591488063143966, 
              c[ 44][ t]], 
            Times[ -0.18675027222298607, 
              c[ 45][ t]], 
            Times[ -0.206748335783172, 
              c[ 46][ t]], 
            Times[ -0.21623620818304481, 
              c[ 47][ t]], 
            Times[ -0.21584055771952013, 
              c[ 48][ t]], 
            Times[ -0.20645618564475843, 
              c[ 49][ t]], 
            Times[ -0.18920668216016434, 
              c[ 50][ t]], 
            Times[ -0.1653986686265376, 
              c[ 51][ t]], 
            Times[ -0.13647135277833605, 
              c[ 52][ t]], 
            Times[ -0.1039432537542934, 
              c[ 53][ t]], 
            Times[ -0.069358014945125918, 
              c[ 54][ t]], 
            Times[ -0.034231213779558949, 
              c[ 55][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 56][ t]], 
            Times[ 0.032022748374426029, 
              c[ 57][ t]], 
            Times[ 0.060688263076985105, 
              c[ 58][ t]], 
            Times[ 0.085044480344421608, 
              c[ 59][ t]], 
            Times[ 0.10436044624225692, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "27", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[27]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.03225825116512552`\)\ \(c[\(-60\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-59\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-58\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-57\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-56\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-55\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-54\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-53\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-52\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-51\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-50\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-49\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-48\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-47\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-46\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-45\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-44\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-43\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-42\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-41\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-40\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-39\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-38\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-37\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-36\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-35\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-34\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-33\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-32\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-31\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-30\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-29\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-28\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-27\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-26\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-25\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-24\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-23\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-22\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-21\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-20\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-19\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-18\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-17\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-16\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-15\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-14\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-13\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-12\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-11\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-10\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-9\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-8\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-7\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-6\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-5\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-4\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-3\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-2\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-1\)]\)[t] - 
            0.10394325375429328`\ \(c[0]\)[t] - 
            0.13647135277833605`\ \(c[1]\)[t] - 
            0.1653986686265376`\ \(c[2]\)[t] - 
            0.18920668216016426`\ \(c[3]\)[t] - 
            0.20645618564475843`\ \(c[4]\)[t] - 
            0.21584055771952013`\ \(c[5]\)[t] - 
            0.21623620818304484`\ \(c[6]\)[t] - 
            0.20674833578317206`\ \(c[7]\)[t] - 
            0.18675027222298607`\ \(c[8]\)[t] - 
            0.15591488063143982`\ \(c[9]\)[t] - 
            0.11423673049785445`\ \(c[10]\)[t] - 
            0.062044074975450475`\ \(c[11]\)[t] + 
            3.898171832519376`*^-17\ \(c[12]\)[t] + 
            0.07090751425765762`\ \(c[13]\)[t] + 
            0.14938649372796345`\ \(c[14]\)[t] + 
            0.23387232094715985`\ \(c[15]\)[t] + 
            0.32256865202152135`\ \(c[16]\)[t] + 
            0.41349667156634395`\ \(c[17]\)[t] + 
            0.5045511524271047`\ \(c[18]\)[t] + 
            0.5935615337286803`\ \(c[19]\)[t] + 
            0.6783560385470632`\ \(c[20]\)[t] + 
            0.7568267286406569`\ \(c[21]\)[t] + 
            0.826993343132688`\ \(c[22]\)[t] + 
            0.8870637930591838`\ \(c[23]\)[t] + 
            0.9354892837886392`\ \(c[24]\)[t] + 
            0.9710122092317629`\ \(c[25]\)[t] + 
            0.9927051996072067`\ \(c[26]\)[t] + 
            16.98875912976476`\ \(c[27]\)[t] + 
            0.9927051996072069`\ \(c[28]\)[t] + 
            0.9710122092317629`\ \(c[29]\)[t] + 
            0.9354892837886392`\ \(c[30]\)[t] + 
            0.8870637930591839`\ \(c[31]\)[t] + 
            0.8269933431326881`\ \(c[32]\)[t] + 
            0.7568267286406569`\ \(c[33]\)[t] + 
            0.6783560385470636`\ \(c[34]\)[t] + 
            0.5935615337286806`\ \(c[35]\)[t] + 
            0.5045511524271047`\ \(c[36]\)[t] + 
            0.4134966715663443`\ \(c[37]\)[t] + 
            0.3225686520215216`\ \(c[38]\)[t] + 
            0.23387232094715985`\ \(c[39]\)[t] + 
            0.14938649372796384`\ \(c[40]\)[t] + 
            0.0709075142576581`\ \(c[41]\)[t] + 
            3.898171832519376`*^-17\ \(c[42]\)[t] - 
            0.06204407497545024`\ \(c[43]\)[t] - 
            0.11423673049785416`\ \(c[44]\)[t] - 
            0.15591488063143982`\ \(c[45]\)[t] - 
            0.18675027222298593`\ \(c[46]\)[t] - 
            0.2067483357831719`\ \(c[47]\)[t] - 
            0.21623620818304484`\ \(c[48]\)[t] - 
            0.21584055771952015`\ \(c[49]\)[t] - 
            0.20645618564475848`\ \(c[50]\)[t] - 
            0.18920668216016426`\ \(c[51]\)[t] - 
            0.1653986686265377`\ \(c[52]\)[t] - 
            0.13647135277833616`\ \(c[53]\)[t] - 
            0.10394325375429328`\ \(c[54]\)[t] - 
            0.06935801494512607`\ \(c[55]\)[t] - 
            0.034231213779559094`\ \(c[56]\)[t] - 
            3.898171832519376`*^-17\ \(c[57]\)[t] + 
            0.032022748374425904`\ \(c[58]\)[t] + 
            0.060688263076985`\ \(c[59]\)[t] + 
            0.0850444803444217`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 27, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 27]][ t]], 
          Plus[ 
            Times[ -0.032258251165125519, 
              c[ -60][ t]], 
            Times[ -0.041258781072520248, 
              c[ -59][ t]], 
            Times[ -0.048646667243099281, 
              c[ -58][ t]], 
            Times[ -0.054059052045761224, 
              c[ -57][ t]], 
            Times[ -0.057210750238908967, 
              c[ -56][ t]], 
            Times[ -0.057908442314993203, 
              c[ -55][ t]], 
            Times[ -0.056061239158567186, 
              c[ -54][ t]], 
            Times[ -0.05168708394579296, 
              c[ -53][ t]], 
            Times[ -0.044914622433376419, 
              c[ -52][ t]], 
            Times[ -0.035980357068793781, 
              c[ -51][ t]], 
            Times[ -0.025221096343682053, 
              c[ -50][ t]], 
            Times[ -0.013061910521147383, 
              c[ -49][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -48][ t]], 
            Times[ 0.013414935129827233, 
              c[ -47][ t]], 
            Times[ 0.026603074225527826, 
              c[ -46][ t]], 
            Times[ 0.03897872015785999, 
              c[ -45][ t]], 
            Times[ 0.049975424961080865, 
              c[ -44][ t]], 
            Times[ 0.059070953080906326, 
              c[ -43][ t]], 
            Times[ 0.065811019881796273, 
              c[ -42][ t]], 
            Times[ 0.069830768673962415, 
              c[ -41][ t]], 
            Times[ 0.070873018952678238, 
              c[ -40][ t]], 
            Times[ 0.068802429876423349, 
              c[ -39][ t]], 
            Times[ 0.063614872548668253, 
              c[ -38][ t]], 
            Times[ 0.055441487066198933, 
              c[ -37][ t]], 
            Times[ 0.044547108751839919, 
              c[ -36][ t]], 
            Times[ 0.031322974491347078, 
              c[ -35][ t]], 
            Times[ 0.016273855731265604, 
              c[ -34][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -33][ t]], 
            Times[ -0.016825511857749401, 
              c[ -32][ t]], 
            Times[ -0.033483179628681567, 
              c[ -31][ t]], 
            Times[ -0.049236278094138941, 
              c[ -30][ t]], 
            Times[ -0.063361699504227528, 
              c[ -29][ t]], 
            Times[ -0.075181213012062598, 
              c[ -28][ t]], 
            Times[ -0.084091858737850814, 
              c[ -27][ t]], 
            Times[ -0.089594193770366884, 
              c[ -26][ t]], 
            Times[ -0.091317159035181589, 
              c[ -25][ t]], 
            Times[ -0.089038438663606695, 
              c[ -24][ t]], 
            Times[ -0.082699334313268744, 
              c[ -23][ t]], 
            Times[ -0.072413370861974122, 
              c[ -22][ t]], 
            Times[ -0.058468080236789913, 
              c[ -21][ t]], 
            Times[ -0.04131966847794722, 
              c[ -20][ t]], 
            Times[ -0.021580547817547879, 
              c[ -19][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -18][ t]], 
            Times[ 0.022561481809254869, 
              c[ -17][ t]], 
            Times[ 0.045163358568919301, 
              c[ -16][ t]], 
            Times[ 0.066820663127759972, 
              c[ -15][ t]], 
            Times[ 0.086542809078944891, 
              c[ -14][ t]], 
            Times[ 0.10337416789158609, 
              c[ -13][ t]], 
            Times[ 0.11643488132933186, 
              c[ -12][ t]], 
            Times[ 0.12496032289024853, 
              c[ -11][ t]], 
            Times[ 0.12833762891430928, 
              c[ -10][ t]], 
            Times[ 0.12613778810677614, 
              c[ -9][ t]], 
            Times[ 0.11814190616181255, 
              c[ -8][ t]], 
            Times[ 0.10436044624225685, 
              c[ -7][ t]], 
            Times[ 0.085044480344421705, 
              c[ -6][ t]], 
            Times[ 0.060688263076985105, 
              c[ -5][ t]], 
            Times[ 0.032022748374426029, 
              c[ -4][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -3][ t]], 
            Times[ -0.034231213779558949, 
              c[ -2][ t]], 
            Times[ -0.069358014945125918, 
              c[ -1][ t]], 
            Times[ -0.10394325375429328, 
              c[ 0][ t]], 
            Times[ -0.13647135277833605, 
              c[ 1][ t]], 
            Times[ -0.1653986686265376, 
              c[ 2][ t]], 
            Times[ -0.18920668216016426, 
              c[ 3][ t]], 
            Times[ -0.20645618564475843, 
              c[ 4][ t]], 
            Times[ -0.21584055771952013, 
              c[ 5][ t]], 
            Times[ -0.21623620818304484, 
              c[ 6][ t]], 
            Times[ -0.20674833578317206, 
              c[ 7][ t]], 
            Times[ -0.18675027222298607, 
              c[ 8][ t]], 
            Times[ -0.15591488063143982, 
              c[ 9][ t]], 
            Times[ -0.11423673049785445, 
              c[ 10][ t]], 
            Times[ -0.062044074975450475, 
              c[ 11][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 12][ t]], 
            Times[ 0.070907514257657622, 
              c[ 13][ t]], 
            Times[ 0.14938649372796345, 
              c[ 14][ t]], 
            Times[ 0.23387232094715985, 
              c[ 15][ t]], 
            Times[ 0.32256865202152135, 
              c[ 16][ t]], 
            Times[ 0.41349667156634395, 
              c[ 17][ t]], 
            Times[ 0.50455115242710469, 
              c[ 18][ t]], 
            Times[ 0.59356153372868026, 
              c[ 19][ t]], 
            Times[ 0.67835603854706317, 
              c[ 20][ t]], 
            Times[ 0.75682672864065692, 
              c[ 21][ t]], 
            Times[ 0.82699334313268802, 
              c[ 22][ t]], 
            Times[ 0.88706379305918381, 
              c[ 23][ t]], 
            Times[ 0.93548928378863916, 
              c[ 24][ t]], 
            Times[ 0.9710122092317629, 
              c[ 25][ t]], 
            Times[ 0.99270519960720671, 
              c[ 26][ t]], 
            Times[ 16.988759129764759, 
              c[ 27][ t]], 
            Times[ 0.99270519960720693, 
              c[ 28][ t]], 
            Times[ 0.9710122092317629, 
              c[ 29][ t]], 
            Times[ 0.93548928378863916, 
              c[ 30][ t]], 
            Times[ 0.88706379305918392, 
              c[ 31][ t]], 
            Times[ 0.82699334313268813, 
              c[ 32][ t]], 
            Times[ 0.75682672864065692, 
              c[ 33][ t]], 
            Times[ 0.67835603854706361, 
              c[ 34][ t]], 
            Times[ 0.59356153372868059, 
              c[ 35][ t]], 
            Times[ 0.50455115242710469, 
              c[ 36][ t]], 
            Times[ 0.41349667156634429, 
              c[ 37][ t]], 
            Times[ 0.32256865202152157, 
              c[ 38][ t]], 
            Times[ 0.23387232094715985, 
              c[ 39][ t]], 
            Times[ 0.14938649372796384, 
              c[ 40][ t]], 
            Times[ 0.070907514257658094, 
              c[ 41][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 42][ t]], 
            Times[ -0.062044074975450239, 
              c[ 43][ t]], 
            Times[ -0.11423673049785416, 
              c[ 44][ t]], 
            Times[ -0.15591488063143982, 
              c[ 45][ t]], 
            Times[ -0.18675027222298593, 
              c[ 46][ t]], 
            Times[ -0.20674833578317189, 
              c[ 47][ t]], 
            Times[ -0.21623620818304484, 
              c[ 48][ t]], 
            Times[ -0.21584055771952015, 
              c[ 49][ t]], 
            Times[ -0.20645618564475848, 
              c[ 50][ t]], 
            Times[ -0.18920668216016426, 
              c[ 51][ t]], 
            Times[ -0.16539866862653771, 
              c[ 52][ t]], 
            Times[ -0.13647135277833616, 
              c[ 53][ t]], 
            Times[ -0.10394325375429328, 
              c[ 54][ t]], 
            Times[ -0.06935801494512607, 
              c[ 55][ t]], 
            Times[ -0.034231213779559094, 
              c[ 56][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 57][ t]], 
            Times[ 0.032022748374425904, 
              c[ 58][ t]], 
            Times[ 0.060688263076985001, 
              c[ 59][ t]], 
            Times[ 0.085044480344421705, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "28", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[28]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.022068459300722043`\)\ \(c[\(-60\)]\)[t] - 
            0.03225825116512568`\ \(c[\(-59\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-58\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-57\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-56\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-55\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-54\)]\)[t] - 
            0.05606123915856713`\ \(c[\(-53\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-52\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-51\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-50\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-49\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-48\)]\)[t] + 
            1.5206810699945212`*^-16\ \(c[\(-47\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-46\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-45\)]\)[t] + 
            0.03897872015786009`\ \(c[\(-44\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-43\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-42\)]\)[t] + 
            0.06581101988179631`\ \(c[\(-41\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-40\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-39\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-38\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-37\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-36\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-35\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-34\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-33\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-32\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-31\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-30\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-29\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-28\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-27\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-26\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-25\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-24\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-23\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-22\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-21\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-20\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-19\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-18\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-17\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-16\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-15\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-14\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-13\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-12\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-11\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-10\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-9\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-8\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-7\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-6\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-5\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-4\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-3\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-2\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-1\)]\)[t] - 
            0.06935801494512607`\ \(c[0]\)[t] - 
            0.1039432537542934`\ \(c[1]\)[t] - 
            0.13647135277833605`\ \(c[2]\)[t] - 
            0.1653986686265377`\ \(c[3]\)[t] - 
            0.18920668216016434`\ \(c[4]\)[t] - 
            0.20645618564475843`\ \(c[5]\)[t] - 
            0.21584055771952015`\ \(c[6]\)[t] - 
            0.21623620818304484`\ \(c[7]\)[t] - 
            0.206748335783172`\ \(c[8]\)[t] - 
            0.18675027222298593`\ \(c[9]\)[t] - 
            0.15591488063143974`\ \(c[10]\)[t] - 
            0.11423673049785436`\ \(c[11]\)[t] - 
            0.06204407497545024`\ \(c[12]\)[t] + 
            1.8033970416801674`*^-16\ \(c[13]\)[t] + 
            0.07090751425765777`\ \(c[14]\)[t] + 
            0.14938649372796384`\ \(c[15]\)[t] + 
            0.23387232094715998`\ \(c[16]\)[t] + 
            0.3225686520215216`\ \(c[17]\)[t] + 
            0.4134966715663443`\ \(c[18]\)[t] + 
            0.5045511524271049`\ \(c[19]\)[t] + 
            0.5935615337286806`\ \(c[20]\)[t] + 
            0.6783560385470636`\ \(c[21]\)[t] + 
            0.7568267286406569`\ \(c[22]\)[t] + 
            0.8269933431326881`\ \(c[23]\)[t] + 
            0.8870637930591839`\ \(c[24]\)[t] + 
            0.9354892837886392`\ \(c[25]\)[t] + 
            0.9710122092317629`\ \(c[26]\)[t] + 
            0.9927051996072069`\ \(c[27]\)[t] + 
            18.195044112120122`\ \(c[28]\)[t] + 
            0.9927051996072067`\ \(c[29]\)[t] + 
            0.9710122092317629`\ \(c[30]\)[t] + 
            0.9354892837886392`\ \(c[31]\)[t] + 
            0.8870637930591838`\ \(c[32]\)[t] + 
            0.826993343132688`\ \(c[33]\)[t] + 
            0.7568267286406569`\ \(c[34]\)[t] + 
            0.6783560385470632`\ \(c[35]\)[t] + 
            0.5935615337286801`\ \(c[36]\)[t] + 
            0.5045511524271047`\ \(c[37]\)[t] + 
            0.41349667156634395`\ \(c[38]\)[t] + 
            0.32256865202152113`\ \(c[39]\)[t] + 
            0.23387232094715985`\ \(c[40]\)[t] + 
            0.14938649372796384`\ \(c[41]\)[t] + 
            0.07090751425765746`\ \(c[42]\)[t] + 
            3.898171832519376`*^-17\ \(c[43]\)[t] - 
            0.06204407497545024`\ \(c[44]\)[t] - 
            0.11423673049785459`\ \(c[45]\)[t] - 
            0.15591488063143982`\ \(c[46]\)[t] - 
            0.18675027222298593`\ \(c[47]\)[t] - 
            0.20674833578317206`\ \(c[48]\)[t] - 
            0.21623620818304484`\ \(c[49]\)[t] - 
            0.21584055771952015`\ \(c[50]\)[t] - 
            0.20645618564475834`\ \(c[51]\)[t] - 
            0.18920668216016426`\ \(c[52]\)[t] - 
            0.1653986686265377`\ \(c[53]\)[t] - 
            0.1364713527783359`\ \(c[54]\)[t] - 
            0.10394325375429328`\ \(c[55]\)[t] - 
            0.06935801494512607`\ \(c[56]\)[t] - 
            0.034231213779558796`\ \(c[57]\)[t] - 
            3.898171832519376`*^-17\ \(c[58]\)[t] + 
            0.032022748374425904`\ \(c[59]\)[t] + 
            0.06068826307698522`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 28, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 28]][ t]], 
          Plus[ 
            Times[ -0.022068459300722043, 
              c[ -60][ t]], 
            Times[ -0.032258251165125679, 
              c[ -59][ t]], 
            Times[ -0.041258781072520248, 
              c[ -58][ t]], 
            Times[ -0.048646667243099281, 
              c[ -57][ t]], 
            Times[ -0.054059052045761224, 
              c[ -56][ t]], 
            Times[ -0.057210750238908967, 
              c[ -55][ t]], 
            Times[ -0.057908442314993203, 
              c[ -54][ t]], 
            Times[ -0.05606123915856713, 
              c[ -53][ t]], 
            Times[ -0.05168708394579296, 
              c[ -52][ t]], 
            Times[ -0.044914622433376419, 
              c[ -51][ t]], 
            Times[ -0.035980357068793781, 
              c[ -50][ t]], 
            Times[ -0.025221096343682053, 
              c[ -49][ t]], 
            Times[ -0.013061910521147383, 
              c[ -48][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ -47][ t]], 
            Times[ 0.013414935129827233, 
              c[ -46][ t]], 
            Times[ 0.026603074225527826, 
              c[ -45][ t]], 
            Times[ 0.038978720157860088, 
              c[ -44][ t]], 
            Times[ 0.049975424961080865, 
              c[ -43][ t]], 
            Times[ 0.059070953080906326, 
              c[ -42][ t]], 
            Times[ 0.065811019881796315, 
              c[ -41][ t]], 
            Times[ 0.069830768673962415, 
              c[ -40][ t]], 
            Times[ 0.070873018952678238, 
              c[ -39][ t]], 
            Times[ 0.068802429876423349, 
              c[ -38][ t]], 
            Times[ 0.063614872548668253, 
              c[ -37][ t]], 
            Times[ 0.055441487066198933, 
              c[ -36][ t]], 
            Times[ 0.044547108751839919, 
              c[ -35][ t]], 
            Times[ 0.031322974491347078, 
              c[ -34][ t]], 
            Times[ 0.016273855731265604, 
              c[ -33][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -32][ t]], 
            Times[ -0.016825511857749401, 
              c[ -31][ t]], 
            Times[ -0.033483179628681567, 
              c[ -30][ t]], 
            Times[ -0.049236278094138941, 
              c[ -29][ t]], 
            Times[ -0.063361699504227528, 
              c[ -28][ t]], 
            Times[ -0.075181213012062598, 
              c[ -27][ t]], 
            Times[ -0.084091858737850814, 
              c[ -26][ t]], 
            Times[ -0.089594193770366884, 
              c[ -25][ t]], 
            Times[ -0.091317159035181589, 
              c[ -24][ t]], 
            Times[ -0.089038438663606695, 
              c[ -23][ t]], 
            Times[ -0.082699334313268744, 
              c[ -22][ t]], 
            Times[ -0.072413370861974122, 
              c[ -21][ t]], 
            Times[ -0.058468080236789913, 
              c[ -20][ t]], 
            Times[ -0.04131966847794722, 
              c[ -19][ t]], 
            Times[ -0.021580547817547879, 
              c[ -18][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -17][ t]], 
            Times[ 0.022561481809254869, 
              c[ -16][ t]], 
            Times[ 0.045163358568919301, 
              c[ -15][ t]], 
            Times[ 0.066820663127759972, 
              c[ -14][ t]], 
            Times[ 0.086542809078944891, 
              c[ -13][ t]], 
            Times[ 0.10337416789158609, 
              c[ -12][ t]], 
            Times[ 0.11643488132933186, 
              c[ -11][ t]], 
            Times[ 0.12496032289024853, 
              c[ -10][ t]], 
            Times[ 0.12833762891430928, 
              c[ -9][ t]], 
            Times[ 0.12613778810677612, 
              c[ -8][ t]], 
            Times[ 0.11814190616181253, 
              c[ -7][ t]], 
            Times[ 0.10436044624225685, 
              c[ -6][ t]], 
            Times[ 0.085044480344421608, 
              c[ -5][ t]], 
            Times[ 0.060688263076985105, 
              c[ -4][ t]], 
            Times[ 0.032022748374425904, 
              c[ -3][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -2][ t]], 
            Times[ -0.034231213779558949, 
              c[ -1][ t]], 
            Times[ -0.06935801494512607, 
              c[ 0][ t]], 
            Times[ -0.1039432537542934, 
              c[ 1][ t]], 
            Times[ -0.13647135277833605, 
              c[ 2][ t]], 
            Times[ -0.16539866862653771, 
              c[ 3][ t]], 
            Times[ -0.18920668216016434, 
              c[ 4][ t]], 
            Times[ -0.20645618564475843, 
              c[ 5][ t]], 
            Times[ -0.21584055771952015, 
              c[ 6][ t]], 
            Times[ -0.21623620818304484, 
              c[ 7][ t]], 
            Times[ -0.206748335783172, 
              c[ 8][ t]], 
            Times[ -0.18675027222298593, 
              c[ 9][ t]], 
            Times[ -0.15591488063143974, 
              c[ 10][ t]], 
            Times[ -0.11423673049785436, 
              c[ 11][ t]], 
            Times[ -0.062044074975450239, 
              c[ 12][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 13][ t]], 
            Times[ 0.070907514257657775, 
              c[ 14][ t]], 
            Times[ 0.14938649372796384, 
              c[ 15][ t]], 
            Times[ 0.23387232094715998, 
              c[ 16][ t]], 
            Times[ 0.32256865202152157, 
              c[ 17][ t]], 
            Times[ 0.41349667156634429, 
              c[ 18][ t]], 
            Times[ 0.50455115242710491, 
              c[ 19][ t]], 
            Times[ 0.59356153372868059, 
              c[ 20][ t]], 
            Times[ 0.67835603854706361, 
              c[ 21][ t]], 
            Times[ 0.75682672864065692, 
              c[ 22][ t]], 
            Times[ 0.82699334313268813, 
              c[ 23][ t]], 
            Times[ 0.88706379305918392, 
              c[ 24][ t]], 
            Times[ 0.93548928378863916, 
              c[ 25][ t]], 
            Times[ 0.9710122092317629, 
              c[ 26][ t]], 
            Times[ 0.99270519960720693, 
              c[ 27][ t]], 
            Times[ 18.195044112120122, 
              c[ 28][ t]], 
            Times[ 0.99270519960720671, 
              c[ 29][ t]], 
            Times[ 0.9710122092317629, 
              c[ 30][ t]], 
            Times[ 0.93548928378863916, 
              c[ 31][ t]], 
            Times[ 0.88706379305918381, 
              c[ 32][ t]], 
            Times[ 0.82699334313268802, 
              c[ 33][ t]], 
            Times[ 0.75682672864065692, 
              c[ 34][ t]], 
            Times[ 0.67835603854706317, 
              c[ 35][ t]], 
            Times[ 0.59356153372868015, 
              c[ 36][ t]], 
            Times[ 0.50455115242710469, 
              c[ 37][ t]], 
            Times[ 0.41349667156634395, 
              c[ 38][ t]], 
            Times[ 0.32256865202152113, 
              c[ 39][ t]], 
            Times[ 0.23387232094715985, 
              c[ 40][ t]], 
            Times[ 0.14938649372796384, 
              c[ 41][ t]], 
            Times[ 0.070907514257657456, 
              c[ 42][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 43][ t]], 
            Times[ -0.062044074975450239, 
              c[ 44][ t]], 
            Times[ -0.11423673049785459, 
              c[ 45][ t]], 
            Times[ -0.15591488063143982, 
              c[ 46][ t]], 
            Times[ -0.18675027222298593, 
              c[ 47][ t]], 
            Times[ -0.20674833578317206, 
              c[ 48][ t]], 
            Times[ -0.21623620818304484, 
              c[ 49][ t]], 
            Times[ -0.21584055771952015, 
              c[ 50][ t]], 
            Times[ -0.20645618564475834, 
              c[ 51][ t]], 
            Times[ -0.18920668216016426, 
              c[ 52][ t]], 
            Times[ -0.16539866862653771, 
              c[ 53][ t]], 
            Times[ -0.13647135277833591, 
              c[ 54][ t]], 
            Times[ -0.10394325375429328, 
              c[ 55][ t]], 
            Times[ -0.06935801494512607, 
              c[ 56][ t]], 
            Times[ -0.034231213779558796, 
              c[ 57][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 58][ t]], 
            Times[ 0.032022748374425904, 
              c[ 59][ t]], 
            Times[ 0.060688263076985223, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "29", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[29]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.011153991006822649`\)\ \(c[\(-60\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-59\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-58\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-57\)]\)[t] - 
            0.0486466672430994`\ \(c[\(-56\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-55\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-54\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-53\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-52\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-51\)]\)[t] - 
            0.04491462243337629`\ \(c[\(-50\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-49\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-48\)]\)[t] - 
            0.013061910521147276`\ \(c[\(-47\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-46\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-45\)]\)[t] + 
            0.026603074225527937`\ \(c[\(-44\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-43\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-42\)]\)[t] + 
            0.0590709530809064`\ \(c[\(-41\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-40\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-39\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-38\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-37\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-36\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-35\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-34\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-33\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-32\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-31\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-30\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-29\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-28\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-27\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-26\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-25\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-24\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-23\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-22\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-21\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-20\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-19\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-18\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-17\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-16\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-15\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-14\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-13\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-12\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-11\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-10\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-9\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-8\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-7\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-6\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-5\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-4\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-3\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-2\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-1\)]\)[t] - 
            0.03423121377955895`\ \(c[0]\)[t] - 
            0.06935801494512607`\ \(c[1]\)[t] - 
            0.10394325375429328`\ \(c[2]\)[t] - 
            0.13647135277833605`\ \(c[3]\)[t] - 
            0.1653986686265377`\ \(c[4]\)[t] - 
            0.18920668216016426`\ \(c[5]\)[t] - 
            0.20645618564475843`\ \(c[6]\)[t] - 
            0.21584055771952015`\ \(c[7]\)[t] - 
            0.21623620818304484`\ \(c[8]\)[t] - 
            0.206748335783172`\ \(c[9]\)[t] - 
            0.186750272222986`\ \(c[10]\)[t] - 
            0.15591488063143982`\ \(c[11]\)[t] - 
            0.11423673049785436`\ \(c[12]\)[t] - 
            0.06204407497545034`\ \(c[13]\)[t] + 
            3.898171832519376`*^-17\ \(c[14]\)[t] + 
            0.07090751425765777`\ \(c[15]\)[t] + 
            0.14938649372796362`\ \(c[16]\)[t] + 
            0.23387232094715985`\ \(c[17]\)[t] + 
            0.3225686520215216`\ \(c[18]\)[t] + 
            0.4134966715663442`\ \(c[19]\)[t] + 
            0.5045511524271047`\ \(c[20]\)[t] + 
            0.5935615337286806`\ \(c[21]\)[t] + 
            0.6783560385470632`\ \(c[22]\)[t] + 
            0.7568267286406569`\ \(c[23]\)[t] + 
            0.8269933431326881`\ \(c[24]\)[t] + 
            0.8870637930591838`\ \(c[25]\)[t] + 
            0.9354892837886392`\ \(c[26]\)[t] + 
            0.9710122092317629`\ \(c[27]\)[t] + 
            0.9927051996072067`\ \(c[28]\)[t] + 
            19.445194002924776`\ \(c[29]\)[t] + 
            0.9927051996072067`\ \(c[30]\)[t] + 
            0.9710122092317629`\ \(c[31]\)[t] + 
            0.9354892837886392`\ \(c[32]\)[t] + 
            0.8870637930591838`\ \(c[33]\)[t] + 
            0.8269933431326881`\ \(c[34]\)[t] + 
            0.7568267286406569`\ \(c[35]\)[t] + 
            0.6783560385470632`\ \(c[36]\)[t] + 
            0.5935615337286806`\ \(c[37]\)[t] + 
            0.5045511524271047`\ \(c[38]\)[t] + 
            0.41349667156634395`\ \(c[39]\)[t] + 
            0.3225686520215216`\ \(c[40]\)[t] + 
            0.23387232094716018`\ \(c[41]\)[t] + 
            0.14938649372796345`\ \(c[42]\)[t] + 
            0.07090751425765777`\ \(c[43]\)[t] + 
            3.216976900108398`*^-16\ \(c[44]\)[t] - 
            0.062044074975450475`\ \(c[45]\)[t] - 
            0.11423673049785436`\ \(c[46]\)[t] - 
            0.15591488063143966`\ \(c[47]\)[t] - 
            0.18675027222298607`\ \(c[48]\)[t] - 
            0.206748335783172`\ \(c[49]\)[t] - 
            0.21623620818304481`\ \(c[50]\)[t] - 
            0.21584055771952013`\ \(c[51]\)[t] - 
            0.20645618564475843`\ \(c[52]\)[t] - 
            0.18920668216016434`\ \(c[53]\)[t] - 
            0.1653986686265376`\ \(c[54]\)[t] - 
            0.13647135277833605`\ \(c[55]\)[t] - 
            0.1039432537542934`\ \(c[56]\)[t] - 
            0.06935801494512592`\ \(c[57]\)[t] - 
            0.03423121377955895`\ \(c[58]\)[t] - 
            1.8033970416801674`*^-16\ \(c[59]\)[t] + 
            0.03202274837442603`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 29, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 29]][ t]], 
          Plus[ 
            Times[ -0.011153991006822649, 
              c[ -60][ t]], 
            Times[ -0.022068459300722043, 
              c[ -59][ t]], 
            Times[ -0.032258251165125519, 
              c[ -58][ t]], 
            Times[ -0.041258781072520248, 
              c[ -57][ t]], 
            Times[ -0.048646667243099399, 
              c[ -56][ t]], 
            Times[ -0.054059052045761224, 
              c[ -55][ t]], 
            Times[ -0.057210750238908967, 
              c[ -54][ t]], 
            Times[ -0.057908442314993203, 
              c[ -53][ t]], 
            Times[ -0.056061239158567186, 
              c[ -52][ t]], 
            Times[ -0.05168708394579296, 
              c[ -51][ t]], 
            Times[ -0.044914622433376288, 
              c[ -50][ t]], 
            Times[ -0.035980357068793781, 
              c[ -49][ t]], 
            Times[ -0.025221096343682053, 
              c[ -48][ t]], 
            Times[ -0.013061910521147276, 
              c[ -47][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -46][ t]], 
            Times[ 0.013414935129827233, 
              c[ -45][ t]], 
            Times[ 0.026603074225527937, 
              c[ -44][ t]], 
            Times[ 0.03897872015785999, 
              c[ -43][ t]], 
            Times[ 0.049975424961080865, 
              c[ -42][ t]], 
            Times[ 0.059070953080906402, 
              c[ -41][ t]], 
            Times[ 0.065811019881796273, 
              c[ -40][ t]], 
            Times[ 0.069830768673962415, 
              c[ -39][ t]], 
            Times[ 0.070873018952678238, 
              c[ -38][ t]], 
            Times[ 0.068802429876423349, 
              c[ -37][ t]], 
            Times[ 0.063614872548668253, 
              c[ -36][ t]], 
            Times[ 0.055441487066198933, 
              c[ -35][ t]], 
            Times[ 0.044547108751839919, 
              c[ -34][ t]], 
            Times[ 0.031322974491347078, 
              c[ -33][ t]], 
            Times[ 0.016273855731265604, 
              c[ -32][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -31][ t]], 
            Times[ -0.016825511857749401, 
              c[ -30][ t]], 
            Times[ -0.033483179628681567, 
              c[ -29][ t]], 
            Times[ -0.049236278094138941, 
              c[ -28][ t]], 
            Times[ -0.063361699504227528, 
              c[ -27][ t]], 
            Times[ -0.075181213012062598, 
              c[ -26][ t]], 
            Times[ -0.084091858737850814, 
              c[ -25][ t]], 
            Times[ -0.089594193770366884, 
              c[ -24][ t]], 
            Times[ -0.091317159035181589, 
              c[ -23][ t]], 
            Times[ -0.089038438663606695, 
              c[ -22][ t]], 
            Times[ -0.082699334313268744, 
              c[ -21][ t]], 
            Times[ -0.072413370861974122, 
              c[ -20][ t]], 
            Times[ -0.058468080236789913, 
              c[ -19][ t]], 
            Times[ -0.04131966847794722, 
              c[ -18][ t]], 
            Times[ -0.021580547817547879, 
              c[ -17][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -16][ t]], 
            Times[ 0.022561481809254869, 
              c[ -15][ t]], 
            Times[ 0.045163358568919301, 
              c[ -14][ t]], 
            Times[ 0.066820663127759972, 
              c[ -13][ t]], 
            Times[ 0.086542809078944891, 
              c[ -12][ t]], 
            Times[ 0.10337416789158609, 
              c[ -11][ t]], 
            Times[ 0.11643488132933186, 
              c[ -10][ t]], 
            Times[ 0.12496032289024853, 
              c[ -9][ t]], 
            Times[ 0.12833762891430928, 
              c[ -8][ t]], 
            Times[ 0.12613778810677614, 
              c[ -7][ t]], 
            Times[ 0.11814190616181255, 
              c[ -6][ t]], 
            Times[ 0.10436044624225685, 
              c[ -5][ t]], 
            Times[ 0.085044480344421705, 
              c[ -4][ t]], 
            Times[ 0.060688263076985105, 
              c[ -3][ t]], 
            Times[ 0.032022748374425904, 
              c[ -2][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -1][ t]], 
            Times[ -0.034231213779558949, 
              c[ 0][ t]], 
            Times[ -0.06935801494512607, 
              c[ 1][ t]], 
            Times[ -0.10394325375429328, 
              c[ 2][ t]], 
            Times[ -0.13647135277833605, 
              c[ 3][ t]], 
            Times[ -0.16539866862653771, 
              c[ 4][ t]], 
            Times[ -0.18920668216016426, 
              c[ 5][ t]], 
            Times[ -0.20645618564475843, 
              c[ 6][ t]], 
            Times[ -0.21584055771952015, 
              c[ 7][ t]], 
            Times[ -0.21623620818304484, 
              c[ 8][ t]], 
            Times[ -0.206748335783172, 
              c[ 9][ t]], 
            Times[ -0.18675027222298601, 
              c[ 10][ t]], 
            Times[ -0.15591488063143982, 
              c[ 11][ t]], 
            Times[ -0.11423673049785436, 
              c[ 12][ t]], 
            Times[ -0.062044074975450343, 
              c[ 13][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 14][ t]], 
            Times[ 0.070907514257657775, 
              c[ 15][ t]], 
            Times[ 0.14938649372796362, 
              c[ 16][ t]], 
            Times[ 0.23387232094715985, 
              c[ 17][ t]], 
            Times[ 0.32256865202152157, 
              c[ 18][ t]], 
            Times[ 0.41349667156634418, 
              c[ 19][ t]], 
            Times[ 0.50455115242710469, 
              c[ 20][ t]], 
            Times[ 0.59356153372868059, 
              c[ 21][ t]], 
            Times[ 0.67835603854706317, 
              c[ 22][ t]], 
            Times[ 0.75682672864065692, 
              c[ 23][ t]], 
            Times[ 0.82699334313268813, 
              c[ 24][ t]], 
            Times[ 0.88706379305918381, 
              c[ 25][ t]], 
            Times[ 0.93548928378863916, 
              c[ 26][ t]], 
            Times[ 0.9710122092317629, 
              c[ 27][ t]], 
            Times[ 0.99270519960720671, 
              c[ 28][ t]], 
            Times[ 19.445194002924776, 
              c[ 29][ t]], 
            Times[ 0.99270519960720671, 
              c[ 30][ t]], 
            Times[ 0.9710122092317629, 
              c[ 31][ t]], 
            Times[ 0.93548928378863916, 
              c[ 32][ t]], 
            Times[ 0.88706379305918381, 
              c[ 33][ t]], 
            Times[ 0.82699334313268813, 
              c[ 34][ t]], 
            Times[ 0.75682672864065692, 
              c[ 35][ t]], 
            Times[ 0.67835603854706317, 
              c[ 36][ t]], 
            Times[ 0.59356153372868059, 
              c[ 37][ t]], 
            Times[ 0.50455115242710469, 
              c[ 38][ t]], 
            Times[ 0.41349667156634395, 
              c[ 39][ t]], 
            Times[ 0.32256865202152157, 
              c[ 40][ t]], 
            Times[ 0.23387232094716018, 
              c[ 41][ t]], 
            Times[ 0.14938649372796345, 
              c[ 42][ t]], 
            Times[ 0.070907514257657775, 
              c[ 43][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ 44][ t]], 
            Times[ -0.062044074975450475, 
              c[ 45][ t]], 
            Times[ -0.11423673049785436, 
              c[ 46][ t]], 
            Times[ -0.15591488063143966, 
              c[ 47][ t]], 
            Times[ -0.18675027222298607, 
              c[ 48][ t]], 
            Times[ -0.206748335783172, 
              c[ 49][ t]], 
            Times[ -0.21623620818304481, 
              c[ 50][ t]], 
            Times[ -0.21584055771952013, 
              c[ 51][ t]], 
            Times[ -0.20645618564475843, 
              c[ 52][ t]], 
            Times[ -0.18920668216016434, 
              c[ 53][ t]], 
            Times[ -0.1653986686265376, 
              c[ 54][ t]], 
            Times[ -0.13647135277833605, 
              c[ 55][ t]], 
            Times[ -0.1039432537542934, 
              c[ 56][ t]], 
            Times[ -0.069358014945125918, 
              c[ 57][ t]], 
            Times[ -0.034231213779558949, 
              c[ 58][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 59][ t]], 
            Times[ 0.032022748374426029, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "30", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[30]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-3.8981718325193755`*^-17\)\ \(c[\(-60\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-59\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-58\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-57\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-56\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-55\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-54\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-53\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-52\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-51\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-50\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-49\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-48\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-47\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-46\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-45\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-44\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-43\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-42\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-41\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-40\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-39\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-38\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-37\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-36\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-35\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-34\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-33\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-32\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-31\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-30\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-29\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-28\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-27\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-26\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-25\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-24\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-23\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-22\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-21\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-20\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-19\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-18\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-17\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-16\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-15\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-14\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-13\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-12\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-11\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-10\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-9\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-8\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-7\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-6\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-5\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-4\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-3\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-2\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-1\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[0]\)[t] - 
            0.03423121377955895`\ \(c[1]\)[t] - 
            0.06935801494512592`\ \(c[2]\)[t] - 
            0.10394325375429328`\ \(c[3]\)[t] - 
            0.13647135277833605`\ \(c[4]\)[t] - 
            0.1653986686265376`\ \(c[5]\)[t] - 
            0.18920668216016426`\ \(c[6]\)[t] - 
            0.20645618564475834`\ \(c[7]\)[t] - 
            0.21584055771952013`\ \(c[8]\)[t] - 
            0.21623620818304484`\ \(c[9]\)[t] - 
            0.20674833578317206`\ \(c[10]\)[t] - 
            0.18675027222298607`\ \(c[11]\)[t] - 
            0.15591488063143982`\ \(c[12]\)[t] - 
            0.11423673049785445`\ \(c[13]\)[t] - 
            0.062044074975450475`\ \(c[14]\)[t] + 
            3.898171832519376`*^-17\ \(c[15]\)[t] + 
            0.07090751425765762`\ \(c[16]\)[t] + 
            0.14938649372796345`\ \(c[17]\)[t] + 
            0.23387232094715985`\ \(c[18]\)[t] + 
            0.32256865202152135`\ \(c[19]\)[t] + 
            0.41349667156634395`\ \(c[20]\)[t] + 
            0.5045511524271047`\ \(c[21]\)[t] + 
            0.5935615337286801`\ \(c[22]\)[t] + 
            0.6783560385470632`\ \(c[23]\)[t] + 
            0.7568267286406569`\ \(c[24]\)[t] + 
            0.826993343132688`\ \(c[25]\)[t] + 
            0.8870637930591838`\ \(c[26]\)[t] + 
            0.9354892837886392`\ \(c[27]\)[t] + 
            0.9710122092317629`\ \(c[28]\)[t] + 
            0.9927051996072067`\ \(c[29]\)[t] + 
            20.739208802178716`\ \(c[30]\)[t] + 
            0.9927051996072069`\ \(c[31]\)[t] + 
            0.9710122092317629`\ \(c[32]\)[t] + 
            0.9354892837886392`\ \(c[33]\)[t] + 
            0.8870637930591839`\ \(c[34]\)[t] + 
            0.8269933431326881`\ \(c[35]\)[t] + 
            0.7568267286406569`\ \(c[36]\)[t] + 
            0.6783560385470636`\ \(c[37]\)[t] + 
            0.5935615337286806`\ \(c[38]\)[t] + 
            0.5045511524271047`\ \(c[39]\)[t] + 
            0.4134966715663443`\ \(c[40]\)[t] + 
            0.3225686520215219`\ \(c[41]\)[t] + 
            0.23387232094715985`\ \(c[42]\)[t] + 
            0.14938649372796384`\ \(c[43]\)[t] + 
            0.0709075142576581`\ \(c[44]\)[t] + 
            3.898171832519376`*^-17\ \(c[45]\)[t] - 
            0.06204407497545024`\ \(c[46]\)[t] - 
            0.11423673049785416`\ \(c[47]\)[t] - 
            0.15591488063143982`\ \(c[48]\)[t] - 
            0.18675027222298593`\ \(c[49]\)[t] - 
            0.2067483357831719`\ \(c[50]\)[t] - 
            0.21623620818304484`\ \(c[51]\)[t] - 
            0.21584055771952015`\ \(c[52]\)[t] - 
            0.20645618564475848`\ \(c[53]\)[t] - 
            0.18920668216016426`\ \(c[54]\)[t] - 
            0.1653986686265377`\ \(c[55]\)[t] - 
            0.13647135277833616`\ \(c[56]\)[t] - 
            0.10394325375429328`\ \(c[57]\)[t] - 
            0.06935801494512607`\ \(c[58]\)[t] - 
            0.034231213779559094`\ \(c[59]\)[t] - 
            3.898171832519376`*^-17\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 30, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 30]][ t]], 
          Plus[ 
            Times[ -3.8981718325193755*^-17, 
              c[ -60][ t]], 
            Times[ -0.011153991006822649, 
              c[ -59][ t]], 
            Times[ -0.022068459300722043, 
              c[ -58][ t]], 
            Times[ -0.032258251165125519, 
              c[ -57][ t]], 
            Times[ -0.041258781072520248, 
              c[ -56][ t]], 
            Times[ -0.048646667243099281, 
              c[ -55][ t]], 
            Times[ -0.054059052045761224, 
              c[ -54][ t]], 
            Times[ -0.057210750238908967, 
              c[ -53][ t]], 
            Times[ -0.057908442314993203, 
              c[ -52][ t]], 
            Times[ -0.056061239158567186, 
              c[ -51][ t]], 
            Times[ -0.05168708394579296, 
              c[ -50][ t]], 
            Times[ -0.044914622433376419, 
              c[ -49][ t]], 
            Times[ -0.035980357068793781, 
              c[ -48][ t]], 
            Times[ -0.025221096343682053, 
              c[ -47][ t]], 
            Times[ -0.013061910521147383, 
              c[ -46][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -45][ t]], 
            Times[ 0.013414935129827233, 
              c[ -44][ t]], 
            Times[ 0.026603074225527826, 
              c[ -43][ t]], 
            Times[ 0.03897872015785999, 
              c[ -42][ t]], 
            Times[ 0.049975424961080865, 
              c[ -41][ t]], 
            Times[ 0.059070953080906326, 
              c[ -40][ t]], 
            Times[ 0.065811019881796273, 
              c[ -39][ t]], 
            Times[ 0.069830768673962415, 
              c[ -38][ t]], 
            Times[ 0.070873018952678238, 
              c[ -37][ t]], 
            Times[ 0.068802429876423349, 
              c[ -36][ t]], 
            Times[ 0.063614872548668253, 
              c[ -35][ t]], 
            Times[ 0.055441487066198933, 
              c[ -34][ t]], 
            Times[ 0.044547108751839919, 
              c[ -33][ t]], 
            Times[ 0.031322974491347078, 
              c[ -32][ t]], 
            Times[ 0.016273855731265604, 
              c[ -31][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -30][ t]], 
            Times[ -0.016825511857749401, 
              c[ -29][ t]], 
            Times[ -0.033483179628681567, 
              c[ -28][ t]], 
            Times[ -0.049236278094138941, 
              c[ -27][ t]], 
            Times[ -0.063361699504227528, 
              c[ -26][ t]], 
            Times[ -0.075181213012062598, 
              c[ -25][ t]], 
            Times[ -0.084091858737850814, 
              c[ -24][ t]], 
            Times[ -0.089594193770366884, 
              c[ -23][ t]], 
            Times[ -0.091317159035181589, 
              c[ -22][ t]], 
            Times[ -0.089038438663606695, 
              c[ -21][ t]], 
            Times[ -0.082699334313268744, 
              c[ -20][ t]], 
            Times[ -0.072413370861974122, 
              c[ -19][ t]], 
            Times[ -0.058468080236789913, 
              c[ -18][ t]], 
            Times[ -0.04131966847794722, 
              c[ -17][ t]], 
            Times[ -0.021580547817547879, 
              c[ -16][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -15][ t]], 
            Times[ 0.022561481809254869, 
              c[ -14][ t]], 
            Times[ 0.045163358568919301, 
              c[ -13][ t]], 
            Times[ 0.066820663127759972, 
              c[ -12][ t]], 
            Times[ 0.086542809078944891, 
              c[ -11][ t]], 
            Times[ 0.10337416789158609, 
              c[ -10][ t]], 
            Times[ 0.11643488132933186, 
              c[ -9][ t]], 
            Times[ 0.12496032289024853, 
              c[ -8][ t]], 
            Times[ 0.12833762891430928, 
              c[ -7][ t]], 
            Times[ 0.12613778810677614, 
              c[ -6][ t]], 
            Times[ 0.11814190616181255, 
              c[ -5][ t]], 
            Times[ 0.10436044624225692, 
              c[ -4][ t]], 
            Times[ 0.085044480344421705, 
              c[ -3][ t]], 
            Times[ 0.060688263076985105, 
              c[ -2][ t]], 
            Times[ 0.032022748374426029, 
              c[ -1][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 0][ t]], 
            Times[ -0.034231213779558949, 
              c[ 1][ t]], 
            Times[ -0.069358014945125918, 
              c[ 2][ t]], 
            Times[ -0.10394325375429328, 
              c[ 3][ t]], 
            Times[ -0.13647135277833605, 
              c[ 4][ t]], 
            Times[ -0.1653986686265376, 
              c[ 5][ t]], 
            Times[ -0.18920668216016426, 
              c[ 6][ t]], 
            Times[ -0.20645618564475834, 
              c[ 7][ t]], 
            Times[ -0.21584055771952013, 
              c[ 8][ t]], 
            Times[ -0.21623620818304484, 
              c[ 9][ t]], 
            Times[ -0.20674833578317206, 
              c[ 10][ t]], 
            Times[ -0.18675027222298607, 
              c[ 11][ t]], 
            Times[ -0.15591488063143982, 
              c[ 12][ t]], 
            Times[ -0.11423673049785445, 
              c[ 13][ t]], 
            Times[ -0.062044074975450475, 
              c[ 14][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 15][ t]], 
            Times[ 0.070907514257657622, 
              c[ 16][ t]], 
            Times[ 0.14938649372796345, 
              c[ 17][ t]], 
            Times[ 0.23387232094715985, 
              c[ 18][ t]], 
            Times[ 0.32256865202152135, 
              c[ 19][ t]], 
            Times[ 0.41349667156634395, 
              c[ 20][ t]], 
            Times[ 0.50455115242710469, 
              c[ 21][ t]], 
            Times[ 0.59356153372868015, 
              c[ 22][ t]], 
            Times[ 0.67835603854706317, 
              c[ 23][ t]], 
            Times[ 0.75682672864065692, 
              c[ 24][ t]], 
            Times[ 0.82699334313268802, 
              c[ 25][ t]], 
            Times[ 0.88706379305918381, 
              c[ 26][ t]], 
            Times[ 0.93548928378863916, 
              c[ 27][ t]], 
            Times[ 0.9710122092317629, 
              c[ 28][ t]], 
            Times[ 0.99270519960720671, 
              c[ 29][ t]], 
            Times[ 20.739208802178716, 
              c[ 30][ t]], 
            Times[ 0.99270519960720693, 
              c[ 31][ t]], 
            Times[ 0.9710122092317629, 
              c[ 32][ t]], 
            Times[ 0.93548928378863916, 
              c[ 33][ t]], 
            Times[ 0.88706379305918392, 
              c[ 34][ t]], 
            Times[ 0.82699334313268813, 
              c[ 35][ t]], 
            Times[ 0.75682672864065692, 
              c[ 36][ t]], 
            Times[ 0.67835603854706361, 
              c[ 37][ t]], 
            Times[ 0.59356153372868059, 
              c[ 38][ t]], 
            Times[ 0.50455115242710469, 
              c[ 39][ t]], 
            Times[ 0.41349667156634429, 
              c[ 40][ t]], 
            Times[ 0.32256865202152191, 
              c[ 41][ t]], 
            Times[ 0.23387232094715985, 
              c[ 42][ t]], 
            Times[ 0.14938649372796384, 
              c[ 43][ t]], 
            Times[ 0.070907514257658094, 
              c[ 44][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 45][ t]], 
            Times[ -0.062044074975450239, 
              c[ 46][ t]], 
            Times[ -0.11423673049785416, 
              c[ 47][ t]], 
            Times[ -0.15591488063143982, 
              c[ 48][ t]], 
            Times[ -0.18675027222298593, 
              c[ 49][ t]], 
            Times[ -0.20674833578317189, 
              c[ 50][ t]], 
            Times[ -0.21623620818304484, 
              c[ 51][ t]], 
            Times[ -0.21584055771952015, 
              c[ 52][ t]], 
            Times[ -0.20645618564475848, 
              c[ 53][ t]], 
            Times[ -0.18920668216016426, 
              c[ 54][ t]], 
            Times[ -0.16539866862653771, 
              c[ 55][ t]], 
            Times[ -0.13647135277833616, 
              c[ 56][ t]], 
            Times[ -0.10394325375429328, 
              c[ 57][ t]], 
            Times[ -0.06935801494512607, 
              c[ 58][ t]], 
            Times[ -0.034231213779559094, 
              c[ 59][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "31", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[31]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.010908848347331966`\ \(c[\(-60\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-59\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-58\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-57\)]\)[t] - 
            0.03225825116512568`\ \(c[\(-56\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-55\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-54\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-53\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-52\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-51\)]\)[t] - 
            0.05606123915856713`\ \(c[\(-50\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-49\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-48\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-47\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-46\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-45\)]\)[t] + 
            1.5206810699945212`*^-16\ \(c[\(-44\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-43\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-42\)]\)[t] + 
            0.03897872015786009`\ \(c[\(-41\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-40\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-39\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-38\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-37\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-36\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-35\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-34\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-33\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-32\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-31\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-30\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-29\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-28\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-27\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-26\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-25\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-24\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-23\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-22\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-21\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-20\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-19\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-18\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-17\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-16\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-15\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-14\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-13\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-12\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-11\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-10\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-9\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-8\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-7\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-6\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-5\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-4\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-3\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-2\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-1\)]\)[t] + 
            0.032022748374425904`\ \(c[0]\)[t] - 
            1.8033970416801674`*^-16\ \(c[1]\)[t] - 
            0.03423121377955895`\ \(c[2]\)[t] - 
            0.06935801494512607`\ \(c[3]\)[t] - 
            0.1039432537542934`\ \(c[4]\)[t] - 
            0.13647135277833605`\ \(c[5]\)[t] - 
            0.1653986686265377`\ \(c[6]\)[t] - 
            0.18920668216016426`\ \(c[7]\)[t] - 
            0.20645618564475843`\ \(c[8]\)[t] - 
            0.21584055771952015`\ \(c[9]\)[t] - 
            0.21623620818304484`\ \(c[10]\)[t] - 
            0.206748335783172`\ \(c[11]\)[t] - 
            0.18675027222298593`\ \(c[12]\)[t] - 
            0.15591488063143974`\ \(c[13]\)[t] - 
            0.11423673049785436`\ \(c[14]\)[t] - 
            0.06204407497545024`\ \(c[15]\)[t] + 
            1.8033970416801674`*^-16\ \(c[16]\)[t] + 
            0.07090751425765777`\ \(c[17]\)[t] + 
            0.14938649372796384`\ \(c[18]\)[t] + 
            0.23387232094715998`\ \(c[19]\)[t] + 
            0.3225686520215216`\ \(c[20]\)[t] + 
            0.4134966715663443`\ \(c[21]\)[t] + 
            0.5045511524271047`\ \(c[22]\)[t] + 
            0.5935615337286806`\ \(c[23]\)[t] + 
            0.6783560385470636`\ \(c[24]\)[t] + 
            0.7568267286406569`\ \(c[25]\)[t] + 
            0.8269933431326881`\ \(c[26]\)[t] + 
            0.8870637930591839`\ \(c[27]\)[t] + 
            0.9354892837886392`\ \(c[28]\)[t] + 
            0.9710122092317629`\ \(c[29]\)[t] + 
            0.9927051996072069`\ \(c[30]\)[t] + 
            22.077088509881936`\ \(c[31]\)[t] + 
            0.9927051996072067`\ \(c[32]\)[t] + 
            0.9710122092317629`\ \(c[33]\)[t] + 
            0.9354892837886392`\ \(c[34]\)[t] + 
            0.8870637930591838`\ \(c[35]\)[t] + 
            0.826993343132688`\ \(c[36]\)[t] + 
            0.7568267286406569`\ \(c[37]\)[t] + 
            0.6783560385470632`\ \(c[38]\)[t] + 
            0.5935615337286801`\ \(c[39]\)[t] + 
            0.5045511524271047`\ \(c[40]\)[t] + 
            0.4134966715663443`\ \(c[41]\)[t] + 
            0.32256865202152113`\ \(c[42]\)[t] + 
            0.23387232094715985`\ \(c[43]\)[t] + 
            0.14938649372796384`\ \(c[44]\)[t] + 
            0.07090751425765746`\ \(c[45]\)[t] + 
            3.898171832519376`*^-17\ \(c[46]\)[t] - 
            0.06204407497545024`\ \(c[47]\)[t] - 
            0.11423673049785459`\ \(c[48]\)[t] - 
            0.15591488063143982`\ \(c[49]\)[t] - 
            0.18675027222298593`\ \(c[50]\)[t] - 
            0.20674833578317206`\ \(c[51]\)[t] - 
            0.21623620818304484`\ \(c[52]\)[t] - 
            0.21584055771952015`\ \(c[53]\)[t] - 
            0.20645618564475834`\ \(c[54]\)[t] - 
            0.18920668216016426`\ \(c[55]\)[t] - 
            0.1653986686265377`\ \(c[56]\)[t] - 
            0.1364713527783359`\ \(c[57]\)[t] - 
            0.10394325375429328`\ \(c[58]\)[t] - 
            0.06935801494512607`\ \(c[59]\)[t] - 
            0.034231213779558796`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 31, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 31]][ t]], 
          Plus[ 
            Times[ 0.010908848347331966, 
              c[ -60][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -59][ t]], 
            Times[ -0.011153991006822649, 
              c[ -58][ t]], 
            Times[ -0.022068459300722043, 
              c[ -57][ t]], 
            Times[ -0.032258251165125679, 
              c[ -56][ t]], 
            Times[ -0.041258781072520248, 
              c[ -55][ t]], 
            Times[ -0.048646667243099281, 
              c[ -54][ t]], 
            Times[ -0.054059052045761224, 
              c[ -53][ t]], 
            Times[ -0.057210750238908967, 
              c[ -52][ t]], 
            Times[ -0.057908442314993203, 
              c[ -51][ t]], 
            Times[ -0.05606123915856713, 
              c[ -50][ t]], 
            Times[ -0.05168708394579296, 
              c[ -49][ t]], 
            Times[ -0.044914622433376419, 
              c[ -48][ t]], 
            Times[ -0.035980357068793781, 
              c[ -47][ t]], 
            Times[ -0.025221096343682053, 
              c[ -46][ t]], 
            Times[ -0.013061910521147383, 
              c[ -45][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ -44][ t]], 
            Times[ 0.013414935129827233, 
              c[ -43][ t]], 
            Times[ 0.026603074225527826, 
              c[ -42][ t]], 
            Times[ 0.038978720157860088, 
              c[ -41][ t]], 
            Times[ 0.049975424961080865, 
              c[ -40][ t]], 
            Times[ 0.059070953080906326, 
              c[ -39][ t]], 
            Times[ 0.065811019881796273, 
              c[ -38][ t]], 
            Times[ 0.069830768673962415, 
              c[ -37][ t]], 
            Times[ 0.070873018952678238, 
              c[ -36][ t]], 
            Times[ 0.068802429876423349, 
              c[ -35][ t]], 
            Times[ 0.063614872548668253, 
              c[ -34][ t]], 
            Times[ 0.055441487066198933, 
              c[ -33][ t]], 
            Times[ 0.044547108751839919, 
              c[ -32][ t]], 
            Times[ 0.031322974491347078, 
              c[ -31][ t]], 
            Times[ 0.016273855731265604, 
              c[ -30][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -29][ t]], 
            Times[ -0.016825511857749401, 
              c[ -28][ t]], 
            Times[ -0.033483179628681567, 
              c[ -27][ t]], 
            Times[ -0.049236278094138941, 
              c[ -26][ t]], 
            Times[ -0.063361699504227528, 
              c[ -25][ t]], 
            Times[ -0.075181213012062598, 
              c[ -24][ t]], 
            Times[ -0.084091858737850814, 
              c[ -23][ t]], 
            Times[ -0.089594193770366884, 
              c[ -22][ t]], 
            Times[ -0.091317159035181589, 
              c[ -21][ t]], 
            Times[ -0.089038438663606695, 
              c[ -20][ t]], 
            Times[ -0.082699334313268744, 
              c[ -19][ t]], 
            Times[ -0.072413370861974122, 
              c[ -18][ t]], 
            Times[ -0.058468080236789913, 
              c[ -17][ t]], 
            Times[ -0.04131966847794722, 
              c[ -16][ t]], 
            Times[ -0.021580547817547879, 
              c[ -15][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -14][ t]], 
            Times[ 0.022561481809254869, 
              c[ -13][ t]], 
            Times[ 0.045163358568919301, 
              c[ -12][ t]], 
            Times[ 0.066820663127759972, 
              c[ -11][ t]], 
            Times[ 0.086542809078944891, 
              c[ -10][ t]], 
            Times[ 0.10337416789158609, 
              c[ -9][ t]], 
            Times[ 0.11643488132933186, 
              c[ -8][ t]], 
            Times[ 0.12496032289024853, 
              c[ -7][ t]], 
            Times[ 0.12833762891430928, 
              c[ -6][ t]], 
            Times[ 0.12613778810677612, 
              c[ -5][ t]], 
            Times[ 0.11814190616181255, 
              c[ -4][ t]], 
            Times[ 0.10436044624225685, 
              c[ -3][ t]], 
            Times[ 0.085044480344421608, 
              c[ -2][ t]], 
            Times[ 0.060688263076985105, 
              c[ -1][ t]], 
            Times[ 0.032022748374425904, 
              c[ 0][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 1][ t]], 
            Times[ -0.034231213779558949, 
              c[ 2][ t]], 
            Times[ -0.06935801494512607, 
              c[ 3][ t]], 
            Times[ -0.1039432537542934, 
              c[ 4][ t]], 
            Times[ -0.13647135277833605, 
              c[ 5][ t]], 
            Times[ -0.16539866862653771, 
              c[ 6][ t]], 
            Times[ -0.18920668216016426, 
              c[ 7][ t]], 
            Times[ -0.20645618564475843, 
              c[ 8][ t]], 
            Times[ -0.21584055771952015, 
              c[ 9][ t]], 
            Times[ -0.21623620818304484, 
              c[ 10][ t]], 
            Times[ -0.206748335783172, 
              c[ 11][ t]], 
            Times[ -0.18675027222298593, 
              c[ 12][ t]], 
            Times[ -0.15591488063143974, 
              c[ 13][ t]], 
            Times[ -0.11423673049785436, 
              c[ 14][ t]], 
            Times[ -0.062044074975450239, 
              c[ 15][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 16][ t]], 
            Times[ 0.070907514257657775, 
              c[ 17][ t]], 
            Times[ 0.14938649372796384, 
              c[ 18][ t]], 
            Times[ 0.23387232094715998, 
              c[ 19][ t]], 
            Times[ 0.32256865202152157, 
              c[ 20][ t]], 
            Times[ 0.41349667156634429, 
              c[ 21][ t]], 
            Times[ 0.50455115242710469, 
              c[ 22][ t]], 
            Times[ 0.59356153372868059, 
              c[ 23][ t]], 
            Times[ 0.67835603854706361, 
              c[ 24][ t]], 
            Times[ 0.75682672864065692, 
              c[ 25][ t]], 
            Times[ 0.82699334313268813, 
              c[ 26][ t]], 
            Times[ 0.88706379305918392, 
              c[ 27][ t]], 
            Times[ 0.93548928378863916, 
              c[ 28][ t]], 
            Times[ 0.9710122092317629, 
              c[ 29][ t]], 
            Times[ 0.99270519960720693, 
              c[ 30][ t]], 
            Times[ 22.077088509881936, 
              c[ 31][ t]], 
            Times[ 0.99270519960720671, 
              c[ 32][ t]], 
            Times[ 0.9710122092317629, 
              c[ 33][ t]], 
            Times[ 0.93548928378863916, 
              c[ 34][ t]], 
            Times[ 0.88706379305918381, 
              c[ 35][ t]], 
            Times[ 0.82699334313268802, 
              c[ 36][ t]], 
            Times[ 0.75682672864065692, 
              c[ 37][ t]], 
            Times[ 0.67835603854706317, 
              c[ 38][ t]], 
            Times[ 0.59356153372868015, 
              c[ 39][ t]], 
            Times[ 0.50455115242710469, 
              c[ 40][ t]], 
            Times[ 0.41349667156634429, 
              c[ 41][ t]], 
            Times[ 0.32256865202152113, 
              c[ 42][ t]], 
            Times[ 0.23387232094715985, 
              c[ 43][ t]], 
            Times[ 0.14938649372796384, 
              c[ 44][ t]], 
            Times[ 0.070907514257657456, 
              c[ 45][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 46][ t]], 
            Times[ -0.062044074975450239, 
              c[ 47][ t]], 
            Times[ -0.11423673049785459, 
              c[ 48][ t]], 
            Times[ -0.15591488063143982, 
              c[ 49][ t]], 
            Times[ -0.18675027222298593, 
              c[ 50][ t]], 
            Times[ -0.20674833578317206, 
              c[ 51][ t]], 
            Times[ -0.21623620818304484, 
              c[ 52][ t]], 
            Times[ -0.21584055771952015, 
              c[ 53][ t]], 
            Times[ -0.20645618564475834, 
              c[ 54][ t]], 
            Times[ -0.18920668216016426, 
              c[ 55][ t]], 
            Times[ -0.16539866862653771, 
              c[ 56][ t]], 
            Times[ -0.13647135277833591, 
              c[ 57][ t]], 
            Times[ -0.10394325375429328, 
              c[ 58][ t]], 
            Times[ -0.06935801494512607, 
              c[ 59][ t]], 
            Times[ -0.034231213779558796, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "32", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[32]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.021108961070255627`\ \(c[\(-60\)]\)[t] + 
            0.010908848347331785`\ \(c[\(-59\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-58\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-57\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-56\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-55\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-54\)]\)[t] - 
            0.0486466672430994`\ \(c[\(-53\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-52\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-51\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-50\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-49\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-48\)]\)[t] - 
            0.04491462243337629`\ \(c[\(-47\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-46\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-45\)]\)[t] - 
            0.013061910521147276`\ \(c[\(-44\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-43\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-42\)]\)[t] + 
            0.026603074225527937`\ \(c[\(-41\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-40\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-39\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-38\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-37\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-36\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-35\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-34\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-33\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-32\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-31\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-30\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-29\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-28\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-27\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-26\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-25\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-24\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-23\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-22\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-21\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-20\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-19\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-18\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-17\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-16\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-15\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-14\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-13\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-12\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-11\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-10\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-9\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-8\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-7\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-6\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-5\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-4\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-3\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-2\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-1\)]\)[t] + 
            0.060688263076985105`\ \(c[0]\)[t] + 
            0.032022748374425904`\ \(c[1]\)[t] - 
            3.898171832519376`*^-17\ \(c[2]\)[t] - 
            0.03423121377955895`\ \(c[3]\)[t] - 
            0.06935801494512607`\ \(c[4]\)[t] - 
            0.10394325375429328`\ \(c[5]\)[t] - 
            0.13647135277833605`\ \(c[6]\)[t] - 
            0.1653986686265377`\ \(c[7]\)[t] - 
            0.18920668216016426`\ \(c[8]\)[t] - 
            0.20645618564475843`\ \(c[9]\)[t] - 
            0.21584055771952015`\ \(c[10]\)[t] - 
            0.21623620818304484`\ \(c[11]\)[t] - 
            0.206748335783172`\ \(c[12]\)[t] - 
            0.186750272222986`\ \(c[13]\)[t] - 
            0.15591488063143982`\ \(c[14]\)[t] - 
            0.11423673049785436`\ \(c[15]\)[t] - 
            0.06204407497545034`\ \(c[16]\)[t] + 
            3.898171832519376`*^-17\ \(c[17]\)[t] + 
            0.07090751425765777`\ \(c[18]\)[t] + 
            0.14938649372796362`\ \(c[19]\)[t] + 
            0.23387232094715985`\ \(c[20]\)[t] + 
            0.3225686520215216`\ \(c[21]\)[t] + 
            0.41349667156634395`\ \(c[22]\)[t] + 
            0.5045511524271047`\ \(c[23]\)[t] + 
            0.5935615337286806`\ \(c[24]\)[t] + 
            0.6783560385470632`\ \(c[25]\)[t] + 
            0.7568267286406569`\ \(c[26]\)[t] + 
            0.8269933431326881`\ \(c[27]\)[t] + 
            0.8870637930591838`\ \(c[28]\)[t] + 
            0.9354892837886392`\ \(c[29]\)[t] + 
            0.9710122092317629`\ \(c[30]\)[t] + 
            0.9927051996072067`\ \(c[31]\)[t] + 
            23.45883312603445`\ \(c[32]\)[t] + 
            0.9927051996072067`\ \(c[33]\)[t] + 
            0.9710122092317629`\ \(c[34]\)[t] + 
            0.9354892837886392`\ \(c[35]\)[t] + 
            0.8870637930591838`\ \(c[36]\)[t] + 
            0.8269933431326881`\ \(c[37]\)[t] + 
            0.7568267286406569`\ \(c[38]\)[t] + 
            0.6783560385470632`\ \(c[39]\)[t] + 
            0.5935615337286806`\ \(c[40]\)[t] + 
            0.504551152427105`\ \(c[41]\)[t] + 
            0.41349667156634395`\ \(c[42]\)[t] + 
            0.3225686520215216`\ \(c[43]\)[t] + 
            0.23387232094716018`\ \(c[44]\)[t] + 
            0.14938649372796345`\ \(c[45]\)[t] + 
            0.07090751425765777`\ \(c[46]\)[t] + 
            3.216976900108398`*^-16\ \(c[47]\)[t] - 
            0.062044074975450475`\ \(c[48]\)[t] - 
            0.11423673049785436`\ \(c[49]\)[t] - 
            0.15591488063143966`\ \(c[50]\)[t] - 
            0.18675027222298607`\ \(c[51]\)[t] - 
            0.206748335783172`\ \(c[52]\)[t] - 
            0.21623620818304481`\ \(c[53]\)[t] - 
            0.21584055771952013`\ \(c[54]\)[t] - 
            0.20645618564475843`\ \(c[55]\)[t] - 
            0.18920668216016434`\ \(c[56]\)[t] - 
            0.1653986686265376`\ \(c[57]\)[t] - 
            0.13647135277833605`\ \(c[58]\)[t] - 
            0.1039432537542934`\ \(c[59]\)[t] - 
            0.06935801494512592`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 32, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 32]][ t]], 
          Plus[ 
            Times[ 0.021108961070255627, 
              c[ -60][ t]], 
            Times[ 0.010908848347331785, 
              c[ -59][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -58][ t]], 
            Times[ -0.011153991006822649, 
              c[ -57][ t]], 
            Times[ -0.022068459300722043, 
              c[ -56][ t]], 
            Times[ -0.032258251165125519, 
              c[ -55][ t]], 
            Times[ -0.041258781072520248, 
              c[ -54][ t]], 
            Times[ -0.048646667243099399, 
              c[ -53][ t]], 
            Times[ -0.054059052045761224, 
              c[ -52][ t]], 
            Times[ -0.057210750238908967, 
              c[ -51][ t]], 
            Times[ -0.057908442314993203, 
              c[ -50][ t]], 
            Times[ -0.056061239158567186, 
              c[ -49][ t]], 
            Times[ -0.05168708394579296, 
              c[ -48][ t]], 
            Times[ -0.044914622433376288, 
              c[ -47][ t]], 
            Times[ -0.035980357068793781, 
              c[ -46][ t]], 
            Times[ -0.025221096343682053, 
              c[ -45][ t]], 
            Times[ -0.013061910521147276, 
              c[ -44][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -43][ t]], 
            Times[ 0.013414935129827233, 
              c[ -42][ t]], 
            Times[ 0.026603074225527937, 
              c[ -41][ t]], 
            Times[ 0.03897872015785999, 
              c[ -40][ t]], 
            Times[ 0.049975424961080865, 
              c[ -39][ t]], 
            Times[ 0.059070953080906326, 
              c[ -38][ t]], 
            Times[ 0.065811019881796273, 
              c[ -37][ t]], 
            Times[ 0.069830768673962415, 
              c[ -36][ t]], 
            Times[ 0.070873018952678238, 
              c[ -35][ t]], 
            Times[ 0.068802429876423349, 
              c[ -34][ t]], 
            Times[ 0.063614872548668253, 
              c[ -33][ t]], 
            Times[ 0.055441487066198933, 
              c[ -32][ t]], 
            Times[ 0.044547108751839919, 
              c[ -31][ t]], 
            Times[ 0.031322974491347078, 
              c[ -30][ t]], 
            Times[ 0.016273855731265604, 
              c[ -29][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -28][ t]], 
            Times[ -0.016825511857749401, 
              c[ -27][ t]], 
            Times[ -0.033483179628681567, 
              c[ -26][ t]], 
            Times[ -0.049236278094138941, 
              c[ -25][ t]], 
            Times[ -0.063361699504227528, 
              c[ -24][ t]], 
            Times[ -0.075181213012062598, 
              c[ -23][ t]], 
            Times[ -0.084091858737850814, 
              c[ -22][ t]], 
            Times[ -0.089594193770366884, 
              c[ -21][ t]], 
            Times[ -0.091317159035181589, 
              c[ -20][ t]], 
            Times[ -0.089038438663606695, 
              c[ -19][ t]], 
            Times[ -0.082699334313268744, 
              c[ -18][ t]], 
            Times[ -0.072413370861974122, 
              c[ -17][ t]], 
            Times[ -0.058468080236789913, 
              c[ -16][ t]], 
            Times[ -0.04131966847794722, 
              c[ -15][ t]], 
            Times[ -0.021580547817547879, 
              c[ -14][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -13][ t]], 
            Times[ 0.022561481809254869, 
              c[ -12][ t]], 
            Times[ 0.045163358568919301, 
              c[ -11][ t]], 
            Times[ 0.066820663127759972, 
              c[ -10][ t]], 
            Times[ 0.086542809078944891, 
              c[ -9][ t]], 
            Times[ 0.10337416789158609, 
              c[ -8][ t]], 
            Times[ 0.11643488132933186, 
              c[ -7][ t]], 
            Times[ 0.12496032289024853, 
              c[ -6][ t]], 
            Times[ 0.12833762891430928, 
              c[ -5][ t]], 
            Times[ 0.12613778810677614, 
              c[ -4][ t]], 
            Times[ 0.11814190616181255, 
              c[ -3][ t]], 
            Times[ 0.10436044624225685, 
              c[ -2][ t]], 
            Times[ 0.085044480344421705, 
              c[ -1][ t]], 
            Times[ 0.060688263076985105, 
              c[ 0][ t]], 
            Times[ 0.032022748374425904, 
              c[ 1][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 2][ t]], 
            Times[ -0.034231213779558949, 
              c[ 3][ t]], 
            Times[ -0.06935801494512607, 
              c[ 4][ t]], 
            Times[ -0.10394325375429328, 
              c[ 5][ t]], 
            Times[ -0.13647135277833605, 
              c[ 6][ t]], 
            Times[ -0.16539866862653771, 
              c[ 7][ t]], 
            Times[ -0.18920668216016426, 
              c[ 8][ t]], 
            Times[ -0.20645618564475843, 
              c[ 9][ t]], 
            Times[ -0.21584055771952015, 
              c[ 10][ t]], 
            Times[ -0.21623620818304484, 
              c[ 11][ t]], 
            Times[ -0.206748335783172, 
              c[ 12][ t]], 
            Times[ -0.18675027222298601, 
              c[ 13][ t]], 
            Times[ -0.15591488063143982, 
              c[ 14][ t]], 
            Times[ -0.11423673049785436, 
              c[ 15][ t]], 
            Times[ -0.062044074975450343, 
              c[ 16][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 17][ t]], 
            Times[ 0.070907514257657775, 
              c[ 18][ t]], 
            Times[ 0.14938649372796362, 
              c[ 19][ t]], 
            Times[ 0.23387232094715985, 
              c[ 20][ t]], 
            Times[ 0.32256865202152157, 
              c[ 21][ t]], 
            Times[ 0.41349667156634395, 
              c[ 22][ t]], 
            Times[ 0.50455115242710469, 
              c[ 23][ t]], 
            Times[ 0.59356153372868059, 
              c[ 24][ t]], 
            Times[ 0.67835603854706317, 
              c[ 25][ t]], 
            Times[ 0.75682672864065692, 
              c[ 26][ t]], 
            Times[ 0.82699334313268813, 
              c[ 27][ t]], 
            Times[ 0.88706379305918381, 
              c[ 28][ t]], 
            Times[ 0.93548928378863916, 
              c[ 29][ t]], 
            Times[ 0.9710122092317629, 
              c[ 30][ t]], 
            Times[ 0.99270519960720671, 
              c[ 31][ t]], 
            Times[ 23.458833126034449, 
              c[ 32][ t]], 
            Times[ 0.99270519960720671, 
              c[ 33][ t]], 
            Times[ 0.9710122092317629, 
              c[ 34][ t]], 
            Times[ 0.93548928378863916, 
              c[ 35][ t]], 
            Times[ 0.88706379305918381, 
              c[ 36][ t]], 
            Times[ 0.82699334313268813, 
              c[ 37][ t]], 
            Times[ 0.75682672864065692, 
              c[ 38][ t]], 
            Times[ 0.67835603854706317, 
              c[ 39][ t]], 
            Times[ 0.59356153372868059, 
              c[ 40][ t]], 
            Times[ 0.50455115242710502, 
              c[ 41][ t]], 
            Times[ 0.41349667156634395, 
              c[ 42][ t]], 
            Times[ 0.32256865202152157, 
              c[ 43][ t]], 
            Times[ 0.23387232094716018, 
              c[ 44][ t]], 
            Times[ 0.14938649372796345, 
              c[ 45][ t]], 
            Times[ 0.070907514257657775, 
              c[ 46][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ 47][ t]], 
            Times[ -0.062044074975450475, 
              c[ 48][ t]], 
            Times[ -0.11423673049785436, 
              c[ 49][ t]], 
            Times[ -0.15591488063143966, 
              c[ 50][ t]], 
            Times[ -0.18675027222298607, 
              c[ 51][ t]], 
            Times[ -0.206748335783172, 
              c[ 52][ t]], 
            Times[ -0.21623620818304481, 
              c[ 53][ t]], 
            Times[ -0.21584055771952013, 
              c[ 54][ t]], 
            Times[ -0.20645618564475843, 
              c[ 55][ t]], 
            Times[ -0.18920668216016434, 
              c[ 56][ t]], 
            Times[ -0.1653986686265376, 
              c[ 57][ t]], 
            Times[ -0.13647135277833605, 
              c[ 58][ t]], 
            Times[ -0.1039432537542934, 
              c[ 59][ t]], 
            Times[ -0.069358014945125918, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "33", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[33]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.030177073670601236`\ \(c[\(-60\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-59\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-58\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-57\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-56\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-55\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-54\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-53\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-52\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-51\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-50\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-49\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-48\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-47\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-46\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-45\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-44\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-43\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-42\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-41\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-40\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-39\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-38\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-37\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-36\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-35\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-34\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-33\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-32\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-31\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-30\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-29\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-28\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-27\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-26\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-25\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-24\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-23\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-22\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-21\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-20\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-19\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-18\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-17\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-16\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-15\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-14\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-13\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-12\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-11\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-10\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-9\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-8\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-7\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-6\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-5\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-4\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-3\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-2\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-1\)]\)[t] + 
            0.0850444803444217`\ \(c[0]\)[t] + 
            0.060688263076985105`\ \(c[1]\)[t] + 
            0.03202274837442603`\ \(c[2]\)[t] - 
            3.898171832519376`*^-17\ \(c[3]\)[t] - 
            0.03423121377955895`\ \(c[4]\)[t] - 
            0.06935801494512592`\ \(c[5]\)[t] - 
            0.10394325375429328`\ \(c[6]\)[t] - 
            0.1364713527783359`\ \(c[7]\)[t] - 
            0.1653986686265376`\ \(c[8]\)[t] - 
            0.18920668216016426`\ \(c[9]\)[t] - 
            0.20645618564475834`\ \(c[10]\)[t] - 
            0.21584055771952013`\ \(c[11]\)[t] - 
            0.21623620818304484`\ \(c[12]\)[t] - 
            0.20674833578317206`\ \(c[13]\)[t] - 
            0.18675027222298607`\ \(c[14]\)[t] - 
            0.15591488063143982`\ \(c[15]\)[t] - 
            0.11423673049785445`\ \(c[16]\)[t] - 
            0.062044074975450475`\ \(c[17]\)[t] + 
            3.898171832519376`*^-17\ \(c[18]\)[t] + 
            0.07090751425765762`\ \(c[19]\)[t] + 
            0.14938649372796345`\ \(c[20]\)[t] + 
            0.23387232094715985`\ \(c[21]\)[t] + 
            0.32256865202152113`\ \(c[22]\)[t] + 
            0.41349667156634395`\ \(c[23]\)[t] + 
            0.5045511524271047`\ \(c[24]\)[t] + 
            0.5935615337286801`\ \(c[25]\)[t] + 
            0.6783560385470632`\ \(c[26]\)[t] + 
            0.7568267286406569`\ \(c[27]\)[t] + 
            0.826993343132688`\ \(c[28]\)[t] + 
            0.8870637930591838`\ \(c[29]\)[t] + 
            0.9354892837886392`\ \(c[30]\)[t] + 
            0.9710122092317629`\ \(c[31]\)[t] + 
            0.9927051996072067`\ \(c[32]\)[t] + 
            24.884442650636245`\ \(c[33]\)[t] + 
            0.9927051996072069`\ \(c[34]\)[t] + 
            0.9710122092317629`\ \(c[35]\)[t] + 
            0.9354892837886392`\ \(c[36]\)[t] + 
            0.8870637930591839`\ \(c[37]\)[t] + 
            0.8269933431326881`\ \(c[38]\)[t] + 
            0.7568267286406569`\ \(c[39]\)[t] + 
            0.6783560385470636`\ \(c[40]\)[t] + 
            0.5935615337286809`\ \(c[41]\)[t] + 
            0.5045511524271047`\ \(c[42]\)[t] + 
            0.4134966715663443`\ \(c[43]\)[t] + 
            0.3225686520215219`\ \(c[44]\)[t] + 
            0.23387232094715985`\ \(c[45]\)[t] + 
            0.14938649372796384`\ \(c[46]\)[t] + 
            0.0709075142576581`\ \(c[47]\)[t] + 
            3.898171832519376`*^-17\ \(c[48]\)[t] - 
            0.06204407497545024`\ \(c[49]\)[t] - 
            0.11423673049785416`\ \(c[50]\)[t] - 
            0.15591488063143982`\ \(c[51]\)[t] - 
            0.18675027222298593`\ \(c[52]\)[t] - 
            0.2067483357831719`\ \(c[53]\)[t] - 
            0.21623620818304484`\ \(c[54]\)[t] - 
            0.21584055771952015`\ \(c[55]\)[t] - 
            0.20645618564475848`\ \(c[56]\)[t] - 
            0.18920668216016426`\ \(c[57]\)[t] - 
            0.1653986686265377`\ \(c[58]\)[t] - 
            0.13647135277833616`\ \(c[59]\)[t] - 
            0.10394325375429328`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 33, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 33]][ t]], 
          Plus[ 
            Times[ 0.030177073670601236, 
              c[ -60][ t]], 
            Times[ 0.021108961070255627, 
              c[ -59][ t]], 
            Times[ 0.010908848347331966, 
              c[ -58][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -57][ t]], 
            Times[ -0.011153991006822649, 
              c[ -56][ t]], 
            Times[ -0.022068459300722043, 
              c[ -55][ t]], 
            Times[ -0.032258251165125519, 
              c[ -54][ t]], 
            Times[ -0.041258781072520248, 
              c[ -53][ t]], 
            Times[ -0.048646667243099281, 
              c[ -52][ t]], 
            Times[ -0.054059052045761224, 
              c[ -51][ t]], 
            Times[ -0.057210750238908967, 
              c[ -50][ t]], 
            Times[ -0.057908442314993203, 
              c[ -49][ t]], 
            Times[ -0.056061239158567186, 
              c[ -48][ t]], 
            Times[ -0.05168708394579296, 
              c[ -47][ t]], 
            Times[ -0.044914622433376419, 
              c[ -46][ t]], 
            Times[ -0.035980357068793781, 
              c[ -45][ t]], 
            Times[ -0.025221096343682053, 
              c[ -44][ t]], 
            Times[ -0.013061910521147383, 
              c[ -43][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -42][ t]], 
            Times[ 0.013414935129827233, 
              c[ -41][ t]], 
            Times[ 0.026603074225527826, 
              c[ -40][ t]], 
            Times[ 0.03897872015785999, 
              c[ -39][ t]], 
            Times[ 0.049975424961080865, 
              c[ -38][ t]], 
            Times[ 0.059070953080906326, 
              c[ -37][ t]], 
            Times[ 0.065811019881796273, 
              c[ -36][ t]], 
            Times[ 0.069830768673962415, 
              c[ -35][ t]], 
            Times[ 0.070873018952678238, 
              c[ -34][ t]], 
            Times[ 0.068802429876423349, 
              c[ -33][ t]], 
            Times[ 0.063614872548668253, 
              c[ -32][ t]], 
            Times[ 0.055441487066198933, 
              c[ -31][ t]], 
            Times[ 0.044547108751839919, 
              c[ -30][ t]], 
            Times[ 0.031322974491347078, 
              c[ -29][ t]], 
            Times[ 0.016273855731265604, 
              c[ -28][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -27][ t]], 
            Times[ -0.016825511857749401, 
              c[ -26][ t]], 
            Times[ -0.033483179628681567, 
              c[ -25][ t]], 
            Times[ -0.049236278094138941, 
              c[ -24][ t]], 
            Times[ -0.063361699504227528, 
              c[ -23][ t]], 
            Times[ -0.075181213012062598, 
              c[ -22][ t]], 
            Times[ -0.084091858737850814, 
              c[ -21][ t]], 
            Times[ -0.089594193770366884, 
              c[ -20][ t]], 
            Times[ -0.091317159035181589, 
              c[ -19][ t]], 
            Times[ -0.089038438663606695, 
              c[ -18][ t]], 
            Times[ -0.082699334313268744, 
              c[ -17][ t]], 
            Times[ -0.072413370861974122, 
              c[ -16][ t]], 
            Times[ -0.058468080236789913, 
              c[ -15][ t]], 
            Times[ -0.04131966847794722, 
              c[ -14][ t]], 
            Times[ -0.021580547817547879, 
              c[ -13][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -12][ t]], 
            Times[ 0.022561481809254869, 
              c[ -11][ t]], 
            Times[ 0.045163358568919301, 
              c[ -10][ t]], 
            Times[ 0.066820663127759972, 
              c[ -9][ t]], 
            Times[ 0.086542809078944752, 
              c[ -8][ t]], 
            Times[ 0.10337416789158609, 
              c[ -7][ t]], 
            Times[ 0.11643488132933186, 
              c[ -6][ t]], 
            Times[ 0.12496032289024853, 
              c[ -5][ t]], 
            Times[ 0.12833762891430925, 
              c[ -4][ t]], 
            Times[ 0.12613778810677614, 
              c[ -3][ t]], 
            Times[ 0.11814190616181255, 
              c[ -2][ t]], 
            Times[ 0.10436044624225692, 
              c[ -1][ t]], 
            Times[ 0.085044480344421705, 
              c[ 0][ t]], 
            Times[ 0.060688263076985105, 
              c[ 1][ t]], 
            Times[ 0.032022748374426029, 
              c[ 2][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 3][ t]], 
            Times[ -0.034231213779558949, 
              c[ 4][ t]], 
            Times[ -0.069358014945125918, 
              c[ 5][ t]], 
            Times[ -0.10394325375429328, 
              c[ 6][ t]], 
            Times[ -0.13647135277833591, 
              c[ 7][ t]], 
            Times[ -0.1653986686265376, 
              c[ 8][ t]], 
            Times[ -0.18920668216016426, 
              c[ 9][ t]], 
            Times[ -0.20645618564475834, 
              c[ 10][ t]], 
            Times[ -0.21584055771952013, 
              c[ 11][ t]], 
            Times[ -0.21623620818304484, 
              c[ 12][ t]], 
            Times[ -0.20674833578317206, 
              c[ 13][ t]], 
            Times[ -0.18675027222298607, 
              c[ 14][ t]], 
            Times[ -0.15591488063143982, 
              c[ 15][ t]], 
            Times[ -0.11423673049785445, 
              c[ 16][ t]], 
            Times[ -0.062044074975450475, 
              c[ 17][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 18][ t]], 
            Times[ 0.070907514257657622, 
              c[ 19][ t]], 
            Times[ 0.14938649372796345, 
              c[ 20][ t]], 
            Times[ 0.23387232094715985, 
              c[ 21][ t]], 
            Times[ 0.32256865202152113, 
              c[ 22][ t]], 
            Times[ 0.41349667156634395, 
              c[ 23][ t]], 
            Times[ 0.50455115242710469, 
              c[ 24][ t]], 
            Times[ 0.59356153372868015, 
              c[ 25][ t]], 
            Times[ 0.67835603854706317, 
              c[ 26][ t]], 
            Times[ 0.75682672864065692, 
              c[ 27][ t]], 
            Times[ 0.82699334313268802, 
              c[ 28][ t]], 
            Times[ 0.88706379305918381, 
              c[ 29][ t]], 
            Times[ 0.93548928378863916, 
              c[ 30][ t]], 
            Times[ 0.9710122092317629, 
              c[ 31][ t]], 
            Times[ 0.99270519960720671, 
              c[ 32][ t]], 
            Times[ 24.884442650636245, 
              c[ 33][ t]], 
            Times[ 0.99270519960720693, 
              c[ 34][ t]], 
            Times[ 0.9710122092317629, 
              c[ 35][ t]], 
            Times[ 0.93548928378863916, 
              c[ 36][ t]], 
            Times[ 0.88706379305918392, 
              c[ 37][ t]], 
            Times[ 0.82699334313268813, 
              c[ 38][ t]], 
            Times[ 0.75682672864065692, 
              c[ 39][ t]], 
            Times[ 0.67835603854706361, 
              c[ 40][ t]], 
            Times[ 0.59356153372868092, 
              c[ 41][ t]], 
            Times[ 0.50455115242710469, 
              c[ 42][ t]], 
            Times[ 0.41349667156634429, 
              c[ 43][ t]], 
            Times[ 0.32256865202152191, 
              c[ 44][ t]], 
            Times[ 0.23387232094715985, 
              c[ 45][ t]], 
            Times[ 0.14938649372796384, 
              c[ 46][ t]], 
            Times[ 0.070907514257658094, 
              c[ 47][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 48][ t]], 
            Times[ -0.062044074975450239, 
              c[ 49][ t]], 
            Times[ -0.11423673049785416, 
              c[ 50][ t]], 
            Times[ -0.15591488063143982, 
              c[ 51][ t]], 
            Times[ -0.18675027222298593, 
              c[ 52][ t]], 
            Times[ -0.20674833578317189, 
              c[ 53][ t]], 
            Times[ -0.21623620818304484, 
              c[ 54][ t]], 
            Times[ -0.21584055771952015, 
              c[ 55][ t]], 
            Times[ -0.20645618564475848, 
              c[ 56][ t]], 
            Times[ -0.18920668216016426, 
              c[ 57][ t]], 
            Times[ -0.16539866862653771, 
              c[ 58][ t]], 
            Times[ -0.13647135277833616, 
              c[ 59][ t]], 
            Times[ -0.10394325375429328, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "34", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[34]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.03774739544932687`\ \(c[\(-60\)]\)[t] + 
            0.030177073670601094`\ \(c[\(-59\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-58\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-57\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-56\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-55\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-54\)]\)[t] - 
            0.03225825116512568`\ \(c[\(-53\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-52\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-51\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-50\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-49\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-48\)]\)[t] - 
            0.05606123915856713`\ \(c[\(-47\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-46\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-45\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-44\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-43\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-42\)]\)[t] + 
            1.5206810699945212`*^-16\ \(c[\(-41\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-40\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-39\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-38\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-37\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-36\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-35\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-34\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-33\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-32\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-31\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-30\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-29\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-28\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-27\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-26\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-25\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-24\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-23\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-22\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-21\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-20\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-19\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-18\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-17\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-16\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-15\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-14\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-13\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-12\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-11\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-10\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-9\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-8\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-7\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-6\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-5\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-4\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-3\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-2\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-1\)]\)[t] + 
            0.10436044624225685`\ \(c[0]\)[t] + 
            0.08504448034442161`\ \(c[1]\)[t] + 
            0.060688263076985105`\ \(c[2]\)[t] + 
            0.032022748374425904`\ \(c[3]\)[t] - 
            1.8033970416801674`*^-16\ \(c[4]\)[t] - 
            0.03423121377955895`\ \(c[5]\)[t] - 
            0.06935801494512607`\ \(c[6]\)[t] - 
            0.10394325375429328`\ \(c[7]\)[t] - 
            0.13647135277833605`\ \(c[8]\)[t] - 
            0.1653986686265377`\ \(c[9]\)[t] - 
            0.18920668216016426`\ \(c[10]\)[t] - 
            0.20645618564475843`\ \(c[11]\)[t] - 
            0.21584055771952015`\ \(c[12]\)[t] - 
            0.21623620818304484`\ \(c[13]\)[t] - 
            0.206748335783172`\ \(c[14]\)[t] - 
            0.18675027222298593`\ \(c[15]\)[t] - 
            0.15591488063143974`\ \(c[16]\)[t] - 
            0.11423673049785436`\ \(c[17]\)[t] - 
            0.06204407497545024`\ \(c[18]\)[t] + 
            1.8033970416801674`*^-16\ \(c[19]\)[t] + 
            0.07090751425765777`\ \(c[20]\)[t] + 
            0.14938649372796384`\ \(c[21]\)[t] + 
            0.23387232094715985`\ \(c[22]\)[t] + 
            0.3225686520215216`\ \(c[23]\)[t] + 
            0.4134966715663443`\ \(c[24]\)[t] + 
            0.5045511524271047`\ \(c[25]\)[t] + 
            0.5935615337286806`\ \(c[26]\)[t] + 
            0.6783560385470636`\ \(c[27]\)[t] + 
            0.7568267286406569`\ \(c[28]\)[t] + 
            0.8269933431326881`\ \(c[29]\)[t] + 
            0.8870637930591839`\ \(c[30]\)[t] + 
            0.9354892837886392`\ \(c[31]\)[t] + 
            0.9710122092317629`\ \(c[32]\)[t] + 
            0.9927051996072069`\ \(c[33]\)[t] + 
            26.353917083687325`\ \(c[34]\)[t] + 
            0.9927051996072067`\ \(c[35]\)[t] + 
            0.9710122092317629`\ \(c[36]\)[t] + 
            0.9354892837886392`\ \(c[37]\)[t] + 
            0.8870637930591838`\ \(c[38]\)[t] + 
            0.826993343132688`\ \(c[39]\)[t] + 
            0.7568267286406569`\ \(c[40]\)[t] + 
            0.6783560385470636`\ \(c[41]\)[t] + 
            0.5935615337286801`\ \(c[42]\)[t] + 
            0.5045511524271047`\ \(c[43]\)[t] + 
            0.4134966715663443`\ \(c[44]\)[t] + 
            0.32256865202152113`\ \(c[45]\)[t] + 
            0.23387232094715985`\ \(c[46]\)[t] + 
            0.14938649372796384`\ \(c[47]\)[t] + 
            0.07090751425765746`\ \(c[48]\)[t] + 
            3.898171832519376`*^-17\ \(c[49]\)[t] - 
            0.06204407497545024`\ \(c[50]\)[t] - 
            0.11423673049785459`\ \(c[51]\)[t] - 
            0.15591488063143982`\ \(c[52]\)[t] - 
            0.18675027222298593`\ \(c[53]\)[t] - 
            0.20674833578317206`\ \(c[54]\)[t] - 
            0.21623620818304484`\ \(c[55]\)[t] - 
            0.21584055771952015`\ \(c[56]\)[t] - 
            0.20645618564475834`\ \(c[57]\)[t] - 
            0.18920668216016426`\ \(c[58]\)[t] - 
            0.1653986686265377`\ \(c[59]\)[t] - 
            0.1364713527783359`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 34, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 34]][ t]], 
          Plus[ 
            Times[ 0.03774739544932687, 
              c[ -60][ t]], 
            Times[ 0.030177073670601094, 
              c[ -59][ t]], 
            Times[ 0.021108961070255627, 
              c[ -58][ t]], 
            Times[ 0.010908848347331966, 
              c[ -57][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -56][ t]], 
            Times[ -0.011153991006822649, 
              c[ -55][ t]], 
            Times[ -0.022068459300722043, 
              c[ -54][ t]], 
            Times[ -0.032258251165125679, 
              c[ -53][ t]], 
            Times[ -0.041258781072520248, 
              c[ -52][ t]], 
            Times[ -0.048646667243099281, 
              c[ -51][ t]], 
            Times[ -0.054059052045761224, 
              c[ -50][ t]], 
            Times[ -0.057210750238908967, 
              c[ -49][ t]], 
            Times[ -0.057908442314993203, 
              c[ -48][ t]], 
            Times[ -0.05606123915856713, 
              c[ -47][ t]], 
            Times[ -0.05168708394579296, 
              c[ -46][ t]], 
            Times[ -0.044914622433376419, 
              c[ -45][ t]], 
            Times[ -0.035980357068793781, 
              c[ -44][ t]], 
            Times[ -0.025221096343682053, 
              c[ -43][ t]], 
            Times[ -0.013061910521147383, 
              c[ -42][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ -41][ t]], 
            Times[ 0.013414935129827233, 
              c[ -40][ t]], 
            Times[ 0.026603074225527826, 
              c[ -39][ t]], 
            Times[ 0.03897872015785999, 
              c[ -38][ t]], 
            Times[ 0.049975424961080865, 
              c[ -37][ t]], 
            Times[ 0.059070953080906326, 
              c[ -36][ t]], 
            Times[ 0.065811019881796273, 
              c[ -35][ t]], 
            Times[ 0.069830768673962415, 
              c[ -34][ t]], 
            Times[ 0.070873018952678238, 
              c[ -33][ t]], 
            Times[ 0.068802429876423349, 
              c[ -32][ t]], 
            Times[ 0.063614872548668253, 
              c[ -31][ t]], 
            Times[ 0.055441487066198933, 
              c[ -30][ t]], 
            Times[ 0.044547108751839919, 
              c[ -29][ t]], 
            Times[ 0.031322974491347078, 
              c[ -28][ t]], 
            Times[ 0.016273855731265604, 
              c[ -27][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -26][ t]], 
            Times[ -0.016825511857749401, 
              c[ -25][ t]], 
            Times[ -0.033483179628681567, 
              c[ -24][ t]], 
            Times[ -0.049236278094138941, 
              c[ -23][ t]], 
            Times[ -0.063361699504227528, 
              c[ -22][ t]], 
            Times[ -0.075181213012062598, 
              c[ -21][ t]], 
            Times[ -0.084091858737850814, 
              c[ -20][ t]], 
            Times[ -0.089594193770366884, 
              c[ -19][ t]], 
            Times[ -0.091317159035181589, 
              c[ -18][ t]], 
            Times[ -0.089038438663606695, 
              c[ -17][ t]], 
            Times[ -0.082699334313268744, 
              c[ -16][ t]], 
            Times[ -0.072413370861974122, 
              c[ -15][ t]], 
            Times[ -0.058468080236789913, 
              c[ -14][ t]], 
            Times[ -0.04131966847794722, 
              c[ -13][ t]], 
            Times[ -0.021580547817547879, 
              c[ -12][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -11][ t]], 
            Times[ 0.022561481809254869, 
              c[ -10][ t]], 
            Times[ 0.045163358568919301, 
              c[ -9][ t]], 
            Times[ 0.066820663127759972, 
              c[ -8][ t]], 
            Times[ 0.086542809078944891, 
              c[ -7][ t]], 
            Times[ 0.10337416789158609, 
              c[ -6][ t]], 
            Times[ 0.11643488132933186, 
              c[ -5][ t]], 
            Times[ 0.12496032289024853, 
              c[ -4][ t]], 
            Times[ 0.12833762891430928, 
              c[ -3][ t]], 
            Times[ 0.12613778810677612, 
              c[ -2][ t]], 
            Times[ 0.11814190616181255, 
              c[ -1][ t]], 
            Times[ 0.10436044624225685, 
              c[ 0][ t]], 
            Times[ 0.085044480344421608, 
              c[ 1][ t]], 
            Times[ 0.060688263076985105, 
              c[ 2][ t]], 
            Times[ 0.032022748374425904, 
              c[ 3][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 4][ t]], 
            Times[ -0.034231213779558949, 
              c[ 5][ t]], 
            Times[ -0.06935801494512607, 
              c[ 6][ t]], 
            Times[ -0.10394325375429328, 
              c[ 7][ t]], 
            Times[ -0.13647135277833605, 
              c[ 8][ t]], 
            Times[ -0.16539866862653771, 
              c[ 9][ t]], 
            Times[ -0.18920668216016426, 
              c[ 10][ t]], 
            Times[ -0.20645618564475843, 
              c[ 11][ t]], 
            Times[ -0.21584055771952015, 
              c[ 12][ t]], 
            Times[ -0.21623620818304484, 
              c[ 13][ t]], 
            Times[ -0.206748335783172, 
              c[ 14][ t]], 
            Times[ -0.18675027222298593, 
              c[ 15][ t]], 
            Times[ -0.15591488063143974, 
              c[ 16][ t]], 
            Times[ -0.11423673049785436, 
              c[ 17][ t]], 
            Times[ -0.062044074975450239, 
              c[ 18][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 19][ t]], 
            Times[ 0.070907514257657775, 
              c[ 20][ t]], 
            Times[ 0.14938649372796384, 
              c[ 21][ t]], 
            Times[ 0.23387232094715985, 
              c[ 22][ t]], 
            Times[ 0.32256865202152157, 
              c[ 23][ t]], 
            Times[ 0.41349667156634429, 
              c[ 24][ t]], 
            Times[ 0.50455115242710469, 
              c[ 25][ t]], 
            Times[ 0.59356153372868059, 
              c[ 26][ t]], 
            Times[ 0.67835603854706361, 
              c[ 27][ t]], 
            Times[ 0.75682672864065692, 
              c[ 28][ t]], 
            Times[ 0.82699334313268813, 
              c[ 29][ t]], 
            Times[ 0.88706379305918392, 
              c[ 30][ t]], 
            Times[ 0.93548928378863916, 
              c[ 31][ t]], 
            Times[ 0.9710122092317629, 
              c[ 32][ t]], 
            Times[ 0.99270519960720693, 
              c[ 33][ t]], 
            Times[ 26.353917083687325, 
              c[ 34][ t]], 
            Times[ 0.99270519960720671, 
              c[ 35][ t]], 
            Times[ 0.9710122092317629, 
              c[ 36][ t]], 
            Times[ 0.93548928378863916, 
              c[ 37][ t]], 
            Times[ 0.88706379305918381, 
              c[ 38][ t]], 
            Times[ 0.82699334313268802, 
              c[ 39][ t]], 
            Times[ 0.75682672864065692, 
              c[ 40][ t]], 
            Times[ 0.67835603854706361, 
              c[ 41][ t]], 
            Times[ 0.59356153372868015, 
              c[ 42][ t]], 
            Times[ 0.50455115242710469, 
              c[ 43][ t]], 
            Times[ 0.41349667156634429, 
              c[ 44][ t]], 
            Times[ 0.32256865202152113, 
              c[ 45][ t]], 
            Times[ 0.23387232094715985, 
              c[ 46][ t]], 
            Times[ 0.14938649372796384, 
              c[ 47][ t]], 
            Times[ 0.070907514257657456, 
              c[ 48][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 49][ t]], 
            Times[ -0.062044074975450239, 
              c[ 50][ t]], 
            Times[ -0.11423673049785459, 
              c[ 51][ t]], 
            Times[ -0.15591488063143982, 
              c[ 52][ t]], 
            Times[ -0.18675027222298593, 
              c[ 53][ t]], 
            Times[ -0.20674833578317206, 
              c[ 54][ t]], 
            Times[ -0.21623620818304484, 
              c[ 55][ t]], 
            Times[ -0.21584055771952015, 
              c[ 56][ t]], 
            Times[ -0.20645618564475834, 
              c[ 57][ t]], 
            Times[ -0.18920668216016426, 
              c[ 58][ t]], 
            Times[ -0.16539866862653771, 
              c[ 59][ t]], 
            Times[ -0.13647135277833591, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "35", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[35]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.04352596542803616`\ \(c[\(-60\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-59\)]\)[t] + 
            0.030177073670601236`\ \(c[\(-58\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-57\)]\)[t] + 
            0.010908848347331785`\ \(c[\(-56\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-55\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-54\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-53\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-52\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-51\)]\)[t] - 
            0.0486466672430994`\ \(c[\(-50\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-49\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-48\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-47\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-46\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-45\)]\)[t] - 
            0.04491462243337629`\ \(c[\(-44\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-43\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-42\)]\)[t] - 
            0.013061910521147276`\ \(c[\(-41\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-40\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-39\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-38\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-37\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-36\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-35\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-34\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-33\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-32\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-31\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-30\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-29\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-28\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-27\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-26\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-25\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-24\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-23\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-22\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-21\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-20\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-19\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-18\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-17\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-16\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-15\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-14\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-13\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-12\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-11\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-10\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-9\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-8\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-7\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-6\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-5\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-4\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-3\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-2\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-1\)]\)[t] + 
            0.11814190616181255`\ \(c[0]\)[t] + 
            0.10436044624225685`\ \(c[1]\)[t] + 
            0.0850444803444217`\ \(c[2]\)[t] + 
            0.060688263076985105`\ \(c[3]\)[t] + 
            0.032022748374425904`\ \(c[4]\)[t] - 
            3.898171832519376`*^-17\ \(c[5]\)[t] - 
            0.03423121377955895`\ \(c[6]\)[t] - 
            0.06935801494512607`\ \(c[7]\)[t] - 
            0.10394325375429328`\ \(c[8]\)[t] - 
            0.13647135277833605`\ \(c[9]\)[t] - 
            0.1653986686265377`\ \(c[10]\)[t] - 
            0.18920668216016426`\ \(c[11]\)[t] - 
            0.20645618564475843`\ \(c[12]\)[t] - 
            0.21584055771952015`\ \(c[13]\)[t] - 
            0.21623620818304484`\ \(c[14]\)[t] - 
            0.206748335783172`\ \(c[15]\)[t] - 
            0.186750272222986`\ \(c[16]\)[t] - 
            0.15591488063143982`\ \(c[17]\)[t] - 
            0.11423673049785436`\ \(c[18]\)[t] - 
            0.06204407497545034`\ \(c[19]\)[t] + 
            3.898171832519376`*^-17\ \(c[20]\)[t] + 
            0.07090751425765777`\ \(c[21]\)[t] + 
            0.14938649372796345`\ \(c[22]\)[t] + 
            0.23387232094715985`\ \(c[23]\)[t] + 
            0.3225686520215216`\ \(c[24]\)[t] + 
            0.41349667156634395`\ \(c[25]\)[t] + 
            0.5045511524271047`\ \(c[26]\)[t] + 
            0.5935615337286806`\ \(c[27]\)[t] + 
            0.6783560385470632`\ \(c[28]\)[t] + 
            0.7568267286406569`\ \(c[29]\)[t] + 
            0.8269933431326881`\ \(c[30]\)[t] + 
            0.8870637930591838`\ \(c[31]\)[t] + 
            0.9354892837886392`\ \(c[32]\)[t] + 
            0.9710122092317629`\ \(c[33]\)[t] + 
            0.9927051996072067`\ \(c[34]\)[t] + 
            27.867256425187694`\ \(c[35]\)[t] + 
            0.9927051996072067`\ \(c[36]\)[t] + 
            0.9710122092317629`\ \(c[37]\)[t] + 
            0.9354892837886392`\ \(c[38]\)[t] + 
            0.8870637930591838`\ \(c[39]\)[t] + 
            0.8269933431326881`\ \(c[40]\)[t] + 
            0.7568267286406574`\ \(c[41]\)[t] + 
            0.6783560385470632`\ \(c[42]\)[t] + 
            0.5935615337286806`\ \(c[43]\)[t] + 
            0.504551152427105`\ \(c[44]\)[t] + 
            0.41349667156634395`\ \(c[45]\)[t] + 
            0.3225686520215216`\ \(c[46]\)[t] + 
            0.23387232094716018`\ \(c[47]\)[t] + 
            0.14938649372796345`\ \(c[48]\)[t] + 
            0.07090751425765777`\ \(c[49]\)[t] + 
            3.216976900108398`*^-16\ \(c[50]\)[t] - 
            0.062044074975450475`\ \(c[51]\)[t] - 
            0.11423673049785436`\ \(c[52]\)[t] - 
            0.15591488063143966`\ \(c[53]\)[t] - 
            0.18675027222298607`\ \(c[54]\)[t] - 
            0.206748335783172`\ \(c[55]\)[t] - 
            0.21623620818304481`\ \(c[56]\)[t] - 
            0.21584055771952013`\ \(c[57]\)[t] - 
            0.20645618564475843`\ \(c[58]\)[t] - 
            0.18920668216016434`\ \(c[59]\)[t] - 
            0.1653986686265376`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 35, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 35]][ t]], 
          Plus[ 
            Times[ 0.043525965428036162, 
              c[ -60][ t]], 
            Times[ 0.03774739544932687, 
              c[ -59][ t]], 
            Times[ 0.030177073670601236, 
              c[ -58][ t]], 
            Times[ 0.021108961070255627, 
              c[ -57][ t]], 
            Times[ 0.010908848347331785, 
              c[ -56][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -55][ t]], 
            Times[ -0.011153991006822649, 
              c[ -54][ t]], 
            Times[ -0.022068459300722043, 
              c[ -53][ t]], 
            Times[ -0.032258251165125519, 
              c[ -52][ t]], 
            Times[ -0.041258781072520248, 
              c[ -51][ t]], 
            Times[ -0.048646667243099399, 
              c[ -50][ t]], 
            Times[ -0.054059052045761224, 
              c[ -49][ t]], 
            Times[ -0.057210750238908967, 
              c[ -48][ t]], 
            Times[ -0.057908442314993203, 
              c[ -47][ t]], 
            Times[ -0.056061239158567186, 
              c[ -46][ t]], 
            Times[ -0.05168708394579296, 
              c[ -45][ t]], 
            Times[ -0.044914622433376288, 
              c[ -44][ t]], 
            Times[ -0.035980357068793781, 
              c[ -43][ t]], 
            Times[ -0.025221096343682053, 
              c[ -42][ t]], 
            Times[ -0.013061910521147276, 
              c[ -41][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -40][ t]], 
            Times[ 0.013414935129827233, 
              c[ -39][ t]], 
            Times[ 0.026603074225527826, 
              c[ -38][ t]], 
            Times[ 0.03897872015785999, 
              c[ -37][ t]], 
            Times[ 0.049975424961080865, 
              c[ -36][ t]], 
            Times[ 0.059070953080906326, 
              c[ -35][ t]], 
            Times[ 0.065811019881796273, 
              c[ -34][ t]], 
            Times[ 0.069830768673962415, 
              c[ -33][ t]], 
            Times[ 0.070873018952678238, 
              c[ -32][ t]], 
            Times[ 0.068802429876423349, 
              c[ -31][ t]], 
            Times[ 0.063614872548668253, 
              c[ -30][ t]], 
            Times[ 0.055441487066198933, 
              c[ -29][ t]], 
            Times[ 0.044547108751839919, 
              c[ -28][ t]], 
            Times[ 0.031322974491347078, 
              c[ -27][ t]], 
            Times[ 0.016273855731265604, 
              c[ -26][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -25][ t]], 
            Times[ -0.016825511857749401, 
              c[ -24][ t]], 
            Times[ -0.033483179628681567, 
              c[ -23][ t]], 
            Times[ -0.049236278094138941, 
              c[ -22][ t]], 
            Times[ -0.063361699504227528, 
              c[ -21][ t]], 
            Times[ -0.075181213012062598, 
              c[ -20][ t]], 
            Times[ -0.084091858737850814, 
              c[ -19][ t]], 
            Times[ -0.089594193770366884, 
              c[ -18][ t]], 
            Times[ -0.091317159035181589, 
              c[ -17][ t]], 
            Times[ -0.089038438663606695, 
              c[ -16][ t]], 
            Times[ -0.082699334313268744, 
              c[ -15][ t]], 
            Times[ -0.072413370861974122, 
              c[ -14][ t]], 
            Times[ -0.058468080236789913, 
              c[ -13][ t]], 
            Times[ -0.04131966847794722, 
              c[ -12][ t]], 
            Times[ -0.021580547817547879, 
              c[ -11][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -10][ t]], 
            Times[ 0.022561481809254869, 
              c[ -9][ t]], 
            Times[ 0.045163358568919301, 
              c[ -8][ t]], 
            Times[ 0.066820663127759972, 
              c[ -7][ t]], 
            Times[ 0.086542809078944891, 
              c[ -6][ t]], 
            Times[ 0.10337416789158609, 
              c[ -5][ t]], 
            Times[ 0.11643488132933186, 
              c[ -4][ t]], 
            Times[ 0.12496032289024853, 
              c[ -3][ t]], 
            Times[ 0.12833762891430928, 
              c[ -2][ t]], 
            Times[ 0.12613778810677614, 
              c[ -1][ t]], 
            Times[ 0.11814190616181255, 
              c[ 0][ t]], 
            Times[ 0.10436044624225685, 
              c[ 1][ t]], 
            Times[ 0.085044480344421705, 
              c[ 2][ t]], 
            Times[ 0.060688263076985105, 
              c[ 3][ t]], 
            Times[ 0.032022748374425904, 
              c[ 4][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 5][ t]], 
            Times[ -0.034231213779558949, 
              c[ 6][ t]], 
            Times[ -0.06935801494512607, 
              c[ 7][ t]], 
            Times[ -0.10394325375429328, 
              c[ 8][ t]], 
            Times[ -0.13647135277833605, 
              c[ 9][ t]], 
            Times[ -0.16539866862653771, 
              c[ 10][ t]], 
            Times[ -0.18920668216016426, 
              c[ 11][ t]], 
            Times[ -0.20645618564475843, 
              c[ 12][ t]], 
            Times[ -0.21584055771952015, 
              c[ 13][ t]], 
            Times[ -0.21623620818304484, 
              c[ 14][ t]], 
            Times[ -0.206748335783172, 
              c[ 15][ t]], 
            Times[ -0.18675027222298601, 
              c[ 16][ t]], 
            Times[ -0.15591488063143982, 
              c[ 17][ t]], 
            Times[ -0.11423673049785436, 
              c[ 18][ t]], 
            Times[ -0.062044074975450343, 
              c[ 19][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 20][ t]], 
            Times[ 0.070907514257657775, 
              c[ 21][ t]], 
            Times[ 0.14938649372796345, 
              c[ 22][ t]], 
            Times[ 0.23387232094715985, 
              c[ 23][ t]], 
            Times[ 0.32256865202152157, 
              c[ 24][ t]], 
            Times[ 0.41349667156634395, 
              c[ 25][ t]], 
            Times[ 0.50455115242710469, 
              c[ 26][ t]], 
            Times[ 0.59356153372868059, 
              c[ 27][ t]], 
            Times[ 0.67835603854706317, 
              c[ 28][ t]], 
            Times[ 0.75682672864065692, 
              c[ 29][ t]], 
            Times[ 0.82699334313268813, 
              c[ 30][ t]], 
            Times[ 0.88706379305918381, 
              c[ 31][ t]], 
            Times[ 0.93548928378863916, 
              c[ 32][ t]], 
            Times[ 0.9710122092317629, 
              c[ 33][ t]], 
            Times[ 0.99270519960720671, 
              c[ 34][ t]], 
            Times[ 27.867256425187694, 
              c[ 35][ t]], 
            Times[ 0.99270519960720671, 
              c[ 36][ t]], 
            Times[ 0.9710122092317629, 
              c[ 37][ t]], 
            Times[ 0.93548928378863916, 
              c[ 38][ t]], 
            Times[ 0.88706379305918381, 
              c[ 39][ t]], 
            Times[ 0.82699334313268813, 
              c[ 40][ t]], 
            Times[ 0.75682672864065736, 
              c[ 41][ t]], 
            Times[ 0.67835603854706317, 
              c[ 42][ t]], 
            Times[ 0.59356153372868059, 
              c[ 43][ t]], 
            Times[ 0.50455115242710502, 
              c[ 44][ t]], 
            Times[ 0.41349667156634395, 
              c[ 45][ t]], 
            Times[ 0.32256865202152157, 
              c[ 46][ t]], 
            Times[ 0.23387232094716018, 
              c[ 47][ t]], 
            Times[ 0.14938649372796345, 
              c[ 48][ t]], 
            Times[ 0.070907514257657775, 
              c[ 49][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ 50][ t]], 
            Times[ -0.062044074975450475, 
              c[ 51][ t]], 
            Times[ -0.11423673049785436, 
              c[ 52][ t]], 
            Times[ -0.15591488063143966, 
              c[ 53][ t]], 
            Times[ -0.18675027222298607, 
              c[ 54][ t]], 
            Times[ -0.206748335783172, 
              c[ 55][ t]], 
            Times[ -0.21623620818304481, 
              c[ 56][ t]], 
            Times[ -0.21584055771952013, 
              c[ 57][ t]], 
            Times[ -0.20645618564475843, 
              c[ 58][ t]], 
            Times[ -0.18920668216016434, 
              c[ 59][ t]], 
            Times[ -0.1653986686265376, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "36", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[36]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.04730167054004106`\ \(c[\(-60\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-59\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-58\)]\)[t] + 
            0.030177073670601236`\ \(c[\(-57\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-56\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-55\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-54\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-53\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-52\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-51\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-50\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-49\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-48\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-47\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-46\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-45\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-44\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-43\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-42\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-41\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-40\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-39\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-38\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-37\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-36\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-35\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-34\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-33\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-32\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-31\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-30\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-29\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-28\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-27\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-26\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-25\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-24\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-23\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-22\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-21\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-20\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-19\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-18\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-17\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-16\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-15\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-14\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-13\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-12\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-11\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-10\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-9\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-8\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-7\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-6\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-5\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-4\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-3\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-2\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-1\)]\)[t] + 
            0.12613778810677614`\ \(c[0]\)[t] + 
            0.11814190616181255`\ \(c[1]\)[t] + 
            0.10436044624225692`\ \(c[2]\)[t] + 
            0.0850444803444217`\ \(c[3]\)[t] + 
            0.060688263076985105`\ \(c[4]\)[t] + 
            0.03202274837442603`\ \(c[5]\)[t] - 
            3.898171832519376`*^-17\ \(c[6]\)[t] - 
            0.034231213779558796`\ \(c[7]\)[t] - 
            0.06935801494512592`\ \(c[8]\)[t] - 
            0.10394325375429328`\ \(c[9]\)[t] - 
            0.1364713527783359`\ \(c[10]\)[t] - 
            0.1653986686265376`\ \(c[11]\)[t] - 
            0.18920668216016426`\ \(c[12]\)[t] - 
            0.20645618564475834`\ \(c[13]\)[t] - 
            0.21584055771952013`\ \(c[14]\)[t] - 
            0.21623620818304484`\ \(c[15]\)[t] - 
            0.20674833578317206`\ \(c[16]\)[t] - 
            0.18675027222298607`\ \(c[17]\)[t] - 
            0.15591488063143982`\ \(c[18]\)[t] - 
            0.11423673049785445`\ \(c[19]\)[t] - 
            0.062044074975450475`\ \(c[20]\)[t] + 
            3.898171832519376`*^-17\ \(c[21]\)[t] + 
            0.07090751425765746`\ \(c[22]\)[t] + 
            0.14938649372796345`\ \(c[23]\)[t] + 
            0.23387232094715985`\ \(c[24]\)[t] + 
            0.32256865202152113`\ \(c[25]\)[t] + 
            0.41349667156634395`\ \(c[26]\)[t] + 
            0.5045511524271047`\ \(c[27]\)[t] + 
            0.5935615337286801`\ \(c[28]\)[t] + 
            0.6783560385470632`\ \(c[29]\)[t] + 
            0.7568267286406569`\ \(c[30]\)[t] + 
            0.826993343132688`\ \(c[31]\)[t] + 
            0.8870637930591838`\ \(c[32]\)[t] + 
            0.9354892837886392`\ \(c[33]\)[t] + 
            0.9710122092317629`\ \(c[34]\)[t] + 
            0.9927051996072067`\ \(c[35]\)[t] + 
            29.42446067513735`\ \(c[36]\)[t] + 
            0.9927051996072069`\ \(c[37]\)[t] + 
            0.9710122092317629`\ \(c[38]\)[t] + 
            0.9354892837886392`\ \(c[39]\)[t] + 
            0.8870637930591839`\ \(c[40]\)[t] + 
            0.8269933431326885`\ \(c[41]\)[t] + 
            0.7568267286406569`\ \(c[42]\)[t] + 
            0.6783560385470636`\ \(c[43]\)[t] + 
            0.5935615337286809`\ \(c[44]\)[t] + 
            0.5045511524271047`\ \(c[45]\)[t] + 
            0.4134966715663443`\ \(c[46]\)[t] + 
            0.3225686520215219`\ \(c[47]\)[t] + 
            0.23387232094715985`\ \(c[48]\)[t] + 
            0.14938649372796384`\ \(c[49]\)[t] + 
            0.0709075142576581`\ \(c[50]\)[t] + 
            3.898171832519376`*^-17\ \(c[51]\)[t] - 
            0.06204407497545024`\ \(c[52]\)[t] - 
            0.11423673049785416`\ \(c[53]\)[t] - 
            0.15591488063143982`\ \(c[54]\)[t] - 
            0.18675027222298593`\ \(c[55]\)[t] - 
            0.2067483357831719`\ \(c[56]\)[t] - 
            0.21623620818304484`\ \(c[57]\)[t] - 
            0.21584055771952015`\ \(c[58]\)[t] - 
            0.20645618564475848`\ \(c[59]\)[t] - 
            0.18920668216016426`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 36, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 36]][ t]], 
          Plus[ 
            Times[ 0.047301670540041058, 
              c[ -60][ t]], 
            Times[ 0.043525965428036162, 
              c[ -59][ t]], 
            Times[ 0.03774739544932687, 
              c[ -58][ t]], 
            Times[ 0.030177073670601236, 
              c[ -57][ t]], 
            Times[ 0.021108961070255627, 
              c[ -56][ t]], 
            Times[ 0.010908848347331966, 
              c[ -55][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -54][ t]], 
            Times[ -0.011153991006822649, 
              c[ -53][ t]], 
            Times[ -0.022068459300722043, 
              c[ -52][ t]], 
            Times[ -0.032258251165125519, 
              c[ -51][ t]], 
            Times[ -0.041258781072520248, 
              c[ -50][ t]], 
            Times[ -0.048646667243099281, 
              c[ -49][ t]], 
            Times[ -0.054059052045761224, 
              c[ -48][ t]], 
            Times[ -0.057210750238908967, 
              c[ -47][ t]], 
            Times[ -0.057908442314993203, 
              c[ -46][ t]], 
            Times[ -0.056061239158567186, 
              c[ -45][ t]], 
            Times[ -0.05168708394579296, 
              c[ -44][ t]], 
            Times[ -0.044914622433376419, 
              c[ -43][ t]], 
            Times[ -0.035980357068793781, 
              c[ -42][ t]], 
            Times[ -0.025221096343682053, 
              c[ -41][ t]], 
            Times[ -0.013061910521147383, 
              c[ -40][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -39][ t]], 
            Times[ 0.013414935129827233, 
              c[ -38][ t]], 
            Times[ 0.026603074225527826, 
              c[ -37][ t]], 
            Times[ 0.03897872015785999, 
              c[ -36][ t]], 
            Times[ 0.049975424961080865, 
              c[ -35][ t]], 
            Times[ 0.059070953080906326, 
              c[ -34][ t]], 
            Times[ 0.065811019881796273, 
              c[ -33][ t]], 
            Times[ 0.069830768673962415, 
              c[ -32][ t]], 
            Times[ 0.070873018952678238, 
              c[ -31][ t]], 
            Times[ 0.068802429876423349, 
              c[ -30][ t]], 
            Times[ 0.063614872548668253, 
              c[ -29][ t]], 
            Times[ 0.055441487066198933, 
              c[ -28][ t]], 
            Times[ 0.044547108751839919, 
              c[ -27][ t]], 
            Times[ 0.031322974491347078, 
              c[ -26][ t]], 
            Times[ 0.016273855731265604, 
              c[ -25][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -24][ t]], 
            Times[ -0.016825511857749401, 
              c[ -23][ t]], 
            Times[ -0.033483179628681567, 
              c[ -22][ t]], 
            Times[ -0.049236278094138941, 
              c[ -21][ t]], 
            Times[ -0.063361699504227528, 
              c[ -20][ t]], 
            Times[ -0.075181213012062598, 
              c[ -19][ t]], 
            Times[ -0.084091858737850814, 
              c[ -18][ t]], 
            Times[ -0.089594193770366884, 
              c[ -17][ t]], 
            Times[ -0.091317159035181589, 
              c[ -16][ t]], 
            Times[ -0.089038438663606695, 
              c[ -15][ t]], 
            Times[ -0.082699334313268744, 
              c[ -14][ t]], 
            Times[ -0.072413370861974122, 
              c[ -13][ t]], 
            Times[ -0.058468080236789913, 
              c[ -12][ t]], 
            Times[ -0.04131966847794722, 
              c[ -11][ t]], 
            Times[ -0.021580547817547879, 
              c[ -10][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -9][ t]], 
            Times[ 0.022561481809254675, 
              c[ -8][ t]], 
            Times[ 0.045163358568919301, 
              c[ -7][ t]], 
            Times[ 0.066820663127759972, 
              c[ -6][ t]], 
            Times[ 0.086542809078944752, 
              c[ -5][ t]], 
            Times[ 0.10337416789158609, 
              c[ -4][ t]], 
            Times[ 0.11643488132933186, 
              c[ -3][ t]], 
            Times[ 0.12496032289024853, 
              c[ -2][ t]], 
            Times[ 0.12833762891430925, 
              c[ -1][ t]], 
            Times[ 0.12613778810677614, 
              c[ 0][ t]], 
            Times[ 0.11814190616181255, 
              c[ 1][ t]], 
            Times[ 0.10436044624225692, 
              c[ 2][ t]], 
            Times[ 0.085044480344421705, 
              c[ 3][ t]], 
            Times[ 0.060688263076985105, 
              c[ 4][ t]], 
            Times[ 0.032022748374426029, 
              c[ 5][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 6][ t]], 
            Times[ -0.034231213779558796, 
              c[ 7][ t]], 
            Times[ -0.069358014945125918, 
              c[ 8][ t]], 
            Times[ -0.10394325375429328, 
              c[ 9][ t]], 
            Times[ -0.13647135277833591, 
              c[ 10][ t]], 
            Times[ -0.1653986686265376, 
              c[ 11][ t]], 
            Times[ -0.18920668216016426, 
              c[ 12][ t]], 
            Times[ -0.20645618564475834, 
              c[ 13][ t]], 
            Times[ -0.21584055771952013, 
              c[ 14][ t]], 
            Times[ -0.21623620818304484, 
              c[ 15][ t]], 
            Times[ -0.20674833578317206, 
              c[ 16][ t]], 
            Times[ -0.18675027222298607, 
              c[ 17][ t]], 
            Times[ -0.15591488063143982, 
              c[ 18][ t]], 
            Times[ -0.11423673049785445, 
              c[ 19][ t]], 
            Times[ -0.062044074975450475, 
              c[ 20][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 21][ t]], 
            Times[ 0.070907514257657456, 
              c[ 22][ t]], 
            Times[ 0.14938649372796345, 
              c[ 23][ t]], 
            Times[ 0.23387232094715985, 
              c[ 24][ t]], 
            Times[ 0.32256865202152113, 
              c[ 25][ t]], 
            Times[ 0.41349667156634395, 
              c[ 26][ t]], 
            Times[ 0.50455115242710469, 
              c[ 27][ t]], 
            Times[ 0.59356153372868015, 
              c[ 28][ t]], 
            Times[ 0.67835603854706317, 
              c[ 29][ t]], 
            Times[ 0.75682672864065692, 
              c[ 30][ t]], 
            Times[ 0.82699334313268802, 
              c[ 31][ t]], 
            Times[ 0.88706379305918381, 
              c[ 32][ t]], 
            Times[ 0.93548928378863916, 
              c[ 33][ t]], 
            Times[ 0.9710122092317629, 
              c[ 34][ t]], 
            Times[ 0.99270519960720671, 
              c[ 35][ t]], 
            Times[ 29.42446067513735, 
              c[ 36][ t]], 
            Times[ 0.99270519960720693, 
              c[ 37][ t]], 
            Times[ 0.9710122092317629, 
              c[ 38][ t]], 
            Times[ 0.93548928378863916, 
              c[ 39][ t]], 
            Times[ 0.88706379305918392, 
              c[ 40][ t]], 
            Times[ 0.82699334313268846, 
              c[ 41][ t]], 
            Times[ 0.75682672864065692, 
              c[ 42][ t]], 
            Times[ 0.67835603854706361, 
              c[ 43][ t]], 
            Times[ 0.59356153372868092, 
              c[ 44][ t]], 
            Times[ 0.50455115242710469, 
              c[ 45][ t]], 
            Times[ 0.41349667156634429, 
              c[ 46][ t]], 
            Times[ 0.32256865202152191, 
              c[ 47][ t]], 
            Times[ 0.23387232094715985, 
              c[ 48][ t]], 
            Times[ 0.14938649372796384, 
              c[ 49][ t]], 
            Times[ 0.070907514257658094, 
              c[ 50][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 51][ t]], 
            Times[ -0.062044074975450239, 
              c[ 52][ t]], 
            Times[ -0.11423673049785416, 
              c[ 53][ t]], 
            Times[ -0.15591488063143982, 
              c[ 54][ t]], 
            Times[ -0.18675027222298593, 
              c[ 55][ t]], 
            Times[ -0.20674833578317189, 
              c[ 56][ t]], 
            Times[ -0.21623620818304484, 
              c[ 57][ t]], 
            Times[ -0.21584055771952015, 
              c[ 58][ t]], 
            Times[ -0.20645618564475848, 
              c[ 59][ t]], 
            Times[ -0.18920668216016426, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "37", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[37]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.04895352855494272`\ \(c[\(-60\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-59\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-58\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-57\)]\)[t] + 
            0.030177073670601094`\ \(c[\(-56\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-55\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-54\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-53\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-52\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-51\)]\)[t] - 
            0.03225825116512568`\ \(c[\(-50\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-49\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-48\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-47\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-46\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-45\)]\)[t] - 
            0.05606123915856713`\ \(c[\(-44\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-43\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-42\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-41\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-40\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-39\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-38\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-37\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-36\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-35\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-34\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-33\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-32\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-31\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-30\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-29\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-28\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-27\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-26\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-25\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-24\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-23\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-22\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-21\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-20\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-19\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-18\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-17\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-16\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-15\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-14\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-13\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-12\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-11\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-10\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-9\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-8\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-7\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-6\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-5\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-4\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-3\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-2\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-1\)]\)[t] + 
            0.12833762891430928`\ \(c[0]\)[t] + 
            0.12613778810677612`\ \(c[1]\)[t] + 
            0.11814190616181255`\ \(c[2]\)[t] + 
            0.10436044624225685`\ \(c[3]\)[t] + 
            0.08504448034442161`\ \(c[4]\)[t] + 
            0.060688263076985105`\ \(c[5]\)[t] + 
            0.032022748374425904`\ \(c[6]\)[t] - 
            3.898171832519376`*^-17\ \(c[7]\)[t] - 
            0.03423121377955895`\ \(c[8]\)[t] - 
            0.06935801494512607`\ \(c[9]\)[t] - 
            0.10394325375429328`\ \(c[10]\)[t] - 
            0.13647135277833605`\ \(c[11]\)[t] - 
            0.1653986686265377`\ \(c[12]\)[t] - 
            0.18920668216016426`\ \(c[13]\)[t] - 
            0.20645618564475843`\ \(c[14]\)[t] - 
            0.21584055771952015`\ \(c[15]\)[t] - 
            0.21623620818304484`\ \(c[16]\)[t] - 
            0.206748335783172`\ \(c[17]\)[t] - 
            0.18675027222298593`\ \(c[18]\)[t] - 
            0.15591488063143974`\ \(c[19]\)[t] - 
            0.11423673049785436`\ \(c[20]\)[t] - 
            0.06204407497545024`\ \(c[21]\)[t] + 
            3.898171832519376`*^-17\ \(c[22]\)[t] + 
            0.07090751425765777`\ \(c[23]\)[t] + 
            0.14938649372796384`\ \(c[24]\)[t] + 
            0.23387232094715985`\ \(c[25]\)[t] + 
            0.3225686520215216`\ \(c[26]\)[t] + 
            0.4134966715663443`\ \(c[27]\)[t] + 
            0.5045511524271047`\ \(c[28]\)[t] + 
            0.5935615337286806`\ \(c[29]\)[t] + 
            0.6783560385470636`\ \(c[30]\)[t] + 
            0.7568267286406569`\ \(c[31]\)[t] + 
            0.8269933431326881`\ \(c[32]\)[t] + 
            0.8870637930591839`\ \(c[33]\)[t] + 
            0.9354892837886392`\ \(c[34]\)[t] + 
            0.9710122092317629`\ \(c[35]\)[t] + 
            0.9927051996072069`\ \(c[36]\)[t] + 
            31.025529833536286`\ \(c[37]\)[t] + 
            0.9927051996072067`\ \(c[38]\)[t] + 
            0.9710122092317629`\ \(c[39]\)[t] + 
            0.9354892837886392`\ \(c[40]\)[t] + 
            0.8870637930591839`\ \(c[41]\)[t] + 
            0.826993343132688`\ \(c[42]\)[t] + 
            0.7568267286406569`\ \(c[43]\)[t] + 
            0.6783560385470636`\ \(c[44]\)[t] + 
            0.5935615337286801`\ \(c[45]\)[t] + 
            0.5045511524271047`\ \(c[46]\)[t] + 
            0.4134966715663443`\ \(c[47]\)[t] + 
            0.32256865202152113`\ \(c[48]\)[t] + 
            0.23387232094715985`\ \(c[49]\)[t] + 
            0.14938649372796384`\ \(c[50]\)[t] + 
            0.07090751425765746`\ \(c[51]\)[t] + 
            3.898171832519376`*^-17\ \(c[52]\)[t] - 
            0.06204407497545024`\ \(c[53]\)[t] - 
            0.11423673049785459`\ \(c[54]\)[t] - 
            0.15591488063143982`\ \(c[55]\)[t] - 
            0.18675027222298593`\ \(c[56]\)[t] - 
            0.20674833578317206`\ \(c[57]\)[t] - 
            0.21623620818304484`\ \(c[58]\)[t] - 
            0.21584055771952015`\ \(c[59]\)[t] - 
            0.20645618564475834`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 37, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 37]][ t]], 
          Plus[ 
            Times[ 0.04895352855494272, 
              c[ -60][ t]], 
            Times[ 0.047301670540041058, 
              c[ -59][ t]], 
            Times[ 0.043525965428036162, 
              c[ -58][ t]], 
            Times[ 0.03774739544932687, 
              c[ -57][ t]], 
            Times[ 0.030177073670601094, 
              c[ -56][ t]], 
            Times[ 0.021108961070255627, 
              c[ -55][ t]], 
            Times[ 0.010908848347331966, 
              c[ -54][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -53][ t]], 
            Times[ -0.011153991006822649, 
              c[ -52][ t]], 
            Times[ -0.022068459300722043, 
              c[ -51][ t]], 
            Times[ -0.032258251165125679, 
              c[ -50][ t]], 
            Times[ -0.041258781072520248, 
              c[ -49][ t]], 
            Times[ -0.048646667243099281, 
              c[ -48][ t]], 
            Times[ -0.054059052045761224, 
              c[ -47][ t]], 
            Times[ -0.057210750238908967, 
              c[ -46][ t]], 
            Times[ -0.057908442314993203, 
              c[ -45][ t]], 
            Times[ -0.05606123915856713, 
              c[ -44][ t]], 
            Times[ -0.05168708394579296, 
              c[ -43][ t]], 
            Times[ -0.044914622433376419, 
              c[ -42][ t]], 
            Times[ -0.035980357068793781, 
              c[ -41][ t]], 
            Times[ -0.025221096343682053, 
              c[ -40][ t]], 
            Times[ -0.013061910521147383, 
              c[ -39][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -38][ t]], 
            Times[ 0.013414935129827233, 
              c[ -37][ t]], 
            Times[ 0.026603074225527826, 
              c[ -36][ t]], 
            Times[ 0.03897872015785999, 
              c[ -35][ t]], 
            Times[ 0.049975424961080865, 
              c[ -34][ t]], 
            Times[ 0.059070953080906326, 
              c[ -33][ t]], 
            Times[ 0.065811019881796273, 
              c[ -32][ t]], 
            Times[ 0.069830768673962415, 
              c[ -31][ t]], 
            Times[ 0.070873018952678238, 
              c[ -30][ t]], 
            Times[ 0.068802429876423349, 
              c[ -29][ t]], 
            Times[ 0.063614872548668253, 
              c[ -28][ t]], 
            Times[ 0.055441487066198933, 
              c[ -27][ t]], 
            Times[ 0.044547108751839919, 
              c[ -26][ t]], 
            Times[ 0.031322974491347078, 
              c[ -25][ t]], 
            Times[ 0.016273855731265604, 
              c[ -24][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -23][ t]], 
            Times[ -0.016825511857749401, 
              c[ -22][ t]], 
            Times[ -0.033483179628681567, 
              c[ -21][ t]], 
            Times[ -0.049236278094138941, 
              c[ -20][ t]], 
            Times[ -0.063361699504227528, 
              c[ -19][ t]], 
            Times[ -0.075181213012062598, 
              c[ -18][ t]], 
            Times[ -0.084091858737850814, 
              c[ -17][ t]], 
            Times[ -0.089594193770366884, 
              c[ -16][ t]], 
            Times[ -0.091317159035181589, 
              c[ -15][ t]], 
            Times[ -0.089038438663606695, 
              c[ -14][ t]], 
            Times[ -0.082699334313268744, 
              c[ -13][ t]], 
            Times[ -0.072413370861974122, 
              c[ -12][ t]], 
            Times[ -0.058468080236789913, 
              c[ -11][ t]], 
            Times[ -0.04131966847794722, 
              c[ -10][ t]], 
            Times[ -0.021580547817547879, 
              c[ -9][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -8][ t]], 
            Times[ 0.022561481809254869, 
              c[ -7][ t]], 
            Times[ 0.045163358568919301, 
              c[ -6][ t]], 
            Times[ 0.066820663127759972, 
              c[ -5][ t]], 
            Times[ 0.086542809078944891, 
              c[ -4][ t]], 
            Times[ 0.10337416789158609, 
              c[ -3][ t]], 
            Times[ 0.11643488132933186, 
              c[ -2][ t]], 
            Times[ 0.12496032289024853, 
              c[ -1][ t]], 
            Times[ 0.12833762891430928, 
              c[ 0][ t]], 
            Times[ 0.12613778810677612, 
              c[ 1][ t]], 
            Times[ 0.11814190616181255, 
              c[ 2][ t]], 
            Times[ 0.10436044624225685, 
              c[ 3][ t]], 
            Times[ 0.085044480344421608, 
              c[ 4][ t]], 
            Times[ 0.060688263076985105, 
              c[ 5][ t]], 
            Times[ 0.032022748374425904, 
              c[ 6][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 7][ t]], 
            Times[ -0.034231213779558949, 
              c[ 8][ t]], 
            Times[ -0.06935801494512607, 
              c[ 9][ t]], 
            Times[ -0.10394325375429328, 
              c[ 10][ t]], 
            Times[ -0.13647135277833605, 
              c[ 11][ t]], 
            Times[ -0.16539866862653771, 
              c[ 12][ t]], 
            Times[ -0.18920668216016426, 
              c[ 13][ t]], 
            Times[ -0.20645618564475843, 
              c[ 14][ t]], 
            Times[ -0.21584055771952015, 
              c[ 15][ t]], 
            Times[ -0.21623620818304484, 
              c[ 16][ t]], 
            Times[ -0.206748335783172, 
              c[ 17][ t]], 
            Times[ -0.18675027222298593, 
              c[ 18][ t]], 
            Times[ -0.15591488063143974, 
              c[ 19][ t]], 
            Times[ -0.11423673049785436, 
              c[ 20][ t]], 
            Times[ -0.062044074975450239, 
              c[ 21][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 22][ t]], 
            Times[ 0.070907514257657775, 
              c[ 23][ t]], 
            Times[ 0.14938649372796384, 
              c[ 24][ t]], 
            Times[ 0.23387232094715985, 
              c[ 25][ t]], 
            Times[ 0.32256865202152157, 
              c[ 26][ t]], 
            Times[ 0.41349667156634429, 
              c[ 27][ t]], 
            Times[ 0.50455115242710469, 
              c[ 28][ t]], 
            Times[ 0.59356153372868059, 
              c[ 29][ t]], 
            Times[ 0.67835603854706361, 
              c[ 30][ t]], 
            Times[ 0.75682672864065692, 
              c[ 31][ t]], 
            Times[ 0.82699334313268813, 
              c[ 32][ t]], 
            Times[ 0.88706379305918392, 
              c[ 33][ t]], 
            Times[ 0.93548928378863916, 
              c[ 34][ t]], 
            Times[ 0.9710122092317629, 
              c[ 35][ t]], 
            Times[ 0.99270519960720693, 
              c[ 36][ t]], 
            Times[ 31.025529833536286, 
              c[ 37][ t]], 
            Times[ 0.99270519960720671, 
              c[ 38][ t]], 
            Times[ 0.9710122092317629, 
              c[ 39][ t]], 
            Times[ 0.93548928378863916, 
              c[ 40][ t]], 
            Times[ 0.88706379305918392, 
              c[ 41][ t]], 
            Times[ 0.82699334313268802, 
              c[ 42][ t]], 
            Times[ 0.75682672864065692, 
              c[ 43][ t]], 
            Times[ 0.67835603854706361, 
              c[ 44][ t]], 
            Times[ 0.59356153372868015, 
              c[ 45][ t]], 
            Times[ 0.50455115242710469, 
              c[ 46][ t]], 
            Times[ 0.41349667156634429, 
              c[ 47][ t]], 
            Times[ 0.32256865202152113, 
              c[ 48][ t]], 
            Times[ 0.23387232094715985, 
              c[ 49][ t]], 
            Times[ 0.14938649372796384, 
              c[ 50][ t]], 
            Times[ 0.070907514257657456, 
              c[ 51][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 52][ t]], 
            Times[ -0.062044074975450239, 
              c[ 53][ t]], 
            Times[ -0.11423673049785459, 
              c[ 54][ t]], 
            Times[ -0.15591488063143982, 
              c[ 55][ t]], 
            Times[ -0.18675027222298593, 
              c[ 56][ t]], 
            Times[ -0.20674833578317206, 
              c[ 57][ t]], 
            Times[ -0.21623620818304484, 
              c[ 58][ t]], 
            Times[ -0.21584055771952015, 
              c[ 59][ t]], 
            Times[ -0.20645618564475834, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "38", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[38]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.04845400275336168`\ \(c[\(-60\)]\)[t] + 
            0.0489535285549427`\ \(c[\(-59\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-58\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-57\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-56\)]\)[t] + 
            0.030177073670601236`\ \(c[\(-55\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-54\)]\)[t] + 
            0.010908848347331785`\ \(c[\(-53\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-52\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-51\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-50\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-49\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-48\)]\)[t] - 
            0.0486466672430994`\ \(c[\(-47\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-46\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-45\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-44\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-43\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-42\)]\)[t] - 
            0.04491462243337629`\ \(c[\(-41\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-40\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-39\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-38\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-37\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-36\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-35\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-34\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-33\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-32\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-31\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-30\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-29\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-28\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-27\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-26\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-25\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-24\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-23\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-22\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-21\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-20\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-19\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-18\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-17\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-16\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-15\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-14\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-13\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-12\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-11\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-10\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-9\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-8\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-7\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-6\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-5\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-4\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-3\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-2\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-1\)]\)[t] + 
            0.12496032289024853`\ \(c[0]\)[t] + 
            0.12833762891430928`\ \(c[1]\)[t] + 
            0.12613778810677614`\ \(c[2]\)[t] + 
            0.11814190616181255`\ \(c[3]\)[t] + 
            0.10436044624225685`\ \(c[4]\)[t] + 
            0.0850444803444217`\ \(c[5]\)[t] + 
            0.060688263076985105`\ \(c[6]\)[t] + 
            0.032022748374425904`\ \(c[7]\)[t] - 
            3.898171832519376`*^-17\ \(c[8]\)[t] - 
            0.03423121377955895`\ \(c[9]\)[t] - 
            0.06935801494512607`\ \(c[10]\)[t] - 
            0.10394325375429328`\ \(c[11]\)[t] - 
            0.13647135277833605`\ \(c[12]\)[t] - 
            0.1653986686265377`\ \(c[13]\)[t] - 
            0.18920668216016426`\ \(c[14]\)[t] - 
            0.20645618564475843`\ \(c[15]\)[t] - 
            0.21584055771952015`\ \(c[16]\)[t] - 
            0.21623620818304484`\ \(c[17]\)[t] - 
            0.206748335783172`\ \(c[18]\)[t] - 
            0.186750272222986`\ \(c[19]\)[t] - 
            0.15591488063143982`\ \(c[20]\)[t] - 
            0.11423673049785436`\ \(c[21]\)[t] - 
            0.062044074975450475`\ \(c[22]\)[t] + 
            3.898171832519376`*^-17\ \(c[23]\)[t] + 
            0.07090751425765777`\ \(c[24]\)[t] + 
            0.14938649372796345`\ \(c[25]\)[t] + 
            0.23387232094715985`\ \(c[26]\)[t] + 
            0.3225686520215216`\ \(c[27]\)[t] + 
            0.41349667156634395`\ \(c[28]\)[t] + 
            0.5045511524271047`\ \(c[29]\)[t] + 
            0.5935615337286806`\ \(c[30]\)[t] + 
            0.6783560385470632`\ \(c[31]\)[t] + 
            0.7568267286406569`\ \(c[32]\)[t] + 
            0.8269933431326881`\ \(c[33]\)[t] + 
            0.8870637930591838`\ \(c[34]\)[t] + 
            0.9354892837886392`\ \(c[35]\)[t] + 
            0.9710122092317629`\ \(c[36]\)[t] + 
            0.9927051996072067`\ \(c[37]\)[t] + 
            32.67046390038452`\ \(c[38]\)[t] + 
            0.9927051996072067`\ \(c[39]\)[t] + 
            0.9710122092317629`\ \(c[40]\)[t] + 
            0.9354892837886393`\ \(c[41]\)[t] + 
            0.8870637930591838`\ \(c[42]\)[t] + 
            0.8269933431326881`\ \(c[43]\)[t] + 
            0.7568267286406574`\ \(c[44]\)[t] + 
            0.6783560385470632`\ \(c[45]\)[t] + 
            0.5935615337286806`\ \(c[46]\)[t] + 
            0.504551152427105`\ \(c[47]\)[t] + 
            0.41349667156634395`\ \(c[48]\)[t] + 
            0.3225686520215216`\ \(c[49]\)[t] + 
            0.23387232094716018`\ \(c[50]\)[t] + 
            0.14938649372796345`\ \(c[51]\)[t] + 
            0.07090751425765777`\ \(c[52]\)[t] + 
            3.216976900108398`*^-16\ \(c[53]\)[t] - 
            0.062044074975450475`\ \(c[54]\)[t] - 
            0.11423673049785436`\ \(c[55]\)[t] - 
            0.15591488063143966`\ \(c[56]\)[t] - 
            0.18675027222298607`\ \(c[57]\)[t] - 
            0.206748335783172`\ \(c[58]\)[t] - 
            0.21623620818304481`\ \(c[59]\)[t] - 
            0.21584055771952013`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 38, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 38]][ t]], 
          Plus[ 
            Times[ 0.048454002753361682, 
              c[ -60][ t]], 
            Times[ 0.048953528554942699, 
              c[ -59][ t]], 
            Times[ 0.047301670540041058, 
              c[ -58][ t]], 
            Times[ 0.043525965428036162, 
              c[ -57][ t]], 
            Times[ 0.03774739544932687, 
              c[ -56][ t]], 
            Times[ 0.030177073670601236, 
              c[ -55][ t]], 
            Times[ 0.021108961070255627, 
              c[ -54][ t]], 
            Times[ 0.010908848347331785, 
              c[ -53][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -52][ t]], 
            Times[ -0.011153991006822649, 
              c[ -51][ t]], 
            Times[ -0.022068459300722043, 
              c[ -50][ t]], 
            Times[ -0.032258251165125519, 
              c[ -49][ t]], 
            Times[ -0.041258781072520248, 
              c[ -48][ t]], 
            Times[ -0.048646667243099399, 
              c[ -47][ t]], 
            Times[ -0.054059052045761224, 
              c[ -46][ t]], 
            Times[ -0.057210750238908967, 
              c[ -45][ t]], 
            Times[ -0.057908442314993203, 
              c[ -44][ t]], 
            Times[ -0.056061239158567186, 
              c[ -43][ t]], 
            Times[ -0.05168708394579296, 
              c[ -42][ t]], 
            Times[ -0.044914622433376288, 
              c[ -41][ t]], 
            Times[ -0.035980357068793781, 
              c[ -40][ t]], 
            Times[ -0.025221096343682053, 
              c[ -39][ t]], 
            Times[ -0.013061910521147383, 
              c[ -38][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -37][ t]], 
            Times[ 0.013414935129827233, 
              c[ -36][ t]], 
            Times[ 0.026603074225527826, 
              c[ -35][ t]], 
            Times[ 0.03897872015785999, 
              c[ -34][ t]], 
            Times[ 0.049975424961080865, 
              c[ -33][ t]], 
            Times[ 0.059070953080906326, 
              c[ -32][ t]], 
            Times[ 0.065811019881796273, 
              c[ -31][ t]], 
            Times[ 0.069830768673962415, 
              c[ -30][ t]], 
            Times[ 0.070873018952678238, 
              c[ -29][ t]], 
            Times[ 0.068802429876423349, 
              c[ -28][ t]], 
            Times[ 0.063614872548668253, 
              c[ -27][ t]], 
            Times[ 0.055441487066198933, 
              c[ -26][ t]], 
            Times[ 0.044547108751839919, 
              c[ -25][ t]], 
            Times[ 0.031322974491347078, 
              c[ -24][ t]], 
            Times[ 0.016273855731265604, 
              c[ -23][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -22][ t]], 
            Times[ -0.016825511857749401, 
              c[ -21][ t]], 
            Times[ -0.033483179628681567, 
              c[ -20][ t]], 
            Times[ -0.049236278094138941, 
              c[ -19][ t]], 
            Times[ -0.063361699504227528, 
              c[ -18][ t]], 
            Times[ -0.075181213012062598, 
              c[ -17][ t]], 
            Times[ -0.084091858737850814, 
              c[ -16][ t]], 
            Times[ -0.089594193770366884, 
              c[ -15][ t]], 
            Times[ -0.091317159035181589, 
              c[ -14][ t]], 
            Times[ -0.089038438663606695, 
              c[ -13][ t]], 
            Times[ -0.082699334313268744, 
              c[ -12][ t]], 
            Times[ -0.072413370861974122, 
              c[ -11][ t]], 
            Times[ -0.058468080236789913, 
              c[ -10][ t]], 
            Times[ -0.04131966847794722, 
              c[ -9][ t]], 
            Times[ -0.021580547817547879, 
              c[ -8][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -7][ t]], 
            Times[ 0.022561481809254869, 
              c[ -6][ t]], 
            Times[ 0.045163358568919301, 
              c[ -5][ t]], 
            Times[ 0.066820663127759972, 
              c[ -4][ t]], 
            Times[ 0.086542809078944891, 
              c[ -3][ t]], 
            Times[ 0.10337416789158609, 
              c[ -2][ t]], 
            Times[ 0.11643488132933186, 
              c[ -1][ t]], 
            Times[ 0.12496032289024853, 
              c[ 0][ t]], 
            Times[ 0.12833762891430928, 
              c[ 1][ t]], 
            Times[ 0.12613778810677614, 
              c[ 2][ t]], 
            Times[ 0.11814190616181255, 
              c[ 3][ t]], 
            Times[ 0.10436044624225685, 
              c[ 4][ t]], 
            Times[ 0.085044480344421705, 
              c[ 5][ t]], 
            Times[ 0.060688263076985105, 
              c[ 6][ t]], 
            Times[ 0.032022748374425904, 
              c[ 7][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 8][ t]], 
            Times[ -0.034231213779558949, 
              c[ 9][ t]], 
            Times[ -0.06935801494512607, 
              c[ 10][ t]], 
            Times[ -0.10394325375429328, 
              c[ 11][ t]], 
            Times[ -0.13647135277833605, 
              c[ 12][ t]], 
            Times[ -0.16539866862653771, 
              c[ 13][ t]], 
            Times[ -0.18920668216016426, 
              c[ 14][ t]], 
            Times[ -0.20645618564475843, 
              c[ 15][ t]], 
            Times[ -0.21584055771952015, 
              c[ 16][ t]], 
            Times[ -0.21623620818304484, 
              c[ 17][ t]], 
            Times[ -0.206748335783172, 
              c[ 18][ t]], 
            Times[ -0.18675027222298601, 
              c[ 19][ t]], 
            Times[ -0.15591488063143982, 
              c[ 20][ t]], 
            Times[ -0.11423673049785436, 
              c[ 21][ t]], 
            Times[ -0.062044074975450475, 
              c[ 22][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 23][ t]], 
            Times[ 0.070907514257657775, 
              c[ 24][ t]], 
            Times[ 0.14938649372796345, 
              c[ 25][ t]], 
            Times[ 0.23387232094715985, 
              c[ 26][ t]], 
            Times[ 0.32256865202152157, 
              c[ 27][ t]], 
            Times[ 0.41349667156634395, 
              c[ 28][ t]], 
            Times[ 0.50455115242710469, 
              c[ 29][ t]], 
            Times[ 0.59356153372868059, 
              c[ 30][ t]], 
            Times[ 0.67835603854706317, 
              c[ 31][ t]], 
            Times[ 0.75682672864065692, 
              c[ 32][ t]], 
            Times[ 0.82699334313268813, 
              c[ 33][ t]], 
            Times[ 0.88706379305918381, 
              c[ 34][ t]], 
            Times[ 0.93548928378863916, 
              c[ 35][ t]], 
            Times[ 0.9710122092317629, 
              c[ 36][ t]], 
            Times[ 0.99270519960720671, 
              c[ 37][ t]], 
            Times[ 32.670463900384519, 
              c[ 38][ t]], 
            Times[ 0.99270519960720671, 
              c[ 39][ t]], 
            Times[ 0.9710122092317629, 
              c[ 40][ t]], 
            Times[ 0.93548928378863927, 
              c[ 41][ t]], 
            Times[ 0.88706379305918381, 
              c[ 42][ t]], 
            Times[ 0.82699334313268813, 
              c[ 43][ t]], 
            Times[ 0.75682672864065736, 
              c[ 44][ t]], 
            Times[ 0.67835603854706317, 
              c[ 45][ t]], 
            Times[ 0.59356153372868059, 
              c[ 46][ t]], 
            Times[ 0.50455115242710502, 
              c[ 47][ t]], 
            Times[ 0.41349667156634395, 
              c[ 48][ t]], 
            Times[ 0.32256865202152157, 
              c[ 49][ t]], 
            Times[ 0.23387232094716018, 
              c[ 50][ t]], 
            Times[ 0.14938649372796345, 
              c[ 51][ t]], 
            Times[ 0.070907514257657775, 
              c[ 52][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ 53][ t]], 
            Times[ -0.062044074975450475, 
              c[ 54][ t]], 
            Times[ -0.11423673049785436, 
              c[ 55][ t]], 
            Times[ -0.15591488063143966, 
              c[ 56][ t]], 
            Times[ -0.18675027222298607, 
              c[ 57][ t]], 
            Times[ -0.206748335783172, 
              c[ 58][ t]], 
            Times[ -0.21623620818304481, 
              c[ 59][ t]], 
            Times[ -0.21584055771952013, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "39", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[39]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.045868286584282256`\ \(c[\(-60\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-59\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-58\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-57\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-56\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-55\)]\)[t] + 
            0.030177073670601236`\ \(c[\(-54\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-53\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-52\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-51\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-50\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-49\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-48\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-47\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-46\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-45\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-44\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-43\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-42\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-41\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-40\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-39\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-38\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-37\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-36\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-35\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-34\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-33\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-32\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-31\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-30\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-29\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-28\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-27\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-26\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-25\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-24\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-23\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-22\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-21\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-20\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-19\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-18\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-17\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-16\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-15\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-14\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-13\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-12\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-11\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-10\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-9\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-8\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-7\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-6\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-5\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-4\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-3\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-2\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-1\)]\)[t] + 
            0.11643488132933186`\ \(c[0]\)[t] + 
            0.12496032289024853`\ \(c[1]\)[t] + 
            0.12833762891430925`\ \(c[2]\)[t] + 
            0.12613778810677614`\ \(c[3]\)[t] + 
            0.11814190616181255`\ \(c[4]\)[t] + 
            0.10436044624225692`\ \(c[5]\)[t] + 
            0.0850444803444217`\ \(c[6]\)[t] + 
            0.06068826307698522`\ \(c[7]\)[t] + 
            0.03202274837442603`\ \(c[8]\)[t] - 
            3.898171832519376`*^-17\ \(c[9]\)[t] - 
            0.034231213779558796`\ \(c[10]\)[t] - 
            0.06935801494512592`\ \(c[11]\)[t] - 
            0.10394325375429328`\ \(c[12]\)[t] - 
            0.1364713527783359`\ \(c[13]\)[t] - 
            0.1653986686265376`\ \(c[14]\)[t] - 
            0.18920668216016426`\ \(c[15]\)[t] - 
            0.20645618564475834`\ \(c[16]\)[t] - 
            0.21584055771952013`\ \(c[17]\)[t] - 
            0.21623620818304484`\ \(c[18]\)[t] - 
            0.20674833578317206`\ \(c[19]\)[t] - 
            0.18675027222298607`\ \(c[20]\)[t] - 
            0.15591488063143982`\ \(c[21]\)[t] - 
            0.11423673049785459`\ \(c[22]\)[t] - 
            0.062044074975450475`\ \(c[23]\)[t] + 
            3.898171832519376`*^-17\ \(c[24]\)[t] + 
            0.07090751425765746`\ \(c[25]\)[t] + 
            0.14938649372796345`\ \(c[26]\)[t] + 
            0.23387232094715985`\ \(c[27]\)[t] + 
            0.32256865202152113`\ \(c[28]\)[t] + 
            0.41349667156634395`\ \(c[29]\)[t] + 
            0.5045511524271047`\ \(c[30]\)[t] + 
            0.5935615337286801`\ \(c[31]\)[t] + 
            0.6783560385470632`\ \(c[32]\)[t] + 
            0.7568267286406569`\ \(c[33]\)[t] + 
            0.826993343132688`\ \(c[34]\)[t] + 
            0.8870637930591838`\ \(c[35]\)[t] + 
            0.9354892837886392`\ \(c[36]\)[t] + 
            0.9710122092317629`\ \(c[37]\)[t] + 
            0.9927051996072067`\ \(c[38]\)[t] + 
            34.35926287568203`\ \(c[39]\)[t] + 
            0.9927051996072069`\ \(c[40]\)[t] + 
            0.9710122092317629`\ \(c[41]\)[t] + 
            0.9354892837886392`\ \(c[42]\)[t] + 
            0.8870637930591839`\ \(c[43]\)[t] + 
            0.8269933431326885`\ \(c[44]\)[t] + 
            0.7568267286406569`\ \(c[45]\)[t] + 
            0.6783560385470636`\ \(c[46]\)[t] + 
            0.5935615337286809`\ \(c[47]\)[t] + 
            0.5045511524271047`\ \(c[48]\)[t] + 
            0.4134966715663443`\ \(c[49]\)[t] + 
            0.3225686520215219`\ \(c[50]\)[t] + 
            0.23387232094715985`\ \(c[51]\)[t] + 
            0.14938649372796384`\ \(c[52]\)[t] + 
            0.0709075142576581`\ \(c[53]\)[t] + 
            3.898171832519376`*^-17\ \(c[54]\)[t] - 
            0.06204407497545024`\ \(c[55]\)[t] - 
            0.11423673049785416`\ \(c[56]\)[t] - 
            0.15591488063143982`\ \(c[57]\)[t] - 
            0.18675027222298593`\ \(c[58]\)[t] - 
            0.2067483357831719`\ \(c[59]\)[t] - 
            0.21623620818304484`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 39, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 39]][ t]], 
          Plus[ 
            Times[ 0.045868286584282256, 
              c[ -60][ t]], 
            Times[ 0.048454002753361682, 
              c[ -59][ t]], 
            Times[ 0.04895352855494272, 
              c[ -58][ t]], 
            Times[ 0.047301670540041058, 
              c[ -57][ t]], 
            Times[ 0.043525965428036162, 
              c[ -56][ t]], 
            Times[ 0.03774739544932687, 
              c[ -55][ t]], 
            Times[ 0.030177073670601236, 
              c[ -54][ t]], 
            Times[ 0.021108961070255627, 
              c[ -53][ t]], 
            Times[ 0.010908848347331966, 
              c[ -52][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -51][ t]], 
            Times[ -0.011153991006822649, 
              c[ -50][ t]], 
            Times[ -0.022068459300722043, 
              c[ -49][ t]], 
            Times[ -0.032258251165125519, 
              c[ -48][ t]], 
            Times[ -0.041258781072520248, 
              c[ -47][ t]], 
            Times[ -0.048646667243099281, 
              c[ -46][ t]], 
            Times[ -0.054059052045761224, 
              c[ -45][ t]], 
            Times[ -0.057210750238908967, 
              c[ -44][ t]], 
            Times[ -0.057908442314993203, 
              c[ -43][ t]], 
            Times[ -0.056061239158567186, 
              c[ -42][ t]], 
            Times[ -0.05168708394579296, 
              c[ -41][ t]], 
            Times[ -0.044914622433376419, 
              c[ -40][ t]], 
            Times[ -0.035980357068793781, 
              c[ -39][ t]], 
            Times[ -0.025221096343682053, 
              c[ -38][ t]], 
            Times[ -0.013061910521147383, 
              c[ -37][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -36][ t]], 
            Times[ 0.013414935129827233, 
              c[ -35][ t]], 
            Times[ 0.026603074225527826, 
              c[ -34][ t]], 
            Times[ 0.03897872015785999, 
              c[ -33][ t]], 
            Times[ 0.049975424961080865, 
              c[ -32][ t]], 
            Times[ 0.059070953080906326, 
              c[ -31][ t]], 
            Times[ 0.065811019881796273, 
              c[ -30][ t]], 
            Times[ 0.069830768673962415, 
              c[ -29][ t]], 
            Times[ 0.070873018952678238, 
              c[ -28][ t]], 
            Times[ 0.068802429876423349, 
              c[ -27][ t]], 
            Times[ 0.063614872548668253, 
              c[ -26][ t]], 
            Times[ 0.055441487066198933, 
              c[ -25][ t]], 
            Times[ 0.044547108751839919, 
              c[ -24][ t]], 
            Times[ 0.031322974491347078, 
              c[ -23][ t]], 
            Times[ 0.016273855731265604, 
              c[ -22][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -21][ t]], 
            Times[ -0.016825511857749401, 
              c[ -20][ t]], 
            Times[ -0.033483179628681567, 
              c[ -19][ t]], 
            Times[ -0.049236278094138941, 
              c[ -18][ t]], 
            Times[ -0.063361699504227528, 
              c[ -17][ t]], 
            Times[ -0.075181213012062598, 
              c[ -16][ t]], 
            Times[ -0.084091858737850814, 
              c[ -15][ t]], 
            Times[ -0.089594193770366884, 
              c[ -14][ t]], 
            Times[ -0.091317159035181589, 
              c[ -13][ t]], 
            Times[ -0.089038438663606695, 
              c[ -12][ t]], 
            Times[ -0.082699334313268744, 
              c[ -11][ t]], 
            Times[ -0.072413370861974122, 
              c[ -10][ t]], 
            Times[ -0.058468080236789913, 
              c[ -9][ t]], 
            Times[ -0.041319668477947373, 
              c[ -8][ t]], 
            Times[ -0.021580547817547879, 
              c[ -7][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -6][ t]], 
            Times[ 0.022561481809254675, 
              c[ -5][ t]], 
            Times[ 0.045163358568919301, 
              c[ -4][ t]], 
            Times[ 0.066820663127759972, 
              c[ -3][ t]], 
            Times[ 0.086542809078944752, 
              c[ -2][ t]], 
            Times[ 0.10337416789158609, 
              c[ -1][ t]], 
            Times[ 0.11643488132933186, 
              c[ 0][ t]], 
            Times[ 0.12496032289024853, 
              c[ 1][ t]], 
            Times[ 0.12833762891430925, 
              c[ 2][ t]], 
            Times[ 0.12613778810677614, 
              c[ 3][ t]], 
            Times[ 0.11814190616181255, 
              c[ 4][ t]], 
            Times[ 0.10436044624225692, 
              c[ 5][ t]], 
            Times[ 0.085044480344421705, 
              c[ 6][ t]], 
            Times[ 0.060688263076985223, 
              c[ 7][ t]], 
            Times[ 0.032022748374426029, 
              c[ 8][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 9][ t]], 
            Times[ -0.034231213779558796, 
              c[ 10][ t]], 
            Times[ -0.069358014945125918, 
              c[ 11][ t]], 
            Times[ -0.10394325375429328, 
              c[ 12][ t]], 
            Times[ -0.13647135277833591, 
              c[ 13][ t]], 
            Times[ -0.1653986686265376, 
              c[ 14][ t]], 
            Times[ -0.18920668216016426, 
              c[ 15][ t]], 
            Times[ -0.20645618564475834, 
              c[ 16][ t]], 
            Times[ -0.21584055771952013, 
              c[ 17][ t]], 
            Times[ -0.21623620818304484, 
              c[ 18][ t]], 
            Times[ -0.20674833578317206, 
              c[ 19][ t]], 
            Times[ -0.18675027222298607, 
              c[ 20][ t]], 
            Times[ -0.15591488063143982, 
              c[ 21][ t]], 
            Times[ -0.11423673049785459, 
              c[ 22][ t]], 
            Times[ -0.062044074975450475, 
              c[ 23][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 24][ t]], 
            Times[ 0.070907514257657456, 
              c[ 25][ t]], 
            Times[ 0.14938649372796345, 
              c[ 26][ t]], 
            Times[ 0.23387232094715985, 
              c[ 27][ t]], 
            Times[ 0.32256865202152113, 
              c[ 28][ t]], 
            Times[ 0.41349667156634395, 
              c[ 29][ t]], 
            Times[ 0.50455115242710469, 
              c[ 30][ t]], 
            Times[ 0.59356153372868015, 
              c[ 31][ t]], 
            Times[ 0.67835603854706317, 
              c[ 32][ t]], 
            Times[ 0.75682672864065692, 
              c[ 33][ t]], 
            Times[ 0.82699334313268802, 
              c[ 34][ t]], 
            Times[ 0.88706379305918381, 
              c[ 35][ t]], 
            Times[ 0.93548928378863916, 
              c[ 36][ t]], 
            Times[ 0.9710122092317629, 
              c[ 37][ t]], 
            Times[ 0.99270519960720671, 
              c[ 38][ t]], 
            Times[ 34.359262875682028, 
              c[ 39][ t]], 
            Times[ 0.99270519960720693, 
              c[ 40][ t]], 
            Times[ 0.9710122092317629, 
              c[ 41][ t]], 
            Times[ 0.93548928378863916, 
              c[ 42][ t]], 
            Times[ 0.88706379305918392, 
              c[ 43][ t]], 
            Times[ 0.82699334313268846, 
              c[ 44][ t]], 
            Times[ 0.75682672864065692, 
              c[ 45][ t]], 
            Times[ 0.67835603854706361, 
              c[ 46][ t]], 
            Times[ 0.59356153372868092, 
              c[ 47][ t]], 
            Times[ 0.50455115242710469, 
              c[ 48][ t]], 
            Times[ 0.41349667156634429, 
              c[ 49][ t]], 
            Times[ 0.32256865202152191, 
              c[ 50][ t]], 
            Times[ 0.23387232094715985, 
              c[ 51][ t]], 
            Times[ 0.14938649372796384, 
              c[ 52][ t]], 
            Times[ 0.070907514257658094, 
              c[ 53][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 54][ t]], 
            Times[ -0.062044074975450239, 
              c[ 55][ t]], 
            Times[ -0.11423673049785416, 
              c[ 56][ t]], 
            Times[ -0.15591488063143982, 
              c[ 57][ t]], 
            Times[ -0.18675027222298593, 
              c[ 58][ t]], 
            Times[ -0.20674833578317189, 
              c[ 59][ t]], 
            Times[ -0.21623620818304484, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "40", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[40]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.04134966715663448`\ \(c[\(-60\)]\)[t] + 
            0.04586828658428231`\ \(c[\(-59\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-58\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-57\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-56\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-55\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-54\)]\)[t] + 
            0.030177073670601094`\ \(c[\(-53\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-52\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-51\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-50\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-49\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-48\)]\)[t] - 
            0.03225825116512568`\ \(c[\(-47\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-46\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-45\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-44\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-43\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-42\)]\)[t] - 
            0.05606123915856713`\ \(c[\(-41\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-40\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-39\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-38\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-37\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-36\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-35\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-34\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-33\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-32\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-31\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-30\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-29\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-28\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-27\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-26\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-25\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-24\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-23\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-22\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-21\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-20\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-19\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-18\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-17\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-16\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-15\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-14\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-13\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-12\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-11\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-10\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-9\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-8\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-7\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-6\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-5\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-4\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-3\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-2\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-1\)]\)[t] + 
            0.10337416789158609`\ \(c[0]\)[t] + 
            0.11643488132933186`\ \(c[1]\)[t] + 
            0.12496032289024853`\ \(c[2]\)[t] + 
            0.12833762891430928`\ \(c[3]\)[t] + 
            0.12613778810677612`\ \(c[4]\)[t] + 
            0.11814190616181255`\ \(c[5]\)[t] + 
            0.10436044624225685`\ \(c[6]\)[t] + 
            0.0850444803444217`\ \(c[7]\)[t] + 
            0.060688263076985105`\ \(c[8]\)[t] + 
            0.032022748374425904`\ \(c[9]\)[t] - 
            3.898171832519376`*^-17\ \(c[10]\)[t] - 
            0.03423121377955895`\ \(c[11]\)[t] - 
            0.06935801494512607`\ \(c[12]\)[t] - 
            0.10394325375429328`\ \(c[13]\)[t] - 
            0.13647135277833605`\ \(c[14]\)[t] - 
            0.1653986686265377`\ \(c[15]\)[t] - 
            0.18920668216016426`\ \(c[16]\)[t] - 
            0.20645618564475843`\ \(c[17]\)[t] - 
            0.21584055771952015`\ \(c[18]\)[t] - 
            0.21623620818304484`\ \(c[19]\)[t] - 
            0.206748335783172`\ \(c[20]\)[t] - 
            0.18675027222298593`\ \(c[21]\)[t] - 
            0.15591488063143982`\ \(c[22]\)[t] - 
            0.11423673049785436`\ \(c[23]\)[t] - 
            0.06204407497545024`\ \(c[24]\)[t] + 
            3.898171832519376`*^-17\ \(c[25]\)[t] + 
            0.07090751425765777`\ \(c[26]\)[t] + 
            0.14938649372796384`\ \(c[27]\)[t] + 
            0.23387232094715985`\ \(c[28]\)[t] + 
            0.3225686520215216`\ \(c[29]\)[t] + 
            0.4134966715663443`\ \(c[30]\)[t] + 
            0.5045511524271047`\ \(c[31]\)[t] + 
            0.5935615337286806`\ \(c[32]\)[t] + 
            0.6783560385470636`\ \(c[33]\)[t] + 
            0.7568267286406569`\ \(c[34]\)[t] + 
            0.8269933431326881`\ \(c[35]\)[t] + 
            0.8870637930591839`\ \(c[36]\)[t] + 
            0.9354892837886392`\ \(c[37]\)[t] + 
            0.9710122092317629`\ \(c[38]\)[t] + 
            0.9927051996072069`\ \(c[39]\)[t] + 
            36.09192675942882`\ \(c[40]\)[t] + 
            0.9927051996072069`\ \(c[41]\)[t] + 
            0.9710122092317629`\ \(c[42]\)[t] + 
            0.9354892837886392`\ \(c[43]\)[t] + 
            0.8870637930591839`\ \(c[44]\)[t] + 
            0.826993343132688`\ \(c[45]\)[t] + 
            0.7568267286406569`\ \(c[46]\)[t] + 
            0.6783560385470636`\ \(c[47]\)[t] + 
            0.5935615337286801`\ \(c[48]\)[t] + 
            0.5045511524271047`\ \(c[49]\)[t] + 
            0.4134966715663443`\ \(c[50]\)[t] + 
            0.32256865202152113`\ \(c[51]\)[t] + 
            0.23387232094715985`\ \(c[52]\)[t] + 
            0.14938649372796384`\ \(c[53]\)[t] + 
            0.07090751425765746`\ \(c[54]\)[t] + 
            3.898171832519376`*^-17\ \(c[55]\)[t] - 
            0.06204407497545024`\ \(c[56]\)[t] - 
            0.11423673049785459`\ \(c[57]\)[t] - 
            0.15591488063143982`\ \(c[58]\)[t] - 
            0.18675027222298593`\ \(c[59]\)[t] - 
            0.20674833578317206`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 40, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 40]][ t]], 
          Plus[ 
            Times[ 0.041349667156634483, 
              c[ -60][ t]], 
            Times[ 0.045868286584282311, 
              c[ -59][ t]], 
            Times[ 0.048454002753361682, 
              c[ -58][ t]], 
            Times[ 0.04895352855494272, 
              c[ -57][ t]], 
            Times[ 0.047301670540041058, 
              c[ -56][ t]], 
            Times[ 0.043525965428036162, 
              c[ -55][ t]], 
            Times[ 0.03774739544932687, 
              c[ -54][ t]], 
            Times[ 0.030177073670601094, 
              c[ -53][ t]], 
            Times[ 0.021108961070255627, 
              c[ -52][ t]], 
            Times[ 0.010908848347331966, 
              c[ -51][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -50][ t]], 
            Times[ -0.011153991006822649, 
              c[ -49][ t]], 
            Times[ -0.022068459300722043, 
              c[ -48][ t]], 
            Times[ -0.032258251165125679, 
              c[ -47][ t]], 
            Times[ -0.041258781072520248, 
              c[ -46][ t]], 
            Times[ -0.048646667243099281, 
              c[ -45][ t]], 
            Times[ -0.054059052045761224, 
              c[ -44][ t]], 
            Times[ -0.057210750238908967, 
              c[ -43][ t]], 
            Times[ -0.057908442314993203, 
              c[ -42][ t]], 
            Times[ -0.05606123915856713, 
              c[ -41][ t]], 
            Times[ -0.05168708394579296, 
              c[ -40][ t]], 
            Times[ -0.044914622433376419, 
              c[ -39][ t]], 
            Times[ -0.035980357068793781, 
              c[ -38][ t]], 
            Times[ -0.025221096343682053, 
              c[ -37][ t]], 
            Times[ -0.013061910521147383, 
              c[ -36][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -35][ t]], 
            Times[ 0.013414935129827233, 
              c[ -34][ t]], 
            Times[ 0.026603074225527826, 
              c[ -33][ t]], 
            Times[ 0.03897872015785999, 
              c[ -32][ t]], 
            Times[ 0.049975424961080865, 
              c[ -31][ t]], 
            Times[ 0.059070953080906326, 
              c[ -30][ t]], 
            Times[ 0.065811019881796273, 
              c[ -29][ t]], 
            Times[ 0.069830768673962415, 
              c[ -28][ t]], 
            Times[ 0.070873018952678238, 
              c[ -27][ t]], 
            Times[ 0.068802429876423349, 
              c[ -26][ t]], 
            Times[ 0.063614872548668253, 
              c[ -25][ t]], 
            Times[ 0.055441487066198933, 
              c[ -24][ t]], 
            Times[ 0.044547108751839919, 
              c[ -23][ t]], 
            Times[ 0.031322974491347078, 
              c[ -22][ t]], 
            Times[ 0.016273855731265604, 
              c[ -21][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -20][ t]], 
            Times[ -0.016825511857749401, 
              c[ -19][ t]], 
            Times[ -0.033483179628681567, 
              c[ -18][ t]], 
            Times[ -0.049236278094138941, 
              c[ -17][ t]], 
            Times[ -0.063361699504227528, 
              c[ -16][ t]], 
            Times[ -0.075181213012062598, 
              c[ -15][ t]], 
            Times[ -0.084091858737850814, 
              c[ -14][ t]], 
            Times[ -0.089594193770366884, 
              c[ -13][ t]], 
            Times[ -0.091317159035181589, 
              c[ -12][ t]], 
            Times[ -0.089038438663606695, 
              c[ -11][ t]], 
            Times[ -0.082699334313268744, 
              c[ -10][ t]], 
            Times[ -0.072413370861974122, 
              c[ -9][ t]], 
            Times[ -0.058468080236789913, 
              c[ -8][ t]], 
            Times[ -0.04131966847794722, 
              c[ -7][ t]], 
            Times[ -0.021580547817547879, 
              c[ -6][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -5][ t]], 
            Times[ 0.022561481809254869, 
              c[ -4][ t]], 
            Times[ 0.045163358568919301, 
              c[ -3][ t]], 
            Times[ 0.066820663127759972, 
              c[ -2][ t]], 
            Times[ 0.086542809078944891, 
              c[ -1][ t]], 
            Times[ 0.10337416789158609, 
              c[ 0][ t]], 
            Times[ 0.11643488132933186, 
              c[ 1][ t]], 
            Times[ 0.12496032289024853, 
              c[ 2][ t]], 
            Times[ 0.12833762891430928, 
              c[ 3][ t]], 
            Times[ 0.12613778810677612, 
              c[ 4][ t]], 
            Times[ 0.11814190616181255, 
              c[ 5][ t]], 
            Times[ 0.10436044624225685, 
              c[ 6][ t]], 
            Times[ 0.085044480344421705, 
              c[ 7][ t]], 
            Times[ 0.060688263076985105, 
              c[ 8][ t]], 
            Times[ 0.032022748374425904, 
              c[ 9][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 10][ t]], 
            Times[ -0.034231213779558949, 
              c[ 11][ t]], 
            Times[ -0.06935801494512607, 
              c[ 12][ t]], 
            Times[ -0.10394325375429328, 
              c[ 13][ t]], 
            Times[ -0.13647135277833605, 
              c[ 14][ t]], 
            Times[ -0.16539866862653771, 
              c[ 15][ t]], 
            Times[ -0.18920668216016426, 
              c[ 16][ t]], 
            Times[ -0.20645618564475843, 
              c[ 17][ t]], 
            Times[ -0.21584055771952015, 
              c[ 18][ t]], 
            Times[ -0.21623620818304484, 
              c[ 19][ t]], 
            Times[ -0.206748335783172, 
              c[ 20][ t]], 
            Times[ -0.18675027222298593, 
              c[ 21][ t]], 
            Times[ -0.15591488063143982, 
              c[ 22][ t]], 
            Times[ -0.11423673049785436, 
              c[ 23][ t]], 
            Times[ -0.062044074975450239, 
              c[ 24][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 25][ t]], 
            Times[ 0.070907514257657775, 
              c[ 26][ t]], 
            Times[ 0.14938649372796384, 
              c[ 27][ t]], 
            Times[ 0.23387232094715985, 
              c[ 28][ t]], 
            Times[ 0.32256865202152157, 
              c[ 29][ t]], 
            Times[ 0.41349667156634429, 
              c[ 30][ t]], 
            Times[ 0.50455115242710469, 
              c[ 31][ t]], 
            Times[ 0.59356153372868059, 
              c[ 32][ t]], 
            Times[ 0.67835603854706361, 
              c[ 33][ t]], 
            Times[ 0.75682672864065692, 
              c[ 34][ t]], 
            Times[ 0.82699334313268813, 
              c[ 35][ t]], 
            Times[ 0.88706379305918392, 
              c[ 36][ t]], 
            Times[ 0.93548928378863916, 
              c[ 37][ t]], 
            Times[ 0.9710122092317629, 
              c[ 38][ t]], 
            Times[ 0.99270519960720693, 
              c[ 39][ t]], 
            Times[ 36.091926759428823, 
              c[ 40][ t]], 
            Times[ 0.99270519960720693, 
              c[ 41][ t]], 
            Times[ 0.9710122092317629, 
              c[ 42][ t]], 
            Times[ 0.93548928378863916, 
              c[ 43][ t]], 
            Times[ 0.88706379305918392, 
              c[ 44][ t]], 
            Times[ 0.82699334313268802, 
              c[ 45][ t]], 
            Times[ 0.75682672864065692, 
              c[ 46][ t]], 
            Times[ 0.67835603854706361, 
              c[ 47][ t]], 
            Times[ 0.59356153372868015, 
              c[ 48][ t]], 
            Times[ 0.50455115242710469, 
              c[ 49][ t]], 
            Times[ 0.41349667156634429, 
              c[ 50][ t]], 
            Times[ 0.32256865202152113, 
              c[ 51][ t]], 
            Times[ 0.23387232094715985, 
              c[ 52][ t]], 
            Times[ 0.14938649372796384, 
              c[ 53][ t]], 
            Times[ 0.070907514257657456, 
              c[ 54][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 55][ t]], 
            Times[ -0.062044074975450239, 
              c[ 56][ t]], 
            Times[ -0.11423673049785459, 
              c[ 57][ t]], 
            Times[ -0.15591488063143982, 
              c[ 58][ t]], 
            Times[ -0.18675027222298593, 
              c[ 59][ t]], 
            Times[ -0.20674833578317206, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "41", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[41]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.035131239329076656`\ \(c[\(-60\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-59\)]\)[t] + 
            0.04586828658428231`\ \(c[\(-58\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-57\)]\)[t] + 
            0.0489535285549427`\ \(c[\(-56\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-55\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-54\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-53\)]\)[t] + 
            0.030177073670601094`\ \(c[\(-52\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-51\)]\)[t] + 
            0.010908848347331785`\ \(c[\(-50\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-49\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-48\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-47\)]\)[t] - 
            0.03225825116512568`\ \(c[\(-46\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-45\)]\)[t] - 
            0.0486466672430994`\ \(c[\(-44\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-43\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-42\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-41\)]\)[t] - 
            0.05606123915856713`\ \(c[\(-40\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-39\)]\)[t] - 
            0.04491462243337629`\ \(c[\(-38\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-37\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-36\)]\)[t] - 
            0.013061910521147276`\ \(c[\(-35\)]\)[t] + 
            1.5206810699945212`*^-16\ \(c[\(-34\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-33\)]\)[t] + 
            0.026603074225527937`\ \(c[\(-32\)]\)[t] + 
            0.03897872015786009`\ \(c[\(-31\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-30\)]\)[t] + 
            0.0590709530809064`\ \(c[\(-29\)]\)[t] + 
            0.06581101988179631`\ \(c[\(-28\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-27\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-26\)]\)[t] + 
            0.06880242987642332`\ \(c[\(-25\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-24\)]\)[t] + 
            0.055441487066198857`\ \(c[\(-23\)]\)[t] + 
            0.044547108751839815`\ \(c[\(-22\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-21\)]\)[t] + 
            0.01627385573126547`\ \(c[\(-20\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-19\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-18\)]\)[t] - 
            0.033483179628681706`\ \(c[\(-17\)]\)[t] - 
            0.049236278094139066`\ \(c[\(-16\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-15\)]\)[t] - 
            0.0751812130120627`\ \(c[\(-14\)]\)[t] - 
            0.08409185873785086`\ \(c[\(-13\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-12\)]\)[t] - 
            0.0913171590351816`\ \(c[\(-11\)]\)[t] - 
            0.08903843866360665`\ \(c[\(-10\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-9\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-8\)]\)[t] - 
            0.058468080236789774`\ \(c[\(-7\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-6\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-5\)]\)[t] + 
            2.274590327822911`*^-16\ \(c[\(-4\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-3\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-2\)]\)[t] + 
            0.06682066312776015`\ \(c[\(-1\)]\)[t] + 
            0.08654280907894489`\ \(c[0]\)[t] + 
            0.10337416789158609`\ \(c[1]\)[t] + 
            0.11643488132933195`\ \(c[2]\)[t] + 
            0.12496032289024853`\ \(c[3]\)[t] + 
            0.12833762891430925`\ \(c[4]\)[t] + 
            0.12613778810677612`\ \(c[5]\)[t] + 
            0.11814190616181253`\ \(c[6]\)[t] + 
            0.10436044624225685`\ \(c[7]\)[t] + 
            0.08504448034442161`\ \(c[8]\)[t] + 
            0.060688263076985`\ \(c[9]\)[t] + 
            0.032022748374425904`\ \(c[10]\)[t] - 
            1.8033970416801674`*^-16\ \(c[11]\)[t] - 
            0.034231213779559094`\ \(c[12]\)[t] - 
            0.06935801494512607`\ \(c[13]\)[t] - 
            0.1039432537542934`\ \(c[14]\)[t] - 
            0.13647135277833616`\ \(c[15]\)[t] - 
            0.1653986686265377`\ \(c[16]\)[t] - 
            0.18920668216016434`\ \(c[17]\)[t] - 
            0.20645618564475848`\ \(c[18]\)[t] - 
            0.21584055771952015`\ \(c[19]\)[t] - 
            0.21623620818304481`\ \(c[20]\)[t] - 
            0.2067483357831719`\ \(c[21]\)[t] - 
            0.18675027222298593`\ \(c[22]\)[t] - 
            0.15591488063143966`\ \(c[23]\)[t] - 
            0.11423673049785416`\ \(c[24]\)[t] - 
            0.06204407497545024`\ \(c[25]\)[t] + 
            3.216976900108398`*^-16\ \(c[26]\)[t] + 
            0.0709075142576581`\ \(c[27]\)[t] + 
            0.14938649372796384`\ \(c[28]\)[t] + 
            0.23387232094716018`\ \(c[29]\)[t] + 
            0.3225686520215219`\ \(c[30]\)[t] + 
            0.4134966715663443`\ \(c[31]\)[t] + 
            0.504551152427105`\ \(c[32]\)[t] + 
            0.5935615337286809`\ \(c[33]\)[t] + 
            0.6783560385470636`\ \(c[34]\)[t] + 
            0.7568267286406574`\ \(c[35]\)[t] + 
            0.8269933431326885`\ \(c[36]\)[t] + 
            0.8870637930591839`\ \(c[37]\)[t] + 
            0.9354892837886393`\ \(c[38]\)[t] + 
            0.9710122092317629`\ \(c[39]\)[t] + 
            0.9927051996072069`\ \(c[40]\)[t] + 
            37.868455551624905`\ \(c[41]\)[t] + 
            0.9927051996072067`\ \(c[42]\)[t] + 
            0.9710122092317629`\ \(c[43]\)[t] + 
            0.9354892837886392`\ \(c[44]\)[t] + 
            0.8870637930591835`\ \(c[45]\)[t] + 
            0.826993343132688`\ \(c[46]\)[t] + 
            0.7568267286406569`\ \(c[47]\)[t] + 
            0.6783560385470627`\ \(c[48]\)[t] + 
            0.5935615337286801`\ \(c[49]\)[t] + 
            0.5045511524271047`\ \(c[50]\)[t] + 
            0.4134966715663436`\ \(c[51]\)[t] + 
            0.32256865202152113`\ \(c[52]\)[t] + 
            0.23387232094715985`\ \(c[53]\)[t] + 
            0.14938649372796314`\ \(c[54]\)[t] + 
            0.07090751425765746`\ \(c[55]\)[t] + 
            3.898171832519376`*^-17\ \(c[56]\)[t] - 
            0.06204407497545072`\ \(c[57]\)[t] - 
            0.11423673049785459`\ \(c[58]\)[t] - 
            0.15591488063143982`\ \(c[59]\)[t] - 
            0.18675027222298618`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 41, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 41]][ t]], 
          Plus[ 
            Times[ 0.035131239329076656, 
              c[ -60][ t]], 
            Times[ 0.041349667156634483, 
              c[ -59][ t]], 
            Times[ 0.045868286584282311, 
              c[ -58][ t]], 
            Times[ 0.048454002753361682, 
              c[ -57][ t]], 
            Times[ 0.048953528554942699, 
              c[ -56][ t]], 
            Times[ 0.047301670540041058, 
              c[ -55][ t]], 
            Times[ 0.043525965428036162, 
              c[ -54][ t]], 
            Times[ 0.03774739544932687, 
              c[ -53][ t]], 
            Times[ 0.030177073670601094, 
              c[ -52][ t]], 
            Times[ 0.021108961070255627, 
              c[ -51][ t]], 
            Times[ 0.010908848347331785, 
              c[ -50][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -49][ t]], 
            Times[ -0.011153991006822649, 
              c[ -48][ t]], 
            Times[ -0.022068459300722043, 
              c[ -47][ t]], 
            Times[ -0.032258251165125679, 
              c[ -46][ t]], 
            Times[ -0.041258781072520248, 
              c[ -45][ t]], 
            Times[ -0.048646667243099399, 
              c[ -44][ t]], 
            Times[ -0.054059052045761224, 
              c[ -43][ t]], 
            Times[ -0.057210750238908967, 
              c[ -42][ t]], 
            Times[ -0.057908442314993203, 
              c[ -41][ t]], 
            Times[ -0.05606123915856713, 
              c[ -40][ t]], 
            Times[ -0.05168708394579296, 
              c[ -39][ t]], 
            Times[ -0.044914622433376288, 
              c[ -38][ t]], 
            Times[ -0.035980357068793781, 
              c[ -37][ t]], 
            Times[ -0.025221096343682053, 
              c[ -36][ t]], 
            Times[ -0.013061910521147276, 
              c[ -35][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ -34][ t]], 
            Times[ 0.013414935129827233, 
              c[ -33][ t]], 
            Times[ 0.026603074225527937, 
              c[ -32][ t]], 
            Times[ 0.038978720157860088, 
              c[ -31][ t]], 
            Times[ 0.049975424961080865, 
              c[ -30][ t]], 
            Times[ 0.059070953080906402, 
              c[ -29][ t]], 
            Times[ 0.065811019881796315, 
              c[ -28][ t]], 
            Times[ 0.069830768673962415, 
              c[ -27][ t]], 
            Times[ 0.070873018952678238, 
              c[ -26][ t]], 
            Times[ 0.068802429876423321, 
              c[ -25][ t]], 
            Times[ 0.063614872548668253, 
              c[ -24][ t]], 
            Times[ 0.055441487066198857, 
              c[ -23][ t]], 
            Times[ 0.044547108751839815, 
              c[ -22][ t]], 
            Times[ 0.031322974491347078, 
              c[ -21][ t]], 
            Times[ 0.016273855731265469, 
              c[ -20][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -19][ t]], 
            Times[ -0.016825511857749401, 
              c[ -18][ t]], 
            Times[ -0.033483179628681706, 
              c[ -17][ t]], 
            Times[ -0.049236278094139066, 
              c[ -16][ t]], 
            Times[ -0.063361699504227528, 
              c[ -15][ t]], 
            Times[ -0.075181213012062695, 
              c[ -14][ t]], 
            Times[ -0.084091858737850855, 
              c[ -13][ t]], 
            Times[ -0.089594193770366884, 
              c[ -12][ t]], 
            Times[ -0.091317159035181603, 
              c[ -11][ t]], 
            Times[ -0.089038438663606653, 
              c[ -10][ t]], 
            Times[ -0.082699334313268744, 
              c[ -9][ t]], 
            Times[ -0.072413370861974122, 
              c[ -8][ t]], 
            Times[ -0.058468080236789774, 
              c[ -7][ t]], 
            Times[ -0.04131966847794722, 
              c[ -6][ t]], 
            Times[ -0.021580547817547879, 
              c[ -5][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ -4][ t]], 
            Times[ 0.022561481809254869, 
              c[ -3][ t]], 
            Times[ 0.045163358568919301, 
              c[ -2][ t]], 
            Times[ 0.066820663127760152, 
              c[ -1][ t]], 
            Times[ 0.086542809078944891, 
              c[ 0][ t]], 
            Times[ 0.10337416789158609, 
              c[ 1][ t]], 
            Times[ 0.11643488132933195, 
              c[ 2][ t]], 
            Times[ 0.12496032289024853, 
              c[ 3][ t]], 
            Times[ 0.12833762891430925, 
              c[ 4][ t]], 
            Times[ 0.12613778810677612, 
              c[ 5][ t]], 
            Times[ 0.11814190616181253, 
              c[ 6][ t]], 
            Times[ 0.10436044624225685, 
              c[ 7][ t]], 
            Times[ 0.085044480344421608, 
              c[ 8][ t]], 
            Times[ 0.060688263076985001, 
              c[ 9][ t]], 
            Times[ 0.032022748374425904, 
              c[ 10][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 11][ t]], 
            Times[ -0.034231213779559094, 
              c[ 12][ t]], 
            Times[ -0.06935801494512607, 
              c[ 13][ t]], 
            Times[ -0.1039432537542934, 
              c[ 14][ t]], 
            Times[ -0.13647135277833616, 
              c[ 15][ t]], 
            Times[ -0.16539866862653771, 
              c[ 16][ t]], 
            Times[ -0.18920668216016434, 
              c[ 17][ t]], 
            Times[ -0.20645618564475848, 
              c[ 18][ t]], 
            Times[ -0.21584055771952015, 
              c[ 19][ t]], 
            Times[ -0.21623620818304481, 
              c[ 20][ t]], 
            Times[ -0.20674833578317189, 
              c[ 21][ t]], 
            Times[ -0.18675027222298593, 
              c[ 22][ t]], 
            Times[ -0.15591488063143966, 
              c[ 23][ t]], 
            Times[ -0.11423673049785416, 
              c[ 24][ t]], 
            Times[ -0.062044074975450239, 
              c[ 25][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ 26][ t]], 
            Times[ 0.070907514257658094, 
              c[ 27][ t]], 
            Times[ 0.14938649372796384, 
              c[ 28][ t]], 
            Times[ 0.23387232094716018, 
              c[ 29][ t]], 
            Times[ 0.32256865202152191, 
              c[ 30][ t]], 
            Times[ 0.41349667156634429, 
              c[ 31][ t]], 
            Times[ 0.50455115242710502, 
              c[ 32][ t]], 
            Times[ 0.59356153372868092, 
              c[ 33][ t]], 
            Times[ 0.67835603854706361, 
              c[ 34][ t]], 
            Times[ 0.75682672864065736, 
              c[ 35][ t]], 
            Times[ 0.82699334313268846, 
              c[ 36][ t]], 
            Times[ 0.88706379305918392, 
              c[ 37][ t]], 
            Times[ 0.93548928378863927, 
              c[ 38][ t]], 
            Times[ 0.9710122092317629, 
              c[ 39][ t]], 
            Times[ 0.99270519960720693, 
              c[ 40][ t]], 
            Times[ 37.868455551624905, 
              c[ 41][ t]], 
            Times[ 0.99270519960720671, 
              c[ 42][ t]], 
            Times[ 0.9710122092317629, 
              c[ 43][ t]], 
            Times[ 0.93548928378863916, 
              c[ 44][ t]], 
            Times[ 0.88706379305918348, 
              c[ 45][ t]], 
            Times[ 0.82699334313268802, 
              c[ 46][ t]], 
            Times[ 0.75682672864065692, 
              c[ 47][ t]], 
            Times[ 0.67835603854706272, 
              c[ 48][ t]], 
            Times[ 0.59356153372868015, 
              c[ 49][ t]], 
            Times[ 0.50455115242710469, 
              c[ 50][ t]], 
            Times[ 0.41349667156634362, 
              c[ 51][ t]], 
            Times[ 0.32256865202152113, 
              c[ 52][ t]], 
            Times[ 0.23387232094715985, 
              c[ 53][ t]], 
            Times[ 0.14938649372796314, 
              c[ 54][ t]], 
            Times[ 0.070907514257657456, 
              c[ 55][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 56][ t]], 
            Times[ -0.062044074975450718, 
              c[ 57][ t]], 
            Times[ -0.11423673049785459, 
              c[ 58][ t]], 
            Times[ -0.15591488063143982, 
              c[ 59][ t]], 
            Times[ -0.18675027222298618, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "42", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[42]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.027514390699665887`\ \(c[\(-60\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-59\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-58\)]\)[t] + 
            0.045868286584282256`\ \(c[\(-57\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-56\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-55\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-54\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-53\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-52\)]\)[t] + 
            0.030177073670601236`\ \(c[\(-51\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-50\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-49\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-48\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-47\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-46\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-45\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-44\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-43\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-42\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-41\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-40\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-39\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-38\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-37\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-36\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-35\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-34\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-33\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-32\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-31\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-30\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-29\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-28\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-27\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-26\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-25\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-24\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-23\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-22\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-21\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-20\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-19\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-18\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-17\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-16\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-15\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-14\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-13\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-12\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-11\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-10\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-9\)]\)[t] - 
            0.08269933431326881`\ \(c[\(-8\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-7\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-6\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-5\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-4\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-3\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-2\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-1\)]\)[t] + 
            0.06682066312775997`\ \(c[0]\)[t] + 
            0.08654280907894475`\ \(c[1]\)[t] + 
            0.10337416789158609`\ \(c[2]\)[t] + 
            0.11643488132933186`\ \(c[3]\)[t] + 
            0.12496032289024853`\ \(c[4]\)[t] + 
            0.12833762891430925`\ \(c[5]\)[t] + 
            0.12613778810677614`\ \(c[6]\)[t] + 
            0.1181419061618126`\ \(c[7]\)[t] + 
            0.10436044624225692`\ \(c[8]\)[t] + 
            0.0850444803444217`\ \(c[9]\)[t] + 
            0.06068826307698522`\ \(c[10]\)[t] + 
            0.03202274837442603`\ \(c[11]\)[t] - 
            3.898171832519376`*^-17\ \(c[12]\)[t] - 
            0.034231213779558796`\ \(c[13]\)[t] - 
            0.06935801494512592`\ \(c[14]\)[t] - 
            0.10394325375429328`\ \(c[15]\)[t] - 
            0.1364713527783359`\ \(c[16]\)[t] - 
            0.1653986686265376`\ \(c[17]\)[t] - 
            0.18920668216016426`\ \(c[18]\)[t] - 
            0.20645618564475834`\ \(c[19]\)[t] - 
            0.21584055771952013`\ \(c[20]\)[t] - 
            0.21623620818304484`\ \(c[21]\)[t] - 
            0.20674833578317206`\ \(c[22]\)[t] - 
            0.18675027222298607`\ \(c[23]\)[t] - 
            0.15591488063143982`\ \(c[24]\)[t] - 
            0.11423673049785459`\ \(c[25]\)[t] - 
            0.062044074975450475`\ \(c[26]\)[t] + 
            3.898171832519376`*^-17\ \(c[27]\)[t] + 
            0.07090751425765746`\ \(c[28]\)[t] + 
            0.14938649372796345`\ \(c[29]\)[t] + 
            0.23387232094715985`\ \(c[30]\)[t] + 
            0.32256865202152113`\ \(c[31]\)[t] + 
            0.41349667156634395`\ \(c[32]\)[t] + 
            0.5045511524271047`\ \(c[33]\)[t] + 
            0.5935615337286801`\ \(c[34]\)[t] + 
            0.6783560385470632`\ \(c[35]\)[t] + 
            0.7568267286406569`\ \(c[36]\)[t] + 
            0.826993343132688`\ \(c[37]\)[t] + 
            0.8870637930591838`\ \(c[38]\)[t] + 
            0.9354892837886392`\ \(c[39]\)[t] + 
            0.9710122092317629`\ \(c[40]\)[t] + 
            0.9927051996072067`\ \(c[41]\)[t] + 
            39.68884925227028`\ \(c[42]\)[t] + 
            0.9927051996072069`\ \(c[43]\)[t] + 
            0.9710122092317629`\ \(c[44]\)[t] + 
            0.9354892837886392`\ \(c[45]\)[t] + 
            0.8870637930591839`\ \(c[46]\)[t] + 
            0.8269933431326885`\ \(c[47]\)[t] + 
            0.7568267286406569`\ \(c[48]\)[t] + 
            0.6783560385470636`\ \(c[49]\)[t] + 
            0.5935615337286809`\ \(c[50]\)[t] + 
            0.5045511524271047`\ \(c[51]\)[t] + 
            0.4134966715663443`\ \(c[52]\)[t] + 
            0.3225686520215219`\ \(c[53]\)[t] + 
            0.23387232094715985`\ \(c[54]\)[t] + 
            0.14938649372796384`\ \(c[55]\)[t] + 
            0.0709075142576581`\ \(c[56]\)[t] + 
            3.898171832519376`*^-17\ \(c[57]\)[t] - 
            0.06204407497545024`\ \(c[58]\)[t] - 
            0.11423673049785416`\ \(c[59]\)[t] - 
            0.15591488063143982`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 42, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 42]][ t]], 
          Plus[ 
            Times[ 0.027514390699665887, 
              c[ -60][ t]], 
            Times[ 0.035131239329076656, 
              c[ -59][ t]], 
            Times[ 0.041349667156634483, 
              c[ -58][ t]], 
            Times[ 0.045868286584282256, 
              c[ -57][ t]], 
            Times[ 0.048454002753361682, 
              c[ -56][ t]], 
            Times[ 0.04895352855494272, 
              c[ -55][ t]], 
            Times[ 0.047301670540041058, 
              c[ -54][ t]], 
            Times[ 0.043525965428036162, 
              c[ -53][ t]], 
            Times[ 0.03774739544932687, 
              c[ -52][ t]], 
            Times[ 0.030177073670601236, 
              c[ -51][ t]], 
            Times[ 0.021108961070255627, 
              c[ -50][ t]], 
            Times[ 0.010908848347331966, 
              c[ -49][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -48][ t]], 
            Times[ -0.011153991006822649, 
              c[ -47][ t]], 
            Times[ -0.022068459300722043, 
              c[ -46][ t]], 
            Times[ -0.032258251165125519, 
              c[ -45][ t]], 
            Times[ -0.041258781072520248, 
              c[ -44][ t]], 
            Times[ -0.048646667243099281, 
              c[ -43][ t]], 
            Times[ -0.054059052045761224, 
              c[ -42][ t]], 
            Times[ -0.057210750238908967, 
              c[ -41][ t]], 
            Times[ -0.057908442314993203, 
              c[ -40][ t]], 
            Times[ -0.056061239158567186, 
              c[ -39][ t]], 
            Times[ -0.05168708394579296, 
              c[ -38][ t]], 
            Times[ -0.044914622433376419, 
              c[ -37][ t]], 
            Times[ -0.035980357068793781, 
              c[ -36][ t]], 
            Times[ -0.025221096343682053, 
              c[ -35][ t]], 
            Times[ -0.013061910521147383, 
              c[ -34][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -33][ t]], 
            Times[ 0.013414935129827233, 
              c[ -32][ t]], 
            Times[ 0.026603074225527826, 
              c[ -31][ t]], 
            Times[ 0.03897872015785999, 
              c[ -30][ t]], 
            Times[ 0.049975424961080865, 
              c[ -29][ t]], 
            Times[ 0.059070953080906326, 
              c[ -28][ t]], 
            Times[ 0.065811019881796273, 
              c[ -27][ t]], 
            Times[ 0.069830768673962415, 
              c[ -26][ t]], 
            Times[ 0.070873018952678238, 
              c[ -25][ t]], 
            Times[ 0.068802429876423349, 
              c[ -24][ t]], 
            Times[ 0.063614872548668253, 
              c[ -23][ t]], 
            Times[ 0.055441487066198933, 
              c[ -22][ t]], 
            Times[ 0.044547108751839919, 
              c[ -21][ t]], 
            Times[ 0.031322974491347078, 
              c[ -20][ t]], 
            Times[ 0.016273855731265604, 
              c[ -19][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -18][ t]], 
            Times[ -0.016825511857749401, 
              c[ -17][ t]], 
            Times[ -0.033483179628681567, 
              c[ -16][ t]], 
            Times[ -0.049236278094138941, 
              c[ -15][ t]], 
            Times[ -0.063361699504227528, 
              c[ -14][ t]], 
            Times[ -0.075181213012062598, 
              c[ -13][ t]], 
            Times[ -0.084091858737850814, 
              c[ -12][ t]], 
            Times[ -0.089594193770366884, 
              c[ -11][ t]], 
            Times[ -0.091317159035181589, 
              c[ -10][ t]], 
            Times[ -0.089038438663606695, 
              c[ -9][ t]], 
            Times[ -0.082699334313268813, 
              c[ -8][ t]], 
            Times[ -0.072413370861974122, 
              c[ -7][ t]], 
            Times[ -0.058468080236789913, 
              c[ -6][ t]], 
            Times[ -0.041319668477947373, 
              c[ -5][ t]], 
            Times[ -0.021580547817547879, 
              c[ -4][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -3][ t]], 
            Times[ 0.022561481809254675, 
              c[ -2][ t]], 
            Times[ 0.045163358568919301, 
              c[ -1][ t]], 
            Times[ 0.066820663127759972, 
              c[ 0][ t]], 
            Times[ 0.086542809078944752, 
              c[ 1][ t]], 
            Times[ 0.10337416789158609, 
              c[ 2][ t]], 
            Times[ 0.11643488132933186, 
              c[ 3][ t]], 
            Times[ 0.12496032289024853, 
              c[ 4][ t]], 
            Times[ 0.12833762891430925, 
              c[ 5][ t]], 
            Times[ 0.12613778810677614, 
              c[ 6][ t]], 
            Times[ 0.1181419061618126, 
              c[ 7][ t]], 
            Times[ 0.10436044624225692, 
              c[ 8][ t]], 
            Times[ 0.085044480344421705, 
              c[ 9][ t]], 
            Times[ 0.060688263076985223, 
              c[ 10][ t]], 
            Times[ 0.032022748374426029, 
              c[ 11][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 12][ t]], 
            Times[ -0.034231213779558796, 
              c[ 13][ t]], 
            Times[ -0.069358014945125918, 
              c[ 14][ t]], 
            Times[ -0.10394325375429328, 
              c[ 15][ t]], 
            Times[ -0.13647135277833591, 
              c[ 16][ t]], 
            Times[ -0.1653986686265376, 
              c[ 17][ t]], 
            Times[ -0.18920668216016426, 
              c[ 18][ t]], 
            Times[ -0.20645618564475834, 
              c[ 19][ t]], 
            Times[ -0.21584055771952013, 
              c[ 20][ t]], 
            Times[ -0.21623620818304484, 
              c[ 21][ t]], 
            Times[ -0.20674833578317206, 
              c[ 22][ t]], 
            Times[ -0.18675027222298607, 
              c[ 23][ t]], 
            Times[ -0.15591488063143982, 
              c[ 24][ t]], 
            Times[ -0.11423673049785459, 
              c[ 25][ t]], 
            Times[ -0.062044074975450475, 
              c[ 26][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 27][ t]], 
            Times[ 0.070907514257657456, 
              c[ 28][ t]], 
            Times[ 0.14938649372796345, 
              c[ 29][ t]], 
            Times[ 0.23387232094715985, 
              c[ 30][ t]], 
            Times[ 0.32256865202152113, 
              c[ 31][ t]], 
            Times[ 0.41349667156634395, 
              c[ 32][ t]], 
            Times[ 0.50455115242710469, 
              c[ 33][ t]], 
            Times[ 0.59356153372868015, 
              c[ 34][ t]], 
            Times[ 0.67835603854706317, 
              c[ 35][ t]], 
            Times[ 0.75682672864065692, 
              c[ 36][ t]], 
            Times[ 0.82699334313268802, 
              c[ 37][ t]], 
            Times[ 0.88706379305918381, 
              c[ 38][ t]], 
            Times[ 0.93548928378863916, 
              c[ 39][ t]], 
            Times[ 0.9710122092317629, 
              c[ 40][ t]], 
            Times[ 0.99270519960720671, 
              c[ 41][ t]], 
            Times[ 39.68884925227028, 
              c[ 42][ t]], 
            Times[ 0.99270519960720693, 
              c[ 43][ t]], 
            Times[ 0.9710122092317629, 
              c[ 44][ t]], 
            Times[ 0.93548928378863916, 
              c[ 45][ t]], 
            Times[ 0.88706379305918392, 
              c[ 46][ t]], 
            Times[ 0.82699334313268846, 
              c[ 47][ t]], 
            Times[ 0.75682672864065692, 
              c[ 48][ t]], 
            Times[ 0.67835603854706361, 
              c[ 49][ t]], 
            Times[ 0.59356153372868092, 
              c[ 50][ t]], 
            Times[ 0.50455115242710469, 
              c[ 51][ t]], 
            Times[ 0.41349667156634429, 
              c[ 52][ t]], 
            Times[ 0.32256865202152191, 
              c[ 53][ t]], 
            Times[ 0.23387232094715985, 
              c[ 54][ t]], 
            Times[ 0.14938649372796384, 
              c[ 55][ t]], 
            Times[ 0.070907514257658094, 
              c[ 56][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 57][ t]], 
            Times[ -0.062044074975450239, 
              c[ 58][ t]], 
            Times[ -0.11423673049785416, 
              c[ 59][ t]], 
            Times[ -0.15591488063143982, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "43", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[43]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.018854606004500233`\ \(c[\(-60\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-59\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-58\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-57\)]\)[t] + 
            0.04586828658428231`\ \(c[\(-56\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-55\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-54\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-53\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-52\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-51\)]\)[t] + 
            0.030177073670601094`\ \(c[\(-50\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-49\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-48\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-47\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-46\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-45\)]\)[t] - 
            0.03225825116512568`\ \(c[\(-44\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-43\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-42\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-41\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-40\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-39\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-38\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-37\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-36\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-35\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-34\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-33\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-32\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-31\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-30\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-29\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-28\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-27\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-26\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-25\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-24\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-23\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-22\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-21\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-20\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-19\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-18\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-17\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-16\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-15\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-14\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-13\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-12\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-11\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-10\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-9\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-8\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-7\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-6\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-5\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-4\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-3\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-2\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-1\)]\)[t] + 
            0.0451633585689193`\ \(c[0]\)[t] + 
            0.06682066312775997`\ \(c[1]\)[t] + 
            0.08654280907894489`\ \(c[2]\)[t] + 
            0.10337416789158609`\ \(c[3]\)[t] + 
            0.11643488132933186`\ \(c[4]\)[t] + 
            0.12496032289024853`\ \(c[5]\)[t] + 
            0.12833762891430928`\ \(c[6]\)[t] + 
            0.12613778810677614`\ \(c[7]\)[t] + 
            0.11814190616181255`\ \(c[8]\)[t] + 
            0.10436044624225685`\ \(c[9]\)[t] + 
            0.0850444803444217`\ \(c[10]\)[t] + 
            0.060688263076985105`\ \(c[11]\)[t] + 
            0.032022748374425904`\ \(c[12]\)[t] - 
            3.898171832519376`*^-17\ \(c[13]\)[t] - 
            0.03423121377955895`\ \(c[14]\)[t] - 
            0.06935801494512607`\ \(c[15]\)[t] - 
            0.10394325375429328`\ \(c[16]\)[t] - 
            0.13647135277833605`\ \(c[17]\)[t] - 
            0.1653986686265377`\ \(c[18]\)[t] - 
            0.18920668216016426`\ \(c[19]\)[t] - 
            0.20645618564475843`\ \(c[20]\)[t] - 
            0.21584055771952015`\ \(c[21]\)[t] - 
            0.21623620818304484`\ \(c[22]\)[t] - 
            0.206748335783172`\ \(c[23]\)[t] - 
            0.18675027222298593`\ \(c[24]\)[t] - 
            0.15591488063143982`\ \(c[25]\)[t] - 
            0.11423673049785436`\ \(c[26]\)[t] - 
            0.06204407497545024`\ \(c[27]\)[t] + 
            3.898171832519376`*^-17\ \(c[28]\)[t] + 
            0.07090751425765777`\ \(c[29]\)[t] + 
            0.14938649372796384`\ \(c[30]\)[t] + 
            0.23387232094715985`\ \(c[31]\)[t] + 
            0.3225686520215216`\ \(c[32]\)[t] + 
            0.4134966715663443`\ \(c[33]\)[t] + 
            0.5045511524271047`\ \(c[34]\)[t] + 
            0.5935615337286806`\ \(c[35]\)[t] + 
            0.6783560385470636`\ \(c[36]\)[t] + 
            0.7568267286406569`\ \(c[37]\)[t] + 
            0.8269933431326881`\ \(c[38]\)[t] + 
            0.8870637930591839`\ \(c[39]\)[t] + 
            0.9354892837886392`\ \(c[40]\)[t] + 
            0.9710122092317629`\ \(c[41]\)[t] + 
            0.9927051996072069`\ \(c[42]\)[t] + 
            41.553107861364936`\ \(c[43]\)[t] + 
            0.9927051996072069`\ \(c[44]\)[t] + 
            0.9710122092317629`\ \(c[45]\)[t] + 
            0.9354892837886392`\ \(c[46]\)[t] + 
            0.8870637930591839`\ \(c[47]\)[t] + 
            0.826993343132688`\ \(c[48]\)[t] + 
            0.7568267286406569`\ \(c[49]\)[t] + 
            0.6783560385470636`\ \(c[50]\)[t] + 
            0.5935615337286801`\ \(c[51]\)[t] + 
            0.5045511524271047`\ \(c[52]\)[t] + 
            0.4134966715663443`\ \(c[53]\)[t] + 
            0.32256865202152113`\ \(c[54]\)[t] + 
            0.23387232094715985`\ \(c[55]\)[t] + 
            0.14938649372796384`\ \(c[56]\)[t] + 
            0.07090751425765746`\ \(c[57]\)[t] + 
            3.898171832519376`*^-17\ \(c[58]\)[t] - 
            0.06204407497545024`\ \(c[59]\)[t] - 
            0.11423673049785459`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 43, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 43]][ t]], 
          Plus[ 
            Times[ 0.018854606004500233, 
              c[ -60][ t]], 
            Times[ 0.027514390699665887, 
              c[ -59][ t]], 
            Times[ 0.035131239329076656, 
              c[ -58][ t]], 
            Times[ 0.041349667156634483, 
              c[ -57][ t]], 
            Times[ 0.045868286584282311, 
              c[ -56][ t]], 
            Times[ 0.048454002753361682, 
              c[ -55][ t]], 
            Times[ 0.04895352855494272, 
              c[ -54][ t]], 
            Times[ 0.047301670540041058, 
              c[ -53][ t]], 
            Times[ 0.043525965428036162, 
              c[ -52][ t]], 
            Times[ 0.03774739544932687, 
              c[ -51][ t]], 
            Times[ 0.030177073670601094, 
              c[ -50][ t]], 
            Times[ 0.021108961070255627, 
              c[ -49][ t]], 
            Times[ 0.010908848347331966, 
              c[ -48][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -47][ t]], 
            Times[ -0.011153991006822649, 
              c[ -46][ t]], 
            Times[ -0.022068459300722043, 
              c[ -45][ t]], 
            Times[ -0.032258251165125679, 
              c[ -44][ t]], 
            Times[ -0.041258781072520248, 
              c[ -43][ t]], 
            Times[ -0.048646667243099281, 
              c[ -42][ t]], 
            Times[ -0.054059052045761224, 
              c[ -41][ t]], 
            Times[ -0.057210750238908967, 
              c[ -40][ t]], 
            Times[ -0.057908442314993203, 
              c[ -39][ t]], 
            Times[ -0.056061239158567186, 
              c[ -38][ t]], 
            Times[ -0.05168708394579296, 
              c[ -37][ t]], 
            Times[ -0.044914622433376419, 
              c[ -36][ t]], 
            Times[ -0.035980357068793781, 
              c[ -35][ t]], 
            Times[ -0.025221096343682053, 
              c[ -34][ t]], 
            Times[ -0.013061910521147383, 
              c[ -33][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -32][ t]], 
            Times[ 0.013414935129827233, 
              c[ -31][ t]], 
            Times[ 0.026603074225527826, 
              c[ -30][ t]], 
            Times[ 0.03897872015785999, 
              c[ -29][ t]], 
            Times[ 0.049975424961080865, 
              c[ -28][ t]], 
            Times[ 0.059070953080906326, 
              c[ -27][ t]], 
            Times[ 0.065811019881796273, 
              c[ -26][ t]], 
            Times[ 0.069830768673962415, 
              c[ -25][ t]], 
            Times[ 0.070873018952678238, 
              c[ -24][ t]], 
            Times[ 0.068802429876423349, 
              c[ -23][ t]], 
            Times[ 0.063614872548668253, 
              c[ -22][ t]], 
            Times[ 0.055441487066198933, 
              c[ -21][ t]], 
            Times[ 0.044547108751839919, 
              c[ -20][ t]], 
            Times[ 0.031322974491347078, 
              c[ -19][ t]], 
            Times[ 0.016273855731265604, 
              c[ -18][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -17][ t]], 
            Times[ -0.016825511857749401, 
              c[ -16][ t]], 
            Times[ -0.033483179628681567, 
              c[ -15][ t]], 
            Times[ -0.049236278094138941, 
              c[ -14][ t]], 
            Times[ -0.063361699504227528, 
              c[ -13][ t]], 
            Times[ -0.075181213012062598, 
              c[ -12][ t]], 
            Times[ -0.084091858737850814, 
              c[ -11][ t]], 
            Times[ -0.089594193770366884, 
              c[ -10][ t]], 
            Times[ -0.091317159035181589, 
              c[ -9][ t]], 
            Times[ -0.089038438663606695, 
              c[ -8][ t]], 
            Times[ -0.082699334313268744, 
              c[ -7][ t]], 
            Times[ -0.072413370861974122, 
              c[ -6][ t]], 
            Times[ -0.058468080236789913, 
              c[ -5][ t]], 
            Times[ -0.04131966847794722, 
              c[ -4][ t]], 
            Times[ -0.021580547817547879, 
              c[ -3][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -2][ t]], 
            Times[ 0.022561481809254869, 
              c[ -1][ t]], 
            Times[ 0.045163358568919301, 
              c[ 0][ t]], 
            Times[ 0.066820663127759972, 
              c[ 1][ t]], 
            Times[ 0.086542809078944891, 
              c[ 2][ t]], 
            Times[ 0.10337416789158609, 
              c[ 3][ t]], 
            Times[ 0.11643488132933186, 
              c[ 4][ t]], 
            Times[ 0.12496032289024853, 
              c[ 5][ t]], 
            Times[ 0.12833762891430928, 
              c[ 6][ t]], 
            Times[ 0.12613778810677614, 
              c[ 7][ t]], 
            Times[ 0.11814190616181255, 
              c[ 8][ t]], 
            Times[ 0.10436044624225685, 
              c[ 9][ t]], 
            Times[ 0.085044480344421705, 
              c[ 10][ t]], 
            Times[ 0.060688263076985105, 
              c[ 11][ t]], 
            Times[ 0.032022748374425904, 
              c[ 12][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 13][ t]], 
            Times[ -0.034231213779558949, 
              c[ 14][ t]], 
            Times[ -0.06935801494512607, 
              c[ 15][ t]], 
            Times[ -0.10394325375429328, 
              c[ 16][ t]], 
            Times[ -0.13647135277833605, 
              c[ 17][ t]], 
            Times[ -0.16539866862653771, 
              c[ 18][ t]], 
            Times[ -0.18920668216016426, 
              c[ 19][ t]], 
            Times[ -0.20645618564475843, 
              c[ 20][ t]], 
            Times[ -0.21584055771952015, 
              c[ 21][ t]], 
            Times[ -0.21623620818304484, 
              c[ 22][ t]], 
            Times[ -0.206748335783172, 
              c[ 23][ t]], 
            Times[ -0.18675027222298593, 
              c[ 24][ t]], 
            Times[ -0.15591488063143982, 
              c[ 25][ t]], 
            Times[ -0.11423673049785436, 
              c[ 26][ t]], 
            Times[ -0.062044074975450239, 
              c[ 27][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 28][ t]], 
            Times[ 0.070907514257657775, 
              c[ 29][ t]], 
            Times[ 0.14938649372796384, 
              c[ 30][ t]], 
            Times[ 0.23387232094715985, 
              c[ 31][ t]], 
            Times[ 0.32256865202152157, 
              c[ 32][ t]], 
            Times[ 0.41349667156634429, 
              c[ 33][ t]], 
            Times[ 0.50455115242710469, 
              c[ 34][ t]], 
            Times[ 0.59356153372868059, 
              c[ 35][ t]], 
            Times[ 0.67835603854706361, 
              c[ 36][ t]], 
            Times[ 0.75682672864065692, 
              c[ 37][ t]], 
            Times[ 0.82699334313268813, 
              c[ 38][ t]], 
            Times[ 0.88706379305918392, 
              c[ 39][ t]], 
            Times[ 0.93548928378863916, 
              c[ 40][ t]], 
            Times[ 0.9710122092317629, 
              c[ 41][ t]], 
            Times[ 0.99270519960720693, 
              c[ 42][ t]], 
            Times[ 41.553107861364936, 
              c[ 43][ t]], 
            Times[ 0.99270519960720693, 
              c[ 44][ t]], 
            Times[ 0.9710122092317629, 
              c[ 45][ t]], 
            Times[ 0.93548928378863916, 
              c[ 46][ t]], 
            Times[ 0.88706379305918392, 
              c[ 47][ t]], 
            Times[ 0.82699334313268802, 
              c[ 48][ t]], 
            Times[ 0.75682672864065692, 
              c[ 49][ t]], 
            Times[ 0.67835603854706361, 
              c[ 50][ t]], 
            Times[ 0.59356153372868015, 
              c[ 51][ t]], 
            Times[ 0.50455115242710469, 
              c[ 52][ t]], 
            Times[ 0.41349667156634429, 
              c[ 53][ t]], 
            Times[ 0.32256865202152113, 
              c[ 54][ t]], 
            Times[ 0.23387232094715985, 
              c[ 55][ t]], 
            Times[ 0.14938649372796384, 
              c[ 56][ t]], 
            Times[ 0.070907514257657456, 
              c[ 57][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 58][ t]], 
            Times[ -0.062044074975450239, 
              c[ 59][ t]], 
            Times[ -0.11423673049785459, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "44", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[44]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.009545242303915543`\ \(c[\(-60\)]\)[t] + 
            0.01885460600450039`\ \(c[\(-59\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-58\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-57\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-56\)]\)[t] + 
            0.04586828658428231`\ \(c[\(-55\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-54\)]\)[t] + 
            0.0489535285549427`\ \(c[\(-53\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-52\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-51\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-50\)]\)[t] + 
            0.030177073670601094`\ \(c[\(-49\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-48\)]\)[t] + 
            0.010908848347331785`\ \(c[\(-47\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-46\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-45\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-44\)]\)[t] - 
            0.03225825116512568`\ \(c[\(-43\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-42\)]\)[t] - 
            0.0486466672430994`\ \(c[\(-41\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-40\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-39\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-38\)]\)[t] - 
            0.05606123915856713`\ \(c[\(-37\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-36\)]\)[t] - 
            0.04491462243337629`\ \(c[\(-35\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-34\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-33\)]\)[t] - 
            0.013061910521147276`\ \(c[\(-32\)]\)[t] + 
            1.5206810699945212`*^-16\ \(c[\(-31\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-30\)]\)[t] + 
            0.026603074225527937`\ \(c[\(-29\)]\)[t] + 
            0.03897872015786009`\ \(c[\(-28\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-27\)]\)[t] + 
            0.0590709530809064`\ \(c[\(-26\)]\)[t] + 
            0.06581101988179631`\ \(c[\(-25\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-24\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-23\)]\)[t] + 
            0.06880242987642332`\ \(c[\(-22\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-21\)]\)[t] + 
            0.055441487066198857`\ \(c[\(-20\)]\)[t] + 
            0.044547108751839815`\ \(c[\(-19\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-18\)]\)[t] + 
            0.01627385573126547`\ \(c[\(-17\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-16\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-15\)]\)[t] - 
            0.033483179628681706`\ \(c[\(-14\)]\)[t] - 
            0.049236278094139066`\ \(c[\(-13\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-12\)]\)[t] - 
            0.0751812130120627`\ \(c[\(-11\)]\)[t] - 
            0.08409185873785086`\ \(c[\(-10\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-9\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-8\)]\)[t] - 
            0.08903843866360665`\ \(c[\(-7\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-6\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-5\)]\)[t] - 
            0.058468080236789774`\ \(c[\(-4\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-3\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-2\)]\)[t] + 
            2.274590327822911`*^-16\ \(c[\(-1\)]\)[t] + 
            0.02256148180925487`\ \(c[0]\)[t] + 
            0.0451633585689193`\ \(c[1]\)[t] + 
            0.06682066312776015`\ \(c[2]\)[t] + 
            0.08654280907894489`\ \(c[3]\)[t] + 
            0.10337416789158609`\ \(c[4]\)[t] + 
            0.11643488132933195`\ \(c[5]\)[t] + 
            0.12496032289024853`\ \(c[6]\)[t] + 
            0.12833762891430928`\ \(c[7]\)[t] + 
            0.12613778810677612`\ \(c[8]\)[t] + 
            0.11814190616181253`\ \(c[9]\)[t] + 
            0.10436044624225685`\ \(c[10]\)[t] + 
            0.08504448034442161`\ \(c[11]\)[t] + 
            0.060688263076985`\ \(c[12]\)[t] + 
            0.032022748374425904`\ \(c[13]\)[t] - 
            1.8033970416801674`*^-16\ \(c[14]\)[t] - 
            0.034231213779559094`\ \(c[15]\)[t] - 
            0.06935801494512607`\ \(c[16]\)[t] - 
            0.1039432537542934`\ \(c[17]\)[t] - 
            0.13647135277833616`\ \(c[18]\)[t] - 
            0.1653986686265377`\ \(c[19]\)[t] - 
            0.18920668216016434`\ \(c[20]\)[t] - 
            0.20645618564475848`\ \(c[21]\)[t] - 
            0.21584055771952015`\ \(c[22]\)[t] - 
            0.21623620818304481`\ \(c[23]\)[t] - 
            0.2067483357831719`\ \(c[24]\)[t] - 
            0.18675027222298593`\ \(c[25]\)[t] - 
            0.15591488063143966`\ \(c[26]\)[t] - 
            0.11423673049785416`\ \(c[27]\)[t] - 
            0.06204407497545024`\ \(c[28]\)[t] + 
            3.216976900108398`*^-16\ \(c[29]\)[t] + 
            0.0709075142576581`\ \(c[30]\)[t] + 
            0.14938649372796384`\ \(c[31]\)[t] + 
            0.23387232094716018`\ \(c[32]\)[t] + 
            0.3225686520215219`\ \(c[33]\)[t] + 
            0.4134966715663443`\ \(c[34]\)[t] + 
            0.504551152427105`\ \(c[35]\)[t] + 
            0.5935615337286809`\ \(c[36]\)[t] + 
            0.6783560385470636`\ \(c[37]\)[t] + 
            0.7568267286406574`\ \(c[38]\)[t] + 
            0.8269933431326885`\ \(c[39]\)[t] + 
            0.8870637930591839`\ \(c[40]\)[t] + 
            0.9354892837886392`\ \(c[41]\)[t] + 
            0.9710122092317629`\ \(c[42]\)[t] + 
            0.9927051996072069`\ \(c[43]\)[t] + 
            43.46123137890887`\ \(c[44]\)[t] + 
            0.9927051996072067`\ \(c[45]\)[t] + 
            0.9710122092317629`\ \(c[46]\)[t] + 
            0.9354892837886392`\ \(c[47]\)[t] + 
            0.8870637930591835`\ \(c[48]\)[t] + 
            0.826993343132688`\ \(c[49]\)[t] + 
            0.7568267286406569`\ \(c[50]\)[t] + 
            0.6783560385470627`\ \(c[51]\)[t] + 
            0.5935615337286801`\ \(c[52]\)[t] + 
            0.5045511524271047`\ \(c[53]\)[t] + 
            0.4134966715663436`\ \(c[54]\)[t] + 
            0.32256865202152113`\ \(c[55]\)[t] + 
            0.23387232094715985`\ \(c[56]\)[t] + 
            0.14938649372796314`\ \(c[57]\)[t] + 
            0.07090751425765746`\ \(c[58]\)[t] + 
            3.898171832519376`*^-17\ \(c[59]\)[t] - 
            0.06204407497545072`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 44, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 44]][ t]], 
          Plus[ 
            Times[ 0.0095452423039155427, 
              c[ -60][ t]], 
            Times[ 0.018854606004500389, 
              c[ -59][ t]], 
            Times[ 0.027514390699665887, 
              c[ -58][ t]], 
            Times[ 0.035131239329076656, 
              c[ -57][ t]], 
            Times[ 0.041349667156634483, 
              c[ -56][ t]], 
            Times[ 0.045868286584282311, 
              c[ -55][ t]], 
            Times[ 0.048454002753361682, 
              c[ -54][ t]], 
            Times[ 0.048953528554942699, 
              c[ -53][ t]], 
            Times[ 0.047301670540041058, 
              c[ -52][ t]], 
            Times[ 0.043525965428036162, 
              c[ -51][ t]], 
            Times[ 0.03774739544932687, 
              c[ -50][ t]], 
            Times[ 0.030177073670601094, 
              c[ -49][ t]], 
            Times[ 0.021108961070255627, 
              c[ -48][ t]], 
            Times[ 0.010908848347331785, 
              c[ -47][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -46][ t]], 
            Times[ -0.011153991006822649, 
              c[ -45][ t]], 
            Times[ -0.022068459300722043, 
              c[ -44][ t]], 
            Times[ -0.032258251165125679, 
              c[ -43][ t]], 
            Times[ -0.041258781072520248, 
              c[ -42][ t]], 
            Times[ -0.048646667243099399, 
              c[ -41][ t]], 
            Times[ -0.054059052045761224, 
              c[ -40][ t]], 
            Times[ -0.057210750238908967, 
              c[ -39][ t]], 
            Times[ -0.057908442314993203, 
              c[ -38][ t]], 
            Times[ -0.05606123915856713, 
              c[ -37][ t]], 
            Times[ -0.05168708394579296, 
              c[ -36][ t]], 
            Times[ -0.044914622433376288, 
              c[ -35][ t]], 
            Times[ -0.035980357068793781, 
              c[ -34][ t]], 
            Times[ -0.025221096343682053, 
              c[ -33][ t]], 
            Times[ -0.013061910521147276, 
              c[ -32][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ -31][ t]], 
            Times[ 0.013414935129827233, 
              c[ -30][ t]], 
            Times[ 0.026603074225527937, 
              c[ -29][ t]], 
            Times[ 0.038978720157860088, 
              c[ -28][ t]], 
            Times[ 0.049975424961080865, 
              c[ -27][ t]], 
            Times[ 0.059070953080906402, 
              c[ -26][ t]], 
            Times[ 0.065811019881796315, 
              c[ -25][ t]], 
            Times[ 0.069830768673962415, 
              c[ -24][ t]], 
            Times[ 0.070873018952678238, 
              c[ -23][ t]], 
            Times[ 0.068802429876423321, 
              c[ -22][ t]], 
            Times[ 0.063614872548668253, 
              c[ -21][ t]], 
            Times[ 0.055441487066198857, 
              c[ -20][ t]], 
            Times[ 0.044547108751839815, 
              c[ -19][ t]], 
            Times[ 0.031322974491347078, 
              c[ -18][ t]], 
            Times[ 0.016273855731265469, 
              c[ -17][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -16][ t]], 
            Times[ -0.016825511857749401, 
              c[ -15][ t]], 
            Times[ -0.033483179628681706, 
              c[ -14][ t]], 
            Times[ -0.049236278094139066, 
              c[ -13][ t]], 
            Times[ -0.063361699504227528, 
              c[ -12][ t]], 
            Times[ -0.075181213012062695, 
              c[ -11][ t]], 
            Times[ -0.084091858737850855, 
              c[ -10][ t]], 
            Times[ -0.089594193770366884, 
              c[ -9][ t]], 
            Times[ -0.091317159035181589, 
              c[ -8][ t]], 
            Times[ -0.089038438663606653, 
              c[ -7][ t]], 
            Times[ -0.082699334313268744, 
              c[ -6][ t]], 
            Times[ -0.072413370861974122, 
              c[ -5][ t]], 
            Times[ -0.058468080236789774, 
              c[ -4][ t]], 
            Times[ -0.04131966847794722, 
              c[ -3][ t]], 
            Times[ -0.021580547817547879, 
              c[ -2][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ -1][ t]], 
            Times[ 0.022561481809254869, 
              c[ 0][ t]], 
            Times[ 0.045163358568919301, 
              c[ 1][ t]], 
            Times[ 0.066820663127760152, 
              c[ 2][ t]], 
            Times[ 0.086542809078944891, 
              c[ 3][ t]], 
            Times[ 0.10337416789158609, 
              c[ 4][ t]], 
            Times[ 0.11643488132933195, 
              c[ 5][ t]], 
            Times[ 0.12496032289024853, 
              c[ 6][ t]], 
            Times[ 0.12833762891430928, 
              c[ 7][ t]], 
            Times[ 0.12613778810677612, 
              c[ 8][ t]], 
            Times[ 0.11814190616181253, 
              c[ 9][ t]], 
            Times[ 0.10436044624225685, 
              c[ 10][ t]], 
            Times[ 0.085044480344421608, 
              c[ 11][ t]], 
            Times[ 0.060688263076985001, 
              c[ 12][ t]], 
            Times[ 0.032022748374425904, 
              c[ 13][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 14][ t]], 
            Times[ -0.034231213779559094, 
              c[ 15][ t]], 
            Times[ -0.06935801494512607, 
              c[ 16][ t]], 
            Times[ -0.1039432537542934, 
              c[ 17][ t]], 
            Times[ -0.13647135277833616, 
              c[ 18][ t]], 
            Times[ -0.16539866862653771, 
              c[ 19][ t]], 
            Times[ -0.18920668216016434, 
              c[ 20][ t]], 
            Times[ -0.20645618564475848, 
              c[ 21][ t]], 
            Times[ -0.21584055771952015, 
              c[ 22][ t]], 
            Times[ -0.21623620818304481, 
              c[ 23][ t]], 
            Times[ -0.20674833578317189, 
              c[ 24][ t]], 
            Times[ -0.18675027222298593, 
              c[ 25][ t]], 
            Times[ -0.15591488063143966, 
              c[ 26][ t]], 
            Times[ -0.11423673049785416, 
              c[ 27][ t]], 
            Times[ -0.062044074975450239, 
              c[ 28][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ 29][ t]], 
            Times[ 0.070907514257658094, 
              c[ 30][ t]], 
            Times[ 0.14938649372796384, 
              c[ 31][ t]], 
            Times[ 0.23387232094716018, 
              c[ 32][ t]], 
            Times[ 0.32256865202152191, 
              c[ 33][ t]], 
            Times[ 0.41349667156634429, 
              c[ 34][ t]], 
            Times[ 0.50455115242710502, 
              c[ 35][ t]], 
            Times[ 0.59356153372868092, 
              c[ 36][ t]], 
            Times[ 0.67835603854706361, 
              c[ 37][ t]], 
            Times[ 0.75682672864065736, 
              c[ 38][ t]], 
            Times[ 0.82699334313268846, 
              c[ 39][ t]], 
            Times[ 0.88706379305918392, 
              c[ 40][ t]], 
            Times[ 0.93548928378863916, 
              c[ 41][ t]], 
            Times[ 0.9710122092317629, 
              c[ 42][ t]], 
            Times[ 0.99270519960720693, 
              c[ 43][ t]], 
            Times[ 43.46123137890887, 
              c[ 44][ t]], 
            Times[ 0.99270519960720671, 
              c[ 45][ t]], 
            Times[ 0.9710122092317629, 
              c[ 46][ t]], 
            Times[ 0.93548928378863916, 
              c[ 47][ t]], 
            Times[ 0.88706379305918348, 
              c[ 48][ t]], 
            Times[ 0.82699334313268802, 
              c[ 49][ t]], 
            Times[ 0.75682672864065692, 
              c[ 50][ t]], 
            Times[ 0.67835603854706272, 
              c[ 51][ t]], 
            Times[ 0.59356153372868015, 
              c[ 52][ t]], 
            Times[ 0.50455115242710469, 
              c[ 53][ t]], 
            Times[ 0.41349667156634362, 
              c[ 54][ t]], 
            Times[ 0.32256865202152113, 
              c[ 55][ t]], 
            Times[ 0.23387232094715985, 
              c[ 56][ t]], 
            Times[ 0.14938649372796314, 
              c[ 57][ t]], 
            Times[ 0.070907514257657456, 
              c[ 58][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 59][ t]], 
            Times[ -0.062044074975450718, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "45", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[45]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(3.8981718325193755`*^-17\ \(c[\(-60\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-59\)]\)[t] + 
            0.018854606004500233`\ \(c[\(-58\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-57\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-56\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-55\)]\)[t] + 
            0.045868286584282256`\ \(c[\(-54\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-53\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-52\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-51\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-50\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-49\)]\)[t] + 
            0.030177073670601236`\ \(c[\(-48\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-47\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-46\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-45\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-44\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-43\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-42\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-41\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-40\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-39\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-38\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-37\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-36\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-35\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-34\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-33\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-32\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-31\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-30\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-29\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-28\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-27\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-26\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-25\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-24\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-23\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-22\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-21\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-20\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-19\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-18\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-17\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-16\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-15\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-14\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-13\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-12\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-11\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-10\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-9\)]\)[t] - 
            0.08959419377036684`\ \(c[\(-8\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-7\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-6\)]\)[t] - 
            0.08269933431326881`\ \(c[\(-5\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-4\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-3\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-2\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-1\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[0]\)[t] + 
            0.022561481809254675`\ \(c[1]\)[t] + 
            0.0451633585689193`\ \(c[2]\)[t] + 
            0.06682066312775997`\ \(c[3]\)[t] + 
            0.08654280907894475`\ \(c[4]\)[t] + 
            0.10337416789158609`\ \(c[5]\)[t] + 
            0.11643488132933186`\ \(c[6]\)[t] + 
            0.12496032289024847`\ \(c[7]\)[t] + 
            0.12833762891430925`\ \(c[8]\)[t] + 
            0.12613778810677614`\ \(c[9]\)[t] + 
            0.1181419061618126`\ \(c[10]\)[t] + 
            0.10436044624225692`\ \(c[11]\)[t] + 
            0.0850444803444217`\ \(c[12]\)[t] + 
            0.06068826307698522`\ \(c[13]\)[t] + 
            0.03202274837442603`\ \(c[14]\)[t] - 
            3.898171832519376`*^-17\ \(c[15]\)[t] - 
            0.034231213779558796`\ \(c[16]\)[t] - 
            0.06935801494512592`\ \(c[17]\)[t] - 
            0.10394325375429328`\ \(c[18]\)[t] - 
            0.1364713527783359`\ \(c[19]\)[t] - 
            0.1653986686265376`\ \(c[20]\)[t] - 
            0.18920668216016426`\ \(c[21]\)[t] - 
            0.20645618564475834`\ \(c[22]\)[t] - 
            0.21584055771952013`\ \(c[23]\)[t] - 
            0.21623620818304484`\ \(c[24]\)[t] - 
            0.20674833578317206`\ \(c[25]\)[t] - 
            0.18675027222298607`\ \(c[26]\)[t] - 
            0.15591488063143982`\ \(c[27]\)[t] - 
            0.11423673049785459`\ \(c[28]\)[t] - 
            0.062044074975450475`\ \(c[29]\)[t] + 
            3.898171832519376`*^-17\ \(c[30]\)[t] + 
            0.07090751425765746`\ \(c[31]\)[t] + 
            0.14938649372796345`\ \(c[32]\)[t] + 
            0.23387232094715985`\ \(c[33]\)[t] + 
            0.32256865202152113`\ \(c[34]\)[t] + 
            0.41349667156634395`\ \(c[35]\)[t] + 
            0.5045511524271047`\ \(c[36]\)[t] + 
            0.5935615337286801`\ \(c[37]\)[t] + 
            0.6783560385470632`\ \(c[38]\)[t] + 
            0.7568267286406569`\ \(c[39]\)[t] + 
            0.826993343132688`\ \(c[40]\)[t] + 
            0.8870637930591835`\ \(c[41]\)[t] + 
            0.9354892837886392`\ \(c[42]\)[t] + 
            0.9710122092317629`\ \(c[43]\)[t] + 
            0.9927051996072067`\ \(c[44]\)[t] + 
            45.41321980490211`\ \(c[45]\)[t] + 
            0.9927051996072069`\ \(c[46]\)[t] + 
            0.9710122092317629`\ \(c[47]\)[t] + 
            0.9354892837886392`\ \(c[48]\)[t] + 
            0.8870637930591839`\ \(c[49]\)[t] + 
            0.8269933431326885`\ \(c[50]\)[t] + 
            0.7568267286406569`\ \(c[51]\)[t] + 
            0.6783560385470636`\ \(c[52]\)[t] + 
            0.5935615337286809`\ \(c[53]\)[t] + 
            0.5045511524271047`\ \(c[54]\)[t] + 
            0.4134966715663443`\ \(c[55]\)[t] + 
            0.3225686520215219`\ \(c[56]\)[t] + 
            0.23387232094715985`\ \(c[57]\)[t] + 
            0.14938649372796384`\ \(c[58]\)[t] + 
            0.0709075142576581`\ \(c[59]\)[t] + 
            3.898171832519376`*^-17\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 45, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 45]][ t]], 
          Plus[ 
            Times[ 3.8981718325193755*^-17, 
              c[ -60][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -59][ t]], 
            Times[ 0.018854606004500233, 
              c[ -58][ t]], 
            Times[ 0.027514390699665887, 
              c[ -57][ t]], 
            Times[ 0.035131239329076656, 
              c[ -56][ t]], 
            Times[ 0.041349667156634483, 
              c[ -55][ t]], 
            Times[ 0.045868286584282256, 
              c[ -54][ t]], 
            Times[ 0.048454002753361682, 
              c[ -53][ t]], 
            Times[ 0.04895352855494272, 
              c[ -52][ t]], 
            Times[ 0.047301670540041058, 
              c[ -51][ t]], 
            Times[ 0.043525965428036162, 
              c[ -50][ t]], 
            Times[ 0.03774739544932687, 
              c[ -49][ t]], 
            Times[ 0.030177073670601236, 
              c[ -48][ t]], 
            Times[ 0.021108961070255627, 
              c[ -47][ t]], 
            Times[ 0.010908848347331966, 
              c[ -46][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -45][ t]], 
            Times[ -0.011153991006822649, 
              c[ -44][ t]], 
            Times[ -0.022068459300722043, 
              c[ -43][ t]], 
            Times[ -0.032258251165125519, 
              c[ -42][ t]], 
            Times[ -0.041258781072520248, 
              c[ -41][ t]], 
            Times[ -0.048646667243099281, 
              c[ -40][ t]], 
            Times[ -0.054059052045761224, 
              c[ -39][ t]], 
            Times[ -0.057210750238908967, 
              c[ -38][ t]], 
            Times[ -0.057908442314993203, 
              c[ -37][ t]], 
            Times[ -0.056061239158567186, 
              c[ -36][ t]], 
            Times[ -0.05168708394579296, 
              c[ -35][ t]], 
            Times[ -0.044914622433376419, 
              c[ -34][ t]], 
            Times[ -0.035980357068793781, 
              c[ -33][ t]], 
            Times[ -0.025221096343682053, 
              c[ -32][ t]], 
            Times[ -0.013061910521147383, 
              c[ -31][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -30][ t]], 
            Times[ 0.013414935129827233, 
              c[ -29][ t]], 
            Times[ 0.026603074225527826, 
              c[ -28][ t]], 
            Times[ 0.03897872015785999, 
              c[ -27][ t]], 
            Times[ 0.049975424961080865, 
              c[ -26][ t]], 
            Times[ 0.059070953080906326, 
              c[ -25][ t]], 
            Times[ 0.065811019881796273, 
              c[ -24][ t]], 
            Times[ 0.069830768673962415, 
              c[ -23][ t]], 
            Times[ 0.070873018952678238, 
              c[ -22][ t]], 
            Times[ 0.068802429876423349, 
              c[ -21][ t]], 
            Times[ 0.063614872548668253, 
              c[ -20][ t]], 
            Times[ 0.055441487066198933, 
              c[ -19][ t]], 
            Times[ 0.044547108751839919, 
              c[ -18][ t]], 
            Times[ 0.031322974491347078, 
              c[ -17][ t]], 
            Times[ 0.016273855731265604, 
              c[ -16][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -15][ t]], 
            Times[ -0.016825511857749401, 
              c[ -14][ t]], 
            Times[ -0.033483179628681567, 
              c[ -13][ t]], 
            Times[ -0.049236278094138941, 
              c[ -12][ t]], 
            Times[ -0.063361699504227528, 
              c[ -11][ t]], 
            Times[ -0.075181213012062598, 
              c[ -10][ t]], 
            Times[ -0.084091858737850814, 
              c[ -9][ t]], 
            Times[ -0.089594193770366842, 
              c[ -8][ t]], 
            Times[ -0.091317159035181589, 
              c[ -7][ t]], 
            Times[ -0.089038438663606695, 
              c[ -6][ t]], 
            Times[ -0.082699334313268813, 
              c[ -5][ t]], 
            Times[ -0.072413370861974122, 
              c[ -4][ t]], 
            Times[ -0.058468080236789913, 
              c[ -3][ t]], 
            Times[ -0.041319668477947373, 
              c[ -2][ t]], 
            Times[ -0.021580547817547879, 
              c[ -1][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 0][ t]], 
            Times[ 0.022561481809254675, 
              c[ 1][ t]], 
            Times[ 0.045163358568919301, 
              c[ 2][ t]], 
            Times[ 0.066820663127759972, 
              c[ 3][ t]], 
            Times[ 0.086542809078944752, 
              c[ 4][ t]], 
            Times[ 0.10337416789158609, 
              c[ 5][ t]], 
            Times[ 0.11643488132933186, 
              c[ 6][ t]], 
            Times[ 0.12496032289024847, 
              c[ 7][ t]], 
            Times[ 0.12833762891430925, 
              c[ 8][ t]], 
            Times[ 0.12613778810677614, 
              c[ 9][ t]], 
            Times[ 0.1181419061618126, 
              c[ 10][ t]], 
            Times[ 0.10436044624225692, 
              c[ 11][ t]], 
            Times[ 0.085044480344421705, 
              c[ 12][ t]], 
            Times[ 0.060688263076985223, 
              c[ 13][ t]], 
            Times[ 0.032022748374426029, 
              c[ 14][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 15][ t]], 
            Times[ -0.034231213779558796, 
              c[ 16][ t]], 
            Times[ -0.069358014945125918, 
              c[ 17][ t]], 
            Times[ -0.10394325375429328, 
              c[ 18][ t]], 
            Times[ -0.13647135277833591, 
              c[ 19][ t]], 
            Times[ -0.1653986686265376, 
              c[ 20][ t]], 
            Times[ -0.18920668216016426, 
              c[ 21][ t]], 
            Times[ -0.20645618564475834, 
              c[ 22][ t]], 
            Times[ -0.21584055771952013, 
              c[ 23][ t]], 
            Times[ -0.21623620818304484, 
              c[ 24][ t]], 
            Times[ -0.20674833578317206, 
              c[ 25][ t]], 
            Times[ -0.18675027222298607, 
              c[ 26][ t]], 
            Times[ -0.15591488063143982, 
              c[ 27][ t]], 
            Times[ -0.11423673049785459, 
              c[ 28][ t]], 
            Times[ -0.062044074975450475, 
              c[ 29][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 30][ t]], 
            Times[ 0.070907514257657456, 
              c[ 31][ t]], 
            Times[ 0.14938649372796345, 
              c[ 32][ t]], 
            Times[ 0.23387232094715985, 
              c[ 33][ t]], 
            Times[ 0.32256865202152113, 
              c[ 34][ t]], 
            Times[ 0.41349667156634395, 
              c[ 35][ t]], 
            Times[ 0.50455115242710469, 
              c[ 36][ t]], 
            Times[ 0.59356153372868015, 
              c[ 37][ t]], 
            Times[ 0.67835603854706317, 
              c[ 38][ t]], 
            Times[ 0.75682672864065692, 
              c[ 39][ t]], 
            Times[ 0.82699334313268802, 
              c[ 40][ t]], 
            Times[ 0.88706379305918348, 
              c[ 41][ t]], 
            Times[ 0.93548928378863916, 
              c[ 42][ t]], 
            Times[ 0.9710122092317629, 
              c[ 43][ t]], 
            Times[ 0.99270519960720671, 
              c[ 44][ t]], 
            Times[ 45.413219804902113, 
              c[ 45][ t]], 
            Times[ 0.99270519960720693, 
              c[ 46][ t]], 
            Times[ 0.9710122092317629, 
              c[ 47][ t]], 
            Times[ 0.93548928378863916, 
              c[ 48][ t]], 
            Times[ 0.88706379305918392, 
              c[ 49][ t]], 
            Times[ 0.82699334313268846, 
              c[ 50][ t]], 
            Times[ 0.75682672864065692, 
              c[ 51][ t]], 
            Times[ 0.67835603854706361, 
              c[ 52][ t]], 
            Times[ 0.59356153372868092, 
              c[ 53][ t]], 
            Times[ 0.50455115242710469, 
              c[ 54][ t]], 
            Times[ 0.41349667156634429, 
              c[ 55][ t]], 
            Times[ 0.32256865202152191, 
              c[ 56][ t]], 
            Times[ 0.23387232094715985, 
              c[ 57][ t]], 
            Times[ 0.14938649372796384, 
              c[ 58][ t]], 
            Times[ 0.070907514257658094, 
              c[ 59][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "46", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[46]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.009365143392520679`\)\ \(c[\(-60\)]\)[t] + 
            2.0053370214556287`*^-16\ \(c[\(-59\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-58\)]\)[t] + 
            0.018854606004500233`\ \(c[\(-57\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-56\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-55\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-54\)]\)[t] + 
            0.04586828658428231`\ \(c[\(-53\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-52\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-51\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-50\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-49\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-48\)]\)[t] + 
            0.030177073670601094`\ \(c[\(-47\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-46\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-45\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-44\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-43\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-42\)]\)[t] - 
            0.03225825116512568`\ \(c[\(-41\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-40\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-39\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-38\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-37\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-36\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-35\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-34\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-33\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-32\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-31\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-30\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-29\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-28\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-27\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-26\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-25\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-24\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-23\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-22\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-21\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-20\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-19\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-18\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-17\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-16\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-15\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-14\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-13\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-12\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-11\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-10\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-9\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-8\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-7\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-6\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-5\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-4\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-3\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-2\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-1\)]\)[t] - 
            0.02158054781754788`\ \(c[0]\)[t] + 
            3.8981718325193755`*^-17\ \(c[1]\)[t] + 
            0.02256148180925487`\ \(c[2]\)[t] + 
            0.0451633585689193`\ \(c[3]\)[t] + 
            0.06682066312775997`\ \(c[4]\)[t] + 
            0.08654280907894489`\ \(c[5]\)[t] + 
            0.10337416789158609`\ \(c[6]\)[t] + 
            0.11643488132933186`\ \(c[7]\)[t] + 
            0.12496032289024853`\ \(c[8]\)[t] + 
            0.12833762891430928`\ \(c[9]\)[t] + 
            0.12613778810677614`\ \(c[10]\)[t] + 
            0.11814190616181255`\ \(c[11]\)[t] + 
            0.10436044624225685`\ \(c[12]\)[t] + 
            0.0850444803444217`\ \(c[13]\)[t] + 
            0.060688263076985105`\ \(c[14]\)[t] + 
            0.032022748374425904`\ \(c[15]\)[t] - 
            3.898171832519376`*^-17\ \(c[16]\)[t] - 
            0.03423121377955895`\ \(c[17]\)[t] - 
            0.06935801494512607`\ \(c[18]\)[t] - 
            0.10394325375429328`\ \(c[19]\)[t] - 
            0.13647135277833605`\ \(c[20]\)[t] - 
            0.1653986686265377`\ \(c[21]\)[t] - 
            0.18920668216016426`\ \(c[22]\)[t] - 
            0.20645618564475843`\ \(c[23]\)[t] - 
            0.21584055771952015`\ \(c[24]\)[t] - 
            0.21623620818304484`\ \(c[25]\)[t] - 
            0.206748335783172`\ \(c[26]\)[t] - 
            0.18675027222298593`\ \(c[27]\)[t] - 
            0.15591488063143982`\ \(c[28]\)[t] - 
            0.11423673049785436`\ \(c[29]\)[t] - 
            0.06204407497545024`\ \(c[30]\)[t] + 
            3.898171832519376`*^-17\ \(c[31]\)[t] + 
            0.07090751425765777`\ \(c[32]\)[t] + 
            0.14938649372796384`\ \(c[33]\)[t] + 
            0.23387232094715985`\ \(c[34]\)[t] + 
            0.3225686520215216`\ \(c[35]\)[t] + 
            0.4134966715663443`\ \(c[36]\)[t] + 
            0.5045511524271047`\ \(c[37]\)[t] + 
            0.5935615337286806`\ \(c[38]\)[t] + 
            0.6783560385470636`\ \(c[39]\)[t] + 
            0.7568267286406569`\ \(c[40]\)[t] + 
            0.826993343132688`\ \(c[41]\)[t] + 
            0.8870637930591839`\ \(c[42]\)[t] + 
            0.9354892837886392`\ \(c[43]\)[t] + 
            0.9710122092317629`\ \(c[44]\)[t] + 
            0.9927051996072069`\ \(c[45]\)[t] + 
            47.40907313934462`\ \(c[46]\)[t] + 
            0.9927051996072069`\ \(c[47]\)[t] + 
            0.9710122092317629`\ \(c[48]\)[t] + 
            0.9354892837886392`\ \(c[49]\)[t] + 
            0.8870637930591839`\ \(c[50]\)[t] + 
            0.826993343132688`\ \(c[51]\)[t] + 
            0.7568267286406569`\ \(c[52]\)[t] + 
            0.6783560385470636`\ \(c[53]\)[t] + 
            0.5935615337286801`\ \(c[54]\)[t] + 
            0.5045511524271047`\ \(c[55]\)[t] + 
            0.4134966715663443`\ \(c[56]\)[t] + 
            0.32256865202152113`\ \(c[57]\)[t] + 
            0.23387232094715985`\ \(c[58]\)[t] + 
            0.14938649372796384`\ \(c[59]\)[t] + 
            0.07090751425765746`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 46, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 46]][ t]], 
          Plus[ 
            Times[ -0.0093651433925206785, 
              c[ -60][ t]], 
            Times[ 2.0053370214556287*^-16, 
              c[ -59][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -58][ t]], 
            Times[ 0.018854606004500233, 
              c[ -57][ t]], 
            Times[ 0.027514390699665887, 
              c[ -56][ t]], 
            Times[ 0.035131239329076656, 
              c[ -55][ t]], 
            Times[ 0.041349667156634483, 
              c[ -54][ t]], 
            Times[ 0.045868286584282311, 
              c[ -53][ t]], 
            Times[ 0.048454002753361682, 
              c[ -52][ t]], 
            Times[ 0.04895352855494272, 
              c[ -51][ t]], 
            Times[ 0.047301670540041058, 
              c[ -50][ t]], 
            Times[ 0.043525965428036162, 
              c[ -49][ t]], 
            Times[ 0.03774739544932687, 
              c[ -48][ t]], 
            Times[ 0.030177073670601094, 
              c[ -47][ t]], 
            Times[ 0.021108961070255627, 
              c[ -46][ t]], 
            Times[ 0.010908848347331966, 
              c[ -45][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -44][ t]], 
            Times[ -0.011153991006822649, 
              c[ -43][ t]], 
            Times[ -0.022068459300722043, 
              c[ -42][ t]], 
            Times[ -0.032258251165125679, 
              c[ -41][ t]], 
            Times[ -0.041258781072520248, 
              c[ -40][ t]], 
            Times[ -0.048646667243099281, 
              c[ -39][ t]], 
            Times[ -0.054059052045761224, 
              c[ -38][ t]], 
            Times[ -0.057210750238908967, 
              c[ -37][ t]], 
            Times[ -0.057908442314993203, 
              c[ -36][ t]], 
            Times[ -0.056061239158567186, 
              c[ -35][ t]], 
            Times[ -0.05168708394579296, 
              c[ -34][ t]], 
            Times[ -0.044914622433376419, 
              c[ -33][ t]], 
            Times[ -0.035980357068793781, 
              c[ -32][ t]], 
            Times[ -0.025221096343682053, 
              c[ -31][ t]], 
            Times[ -0.013061910521147383, 
              c[ -30][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -29][ t]], 
            Times[ 0.013414935129827233, 
              c[ -28][ t]], 
            Times[ 0.026603074225527826, 
              c[ -27][ t]], 
            Times[ 0.03897872015785999, 
              c[ -26][ t]], 
            Times[ 0.049975424961080865, 
              c[ -25][ t]], 
            Times[ 0.059070953080906326, 
              c[ -24][ t]], 
            Times[ 0.065811019881796273, 
              c[ -23][ t]], 
            Times[ 0.069830768673962415, 
              c[ -22][ t]], 
            Times[ 0.070873018952678238, 
              c[ -21][ t]], 
            Times[ 0.068802429876423349, 
              c[ -20][ t]], 
            Times[ 0.063614872548668253, 
              c[ -19][ t]], 
            Times[ 0.055441487066198933, 
              c[ -18][ t]], 
            Times[ 0.044547108751839919, 
              c[ -17][ t]], 
            Times[ 0.031322974491347078, 
              c[ -16][ t]], 
            Times[ 0.016273855731265604, 
              c[ -15][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -14][ t]], 
            Times[ -0.016825511857749401, 
              c[ -13][ t]], 
            Times[ -0.033483179628681567, 
              c[ -12][ t]], 
            Times[ -0.049236278094138941, 
              c[ -11][ t]], 
            Times[ -0.063361699504227528, 
              c[ -10][ t]], 
            Times[ -0.075181213012062598, 
              c[ -9][ t]], 
            Times[ -0.084091858737850814, 
              c[ -8][ t]], 
            Times[ -0.089594193770366884, 
              c[ -7][ t]], 
            Times[ -0.091317159035181589, 
              c[ -6][ t]], 
            Times[ -0.089038438663606695, 
              c[ -5][ t]], 
            Times[ -0.082699334313268744, 
              c[ -4][ t]], 
            Times[ -0.072413370861974122, 
              c[ -3][ t]], 
            Times[ -0.058468080236789913, 
              c[ -2][ t]], 
            Times[ -0.04131966847794722, 
              c[ -1][ t]], 
            Times[ -0.021580547817547879, 
              c[ 0][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 1][ t]], 
            Times[ 0.022561481809254869, 
              c[ 2][ t]], 
            Times[ 0.045163358568919301, 
              c[ 3][ t]], 
            Times[ 0.066820663127759972, 
              c[ 4][ t]], 
            Times[ 0.086542809078944891, 
              c[ 5][ t]], 
            Times[ 0.10337416789158609, 
              c[ 6][ t]], 
            Times[ 0.11643488132933186, 
              c[ 7][ t]], 
            Times[ 0.12496032289024853, 
              c[ 8][ t]], 
            Times[ 0.12833762891430928, 
              c[ 9][ t]], 
            Times[ 0.12613778810677614, 
              c[ 10][ t]], 
            Times[ 0.11814190616181255, 
              c[ 11][ t]], 
            Times[ 0.10436044624225685, 
              c[ 12][ t]], 
            Times[ 0.085044480344421705, 
              c[ 13][ t]], 
            Times[ 0.060688263076985105, 
              c[ 14][ t]], 
            Times[ 0.032022748374425904, 
              c[ 15][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 16][ t]], 
            Times[ -0.034231213779558949, 
              c[ 17][ t]], 
            Times[ -0.06935801494512607, 
              c[ 18][ t]], 
            Times[ -0.10394325375429328, 
              c[ 19][ t]], 
            Times[ -0.13647135277833605, 
              c[ 20][ t]], 
            Times[ -0.16539866862653771, 
              c[ 21][ t]], 
            Times[ -0.18920668216016426, 
              c[ 22][ t]], 
            Times[ -0.20645618564475843, 
              c[ 23][ t]], 
            Times[ -0.21584055771952015, 
              c[ 24][ t]], 
            Times[ -0.21623620818304484, 
              c[ 25][ t]], 
            Times[ -0.206748335783172, 
              c[ 26][ t]], 
            Times[ -0.18675027222298593, 
              c[ 27][ t]], 
            Times[ -0.15591488063143982, 
              c[ 28][ t]], 
            Times[ -0.11423673049785436, 
              c[ 29][ t]], 
            Times[ -0.062044074975450239, 
              c[ 30][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 31][ t]], 
            Times[ 0.070907514257657775, 
              c[ 32][ t]], 
            Times[ 0.14938649372796384, 
              c[ 33][ t]], 
            Times[ 0.23387232094715985, 
              c[ 34][ t]], 
            Times[ 0.32256865202152157, 
              c[ 35][ t]], 
            Times[ 0.41349667156634429, 
              c[ 36][ t]], 
            Times[ 0.50455115242710469, 
              c[ 37][ t]], 
            Times[ 0.59356153372868059, 
              c[ 38][ t]], 
            Times[ 0.67835603854706361, 
              c[ 39][ t]], 
            Times[ 0.75682672864065692, 
              c[ 40][ t]], 
            Times[ 0.82699334313268802, 
              c[ 41][ t]], 
            Times[ 0.88706379305918392, 
              c[ 42][ t]], 
            Times[ 0.93548928378863916, 
              c[ 43][ t]], 
            Times[ 0.9710122092317629, 
              c[ 44][ t]], 
            Times[ 0.99270519960720693, 
              c[ 45][ t]], 
            Times[ 47.409073139344621, 
              c[ 46][ t]], 
            Times[ 0.99270519960720693, 
              c[ 47][ t]], 
            Times[ 0.9710122092317629, 
              c[ 48][ t]], 
            Times[ 0.93548928378863916, 
              c[ 49][ t]], 
            Times[ 0.88706379305918392, 
              c[ 50][ t]], 
            Times[ 0.82699334313268802, 
              c[ 51][ t]], 
            Times[ 0.75682672864065692, 
              c[ 52][ t]], 
            Times[ 0.67835603854706361, 
              c[ 53][ t]], 
            Times[ 0.59356153372868015, 
              c[ 54][ t]], 
            Times[ 0.50455115242710469, 
              c[ 55][ t]], 
            Times[ 0.41349667156634429, 
              c[ 56][ t]], 
            Times[ 0.32256865202152113, 
              c[ 57][ t]], 
            Times[ 0.23387232094715985, 
              c[ 58][ t]], 
            Times[ 0.14938649372796384, 
              c[ 59][ t]], 
            Times[ 0.070907514257657456, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "47", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[47]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.018149760920219783`\)\ \(c[\(-60\)]\)[t] - 
            0.009365143392520679`\ \(c[\(-59\)]\)[t] + 
            2.0053370214556287`*^-16\ \(c[\(-58\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-57\)]\)[t] + 
            0.01885460600450039`\ \(c[\(-56\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-55\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-54\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-53\)]\)[t] + 
            0.04586828658428231`\ \(c[\(-52\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-51\)]\)[t] + 
            0.0489535285549427`\ \(c[\(-50\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-49\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-48\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-47\)]\)[t] + 
            0.030177073670601094`\ \(c[\(-46\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-45\)]\)[t] + 
            0.010908848347331785`\ \(c[\(-44\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-43\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-42\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-41\)]\)[t] - 
            0.03225825116512568`\ \(c[\(-40\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-39\)]\)[t] - 
            0.0486466672430994`\ \(c[\(-38\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-37\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-36\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-35\)]\)[t] - 
            0.05606123915856713`\ \(c[\(-34\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-33\)]\)[t] - 
            0.04491462243337629`\ \(c[\(-32\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-31\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-30\)]\)[t] - 
            0.013061910521147276`\ \(c[\(-29\)]\)[t] + 
            1.5206810699945212`*^-16\ \(c[\(-28\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-27\)]\)[t] + 
            0.026603074225527937`\ \(c[\(-26\)]\)[t] + 
            0.03897872015786009`\ \(c[\(-25\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-24\)]\)[t] + 
            0.0590709530809064`\ \(c[\(-23\)]\)[t] + 
            0.06581101988179631`\ \(c[\(-22\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-21\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-20\)]\)[t] + 
            0.06880242987642332`\ \(c[\(-19\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-18\)]\)[t] + 
            0.055441487066198857`\ \(c[\(-17\)]\)[t] + 
            0.044547108751839815`\ \(c[\(-16\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-15\)]\)[t] + 
            0.01627385573126547`\ \(c[\(-14\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-13\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-12\)]\)[t] - 
            0.033483179628681706`\ \(c[\(-11\)]\)[t] - 
            0.049236278094139066`\ \(c[\(-10\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-9\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-8\)]\)[t] - 
            0.08409185873785086`\ \(c[\(-7\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-6\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-5\)]\)[t] - 
            0.08903843866360665`\ \(c[\(-4\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-3\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-2\)]\)[t] - 
            0.058468080236789774`\ \(c[\(-1\)]\)[t] - 
            0.04131966847794722`\ \(c[0]\)[t] - 
            0.02158054781754788`\ \(c[1]\)[t] + 
            2.274590327822911`*^-16\ \(c[2]\)[t] + 
            0.02256148180925487`\ \(c[3]\)[t] + 
            0.0451633585689193`\ \(c[4]\)[t] + 
            0.06682066312776015`\ \(c[5]\)[t] + 
            0.08654280907894489`\ \(c[6]\)[t] + 
            0.10337416789158609`\ \(c[7]\)[t] + 
            0.11643488132933195`\ \(c[8]\)[t] + 
            0.12496032289024853`\ \(c[9]\)[t] + 
            0.12833762891430928`\ \(c[10]\)[t] + 
            0.12613778810677612`\ \(c[11]\)[t] + 
            0.11814190616181253`\ \(c[12]\)[t] + 
            0.10436044624225685`\ \(c[13]\)[t] + 
            0.08504448034442161`\ \(c[14]\)[t] + 
            0.060688263076985`\ \(c[15]\)[t] + 
            0.032022748374425904`\ \(c[16]\)[t] - 
            1.8033970416801674`*^-16\ \(c[17]\)[t] - 
            0.034231213779559094`\ \(c[18]\)[t] - 
            0.06935801494512607`\ \(c[19]\)[t] - 
            0.1039432537542934`\ \(c[20]\)[t] - 
            0.13647135277833616`\ \(c[21]\)[t] - 
            0.1653986686265377`\ \(c[22]\)[t] - 
            0.18920668216016434`\ \(c[23]\)[t] - 
            0.20645618564475848`\ \(c[24]\)[t] - 
            0.21584055771952015`\ \(c[25]\)[t] - 
            0.21623620818304481`\ \(c[26]\)[t] - 
            0.2067483357831719`\ \(c[27]\)[t] - 
            0.18675027222298593`\ \(c[28]\)[t] - 
            0.15591488063143966`\ \(c[29]\)[t] - 
            0.11423673049785416`\ \(c[30]\)[t] - 
            0.06204407497545024`\ \(c[31]\)[t] + 
            3.216976900108398`*^-16\ \(c[32]\)[t] + 
            0.0709075142576581`\ \(c[33]\)[t] + 
            0.14938649372796384`\ \(c[34]\)[t] + 
            0.23387232094716018`\ \(c[35]\)[t] + 
            0.3225686520215219`\ \(c[36]\)[t] + 
            0.4134966715663443`\ \(c[37]\)[t] + 
            0.504551152427105`\ \(c[38]\)[t] + 
            0.5935615337286809`\ \(c[39]\)[t] + 
            0.6783560385470636`\ \(c[40]\)[t] + 
            0.7568267286406569`\ \(c[41]\)[t] + 
            0.8269933431326885`\ \(c[42]\)[t] + 
            0.8870637930591839`\ \(c[43]\)[t] + 
            0.9354892837886392`\ \(c[44]\)[t] + 
            0.9710122092317629`\ \(c[45]\)[t] + 
            0.9927051996072069`\ \(c[46]\)[t] + 
            49.448791382236415`\ \(c[47]\)[t] + 
            0.9927051996072067`\ \(c[48]\)[t] + 
            0.9710122092317629`\ \(c[49]\)[t] + 
            0.9354892837886392`\ \(c[50]\)[t] + 
            0.8870637930591835`\ \(c[51]\)[t] + 
            0.826993343132688`\ \(c[52]\)[t] + 
            0.7568267286406569`\ \(c[53]\)[t] + 
            0.6783560385470627`\ \(c[54]\)[t] + 
            0.5935615337286801`\ \(c[55]\)[t] + 
            0.5045511524271047`\ \(c[56]\)[t] + 
            0.4134966715663436`\ \(c[57]\)[t] + 
            0.32256865202152113`\ \(c[58]\)[t] + 
            0.23387232094715985`\ \(c[59]\)[t] + 
            0.14938649372796314`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 47, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 47]][ t]], 
          Plus[ 
            Times[ -0.018149760920219783, 
              c[ -60][ t]], 
            Times[ -0.0093651433925206785, 
              c[ -59][ t]], 
            Times[ 2.0053370214556287*^-16, 
              c[ -58][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -57][ t]], 
            Times[ 0.018854606004500389, 
              c[ -56][ t]], 
            Times[ 0.027514390699665887, 
              c[ -55][ t]], 
            Times[ 0.035131239329076656, 
              c[ -54][ t]], 
            Times[ 0.041349667156634483, 
              c[ -53][ t]], 
            Times[ 0.045868286584282311, 
              c[ -52][ t]], 
            Times[ 0.048454002753361682, 
              c[ -51][ t]], 
            Times[ 0.048953528554942699, 
              c[ -50][ t]], 
            Times[ 0.047301670540041058, 
              c[ -49][ t]], 
            Times[ 0.043525965428036162, 
              c[ -48][ t]], 
            Times[ 0.03774739544932687, 
              c[ -47][ t]], 
            Times[ 0.030177073670601094, 
              c[ -46][ t]], 
            Times[ 0.021108961070255627, 
              c[ -45][ t]], 
            Times[ 0.010908848347331785, 
              c[ -44][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -43][ t]], 
            Times[ -0.011153991006822649, 
              c[ -42][ t]], 
            Times[ -0.022068459300722043, 
              c[ -41][ t]], 
            Times[ -0.032258251165125679, 
              c[ -40][ t]], 
            Times[ -0.041258781072520248, 
              c[ -39][ t]], 
            Times[ -0.048646667243099399, 
              c[ -38][ t]], 
            Times[ -0.054059052045761224, 
              c[ -37][ t]], 
            Times[ -0.057210750238908967, 
              c[ -36][ t]], 
            Times[ -0.057908442314993203, 
              c[ -35][ t]], 
            Times[ -0.05606123915856713, 
              c[ -34][ t]], 
            Times[ -0.05168708394579296, 
              c[ -33][ t]], 
            Times[ -0.044914622433376288, 
              c[ -32][ t]], 
            Times[ -0.035980357068793781, 
              c[ -31][ t]], 
            Times[ -0.025221096343682053, 
              c[ -30][ t]], 
            Times[ -0.013061910521147276, 
              c[ -29][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ -28][ t]], 
            Times[ 0.013414935129827233, 
              c[ -27][ t]], 
            Times[ 0.026603074225527937, 
              c[ -26][ t]], 
            Times[ 0.038978720157860088, 
              c[ -25][ t]], 
            Times[ 0.049975424961080865, 
              c[ -24][ t]], 
            Times[ 0.059070953080906402, 
              c[ -23][ t]], 
            Times[ 0.065811019881796315, 
              c[ -22][ t]], 
            Times[ 0.069830768673962415, 
              c[ -21][ t]], 
            Times[ 0.070873018952678238, 
              c[ -20][ t]], 
            Times[ 0.068802429876423321, 
              c[ -19][ t]], 
            Times[ 0.063614872548668253, 
              c[ -18][ t]], 
            Times[ 0.055441487066198857, 
              c[ -17][ t]], 
            Times[ 0.044547108751839815, 
              c[ -16][ t]], 
            Times[ 0.031322974491347078, 
              c[ -15][ t]], 
            Times[ 0.016273855731265469, 
              c[ -14][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -13][ t]], 
            Times[ -0.016825511857749401, 
              c[ -12][ t]], 
            Times[ -0.033483179628681706, 
              c[ -11][ t]], 
            Times[ -0.049236278094139066, 
              c[ -10][ t]], 
            Times[ -0.063361699504227528, 
              c[ -9][ t]], 
            Times[ -0.075181213012062598, 
              c[ -8][ t]], 
            Times[ -0.084091858737850855, 
              c[ -7][ t]], 
            Times[ -0.089594193770366884, 
              c[ -6][ t]], 
            Times[ -0.091317159035181589, 
              c[ -5][ t]], 
            Times[ -0.089038438663606653, 
              c[ -4][ t]], 
            Times[ -0.082699334313268744, 
              c[ -3][ t]], 
            Times[ -0.072413370861974122, 
              c[ -2][ t]], 
            Times[ -0.058468080236789774, 
              c[ -1][ t]], 
            Times[ -0.04131966847794722, 
              c[ 0][ t]], 
            Times[ -0.021580547817547879, 
              c[ 1][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ 2][ t]], 
            Times[ 0.022561481809254869, 
              c[ 3][ t]], 
            Times[ 0.045163358568919301, 
              c[ 4][ t]], 
            Times[ 0.066820663127760152, 
              c[ 5][ t]], 
            Times[ 0.086542809078944891, 
              c[ 6][ t]], 
            Times[ 0.10337416789158609, 
              c[ 7][ t]], 
            Times[ 0.11643488132933195, 
              c[ 8][ t]], 
            Times[ 0.12496032289024853, 
              c[ 9][ t]], 
            Times[ 0.12833762891430928, 
              c[ 10][ t]], 
            Times[ 0.12613778810677612, 
              c[ 11][ t]], 
            Times[ 0.11814190616181253, 
              c[ 12][ t]], 
            Times[ 0.10436044624225685, 
              c[ 13][ t]], 
            Times[ 0.085044480344421608, 
              c[ 14][ t]], 
            Times[ 0.060688263076985001, 
              c[ 15][ t]], 
            Times[ 0.032022748374425904, 
              c[ 16][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 17][ t]], 
            Times[ -0.034231213779559094, 
              c[ 18][ t]], 
            Times[ -0.06935801494512607, 
              c[ 19][ t]], 
            Times[ -0.1039432537542934, 
              c[ 20][ t]], 
            Times[ -0.13647135277833616, 
              c[ 21][ t]], 
            Times[ -0.16539866862653771, 
              c[ 22][ t]], 
            Times[ -0.18920668216016434, 
              c[ 23][ t]], 
            Times[ -0.20645618564475848, 
              c[ 24][ t]], 
            Times[ -0.21584055771952015, 
              c[ 25][ t]], 
            Times[ -0.21623620818304481, 
              c[ 26][ t]], 
            Times[ -0.20674833578317189, 
              c[ 27][ t]], 
            Times[ -0.18675027222298593, 
              c[ 28][ t]], 
            Times[ -0.15591488063143966, 
              c[ 29][ t]], 
            Times[ -0.11423673049785416, 
              c[ 30][ t]], 
            Times[ -0.062044074975450239, 
              c[ 31][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ 32][ t]], 
            Times[ 0.070907514257658094, 
              c[ 33][ t]], 
            Times[ 0.14938649372796384, 
              c[ 34][ t]], 
            Times[ 0.23387232094716018, 
              c[ 35][ t]], 
            Times[ 0.32256865202152191, 
              c[ 36][ t]], 
            Times[ 0.41349667156634429, 
              c[ 37][ t]], 
            Times[ 0.50455115242710502, 
              c[ 38][ t]], 
            Times[ 0.59356153372868092, 
              c[ 39][ t]], 
            Times[ 0.67835603854706361, 
              c[ 40][ t]], 
            Times[ 0.75682672864065692, 
              c[ 41][ t]], 
            Times[ 0.82699334313268846, 
              c[ 42][ t]], 
            Times[ 0.88706379305918392, 
              c[ 43][ t]], 
            Times[ 0.93548928378863916, 
              c[ 44][ t]], 
            Times[ 0.9710122092317629, 
              c[ 45][ t]], 
            Times[ 0.99270519960720693, 
              c[ 46][ t]], 
            Times[ 49.448791382236415, 
              c[ 47][ t]], 
            Times[ 0.99270519960720671, 
              c[ 48][ t]], 
            Times[ 0.9710122092317629, 
              c[ 49][ t]], 
            Times[ 0.93548928378863916, 
              c[ 50][ t]], 
            Times[ 0.88706379305918348, 
              c[ 51][ t]], 
            Times[ 0.82699334313268802, 
              c[ 52][ t]], 
            Times[ 0.75682672864065692, 
              c[ 53][ t]], 
            Times[ 0.67835603854706272, 
              c[ 54][ t]], 
            Times[ 0.59356153372868015, 
              c[ 55][ t]], 
            Times[ 0.50455115242710469, 
              c[ 56][ t]], 
            Times[ 0.41349667156634362, 
              c[ 57][ t]], 
            Times[ 0.32256865202152113, 
              c[ 58][ t]], 
            Times[ 0.23387232094715985, 
              c[ 59][ t]], 
            Times[ 0.14938649372796314, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "48", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[48]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.02598581343857328`\)\ \(c[\(-60\)]\)[t] - 
            0.018149760920219783`\ \(c[\(-59\)]\)[t] - 
            0.009365143392520679`\ \(c[\(-58\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-57\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-56\)]\)[t] + 
            0.018854606004500233`\ \(c[\(-55\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-54\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-53\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-52\)]\)[t] + 
            0.045868286584282256`\ \(c[\(-51\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-50\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-49\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-48\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-47\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-46\)]\)[t] + 
            0.030177073670601236`\ \(c[\(-45\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-44\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-43\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-42\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-41\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-40\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-39\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-38\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-37\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-36\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-35\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-34\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-33\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-32\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-31\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-30\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-29\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-28\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-27\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-26\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-25\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-24\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-23\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-22\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-21\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-20\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-19\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-18\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-17\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-16\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-15\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-14\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-13\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-12\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-11\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-10\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-9\)]\)[t] - 
            0.0633616995042274`\ \(c[\(-8\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-7\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-6\)]\)[t] - 
            0.08959419377036684`\ \(c[\(-5\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-4\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-3\)]\)[t] - 
            0.08269933431326881`\ \(c[\(-2\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-1\)]\)[t] - 
            0.05846808023678991`\ \(c[0]\)[t] - 
            0.04131966847794737`\ \(c[1]\)[t] - 
            0.02158054781754788`\ \(c[2]\)[t] + 
            3.8981718325193755`*^-17\ \(c[3]\)[t] + 
            0.022561481809254675`\ \(c[4]\)[t] + 
            0.0451633585689193`\ \(c[5]\)[t] + 
            0.06682066312775997`\ \(c[6]\)[t] + 
            0.08654280907894475`\ \(c[7]\)[t] + 
            0.10337416789158609`\ \(c[8]\)[t] + 
            0.11643488132933186`\ \(c[9]\)[t] + 
            0.12496032289024847`\ \(c[10]\)[t] + 
            0.12833762891430925`\ \(c[11]\)[t] + 
            0.12613778810677614`\ \(c[12]\)[t] + 
            0.1181419061618126`\ \(c[13]\)[t] + 
            0.10436044624225692`\ \(c[14]\)[t] + 
            0.0850444803444217`\ \(c[15]\)[t] + 
            0.06068826307698522`\ \(c[16]\)[t] + 
            0.03202274837442603`\ \(c[17]\)[t] - 
            3.898171832519376`*^-17\ \(c[18]\)[t] - 
            0.034231213779558796`\ \(c[19]\)[t] - 
            0.06935801494512592`\ \(c[20]\)[t] - 
            0.10394325375429328`\ \(c[21]\)[t] - 
            0.1364713527783359`\ \(c[22]\)[t] - 
            0.1653986686265376`\ \(c[23]\)[t] - 
            0.18920668216016426`\ \(c[24]\)[t] - 
            0.20645618564475834`\ \(c[25]\)[t] - 
            0.21584055771952013`\ \(c[26]\)[t] - 
            0.21623620818304484`\ \(c[27]\)[t] - 
            0.20674833578317206`\ \(c[28]\)[t] - 
            0.18675027222298607`\ \(c[29]\)[t] - 
            0.15591488063143982`\ \(c[30]\)[t] - 
            0.11423673049785459`\ \(c[31]\)[t] - 
            0.062044074975450475`\ \(c[32]\)[t] + 
            3.898171832519376`*^-17\ \(c[33]\)[t] + 
            0.07090751425765746`\ \(c[34]\)[t] + 
            0.14938649372796345`\ \(c[35]\)[t] + 
            0.23387232094715985`\ \(c[36]\)[t] + 
            0.32256865202152113`\ \(c[37]\)[t] + 
            0.41349667156634395`\ \(c[38]\)[t] + 
            0.5045511524271047`\ \(c[39]\)[t] + 
            0.5935615337286801`\ \(c[40]\)[t] + 
            0.6783560385470627`\ \(c[41]\)[t] + 
            0.7568267286406569`\ \(c[42]\)[t] + 
            0.826993343132688`\ \(c[43]\)[t] + 
            0.8870637930591835`\ \(c[44]\)[t] + 
            0.9354892837886392`\ \(c[45]\)[t] + 
            0.9710122092317629`\ \(c[46]\)[t] + 
            0.9927051996072067`\ \(c[47]\)[t] + 
            51.53237453357751`\ \(c[48]\)[t] + 
            0.9927051996072069`\ \(c[49]\)[t] + 
            0.9710122092317629`\ \(c[50]\)[t] + 
            0.9354892837886392`\ \(c[51]\)[t] + 
            0.8870637930591839`\ \(c[52]\)[t] + 
            0.8269933431326885`\ \(c[53]\)[t] + 
            0.7568267286406569`\ \(c[54]\)[t] + 
            0.6783560385470636`\ \(c[55]\)[t] + 
            0.5935615337286809`\ \(c[56]\)[t] + 
            0.5045511524271047`\ \(c[57]\)[t] + 
            0.4134966715663443`\ \(c[58]\)[t] + 
            0.3225686520215219`\ \(c[59]\)[t] + 
            0.23387232094715985`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 48, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 48]][ t]], 
          Plus[ 
            Times[ -0.025985813438573278, 
              c[ -60][ t]], 
            Times[ -0.018149760920219783, 
              c[ -59][ t]], 
            Times[ -0.0093651433925206785, 
              c[ -58][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -57][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -56][ t]], 
            Times[ 0.018854606004500233, 
              c[ -55][ t]], 
            Times[ 0.027514390699665887, 
              c[ -54][ t]], 
            Times[ 0.035131239329076656, 
              c[ -53][ t]], 
            Times[ 0.041349667156634483, 
              c[ -52][ t]], 
            Times[ 0.045868286584282256, 
              c[ -51][ t]], 
            Times[ 0.048454002753361682, 
              c[ -50][ t]], 
            Times[ 0.04895352855494272, 
              c[ -49][ t]], 
            Times[ 0.047301670540041058, 
              c[ -48][ t]], 
            Times[ 0.043525965428036162, 
              c[ -47][ t]], 
            Times[ 0.03774739544932687, 
              c[ -46][ t]], 
            Times[ 0.030177073670601236, 
              c[ -45][ t]], 
            Times[ 0.021108961070255627, 
              c[ -44][ t]], 
            Times[ 0.010908848347331966, 
              c[ -43][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -42][ t]], 
            Times[ -0.011153991006822649, 
              c[ -41][ t]], 
            Times[ -0.022068459300722043, 
              c[ -40][ t]], 
            Times[ -0.032258251165125519, 
              c[ -39][ t]], 
            Times[ -0.041258781072520248, 
              c[ -38][ t]], 
            Times[ -0.048646667243099281, 
              c[ -37][ t]], 
            Times[ -0.054059052045761224, 
              c[ -36][ t]], 
            Times[ -0.057210750238908967, 
              c[ -35][ t]], 
            Times[ -0.057908442314993203, 
              c[ -34][ t]], 
            Times[ -0.056061239158567186, 
              c[ -33][ t]], 
            Times[ -0.05168708394579296, 
              c[ -32][ t]], 
            Times[ -0.044914622433376419, 
              c[ -31][ t]], 
            Times[ -0.035980357068793781, 
              c[ -30][ t]], 
            Times[ -0.025221096343682053, 
              c[ -29][ t]], 
            Times[ -0.013061910521147383, 
              c[ -28][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -27][ t]], 
            Times[ 0.013414935129827233, 
              c[ -26][ t]], 
            Times[ 0.026603074225527826, 
              c[ -25][ t]], 
            Times[ 0.03897872015785999, 
              c[ -24][ t]], 
            Times[ 0.049975424961080865, 
              c[ -23][ t]], 
            Times[ 0.059070953080906326, 
              c[ -22][ t]], 
            Times[ 0.065811019881796273, 
              c[ -21][ t]], 
            Times[ 0.069830768673962415, 
              c[ -20][ t]], 
            Times[ 0.070873018952678238, 
              c[ -19][ t]], 
            Times[ 0.068802429876423349, 
              c[ -18][ t]], 
            Times[ 0.063614872548668253, 
              c[ -17][ t]], 
            Times[ 0.055441487066198933, 
              c[ -16][ t]], 
            Times[ 0.044547108751839919, 
              c[ -15][ t]], 
            Times[ 0.031322974491347078, 
              c[ -14][ t]], 
            Times[ 0.016273855731265604, 
              c[ -13][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -12][ t]], 
            Times[ -0.016825511857749401, 
              c[ -11][ t]], 
            Times[ -0.033483179628681567, 
              c[ -10][ t]], 
            Times[ -0.049236278094138941, 
              c[ -9][ t]], 
            Times[ -0.063361699504227403, 
              c[ -8][ t]], 
            Times[ -0.075181213012062598, 
              c[ -7][ t]], 
            Times[ -0.084091858737850814, 
              c[ -6][ t]], 
            Times[ -0.089594193770366842, 
              c[ -5][ t]], 
            Times[ -0.091317159035181589, 
              c[ -4][ t]], 
            Times[ -0.089038438663606695, 
              c[ -3][ t]], 
            Times[ -0.082699334313268813, 
              c[ -2][ t]], 
            Times[ -0.072413370861974122, 
              c[ -1][ t]], 
            Times[ -0.058468080236789913, 
              c[ 0][ t]], 
            Times[ -0.041319668477947373, 
              c[ 1][ t]], 
            Times[ -0.021580547817547879, 
              c[ 2][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 3][ t]], 
            Times[ 0.022561481809254675, 
              c[ 4][ t]], 
            Times[ 0.045163358568919301, 
              c[ 5][ t]], 
            Times[ 0.066820663127759972, 
              c[ 6][ t]], 
            Times[ 0.086542809078944752, 
              c[ 7][ t]], 
            Times[ 0.10337416789158609, 
              c[ 8][ t]], 
            Times[ 0.11643488132933186, 
              c[ 9][ t]], 
            Times[ 0.12496032289024847, 
              c[ 10][ t]], 
            Times[ 0.12833762891430925, 
              c[ 11][ t]], 
            Times[ 0.12613778810677614, 
              c[ 12][ t]], 
            Times[ 0.1181419061618126, 
              c[ 13][ t]], 
            Times[ 0.10436044624225692, 
              c[ 14][ t]], 
            Times[ 0.085044480344421705, 
              c[ 15][ t]], 
            Times[ 0.060688263076985223, 
              c[ 16][ t]], 
            Times[ 0.032022748374426029, 
              c[ 17][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 18][ t]], 
            Times[ -0.034231213779558796, 
              c[ 19][ t]], 
            Times[ -0.069358014945125918, 
              c[ 20][ t]], 
            Times[ -0.10394325375429328, 
              c[ 21][ t]], 
            Times[ -0.13647135277833591, 
              c[ 22][ t]], 
            Times[ -0.1653986686265376, 
              c[ 23][ t]], 
            Times[ -0.18920668216016426, 
              c[ 24][ t]], 
            Times[ -0.20645618564475834, 
              c[ 25][ t]], 
            Times[ -0.21584055771952013, 
              c[ 26][ t]], 
            Times[ -0.21623620818304484, 
              c[ 27][ t]], 
            Times[ -0.20674833578317206, 
              c[ 28][ t]], 
            Times[ -0.18675027222298607, 
              c[ 29][ t]], 
            Times[ -0.15591488063143982, 
              c[ 30][ t]], 
            Times[ -0.11423673049785459, 
              c[ 31][ t]], 
            Times[ -0.062044074975450475, 
              c[ 32][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 33][ t]], 
            Times[ 0.070907514257657456, 
              c[ 34][ t]], 
            Times[ 0.14938649372796345, 
              c[ 35][ t]], 
            Times[ 0.23387232094715985, 
              c[ 36][ t]], 
            Times[ 0.32256865202152113, 
              c[ 37][ t]], 
            Times[ 0.41349667156634395, 
              c[ 38][ t]], 
            Times[ 0.50455115242710469, 
              c[ 39][ t]], 
            Times[ 0.59356153372868015, 
              c[ 40][ t]], 
            Times[ 0.67835603854706272, 
              c[ 41][ t]], 
            Times[ 0.75682672864065692, 
              c[ 42][ t]], 
            Times[ 0.82699334313268802, 
              c[ 43][ t]], 
            Times[ 0.88706379305918348, 
              c[ 44][ t]], 
            Times[ 0.93548928378863916, 
              c[ 45][ t]], 
            Times[ 0.9710122092317629, 
              c[ 46][ t]], 
            Times[ 0.99270519960720671, 
              c[ 47][ t]], 
            Times[ 51.53237453357751, 
              c[ 48][ t]], 
            Times[ 0.99270519960720693, 
              c[ 49][ t]], 
            Times[ 0.9710122092317629, 
              c[ 50][ t]], 
            Times[ 0.93548928378863916, 
              c[ 51][ t]], 
            Times[ 0.88706379305918392, 
              c[ 52][ t]], 
            Times[ 0.82699334313268846, 
              c[ 53][ t]], 
            Times[ 0.75682672864065692, 
              c[ 54][ t]], 
            Times[ 0.67835603854706361, 
              c[ 55][ t]], 
            Times[ 0.59356153372868092, 
              c[ 56][ t]], 
            Times[ 0.50455115242710469, 
              c[ 57][ t]], 
            Times[ 0.41349667156634429, 
              c[ 58][ t]], 
            Times[ 0.32256865202152191, 
              c[ 59][ t]], 
            Times[ 0.23387232094715985, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "49", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[49]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.032552799745291155`\)\ \(c[\(-60\)]\)[t] - 
            0.02598581343857328`\ \(c[\(-59\)]\)[t] - 
            0.018149760920219783`\ \(c[\(-58\)]\)[t] - 
            0.009365143392520679`\ \(c[\(-57\)]\)[t] + 
            2.0053370214556287`*^-16\ \(c[\(-56\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-55\)]\)[t] + 
            0.018854606004500233`\ \(c[\(-54\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-53\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-52\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-51\)]\)[t] + 
            0.04586828658428231`\ \(c[\(-50\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-49\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-48\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-47\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-46\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-45\)]\)[t] + 
            0.030177073670601094`\ \(c[\(-44\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-43\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-42\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-41\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-40\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-39\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-38\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-37\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-36\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-35\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-34\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-33\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-32\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-31\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-30\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-29\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-28\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-27\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-26\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-25\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-24\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-23\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-22\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-21\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-20\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-19\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-18\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-17\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-16\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-15\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-14\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-13\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-12\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-11\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-10\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-9\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-8\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-7\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-6\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-5\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-4\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-3\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-2\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-1\)]\)[t] - 
            0.07241337086197412`\ \(c[0]\)[t] - 
            0.05846808023678991`\ \(c[1]\)[t] - 
            0.04131966847794722`\ \(c[2]\)[t] - 
            0.02158054781754788`\ \(c[3]\)[t] + 
            3.8981718325193755`*^-17\ \(c[4]\)[t] + 
            0.02256148180925487`\ \(c[5]\)[t] + 
            0.0451633585689193`\ \(c[6]\)[t] + 
            0.06682066312775997`\ \(c[7]\)[t] + 
            0.08654280907894489`\ \(c[8]\)[t] + 
            0.10337416789158609`\ \(c[9]\)[t] + 
            0.11643488132933186`\ \(c[10]\)[t] + 
            0.12496032289024853`\ \(c[11]\)[t] + 
            0.12833762891430928`\ \(c[12]\)[t] + 
            0.12613778810677614`\ \(c[13]\)[t] + 
            0.11814190616181255`\ \(c[14]\)[t] + 
            0.10436044624225685`\ \(c[15]\)[t] + 
            0.0850444803444217`\ \(c[16]\)[t] + 
            0.060688263076985105`\ \(c[17]\)[t] + 
            0.032022748374425904`\ \(c[18]\)[t] - 
            3.898171832519376`*^-17\ \(c[19]\)[t] - 
            0.03423121377955895`\ \(c[20]\)[t] - 
            0.06935801494512607`\ \(c[21]\)[t] - 
            0.10394325375429328`\ \(c[22]\)[t] - 
            0.13647135277833605`\ \(c[23]\)[t] - 
            0.1653986686265377`\ \(c[24]\)[t] - 
            0.18920668216016426`\ \(c[25]\)[t] - 
            0.20645618564475843`\ \(c[26]\)[t] - 
            0.21584055771952015`\ \(c[27]\)[t] - 
            0.21623620818304484`\ \(c[28]\)[t] - 
            0.206748335783172`\ \(c[29]\)[t] - 
            0.18675027222298593`\ \(c[30]\)[t] - 
            0.15591488063143982`\ \(c[31]\)[t] - 
            0.11423673049785436`\ \(c[32]\)[t] - 
            0.06204407497545024`\ \(c[33]\)[t] + 
            3.898171832519376`*^-17\ \(c[34]\)[t] + 
            0.07090751425765777`\ \(c[35]\)[t] + 
            0.14938649372796384`\ \(c[36]\)[t] + 
            0.23387232094715985`\ \(c[37]\)[t] + 
            0.3225686520215216`\ \(c[38]\)[t] + 
            0.4134966715663443`\ \(c[39]\)[t] + 
            0.5045511524271047`\ \(c[40]\)[t] + 
            0.5935615337286801`\ \(c[41]\)[t] + 
            0.6783560385470636`\ \(c[42]\)[t] + 
            0.7568267286406569`\ \(c[43]\)[t] + 
            0.826993343132688`\ \(c[44]\)[t] + 
            0.8870637930591839`\ \(c[45]\)[t] + 
            0.9354892837886392`\ \(c[46]\)[t] + 
            0.9710122092317629`\ \(c[47]\)[t] + 
            0.9927051996072069`\ \(c[48]\)[t] + 
            53.65982259336788`\ \(c[49]\)[t] + 
            0.9927051996072069`\ \(c[50]\)[t] + 
            0.9710122092317629`\ \(c[51]\)[t] + 
            0.9354892837886392`\ \(c[52]\)[t] + 
            0.8870637930591839`\ \(c[53]\)[t] + 
            0.826993343132688`\ \(c[54]\)[t] + 
            0.7568267286406569`\ \(c[55]\)[t] + 
            0.6783560385470636`\ \(c[56]\)[t] + 
            0.5935615337286801`\ \(c[57]\)[t] + 
            0.5045511524271047`\ \(c[58]\)[t] + 
            0.4134966715663443`\ \(c[59]\)[t] + 
            0.32256865202152113`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 49, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 49]][ t]], 
          Plus[ 
            Times[ -0.032552799745291155, 
              c[ -60][ t]], 
            Times[ -0.025985813438573278, 
              c[ -59][ t]], 
            Times[ -0.018149760920219783, 
              c[ -58][ t]], 
            Times[ -0.0093651433925206785, 
              c[ -57][ t]], 
            Times[ 2.0053370214556287*^-16, 
              c[ -56][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -55][ t]], 
            Times[ 0.018854606004500233, 
              c[ -54][ t]], 
            Times[ 0.027514390699665887, 
              c[ -53][ t]], 
            Times[ 0.035131239329076656, 
              c[ -52][ t]], 
            Times[ 0.041349667156634483, 
              c[ -51][ t]], 
            Times[ 0.045868286584282311, 
              c[ -50][ t]], 
            Times[ 0.048454002753361682, 
              c[ -49][ t]], 
            Times[ 0.04895352855494272, 
              c[ -48][ t]], 
            Times[ 0.047301670540041058, 
              c[ -47][ t]], 
            Times[ 0.043525965428036162, 
              c[ -46][ t]], 
            Times[ 0.03774739544932687, 
              c[ -45][ t]], 
            Times[ 0.030177073670601094, 
              c[ -44][ t]], 
            Times[ 0.021108961070255627, 
              c[ -43][ t]], 
            Times[ 0.010908848347331966, 
              c[ -42][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -41][ t]], 
            Times[ -0.011153991006822649, 
              c[ -40][ t]], 
            Times[ -0.022068459300722043, 
              c[ -39][ t]], 
            Times[ -0.032258251165125519, 
              c[ -38][ t]], 
            Times[ -0.041258781072520248, 
              c[ -37][ t]], 
            Times[ -0.048646667243099281, 
              c[ -36][ t]], 
            Times[ -0.054059052045761224, 
              c[ -35][ t]], 
            Times[ -0.057210750238908967, 
              c[ -34][ t]], 
            Times[ -0.057908442314993203, 
              c[ -33][ t]], 
            Times[ -0.056061239158567186, 
              c[ -32][ t]], 
            Times[ -0.05168708394579296, 
              c[ -31][ t]], 
            Times[ -0.044914622433376419, 
              c[ -30][ t]], 
            Times[ -0.035980357068793781, 
              c[ -29][ t]], 
            Times[ -0.025221096343682053, 
              c[ -28][ t]], 
            Times[ -0.013061910521147383, 
              c[ -27][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -26][ t]], 
            Times[ 0.013414935129827233, 
              c[ -25][ t]], 
            Times[ 0.026603074225527826, 
              c[ -24][ t]], 
            Times[ 0.03897872015785999, 
              c[ -23][ t]], 
            Times[ 0.049975424961080865, 
              c[ -22][ t]], 
            Times[ 0.059070953080906326, 
              c[ -21][ t]], 
            Times[ 0.065811019881796273, 
              c[ -20][ t]], 
            Times[ 0.069830768673962415, 
              c[ -19][ t]], 
            Times[ 0.070873018952678238, 
              c[ -18][ t]], 
            Times[ 0.068802429876423349, 
              c[ -17][ t]], 
            Times[ 0.063614872548668253, 
              c[ -16][ t]], 
            Times[ 0.055441487066198933, 
              c[ -15][ t]], 
            Times[ 0.044547108751839919, 
              c[ -14][ t]], 
            Times[ 0.031322974491347078, 
              c[ -13][ t]], 
            Times[ 0.016273855731265604, 
              c[ -12][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -11][ t]], 
            Times[ -0.016825511857749401, 
              c[ -10][ t]], 
            Times[ -0.033483179628681567, 
              c[ -9][ t]], 
            Times[ -0.049236278094138941, 
              c[ -8][ t]], 
            Times[ -0.063361699504227528, 
              c[ -7][ t]], 
            Times[ -0.075181213012062598, 
              c[ -6][ t]], 
            Times[ -0.084091858737850814, 
              c[ -5][ t]], 
            Times[ -0.089594193770366884, 
              c[ -4][ t]], 
            Times[ -0.091317159035181589, 
              c[ -3][ t]], 
            Times[ -0.089038438663606695, 
              c[ -2][ t]], 
            Times[ -0.082699334313268744, 
              c[ -1][ t]], 
            Times[ -0.072413370861974122, 
              c[ 0][ t]], 
            Times[ -0.058468080236789913, 
              c[ 1][ t]], 
            Times[ -0.04131966847794722, 
              c[ 2][ t]], 
            Times[ -0.021580547817547879, 
              c[ 3][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 4][ t]], 
            Times[ 0.022561481809254869, 
              c[ 5][ t]], 
            Times[ 0.045163358568919301, 
              c[ 6][ t]], 
            Times[ 0.066820663127759972, 
              c[ 7][ t]], 
            Times[ 0.086542809078944891, 
              c[ 8][ t]], 
            Times[ 0.10337416789158609, 
              c[ 9][ t]], 
            Times[ 0.11643488132933186, 
              c[ 10][ t]], 
            Times[ 0.12496032289024853, 
              c[ 11][ t]], 
            Times[ 0.12833762891430928, 
              c[ 12][ t]], 
            Times[ 0.12613778810677614, 
              c[ 13][ t]], 
            Times[ 0.11814190616181255, 
              c[ 14][ t]], 
            Times[ 0.10436044624225685, 
              c[ 15][ t]], 
            Times[ 0.085044480344421705, 
              c[ 16][ t]], 
            Times[ 0.060688263076985105, 
              c[ 17][ t]], 
            Times[ 0.032022748374425904, 
              c[ 18][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 19][ t]], 
            Times[ -0.034231213779558949, 
              c[ 20][ t]], 
            Times[ -0.06935801494512607, 
              c[ 21][ t]], 
            Times[ -0.10394325375429328, 
              c[ 22][ t]], 
            Times[ -0.13647135277833605, 
              c[ 23][ t]], 
            Times[ -0.16539866862653771, 
              c[ 24][ t]], 
            Times[ -0.18920668216016426, 
              c[ 25][ t]], 
            Times[ -0.20645618564475843, 
              c[ 26][ t]], 
            Times[ -0.21584055771952015, 
              c[ 27][ t]], 
            Times[ -0.21623620818304484, 
              c[ 28][ t]], 
            Times[ -0.206748335783172, 
              c[ 29][ t]], 
            Times[ -0.18675027222298593, 
              c[ 30][ t]], 
            Times[ -0.15591488063143982, 
              c[ 31][ t]], 
            Times[ -0.11423673049785436, 
              c[ 32][ t]], 
            Times[ -0.062044074975450239, 
              c[ 33][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 34][ t]], 
            Times[ 0.070907514257657775, 
              c[ 35][ t]], 
            Times[ 0.14938649372796384, 
              c[ 36][ t]], 
            Times[ 0.23387232094715985, 
              c[ 37][ t]], 
            Times[ 0.32256865202152157, 
              c[ 38][ t]], 
            Times[ 0.41349667156634429, 
              c[ 39][ t]], 
            Times[ 0.50455115242710469, 
              c[ 40][ t]], 
            Times[ 0.59356153372868015, 
              c[ 41][ t]], 
            Times[ 0.67835603854706361, 
              c[ 42][ t]], 
            Times[ 0.75682672864065692, 
              c[ 43][ t]], 
            Times[ 0.82699334313268802, 
              c[ 44][ t]], 
            Times[ 0.88706379305918392, 
              c[ 45][ t]], 
            Times[ 0.93548928378863916, 
              c[ 46][ t]], 
            Times[ 0.9710122092317629, 
              c[ 47][ t]], 
            Times[ 0.99270519960720693, 
              c[ 48][ t]], 
            Times[ 53.659822593367878, 
              c[ 49][ t]], 
            Times[ 0.99270519960720693, 
              c[ 50][ t]], 
            Times[ 0.9710122092317629, 
              c[ 51][ t]], 
            Times[ 0.93548928378863916, 
              c[ 52][ t]], 
            Times[ 0.88706379305918392, 
              c[ 53][ t]], 
            Times[ 0.82699334313268802, 
              c[ 54][ t]], 
            Times[ 0.75682672864065692, 
              c[ 55][ t]], 
            Times[ 0.67835603854706361, 
              c[ 56][ t]], 
            Times[ 0.59356153372868015, 
              c[ 57][ t]], 
            Times[ 0.50455115242710469, 
              c[ 58][ t]], 
            Times[ 0.41349667156634429, 
              c[ 59][ t]], 
            Times[ 0.32256865202152113, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "50", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[50]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.037590606506031236`\)\ \(c[\(-60\)]\)[t] - 
            0.03255279974529105`\ \(c[\(-59\)]\)[t] - 
            0.02598581343857328`\ \(c[\(-58\)]\)[t] - 
            0.018149760920219783`\ \(c[\(-57\)]\)[t] - 
            0.009365143392520679`\ \(c[\(-56\)]\)[t] + 
            2.0053370214556287`*^-16\ \(c[\(-55\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-54\)]\)[t] + 
            0.01885460600450039`\ \(c[\(-53\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-52\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-51\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-50\)]\)[t] + 
            0.04586828658428231`\ \(c[\(-49\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-48\)]\)[t] + 
            0.0489535285549427`\ \(c[\(-47\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-46\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-45\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-44\)]\)[t] + 
            0.030177073670601094`\ \(c[\(-43\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-42\)]\)[t] + 
            0.010908848347331785`\ \(c[\(-41\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-40\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-39\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-38\)]\)[t] - 
            0.03225825116512568`\ \(c[\(-37\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-36\)]\)[t] - 
            0.0486466672430994`\ \(c[\(-35\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-34\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-33\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-32\)]\)[t] - 
            0.05606123915856713`\ \(c[\(-31\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-30\)]\)[t] - 
            0.04491462243337629`\ \(c[\(-29\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-28\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-27\)]\)[t] - 
            0.013061910521147276`\ \(c[\(-26\)]\)[t] + 
            1.5206810699945212`*^-16\ \(c[\(-25\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-24\)]\)[t] + 
            0.026603074225527937`\ \(c[\(-23\)]\)[t] + 
            0.03897872015786009`\ \(c[\(-22\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-21\)]\)[t] + 
            0.0590709530809064`\ \(c[\(-20\)]\)[t] + 
            0.06581101988179631`\ \(c[\(-19\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-18\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-17\)]\)[t] + 
            0.06880242987642332`\ \(c[\(-16\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-15\)]\)[t] + 
            0.055441487066198857`\ \(c[\(-14\)]\)[t] + 
            0.044547108751839815`\ \(c[\(-13\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-12\)]\)[t] + 
            0.01627385573126547`\ \(c[\(-11\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-10\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-9\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-8\)]\)[t] - 
            0.049236278094139066`\ \(c[\(-7\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-6\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-5\)]\)[t] - 
            0.08409185873785086`\ \(c[\(-4\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-3\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-2\)]\)[t] - 
            0.08903843866360665`\ \(c[\(-1\)]\)[t] - 
            0.08269933431326874`\ \(c[0]\)[t] - 
            0.07241337086197412`\ \(c[1]\)[t] - 
            0.058468080236789774`\ \(c[2]\)[t] - 
            0.04131966847794722`\ \(c[3]\)[t] - 
            0.02158054781754788`\ \(c[4]\)[t] + 
            2.274590327822911`*^-16\ \(c[5]\)[t] + 
            0.02256148180925487`\ \(c[6]\)[t] + 
            0.0451633585689193`\ \(c[7]\)[t] + 
            0.06682066312776015`\ \(c[8]\)[t] + 
            0.08654280907894489`\ \(c[9]\)[t] + 
            0.10337416789158609`\ \(c[10]\)[t] + 
            0.11643488132933186`\ \(c[11]\)[t] + 
            0.12496032289024853`\ \(c[12]\)[t] + 
            0.12833762891430928`\ \(c[13]\)[t] + 
            0.12613778810677612`\ \(c[14]\)[t] + 
            0.11814190616181253`\ \(c[15]\)[t] + 
            0.10436044624225685`\ \(c[16]\)[t] + 
            0.08504448034442161`\ \(c[17]\)[t] + 
            0.060688263076985`\ \(c[18]\)[t] + 
            0.032022748374425904`\ \(c[19]\)[t] - 
            1.8033970416801674`*^-16\ \(c[20]\)[t] - 
            0.034231213779559094`\ \(c[21]\)[t] - 
            0.06935801494512607`\ \(c[22]\)[t] - 
            0.1039432537542934`\ \(c[23]\)[t] - 
            0.13647135277833616`\ \(c[24]\)[t] - 
            0.1653986686265377`\ \(c[25]\)[t] - 
            0.18920668216016434`\ \(c[26]\)[t] - 
            0.20645618564475848`\ \(c[27]\)[t] - 
            0.21584055771952015`\ \(c[28]\)[t] - 
            0.21623620818304481`\ \(c[29]\)[t] - 
            0.2067483357831719`\ \(c[30]\)[t] - 
            0.18675027222298593`\ \(c[31]\)[t] - 
            0.15591488063143966`\ \(c[32]\)[t] - 
            0.11423673049785416`\ \(c[33]\)[t] - 
            0.06204407497545024`\ \(c[34]\)[t] + 
            3.216976900108398`*^-16\ \(c[35]\)[t] + 
            0.0709075142576581`\ \(c[36]\)[t] + 
            0.14938649372796384`\ \(c[37]\)[t] + 
            0.23387232094716018`\ \(c[38]\)[t] + 
            0.3225686520215219`\ \(c[39]\)[t] + 
            0.4134966715663443`\ \(c[40]\)[t] + 
            0.5045511524271047`\ \(c[41]\)[t] + 
            0.5935615337286809`\ \(c[42]\)[t] + 
            0.6783560385470636`\ \(c[43]\)[t] + 
            0.7568267286406569`\ \(c[44]\)[t] + 
            0.8269933431326885`\ \(c[45]\)[t] + 
            0.8870637930591839`\ \(c[46]\)[t] + 
            0.9354892837886392`\ \(c[47]\)[t] + 
            0.9710122092317629`\ \(c[48]\)[t] + 
            0.9927051996072069`\ \(c[49]\)[t] + 
            55.83113556160753`\ \(c[50]\)[t] + 
            0.9927051996072067`\ \(c[51]\)[t] + 
            0.9710122092317629`\ \(c[52]\)[t] + 
            0.9354892837886392`\ \(c[53]\)[t] + 
            0.8870637930591835`\ \(c[54]\)[t] + 
            0.826993343132688`\ \(c[55]\)[t] + 
            0.7568267286406569`\ \(c[56]\)[t] + 
            0.6783560385470627`\ \(c[57]\)[t] + 
            0.5935615337286801`\ \(c[58]\)[t] + 
            0.5045511524271047`\ \(c[59]\)[t] + 
            0.4134966715663436`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 50, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 50]][ t]], 
          Plus[ 
            Times[ -0.037590606506031236, 
              c[ -60][ t]], 
            Times[ -0.032552799745291051, 
              c[ -59][ t]], 
            Times[ -0.025985813438573278, 
              c[ -58][ t]], 
            Times[ -0.018149760920219783, 
              c[ -57][ t]], 
            Times[ -0.0093651433925206785, 
              c[ -56][ t]], 
            Times[ 2.0053370214556287*^-16, 
              c[ -55][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -54][ t]], 
            Times[ 0.018854606004500389, 
              c[ -53][ t]], 
            Times[ 0.027514390699665887, 
              c[ -52][ t]], 
            Times[ 0.035131239329076656, 
              c[ -51][ t]], 
            Times[ 0.041349667156634483, 
              c[ -50][ t]], 
            Times[ 0.045868286584282311, 
              c[ -49][ t]], 
            Times[ 0.048454002753361682, 
              c[ -48][ t]], 
            Times[ 0.048953528554942699, 
              c[ -47][ t]], 
            Times[ 0.047301670540041058, 
              c[ -46][ t]], 
            Times[ 0.043525965428036162, 
              c[ -45][ t]], 
            Times[ 0.03774739544932687, 
              c[ -44][ t]], 
            Times[ 0.030177073670601094, 
              c[ -43][ t]], 
            Times[ 0.021108961070255627, 
              c[ -42][ t]], 
            Times[ 0.010908848347331785, 
              c[ -41][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -40][ t]], 
            Times[ -0.011153991006822649, 
              c[ -39][ t]], 
            Times[ -0.022068459300722043, 
              c[ -38][ t]], 
            Times[ -0.032258251165125679, 
              c[ -37][ t]], 
            Times[ -0.041258781072520248, 
              c[ -36][ t]], 
            Times[ -0.048646667243099399, 
              c[ -35][ t]], 
            Times[ -0.054059052045761224, 
              c[ -34][ t]], 
            Times[ -0.057210750238908967, 
              c[ -33][ t]], 
            Times[ -0.057908442314993203, 
              c[ -32][ t]], 
            Times[ -0.05606123915856713, 
              c[ -31][ t]], 
            Times[ -0.05168708394579296, 
              c[ -30][ t]], 
            Times[ -0.044914622433376288, 
              c[ -29][ t]], 
            Times[ -0.035980357068793781, 
              c[ -28][ t]], 
            Times[ -0.025221096343682053, 
              c[ -27][ t]], 
            Times[ -0.013061910521147276, 
              c[ -26][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ -25][ t]], 
            Times[ 0.013414935129827233, 
              c[ -24][ t]], 
            Times[ 0.026603074225527937, 
              c[ -23][ t]], 
            Times[ 0.038978720157860088, 
              c[ -22][ t]], 
            Times[ 0.049975424961080865, 
              c[ -21][ t]], 
            Times[ 0.059070953080906402, 
              c[ -20][ t]], 
            Times[ 0.065811019881796315, 
              c[ -19][ t]], 
            Times[ 0.069830768673962415, 
              c[ -18][ t]], 
            Times[ 0.070873018952678238, 
              c[ -17][ t]], 
            Times[ 0.068802429876423321, 
              c[ -16][ t]], 
            Times[ 0.063614872548668253, 
              c[ -15][ t]], 
            Times[ 0.055441487066198857, 
              c[ -14][ t]], 
            Times[ 0.044547108751839815, 
              c[ -13][ t]], 
            Times[ 0.031322974491347078, 
              c[ -12][ t]], 
            Times[ 0.016273855731265469, 
              c[ -11][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -10][ t]], 
            Times[ -0.016825511857749401, 
              c[ -9][ t]], 
            Times[ -0.033483179628681567, 
              c[ -8][ t]], 
            Times[ -0.049236278094139066, 
              c[ -7][ t]], 
            Times[ -0.063361699504227528, 
              c[ -6][ t]], 
            Times[ -0.075181213012062598, 
              c[ -5][ t]], 
            Times[ -0.084091858737850855, 
              c[ -4][ t]], 
            Times[ -0.089594193770366884, 
              c[ -3][ t]], 
            Times[ -0.091317159035181589, 
              c[ -2][ t]], 
            Times[ -0.089038438663606653, 
              c[ -1][ t]], 
            Times[ -0.082699334313268744, 
              c[ 0][ t]], 
            Times[ -0.072413370861974122, 
              c[ 1][ t]], 
            Times[ -0.058468080236789774, 
              c[ 2][ t]], 
            Times[ -0.04131966847794722, 
              c[ 3][ t]], 
            Times[ -0.021580547817547879, 
              c[ 4][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ 5][ t]], 
            Times[ 0.022561481809254869, 
              c[ 6][ t]], 
            Times[ 0.045163358568919301, 
              c[ 7][ t]], 
            Times[ 0.066820663127760152, 
              c[ 8][ t]], 
            Times[ 0.086542809078944891, 
              c[ 9][ t]], 
            Times[ 0.10337416789158609, 
              c[ 10][ t]], 
            Times[ 0.11643488132933186, 
              c[ 11][ t]], 
            Times[ 0.12496032289024853, 
              c[ 12][ t]], 
            Times[ 0.12833762891430928, 
              c[ 13][ t]], 
            Times[ 0.12613778810677612, 
              c[ 14][ t]], 
            Times[ 0.11814190616181253, 
              c[ 15][ t]], 
            Times[ 0.10436044624225685, 
              c[ 16][ t]], 
            Times[ 0.085044480344421608, 
              c[ 17][ t]], 
            Times[ 0.060688263076985001, 
              c[ 18][ t]], 
            Times[ 0.032022748374425904, 
              c[ 19][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 20][ t]], 
            Times[ -0.034231213779559094, 
              c[ 21][ t]], 
            Times[ -0.06935801494512607, 
              c[ 22][ t]], 
            Times[ -0.1039432537542934, 
              c[ 23][ t]], 
            Times[ -0.13647135277833616, 
              c[ 24][ t]], 
            Times[ -0.16539866862653771, 
              c[ 25][ t]], 
            Times[ -0.18920668216016434, 
              c[ 26][ t]], 
            Times[ -0.20645618564475848, 
              c[ 27][ t]], 
            Times[ -0.21584055771952015, 
              c[ 28][ t]], 
            Times[ -0.21623620818304481, 
              c[ 29][ t]], 
            Times[ -0.20674833578317189, 
              c[ 30][ t]], 
            Times[ -0.18675027222298593, 
              c[ 31][ t]], 
            Times[ -0.15591488063143966, 
              c[ 32][ t]], 
            Times[ -0.11423673049785416, 
              c[ 33][ t]], 
            Times[ -0.062044074975450239, 
              c[ 34][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ 35][ t]], 
            Times[ 0.070907514257658094, 
              c[ 36][ t]], 
            Times[ 0.14938649372796384, 
              c[ 37][ t]], 
            Times[ 0.23387232094716018, 
              c[ 38][ t]], 
            Times[ 0.32256865202152191, 
              c[ 39][ t]], 
            Times[ 0.41349667156634429, 
              c[ 40][ t]], 
            Times[ 0.50455115242710469, 
              c[ 41][ t]], 
            Times[ 0.59356153372868092, 
              c[ 42][ t]], 
            Times[ 0.67835603854706361, 
              c[ 43][ t]], 
            Times[ 0.75682672864065692, 
              c[ 44][ t]], 
            Times[ 0.82699334313268846, 
              c[ 45][ t]], 
            Times[ 0.88706379305918392, 
              c[ 46][ t]], 
            Times[ 0.93548928378863916, 
              c[ 47][ t]], 
            Times[ 0.9710122092317629, 
              c[ 48][ t]], 
            Times[ 0.99270519960720693, 
              c[ 49][ t]], 
            Times[ 55.831135561607532, 
              c[ 50][ t]], 
            Times[ 0.99270519960720671, 
              c[ 51][ t]], 
            Times[ 0.9710122092317629, 
              c[ 52][ t]], 
            Times[ 0.93548928378863916, 
              c[ 53][ t]], 
            Times[ 0.88706379305918348, 
              c[ 54][ t]], 
            Times[ 0.82699334313268802, 
              c[ 55][ t]], 
            Times[ 0.75682672864065692, 
              c[ 56][ t]], 
            Times[ 0.67835603854706272, 
              c[ 57][ t]], 
            Times[ 0.59356153372868015, 
              c[ 58][ t]], 
            Times[ 0.50455115242710469, 
              c[ 59][ t]], 
            Times[ 0.41349667156634362, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "51", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[51]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.040909552899494966`\)\ \(c[\(-60\)]\)[t] - 
            0.037590606506031236`\ \(c[\(-59\)]\)[t] - 
            0.032552799745291155`\ \(c[\(-58\)]\)[t] - 
            0.02598581343857328`\ \(c[\(-57\)]\)[t] - 
            0.018149760920219783`\ \(c[\(-56\)]\)[t] - 
            0.009365143392520679`\ \(c[\(-55\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-54\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-53\)]\)[t] + 
            0.018854606004500233`\ \(c[\(-52\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-51\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-50\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-49\)]\)[t] + 
            0.045868286584282256`\ \(c[\(-48\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-47\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-46\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-45\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-44\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-43\)]\)[t] + 
            0.030177073670601236`\ \(c[\(-42\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-41\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-40\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-39\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-38\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-37\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-36\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-35\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-34\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-33\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-32\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-31\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-30\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-29\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-28\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-27\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-26\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-25\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-24\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-23\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-22\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-21\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-20\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-19\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-18\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-17\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-16\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-15\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-14\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-13\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-12\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-11\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-10\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-9\)]\)[t] - 
            0.016825511857749262`\ \(c[\(-8\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-7\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-6\)]\)[t] - 
            0.0633616995042274`\ \(c[\(-5\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-4\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-3\)]\)[t] - 
            0.08959419377036684`\ \(c[\(-2\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-1\)]\)[t] - 
            0.0890384386636067`\ \(c[0]\)[t] - 
            0.08269933431326881`\ \(c[1]\)[t] - 
            0.07241337086197412`\ \(c[2]\)[t] - 
            0.05846808023678991`\ \(c[3]\)[t] - 
            0.04131966847794737`\ \(c[4]\)[t] - 
            0.02158054781754788`\ \(c[5]\)[t] + 
            3.8981718325193755`*^-17\ \(c[6]\)[t] + 
            0.022561481809254675`\ \(c[7]\)[t] + 
            0.0451633585689193`\ \(c[8]\)[t] + 
            0.06682066312775997`\ \(c[9]\)[t] + 
            0.08654280907894475`\ \(c[10]\)[t] + 
            0.10337416789158595`\ \(c[11]\)[t] + 
            0.11643488132933186`\ \(c[12]\)[t] + 
            0.12496032289024847`\ \(c[13]\)[t] + 
            0.12833762891430925`\ \(c[14]\)[t] + 
            0.12613778810677614`\ \(c[15]\)[t] + 
            0.1181419061618126`\ \(c[16]\)[t] + 
            0.10436044624225692`\ \(c[17]\)[t] + 
            0.0850444803444217`\ \(c[18]\)[t] + 
            0.06068826307698522`\ \(c[19]\)[t] + 
            0.03202274837442603`\ \(c[20]\)[t] - 
            3.898171832519376`*^-17\ \(c[21]\)[t] - 
            0.034231213779558796`\ \(c[22]\)[t] - 
            0.06935801494512592`\ \(c[23]\)[t] - 
            0.10394325375429328`\ \(c[24]\)[t] - 
            0.1364713527783359`\ \(c[25]\)[t] - 
            0.1653986686265376`\ \(c[26]\)[t] - 
            0.18920668216016426`\ \(c[27]\)[t] - 
            0.20645618564475834`\ \(c[28]\)[t] - 
            0.21584055771952013`\ \(c[29]\)[t] - 
            0.21623620818304484`\ \(c[30]\)[t] - 
            0.20674833578317206`\ \(c[31]\)[t] - 
            0.18675027222298607`\ \(c[32]\)[t] - 
            0.15591488063143982`\ \(c[33]\)[t] - 
            0.11423673049785459`\ \(c[34]\)[t] - 
            0.062044074975450475`\ \(c[35]\)[t] + 
            3.898171832519376`*^-17\ \(c[36]\)[t] + 
            0.07090751425765746`\ \(c[37]\)[t] + 
            0.14938649372796345`\ \(c[38]\)[t] + 
            0.23387232094715985`\ \(c[39]\)[t] + 
            0.32256865202152113`\ \(c[40]\)[t] + 
            0.4134966715663436`\ \(c[41]\)[t] + 
            0.5045511524271047`\ \(c[42]\)[t] + 
            0.5935615337286801`\ \(c[43]\)[t] + 
            0.6783560385470627`\ \(c[44]\)[t] + 
            0.7568267286406569`\ \(c[45]\)[t] + 
            0.826993343132688`\ \(c[46]\)[t] + 
            0.8870637930591835`\ \(c[47]\)[t] + 
            0.9354892837886392`\ \(c[48]\)[t] + 
            0.9710122092317629`\ \(c[49]\)[t] + 
            0.9927051996072067`\ \(c[50]\)[t] + 
            58.04631343829649`\ \(c[51]\)[t] + 
            0.9927051996072069`\ \(c[52]\)[t] + 
            0.9710122092317629`\ \(c[53]\)[t] + 
            0.9354892837886392`\ \(c[54]\)[t] + 
            0.8870637930591839`\ \(c[55]\)[t] + 
            0.8269933431326885`\ \(c[56]\)[t] + 
            0.7568267286406569`\ \(c[57]\)[t] + 
            0.6783560385470636`\ \(c[58]\)[t] + 
            0.5935615337286809`\ \(c[59]\)[t] + 
            0.5045511524271047`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 51, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 51]][ t]], 
          Plus[ 
            Times[ -0.040909552899494966, 
              c[ -60][ t]], 
            Times[ -0.037590606506031236, 
              c[ -59][ t]], 
            Times[ -0.032552799745291155, 
              c[ -58][ t]], 
            Times[ -0.025985813438573278, 
              c[ -57][ t]], 
            Times[ -0.018149760920219783, 
              c[ -56][ t]], 
            Times[ -0.0093651433925206785, 
              c[ -55][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -54][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -53][ t]], 
            Times[ 0.018854606004500233, 
              c[ -52][ t]], 
            Times[ 0.027514390699665887, 
              c[ -51][ t]], 
            Times[ 0.035131239329076656, 
              c[ -50][ t]], 
            Times[ 0.041349667156634483, 
              c[ -49][ t]], 
            Times[ 0.045868286584282256, 
              c[ -48][ t]], 
            Times[ 0.048454002753361682, 
              c[ -47][ t]], 
            Times[ 0.04895352855494272, 
              c[ -46][ t]], 
            Times[ 0.047301670540041058, 
              c[ -45][ t]], 
            Times[ 0.043525965428036162, 
              c[ -44][ t]], 
            Times[ 0.03774739544932687, 
              c[ -43][ t]], 
            Times[ 0.030177073670601236, 
              c[ -42][ t]], 
            Times[ 0.021108961070255627, 
              c[ -41][ t]], 
            Times[ 0.010908848347331966, 
              c[ -40][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -39][ t]], 
            Times[ -0.011153991006822649, 
              c[ -38][ t]], 
            Times[ -0.022068459300722043, 
              c[ -37][ t]], 
            Times[ -0.032258251165125519, 
              c[ -36][ t]], 
            Times[ -0.041258781072520248, 
              c[ -35][ t]], 
            Times[ -0.048646667243099281, 
              c[ -34][ t]], 
            Times[ -0.054059052045761224, 
              c[ -33][ t]], 
            Times[ -0.057210750238908967, 
              c[ -32][ t]], 
            Times[ -0.057908442314993203, 
              c[ -31][ t]], 
            Times[ -0.056061239158567186, 
              c[ -30][ t]], 
            Times[ -0.05168708394579296, 
              c[ -29][ t]], 
            Times[ -0.044914622433376419, 
              c[ -28][ t]], 
            Times[ -0.035980357068793781, 
              c[ -27][ t]], 
            Times[ -0.025221096343682053, 
              c[ -26][ t]], 
            Times[ -0.013061910521147383, 
              c[ -25][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -24][ t]], 
            Times[ 0.013414935129827233, 
              c[ -23][ t]], 
            Times[ 0.026603074225527826, 
              c[ -22][ t]], 
            Times[ 0.03897872015785999, 
              c[ -21][ t]], 
            Times[ 0.049975424961080865, 
              c[ -20][ t]], 
            Times[ 0.059070953080906326, 
              c[ -19][ t]], 
            Times[ 0.065811019881796273, 
              c[ -18][ t]], 
            Times[ 0.069830768673962415, 
              c[ -17][ t]], 
            Times[ 0.070873018952678238, 
              c[ -16][ t]], 
            Times[ 0.068802429876423349, 
              c[ -15][ t]], 
            Times[ 0.063614872548668253, 
              c[ -14][ t]], 
            Times[ 0.055441487066198933, 
              c[ -13][ t]], 
            Times[ 0.044547108751839919, 
              c[ -12][ t]], 
            Times[ 0.031322974491347078, 
              c[ -11][ t]], 
            Times[ 0.016273855731265604, 
              c[ -10][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -9][ t]], 
            Times[ -0.016825511857749262, 
              c[ -8][ t]], 
            Times[ -0.033483179628681567, 
              c[ -7][ t]], 
            Times[ -0.049236278094138941, 
              c[ -6][ t]], 
            Times[ -0.063361699504227403, 
              c[ -5][ t]], 
            Times[ -0.075181213012062598, 
              c[ -4][ t]], 
            Times[ -0.084091858737850814, 
              c[ -3][ t]], 
            Times[ -0.089594193770366842, 
              c[ -2][ t]], 
            Times[ -0.091317159035181589, 
              c[ -1][ t]], 
            Times[ -0.089038438663606695, 
              c[ 0][ t]], 
            Times[ -0.082699334313268813, 
              c[ 1][ t]], 
            Times[ -0.072413370861974122, 
              c[ 2][ t]], 
            Times[ -0.058468080236789913, 
              c[ 3][ t]], 
            Times[ -0.041319668477947373, 
              c[ 4][ t]], 
            Times[ -0.021580547817547879, 
              c[ 5][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 6][ t]], 
            Times[ 0.022561481809254675, 
              c[ 7][ t]], 
            Times[ 0.045163358568919301, 
              c[ 8][ t]], 
            Times[ 0.066820663127759972, 
              c[ 9][ t]], 
            Times[ 0.086542809078944752, 
              c[ 10][ t]], 
            Times[ 0.10337416789158595, 
              c[ 11][ t]], 
            Times[ 0.11643488132933186, 
              c[ 12][ t]], 
            Times[ 0.12496032289024847, 
              c[ 13][ t]], 
            Times[ 0.12833762891430925, 
              c[ 14][ t]], 
            Times[ 0.12613778810677614, 
              c[ 15][ t]], 
            Times[ 0.1181419061618126, 
              c[ 16][ t]], 
            Times[ 0.10436044624225692, 
              c[ 17][ t]], 
            Times[ 0.085044480344421705, 
              c[ 18][ t]], 
            Times[ 0.060688263076985223, 
              c[ 19][ t]], 
            Times[ 0.032022748374426029, 
              c[ 20][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 21][ t]], 
            Times[ -0.034231213779558796, 
              c[ 22][ t]], 
            Times[ -0.069358014945125918, 
              c[ 23][ t]], 
            Times[ -0.10394325375429328, 
              c[ 24][ t]], 
            Times[ -0.13647135277833591, 
              c[ 25][ t]], 
            Times[ -0.1653986686265376, 
              c[ 26][ t]], 
            Times[ -0.18920668216016426, 
              c[ 27][ t]], 
            Times[ -0.20645618564475834, 
              c[ 28][ t]], 
            Times[ -0.21584055771952013, 
              c[ 29][ t]], 
            Times[ -0.21623620818304484, 
              c[ 30][ t]], 
            Times[ -0.20674833578317206, 
              c[ 31][ t]], 
            Times[ -0.18675027222298607, 
              c[ 32][ t]], 
            Times[ -0.15591488063143982, 
              c[ 33][ t]], 
            Times[ -0.11423673049785459, 
              c[ 34][ t]], 
            Times[ -0.062044074975450475, 
              c[ 35][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 36][ t]], 
            Times[ 0.070907514257657456, 
              c[ 37][ t]], 
            Times[ 0.14938649372796345, 
              c[ 38][ t]], 
            Times[ 0.23387232094715985, 
              c[ 39][ t]], 
            Times[ 0.32256865202152113, 
              c[ 40][ t]], 
            Times[ 0.41349667156634362, 
              c[ 41][ t]], 
            Times[ 0.50455115242710469, 
              c[ 42][ t]], 
            Times[ 0.59356153372868015, 
              c[ 43][ t]], 
            Times[ 0.67835603854706272, 
              c[ 44][ t]], 
            Times[ 0.75682672864065692, 
              c[ 45][ t]], 
            Times[ 0.82699334313268802, 
              c[ 46][ t]], 
            Times[ 0.88706379305918348, 
              c[ 47][ t]], 
            Times[ 0.93548928378863916, 
              c[ 48][ t]], 
            Times[ 0.9710122092317629, 
              c[ 49][ t]], 
            Times[ 0.99270519960720671, 
              c[ 50][ t]], 
            Times[ 58.046313438296487, 
              c[ 51][ t]], 
            Times[ 0.99270519960720693, 
              c[ 52][ t]], 
            Times[ 0.9710122092317629, 
              c[ 53][ t]], 
            Times[ 0.93548928378863916, 
              c[ 54][ t]], 
            Times[ 0.88706379305918392, 
              c[ 55][ t]], 
            Times[ 0.82699334313268846, 
              c[ 56][ t]], 
            Times[ 0.75682672864065692, 
              c[ 57][ t]], 
            Times[ 0.67835603854706361, 
              c[ 58][ t]], 
            Times[ 0.59356153372868092, 
              c[ 59][ t]], 
            Times[ 0.50455115242710469, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "52", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[52]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.04239725240919144`\)\ \(c[\(-60\)]\)[t] - 
            0.040909552899494925`\ \(c[\(-59\)]\)[t] - 
            0.037590606506031236`\ \(c[\(-58\)]\)[t] - 
            0.032552799745291155`\ \(c[\(-57\)]\)[t] - 
            0.02598581343857328`\ \(c[\(-56\)]\)[t] - 
            0.018149760920219783`\ \(c[\(-55\)]\)[t] - 
            0.009365143392520679`\ \(c[\(-54\)]\)[t] + 
            2.0053370214556287`*^-16\ \(c[\(-53\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-52\)]\)[t] + 
            0.018854606004500233`\ \(c[\(-51\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-50\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-49\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-48\)]\)[t] + 
            0.04586828658428231`\ \(c[\(-47\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-46\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-45\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-44\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-43\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-42\)]\)[t] + 
            0.030177073670601094`\ \(c[\(-41\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-40\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-39\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-38\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-37\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-36\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-35\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-34\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-33\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-32\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-31\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-30\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-29\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-28\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-27\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-26\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-25\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-24\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-23\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-22\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-21\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-20\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-19\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-18\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-17\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-16\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-15\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-14\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-13\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-12\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-11\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-10\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-9\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-8\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-7\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-6\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-5\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-4\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-3\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-2\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-1\)]\)[t] - 
            0.09131715903518159`\ \(c[0]\)[t] - 
            0.0890384386636067`\ \(c[1]\)[t] - 
            0.08269933431326874`\ \(c[2]\)[t] - 
            0.07241337086197412`\ \(c[3]\)[t] - 
            0.05846808023678991`\ \(c[4]\)[t] - 
            0.04131966847794722`\ \(c[5]\)[t] - 
            0.02158054781754788`\ \(c[6]\)[t] + 
            3.8981718325193755`*^-17\ \(c[7]\)[t] + 
            0.02256148180925487`\ \(c[8]\)[t] + 
            0.0451633585689193`\ \(c[9]\)[t] + 
            0.06682066312775997`\ \(c[10]\)[t] + 
            0.08654280907894489`\ \(c[11]\)[t] + 
            0.10337416789158609`\ \(c[12]\)[t] + 
            0.11643488132933186`\ \(c[13]\)[t] + 
            0.12496032289024853`\ \(c[14]\)[t] + 
            0.12833762891430928`\ \(c[15]\)[t] + 
            0.12613778810677614`\ \(c[16]\)[t] + 
            0.11814190616181255`\ \(c[17]\)[t] + 
            0.10436044624225685`\ \(c[18]\)[t] + 
            0.0850444803444217`\ \(c[19]\)[t] + 
            0.060688263076985105`\ \(c[20]\)[t] + 
            0.032022748374425904`\ \(c[21]\)[t] - 
            3.898171832519376`*^-17\ \(c[22]\)[t] - 
            0.03423121377955895`\ \(c[23]\)[t] - 
            0.06935801494512607`\ \(c[24]\)[t] - 
            0.10394325375429328`\ \(c[25]\)[t] - 
            0.13647135277833605`\ \(c[26]\)[t] - 
            0.1653986686265377`\ \(c[27]\)[t] - 
            0.18920668216016426`\ \(c[28]\)[t] - 
            0.20645618564475843`\ \(c[29]\)[t] - 
            0.21584055771952015`\ \(c[30]\)[t] - 
            0.21623620818304484`\ \(c[31]\)[t] - 
            0.206748335783172`\ \(c[32]\)[t] - 
            0.18675027222298593`\ \(c[33]\)[t] - 
            0.15591488063143982`\ \(c[34]\)[t] - 
            0.11423673049785436`\ \(c[35]\)[t] - 
            0.06204407497545024`\ \(c[36]\)[t] + 
            3.898171832519376`*^-17\ \(c[37]\)[t] + 
            0.07090751425765777`\ \(c[38]\)[t] + 
            0.14938649372796384`\ \(c[39]\)[t] + 
            0.23387232094715985`\ \(c[40]\)[t] + 
            0.32256865202152113`\ \(c[41]\)[t] + 
            0.4134966715663443`\ \(c[42]\)[t] + 
            0.5045511524271047`\ \(c[43]\)[t] + 
            0.5935615337286801`\ \(c[44]\)[t] + 
            0.6783560385470636`\ \(c[45]\)[t] + 
            0.7568267286406569`\ \(c[46]\)[t] + 
            0.826993343132688`\ \(c[47]\)[t] + 
            0.8870637930591839`\ \(c[48]\)[t] + 
            0.9354892837886392`\ \(c[49]\)[t] + 
            0.9710122092317629`\ \(c[50]\)[t] + 
            0.9927051996072069`\ \(c[51]\)[t] + 
            60.305356223434714`\ \(c[52]\)[t] + 
            0.9927051996072069`\ \(c[53]\)[t] + 
            0.9710122092317629`\ \(c[54]\)[t] + 
            0.9354892837886392`\ \(c[55]\)[t] + 
            0.8870637930591839`\ \(c[56]\)[t] + 
            0.826993343132688`\ \(c[57]\)[t] + 
            0.7568267286406569`\ \(c[58]\)[t] + 
            0.6783560385470636`\ \(c[59]\)[t] + 
            0.5935615337286801`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 52, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 52]][ t]], 
          Plus[ 
            Times[ -0.042397252409191441, 
              c[ -60][ t]], 
            Times[ -0.040909552899494925, 
              c[ -59][ t]], 
            Times[ -0.037590606506031236, 
              c[ -58][ t]], 
            Times[ -0.032552799745291155, 
              c[ -57][ t]], 
            Times[ -0.025985813438573278, 
              c[ -56][ t]], 
            Times[ -0.018149760920219783, 
              c[ -55][ t]], 
            Times[ -0.0093651433925206785, 
              c[ -54][ t]], 
            Times[ 2.0053370214556287*^-16, 
              c[ -53][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -52][ t]], 
            Times[ 0.018854606004500233, 
              c[ -51][ t]], 
            Times[ 0.027514390699665887, 
              c[ -50][ t]], 
            Times[ 0.035131239329076656, 
              c[ -49][ t]], 
            Times[ 0.041349667156634483, 
              c[ -48][ t]], 
            Times[ 0.045868286584282311, 
              c[ -47][ t]], 
            Times[ 0.048454002753361682, 
              c[ -46][ t]], 
            Times[ 0.04895352855494272, 
              c[ -45][ t]], 
            Times[ 0.047301670540041058, 
              c[ -44][ t]], 
            Times[ 0.043525965428036162, 
              c[ -43][ t]], 
            Times[ 0.03774739544932687, 
              c[ -42][ t]], 
            Times[ 0.030177073670601094, 
              c[ -41][ t]], 
            Times[ 0.021108961070255627, 
              c[ -40][ t]], 
            Times[ 0.010908848347331966, 
              c[ -39][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -38][ t]], 
            Times[ -0.011153991006822649, 
              c[ -37][ t]], 
            Times[ -0.022068459300722043, 
              c[ -36][ t]], 
            Times[ -0.032258251165125519, 
              c[ -35][ t]], 
            Times[ -0.041258781072520248, 
              c[ -34][ t]], 
            Times[ -0.048646667243099281, 
              c[ -33][ t]], 
            Times[ -0.054059052045761224, 
              c[ -32][ t]], 
            Times[ -0.057210750238908967, 
              c[ -31][ t]], 
            Times[ -0.057908442314993203, 
              c[ -30][ t]], 
            Times[ -0.056061239158567186, 
              c[ -29][ t]], 
            Times[ -0.05168708394579296, 
              c[ -28][ t]], 
            Times[ -0.044914622433376419, 
              c[ -27][ t]], 
            Times[ -0.035980357068793781, 
              c[ -26][ t]], 
            Times[ -0.025221096343682053, 
              c[ -25][ t]], 
            Times[ -0.013061910521147383, 
              c[ -24][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -23][ t]], 
            Times[ 0.013414935129827233, 
              c[ -22][ t]], 
            Times[ 0.026603074225527826, 
              c[ -21][ t]], 
            Times[ 0.03897872015785999, 
              c[ -20][ t]], 
            Times[ 0.049975424961080865, 
              c[ -19][ t]], 
            Times[ 0.059070953080906326, 
              c[ -18][ t]], 
            Times[ 0.065811019881796273, 
              c[ -17][ t]], 
            Times[ 0.069830768673962415, 
              c[ -16][ t]], 
            Times[ 0.070873018952678238, 
              c[ -15][ t]], 
            Times[ 0.068802429876423349, 
              c[ -14][ t]], 
            Times[ 0.063614872548668253, 
              c[ -13][ t]], 
            Times[ 0.055441487066198933, 
              c[ -12][ t]], 
            Times[ 0.044547108751839919, 
              c[ -11][ t]], 
            Times[ 0.031322974491347078, 
              c[ -10][ t]], 
            Times[ 0.016273855731265604, 
              c[ -9][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -8][ t]], 
            Times[ -0.016825511857749401, 
              c[ -7][ t]], 
            Times[ -0.033483179628681567, 
              c[ -6][ t]], 
            Times[ -0.049236278094138941, 
              c[ -5][ t]], 
            Times[ -0.063361699504227528, 
              c[ -4][ t]], 
            Times[ -0.075181213012062598, 
              c[ -3][ t]], 
            Times[ -0.084091858737850814, 
              c[ -2][ t]], 
            Times[ -0.089594193770366884, 
              c[ -1][ t]], 
            Times[ -0.091317159035181589, 
              c[ 0][ t]], 
            Times[ -0.089038438663606695, 
              c[ 1][ t]], 
            Times[ -0.082699334313268744, 
              c[ 2][ t]], 
            Times[ -0.072413370861974122, 
              c[ 3][ t]], 
            Times[ -0.058468080236789913, 
              c[ 4][ t]], 
            Times[ -0.04131966847794722, 
              c[ 5][ t]], 
            Times[ -0.021580547817547879, 
              c[ 6][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 7][ t]], 
            Times[ 0.022561481809254869, 
              c[ 8][ t]], 
            Times[ 0.045163358568919301, 
              c[ 9][ t]], 
            Times[ 0.066820663127759972, 
              c[ 10][ t]], 
            Times[ 0.086542809078944891, 
              c[ 11][ t]], 
            Times[ 0.10337416789158609, 
              c[ 12][ t]], 
            Times[ 0.11643488132933186, 
              c[ 13][ t]], 
            Times[ 0.12496032289024853, 
              c[ 14][ t]], 
            Times[ 0.12833762891430928, 
              c[ 15][ t]], 
            Times[ 0.12613778810677614, 
              c[ 16][ t]], 
            Times[ 0.11814190616181255, 
              c[ 17][ t]], 
            Times[ 0.10436044624225685, 
              c[ 18][ t]], 
            Times[ 0.085044480344421705, 
              c[ 19][ t]], 
            Times[ 0.060688263076985105, 
              c[ 20][ t]], 
            Times[ 0.032022748374425904, 
              c[ 21][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 22][ t]], 
            Times[ -0.034231213779558949, 
              c[ 23][ t]], 
            Times[ -0.06935801494512607, 
              c[ 24][ t]], 
            Times[ -0.10394325375429328, 
              c[ 25][ t]], 
            Times[ -0.13647135277833605, 
              c[ 26][ t]], 
            Times[ -0.16539866862653771, 
              c[ 27][ t]], 
            Times[ -0.18920668216016426, 
              c[ 28][ t]], 
            Times[ -0.20645618564475843, 
              c[ 29][ t]], 
            Times[ -0.21584055771952015, 
              c[ 30][ t]], 
            Times[ -0.21623620818304484, 
              c[ 31][ t]], 
            Times[ -0.206748335783172, 
              c[ 32][ t]], 
            Times[ -0.18675027222298593, 
              c[ 33][ t]], 
            Times[ -0.15591488063143982, 
              c[ 34][ t]], 
            Times[ -0.11423673049785436, 
              c[ 35][ t]], 
            Times[ -0.062044074975450239, 
              c[ 36][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 37][ t]], 
            Times[ 0.070907514257657775, 
              c[ 38][ t]], 
            Times[ 0.14938649372796384, 
              c[ 39][ t]], 
            Times[ 0.23387232094715985, 
              c[ 40][ t]], 
            Times[ 0.32256865202152113, 
              c[ 41][ t]], 
            Times[ 0.41349667156634429, 
              c[ 42][ t]], 
            Times[ 0.50455115242710469, 
              c[ 43][ t]], 
            Times[ 0.59356153372868015, 
              c[ 44][ t]], 
            Times[ 0.67835603854706361, 
              c[ 45][ t]], 
            Times[ 0.75682672864065692, 
              c[ 46][ t]], 
            Times[ 0.82699334313268802, 
              c[ 47][ t]], 
            Times[ 0.88706379305918392, 
              c[ 48][ t]], 
            Times[ 0.93548928378863916, 
              c[ 49][ t]], 
            Times[ 0.9710122092317629, 
              c[ 50][ t]], 
            Times[ 0.99270519960720693, 
              c[ 51][ t]], 
            Times[ 60.305356223434714, 
              c[ 52][ t]], 
            Times[ 0.99270519960720693, 
              c[ 53][ t]], 
            Times[ 0.9710122092317629, 
              c[ 54][ t]], 
            Times[ 0.93548928378863916, 
              c[ 55][ t]], 
            Times[ 0.88706379305918392, 
              c[ 56][ t]], 
            Times[ 0.82699334313268802, 
              c[ 57][ t]], 
            Times[ 0.75682672864065692, 
              c[ 58][ t]], 
            Times[ 0.67835603854706361, 
              c[ 59][ t]], 
            Times[ 0.59356153372868015, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "53", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[53]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.042022055485216314`\)\ \(c[\(-60\)]\)[t] - 
            0.04239725240919144`\ \(c[\(-59\)]\)[t] - 
            0.040909552899494925`\ \(c[\(-58\)]\)[t] - 
            0.037590606506031236`\ \(c[\(-57\)]\)[t] - 
            0.03255279974529105`\ \(c[\(-56\)]\)[t] - 
            0.02598581343857328`\ \(c[\(-55\)]\)[t] - 
            0.018149760920219783`\ \(c[\(-54\)]\)[t] - 
            0.009365143392520679`\ \(c[\(-53\)]\)[t] + 
            2.0053370214556287`*^-16\ \(c[\(-52\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-51\)]\)[t] + 
            0.01885460600450039`\ \(c[\(-50\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-49\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-48\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-47\)]\)[t] + 
            0.04586828658428231`\ \(c[\(-46\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-45\)]\)[t] + 
            0.0489535285549427`\ \(c[\(-44\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-43\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-42\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-41\)]\)[t] + 
            0.030177073670601094`\ \(c[\(-40\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-39\)]\)[t] + 
            0.010908848347331785`\ \(c[\(-38\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-37\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-36\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-35\)]\)[t] - 
            0.03225825116512568`\ \(c[\(-34\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-33\)]\)[t] - 
            0.0486466672430994`\ \(c[\(-32\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-31\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-30\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-29\)]\)[t] - 
            0.05606123915856713`\ \(c[\(-28\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-27\)]\)[t] - 
            0.04491462243337629`\ \(c[\(-26\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-25\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-24\)]\)[t] - 
            0.013061910521147276`\ \(c[\(-23\)]\)[t] + 
            1.5206810699945212`*^-16\ \(c[\(-22\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-21\)]\)[t] + 
            0.026603074225527937`\ \(c[\(-20\)]\)[t] + 
            0.03897872015786009`\ \(c[\(-19\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-18\)]\)[t] + 
            0.0590709530809064`\ \(c[\(-17\)]\)[t] + 
            0.06581101988179631`\ \(c[\(-16\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-15\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-14\)]\)[t] + 
            0.06880242987642332`\ \(c[\(-13\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-12\)]\)[t] + 
            0.055441487066198857`\ \(c[\(-11\)]\)[t] + 
            0.044547108751839815`\ \(c[\(-10\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-9\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-8\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-7\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-6\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-5\)]\)[t] - 
            0.049236278094139066`\ \(c[\(-4\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-3\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-2\)]\)[t] - 
            0.08409185873785086`\ \(c[\(-1\)]\)[t] - 
            0.08959419377036688`\ \(c[0]\)[t] - 
            0.09131715903518159`\ \(c[1]\)[t] - 
            0.08903843866360665`\ \(c[2]\)[t] - 
            0.08269933431326874`\ \(c[3]\)[t] - 
            0.07241337086197412`\ \(c[4]\)[t] - 
            0.058468080236789774`\ \(c[5]\)[t] - 
            0.04131966847794722`\ \(c[6]\)[t] - 
            0.02158054781754788`\ \(c[7]\)[t] + 
            2.274590327822911`*^-16\ \(c[8]\)[t] + 
            0.02256148180925487`\ \(c[9]\)[t] + 
            0.0451633585689193`\ \(c[10]\)[t] + 
            0.06682066312775997`\ \(c[11]\)[t] + 
            0.08654280907894489`\ \(c[12]\)[t] + 
            0.10337416789158609`\ \(c[13]\)[t] + 
            0.11643488132933186`\ \(c[14]\)[t] + 
            0.12496032289024853`\ \(c[15]\)[t] + 
            0.12833762891430928`\ \(c[16]\)[t] + 
            0.12613778810677612`\ \(c[17]\)[t] + 
            0.11814190616181253`\ \(c[18]\)[t] + 
            0.10436044624225685`\ \(c[19]\)[t] + 
            0.08504448034442161`\ \(c[20]\)[t] + 
            0.060688263076985`\ \(c[21]\)[t] + 
            0.032022748374425904`\ \(c[22]\)[t] - 
            1.8033970416801674`*^-16\ \(c[23]\)[t] - 
            0.034231213779559094`\ \(c[24]\)[t] - 
            0.06935801494512607`\ \(c[25]\)[t] - 
            0.1039432537542934`\ \(c[26]\)[t] - 
            0.13647135277833616`\ \(c[27]\)[t] - 
            0.1653986686265377`\ \(c[28]\)[t] - 
            0.18920668216016434`\ \(c[29]\)[t] - 
            0.20645618564475848`\ \(c[30]\)[t] - 
            0.21584055771952015`\ \(c[31]\)[t] - 
            0.21623620818304481`\ \(c[32]\)[t] - 
            0.2067483357831719`\ \(c[33]\)[t] - 
            0.18675027222298593`\ \(c[34]\)[t] - 
            0.15591488063143966`\ \(c[35]\)[t] - 
            0.11423673049785416`\ \(c[36]\)[t] - 
            0.06204407497545024`\ \(c[37]\)[t] + 
            3.216976900108398`*^-16\ \(c[38]\)[t] + 
            0.0709075142576581`\ \(c[39]\)[t] + 
            0.14938649372796384`\ \(c[40]\)[t] + 
            0.23387232094715985`\ \(c[41]\)[t] + 
            0.3225686520215219`\ \(c[42]\)[t] + 
            0.4134966715663443`\ \(c[43]\)[t] + 
            0.5045511524271047`\ \(c[44]\)[t] + 
            0.5935615337286809`\ \(c[45]\)[t] + 
            0.6783560385470636`\ \(c[46]\)[t] + 
            0.7568267286406569`\ \(c[47]\)[t] + 
            0.8269933431326885`\ \(c[48]\)[t] + 
            0.8870637930591839`\ \(c[49]\)[t] + 
            0.9354892837886392`\ \(c[50]\)[t] + 
            0.9710122092317629`\ \(c[51]\)[t] + 
            0.9927051996072069`\ \(c[52]\)[t] + 
            62.60826391702222`\ \(c[53]\)[t] + 
            0.9927051996072067`\ \(c[54]\)[t] + 
            0.9710122092317629`\ \(c[55]\)[t] + 
            0.9354892837886392`\ \(c[56]\)[t] + 
            0.8870637930591835`\ \(c[57]\)[t] + 
            0.826993343132688`\ \(c[58]\)[t] + 
            0.7568267286406569`\ \(c[59]\)[t] + 
            0.6783560385470627`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 53, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 53]][ t]], 
          Plus[ 
            Times[ -0.042022055485216314, 
              c[ -60][ t]], 
            Times[ -0.042397252409191441, 
              c[ -59][ t]], 
            Times[ -0.040909552899494925, 
              c[ -58][ t]], 
            Times[ -0.037590606506031236, 
              c[ -57][ t]], 
            Times[ -0.032552799745291051, 
              c[ -56][ t]], 
            Times[ -0.025985813438573278, 
              c[ -55][ t]], 
            Times[ -0.018149760920219783, 
              c[ -54][ t]], 
            Times[ -0.0093651433925206785, 
              c[ -53][ t]], 
            Times[ 2.0053370214556287*^-16, 
              c[ -52][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -51][ t]], 
            Times[ 0.018854606004500389, 
              c[ -50][ t]], 
            Times[ 0.027514390699665887, 
              c[ -49][ t]], 
            Times[ 0.035131239329076656, 
              c[ -48][ t]], 
            Times[ 0.041349667156634483, 
              c[ -47][ t]], 
            Times[ 0.045868286584282311, 
              c[ -46][ t]], 
            Times[ 0.048454002753361682, 
              c[ -45][ t]], 
            Times[ 0.048953528554942699, 
              c[ -44][ t]], 
            Times[ 0.047301670540041058, 
              c[ -43][ t]], 
            Times[ 0.043525965428036162, 
              c[ -42][ t]], 
            Times[ 0.03774739544932687, 
              c[ -41][ t]], 
            Times[ 0.030177073670601094, 
              c[ -40][ t]], 
            Times[ 0.021108961070255627, 
              c[ -39][ t]], 
            Times[ 0.010908848347331785, 
              c[ -38][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -37][ t]], 
            Times[ -0.011153991006822649, 
              c[ -36][ t]], 
            Times[ -0.022068459300722043, 
              c[ -35][ t]], 
            Times[ -0.032258251165125679, 
              c[ -34][ t]], 
            Times[ -0.041258781072520248, 
              c[ -33][ t]], 
            Times[ -0.048646667243099399, 
              c[ -32][ t]], 
            Times[ -0.054059052045761224, 
              c[ -31][ t]], 
            Times[ -0.057210750238908967, 
              c[ -30][ t]], 
            Times[ -0.057908442314993203, 
              c[ -29][ t]], 
            Times[ -0.05606123915856713, 
              c[ -28][ t]], 
            Times[ -0.05168708394579296, 
              c[ -27][ t]], 
            Times[ -0.044914622433376288, 
              c[ -26][ t]], 
            Times[ -0.035980357068793781, 
              c[ -25][ t]], 
            Times[ -0.025221096343682053, 
              c[ -24][ t]], 
            Times[ -0.013061910521147276, 
              c[ -23][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ -22][ t]], 
            Times[ 0.013414935129827233, 
              c[ -21][ t]], 
            Times[ 0.026603074225527937, 
              c[ -20][ t]], 
            Times[ 0.038978720157860088, 
              c[ -19][ t]], 
            Times[ 0.049975424961080865, 
              c[ -18][ t]], 
            Times[ 0.059070953080906402, 
              c[ -17][ t]], 
            Times[ 0.065811019881796315, 
              c[ -16][ t]], 
            Times[ 0.069830768673962415, 
              c[ -15][ t]], 
            Times[ 0.070873018952678238, 
              c[ -14][ t]], 
            Times[ 0.068802429876423321, 
              c[ -13][ t]], 
            Times[ 0.063614872548668253, 
              c[ -12][ t]], 
            Times[ 0.055441487066198857, 
              c[ -11][ t]], 
            Times[ 0.044547108751839815, 
              c[ -10][ t]], 
            Times[ 0.031322974491347078, 
              c[ -9][ t]], 
            Times[ 0.016273855731265604, 
              c[ -8][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -7][ t]], 
            Times[ -0.016825511857749401, 
              c[ -6][ t]], 
            Times[ -0.033483179628681567, 
              c[ -5][ t]], 
            Times[ -0.049236278094139066, 
              c[ -4][ t]], 
            Times[ -0.063361699504227528, 
              c[ -3][ t]], 
            Times[ -0.075181213012062598, 
              c[ -2][ t]], 
            Times[ -0.084091858737850855, 
              c[ -1][ t]], 
            Times[ -0.089594193770366884, 
              c[ 0][ t]], 
            Times[ -0.091317159035181589, 
              c[ 1][ t]], 
            Times[ -0.089038438663606653, 
              c[ 2][ t]], 
            Times[ -0.082699334313268744, 
              c[ 3][ t]], 
            Times[ -0.072413370861974122, 
              c[ 4][ t]], 
            Times[ -0.058468080236789774, 
              c[ 5][ t]], 
            Times[ -0.04131966847794722, 
              c[ 6][ t]], 
            Times[ -0.021580547817547879, 
              c[ 7][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ 8][ t]], 
            Times[ 0.022561481809254869, 
              c[ 9][ t]], 
            Times[ 0.045163358568919301, 
              c[ 10][ t]], 
            Times[ 0.066820663127759972, 
              c[ 11][ t]], 
            Times[ 0.086542809078944891, 
              c[ 12][ t]], 
            Times[ 0.10337416789158609, 
              c[ 13][ t]], 
            Times[ 0.11643488132933186, 
              c[ 14][ t]], 
            Times[ 0.12496032289024853, 
              c[ 15][ t]], 
            Times[ 0.12833762891430928, 
              c[ 16][ t]], 
            Times[ 0.12613778810677612, 
              c[ 17][ t]], 
            Times[ 0.11814190616181253, 
              c[ 18][ t]], 
            Times[ 0.10436044624225685, 
              c[ 19][ t]], 
            Times[ 0.085044480344421608, 
              c[ 20][ t]], 
            Times[ 0.060688263076985001, 
              c[ 21][ t]], 
            Times[ 0.032022748374425904, 
              c[ 22][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 23][ t]], 
            Times[ -0.034231213779559094, 
              c[ 24][ t]], 
            Times[ -0.06935801494512607, 
              c[ 25][ t]], 
            Times[ -0.1039432537542934, 
              c[ 26][ t]], 
            Times[ -0.13647135277833616, 
              c[ 27][ t]], 
            Times[ -0.16539866862653771, 
              c[ 28][ t]], 
            Times[ -0.18920668216016434, 
              c[ 29][ t]], 
            Times[ -0.20645618564475848, 
              c[ 30][ t]], 
            Times[ -0.21584055771952015, 
              c[ 31][ t]], 
            Times[ -0.21623620818304481, 
              c[ 32][ t]], 
            Times[ -0.20674833578317189, 
              c[ 33][ t]], 
            Times[ -0.18675027222298593, 
              c[ 34][ t]], 
            Times[ -0.15591488063143966, 
              c[ 35][ t]], 
            Times[ -0.11423673049785416, 
              c[ 36][ t]], 
            Times[ -0.062044074975450239, 
              c[ 37][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ 38][ t]], 
            Times[ 0.070907514257658094, 
              c[ 39][ t]], 
            Times[ 0.14938649372796384, 
              c[ 40][ t]], 
            Times[ 0.23387232094715985, 
              c[ 41][ t]], 
            Times[ 0.32256865202152191, 
              c[ 42][ t]], 
            Times[ 0.41349667156634429, 
              c[ 43][ t]], 
            Times[ 0.50455115242710469, 
              c[ 44][ t]], 
            Times[ 0.59356153372868092, 
              c[ 45][ t]], 
            Times[ 0.67835603854706361, 
              c[ 46][ t]], 
            Times[ 0.75682672864065692, 
              c[ 47][ t]], 
            Times[ 0.82699334313268846, 
              c[ 48][ t]], 
            Times[ 0.88706379305918392, 
              c[ 49][ t]], 
            Times[ 0.93548928378863916, 
              c[ 50][ t]], 
            Times[ 0.9710122092317629, 
              c[ 51][ t]], 
            Times[ 0.99270519960720693, 
              c[ 52][ t]], 
            Times[ 62.608263917022221, 
              c[ 53][ t]], 
            Times[ 0.99270519960720671, 
              c[ 54][ t]], 
            Times[ 0.9710122092317629, 
              c[ 55][ t]], 
            Times[ 0.93548928378863916, 
              c[ 56][ t]], 
            Times[ 0.88706379305918348, 
              c[ 57][ t]], 
            Times[ 0.82699334313268802, 
              c[ 58][ t]], 
            Times[ 0.75682672864065692, 
              c[ 59][ t]], 
            Times[ 0.67835603854706272, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "54", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[54]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.039832985717929335`\)\ \(c[\(-60\)]\)[t] - 
            0.042022055485216314`\ \(c[\(-59\)]\)[t] - 
            0.04239725240919144`\ \(c[\(-58\)]\)[t] - 
            0.040909552899494966`\ \(c[\(-57\)]\)[t] - 
            0.037590606506031236`\ \(c[\(-56\)]\)[t] - 
            0.032552799745291155`\ \(c[\(-55\)]\)[t] - 
            0.02598581343857328`\ \(c[\(-54\)]\)[t] - 
            0.018149760920219783`\ \(c[\(-53\)]\)[t] - 
            0.009365143392520679`\ \(c[\(-52\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-51\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-50\)]\)[t] + 
            0.018854606004500233`\ \(c[\(-49\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-48\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-47\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-46\)]\)[t] + 
            0.045868286584282256`\ \(c[\(-45\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-44\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-43\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-42\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-41\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-40\)]\)[t] + 
            0.030177073670601236`\ \(c[\(-39\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-38\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-37\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-36\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-35\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-34\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-33\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-32\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-31\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-30\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-29\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-28\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-27\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-26\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-25\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-24\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-23\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-22\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-21\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-20\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-19\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-18\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-17\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-16\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-15\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-14\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-13\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-12\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-11\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-10\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-9\)]\)[t] + 
            0.0313229744913472`\ \(c[\(-8\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-7\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-6\)]\)[t] - 
            0.016825511857749262`\ \(c[\(-5\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-4\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-3\)]\)[t] - 
            0.0633616995042274`\ \(c[\(-2\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-1\)]\)[t] - 
            0.08409185873785081`\ \(c[0]\)[t] - 
            0.08959419377036684`\ \(c[1]\)[t] - 
            0.09131715903518159`\ \(c[2]\)[t] - 
            0.0890384386636067`\ \(c[3]\)[t] - 
            0.08269933431326881`\ \(c[4]\)[t] - 
            0.07241337086197412`\ \(c[5]\)[t] - 
            0.05846808023678991`\ \(c[6]\)[t] - 
            0.04131966847794737`\ \(c[7]\)[t] - 
            0.02158054781754788`\ \(c[8]\)[t] + 
            3.8981718325193755`*^-17\ \(c[9]\)[t] + 
            0.022561481809254675`\ \(c[10]\)[t] + 
            0.045163358568919114`\ \(c[11]\)[t] + 
            0.06682066312775997`\ \(c[12]\)[t] + 
            0.08654280907894475`\ \(c[13]\)[t] + 
            0.10337416789158595`\ \(c[14]\)[t] + 
            0.11643488132933186`\ \(c[15]\)[t] + 
            0.12496032289024847`\ \(c[16]\)[t] + 
            0.12833762891430925`\ \(c[17]\)[t] + 
            0.12613778810677614`\ \(c[18]\)[t] + 
            0.1181419061618126`\ \(c[19]\)[t] + 
            0.10436044624225692`\ \(c[20]\)[t] + 
            0.0850444803444217`\ \(c[21]\)[t] + 
            0.06068826307698522`\ \(c[22]\)[t] + 
            0.03202274837442603`\ \(c[23]\)[t] - 
            3.898171832519376`*^-17\ \(c[24]\)[t] - 
            0.034231213779558796`\ \(c[25]\)[t] - 
            0.06935801494512592`\ \(c[26]\)[t] - 
            0.10394325375429328`\ \(c[27]\)[t] - 
            0.1364713527783359`\ \(c[28]\)[t] - 
            0.1653986686265376`\ \(c[29]\)[t] - 
            0.18920668216016426`\ \(c[30]\)[t] - 
            0.20645618564475834`\ \(c[31]\)[t] - 
            0.21584055771952013`\ \(c[32]\)[t] - 
            0.21623620818304484`\ \(c[33]\)[t] - 
            0.20674833578317206`\ \(c[34]\)[t] - 
            0.18675027222298607`\ \(c[35]\)[t] - 
            0.15591488063143982`\ \(c[36]\)[t] - 
            0.11423673049785459`\ \(c[37]\)[t] - 
            0.062044074975450475`\ \(c[38]\)[t] + 
            3.898171832519376`*^-17\ \(c[39]\)[t] + 
            0.07090751425765746`\ \(c[40]\)[t] + 
            0.14938649372796314`\ \(c[41]\)[t] + 
            0.23387232094715985`\ \(c[42]\)[t] + 
            0.32256865202152113`\ \(c[43]\)[t] + 
            0.4134966715663436`\ \(c[44]\)[t] + 
            0.5045511524271047`\ \(c[45]\)[t] + 
            0.5935615337286801`\ \(c[46]\)[t] + 
            0.6783560385470627`\ \(c[47]\)[t] + 
            0.7568267286406569`\ \(c[48]\)[t] + 
            0.826993343132688`\ \(c[49]\)[t] + 
            0.8870637930591835`\ \(c[50]\)[t] + 
            0.9354892837886392`\ \(c[51]\)[t] + 
            0.9710122092317629`\ \(c[52]\)[t] + 
            0.9927051996072067`\ \(c[53]\)[t] + 
            64.95503651905904`\ \(c[54]\)[t] + 
            0.9927051996072069`\ \(c[55]\)[t] + 
            0.9710122092317629`\ \(c[56]\)[t] + 
            0.9354892837886392`\ \(c[57]\)[t] + 
            0.8870637930591839`\ \(c[58]\)[t] + 
            0.8269933431326885`\ \(c[59]\)[t] + 
            0.7568267286406569`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 54, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 54]][ t]], 
          Plus[ 
            Times[ -0.039832985717929335, 
              c[ -60][ t]], 
            Times[ -0.042022055485216314, 
              c[ -59][ t]], 
            Times[ -0.042397252409191441, 
              c[ -58][ t]], 
            Times[ -0.040909552899494966, 
              c[ -57][ t]], 
            Times[ -0.037590606506031236, 
              c[ -56][ t]], 
            Times[ -0.032552799745291155, 
              c[ -55][ t]], 
            Times[ -0.025985813438573278, 
              c[ -54][ t]], 
            Times[ -0.018149760920219783, 
              c[ -53][ t]], 
            Times[ -0.0093651433925206785, 
              c[ -52][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -51][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -50][ t]], 
            Times[ 0.018854606004500233, 
              c[ -49][ t]], 
            Times[ 0.027514390699665887, 
              c[ -48][ t]], 
            Times[ 0.035131239329076656, 
              c[ -47][ t]], 
            Times[ 0.041349667156634483, 
              c[ -46][ t]], 
            Times[ 0.045868286584282256, 
              c[ -45][ t]], 
            Times[ 0.048454002753361682, 
              c[ -44][ t]], 
            Times[ 0.04895352855494272, 
              c[ -43][ t]], 
            Times[ 0.047301670540041058, 
              c[ -42][ t]], 
            Times[ 0.043525965428036162, 
              c[ -41][ t]], 
            Times[ 0.03774739544932687, 
              c[ -40][ t]], 
            Times[ 0.030177073670601236, 
              c[ -39][ t]], 
            Times[ 0.021108961070255627, 
              c[ -38][ t]], 
            Times[ 0.010908848347331966, 
              c[ -37][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -36][ t]], 
            Times[ -0.011153991006822649, 
              c[ -35][ t]], 
            Times[ -0.022068459300722043, 
              c[ -34][ t]], 
            Times[ -0.032258251165125519, 
              c[ -33][ t]], 
            Times[ -0.041258781072520248, 
              c[ -32][ t]], 
            Times[ -0.048646667243099281, 
              c[ -31][ t]], 
            Times[ -0.054059052045761224, 
              c[ -30][ t]], 
            Times[ -0.057210750238908967, 
              c[ -29][ t]], 
            Times[ -0.057908442314993203, 
              c[ -28][ t]], 
            Times[ -0.056061239158567186, 
              c[ -27][ t]], 
            Times[ -0.05168708394579296, 
              c[ -26][ t]], 
            Times[ -0.044914622433376419, 
              c[ -25][ t]], 
            Times[ -0.035980357068793781, 
              c[ -24][ t]], 
            Times[ -0.025221096343682053, 
              c[ -23][ t]], 
            Times[ -0.013061910521147383, 
              c[ -22][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -21][ t]], 
            Times[ 0.013414935129827233, 
              c[ -20][ t]], 
            Times[ 0.026603074225527826, 
              c[ -19][ t]], 
            Times[ 0.03897872015785999, 
              c[ -18][ t]], 
            Times[ 0.049975424961080865, 
              c[ -17][ t]], 
            Times[ 0.059070953080906326, 
              c[ -16][ t]], 
            Times[ 0.065811019881796273, 
              c[ -15][ t]], 
            Times[ 0.069830768673962415, 
              c[ -14][ t]], 
            Times[ 0.070873018952678238, 
              c[ -13][ t]], 
            Times[ 0.068802429876423349, 
              c[ -12][ t]], 
            Times[ 0.063614872548668253, 
              c[ -11][ t]], 
            Times[ 0.055441487066198933, 
              c[ -10][ t]], 
            Times[ 0.044547108751839919, 
              c[ -9][ t]], 
            Times[ 0.031322974491347202, 
              c[ -8][ t]], 
            Times[ 0.016273855731265604, 
              c[ -7][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -6][ t]], 
            Times[ -0.016825511857749262, 
              c[ -5][ t]], 
            Times[ -0.033483179628681567, 
              c[ -4][ t]], 
            Times[ -0.049236278094138941, 
              c[ -3][ t]], 
            Times[ -0.063361699504227403, 
              c[ -2][ t]], 
            Times[ -0.075181213012062598, 
              c[ -1][ t]], 
            Times[ -0.084091858737850814, 
              c[ 0][ t]], 
            Times[ -0.089594193770366842, 
              c[ 1][ t]], 
            Times[ -0.091317159035181589, 
              c[ 2][ t]], 
            Times[ -0.089038438663606695, 
              c[ 3][ t]], 
            Times[ -0.082699334313268813, 
              c[ 4][ t]], 
            Times[ -0.072413370861974122, 
              c[ 5][ t]], 
            Times[ -0.058468080236789913, 
              c[ 6][ t]], 
            Times[ -0.041319668477947373, 
              c[ 7][ t]], 
            Times[ -0.021580547817547879, 
              c[ 8][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 9][ t]], 
            Times[ 0.022561481809254675, 
              c[ 10][ t]], 
            Times[ 0.045163358568919114, 
              c[ 11][ t]], 
            Times[ 0.066820663127759972, 
              c[ 12][ t]], 
            Times[ 0.086542809078944752, 
              c[ 13][ t]], 
            Times[ 0.10337416789158595, 
              c[ 14][ t]], 
            Times[ 0.11643488132933186, 
              c[ 15][ t]], 
            Times[ 0.12496032289024847, 
              c[ 16][ t]], 
            Times[ 0.12833762891430925, 
              c[ 17][ t]], 
            Times[ 0.12613778810677614, 
              c[ 18][ t]], 
            Times[ 0.1181419061618126, 
              c[ 19][ t]], 
            Times[ 0.10436044624225692, 
              c[ 20][ t]], 
            Times[ 0.085044480344421705, 
              c[ 21][ t]], 
            Times[ 0.060688263076985223, 
              c[ 22][ t]], 
            Times[ 0.032022748374426029, 
              c[ 23][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 24][ t]], 
            Times[ -0.034231213779558796, 
              c[ 25][ t]], 
            Times[ -0.069358014945125918, 
              c[ 26][ t]], 
            Times[ -0.10394325375429328, 
              c[ 27][ t]], 
            Times[ -0.13647135277833591, 
              c[ 28][ t]], 
            Times[ -0.1653986686265376, 
              c[ 29][ t]], 
            Times[ -0.18920668216016426, 
              c[ 30][ t]], 
            Times[ -0.20645618564475834, 
              c[ 31][ t]], 
            Times[ -0.21584055771952013, 
              c[ 32][ t]], 
            Times[ -0.21623620818304484, 
              c[ 33][ t]], 
            Times[ -0.20674833578317206, 
              c[ 34][ t]], 
            Times[ -0.18675027222298607, 
              c[ 35][ t]], 
            Times[ -0.15591488063143982, 
              c[ 36][ t]], 
            Times[ -0.11423673049785459, 
              c[ 37][ t]], 
            Times[ -0.062044074975450475, 
              c[ 38][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 39][ t]], 
            Times[ 0.070907514257657456, 
              c[ 40][ t]], 
            Times[ 0.14938649372796314, 
              c[ 41][ t]], 
            Times[ 0.23387232094715985, 
              c[ 42][ t]], 
            Times[ 0.32256865202152113, 
              c[ 43][ t]], 
            Times[ 0.41349667156634362, 
              c[ 44][ t]], 
            Times[ 0.50455115242710469, 
              c[ 45][ t]], 
            Times[ 0.59356153372868015, 
              c[ 46][ t]], 
            Times[ 0.67835603854706272, 
              c[ 47][ t]], 
            Times[ 0.75682672864065692, 
              c[ 48][ t]], 
            Times[ 0.82699334313268802, 
              c[ 49][ t]], 
            Times[ 0.88706379305918348, 
              c[ 50][ t]], 
            Times[ 0.93548928378863916, 
              c[ 51][ t]], 
            Times[ 0.9710122092317629, 
              c[ 52][ t]], 
            Times[ 0.99270519960720671, 
              c[ 53][ t]], 
            Times[ 64.955036519059036, 
              c[ 54][ t]], 
            Times[ 0.99270519960720693, 
              c[ 55][ t]], 
            Times[ 0.9710122092317629, 
              c[ 56][ t]], 
            Times[ 0.93548928378863916, 
              c[ 57][ t]], 
            Times[ 0.88706379305918392, 
              c[ 58][ t]], 
            Times[ 0.82699334313268846, 
              c[ 59][ t]], 
            Times[ 0.75682672864065692, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "55", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[55]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.03595623231011687`\)\ \(c[\(-60\)]\)[t] - 
            0.039832985717929335`\ \(c[\(-59\)]\)[t] - 
            0.042022055485216314`\ \(c[\(-58\)]\)[t] - 
            0.04239725240919144`\ \(c[\(-57\)]\)[t] - 
            0.040909552899494925`\ \(c[\(-56\)]\)[t] - 
            0.037590606506031236`\ \(c[\(-55\)]\)[t] - 
            0.032552799745291155`\ \(c[\(-54\)]\)[t] - 
            0.02598581343857328`\ \(c[\(-53\)]\)[t] - 
            0.018149760920219783`\ \(c[\(-52\)]\)[t] - 
            0.009365143392520679`\ \(c[\(-51\)]\)[t] + 
            2.0053370214556287`*^-16\ \(c[\(-50\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-49\)]\)[t] + 
            0.018854606004500233`\ \(c[\(-48\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-47\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-46\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-45\)]\)[t] + 
            0.04586828658428231`\ \(c[\(-44\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-43\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-42\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-41\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-40\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-39\)]\)[t] + 
            0.030177073670601236`\ \(c[\(-38\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-37\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-36\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-35\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-34\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-33\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-32\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-31\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-30\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-29\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-28\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-27\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-26\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-25\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-24\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-23\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-22\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-21\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-20\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-19\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-18\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-17\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-16\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-15\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-14\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-13\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-12\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-11\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-10\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-9\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-8\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-7\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-6\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-5\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-4\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-3\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-2\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-1\)]\)[t] - 
            0.0751812130120626`\ \(c[0]\)[t] - 
            0.08409185873785081`\ \(c[1]\)[t] - 
            0.08959419377036688`\ \(c[2]\)[t] - 
            0.09131715903518159`\ \(c[3]\)[t] - 
            0.0890384386636067`\ \(c[4]\)[t] - 
            0.08269933431326874`\ \(c[5]\)[t] - 
            0.07241337086197412`\ \(c[6]\)[t] - 
            0.05846808023678991`\ \(c[7]\)[t] - 
            0.04131966847794722`\ \(c[8]\)[t] - 
            0.02158054781754788`\ \(c[9]\)[t] + 
            3.8981718325193755`*^-17\ \(c[10]\)[t] + 
            0.02256148180925487`\ \(c[11]\)[t] + 
            0.0451633585689193`\ \(c[12]\)[t] + 
            0.06682066312775997`\ \(c[13]\)[t] + 
            0.08654280907894489`\ \(c[14]\)[t] + 
            0.10337416789158609`\ \(c[15]\)[t] + 
            0.11643488132933186`\ \(c[16]\)[t] + 
            0.12496032289024853`\ \(c[17]\)[t] + 
            0.12833762891430928`\ \(c[18]\)[t] + 
            0.12613778810677614`\ \(c[19]\)[t] + 
            0.11814190616181255`\ \(c[20]\)[t] + 
            0.10436044624225685`\ \(c[21]\)[t] + 
            0.0850444803444217`\ \(c[22]\)[t] + 
            0.060688263076985105`\ \(c[23]\)[t] + 
            0.032022748374425904`\ \(c[24]\)[t] - 
            3.898171832519376`*^-17\ \(c[25]\)[t] - 
            0.03423121377955895`\ \(c[26]\)[t] - 
            0.06935801494512607`\ \(c[27]\)[t] - 
            0.10394325375429328`\ \(c[28]\)[t] - 
            0.13647135277833605`\ \(c[29]\)[t] - 
            0.1653986686265377`\ \(c[30]\)[t] - 
            0.18920668216016426`\ \(c[31]\)[t] - 
            0.20645618564475843`\ \(c[32]\)[t] - 
            0.21584055771952015`\ \(c[33]\)[t] - 
            0.21623620818304484`\ \(c[34]\)[t] - 
            0.206748335783172`\ \(c[35]\)[t] - 
            0.18675027222298593`\ \(c[36]\)[t] - 
            0.15591488063143982`\ \(c[37]\)[t] - 
            0.11423673049785436`\ \(c[38]\)[t] - 
            0.06204407497545024`\ \(c[39]\)[t] + 
            3.898171832519376`*^-17\ \(c[40]\)[t] + 
            0.07090751425765746`\ \(c[41]\)[t] + 
            0.14938649372796384`\ \(c[42]\)[t] + 
            0.23387232094715985`\ \(c[43]\)[t] + 
            0.32256865202152113`\ \(c[44]\)[t] + 
            0.4134966715663443`\ \(c[45]\)[t] + 
            0.5045511524271047`\ \(c[46]\)[t] + 
            0.5935615337286801`\ \(c[47]\)[t] + 
            0.6783560385470636`\ \(c[48]\)[t] + 
            0.7568267286406569`\ \(c[49]\)[t] + 
            0.826993343132688`\ \(c[50]\)[t] + 
            0.8870637930591839`\ \(c[51]\)[t] + 
            0.9354892837886392`\ \(c[52]\)[t] + 
            0.9710122092317629`\ \(c[53]\)[t] + 
            0.9927051996072069`\ \(c[54]\)[t] + 
            67.34567402954512`\ \(c[55]\)[t] + 
            0.9927051996072069`\ \(c[56]\)[t] + 
            0.9710122092317629`\ \(c[57]\)[t] + 
            0.9354892837886392`\ \(c[58]\)[t] + 
            0.8870637930591839`\ \(c[59]\)[t] + 
            0.826993343132688`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 55, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 55]][ t]], 
          Plus[ 
            Times[ -0.035956232310116867, 
              c[ -60][ t]], 
            Times[ -0.039832985717929335, 
              c[ -59][ t]], 
            Times[ -0.042022055485216314, 
              c[ -58][ t]], 
            Times[ -0.042397252409191441, 
              c[ -57][ t]], 
            Times[ -0.040909552899494925, 
              c[ -56][ t]], 
            Times[ -0.037590606506031236, 
              c[ -55][ t]], 
            Times[ -0.032552799745291155, 
              c[ -54][ t]], 
            Times[ -0.025985813438573278, 
              c[ -53][ t]], 
            Times[ -0.018149760920219783, 
              c[ -52][ t]], 
            Times[ -0.0093651433925206785, 
              c[ -51][ t]], 
            Times[ 2.0053370214556287*^-16, 
              c[ -50][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -49][ t]], 
            Times[ 0.018854606004500233, 
              c[ -48][ t]], 
            Times[ 0.027514390699665887, 
              c[ -47][ t]], 
            Times[ 0.035131239329076656, 
              c[ -46][ t]], 
            Times[ 0.041349667156634483, 
              c[ -45][ t]], 
            Times[ 0.045868286584282311, 
              c[ -44][ t]], 
            Times[ 0.048454002753361682, 
              c[ -43][ t]], 
            Times[ 0.04895352855494272, 
              c[ -42][ t]], 
            Times[ 0.047301670540041058, 
              c[ -41][ t]], 
            Times[ 0.043525965428036162, 
              c[ -40][ t]], 
            Times[ 0.03774739544932687, 
              c[ -39][ t]], 
            Times[ 0.030177073670601236, 
              c[ -38][ t]], 
            Times[ 0.021108961070255627, 
              c[ -37][ t]], 
            Times[ 0.010908848347331966, 
              c[ -36][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -35][ t]], 
            Times[ -0.011153991006822649, 
              c[ -34][ t]], 
            Times[ -0.022068459300722043, 
              c[ -33][ t]], 
            Times[ -0.032258251165125519, 
              c[ -32][ t]], 
            Times[ -0.041258781072520248, 
              c[ -31][ t]], 
            Times[ -0.048646667243099281, 
              c[ -30][ t]], 
            Times[ -0.054059052045761224, 
              c[ -29][ t]], 
            Times[ -0.057210750238908967, 
              c[ -28][ t]], 
            Times[ -0.057908442314993203, 
              c[ -27][ t]], 
            Times[ -0.056061239158567186, 
              c[ -26][ t]], 
            Times[ -0.05168708394579296, 
              c[ -25][ t]], 
            Times[ -0.044914622433376419, 
              c[ -24][ t]], 
            Times[ -0.035980357068793781, 
              c[ -23][ t]], 
            Times[ -0.025221096343682053, 
              c[ -22][ t]], 
            Times[ -0.013061910521147383, 
              c[ -21][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -20][ t]], 
            Times[ 0.013414935129827233, 
              c[ -19][ t]], 
            Times[ 0.026603074225527826, 
              c[ -18][ t]], 
            Times[ 0.03897872015785999, 
              c[ -17][ t]], 
            Times[ 0.049975424961080865, 
              c[ -16][ t]], 
            Times[ 0.059070953080906326, 
              c[ -15][ t]], 
            Times[ 0.065811019881796273, 
              c[ -14][ t]], 
            Times[ 0.069830768673962415, 
              c[ -13][ t]], 
            Times[ 0.070873018952678238, 
              c[ -12][ t]], 
            Times[ 0.068802429876423349, 
              c[ -11][ t]], 
            Times[ 0.063614872548668253, 
              c[ -10][ t]], 
            Times[ 0.055441487066198933, 
              c[ -9][ t]], 
            Times[ 0.044547108751839919, 
              c[ -8][ t]], 
            Times[ 0.031322974491347078, 
              c[ -7][ t]], 
            Times[ 0.016273855731265604, 
              c[ -6][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -5][ t]], 
            Times[ -0.016825511857749401, 
              c[ -4][ t]], 
            Times[ -0.033483179628681567, 
              c[ -3][ t]], 
            Times[ -0.049236278094138941, 
              c[ -2][ t]], 
            Times[ -0.063361699504227528, 
              c[ -1][ t]], 
            Times[ -0.075181213012062598, 
              c[ 0][ t]], 
            Times[ -0.084091858737850814, 
              c[ 1][ t]], 
            Times[ -0.089594193770366884, 
              c[ 2][ t]], 
            Times[ -0.091317159035181589, 
              c[ 3][ t]], 
            Times[ -0.089038438663606695, 
              c[ 4][ t]], 
            Times[ -0.082699334313268744, 
              c[ 5][ t]], 
            Times[ -0.072413370861974122, 
              c[ 6][ t]], 
            Times[ -0.058468080236789913, 
              c[ 7][ t]], 
            Times[ -0.04131966847794722, 
              c[ 8][ t]], 
            Times[ -0.021580547817547879, 
              c[ 9][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 10][ t]], 
            Times[ 0.022561481809254869, 
              c[ 11][ t]], 
            Times[ 0.045163358568919301, 
              c[ 12][ t]], 
            Times[ 0.066820663127759972, 
              c[ 13][ t]], 
            Times[ 0.086542809078944891, 
              c[ 14][ t]], 
            Times[ 0.10337416789158609, 
              c[ 15][ t]], 
            Times[ 0.11643488132933186, 
              c[ 16][ t]], 
            Times[ 0.12496032289024853, 
              c[ 17][ t]], 
            Times[ 0.12833762891430928, 
              c[ 18][ t]], 
            Times[ 0.12613778810677614, 
              c[ 19][ t]], 
            Times[ 0.11814190616181255, 
              c[ 20][ t]], 
            Times[ 0.10436044624225685, 
              c[ 21][ t]], 
            Times[ 0.085044480344421705, 
              c[ 22][ t]], 
            Times[ 0.060688263076985105, 
              c[ 23][ t]], 
            Times[ 0.032022748374425904, 
              c[ 24][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 25][ t]], 
            Times[ -0.034231213779558949, 
              c[ 26][ t]], 
            Times[ -0.06935801494512607, 
              c[ 27][ t]], 
            Times[ -0.10394325375429328, 
              c[ 28][ t]], 
            Times[ -0.13647135277833605, 
              c[ 29][ t]], 
            Times[ -0.16539866862653771, 
              c[ 30][ t]], 
            Times[ -0.18920668216016426, 
              c[ 31][ t]], 
            Times[ -0.20645618564475843, 
              c[ 32][ t]], 
            Times[ -0.21584055771952015, 
              c[ 33][ t]], 
            Times[ -0.21623620818304484, 
              c[ 34][ t]], 
            Times[ -0.206748335783172, 
              c[ 35][ t]], 
            Times[ -0.18675027222298593, 
              c[ 36][ t]], 
            Times[ -0.15591488063143982, 
              c[ 37][ t]], 
            Times[ -0.11423673049785436, 
              c[ 38][ t]], 
            Times[ -0.062044074975450239, 
              c[ 39][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 40][ t]], 
            Times[ 0.070907514257657456, 
              c[ 41][ t]], 
            Times[ 0.14938649372796384, 
              c[ 42][ t]], 
            Times[ 0.23387232094715985, 
              c[ 43][ t]], 
            Times[ 0.32256865202152113, 
              c[ 44][ t]], 
            Times[ 0.41349667156634429, 
              c[ 45][ t]], 
            Times[ 0.50455115242710469, 
              c[ 46][ t]], 
            Times[ 0.59356153372868015, 
              c[ 47][ t]], 
            Times[ 0.67835603854706361, 
              c[ 48][ t]], 
            Times[ 0.75682672864065692, 
              c[ 49][ t]], 
            Times[ 0.82699334313268802, 
              c[ 50][ t]], 
            Times[ 0.88706379305918392, 
              c[ 51][ t]], 
            Times[ 0.93548928378863916, 
              c[ 52][ t]], 
            Times[ 0.9710122092317629, 
              c[ 53][ t]], 
            Times[ 0.99270519960720693, 
              c[ 54][ t]], 
            Times[ 67.345674029545123, 
              c[ 55][ t]], 
            Times[ 0.99270519960720693, 
              c[ 56][ t]], 
            Times[ 0.9710122092317629, 
              c[ 57][ t]], 
            Times[ 0.93548928378863916, 
              c[ 58][ t]], 
            Times[ 0.88706379305918392, 
              c[ 59][ t]], 
            Times[ 0.82699334313268802, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "56", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[56]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.030588406657213296`\)\ \(c[\(-60\)]\)[t] - 
            0.035956232310116944`\ \(c[\(-59\)]\)[t] - 
            0.039832985717929335`\ \(c[\(-58\)]\)[t] - 
            0.042022055485216314`\ \(c[\(-57\)]\)[t] - 
            0.04239725240919144`\ \(c[\(-56\)]\)[t] - 
            0.040909552899494925`\ \(c[\(-55\)]\)[t] - 
            0.037590606506031236`\ \(c[\(-54\)]\)[t] - 
            0.03255279974529105`\ \(c[\(-53\)]\)[t] - 
            0.02598581343857328`\ \(c[\(-52\)]\)[t] - 
            0.018149760920219783`\ \(c[\(-51\)]\)[t] - 
            0.009365143392520679`\ \(c[\(-50\)]\)[t] + 
            2.0053370214556287`*^-16\ \(c[\(-49\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-48\)]\)[t] + 
            0.01885460600450039`\ \(c[\(-47\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-46\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-45\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-44\)]\)[t] + 
            0.04586828658428231`\ \(c[\(-43\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-42\)]\)[t] + 
            0.0489535285549427`\ \(c[\(-41\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-40\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-39\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-38\)]\)[t] + 
            0.030177073670601094`\ \(c[\(-37\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-36\)]\)[t] + 
            0.010908848347331785`\ \(c[\(-35\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-34\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-33\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-32\)]\)[t] - 
            0.03225825116512568`\ \(c[\(-31\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-30\)]\)[t] - 
            0.0486466672430994`\ \(c[\(-29\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-28\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-27\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-26\)]\)[t] - 
            0.05606123915856713`\ \(c[\(-25\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-24\)]\)[t] - 
            0.04491462243337629`\ \(c[\(-23\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-22\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-21\)]\)[t] - 
            0.013061910521147276`\ \(c[\(-20\)]\)[t] + 
            1.5206810699945212`*^-16\ \(c[\(-19\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-18\)]\)[t] + 
            0.026603074225527937`\ \(c[\(-17\)]\)[t] + 
            0.03897872015786009`\ \(c[\(-16\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-15\)]\)[t] + 
            0.0590709530809064`\ \(c[\(-14\)]\)[t] + 
            0.06581101988179631`\ \(c[\(-13\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-12\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-11\)]\)[t] + 
            0.06880242987642332`\ \(c[\(-10\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-9\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-8\)]\)[t] + 
            0.044547108751839815`\ \(c[\(-7\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-6\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-5\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-4\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-3\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-2\)]\)[t] - 
            0.049236278094139066`\ \(c[\(-1\)]\)[t] - 
            0.06336169950422753`\ \(c[0]\)[t] - 
            0.0751812130120626`\ \(c[1]\)[t] - 
            0.08409185873785086`\ \(c[2]\)[t] - 
            0.08959419377036688`\ \(c[3]\)[t] - 
            0.09131715903518159`\ \(c[4]\)[t] - 
            0.08903843866360665`\ \(c[5]\)[t] - 
            0.08269933431326874`\ \(c[6]\)[t] - 
            0.07241337086197412`\ \(c[7]\)[t] - 
            0.058468080236789774`\ \(c[8]\)[t] - 
            0.04131966847794722`\ \(c[9]\)[t] - 
            0.02158054781754788`\ \(c[10]\)[t] + 
            3.8981718325193755`*^-17\ \(c[11]\)[t] + 
            0.02256148180925487`\ \(c[12]\)[t] + 
            0.0451633585689193`\ \(c[13]\)[t] + 
            0.06682066312775997`\ \(c[14]\)[t] + 
            0.08654280907894489`\ \(c[15]\)[t] + 
            0.10337416789158609`\ \(c[16]\)[t] + 
            0.11643488132933186`\ \(c[17]\)[t] + 
            0.12496032289024853`\ \(c[18]\)[t] + 
            0.12833762891430928`\ \(c[19]\)[t] + 
            0.12613778810677612`\ \(c[20]\)[t] + 
            0.11814190616181253`\ \(c[21]\)[t] + 
            0.10436044624225685`\ \(c[22]\)[t] + 
            0.08504448034442161`\ \(c[23]\)[t] + 
            0.060688263076985`\ \(c[24]\)[t] + 
            0.032022748374425904`\ \(c[25]\)[t] - 
            1.8033970416801674`*^-16\ \(c[26]\)[t] - 
            0.034231213779559094`\ \(c[27]\)[t] - 
            0.06935801494512607`\ \(c[28]\)[t] - 
            0.1039432537542934`\ \(c[29]\)[t] - 
            0.13647135277833616`\ \(c[30]\)[t] - 
            0.1653986686265377`\ \(c[31]\)[t] - 
            0.18920668216016434`\ \(c[32]\)[t] - 
            0.20645618564475848`\ \(c[33]\)[t] - 
            0.21584055771952015`\ \(c[34]\)[t] - 
            0.21623620818304481`\ \(c[35]\)[t] - 
            0.2067483357831719`\ \(c[36]\)[t] - 
            0.18675027222298593`\ \(c[37]\)[t] - 
            0.15591488063143966`\ \(c[38]\)[t] - 
            0.11423673049785416`\ \(c[39]\)[t] - 
            0.06204407497545024`\ \(c[40]\)[t] + 
            3.898171832519376`*^-17\ \(c[41]\)[t] + 
            0.0709075142576581`\ \(c[42]\)[t] + 
            0.14938649372796384`\ \(c[43]\)[t] + 
            0.23387232094715985`\ \(c[44]\)[t] + 
            0.3225686520215219`\ \(c[45]\)[t] + 
            0.4134966715663443`\ \(c[46]\)[t] + 
            0.5045511524271047`\ \(c[47]\)[t] + 
            0.5935615337286809`\ \(c[48]\)[t] + 
            0.6783560385470636`\ \(c[49]\)[t] + 
            0.7568267286406569`\ \(c[50]\)[t] + 
            0.8269933431326885`\ \(c[51]\)[t] + 
            0.8870637930591839`\ \(c[52]\)[t] + 
            0.9354892837886392`\ \(c[53]\)[t] + 
            0.9710122092317629`\ \(c[54]\)[t] + 
            0.9927051996072069`\ \(c[55]\)[t] + 
            69.78017644848049`\ \(c[56]\)[t] + 
            0.9927051996072067`\ \(c[57]\)[t] + 
            0.9710122092317629`\ \(c[58]\)[t] + 
            0.9354892837886392`\ \(c[59]\)[t] + 
            0.8870637930591835`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 56, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 56]][ t]], 
          Plus[ 
            Times[ -0.030588406657213296, 
              c[ -60][ t]], 
            Times[ -0.035956232310116944, 
              c[ -59][ t]], 
            Times[ -0.039832985717929335, 
              c[ -58][ t]], 
            Times[ -0.042022055485216314, 
              c[ -57][ t]], 
            Times[ -0.042397252409191441, 
              c[ -56][ t]], 
            Times[ -0.040909552899494925, 
              c[ -55][ t]], 
            Times[ -0.037590606506031236, 
              c[ -54][ t]], 
            Times[ -0.032552799745291051, 
              c[ -53][ t]], 
            Times[ -0.025985813438573278, 
              c[ -52][ t]], 
            Times[ -0.018149760920219783, 
              c[ -51][ t]], 
            Times[ -0.0093651433925206785, 
              c[ -50][ t]], 
            Times[ 2.0053370214556287*^-16, 
              c[ -49][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -48][ t]], 
            Times[ 0.018854606004500389, 
              c[ -47][ t]], 
            Times[ 0.027514390699665887, 
              c[ -46][ t]], 
            Times[ 0.035131239329076656, 
              c[ -45][ t]], 
            Times[ 0.041349667156634483, 
              c[ -44][ t]], 
            Times[ 0.045868286584282311, 
              c[ -43][ t]], 
            Times[ 0.048454002753361682, 
              c[ -42][ t]], 
            Times[ 0.048953528554942699, 
              c[ -41][ t]], 
            Times[ 0.047301670540041058, 
              c[ -40][ t]], 
            Times[ 0.043525965428036162, 
              c[ -39][ t]], 
            Times[ 0.03774739544932687, 
              c[ -38][ t]], 
            Times[ 0.030177073670601094, 
              c[ -37][ t]], 
            Times[ 0.021108961070255627, 
              c[ -36][ t]], 
            Times[ 0.010908848347331785, 
              c[ -35][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -34][ t]], 
            Times[ -0.011153991006822649, 
              c[ -33][ t]], 
            Times[ -0.022068459300722043, 
              c[ -32][ t]], 
            Times[ -0.032258251165125679, 
              c[ -31][ t]], 
            Times[ -0.041258781072520248, 
              c[ -30][ t]], 
            Times[ -0.048646667243099399, 
              c[ -29][ t]], 
            Times[ -0.054059052045761224, 
              c[ -28][ t]], 
            Times[ -0.057210750238908967, 
              c[ -27][ t]], 
            Times[ -0.057908442314993203, 
              c[ -26][ t]], 
            Times[ -0.05606123915856713, 
              c[ -25][ t]], 
            Times[ -0.05168708394579296, 
              c[ -24][ t]], 
            Times[ -0.044914622433376288, 
              c[ -23][ t]], 
            Times[ -0.035980357068793781, 
              c[ -22][ t]], 
            Times[ -0.025221096343682053, 
              c[ -21][ t]], 
            Times[ -0.013061910521147276, 
              c[ -20][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ -19][ t]], 
            Times[ 0.013414935129827233, 
              c[ -18][ t]], 
            Times[ 0.026603074225527937, 
              c[ -17][ t]], 
            Times[ 0.038978720157860088, 
              c[ -16][ t]], 
            Times[ 0.049975424961080865, 
              c[ -15][ t]], 
            Times[ 0.059070953080906402, 
              c[ -14][ t]], 
            Times[ 0.065811019881796315, 
              c[ -13][ t]], 
            Times[ 0.069830768673962415, 
              c[ -12][ t]], 
            Times[ 0.070873018952678238, 
              c[ -11][ t]], 
            Times[ 0.068802429876423321, 
              c[ -10][ t]], 
            Times[ 0.063614872548668253, 
              c[ -9][ t]], 
            Times[ 0.055441487066198933, 
              c[ -8][ t]], 
            Times[ 0.044547108751839815, 
              c[ -7][ t]], 
            Times[ 0.031322974491347078, 
              c[ -6][ t]], 
            Times[ 0.016273855731265604, 
              c[ -5][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -4][ t]], 
            Times[ -0.016825511857749401, 
              c[ -3][ t]], 
            Times[ -0.033483179628681567, 
              c[ -2][ t]], 
            Times[ -0.049236278094139066, 
              c[ -1][ t]], 
            Times[ -0.063361699504227528, 
              c[ 0][ t]], 
            Times[ -0.075181213012062598, 
              c[ 1][ t]], 
            Times[ -0.084091858737850855, 
              c[ 2][ t]], 
            Times[ -0.089594193770366884, 
              c[ 3][ t]], 
            Times[ -0.091317159035181589, 
              c[ 4][ t]], 
            Times[ -0.089038438663606653, 
              c[ 5][ t]], 
            Times[ -0.082699334313268744, 
              c[ 6][ t]], 
            Times[ -0.072413370861974122, 
              c[ 7][ t]], 
            Times[ -0.058468080236789774, 
              c[ 8][ t]], 
            Times[ -0.04131966847794722, 
              c[ 9][ t]], 
            Times[ -0.021580547817547879, 
              c[ 10][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 11][ t]], 
            Times[ 0.022561481809254869, 
              c[ 12][ t]], 
            Times[ 0.045163358568919301, 
              c[ 13][ t]], 
            Times[ 0.066820663127759972, 
              c[ 14][ t]], 
            Times[ 0.086542809078944891, 
              c[ 15][ t]], 
            Times[ 0.10337416789158609, 
              c[ 16][ t]], 
            Times[ 0.11643488132933186, 
              c[ 17][ t]], 
            Times[ 0.12496032289024853, 
              c[ 18][ t]], 
            Times[ 0.12833762891430928, 
              c[ 19][ t]], 
            Times[ 0.12613778810677612, 
              c[ 20][ t]], 
            Times[ 0.11814190616181253, 
              c[ 21][ t]], 
            Times[ 0.10436044624225685, 
              c[ 22][ t]], 
            Times[ 0.085044480344421608, 
              c[ 23][ t]], 
            Times[ 0.060688263076985001, 
              c[ 24][ t]], 
            Times[ 0.032022748374425904, 
              c[ 25][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 26][ t]], 
            Times[ -0.034231213779559094, 
              c[ 27][ t]], 
            Times[ -0.06935801494512607, 
              c[ 28][ t]], 
            Times[ -0.1039432537542934, 
              c[ 29][ t]], 
            Times[ -0.13647135277833616, 
              c[ 30][ t]], 
            Times[ -0.16539866862653771, 
              c[ 31][ t]], 
            Times[ -0.18920668216016434, 
              c[ 32][ t]], 
            Times[ -0.20645618564475848, 
              c[ 33][ t]], 
            Times[ -0.21584055771952015, 
              c[ 34][ t]], 
            Times[ -0.21623620818304481, 
              c[ 35][ t]], 
            Times[ -0.20674833578317189, 
              c[ 36][ t]], 
            Times[ -0.18675027222298593, 
              c[ 37][ t]], 
            Times[ -0.15591488063143966, 
              c[ 38][ t]], 
            Times[ -0.11423673049785416, 
              c[ 39][ t]], 
            Times[ -0.062044074975450239, 
              c[ 40][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 41][ t]], 
            Times[ 0.070907514257658094, 
              c[ 42][ t]], 
            Times[ 0.14938649372796384, 
              c[ 43][ t]], 
            Times[ 0.23387232094715985, 
              c[ 44][ t]], 
            Times[ 0.32256865202152191, 
              c[ 45][ t]], 
            Times[ 0.41349667156634429, 
              c[ 46][ t]], 
            Times[ 0.50455115242710469, 
              c[ 47][ t]], 
            Times[ 0.59356153372868092, 
              c[ 48][ t]], 
            Times[ 0.67835603854706361, 
              c[ 49][ t]], 
            Times[ 0.75682672864065692, 
              c[ 50][ t]], 
            Times[ 0.82699334313268846, 
              c[ 51][ t]], 
            Times[ 0.88706379305918392, 
              c[ 52][ t]], 
            Times[ 0.93548928378863916, 
              c[ 53][ t]], 
            Times[ 0.9710122092317629, 
              c[ 54][ t]], 
            Times[ 0.99270519960720693, 
              c[ 55][ t]], 
            Times[ 69.780176448480489, 
              c[ 56][ t]], 
            Times[ 0.99270519960720671, 
              c[ 57][ t]], 
            Times[ 0.9710122092317629, 
              c[ 58][ t]], 
            Times[ 0.93548928378863916, 
              c[ 59][ t]], 
            Times[ 0.88706379305918348, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "57", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[57]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.023986904712529237`\)\ \(c[\(-60\)]\)[t] - 
            0.030588406657213296`\ \(c[\(-59\)]\)[t] - 
            0.03595623231011687`\ \(c[\(-58\)]\)[t] - 
            0.039832985717929335`\ \(c[\(-57\)]\)[t] - 
            0.042022055485216314`\ \(c[\(-56\)]\)[t] - 
            0.04239725240919144`\ \(c[\(-55\)]\)[t] - 
            0.040909552899494966`\ \(c[\(-54\)]\)[t] - 
            0.037590606506031236`\ \(c[\(-53\)]\)[t] - 
            0.032552799745291155`\ \(c[\(-52\)]\)[t] - 
            0.02598581343857328`\ \(c[\(-51\)]\)[t] - 
            0.018149760920219783`\ \(c[\(-50\)]\)[t] - 
            0.009365143392520679`\ \(c[\(-49\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-48\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-47\)]\)[t] + 
            0.018854606004500233`\ \(c[\(-46\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-45\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-44\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-43\)]\)[t] + 
            0.045868286584282256`\ \(c[\(-42\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-41\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-40\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-39\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-38\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-37\)]\)[t] + 
            0.030177073670601236`\ \(c[\(-36\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-35\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-34\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-33\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-32\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-31\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-30\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-29\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-28\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-27\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-26\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-25\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-24\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-23\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-22\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-21\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-20\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-19\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-18\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-17\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-16\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-15\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-14\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-13\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-12\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-11\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-10\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-9\)]\)[t] + 
            0.06361487254866832`\ \(c[\(-8\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-7\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-6\)]\)[t] + 
            0.0313229744913472`\ \(c[\(-5\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-4\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-3\)]\)[t] - 
            0.016825511857749262`\ \(c[\(-2\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-1\)]\)[t] - 
            0.04923627809413894`\ \(c[0]\)[t] - 
            0.0633616995042274`\ \(c[1]\)[t] - 
            0.0751812130120626`\ \(c[2]\)[t] - 
            0.08409185873785081`\ \(c[3]\)[t] - 
            0.08959419377036684`\ \(c[4]\)[t] - 
            0.09131715903518159`\ \(c[5]\)[t] - 
            0.0890384386636067`\ \(c[6]\)[t] - 
            0.08269933431326881`\ \(c[7]\)[t] - 
            0.07241337086197412`\ \(c[8]\)[t] - 
            0.05846808023678991`\ \(c[9]\)[t] - 
            0.04131966847794737`\ \(c[10]\)[t] - 
            0.021580547817548056`\ \(c[11]\)[t] + 
            3.8981718325193755`*^-17\ \(c[12]\)[t] + 
            0.022561481809254675`\ \(c[13]\)[t] + 
            0.045163358568919114`\ \(c[14]\)[t] + 
            0.06682066312775997`\ \(c[15]\)[t] + 
            0.08654280907894475`\ \(c[16]\)[t] + 
            0.10337416789158595`\ \(c[17]\)[t] + 
            0.11643488132933186`\ \(c[18]\)[t] + 
            0.12496032289024847`\ \(c[19]\)[t] + 
            0.12833762891430925`\ \(c[20]\)[t] + 
            0.12613778810677614`\ \(c[21]\)[t] + 
            0.1181419061618126`\ \(c[22]\)[t] + 
            0.10436044624225692`\ \(c[23]\)[t] + 
            0.0850444803444217`\ \(c[24]\)[t] + 
            0.06068826307698522`\ \(c[25]\)[t] + 
            0.03202274837442603`\ \(c[26]\)[t] - 
            3.898171832519376`*^-17\ \(c[27]\)[t] - 
            0.034231213779558796`\ \(c[28]\)[t] - 
            0.06935801494512592`\ \(c[29]\)[t] - 
            0.10394325375429328`\ \(c[30]\)[t] - 
            0.1364713527783359`\ \(c[31]\)[t] - 
            0.1653986686265376`\ \(c[32]\)[t] - 
            0.18920668216016426`\ \(c[33]\)[t] - 
            0.20645618564475834`\ \(c[34]\)[t] - 
            0.21584055771952013`\ \(c[35]\)[t] - 
            0.21623620818304484`\ \(c[36]\)[t] - 
            0.20674833578317206`\ \(c[37]\)[t] - 
            0.18675027222298607`\ \(c[38]\)[t] - 
            0.15591488063143982`\ \(c[39]\)[t] - 
            0.11423673049785459`\ \(c[40]\)[t] - 
            0.06204407497545072`\ \(c[41]\)[t] + 
            3.898171832519376`*^-17\ \(c[42]\)[t] + 
            0.07090751425765746`\ \(c[43]\)[t] + 
            0.14938649372796314`\ \(c[44]\)[t] + 
            0.23387232094715985`\ \(c[45]\)[t] + 
            0.32256865202152113`\ \(c[46]\)[t] + 
            0.4134966715663436`\ \(c[47]\)[t] + 
            0.5045511524271047`\ \(c[48]\)[t] + 
            0.5935615337286801`\ \(c[49]\)[t] + 
            0.6783560385470627`\ \(c[50]\)[t] + 
            0.7568267286406569`\ \(c[51]\)[t] + 
            0.826993343132688`\ \(c[52]\)[t] + 
            0.8870637930591835`\ \(c[53]\)[t] + 
            0.9354892837886392`\ \(c[54]\)[t] + 
            0.9710122092317629`\ \(c[55]\)[t] + 
            0.9927051996072067`\ \(c[56]\)[t] + 
            72.25854377586516`\ \(c[57]\)[t] + 
            0.9927051996072069`\ \(c[58]\)[t] + 
            0.9710122092317629`\ \(c[59]\)[t] + 
            0.9354892837886392`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 57, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 57]][ t]], 
          Plus[ 
            Times[ -0.023986904712529237, 
              c[ -60][ t]], 
            Times[ -0.030588406657213296, 
              c[ -59][ t]], 
            Times[ -0.035956232310116867, 
              c[ -58][ t]], 
            Times[ -0.039832985717929335, 
              c[ -57][ t]], 
            Times[ -0.042022055485216314, 
              c[ -56][ t]], 
            Times[ -0.042397252409191441, 
              c[ -55][ t]], 
            Times[ -0.040909552899494966, 
              c[ -54][ t]], 
            Times[ -0.037590606506031236, 
              c[ -53][ t]], 
            Times[ -0.032552799745291155, 
              c[ -52][ t]], 
            Times[ -0.025985813438573278, 
              c[ -51][ t]], 
            Times[ -0.018149760920219783, 
              c[ -50][ t]], 
            Times[ -0.0093651433925206785, 
              c[ -49][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -48][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -47][ t]], 
            Times[ 0.018854606004500233, 
              c[ -46][ t]], 
            Times[ 0.027514390699665887, 
              c[ -45][ t]], 
            Times[ 0.035131239329076656, 
              c[ -44][ t]], 
            Times[ 0.041349667156634483, 
              c[ -43][ t]], 
            Times[ 0.045868286584282256, 
              c[ -42][ t]], 
            Times[ 0.048454002753361682, 
              c[ -41][ t]], 
            Times[ 0.04895352855494272, 
              c[ -40][ t]], 
            Times[ 0.047301670540041058, 
              c[ -39][ t]], 
            Times[ 0.043525965428036162, 
              c[ -38][ t]], 
            Times[ 0.03774739544932687, 
              c[ -37][ t]], 
            Times[ 0.030177073670601236, 
              c[ -36][ t]], 
            Times[ 0.021108961070255627, 
              c[ -35][ t]], 
            Times[ 0.010908848347331966, 
              c[ -34][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -33][ t]], 
            Times[ -0.011153991006822649, 
              c[ -32][ t]], 
            Times[ -0.022068459300722043, 
              c[ -31][ t]], 
            Times[ -0.032258251165125519, 
              c[ -30][ t]], 
            Times[ -0.041258781072520248, 
              c[ -29][ t]], 
            Times[ -0.048646667243099281, 
              c[ -28][ t]], 
            Times[ -0.054059052045761224, 
              c[ -27][ t]], 
            Times[ -0.057210750238908967, 
              c[ -26][ t]], 
            Times[ -0.057908442314993203, 
              c[ -25][ t]], 
            Times[ -0.056061239158567186, 
              c[ -24][ t]], 
            Times[ -0.05168708394579296, 
              c[ -23][ t]], 
            Times[ -0.044914622433376419, 
              c[ -22][ t]], 
            Times[ -0.035980357068793781, 
              c[ -21][ t]], 
            Times[ -0.025221096343682053, 
              c[ -20][ t]], 
            Times[ -0.013061910521147383, 
              c[ -19][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -18][ t]], 
            Times[ 0.013414935129827233, 
              c[ -17][ t]], 
            Times[ 0.026603074225527826, 
              c[ -16][ t]], 
            Times[ 0.03897872015785999, 
              c[ -15][ t]], 
            Times[ 0.049975424961080865, 
              c[ -14][ t]], 
            Times[ 0.059070953080906326, 
              c[ -13][ t]], 
            Times[ 0.065811019881796273, 
              c[ -12][ t]], 
            Times[ 0.069830768673962415, 
              c[ -11][ t]], 
            Times[ 0.070873018952678238, 
              c[ -10][ t]], 
            Times[ 0.068802429876423349, 
              c[ -9][ t]], 
            Times[ 0.063614872548668322, 
              c[ -8][ t]], 
            Times[ 0.055441487066198933, 
              c[ -7][ t]], 
            Times[ 0.044547108751839919, 
              c[ -6][ t]], 
            Times[ 0.031322974491347202, 
              c[ -5][ t]], 
            Times[ 0.016273855731265604, 
              c[ -4][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -3][ t]], 
            Times[ -0.016825511857749262, 
              c[ -2][ t]], 
            Times[ -0.033483179628681567, 
              c[ -1][ t]], 
            Times[ -0.049236278094138941, 
              c[ 0][ t]], 
            Times[ -0.063361699504227403, 
              c[ 1][ t]], 
            Times[ -0.075181213012062598, 
              c[ 2][ t]], 
            Times[ -0.084091858737850814, 
              c[ 3][ t]], 
            Times[ -0.089594193770366842, 
              c[ 4][ t]], 
            Times[ -0.091317159035181589, 
              c[ 5][ t]], 
            Times[ -0.089038438663606695, 
              c[ 6][ t]], 
            Times[ -0.082699334313268813, 
              c[ 7][ t]], 
            Times[ -0.072413370861974122, 
              c[ 8][ t]], 
            Times[ -0.058468080236789913, 
              c[ 9][ t]], 
            Times[ -0.041319668477947373, 
              c[ 10][ t]], 
            Times[ -0.021580547817548056, 
              c[ 11][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 12][ t]], 
            Times[ 0.022561481809254675, 
              c[ 13][ t]], 
            Times[ 0.045163358568919114, 
              c[ 14][ t]], 
            Times[ 0.066820663127759972, 
              c[ 15][ t]], 
            Times[ 0.086542809078944752, 
              c[ 16][ t]], 
            Times[ 0.10337416789158595, 
              c[ 17][ t]], 
            Times[ 0.11643488132933186, 
              c[ 18][ t]], 
            Times[ 0.12496032289024847, 
              c[ 19][ t]], 
            Times[ 0.12833762891430925, 
              c[ 20][ t]], 
            Times[ 0.12613778810677614, 
              c[ 21][ t]], 
            Times[ 0.1181419061618126, 
              c[ 22][ t]], 
            Times[ 0.10436044624225692, 
              c[ 23][ t]], 
            Times[ 0.085044480344421705, 
              c[ 24][ t]], 
            Times[ 0.060688263076985223, 
              c[ 25][ t]], 
            Times[ 0.032022748374426029, 
              c[ 26][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 27][ t]], 
            Times[ -0.034231213779558796, 
              c[ 28][ t]], 
            Times[ -0.069358014945125918, 
              c[ 29][ t]], 
            Times[ -0.10394325375429328, 
              c[ 30][ t]], 
            Times[ -0.13647135277833591, 
              c[ 31][ t]], 
            Times[ -0.1653986686265376, 
              c[ 32][ t]], 
            Times[ -0.18920668216016426, 
              c[ 33][ t]], 
            Times[ -0.20645618564475834, 
              c[ 34][ t]], 
            Times[ -0.21584055771952013, 
              c[ 35][ t]], 
            Times[ -0.21623620818304484, 
              c[ 36][ t]], 
            Times[ -0.20674833578317206, 
              c[ 37][ t]], 
            Times[ -0.18675027222298607, 
              c[ 38][ t]], 
            Times[ -0.15591488063143982, 
              c[ 39][ t]], 
            Times[ -0.11423673049785459, 
              c[ 40][ t]], 
            Times[ -0.062044074975450718, 
              c[ 41][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 42][ t]], 
            Times[ 0.070907514257657456, 
              c[ 43][ t]], 
            Times[ 0.14938649372796314, 
              c[ 44][ t]], 
            Times[ 0.23387232094715985, 
              c[ 45][ t]], 
            Times[ 0.32256865202152113, 
              c[ 46][ t]], 
            Times[ 0.41349667156634362, 
              c[ 47][ t]], 
            Times[ 0.50455115242710469, 
              c[ 48][ t]], 
            Times[ 0.59356153372868015, 
              c[ 49][ t]], 
            Times[ 0.67835603854706272, 
              c[ 50][ t]], 
            Times[ 0.75682672864065692, 
              c[ 51][ t]], 
            Times[ 0.82699334313268802, 
              c[ 52][ t]], 
            Times[ 0.88706379305918348, 
              c[ 53][ t]], 
            Times[ 0.93548928378863916, 
              c[ 54][ t]], 
            Times[ 0.9710122092317629, 
              c[ 55][ t]], 
            Times[ 0.99270519960720671, 
              c[ 56][ t]], 
            Times[ 72.258543775865164, 
              c[ 57][ t]], 
            Times[ 0.99270519960720693, 
              c[ 58][ t]], 
            Times[ 0.9710122092317629, 
              c[ 59][ t]], 
            Times[ 0.93548928378863916, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "58", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[58]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.01645783405477577`\)\ \(c[\(-60\)]\)[t] - 
            0.02398690471252936`\ \(c[\(-59\)]\)[t] - 
            0.030588406657213296`\ \(c[\(-58\)]\)[t] - 
            0.03595623231011687`\ \(c[\(-57\)]\)[t] - 
            0.039832985717929335`\ \(c[\(-56\)]\)[t] - 
            0.042022055485216314`\ \(c[\(-55\)]\)[t] - 
            0.04239725240919144`\ \(c[\(-54\)]\)[t] - 
            0.040909552899494925`\ \(c[\(-53\)]\)[t] - 
            0.037590606506031236`\ \(c[\(-52\)]\)[t] - 
            0.032552799745291155`\ \(c[\(-51\)]\)[t] - 
            0.02598581343857328`\ \(c[\(-50\)]\)[t] - 
            0.018149760920219783`\ \(c[\(-49\)]\)[t] - 
            0.009365143392520679`\ \(c[\(-48\)]\)[t] + 
            2.0053370214556287`*^-16\ \(c[\(-47\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-46\)]\)[t] + 
            0.018854606004500233`\ \(c[\(-45\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-44\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-43\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-42\)]\)[t] + 
            0.04586828658428231`\ \(c[\(-41\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-40\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-39\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-38\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-37\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-36\)]\)[t] + 
            0.030177073670601236`\ \(c[\(-35\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-34\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-33\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-32\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-31\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-30\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-29\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-28\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-27\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-26\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-25\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-24\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-23\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-22\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-21\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-20\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-19\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-18\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-17\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-16\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-15\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-14\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-13\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-12\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-11\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-10\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-9\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-8\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-7\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-6\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-5\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-4\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-3\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-2\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-1\)]\)[t] - 
            0.03348317962868157`\ \(c[0]\)[t] - 
            0.04923627809413894`\ \(c[1]\)[t] - 
            0.06336169950422753`\ \(c[2]\)[t] - 
            0.0751812130120626`\ \(c[3]\)[t] - 
            0.08409185873785081`\ \(c[4]\)[t] - 
            0.08959419377036688`\ \(c[5]\)[t] - 
            0.09131715903518159`\ \(c[6]\)[t] - 
            0.0890384386636067`\ \(c[7]\)[t] - 
            0.08269933431326874`\ \(c[8]\)[t] - 
            0.07241337086197412`\ \(c[9]\)[t] - 
            0.05846808023678991`\ \(c[10]\)[t] - 
            0.04131966847794722`\ \(c[11]\)[t] - 
            0.02158054781754788`\ \(c[12]\)[t] + 
            3.8981718325193755`*^-17\ \(c[13]\)[t] + 
            0.02256148180925487`\ \(c[14]\)[t] + 
            0.0451633585689193`\ \(c[15]\)[t] + 
            0.06682066312775997`\ \(c[16]\)[t] + 
            0.08654280907894489`\ \(c[17]\)[t] + 
            0.10337416789158609`\ \(c[18]\)[t] + 
            0.11643488132933186`\ \(c[19]\)[t] + 
            0.12496032289024853`\ \(c[20]\)[t] + 
            0.12833762891430928`\ \(c[21]\)[t] + 
            0.12613778810677614`\ \(c[22]\)[t] + 
            0.11814190616181255`\ \(c[23]\)[t] + 
            0.10436044624225685`\ \(c[24]\)[t] + 
            0.0850444803444217`\ \(c[25]\)[t] + 
            0.060688263076985105`\ \(c[26]\)[t] + 
            0.032022748374425904`\ \(c[27]\)[t] - 
            3.898171832519376`*^-17\ \(c[28]\)[t] - 
            0.03423121377955895`\ \(c[29]\)[t] - 
            0.06935801494512607`\ \(c[30]\)[t] - 
            0.10394325375429328`\ \(c[31]\)[t] - 
            0.13647135277833605`\ \(c[32]\)[t] - 
            0.1653986686265377`\ \(c[33]\)[t] - 
            0.18920668216016426`\ \(c[34]\)[t] - 
            0.20645618564475843`\ \(c[35]\)[t] - 
            0.21584055771952015`\ \(c[36]\)[t] - 
            0.21623620818304484`\ \(c[37]\)[t] - 
            0.206748335783172`\ \(c[38]\)[t] - 
            0.18675027222298593`\ \(c[39]\)[t] - 
            0.15591488063143982`\ \(c[40]\)[t] - 
            0.11423673049785459`\ \(c[41]\)[t] - 
            0.06204407497545024`\ \(c[42]\)[t] + 
            3.898171832519376`*^-17\ \(c[43]\)[t] + 
            0.07090751425765746`\ \(c[44]\)[t] + 
            0.14938649372796384`\ \(c[45]\)[t] + 
            0.23387232094715985`\ \(c[46]\)[t] + 
            0.32256865202152113`\ \(c[47]\)[t] + 
            0.4134966715663443`\ \(c[48]\)[t] + 
            0.5045511524271047`\ \(c[49]\)[t] + 
            0.5935615337286801`\ \(c[50]\)[t] + 
            0.6783560385470636`\ \(c[51]\)[t] + 
            0.7568267286406569`\ \(c[52]\)[t] + 
            0.826993343132688`\ \(c[53]\)[t] + 
            0.8870637930591839`\ \(c[54]\)[t] + 
            0.9354892837886392`\ \(c[55]\)[t] + 
            0.9710122092317629`\ \(c[56]\)[t] + 
            0.9927051996072069`\ \(c[57]\)[t] + 
            74.7807760116991`\ \(c[58]\)[t] + 
            0.9927051996072069`\ \(c[59]\)[t] + 
            0.9710122092317629`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 58, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 58]][ t]], 
          Plus[ 
            Times[ -0.016457834054775768, 
              c[ -60][ t]], 
            Times[ -0.023986904712529358, 
              c[ -59][ t]], 
            Times[ -0.030588406657213296, 
              c[ -58][ t]], 
            Times[ -0.035956232310116867, 
              c[ -57][ t]], 
            Times[ -0.039832985717929335, 
              c[ -56][ t]], 
            Times[ -0.042022055485216314, 
              c[ -55][ t]], 
            Times[ -0.042397252409191441, 
              c[ -54][ t]], 
            Times[ -0.040909552899494925, 
              c[ -53][ t]], 
            Times[ -0.037590606506031236, 
              c[ -52][ t]], 
            Times[ -0.032552799745291155, 
              c[ -51][ t]], 
            Times[ -0.025985813438573278, 
              c[ -50][ t]], 
            Times[ -0.018149760920219783, 
              c[ -49][ t]], 
            Times[ -0.0093651433925206785, 
              c[ -48][ t]], 
            Times[ 2.0053370214556287*^-16, 
              c[ -47][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -46][ t]], 
            Times[ 0.018854606004500233, 
              c[ -45][ t]], 
            Times[ 0.027514390699665887, 
              c[ -44][ t]], 
            Times[ 0.035131239329076656, 
              c[ -43][ t]], 
            Times[ 0.041349667156634483, 
              c[ -42][ t]], 
            Times[ 0.045868286584282311, 
              c[ -41][ t]], 
            Times[ 0.048454002753361682, 
              c[ -40][ t]], 
            Times[ 0.04895352855494272, 
              c[ -39][ t]], 
            Times[ 0.047301670540041058, 
              c[ -38][ t]], 
            Times[ 0.043525965428036162, 
              c[ -37][ t]], 
            Times[ 0.03774739544932687, 
              c[ -36][ t]], 
            Times[ 0.030177073670601236, 
              c[ -35][ t]], 
            Times[ 0.021108961070255627, 
              c[ -34][ t]], 
            Times[ 0.010908848347331966, 
              c[ -33][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -32][ t]], 
            Times[ -0.011153991006822649, 
              c[ -31][ t]], 
            Times[ -0.022068459300722043, 
              c[ -30][ t]], 
            Times[ -0.032258251165125519, 
              c[ -29][ t]], 
            Times[ -0.041258781072520248, 
              c[ -28][ t]], 
            Times[ -0.048646667243099281, 
              c[ -27][ t]], 
            Times[ -0.054059052045761224, 
              c[ -26][ t]], 
            Times[ -0.057210750238908967, 
              c[ -25][ t]], 
            Times[ -0.057908442314993203, 
              c[ -24][ t]], 
            Times[ -0.056061239158567186, 
              c[ -23][ t]], 
            Times[ -0.05168708394579296, 
              c[ -22][ t]], 
            Times[ -0.044914622433376419, 
              c[ -21][ t]], 
            Times[ -0.035980357068793781, 
              c[ -20][ t]], 
            Times[ -0.025221096343682053, 
              c[ -19][ t]], 
            Times[ -0.013061910521147383, 
              c[ -18][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -17][ t]], 
            Times[ 0.013414935129827233, 
              c[ -16][ t]], 
            Times[ 0.026603074225527826, 
              c[ -15][ t]], 
            Times[ 0.03897872015785999, 
              c[ -14][ t]], 
            Times[ 0.049975424961080865, 
              c[ -13][ t]], 
            Times[ 0.059070953080906326, 
              c[ -12][ t]], 
            Times[ 0.065811019881796273, 
              c[ -11][ t]], 
            Times[ 0.069830768673962415, 
              c[ -10][ t]], 
            Times[ 0.070873018952678238, 
              c[ -9][ t]], 
            Times[ 0.068802429876423349, 
              c[ -8][ t]], 
            Times[ 0.063614872548668253, 
              c[ -7][ t]], 
            Times[ 0.055441487066198933, 
              c[ -6][ t]], 
            Times[ 0.044547108751839919, 
              c[ -5][ t]], 
            Times[ 0.031322974491347078, 
              c[ -4][ t]], 
            Times[ 0.016273855731265604, 
              c[ -3][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -2][ t]], 
            Times[ -0.016825511857749401, 
              c[ -1][ t]], 
            Times[ -0.033483179628681567, 
              c[ 0][ t]], 
            Times[ -0.049236278094138941, 
              c[ 1][ t]], 
            Times[ -0.063361699504227528, 
              c[ 2][ t]], 
            Times[ -0.075181213012062598, 
              c[ 3][ t]], 
            Times[ -0.084091858737850814, 
              c[ 4][ t]], 
            Times[ -0.089594193770366884, 
              c[ 5][ t]], 
            Times[ -0.091317159035181589, 
              c[ 6][ t]], 
            Times[ -0.089038438663606695, 
              c[ 7][ t]], 
            Times[ -0.082699334313268744, 
              c[ 8][ t]], 
            Times[ -0.072413370861974122, 
              c[ 9][ t]], 
            Times[ -0.058468080236789913, 
              c[ 10][ t]], 
            Times[ -0.04131966847794722, 
              c[ 11][ t]], 
            Times[ -0.021580547817547879, 
              c[ 12][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 13][ t]], 
            Times[ 0.022561481809254869, 
              c[ 14][ t]], 
            Times[ 0.045163358568919301, 
              c[ 15][ t]], 
            Times[ 0.066820663127759972, 
              c[ 16][ t]], 
            Times[ 0.086542809078944891, 
              c[ 17][ t]], 
            Times[ 0.10337416789158609, 
              c[ 18][ t]], 
            Times[ 0.11643488132933186, 
              c[ 19][ t]], 
            Times[ 0.12496032289024853, 
              c[ 20][ t]], 
            Times[ 0.12833762891430928, 
              c[ 21][ t]], 
            Times[ 0.12613778810677614, 
              c[ 22][ t]], 
            Times[ 0.11814190616181255, 
              c[ 23][ t]], 
            Times[ 0.10436044624225685, 
              c[ 24][ t]], 
            Times[ 0.085044480344421705, 
              c[ 25][ t]], 
            Times[ 0.060688263076985105, 
              c[ 26][ t]], 
            Times[ 0.032022748374425904, 
              c[ 27][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 28][ t]], 
            Times[ -0.034231213779558949, 
              c[ 29][ t]], 
            Times[ -0.06935801494512607, 
              c[ 30][ t]], 
            Times[ -0.10394325375429328, 
              c[ 31][ t]], 
            Times[ -0.13647135277833605, 
              c[ 32][ t]], 
            Times[ -0.16539866862653771, 
              c[ 33][ t]], 
            Times[ -0.18920668216016426, 
              c[ 34][ t]], 
            Times[ -0.20645618564475843, 
              c[ 35][ t]], 
            Times[ -0.21584055771952015, 
              c[ 36][ t]], 
            Times[ -0.21623620818304484, 
              c[ 37][ t]], 
            Times[ -0.206748335783172, 
              c[ 38][ t]], 
            Times[ -0.18675027222298593, 
              c[ 39][ t]], 
            Times[ -0.15591488063143982, 
              c[ 40][ t]], 
            Times[ -0.11423673049785459, 
              c[ 41][ t]], 
            Times[ -0.062044074975450239, 
              c[ 42][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 43][ t]], 
            Times[ 0.070907514257657456, 
              c[ 44][ t]], 
            Times[ 0.14938649372796384, 
              c[ 45][ t]], 
            Times[ 0.23387232094715985, 
              c[ 46][ t]], 
            Times[ 0.32256865202152113, 
              c[ 47][ t]], 
            Times[ 0.41349667156634429, 
              c[ 48][ t]], 
            Times[ 0.50455115242710469, 
              c[ 49][ t]], 
            Times[ 0.59356153372868015, 
              c[ 50][ t]], 
            Times[ 0.67835603854706361, 
              c[ 51][ t]], 
            Times[ 0.75682672864065692, 
              c[ 52][ t]], 
            Times[ 0.82699334313268802, 
              c[ 53][ t]], 
            Times[ 0.88706379305918392, 
              c[ 54][ t]], 
            Times[ 0.93548928378863916, 
              c[ 55][ t]], 
            Times[ 0.9710122092317629, 
              c[ 56][ t]], 
            Times[ 0.99270519960720693, 
              c[ 57][ t]], 
            Times[ 74.780776011699103, 
              c[ 58][ t]], 
            Times[ 0.99270519960720693, 
              c[ 59][ t]], 
            Times[ 0.9710122092317629, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "59", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[59]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.008342060500900982`\)\ \(c[\(-60\)]\)[t] - 
            0.01645783405477577`\ \(c[\(-59\)]\)[t] - 
            0.02398690471252936`\ \(c[\(-58\)]\)[t] - 
            0.030588406657213296`\ \(c[\(-57\)]\)[t] - 
            0.035956232310116944`\ \(c[\(-56\)]\)[t] - 
            0.039832985717929335`\ \(c[\(-55\)]\)[t] - 
            0.042022055485216314`\ \(c[\(-54\)]\)[t] - 
            0.04239725240919144`\ \(c[\(-53\)]\)[t] - 
            0.040909552899494925`\ \(c[\(-52\)]\)[t] - 
            0.037590606506031236`\ \(c[\(-51\)]\)[t] - 
            0.03255279974529105`\ \(c[\(-50\)]\)[t] - 
            0.02598581343857328`\ \(c[\(-49\)]\)[t] - 
            0.018149760920219783`\ \(c[\(-48\)]\)[t] - 
            0.009365143392520679`\ \(c[\(-47\)]\)[t] + 
            2.0053370214556287`*^-16\ \(c[\(-46\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-45\)]\)[t] + 
            0.01885460600450039`\ \(c[\(-44\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-43\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-42\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-41\)]\)[t] + 
            0.04586828658428231`\ \(c[\(-40\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-39\)]\)[t] + 
            0.0489535285549427`\ \(c[\(-38\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-37\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-36\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-35\)]\)[t] + 
            0.030177073670601094`\ \(c[\(-34\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-33\)]\)[t] + 
            0.010908848347331785`\ \(c[\(-32\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-31\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-30\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-29\)]\)[t] - 
            0.03225825116512568`\ \(c[\(-28\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-27\)]\)[t] - 
            0.0486466672430994`\ \(c[\(-26\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-25\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-24\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-23\)]\)[t] - 
            0.05606123915856713`\ \(c[\(-22\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-21\)]\)[t] - 
            0.04491462243337629`\ \(c[\(-20\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-19\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-18\)]\)[t] - 
            0.013061910521147276`\ \(c[\(-17\)]\)[t] + 
            1.5206810699945212`*^-16\ \(c[\(-16\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-15\)]\)[t] + 
            0.026603074225527937`\ \(c[\(-14\)]\)[t] + 
            0.03897872015786009`\ \(c[\(-13\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-12\)]\)[t] + 
            0.0590709530809064`\ \(c[\(-11\)]\)[t] + 
            0.06581101988179631`\ \(c[\(-10\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-9\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-8\)]\)[t] + 
            0.06880242987642332`\ \(c[\(-7\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-6\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-5\)]\)[t] + 
            0.044547108751839815`\ \(c[\(-4\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-3\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-2\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-1\)]\)[t] - 
            0.0168255118577494`\ \(c[0]\)[t] - 
            0.03348317962868157`\ \(c[1]\)[t] - 
            0.049236278094139066`\ \(c[2]\)[t] - 
            0.06336169950422753`\ \(c[3]\)[t] - 
            0.0751812130120626`\ \(c[4]\)[t] - 
            0.08409185873785086`\ \(c[5]\)[t] - 
            0.08959419377036688`\ \(c[6]\)[t] - 
            0.09131715903518159`\ \(c[7]\)[t] - 
            0.08903843866360665`\ \(c[8]\)[t] - 
            0.08269933431326874`\ \(c[9]\)[t] - 
            0.07241337086197412`\ \(c[10]\)[t] - 
            0.05846808023678991`\ \(c[11]\)[t] - 
            0.04131966847794722`\ \(c[12]\)[t] - 
            0.02158054781754788`\ \(c[13]\)[t] + 
            3.8981718325193755`*^-17\ \(c[14]\)[t] + 
            0.02256148180925487`\ \(c[15]\)[t] + 
            0.0451633585689193`\ \(c[16]\)[t] + 
            0.06682066312775997`\ \(c[17]\)[t] + 
            0.08654280907894489`\ \(c[18]\)[t] + 
            0.10337416789158609`\ \(c[19]\)[t] + 
            0.11643488132933186`\ \(c[20]\)[t] + 
            0.12496032289024853`\ \(c[21]\)[t] + 
            0.12833762891430928`\ \(c[22]\)[t] + 
            0.12613778810677612`\ \(c[23]\)[t] + 
            0.11814190616181253`\ \(c[24]\)[t] + 
            0.10436044624225685`\ \(c[25]\)[t] + 
            0.08504448034442161`\ \(c[26]\)[t] + 
            0.060688263076985`\ \(c[27]\)[t] + 
            0.032022748374425904`\ \(c[28]\)[t] - 
            1.8033970416801674`*^-16\ \(c[29]\)[t] - 
            0.034231213779559094`\ \(c[30]\)[t] - 
            0.06935801494512607`\ \(c[31]\)[t] - 
            0.1039432537542934`\ \(c[32]\)[t] - 
            0.13647135277833616`\ \(c[33]\)[t] - 
            0.1653986686265377`\ \(c[34]\)[t] - 
            0.18920668216016434`\ \(c[35]\)[t] - 
            0.20645618564475848`\ \(c[36]\)[t] - 
            0.21584055771952015`\ \(c[37]\)[t] - 
            0.21623620818304481`\ \(c[38]\)[t] - 
            0.2067483357831719`\ \(c[39]\)[t] - 
            0.18675027222298593`\ \(c[40]\)[t] - 
            0.15591488063143982`\ \(c[41]\)[t] - 
            0.11423673049785416`\ \(c[42]\)[t] - 
            0.06204407497545024`\ \(c[43]\)[t] + 
            3.898171832519376`*^-17\ \(c[44]\)[t] + 
            0.0709075142576581`\ \(c[45]\)[t] + 
            0.14938649372796384`\ \(c[46]\)[t] + 
            0.23387232094715985`\ \(c[47]\)[t] + 
            0.3225686520215219`\ \(c[48]\)[t] + 
            0.4134966715663443`\ \(c[49]\)[t] + 
            0.5045511524271047`\ \(c[50]\)[t] + 
            0.5935615337286809`\ \(c[51]\)[t] + 
            0.6783560385470636`\ \(c[52]\)[t] + 
            0.7568267286406569`\ \(c[53]\)[t] + 
            0.8269933431326885`\ \(c[54]\)[t] + 
            0.8870637930591839`\ \(c[55]\)[t] + 
            0.9354892837886392`\ \(c[56]\)[t] + 
            0.9710122092317629`\ \(c[57]\)[t] + 
            0.9927051996072069`\ \(c[58]\)[t] + 
            77.34687315598232`\ \(c[59]\)[t] + 
            0.9927051996072067`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 59, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 59]][ t]], 
          Plus[ 
            Times[ -0.0083420605009009823, 
              c[ -60][ t]], 
            Times[ -0.016457834054775768, 
              c[ -59][ t]], 
            Times[ -0.023986904712529358, 
              c[ -58][ t]], 
            Times[ -0.030588406657213296, 
              c[ -57][ t]], 
            Times[ -0.035956232310116944, 
              c[ -56][ t]], 
            Times[ -0.039832985717929335, 
              c[ -55][ t]], 
            Times[ -0.042022055485216314, 
              c[ -54][ t]], 
            Times[ -0.042397252409191441, 
              c[ -53][ t]], 
            Times[ -0.040909552899494925, 
              c[ -52][ t]], 
            Times[ -0.037590606506031236, 
              c[ -51][ t]], 
            Times[ -0.032552799745291051, 
              c[ -50][ t]], 
            Times[ -0.025985813438573278, 
              c[ -49][ t]], 
            Times[ -0.018149760920219783, 
              c[ -48][ t]], 
            Times[ -0.0093651433925206785, 
              c[ -47][ t]], 
            Times[ 2.0053370214556287*^-16, 
              c[ -46][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -45][ t]], 
            Times[ 0.018854606004500389, 
              c[ -44][ t]], 
            Times[ 0.027514390699665887, 
              c[ -43][ t]], 
            Times[ 0.035131239329076656, 
              c[ -42][ t]], 
            Times[ 0.041349667156634483, 
              c[ -41][ t]], 
            Times[ 0.045868286584282311, 
              c[ -40][ t]], 
            Times[ 0.048454002753361682, 
              c[ -39][ t]], 
            Times[ 0.048953528554942699, 
              c[ -38][ t]], 
            Times[ 0.047301670540041058, 
              c[ -37][ t]], 
            Times[ 0.043525965428036162, 
              c[ -36][ t]], 
            Times[ 0.03774739544932687, 
              c[ -35][ t]], 
            Times[ 0.030177073670601094, 
              c[ -34][ t]], 
            Times[ 0.021108961070255627, 
              c[ -33][ t]], 
            Times[ 0.010908848347331785, 
              c[ -32][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -31][ t]], 
            Times[ -0.011153991006822649, 
              c[ -30][ t]], 
            Times[ -0.022068459300722043, 
              c[ -29][ t]], 
            Times[ -0.032258251165125679, 
              c[ -28][ t]], 
            Times[ -0.041258781072520248, 
              c[ -27][ t]], 
            Times[ -0.048646667243099399, 
              c[ -26][ t]], 
            Times[ -0.054059052045761224, 
              c[ -25][ t]], 
            Times[ -0.057210750238908967, 
              c[ -24][ t]], 
            Times[ -0.057908442314993203, 
              c[ -23][ t]], 
            Times[ -0.05606123915856713, 
              c[ -22][ t]], 
            Times[ -0.05168708394579296, 
              c[ -21][ t]], 
            Times[ -0.044914622433376288, 
              c[ -20][ t]], 
            Times[ -0.035980357068793781, 
              c[ -19][ t]], 
            Times[ -0.025221096343682053, 
              c[ -18][ t]], 
            Times[ -0.013061910521147276, 
              c[ -17][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ -16][ t]], 
            Times[ 0.013414935129827233, 
              c[ -15][ t]], 
            Times[ 0.026603074225527937, 
              c[ -14][ t]], 
            Times[ 0.038978720157860088, 
              c[ -13][ t]], 
            Times[ 0.049975424961080865, 
              c[ -12][ t]], 
            Times[ 0.059070953080906402, 
              c[ -11][ t]], 
            Times[ 0.065811019881796315, 
              c[ -10][ t]], 
            Times[ 0.069830768673962415, 
              c[ -9][ t]], 
            Times[ 0.070873018952678238, 
              c[ -8][ t]], 
            Times[ 0.068802429876423321, 
              c[ -7][ t]], 
            Times[ 0.063614872548668253, 
              c[ -6][ t]], 
            Times[ 0.055441487066198933, 
              c[ -5][ t]], 
            Times[ 0.044547108751839815, 
              c[ -4][ t]], 
            Times[ 0.031322974491347078, 
              c[ -3][ t]], 
            Times[ 0.016273855731265604, 
              c[ -2][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -1][ t]], 
            Times[ -0.016825511857749401, 
              c[ 0][ t]], 
            Times[ -0.033483179628681567, 
              c[ 1][ t]], 
            Times[ -0.049236278094139066, 
              c[ 2][ t]], 
            Times[ -0.063361699504227528, 
              c[ 3][ t]], 
            Times[ -0.075181213012062598, 
              c[ 4][ t]], 
            Times[ -0.084091858737850855, 
              c[ 5][ t]], 
            Times[ -0.089594193770366884, 
              c[ 6][ t]], 
            Times[ -0.091317159035181589, 
              c[ 7][ t]], 
            Times[ -0.089038438663606653, 
              c[ 8][ t]], 
            Times[ -0.082699334313268744, 
              c[ 9][ t]], 
            Times[ -0.072413370861974122, 
              c[ 10][ t]], 
            Times[ -0.058468080236789913, 
              c[ 11][ t]], 
            Times[ -0.04131966847794722, 
              c[ 12][ t]], 
            Times[ -0.021580547817547879, 
              c[ 13][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 14][ t]], 
            Times[ 0.022561481809254869, 
              c[ 15][ t]], 
            Times[ 0.045163358568919301, 
              c[ 16][ t]], 
            Times[ 0.066820663127759972, 
              c[ 17][ t]], 
            Times[ 0.086542809078944891, 
              c[ 18][ t]], 
            Times[ 0.10337416789158609, 
              c[ 19][ t]], 
            Times[ 0.11643488132933186, 
              c[ 20][ t]], 
            Times[ 0.12496032289024853, 
              c[ 21][ t]], 
            Times[ 0.12833762891430928, 
              c[ 22][ t]], 
            Times[ 0.12613778810677612, 
              c[ 23][ t]], 
            Times[ 0.11814190616181253, 
              c[ 24][ t]], 
            Times[ 0.10436044624225685, 
              c[ 25][ t]], 
            Times[ 0.085044480344421608, 
              c[ 26][ t]], 
            Times[ 0.060688263076985001, 
              c[ 27][ t]], 
            Times[ 0.032022748374425904, 
              c[ 28][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 29][ t]], 
            Times[ -0.034231213779559094, 
              c[ 30][ t]], 
            Times[ -0.06935801494512607, 
              c[ 31][ t]], 
            Times[ -0.1039432537542934, 
              c[ 32][ t]], 
            Times[ -0.13647135277833616, 
              c[ 33][ t]], 
            Times[ -0.16539866862653771, 
              c[ 34][ t]], 
            Times[ -0.18920668216016434, 
              c[ 35][ t]], 
            Times[ -0.20645618564475848, 
              c[ 36][ t]], 
            Times[ -0.21584055771952015, 
              c[ 37][ t]], 
            Times[ -0.21623620818304481, 
              c[ 38][ t]], 
            Times[ -0.20674833578317189, 
              c[ 39][ t]], 
            Times[ -0.18675027222298593, 
              c[ 40][ t]], 
            Times[ -0.15591488063143982, 
              c[ 41][ t]], 
            Times[ -0.11423673049785416, 
              c[ 42][ t]], 
            Times[ -0.062044074975450239, 
              c[ 43][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 44][ t]], 
            Times[ 0.070907514257658094, 
              c[ 45][ t]], 
            Times[ 0.14938649372796384, 
              c[ 46][ t]], 
            Times[ 0.23387232094715985, 
              c[ 47][ t]], 
            Times[ 0.32256865202152191, 
              c[ 48][ t]], 
            Times[ 0.41349667156634429, 
              c[ 49][ t]], 
            Times[ 0.50455115242710469, 
              c[ 50][ t]], 
            Times[ 0.59356153372868092, 
              c[ 51][ t]], 
            Times[ 0.67835603854706361, 
              c[ 52][ t]], 
            Times[ 0.75682672864065692, 
              c[ 53][ t]], 
            Times[ 0.82699334313268846, 
              c[ 54][ t]], 
            Times[ 0.88706379305918392, 
              c[ 55][ t]], 
            Times[ 0.93548928378863916, 
              c[ 56][ t]], 
            Times[ 0.9710122092317629, 
              c[ 57][ t]], 
            Times[ 0.99270519960720693, 
              c[ 58][ t]], 
            Times[ 77.346873155982323, 
              c[ 59][ t]], 
            Times[ 0.99270519960720671, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "60", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[60]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-3.898171832519376`*^-17\)\ \(c[\(-60\)]\)[t] - 
            0.008342060500900982`\ \(c[\(-59\)]\)[t] - 
            0.01645783405477577`\ \(c[\(-58\)]\)[t] - 
            0.023986904712529237`\ \(c[\(-57\)]\)[t] - 
            0.030588406657213296`\ \(c[\(-56\)]\)[t] - 
            0.03595623231011687`\ \(c[\(-55\)]\)[t] - 
            0.039832985717929335`\ \(c[\(-54\)]\)[t] - 
            0.042022055485216314`\ \(c[\(-53\)]\)[t] - 
            0.04239725240919144`\ \(c[\(-52\)]\)[t] - 
            0.040909552899494966`\ \(c[\(-51\)]\)[t] - 
            0.037590606506031236`\ \(c[\(-50\)]\)[t] - 
            0.032552799745291155`\ \(c[\(-49\)]\)[t] - 
            0.02598581343857328`\ \(c[\(-48\)]\)[t] - 
            0.018149760920219783`\ \(c[\(-47\)]\)[t] - 
            0.009365143392520679`\ \(c[\(-46\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-45\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-44\)]\)[t] + 
            0.018854606004500233`\ \(c[\(-43\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-42\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-41\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-40\)]\)[t] + 
            0.045868286584282256`\ \(c[\(-39\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-38\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-37\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-36\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-35\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-34\)]\)[t] + 
            0.030177073670601236`\ \(c[\(-33\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-32\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-31\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-30\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-29\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-28\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-27\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-26\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-25\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-24\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-23\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-22\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-21\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-20\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-19\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-18\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-17\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-16\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-15\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-14\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-13\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-12\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-11\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-10\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-9\)]\)[t] + 
            0.06983076867396239`\ \(c[\(-8\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-7\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-6\)]\)[t] + 
            0.06361487254866832`\ \(c[\(-5\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-4\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-3\)]\)[t] + 
            0.0313229744913472`\ \(c[\(-2\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-1\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[0]\)[t] - 
            0.016825511857749262`\ \(c[1]\)[t] - 
            0.03348317962868157`\ \(c[2]\)[t] - 
            0.04923627809413894`\ \(c[3]\)[t] - 
            0.0633616995042274`\ \(c[4]\)[t] - 
            0.0751812130120626`\ \(c[5]\)[t] - 
            0.08409185873785081`\ \(c[6]\)[t] - 
            0.08959419377036684`\ \(c[7]\)[t] - 
            0.09131715903518159`\ \(c[8]\)[t] - 
            0.0890384386636067`\ \(c[9]\)[t] - 
            0.08269933431326881`\ \(c[10]\)[t] - 
            0.07241337086197425`\ \(c[11]\)[t] - 
            0.05846808023678991`\ \(c[12]\)[t] - 
            0.04131966847794737`\ \(c[13]\)[t] - 
            0.021580547817548056`\ \(c[14]\)[t] + 
            3.8981718325193755`*^-17\ \(c[15]\)[t] + 
            0.022561481809254675`\ \(c[16]\)[t] + 
            0.045163358568919114`\ \(c[17]\)[t] + 
            0.06682066312775997`\ \(c[18]\)[t] + 
            0.08654280907894475`\ \(c[19]\)[t] + 
            0.10337416789158595`\ \(c[20]\)[t] + 
            0.11643488132933186`\ \(c[21]\)[t] + 
            0.12496032289024847`\ \(c[22]\)[t] + 
            0.12833762891430925`\ \(c[23]\)[t] + 
            0.12613778810677614`\ \(c[24]\)[t] + 
            0.1181419061618126`\ \(c[25]\)[t] + 
            0.10436044624225692`\ \(c[26]\)[t] + 
            0.0850444803444217`\ \(c[27]\)[t] + 
            0.06068826307698522`\ \(c[28]\)[t] + 
            0.03202274837442603`\ \(c[29]\)[t] - 
            3.898171832519376`*^-17\ \(c[30]\)[t] - 
            0.034231213779558796`\ \(c[31]\)[t] - 
            0.06935801494512592`\ \(c[32]\)[t] - 
            0.10394325375429328`\ \(c[33]\)[t] - 
            0.1364713527783359`\ \(c[34]\)[t] - 
            0.1653986686265376`\ \(c[35]\)[t] - 
            0.18920668216016426`\ \(c[36]\)[t] - 
            0.20645618564475834`\ \(c[37]\)[t] - 
            0.21584055771952013`\ \(c[38]\)[t] - 
            0.21623620818304484`\ \(c[39]\)[t] - 
            0.20674833578317206`\ \(c[40]\)[t] - 
            0.18675027222298618`\ \(c[41]\)[t] - 
            0.15591488063143982`\ \(c[42]\)[t] - 
            0.11423673049785459`\ \(c[43]\)[t] - 
            0.06204407497545072`\ \(c[44]\)[t] + 
            3.898171832519376`*^-17\ \(c[45]\)[t] + 
            0.07090751425765746`\ \(c[46]\)[t] + 
            0.14938649372796314`\ \(c[47]\)[t] + 
            0.23387232094715985`\ \(c[48]\)[t] + 
            0.32256865202152113`\ \(c[49]\)[t] + 
            0.4134966715663436`\ \(c[50]\)[t] + 
            0.5045511524271047`\ \(c[51]\)[t] + 
            0.5935615337286801`\ \(c[52]\)[t] + 
            0.6783560385470627`\ \(c[53]\)[t] + 
            0.7568267286406569`\ \(c[54]\)[t] + 
            0.826993343132688`\ \(c[55]\)[t] + 
            0.8870637930591835`\ \(c[56]\)[t] + 
            0.9354892837886392`\ \(c[57]\)[t] + 
            0.9710122092317629`\ \(c[58]\)[t] + 
            0.9927051996072067`\ \(c[59]\)[t] + 
            79.95683520871486`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 60, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 60]][ t]], 
          Plus[ 
            Times[ -3.8981718325193761*^-17, 
              c[ -60][ t]], 
            Times[ -0.0083420605009009823, 
              c[ -59][ t]], 
            Times[ -0.016457834054775768, 
              c[ -58][ t]], 
            Times[ -0.023986904712529237, 
              c[ -57][ t]], 
            Times[ -0.030588406657213296, 
              c[ -56][ t]], 
            Times[ -0.035956232310116867, 
              c[ -55][ t]], 
            Times[ -0.039832985717929335, 
              c[ -54][ t]], 
            Times[ -0.042022055485216314, 
              c[ -53][ t]], 
            Times[ -0.042397252409191441, 
              c[ -52][ t]], 
            Times[ -0.040909552899494966, 
              c[ -51][ t]], 
            Times[ -0.037590606506031236, 
              c[ -50][ t]], 
            Times[ -0.032552799745291155, 
              c[ -49][ t]], 
            Times[ -0.025985813438573278, 
              c[ -48][ t]], 
            Times[ -0.018149760920219783, 
              c[ -47][ t]], 
            Times[ -0.0093651433925206785, 
              c[ -46][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -45][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -44][ t]], 
            Times[ 0.018854606004500233, 
              c[ -43][ t]], 
            Times[ 0.027514390699665887, 
              c[ -42][ t]], 
            Times[ 0.035131239329076656, 
              c[ -41][ t]], 
            Times[ 0.041349667156634483, 
              c[ -40][ t]], 
            Times[ 0.045868286584282256, 
              c[ -39][ t]], 
            Times[ 0.048454002753361682, 
              c[ -38][ t]], 
            Times[ 0.04895352855494272, 
              c[ -37][ t]], 
            Times[ 0.047301670540041058, 
              c[ -36][ t]], 
            Times[ 0.043525965428036162, 
              c[ -35][ t]], 
            Times[ 0.03774739544932687, 
              c[ -34][ t]], 
            Times[ 0.030177073670601236, 
              c[ -33][ t]], 
            Times[ 0.021108961070255627, 
              c[ -32][ t]], 
            Times[ 0.010908848347331966, 
              c[ -31][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -30][ t]], 
            Times[ -0.011153991006822649, 
              c[ -29][ t]], 
            Times[ -0.022068459300722043, 
              c[ -28][ t]], 
            Times[ -0.032258251165125519, 
              c[ -27][ t]], 
            Times[ -0.041258781072520248, 
              c[ -26][ t]], 
            Times[ -0.048646667243099281, 
              c[ -25][ t]], 
            Times[ -0.054059052045761224, 
              c[ -24][ t]], 
            Times[ -0.057210750238908967, 
              c[ -23][ t]], 
            Times[ -0.057908442314993203, 
              c[ -22][ t]], 
            Times[ -0.056061239158567186, 
              c[ -21][ t]], 
            Times[ -0.05168708394579296, 
              c[ -20][ t]], 
            Times[ -0.044914622433376419, 
              c[ -19][ t]], 
            Times[ -0.035980357068793781, 
              c[ -18][ t]], 
            Times[ -0.025221096343682053, 
              c[ -17][ t]], 
            Times[ -0.013061910521147383, 
              c[ -16][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -15][ t]], 
            Times[ 0.013414935129827233, 
              c[ -14][ t]], 
            Times[ 0.026603074225527826, 
              c[ -13][ t]], 
            Times[ 0.03897872015785999, 
              c[ -12][ t]], 
            Times[ 0.049975424961080865, 
              c[ -11][ t]], 
            Times[ 0.059070953080906326, 
              c[ -10][ t]], 
            Times[ 0.065811019881796273, 
              c[ -9][ t]], 
            Times[ 0.069830768673962387, 
              c[ -8][ t]], 
            Times[ 0.070873018952678238, 
              c[ -7][ t]], 
            Times[ 0.068802429876423349, 
              c[ -6][ t]], 
            Times[ 0.063614872548668322, 
              c[ -5][ t]], 
            Times[ 0.055441487066198933, 
              c[ -4][ t]], 
            Times[ 0.044547108751839919, 
              c[ -3][ t]], 
            Times[ 0.031322974491347202, 
              c[ -2][ t]], 
            Times[ 0.016273855731265604, 
              c[ -1][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 0][ t]], 
            Times[ -0.016825511857749262, 
              c[ 1][ t]], 
            Times[ -0.033483179628681567, 
              c[ 2][ t]], 
            Times[ -0.049236278094138941, 
              c[ 3][ t]], 
            Times[ -0.063361699504227403, 
              c[ 4][ t]], 
            Times[ -0.075181213012062598, 
              c[ 5][ t]], 
            Times[ -0.084091858737850814, 
              c[ 6][ t]], 
            Times[ -0.089594193770366842, 
              c[ 7][ t]], 
            Times[ -0.091317159035181589, 
              c[ 8][ t]], 
            Times[ -0.089038438663606695, 
              c[ 9][ t]], 
            Times[ -0.082699334313268813, 
              c[ 10][ t]], 
            Times[ -0.072413370861974247, 
              c[ 11][ t]], 
            Times[ -0.058468080236789913, 
              c[ 12][ t]], 
            Times[ -0.041319668477947373, 
              c[ 13][ t]], 
            Times[ -0.021580547817548056, 
              c[ 14][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 15][ t]], 
            Times[ 0.022561481809254675, 
              c[ 16][ t]], 
            Times[ 0.045163358568919114, 
              c[ 17][ t]], 
            Times[ 0.066820663127759972, 
              c[ 18][ t]], 
            Times[ 0.086542809078944752, 
              c[ 19][ t]], 
            Times[ 0.10337416789158595, 
              c[ 20][ t]], 
            Times[ 0.11643488132933186, 
              c[ 21][ t]], 
            Times[ 0.12496032289024847, 
              c[ 22][ t]], 
            Times[ 0.12833762891430925, 
              c[ 23][ t]], 
            Times[ 0.12613778810677614, 
              c[ 24][ t]], 
            Times[ 0.1181419061618126, 
              c[ 25][ t]], 
            Times[ 0.10436044624225692, 
              c[ 26][ t]], 
            Times[ 0.085044480344421705, 
              c[ 27][ t]], 
            Times[ 0.060688263076985223, 
              c[ 28][ t]], 
            Times[ 0.032022748374426029, 
              c[ 29][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 30][ t]], 
            Times[ -0.034231213779558796, 
              c[ 31][ t]], 
            Times[ -0.069358014945125918, 
              c[ 32][ t]], 
            Times[ -0.10394325375429328, 
              c[ 33][ t]], 
            Times[ -0.13647135277833591, 
              c[ 34][ t]], 
            Times[ -0.1653986686265376, 
              c[ 35][ t]], 
            Times[ -0.18920668216016426, 
              c[ 36][ t]], 
            Times[ -0.20645618564475834, 
              c[ 37][ t]], 
            Times[ -0.21584055771952013, 
              c[ 38][ t]], 
            Times[ -0.21623620818304484, 
              c[ 39][ t]], 
            Times[ -0.20674833578317206, 
              c[ 40][ t]], 
            Times[ -0.18675027222298618, 
              c[ 41][ t]], 
            Times[ -0.15591488063143982, 
              c[ 42][ t]], 
            Times[ -0.11423673049785459, 
              c[ 43][ t]], 
            Times[ -0.062044074975450718, 
              c[ 44][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 45][ t]], 
            Times[ 0.070907514257657456, 
              c[ 46][ t]], 
            Times[ 0.14938649372796314, 
              c[ 47][ t]], 
            Times[ 0.23387232094715985, 
              c[ 48][ t]], 
            Times[ 0.32256865202152113, 
              c[ 49][ t]], 
            Times[ 0.41349667156634362, 
              c[ 50][ t]], 
            Times[ 0.50455115242710469, 
              c[ 51][ t]], 
            Times[ 0.59356153372868015, 
              c[ 52][ t]], 
            Times[ 0.67835603854706272, 
              c[ 53][ t]], 
            Times[ 0.75682672864065692, 
              c[ 54][ t]], 
            Times[ 0.82699334313268802, 
              c[ 55][ t]], 
            Times[ 0.88706379305918348, 
              c[ 56][ t]], 
            Times[ 0.93548928378863916, 
              c[ 57][ t]], 
            Times[ 0.9710122092317629, 
              c[ 58][ t]], 
            Times[ 0.99270519960720671, 
              c[ 59][ t]], 
            Times[ 79.956835208714864, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        Plot[Abs[\[Psi][x, t]]^2, {x, \(-15\), 15}, PlotRange \[Rule] {0, 1}, 
          PlotLabel \[Rule] \*"\"\<(|\[Psi][x,t]|\!\(\()\^2\)\), t= \>\"" <> 
              ToString[t], AxesLabel \[Rule] {"\<x\>", "\<\>"}], {t, 0, 
          2.4,  .1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.51"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -52.625 0 ]
[.5 .63053 52.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -113.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
164.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.04262 0 L
.06244 0 L
.08255 0 L
.10458 0 L
.12415 0 L
.14509 0 L
.16639 0 L
.18653 0 L
.20651 0 L
.22495 0 L
.23397 0 L
.24367 0 L
.24923 0 L
.25432 0 L
.25677 0 L
.25744 0 L
.25815 0 L
.25944 0 L
.26075 0 L
.26199 0 L
.2631 0 L
.2643 0 L
.26667 0 L
.26735 0 L
.268 0 L
.26921 0 L
.27036 0 L
.27141 0 L
.27257 0 L
.2738 0 L
.27504 0 L
.27573 0 L
.27636 0 L
.27753 0 L
.27876 0 L
.27942 0 L
.28012 0 L
.28138 0 L
.28215 0 L
.28288 0 L
.28353 0 L
.28424 0 L
.28555 0 L
.28677 0 L
.28748 1e-05 L
.28812 1e-05 L
.28886 1e-05 L
.28956 1e-05 L
.29024 2e-05 L
Mistroke
.29096 3e-05 L
.29226 4e-05 L
.29305 6e-05 L
.2938 8e-05 L
.29447 .0001 L
.2952 .00013 L
.29642 .00021 L
.29711 .00027 L
.29776 .00034 L
.29907 .00053 L
.2998 .00067 L
.30046 .00083 L
.30166 .00122 L
.30295 .00182 L
.30417 .00263 L
.3053 .00365 L
.30648 .00508 L
.30773 .00711 L
.30879 .00939 L
.30995 .0126 L
.31121 .0171 L
.31254 .02336 L
.31381 .03097 L
.31495 .03955 L
.31719 .06187 L
.31961 .09604 L
.3219 .13938 L
.324 .18932 L
.32915 .34492 L
.33198 .43876 L
.33466 .51972 L
.33587 .5505 L
.33716 .57784 L
.33782 .58955 L
.33856 .60028 L
.33987 .61317 L
.34105 .61784 L
.34232 .61527 L
.34352 .60568 L
.34462 .59105 L
.34571 .5714 L
.34688 .54535 L
.34899 .48783 L
.35378 .33228 L
.3584 .1928 L
.36101 .13155 L
.36342 .08811 L
.36612 .05323 L
.36748 .04039 L
.36898 .0293 L
Mistroke
.37029 .02183 L
.3717 .01567 L
.37303 .0113 L
.37424 .00827 L
.37549 .00593 L
.37665 .0043 L
.37793 .00299 L
.37858 .00247 L
.37928 .002 L
.38058 .00134 L
.3818 .00091 L
.38298 .00062 L
.38408 .00043 L
.38534 .00028 L
.38654 .00018 L
.38761 .00012 L
.38878 8e-05 L
.39005 5e-05 L
.39069 4e-05 L
.3914 3e-05 L
.39265 2e-05 L
.39382 1e-05 L
.39493 1e-05 L
.39611 0 L
.39711 0 L
.3982 0 L
.39938 0 L
.40064 0 L
.40183 0 L
.40292 0 L
.40421 0 L
.40486 0 L
.40557 0 L
.40684 0 L
.40802 0 L
.40873 0 L
.40941 0 L
.41069 0 L
.4114 0 L
.41206 0 L
.41278 0 L
.41355 0 L
.41485 0 L
.41559 0 L
.41626 0 L
.41748 0 L
.41813 0 L
.41882 0 L
.42002 0 L
.42114 0 L
Mistroke
.42242 0 L
.42358 0 L
.42477 0 L
.42588 0 L
.42841 0 L
.43353 0 L
.44272 0 L
.45337 0 L
.4635 0 L
.48374 0 L
.50226 0 L
.52206 0 L
.54044 0 L
.56095 0 L
.57956 0 L
.60042 0 L
.61961 0 L
.65815 0 L
.67697 0 L
.69763 0 L
.71713 0 L
.73804 0 L
.74821 0 L
.75927 0 L
.76883 0 L
.77939 0 L
.78429 0 L
.78958 0 L
.79415 0 L
.79915 0 L
.80449 0 L
.8074 0 L
.80879 0 L
.81011 0 L
.81133 0 L
.81265 0 L
.81386 0 L
.81497 0 L
.81617 0 L
.81749 0 L
.81815 0 L
.81887 0 L
.82016 0 L
.82084 0 L
.82149 0 L
.8227 0 L
.824 0 L
.82541 0 L
.82795 0 L
.83028 0 L
Mistroke
.83565 0 L
.84132 0 L
.85091 0 L
.86142 0 L
.88096 0 L
.89191 0 L
.90188 0 L
.92261 0 L
.94177 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`0Rooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00GoA4A4o`000?l0003o<S8bomgMg@1Gooooo`05odA4A?l0003o0000oc8b<_oMgMd09oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo02Gooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool09?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00omgMgOo<S8booooo`1Iooooo`03ogMgMolb<S;ooooo02Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Uooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool6o`0000Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[
ooooo`03ogMgMolb<S;ooooo05Wooooo00?oMgMgoc8b<_ooool0:?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo02Gooooo000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0Eoooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001Wooooo
00?oEEEEofIVI_l000001Oooool4o`0002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo1?l0001Hooooo`Co0000:?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool00omEEEGoIVIVo`000005ooooo`Co00009oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooC_ooool2o`0000;ooooo0_l0000Eooooo`00oooooom>
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5Oooool00?ooooooCoooool01?oMgMgo0000oa0@
4?o<c<`Fooooo`005?ooooooo`00033o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hFooooo`006ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?oo
ool3o`0000Wooooo00?o0000ooooooooool01oooool3o`0000Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?oo
ool01?lQ8B7oMgMgogMgMolb<S8Fooooo`006oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo02;ooooo0_l00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`0001Gooooo001aooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`2jooooo`00LOooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0^_ooool007;o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0;[o
oooo001booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`2jooooo`00L_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0^_ooool007;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo0;[ooooo001cooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`2jooooo`00Loooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo02Gooooo0_l0002kooooo`00Loooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0^_ooool007?ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo0;[ooooo001cooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`2jooooo`00Loooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0^_ooool007?o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0;[o
oooo001dooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`2jooooo`00M?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0^_ooool007Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo0;[ooooo001dooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool09_ooool2o`000;_ooooo001dooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`2jooooo`00M?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0^_ooool007Cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0;[ooooo001dooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2jooooo`00M?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0^_ooool007Co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0;[o
oooo001dooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`2jooooo`00M?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0^_ooool007Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0V
ooooo`;o0000^oooool007Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo0;[ooooo001dooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`2jooooo`00M?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0^_ooool007Cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0;[ooooo001dooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2jooooo`00M?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0^_ooool007Co
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0;[ooooo001eooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`2j
ooooo`00MOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0^_ooool0
07Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`05o`000?oooooooooo
ooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000^_ooool007Gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0;[ooooo001eooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool03?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`2jooooo`00MOooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`2jooooo`00MOooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2jooooo`00MOooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0^_ooool007Gooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0;[ooooo001eoooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2joooo
o`00MOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool0^_ooool007Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Wooooo`;o0000
^oooool007Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo0;[ooooo001eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`2jooooo`00M_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool0^_ooool007Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo0;[ooooo001fooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`2jooooo`00M_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0^_ooool007Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0;[ooooo001foooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`2joooo
o`00M_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Sooooo0_l0002kooooo`00
M_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
^_ooool007Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo0;[ooooo001fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`2jooooo`00M_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool0^_ooool007Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo0;[ooooo001fooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`2jooooo`00M_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0^_ooool007Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0;[ooooo001foooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`2joooo
o`00M_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Sooooo0_l0002kooooo`00
M_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
^_ooool007Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo0;[ooooo001fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`2jooooo`00M_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool0^_ooool007Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo0;[ooooo001fooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool03Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o
000000?o410@ooooooooool01?ooool00ol0003oooooooooo`2jooooo`00M_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;[ooooo001fooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@00_o
oooo1Ol00006ooooo`03o`000?oooooooooo0;[ooooo001fooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoo
oooo00001oooool3o`000;[ooooo001fooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03Oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool0
0ol0003oooooooooo`2jooooo`00M_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00gooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000
ooooooooool0^_ooool007Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooo
oooo0;[ooooo001fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`2j
ooooo`00M_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0^_ooool007Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo0;[ooooo001gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`2jooooo`00Moooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0^_ooool007Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Yooooo`;o0000^oooool007Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo0;[ooooo001gooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2jooooo`00Moooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0^_ooool007Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0;[ooooo001g
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2j
ooooo`00Moooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0^_ooool007Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo0;[ooooo001gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`2jooooo`00Moooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0^_ooool007Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Yooooo`;o0000^oooool007Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo0;[ooooo001gooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2jooooo`00Moooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0^_ooool007Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0;[ooooo001g
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2j
ooooo`00Moooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0^_ooool007Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo0;[ooooo001gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`2jooooo`00Moooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02Wooooo0_l0002kooooo`00Moooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0^_ooool007Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo0;[ooooo001gooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2jooooo`00Moooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0^_ooool007Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0;[ooooo001g
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2j
ooooo`00Moooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o
0000ooooooooool0^_ooool007Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo0;[ooooo001gooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool03_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooo
ooooo`000006ooooo`?o0000^_ooool007Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0>ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool0^_ooool007Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0?ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0^_ooool007Oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0?ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08
ooooo`03o`000?oooooooooo0;[ooooo001gooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool03oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool0
0ol0003oooooooooo`2jooooo`00Moooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o
0000ooooooooool0^_ooool007Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo0;[ooooo001gooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`2jooooo`00N?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0^_ooool007Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0;[ooooo001hooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0:_ooool2o`000;_ooooo001hooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2jooooo`00N?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0^_ooool007So
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0;[o
oooo001hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`2jooooo`00N?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0^_ooool007Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo0;[ooooo001hooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`2jooooo`00N?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0^_ooool007Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Zooooo`;o0000^oooool007Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0;[ooooo001hooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2jooooo`00N?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0^_ooool007So
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0;[o
oooo001hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`2jooooo`00N?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool0^_ooool007Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo0;[ooooo001hooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`2jooooo`00N?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo02_ooooo0_l0002kooooo`00N?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0^_ooool007Sooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo0;[ooooo001hooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`2jooooo`00N?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0^_ooool007So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo0;[o
oooo001iooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`2jooooo`00
NOooool01Ol0003ooooooooooooooooo000001;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0^_ooool0
07Wooooo00Go0000ooooooooooooooooo`00000Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;[ooooo
001iooooo`05o`000?ooooooooooooooool000004_ooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;[ooooo001iooooo`05
o`000?ooooooooooooooool000004_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8b
oiRHV?ooooooV9RHoc8b<P06ooooo`?o0000^_ooool007Wooooo00Go0000ooooooooooooooooo`00
000Booooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Ko
oooo00?o0000ooooooooool0^_ooool007Wooooo00Go0000ooooooooooooooooo`00000Booooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000
ooooooooool0^_ooool007Wooooo00Go0000ooooooooooooooooo`00000Booooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0
^_ooool007Wooooo00Go0000ooooooooooooooooo`00000Booooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0^_ooool007Wo
oooo00Go0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo0;[ooooo001iooooo`05
o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`2jooooo`00NOooool01Ol0003o
oooooooooooooooo000002gooooo00?o0000ooooooooool0^_ooool007Wooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo0;[ooooo001iooooo`05o`000?oooooooooooooo
ool00000;Oooool2o`000;_ooooo001iooooo`05o`000?ooooooooooooooool00000;Oooool00ol0
003oooooooooo`2jooooo`00NOooool01Ol0003ooooooooooooooooo000002gooooo00?o0000oooo
ooooool0^_ooool007Wooooo00Go0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo
0;[ooooo001iooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`2joooo
o`00NOooool01Ol0003ooooooooooooooooo000002gooooo00?o0000ooooooooool0^_ooool007Wo
oooo00Go0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo0;[ooooo001iooooo`05
o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`2jooooo`00NOooool01Ol0003o
oooooooooooooooo000002gooooo00?o0000ooooooooool0^_ooool007Wooooo00Go0000oooooooo
ooooooooo`00000]ooooo`;o0000^oooool007Wooooo00Go0000ooooooooooooooooo`00000]oooo
o`03o`000?oooooooooo0;[ooooo001iooooo`04o`000?ooooooooooo`0002kooooo00?o0000oooo
ooooool0^_ooool007Wooooo00Co0000oooooooooooo0000;_ooool00ol0003oooooooooo`2joooo
o`00N_ooool00ol0003oooooo`00000^ooooo`03o`000?oooooooooo0;[ooooo001jooooo`03o`00
0?oooooo000002kooooo00?o0000ooooooooool0^_ooool007[ooooo00?o0000ooooool00000;_oo
ool00ol0003oooooooooo`2jooooo`00N_ooool00ol0003oooooo`00000^ooooo`03o`000?oooooo
oooo0;[ooooo001jooooo`03o`000?oooooo000002kooooo00?o0000ooooooooool0^_ooool007[o
oooo00?o0000ooooool00000;_ooool00ol0003oooooooooo`2jooooo`00N_ooool00ol0003ooooo
o`00000^ooooo`;o0000^oooool007[ooooo00?o0000ooooool00000;_ooool00ol0003ooooooooo
o`2jooooo`00N_ooool00ol0003oooooo`00000^ooooo`03o`000?oooooooooo0;[ooooo001joooo
o`03o`000?oooooo000002kooooo00?o0000ooooooooool0^_ooool007[ooooo00?o0000ooooool0
0000;_ooool00ol0003oooooooooo`2jooooo`00N_ooool00ol0003oooooo`00000^ooooo`03o`00
0?oooooooooo0;[ooooo001jooooo`03o`000?oooooo000002kooooo00?o0000ooooooooool0^_oo
ool007_ooooo00?o0000ooooooooool08oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0^_ooool007_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0;[ooooo001kooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool01Oooool3o`000;[ooooo002Sooooo`03o`000?oooooooooo0<;ooooo002Sooooo`03o`000?oo
oooooooo0<;ooooo002Sooooo`03o`000?oooooooooo0<;ooooo002Sooooo`03o`000?oooooooooo
0<;ooooo002Qooooo`03oeEEEOmVIVKo00000<Cooooo003oooooofWooooo001aooooo`03ogMgMomV
IVKooooo00?ooooo00?o0000ooooooooool00oooool00onj^[[o<S8booooo`06ooooo`;o00002ooo
ool00ol0003o^[Zjooooo`0<ooooo`;o00002?ooool01_l0003oooooooooooooooooIVIVogMgM`go
oooo00?o0000okZj^_ooool0Y_ooool0073ooooo00?ogMgMoa0@4?o^k^h01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo
00?o0000ooooooooool01_ooool01ol0003oooooooooooooooook^k^oa0@4?oMgMd03?ooool2oc8b
<ZOooooo001`ooooo`03oeEEEOnHV9Sooooo00Cooooo00?o0000ooooooooool00_ooool01OnHV9So
410@o`000?l0003oZJVY00Gooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l00002oooo
o`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00_ooool00on7QhOoIVIVooooo`0;ooooo`03ohN7Qol0003o
^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
Ooooool0073ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`06o`000?nY
ZJWoEEEEoiRHV?mEEEGo^[Zj1?ooool00ol0003oooooooooo`02ooooo`06onk^k_lQ8B7oQhN7okZj
^_l0003ogMgM0_ooool00oo<c<co0000oa0@4005ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?ok^k^o`000?ooool02ooo
ool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool6o`0000Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`1oooooo`00L?ooool00olb<S;oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00Ko<S8bonk^k_nHV9SoEEEEomgMgOl@4104ooooo`03o`000?oooooooooo
00?ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01?ooooo00Go410@oooooooooooooooooa0@401oooooo`00L?ooool00olb<S;oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00Oo^[ZjodA4A?o<c<co8B4Qooooool@413oc<c<00?ooooo
00?o0000ooooooooool00oooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool01?ooool6o`0000Wooooo00Go0000ooooooooooooooooo`00001ooooo
o`00L?ooool00ol0003ok^k^ooooo`04ooooo`03o`000?oooooooooo00;ooooo00Ook^k^o`000?oo
oooo0000oooooomVIVKoQhN700?ooooo00?o0000ooooooooool00oooool01?lQ8B7oMgMgogMgMolb
<S8;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`03onk^k_l0003ooooo01[ooooo00?o0000ooooooooool04oooool01Ol0003ooooooooo
oooooooo000007oooooo001`ooooo`03oeEEEOmgMgOooooo00Cooooo00?o0000ooooooooool00_oo
ool01?mVIVKoV9RHoooooolb<S82okZj^P05o`000?ooooooooooooooool000001?ooool2o`0000;o
oooo0_l00008ooooo`03oa0@4?l0003o000000?o00001?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00;ooooo00?oMgMgoeEEEOooool00oooool4o`00017ooooo00?o410@o`000?l0
00000ol0000Booooo`05oa0@4?ooooooooooooooool@4100Ooooool0073ooooo00?ogMgMoa0@4?o^
k^h01?ooool00ol0003oooooooooo`05ooooo`03ofIVI_n7QhOooooo00Cooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00Oo0000oooooooo
ooooooooonk^k_l@413ogMgM00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0C
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Ooooool0077ooooo00?oMgMgofIVI_ooool00oooool0
0ol0003oooooooooo`05ooooo`03ojVYZOm4A4Cooooo00Cooooo0_l0000Cooooo`03o`000?oooooo
oooo00Cooooo0_l00008ooooo`06o`000?oooooooooooooooomVIVKoMgMg1oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1oooooo`00
^_ooool00ol0003oooooooooo`2[ooooo`00]oooool01?l0003oooooooooool0002]ooooo`00^?oo
ool2o`000:kooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.8522, -0.080387, \
0.130126, 0.00668404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
176.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.04262 0 L
.06244 0 L
.08255 0 L
.09409 0 L
.10458 0 L
.12415 0 L
.14509 0 L
.16424 0 L
.18502 0 L
.20486 0 L
.21486 0 L
.22588 0 L
.24692 0 L
.25175 0 L
.25446 0 L
.25691 0 L
.2592 0 L
.26168 0 L
.26282 0 L
.26402 0 L
.26505 0 L
.26617 0 L
.26741 0 L
.26854 0 L
.26985 0 L
.27109 0 L
.27223 0 L
.27329 0 L
.27568 0 L
.27691 0 L
.27807 0 L
.27934 0 L
.28005 0 L
.28071 0 L
.28195 0 L
.28265 0 L
.28331 0 L
.284 0 L
.28463 0 L
.28536 0 L
.28605 0 L
.28714 0 L
.28834 0 L
.28959 0 L
.29077 0 L
.29186 0 L
.29286 0 L
.29402 0 L
.29512 0 L
Mistroke
.2963 0 L
.29756 0 L
.29874 0 L
.29982 1e-05 L
.30109 1e-05 L
.3018 2e-05 L
.30246 2e-05 L
.30367 3e-05 L
.30494 5e-05 L
.30617 8e-05 L
.30686 .0001 L
.3075 .00012 L
.30867 .00019 L
.30992 .00028 L
.31103 .0004 L
.31207 .00055 L
.31322 .00078 L
.31445 .00112 L
.31568 .0016 L
.31704 .00234 L
.31845 .00342 L
.31976 .00481 L
.32099 .00655 L
.32211 .00861 L
.3234 .01167 L
.32462 .01538 L
.32685 .02484 L
.32797 .03123 L
.32921 .03974 L
.33139 .05936 L
.33343 .08384 L
.33584 .12143 L
.33803 .16448 L
.34297 .28851 L
.34777 .42467 L
.35039 .49101 L
.35168 .51817 L
.35287 .539 L
.35389 .55338 L
.35496 .56457 L
.35604 .57146 L
.35722 .57384 L
.35842 .57064 L
.35971 .56104 L
.36093 .54642 L
.36203 .52879 L
.37282 .24741 L
.37756 .1378 L
.38026 .09225 L
.38278 .06057 L
Mistroke
.38512 .03942 L
.38726 .02575 L
.38845 .02008 L
.38974 .01514 L
.39095 .0115 L
.39208 .0088 L
.39338 .00641 L
.39456 .00476 L
.39583 .00342 L
.3972 .00236 L
.3984 .00169 L
.39967 .00117 L
.40075 .00085 L
.40194 .0006 L
.40261 .00048 L
.40334 .00039 L
.40466 .00025 L
.40594 .00017 L
.40713 .00011 L
.40842 7e-05 L
.40915 6e-05 L
.40983 4e-05 L
.4105 3e-05 L
.41121 3e-05 L
.41199 2e-05 L
.4127 2e-05 L
.4139 1e-05 L
.41518 1e-05 L
.41639 0 L
.41749 0 L
.41878 0 L
.41951 0 L
.42019 0 L
.42142 0 L
.42273 0 L
.42394 0 L
.42526 0 L
.42651 0 L
.42767 0 L
.42882 0 L
.42985 0 L
.43105 0 L
.43218 0 L
.43341 0 L
.43472 0 L
.43585 0 L
.43705 0 L
.43836 0 L
.43957 0 L
.441 0 L
Mistroke
.44232 0 L
.44347 0 L
.44468 0 L
.4459 0 L
.4466 0 L
.44725 0 L
.44842 0 L
.44949 0 L
.45073 0 L
.45191 0 L
.45296 0 L
.45407 0 L
.45513 0 L
.45608 0 L
.45721 0 L
.45843 0 L
.45958 0 L
.46064 0 L
.46305 0 L
.46424 0 L
.46533 0 L
.46659 0 L
.46726 0 L
.46797 0 L
.46911 0 L
.47037 0 L
.47154 0 L
.47262 0 L
.47381 0 L
.47505 0 L
.47614 0 L
.47715 0 L
.47827 0 L
.47945 0 L
.4902 0 L
.50011 0 L
.50508 0 L
.50629 0 L
.50759 0 L
.50834 0 L
.50902 0 L
.5097 0 L
.51035 0 L
.51105 0 L
.51168 0 L
.5131 0 L
.51375 0 L
.51444 0 L
.51566 0 L
.51634 0 L
Mistroke
.51709 0 L
.51784 0 L
.51864 0 L
.5194 0 L
.5201 0 L
.52145 0 L
.5227 0 L
.52333 0 L
.52403 0 L
.52526 0 L
.52641 0 L
.52707 0 L
.52777 0 L
.52901 0 L
.53036 0 L
.5311 0 L
.5318 0 L
.53307 0 L
.53423 0 L
.53531 0 L
.53648 0 L
.5416 0 L
.54395 0 L
.5451 0 L
.54617 0 L
.5474 0 L
.54874 0 L
.54995 0 L
.55108 0 L
.55232 0 L
.55298 0 L
.55369 0 L
.5544 0 L
.55514 0 L
.55647 0 L
.5615 0 L
.56673 0 L
.5693 0 L
.57043 0 L
.57168 0 L
.57236 0 L
.573 0 L
.57368 0 L
.57441 0 L
.5752 0 L
.57596 0 L
.57664 0 L
.57737 0 L
.57868 0 L
.57939 0 L
Mistroke
.58006 0 L
.58137 0 L
.58256 0 L
.5837 0 L
.58496 0 L
.58618 0 L
.58749 0 L
.58872 0 L
.58984 0 L
.59096 0 L
.59203 0 L
.59326 0 L
.59457 0 L
.59569 0 L
.59693 0 L
.59762 0 L
.59825 0 L
.59895 0 L
.59968 0 L
.60092 0 L
.60162 0 L
.60227 0 L
.60341 0 L
.60466 0 L
.60583 0 L
.60692 0 L
.60789 0 L
.60897 0 L
.61008 0 L
.61114 0 L
.61238 0 L
.6135 0 L
.61472 0 L
.6154 0 L
.61604 0 L
.6172 0 L
.61826 0 L
.61948 0 L
.62062 0 L
.62179 0 L
.62304 0 L
.62422 0 L
.62529 0 L
.62656 0 L
.62727 0 L
.62793 0 L
.62913 0 L
.63041 0 L
.63164 0 L
.63295 0 L
Mistroke
.63419 0 L
.63533 0 L
.63602 0 L
.63666 0 L
.63742 0 L
.6381 0 L
.63938 0 L
.64008 0 L
.64075 0 L
.64182 0 L
.64299 0 L
.64422 0 L
.64537 0 L
.64644 0 L
.64742 0 L
.64855 0 L
.64962 0 L
.65078 0 L
.65201 0 L
.65308 0 L
.65422 0 L
.65545 0 L
.6566 0 L
.65727 0 L
.65797 0 L
.65923 0 L
.69732 0 L
.70823 0 L
.70888 0 L
.70958 0 L
.71084 0 L
.71215 0 L
.71291 0 L
.7136 0 L
.71481 0 L
.7155 0 L
.71614 0 L
.7173 0 L
.71855 0 L
.71975 0 L
.72105 0 L
.72228 0 L
.72341 0 L
.72451 0 L
.72555 0 L
.72663 0 L
.72781 0 L
.72911 0 L
.73035 0 L
.73145 0 L
Mistroke
.73266 0 L
.73397 0 L
.73463 0 L
.73536 0 L
.73664 0 L
.73785 0 L
.73913 0 L
.74034 0 L
.74101 0 L
.74173 0 L
.74299 0 L
.7442 0 L
.74548 0 L
.74657 0 L
.74778 0 L
.74902 0 L
.74972 0 L
.75035 0 L
.7516 0 L
.75276 0 L
.75341 0 L
.7541 0 L
.75487 0 L
.75556 0 L
.75622 0 L
.75693 0 L
.75822 0 L
.75938 0 L
.76047 0 L
.76167 0 L
.76295 0 L
.76359 0 L
.76429 0 L
.76556 0 L
.7668 0 L
.76794 0 L
.76901 0 L
.77 0 L
.77119 0 L
.77228 0 L
.77341 0 L
.77449 0 L
.77563 0 L
.77687 0 L
.77813 0 L
.7788 0 L
.7795 0 L
.78078 0 L
.78197 0 L
.78303 0 L
Mistroke
.78417 0 L
.78542 0 L
.78659 0 L
.78723 0 L
.78792 0 L
.78867 0 L
.78937 0 L
.79062 0 L
.79134 0 L
.79201 0 L
.79325 0 L
.79438 0 L
.79563 0 L
.79695 0 L
.79812 0 L
.79918 0 L
.8004 0 L
.80156 0 L
.80256 0 L
.80362 0 L
.80478 0 L
.80585 0 L
.807 0 L
.80824 0 L
.80942 0 L
.81049 0 L
.81174 0 L
.81245 0 L
.8131 0 L
.81429 0 L
.81559 0 L
.81688 0 L
.81758 0 L
.81824 0 L
.81942 0 L
.82068 0 L
.82139 0 L
.82216 0 L
.82289 0 L
.82356 0 L
.82483 0 L
.82547 0 L
.82618 0 L
.82747 0 L
.82866 0 L
.82996 0 L
.83062 0 L
.83132 0 L
.83252 0 L
.83363 0 L
Mistroke
.83495 0 L
.83615 0 L
.83731 0 L
.83854 0 L
.83959 0 L
.84075 0 L
.84199 0 L
.84269 0 L
.84332 0 L
.84456 0 L
.84573 0 L
.84682 0 L
.84797 0 L
.84896 0 L
.85005 0 L
.85122 0 L
.85248 0 L
.85367 0 L
.85476 0 L
.85604 0 L
.85724 0 L
.85832 0 L
.85949 0 L
.86077 0 L
.86147 0 L
.86212 0 L
.86328 0 L
.86455 0 L
.86573 0 L
.86684 0 L
.86785 0 L
.86894 0 L
.87013 0 L
.87139 0 L
.87258 0 L
.87366 0 L
.87496 0 L
.87561 0 L
.87633 0 L
.87761 0 L
.87878 0 L
.87949 0 L
.88016 0 L
.88093 0 L
.88165 0 L
.88293 0 L
.8836 0 L
.88432 0 L
.8855 0 L
.88678 0 L
Mistroke
.88798 0 L
.88909 0 L
.89031 0 L
.89101 0 L
.89165 0 L
.89296 0 L
.89368 0 L
.89435 0 L
.8956 0 L
.89627 0 L
.89698 0 L
.89825 0 L
.89941 0 L
.9001 0 L
.90075 0 L
.90152 0 L
.90222 0 L
.90351 0 L
.90422 0 L
.90488 0 L
.9061 0 L
.90737 0 L
.90846 0 L
.90966 0 L
.91095 0 L
.91167 0 L
.91233 0 L
.91361 0 L
.91482 0 L
.92373 0 L
.93341 0 L
.94277 0 L
.94406 0 L
.94479 0 L
.94547 0 L
.94671 0 L
.9474 0 L
.94803 0 L
.94922 0 L
.95051 0 L
.95173 0 L
.95285 0 L
.95349 0 L
.95417 0 L
.95541 0 L
.95616 0 L
.95688 0 L
.95752 0 L
.95822 0 L
.9589 0 L
Mistroke
.95965 0 L
.96043 0 L
.96117 0 L
.96248 0 L
.96322 0 L
.9639 0 L
.96515 0 L
.96631 0 L
.96759 0 L
.9683 0 L
.96895 0 L
.97026 0 L
.971 0 L
.97168 0 L
.97293 0 L
.97357 0 L
.97426 0 L
.97526 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`0Rooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00GoA4A4o`000?l0003o<S8bomgMg@1Gooooo`05odA4A?l0003o0000oc8b<_oMgMd09oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo02Gooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool09?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00omgMgOo<S8booooo`1Iooooo`03ogMgMolb<S;ooooo02Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Uooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool6o`0000Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[
ooooo`03ogMgMolb<S;ooooo05Wooooo00?oMgMgoc8b<_ooool0:?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo02Gooooo000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0Eoooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001Wooooo
00?oEEEEofIVI_l000001Oooool4o`0002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo1?l0001Hooooo`Co0000:?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool00omEEEGoIVIVo`000005ooooo`Co00009oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooC_ooool2o`0000;ooooo0_l0000Eooooo`00oooooom>
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5Oooool00?ooooooCoooool01?oMgMgo0000oa0@
4?o<c<`Fooooo`005?ooooooo`00033o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hFooooo`006ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool01?l0003oooooo`000?l00006ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0oooool4o`0000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo013ooooo00Co8B4QogMgMomgMgOo<S8b5_ooool001_ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0Vooooo`;o00001Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool03oooool2o`0000;ooooo0_l0000Eooooo`00MOoo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0^_oo
ool007Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo0;[ooooo001fooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`2jooooo`00M_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool0^_ooool007Oooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo0;[ooooo001gooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`2jooooo`00Moooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0^_ooool007Oooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Oooooo`;o0000^oooool007Oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0;[ooooo001gooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2jooooo`00Mooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0^_oo
ool007Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo0;[ooooo001gooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`2jooooo`00N?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool0^_ooool007Sooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo0;[ooooo001hooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`2jooooo`00N?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo023ooooo0_l0002kooooo`00N?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool0^_ooool007Sooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0;[ooooo001hooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2jooooo`00NOoo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0^_oo
ool007Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo0;[ooooo001iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`2jooooo`00NOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0^_ooool007Wooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo0;[ooooo001iooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool08Oooool2o`000;_ooooo001iooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`2jooooo`00NOooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0^_ooool007Wooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0;[ooooo001iooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`2jooooo`00NOoo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0^_oo
ool007Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo0;[ooooo001iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`2j
ooooo`00NOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o
0000ooooooooool0^_ooool007Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oo
oooooooo0;[ooooo001iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;[ooooo001i
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`2jooooo`00NOooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool007Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`07ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0^_ooool007Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0^_ooool007Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo0;[ooooo
001jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`2jooooo`00N_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool0^_ooool007[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo0;[ooooo001jooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool08_ooool2o`000;_ooooo001jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`2jooooo`00N_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0^_ooool007[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo0;[ooooo001jooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2jooooo`00N_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0^_ooool007[ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo0;[ooooo
001jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`2jooooo`00N_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool0^_ooool007[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Roooo
o`;o0000^oooool007[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo0;[ooooo001jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`2jooooo`00N_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool0^_ooool007[ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0;[ooooo001jooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`2jooooo`00N_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0^_ooool007[ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0;[ooooo
001jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`2jooooo`00N_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool0^_ooool007[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Soooo
o`;o0000^oooool007[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo0;[ooooo001jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`2jooooo`00Noooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool0^_ooool007_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0;[ooooo001kooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`2jooooo`00Noooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool007_o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2joooo
o`00Noooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`2jooooo`00Noooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002jooooo`00Noooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0000Oooooo00?o0000ooooooooool0^_ooool007_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00
0007ooooo`03o`000?oooooooooo0;[ooooo001kooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001ooo
ool00ol0003oooooooooo`2jooooo`00Noooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o
0000ooooooooool0^_ooool007_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo0;[ooooo001kooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`2jooooo`00Noooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0^_ooool007_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0;[ooooo001kooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool08oooool2o`000;_ooooo001kooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`2jooooo`00Noooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0^_ooool007_o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0;[o
oooo001kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`2jooooo`00Noooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0^_ooool007_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo0;[ooooo001kooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`2jooooo`00Noooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0^_ooool007_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0;[ooooo001kooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool09?ooool2o`000;_ooooo001kooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2jooooo`00Noooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0^_ooool007_o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0;[o
oooo001looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`2jooooo`00O?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0^_ooool007cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo0;[ooooo001looooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`2jooooo`00O?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0^_ooool007cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Tooooo`;o0000^oooool007cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0;[ooooo001looooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2jooooo`00O?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0^_ooool007co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0;[o
oooo001looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`2jooooo`00O?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0^_ooool007cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@
olc<c006ooooo`03o`000?oooooooooo0;[ooooo001looooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEE
EOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2jooooo`00O?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05
o`000?ooooooooooooooool000001_ooool3o`000;[ooooo001looooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRH
V?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;[ooooo001looooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000
oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;[ooooo001looooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o
EEEEohN7Qoooool02?ooool00ol0003oooooooooo`2jooooo`00O?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@
413oV9RH00Sooooo00?o0000ooooooooool0^_ooool007cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0:ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`00
0?l@4106ooooo`03o`000?oooooooooo0;[ooooo001looooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`2jooooo`00OOooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0^_ooool007gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo0;[ooooo001mooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`2jooooo`00
OOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo0_l0002kooooo`00OOoo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0^_oo
ool007gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo0;[ooooo001mooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`2jooooo`00OOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0^_ooool007gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo0;[ooooo001mooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`2jooooo`00OOooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0^_ooool007gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0;[ooooo001mooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool09_ooool2o`000;_ooooo001mooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2jooooo`00OOoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0^_oo
ool007gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo0;[ooooo001mooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`2jooooo`00OOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0^_ooool007gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo0;[ooooo001mooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`2jooooo`00OOooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0^_ooool007kooooo00Go0000oooo
ooooooooooooo`00000Xooooo`;o0000^oooool007kooooo00Go0000ooooooooooooooooo`00000X
ooooo`03o`000?oooooooooo0;[ooooo001nooooo`05o`000?ooooooooooooooool00000:?ooool0
0ol0003oooooooooo`2jooooo`00O_ooool01Ol0003ooooooooooooooooo000002Sooooo00?o0000
ooooooooool0^_ooool007kooooo00Go0000ooooooooooooooooo`00000Xooooo`03o`000?oooooo
oooo0;[ooooo001nooooo`05o`000?ooooooooooooooool00000:?ooool00ol0003oooooooooo`2j
ooooo`00O_ooool01Ol0003ooooooooooooooooo000002Sooooo00?o0000ooooooooool0^_ooool0
07kooooo00Go0000ooooooooooooooooo`00000=ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;[ooooo
001nooooo`05o`000?ooooooooooooooool000003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2joooo
o`00O_ooool01Ol0003ooooooooooooooooo000000gooooo00Go410@oooooooooooooooooa0@400;
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2jooooo`00O_ooool0
1?l0003oooooooooool0000>ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RH
oooooonHV9So<S8b00Kooooo0ol0002jooooo`00O_ooool01?l0003oooooooooool0000>ooooo`05
o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000
ooooooooool0^_ooool007kooooo00Co0000oooooooooooo00003_ooool01Ol@413ooooooooooooo
oooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0;[ooooo
001nooooo`04o`000?ooooooooooo`0000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`2jooooo`00O_ooool01?l0003o
ooooooooool0000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00Kooooo00?o0000ooooooooool0^_ooool007kooooo00Co0000oooooooooooo0000:Ooo
ool00ol0003oooooooooo`2jooooo`00O_ooool01?l0003oooooooooool0000Yooooo`03o`000?oo
oooooooo0;[ooooo001nooooo`04o`000?ooooooooooo`0002Wooooo00?o0000ooooooooool0^_oo
ool007kooooo00Co0000oooooooooooo0000:Oooool00ol0003oooooooooo`2jooooo`00O_ooool0
1?l0003oooooooooool0000Yooooo`;o0000^oooool007kooooo00Co0000oooooooooooo0000:Ooo
ool00ol0003oooooooooo`2jooooo`00O_ooool01?l0003oooooooooool0000Yooooo`03o`000?oo
oooooooo0;[ooooo001nooooo`04o`000?ooooooooooo`0002Wooooo00?o0000ooooooooool0^_oo
ool007kooooo00Co0000oooooooooooo0000:Oooool00ol0003oooooooooo`2jooooo`00O_ooool0
1?l0003oooooooooool0000Yooooo`03o`000?oooooooooo0;[ooooo001nooooo`04o`000?oooooo
ooooo`0002Wooooo00?o0000ooooooooool0^_ooool007oooooo00?o0000ooooool00000:Oooool0
0ol0003oooooooooo`2jooooo`00Ooooool00ol0003oooooo`00000Yooooo`03o`000?oooooooooo
0;[ooooo001oooooo`03o`000?oooooo000002Wooooo0_l0002kooooo`00Ooooool00ol0003ooooo
o`00000Yooooo`03o`000?oooooooooo0;[ooooo001oooooo`03o`000?oooooo000002Wooooo00?o
0000ooooooooool0^_ooool007oooooo00?o0000ooooool00000:Oooool00ol0003oooooooooo`2j
ooooo`00Ooooool2o`0002[ooooo00?o0000ooooooooool0^_ooool007oooooo0_l0000Zooooo`03
o`000?oooooooooo0;[ooooo0020ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00XOooool4o`000003oa0@4?oooooooooo00?ooooo00?o
0000ooooooooool0^_ooool00:?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2j
ooooo`00Xoooool00ol0003oooooooooo`05ooooo`?o0000^_ooool00:?ooooo00?o0000oooooooo
ool0`_ooool00:?ooooo00?o0000ooooooooool0`_ooool00:?ooooo00?o0000ooooooooool0`_oo
ool00:?ooooo00?o0000ooooooooool0`_ooool00:7ooooo00?oEEEEofIVI_l00000a?ooool00?oo
ooooJOooool006Wooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`02ooooo`03okZj
^_lb<S;ooooo00Oooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00007ooooo`03o`00
0?oooooooooo00;ooooo00?oIVIVogMgMoooool03?ooool00ol0003o^[Zjooooo`2]ooooo`00J?oo
ool00ooMgMgo410@onk^kP05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?ok^k^oa0@4?oMgMd03?ooool2oc8b<Zkooooo001Xooooo`03oeEEEOnHV9So
oooo00Gooooo00Ko0000oooooooooooooooooiRHV?l@4102o`000003ojVYZOoooooooooo00Cooooo
00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05
oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?oQhN7ofIVI_ooool02oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000
odA4A?nj^[X04?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o
410@ooooooooool0M?ooool006Sooooo00?o0000ooooooooool01Oooool02_l0003ooooooooooooo
oooo0000ojVYZOmEEEGoV9RHoeEEEOnj^[X5ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7
Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03onk^k_l0003ooooo
00_ooooo00?oc<c<o`000?l@41003?ooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00002Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo07Kooooo
001Xooooo`03oc8b<_oooooooooo00Gooooo00[o0000oooooooooooooooooc8b<_o^k^koV9RHoeEE
EOoMgMgo410@1Oooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Booooo`05oa0@4?ooooooooooooooool@4100
3_ooool00ol0003oooooooooo`1fooooo`00J?ooool00olb<S;oooooooooo`05ooooo`0;o`000?oo
oooooooooooooonj^[[oA4A4olc<c?lQ8B7ooooooa0@4?o<c<`01?ooool00ol0003oooooooooo`02
ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`03ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool0
M_ooool006Sooooo00?o0000onk^k_ooool01Oooool02ol0003oooooooooooooooook^k^o`000?oo
oooo0000oooooomVIVKoQhN700Cooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb
<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03onk^k_l0003ooooo01[ooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooo
oooooooo000000kooooo00?o0000ooooooooool0M_ooool006Sooooo00?oEEEEogMgMoooool01Ooo
ool02?l0003oooooooooooooooooIVIVoiRHV?oooooo<S8b0_nj^[X00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00omgMgOoEEEEooooo`02
ooooo`Co00004_ooool00ol@413o0000o`000003o`00017ooooo00Go410@oooooooooooooooooa0@
400>ooooo`03o`000?oooooooooo07Kooooo001Xooooo`03omgMgOl@413ok^k^00Gooooo00?o0000
ooooooooool01?ooool00omVIVKoQhN7ooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?ok^k^
oa0@4?oMgMd01?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo07Kooooo001Yooooo`03ogMgMomVIVKo
oooo00Cooooo00?o0000ooooooooool01?ooool00onYZJWoA4A4ooooo`05ooooo`;o00004_ooool0
0ol0003oooooooooo`05ooooo`;o00001oooool00ol0003oooooooooo`02ooooo`03ofIVI_mgMgOo
oooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`00001hooooo`00/_ooool00ol0003oooooooooo`2c
ooooo`00[oooool01?l0003oooooooooool0002eooooo`00/?ooool2o`000;Kooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.8522, -0.080387, \
0.130126, 0.00668404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
176.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02721 0 L
.02846 0 L
.02961 0 L
.03068 0 L
.0317 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03638 0 L
.03746 0 L
.03873 0 L
.03944 0 L
.04011 0 L
.04132 0 L
.04262 0 L
.04327 0 L
.04396 0 L
.04519 0 L
.04588 0 L
.04652 0 L
.04722 0 L
.04797 0 L
.04862 0 L
.04933 0 L
.05061 0 L
.05186 0 L
.05302 0 L
.05414 0 L
.05519 0 L
.05634 0 L
.05759 0 L
.05882 0 L
.06012 0 L
.06123 0 L
.06244 0 L
.06315 0 L
.06381 0 L
.06453 0 L
.06529 0 L
.06596 0 L
.06668 0 L
.06797 0 L
.06922 0 L
.07037 0 L
.07101 0 L
.07172 0 L
.073 0 L
Mistroke
.0737 0 L
.07446 0 L
.07517 0 L
.07583 0 L
.0766 0 L
.07741 0 L
.07811 0 L
.07885 0 L
.07955 0 L
.08019 0 L
.08144 0 L
.08213 0 L
.08289 0 L
.08361 0 L
.08427 0 L
.08544 0 L
.08669 0 L
.08787 0 L
.08896 0 L
.09026 0 L
.09148 0 L
.09274 0 L
.09341 0 L
.09413 0 L
.09483 0 L
.09548 0 L
.09619 0 L
.09695 0 L
.09821 0 L
.09893 0 L
.09961 0 L
.10086 0 L
.10201 0 L
.10333 0 L
.10458 0 L
.10572 0 L
.10694 0 L
.1081 0 L
.10916 0 L
.11033 0 L
.11162 0 L
.11227 0 L
.11297 0 L
.11422 0 L
.11491 0 L
.11554 0 L
.11624 0 L
.11698 0 L
.11822 0 L
.11892 0 L
Mistroke
.11958 0 L
.12446 0 L
.1256 0 L
.12684 0 L
.12801 0 L
.1291 0 L
.13018 0 L
.13115 0 L
.13228 0 L
.13334 0 L
.1345 0 L
.13573 0 L
.13677 0 L
.13792 0 L
.13916 0 L
.13985 0 L
.14048 0 L
.14171 0 L
.14288 0 L
.15165 0 L
.15281 0 L
.15404 0 L
.15521 0 L
.15626 0 L
.15745 0 L
.15858 0 L
.15979 0 L
.16111 0 L
.16176 0 L
.16248 0 L
.16323 0 L
.16393 0 L
.16518 0 L
.16588 0 L
.16653 0 L
.16777 0 L
.16846 0 L
.1691 0 L
.17035 0 L
.17149 0 L
.17274 0 L
.17388 0 L
.17513 0 L
.17579 0 L
.17649 0 L
.17766 0 L
.17875 0 L
.17995 0 L
.18123 0 L
.18187 0 L
Mistroke
.18255 0 L
.18378 0 L
.1851 0 L
.18585 0 L
.18655 0 L
.18782 0 L
.18898 0 L
.18962 0 L
.19031 0 L
.19159 0 L
.19283 0 L
.19395 0 L
.19525 0 L
.19648 0 L
.19761 0 L
.19866 0 L
.19989 0 L
.20102 0 L
.20223 0 L
.20353 0 L
.20474 0 L
.20589 0 L
.21123 0 L
.21252 0 L
.21374 0 L
.215 0 L
.21569 0 L
.2164 0 L
.21714 0 L
.21781 0 L
.21853 0 L
.21932 0 L
.22 0 L
.22073 0 L
.22203 0 L
.24193 0 L
.24257 0 L
.24327 0 L
.24454 0 L
.2453 0 L
.24601 0 L
.2467 0 L
.24735 0 L
.24863 0 L
.2498 0 L
.25106 0 L
.25176 0 L
.25241 0 L
.25364 0 L
.25434 0 L
Mistroke
.25498 0 L
.2563 0 L
.25703 0 L
.2577 0 L
.25844 0 L
.25913 0 L
.25989 0 L
.26069 0 L
.26138 0 L
.26203 0 L
.26275 0 L
.26351 0 L
.26482 0 L
.26604 0 L
.26674 0 L
.26738 0 L
.26811 0 L
.2688 0 L
.27021 0 L
.27098 0 L
.2717 0 L
.27297 0 L
.27364 0 L
.27437 0 L
.27565 0 L
.27686 0 L
.27796 0 L
.27914 0 L
.28042 0 L
.28161 0 L
.28289 0 L
.28362 0 L
.28431 0 L
.28542 0 L
.28665 0 L
.28793 0 L
.28912 0 L
.29023 0 L
.29125 0 L
.29242 0 L
.29353 0 L
.29473 0 L
.29601 0 L
.2971 0 L
.2983 0 L
.29959 0 L
.30032 0 L
.30098 0 L
.30226 0 L
.30348 0 L
Mistroke
.30473 1e-05 L
.30543 1e-05 L
.30607 1e-05 L
.30726 1e-05 L
.30851 2e-05 L
.30964 3e-05 L
.31069 4e-05 L
.31184 6e-05 L
.31307 8e-05 L
.31439 .00012 L
.31513 .00015 L
.31582 .00018 L
.31708 .00025 L
.31842 .00036 L
.31962 .00049 L
.32074 .00065 L
.32197 .00088 L
.3233 .00122 L
.32445 .0016 L
.32553 .00206 L
.32671 .00269 L
.32797 .00355 L
.3293 .00472 L
.33055 .00613 L
.33168 .00773 L
.33289 .0098 L
.33509 .01484 L
.33711 .02132 L
.33929 .03077 L
.34168 .04486 L
.34418 .06451 L
.3469 .09261 L
.35185 .16319 L
.36114 .34304 L
.36384 .39373 L
.36639 .43394 L
.3678 .45183 L
.36854 .45974 L
.36932 .46689 L
.36998 .47193 L
.37071 .47636 L
.37198 .48128 L
.3733 .48243 L
.37449 .47998 L
.37516 .47721 L
.37588 .47308 L
.37718 .46269 L
.37841 .4498 L
.3797 .43307 L
.38203 .39642 L
Mistroke
.39143 .2124 L
.39391 .16778 L
.39662 .12535 L
.3992 .09179 L
.40155 .06728 L
.40394 .04767 L
.4065 .03201 L
.40887 .02153 L
.4111 .01445 L
.41216 .01185 L
.41328 .00955 L
.4153 .00639 L
.41642 .00507 L
.41746 .00406 L
.41859 .00317 L
.41984 .0024 L
.4211 .0018 L
.42244 .00131 L
.42368 .00097 L
.42484 .00073 L
.42621 .00051 L
.42746 .00037 L
.42883 .00026 L
.42952 .00021 L
.43028 .00017 L
.43158 .00012 L
.43276 8e-05 L
.43341 7e-05 L
.43412 6e-05 L
.4354 4e-05 L
.43661 3e-05 L
.43789 2e-05 L
.43898 1e-05 L
.44018 1e-05 L
.44141 1e-05 L
.44259 0 L
.44364 0 L
.44479 0 L
.44604 0 L
.44674 0 L
.44737 0 L
.4486 0 L
.44976 0 L
.45085 0 L
.452 0 L
.45299 0 L
.45407 0 L
.45523 0 L
.45648 0 L
.45765 0 L
Mistroke
.45873 0 L
.45991 0 L
.46102 0 L
.46223 0 L
.46354 0 L
.46484 0 L
.46549 0 L
.46621 0 L
.46748 0 L
.46865 0 L
.46985 0 L
.47098 0 L
.47201 0 L
.47309 0 L
.47428 0 L
.47537 0 L
.47654 0 L
.47783 0 L
.4785 0 L
.47922 0 L
.48054 0 L
.48182 0 L
.48301 0 L
.48856 0 L
.4986 0 L
.50921 0 L
.51052 0 L
.51174 0 L
.51301 0 L
.51373 0 L
.51441 0 L
.51562 0 L
.51671 0 L
.51918 0 L
.52814 0 L
.53039 0 L
.53152 0 L
.53278 0 L
.53343 0 L
.53413 0 L
.53539 0 L
.53781 0 L
.53849 0 L
.53914 0 L
.54034 0 L
.54164 0 L
.54231 0 L
.54305 0 L
.54428 0 L
.54558 0 L
Mistroke
.54679 0 L
.54791 0 L
.54922 0 L
.54996 0 L
.55064 0 L
.5519 0 L
.55323 0 L
.55396 0 L
.55465 0 L
.5554 0 L
.55622 0 L
.55691 0 L
.55764 0 L
.55894 0 L
.56017 0 L
.56134 0 L
.56199 0 L
.56269 0 L
.56391 0 L
.56508 0 L
.56631 0 L
.56747 0 L
.56853 0 L
.56978 0 L
.57046 0 L
.57111 0 L
.57227 0 L
.57353 0 L
.57424 0 L
.57491 0 L
.57568 0 L
.57638 0 L
.57765 0 L
.57903 0 L
.59861 0 L
.60116 0 L
.60186 0 L
.60261 0 L
.60324 0 L
.60394 0 L
.60519 0 L
.60589 0 L
.60654 0 L
.60773 0 L
.60898 0 L
.60967 0 L
.61042 0 L
.61112 0 L
.61175 0 L
.61246 0 L
Mistroke
.61321 0 L
.61403 0 L
.61479 0 L
.61609 0 L
.61677 0 L
.61751 0 L
.6182 0 L
.61884 0 L
.62008 0 L
.62134 0 L
.62198 0 L
.62269 0 L
.62394 0 L
.62511 0 L
.62577 0 L
.62648 0 L
.62774 0 L
.62844 0 L
.62911 0 L
.62988 0 L
.63058 0 L
.63176 0 L
.63304 0 L
.63423 0 L
.63533 0 L
.63654 0 L
.63723 0 L
.63786 0 L
.63853 0 L
.63924 0 L
.64054 0 L
.64171 0 L
.64296 0 L
.64414 0 L
.64521 0 L
.64648 0 L
.64719 0 L
.64784 0 L
.64905 0 L
.65032 0 L
.65143 0 L
.65261 0 L
.65373 0 L
.65475 0 L
.65595 0 L
.65725 0 L
.65848 0 L
.65961 0 L
.66079 0 L
.66203 0 L
Mistroke
.66309 0 L
.66425 0 L
.6655 0 L
.6662 0 L
.66684 0 L
.66808 0 L
.66925 0 L
.67035 0 L
.67151 0 L
.67251 0 L
.67359 0 L
.67474 0 L
.67583 0 L
.67711 0 L
.67829 0 L
.67956 0 L
.68026 0 L
.68092 0 L
.68219 0 L
.68335 0 L
.68464 0 L
.68529 0 L
.686 0 L
.68677 0 L
.68749 0 L
.68815 0 L
.68886 0 L
.69017 0 L
.6914 0 L
.6925 0 L
.69371 0 L
.69502 0 L
.69573 0 L
.6964 0 L
.6976 0 L
.6989 0 L
.7002 0 L
.70143 0 L
.70211 0 L
.70284 0 L
.70413 0 L
.70536 0 L
.70666 0 L
.70788 0 L
.70899 0 L
.7103 0 L
.71102 0 L
.71171 0 L
.71292 0 L
.71425 0 L
Mistroke
.71494 0 L
.7157 0 L
.71649 0 L
.71724 0 L
.71794 0 L
.71858 0 L
.71933 0 L
.72002 0 L
.72119 0 L
.72244 0 L
.72361 0 L
.72469 0 L
.72595 0 L
.72661 0 L
.72732 0 L
.7285 0 L
.7298 0 L
.73102 0 L
.73233 0 L
.73308 0 L
.73376 0 L
.73444 0 L
.73508 0 L
.73634 0 L
.7375 0 L
.73876 0 L
.73946 0 L
.7401 0 L
.74131 0 L
.74261 0 L
.74381 0 L
.74495 0 L
.74627 0 L
.74749 0 L
.74813 0 L
.74883 0 L
.74957 0 L
.75026 0 L
.75139 0 L
.75259 0 L
.75361 0 L
.75472 0 L
.75593 0 L
.75722 0 L
.75843 0 L
.75954 0 L
.76084 0 L
.7615 0 L
.76222 0 L
.7635 0 L
Mistroke
.7647 0 L
.76542 0 L
.76611 0 L
.76739 0 L
.76811 0 L
.76878 0 L
.76951 0 L
.77029 0 L
.77148 0 L
.77277 0 L
.77399 0 L
.7751 0 L
.77634 0 L
.77704 0 L
.77769 0 L
.77901 0 L
.77975 0 L
.78043 0 L
.78161 0 L
.78273 0 L
.78395 0 L
.78526 0 L
.78591 0 L
.78663 0 L
.78793 0 L
.7892 0 L
.79038 0 L
.79158 0 L
.79272 0 L
.79373 0 L
.79483 0 L
.79603 0 L
.7973 0 L
.79847 0 L
.79957 0 L
.80087 0 L
.80205 0 L
.80332 0 L
.80404 0 L
.8047 0 L
.8058 0 L
.80702 0 L
.80829 0 L
.80948 0 L
.81017 0 L
.81081 0 L
.81148 0 L
.81221 0 L
.81342 0 L
.81472 0 L
Mistroke
.81545 0 L
.81624 0 L
.81698 0 L
.81767 0 L
.81898 0 L
.81963 0 L
.82036 0 L
.82165 0 L
.82285 0 L
.82417 0 L
.82491 0 L
.82557 0 L
.8268 0 L
.82749 0 L
.82812 0 L
.82929 0 L
.83052 0 L
.83163 0 L
.83281 0 L
.83384 0 L
.83495 0 L
.83626 0 L
.83749 0 L
.8387 0 L
.83981 0 L
.84504 0 L
.84629 0 L
.8476 0 L
.84872 0 L
.84995 0 L
.85122 0 L
.85241 0 L
.85306 0 L
.85377 0 L
.85506 0 L
.85581 0 L
.85649 0 L
.85779 0 L
.85846 0 L
.85921 0 L
.85998 0 L
.8607 0 L
.86196 0 L
.86259 0 L
.8633 0 L
.86453 0 L
.8657 0 L
.86636 0 L
.86706 0 L
.86831 0 L
Mistroke
.86897 0 L
.86966 0 L
.87043 0 L
.87114 0 L
.87232 0 L
.87358 0 L
.87423 0 L
.87495 0 L
.87622 0 L
.87742 0 L
.87871 0 L
.87992 0 L
.88103 0 L
.88227 0 L
.88341 0 L
.88467 0 L
.88538 0 L
.88601 0 L
.88718 0 L
.88845 0 L
.88965 0 L
.89075 0 L
.89181 0 L
.89279 0 L
.89388 0 L
.89504 0 L
.89608 0 L
.8972 0 L
.89843 0 L
.89958 0 L
.90083 0 L
.90215 0 L
.90283 0 L
.90357 0 L
.90487 0 L
.9061 0 L
.90741 0 L
.90863 0 L
.90977 0 L
.91046 0 L
.9112 0 L
.912 0 L
.91275 0 L
.9134 0 L
.91409 0 L
.91486 0 L
.91557 0 L
.91686 0 L
.91759 0 L
.91827 0 L
Mistroke
.91952 0 L
.92084 0 L
.9215 0 L
.9222 0 L
.92346 0 L
.92411 0 L
.9248 0 L
.92557 0 L
.92628 0 L
.92754 0 L
.92821 0 L
.92891 0 L
.93021 0 L
.9314 0 L
.93263 0 L
.93378 0 L
.93505 0 L
.93576 0 L
.93641 0 L
.93752 0 L
.93874 0 L
.93989 0 L
.94096 0 L
.94212 0 L
.94334 0 L
.94439 0 L
.94553 0 L
.94677 0 L
.94809 0 L
.94934 0 L
.95048 0 L
.95162 0 L
.95268 0 L
.95384 0 L
.95508 0 L
.95607 0 L
.95715 0 L
.95833 0 L
.95944 0 L
.96049 0 L
.96147 0 L
.96254 0 L
.96369 0 L
.9649 0 L
.96604 0 L
.96707 0 L
.96818 0 L
.96914 0 L
.9702 0 L
.97123 0 L
Mistroke
.97235 0 L
.97338 0 L
.97433 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`0Rooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00GoA4A4o`000?l0003o<S8bomgMg@1Gooooo`05odA4A?l0003o0000oc8b<_oMgMd09oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo02Gooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool09?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00omgMgOo<S8booooo`1Iooooo`03ogMgMolb<S;ooooo02Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Uooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool6o`0000Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[
ooooo`03ogMgMolb<S;ooooo05Wooooo00?oMgMgoc8b<_ooool0:?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo02Gooooo000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0Eoooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001Wooooo
00?oEEEEofIVI_l000001Oooool4o`0002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo1?l0001Hooooo`Co0000:?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool00omEEEGoIVIVo`000005ooooo`Co00009oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooC_ooool2o`0000;ooooo0_l0000Eooooo`00oooooom>
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5Oooool00?ooooooCoooool01?oMgMgo0000oa0@
4?o<c<`Fooooo`005?ooooooo`00033o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hFooooo`006ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`;o00000oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo00Co0000oooooooooooooooo0ol00003ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`04ob4Q8OmgMgOoMgMgoc8b<QKo
oooo000Kooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0:Oooool2o`0000;ooooo
00?o0000ooooooooool04oooool2o`0001Sooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03oooool2o`0000;ooooo
0_l0000Eooooo`00N?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0^_ooool007Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo0;[ooooo001iooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`2jooooo`00NOooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0^_ooool007[ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0;[ooooo001jooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2jooooo`00N_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0^_ooool0
07[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Iooooo`;o0000^oooool007[o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0;[o
oooo001kooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`2jooooo`00Noooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0^_ooool007_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo0;[ooooo001kooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`2jooooo`00Noooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0^_ooool007_ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0;[ooooo001looooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2jooooo`00O?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01_ooooo0_l0002kooooo`00O?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0^_ooool007co
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0;[o
oooo001looooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`2jooooo`00O?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0^_ooool007cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo0;[ooooo001mooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`2jooooo`00OOooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0^_ooool007gooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0;[ooooo001mooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool07?ooool2o`000;_ooooo001mooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`2jooooo`00OOooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0^_ooool007go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0;[o
oooo001mooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`2jooooo`00OOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0^_ooool007gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo0;[ooooo001mooooo`03o`000?oooooooooo00cooooo00Wo0000oooo
ooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`00
0?oooooooooo0;[ooooo001mooooo`03o`000?oooooooooo00cooooo00Wo0000oooooooooooooooo
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006
ooooo`03o`000?oooooooooo0;[ooooo001mooooo`03o`000?oooooooooo00cooooo00Go0000oooo
oooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool0
0ol0003oooooooooo`2jooooo`00OOooool00ol0003oooooooooo`0<ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0002j
ooooo`00OOooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0^_ooool0
07kooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;[ooooo001noooo
o`03o`000?oooooooooo00_ooooo00Wo0000ooooooooooooooooogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0^_ooool007kooooo
00?o0000ooooooooool02oooool02Ol0003oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2jooooo`00O_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0^_ooool0
07kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
0;[ooooo001nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`2jooooo`00O_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool0^_ooool007kooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Mooooo`;o0000^oooool007kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo0;[ooooo001nooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`2jooooo`00O_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0^_ooool007kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0;[ooooo001nooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`2jooooo`00O_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0^_ooool0
07kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
0;[ooooo001nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`2jooooo`00O_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01gooooo
0_l0002kooooo`00O_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0^_ooool007kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo0;[ooooo001nooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`2jooooo`00Ooooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool0^_ooool007oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0;[ooooo001oooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2jooooo`00Ooooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0^_ooool0
07oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
0;[ooooo001oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`2jooooo`00Ooooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo
0_l0002kooooo`00Ooooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool0^_ooool007oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo0;[ooooo001oooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`2jooooo`00Ooooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool0^_ooool007oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0;[ooooo001oooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`2jooooo`00Oooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;[ooooo
001oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo0;[ooooo001oooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo
00CoA4A4omgMgOoooooo00001oooool3o`000;[ooooo001oooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoo
oooo00001oooool00ol0003oooooooooo`2jooooo`00Ooooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co0000
00Oooooo00?o0000ooooooooool0^_ooool0083ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo0;[ooooo0020ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0
003oooooooooo`2jooooo`00P?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool0^_ooool0083ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo0;[ooooo0020ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`2jooooo`00P?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0^_ooool0083ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Oooooo`;o0000^oooool0083ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0;[ooooo0020ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`2jooooo`00P?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0^_oo
ool0083ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo0;[ooooo0020ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`2jooooo`00P?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool0^_ooool0083ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo0;[ooooo0020ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`2jooooo`00P?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0^_ooool0083ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Pooooo`;o0000^oooool0083ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0;[ooooo0021ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2jooooo`00POoo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0^_oo
ool0087ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo0;[ooooo0021ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`2jooooo`00POooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool0^_ooool0087ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo0;[ooooo0021ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`2jooooo`00POooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo023ooooo0_l0002kooooo`00POooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool0^_ooool0087ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0;[ooooo0021ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2jooooo`00POoo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0^_oo
ool0087ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo0;[ooooo0021ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`2jooooo`00POooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0^_ooool0087ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEE
ogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;[ooooo0022ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000^_ooool008;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RH
oooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0^_ooool008;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003o
EEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0^_ooool008;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@41002oooool00omE
EEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0;[ooooo0022ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@
4?nHV9P02?ooool00ol0003oooooooooo`2jooooo`00P_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000
oa0@40Kooooo00?o0000ooooooooool0^_ooool008;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo0;[ooooo0022ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`2jooooo`00P_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0^_ooool008;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0;[ooooo0022
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08Oooool2o`000;_ooooo0022oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`2joooo
o`00P_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool0^_ooool008;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo0;[ooooo0023ooooo`05o`000?ooooooooooooooool000008oooool00ol0003ooooo
ooooo`2jooooo`00Poooool01Ol0003ooooooooooooooooo000002?ooooo00?o0000ooooooooool0
^_ooool008?ooooo00Go0000ooooooooooooooooo`00000Sooooo`03o`000?oooooooooo0;[ooooo
0023ooooo`05o`000?ooooooooooooooool000008oooool00ol0003oooooooooo`2jooooo`00Pooo
ool01Ol0003ooooooooooooooooo000002?ooooo00?o0000ooooooooool0^_ooool008?ooooo00Go
0000ooooooooooooooooo`00000Sooooo`;o0000^oooool008?ooooo00Go0000oooooooooooooooo
o`00000Sooooo`03o`000?oooooooooo0;[ooooo0023ooooo`05o`000?ooooooooooooooool00000
8oooool00ol0003oooooooooo`2jooooo`00Poooool01?l0003oooooooooool0000Tooooo`03o`00
0?oooooooooo0;[ooooo0023ooooo`04o`000?ooooooooooo`0002Cooooo00?o0000ooooooooool0
^_ooool008?ooooo00Co0000oooooooooooo00009?ooool00ol0003oooooooooo`2jooooo`00Pooo
ool01?l0003oooooooooool0000Tooooo`03o`000?oooooooooo0;[ooooo0023ooooo`04o`000?oo
ooooooooo`0002Cooooo00?o0000ooooooooool0^_ooool008?ooooo00Co0000oooooooooooo0000
9?ooool00ol0003oooooooooo`2jooooo`00Poooool01?l0003oooooooooool0000Tooooo`;o0000
^oooool008?ooooo00Co0000oooooooooooo00009?ooool00ol0003oooooooooo`2jooooo`00Pooo
ool00ol0003oooooo`00000Uooooo`03o`000?oooooooooo0;[ooooo0024ooooo`;o00009Oooool0
0ol0003oooooooooo`2jooooo`00Q?ooool2o`0002Gooooo00?o0000ooooooooool0^_ooool008Co
oooo0_l0000Uooooo`03o`000?oooooooooo0;[ooooo0024ooooo`;o00009Oooool00ol0003ooooo
ooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<
c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2jooooo`00T?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0
003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05o`000?oooooooooo
ooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002jooooo`00T?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`00
0?oooooooooo0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zj
oooooonj^[[o410@00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`2joooo
o`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002Qooooo`Co000000?o410@ooooooooool00oooool00ol0
003oooooooooo`2jooooo`00Xoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;[o
oooo002Sooooo`03o`000?oooooooooo00Gooooo0ol0002jooooo`00Xoooool00ol0003ooooooooo
o`32ooooo`00Xoooool00ol0003oooooooooo`32ooooo`00Xoooool00ol0003oooooooooo`32oooo
o`00Xoooool00ol0003oooooooooo`32ooooo`00XOooool00omEEEGoIVIVo`000034ooooo`00oooo
oomYooooo`00JOooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o^[Zj
oc8b<_ooool01oooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Oooooo00?o0000
ooooooooool00_ooool00omVIVKoMgMgooooo`0<ooooo`03o`000?nj^[[ooooo0:gooooo001Xoooo
o`03omgMgOl@413ok^k^00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool00oo^k^ko410@omgMg@0<ooooo`;o<S8b[_ooool006Sooooo00?oEEEEoiRHV?oo
ool01Oooool01_l0003oooooooooooooooooV9RHoa0@40;o000000?oZJVYooooooooool01?ooool0
1?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00Go
V9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00on7QhOoIVIVooooo`0;ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003o
A4A4okZj^P0@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0001goooo
o`00J?ooool00ol0003oooooooooo`05ooooo`0:o`000?ooooooooooooooool0003oZJVYoeEEEOnH
V9SoEEEEokZj^PGooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0ooo
ool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo00?ok^k^o`000?ooool02oooool00oo<c<co0000
oa0@400<ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l00009ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A01gooooo`00J?ooool0
0olb<S;oooooooooo`05ooooo`0:o`000?oooooooooooooooolb<S;ok^k^oiRHV?mEEEGogMgMoa0@
40Gooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool04_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h0N?ooool006Sooooo00?o<S8booooooooool01Oooool02ol0003ooooooooooooo
oooo^[ZjodA4A?o<c<co8B4Qooooool@413oc<c<00Cooooo00?o0000ooooooooool00_ooool01?o^
k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool6
o`0000Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^07Oooooo001X
ooooo`03o`000?o^k^kooooo00Gooooo00_o0000ooooooooooooooooonk^k_l0003oooooo`000?oo
ooooIVIVohN7Q`04ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool0
0oo^k^ko0000ooooo`0Jooooo`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo07Kooooo001Xooooo`03oeEEEOmgMgOooooo00Gooooo00So0000
ooooooooooooooooofIVI_nHV9Sooooooc8b<P;o^[Zj00?o0000ooooooooool00_ooool01?l0003o
ooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?oMgMgoeEEEOooool00_ooool4o`00
01;ooooo00?o410@o`000?l000000ol0000Aooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`1eooooo`00J?ooool00ooMgMgo410@onk^kP05ooooo`03o`000?oooooooooo
00Cooooo00?oIVIVohN7Qoooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03onk^k_l@413ogMgM
00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Booooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@07Oooooo001Yooooo`03ogMgMomVIVKo
oooo00Cooooo00?o0000ooooooooool01?ooool00onYZJWoA4A4ooooo`05ooooo`;o00004_ooool0
0ol0003oooooooooo`05ooooo`;o00001oooool00ol0003oooooooooo`02ooooo`03ofIVI_mgMgOo
oooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<07Oooooo002booooo`03o`000?oo
oooooooo0;?ooooo002_ooooo`04o`000?ooooooooooo`000;Gooooo002`ooooo`;o0000]_ooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.8522, -0.080387, \
0.130126, 0.00668404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
176.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 0 L
.06361 0 L
.06484 0 L
.06548 0 L
.06619 0 L
.06744 0 L
.06861 0 L
.06988 0 L
.07107 0 L
.07216 0 L
.07285 0 L
.07349 0 L
.0742 0 L
.07495 0 L
.07567 0 L
.07634 0 L
.0776 0 L
.07884 0 L
.07998 0 L
.08123 0 L
.08255 0 L
.08326 0 L
.08391 0 L
.08466 0 L
.08537 0 L
.08662 0 L
.08733 0 L
.08799 0 L
.08871 0 L
.08948 0 L
.09021 0 L
.09088 0 L
.09159 0 L
.09234 0 L
.09319 0 L
.09396 0 L
.09523 0 L
.09593 0 L
.09658 0 L
.09776 0 L
.09903 0 L
.0997 0 L
.10043 0 L
.10115 0 L
.10192 0 L
.10264 0 L
.10329 0 L
.10458 0 L
.10586 0 L
Mistroke
.10702 0 L
.10766 0 L
.10836 0 L
.10962 0 L
.1108 0 L
.11205 0 L
.11323 0 L
.11429 0 L
.11555 0 L
.11625 0 L
.11691 0 L
.11807 0 L
.11934 0 L
.12001 0 L
.12074 0 L
.1215 0 L
.12222 0 L
.1235 0 L
.12422 0 L
.12488 0 L
.12601 0 L
.12721 0 L
.12834 0 L
.12937 0 L
.13058 0 L
.13189 0 L
.13312 0 L
.13427 0 L
.13547 0 L
.13677 0 L
.13805 0 L
.13876 0 L
.13942 0 L
.14058 0 L
.14185 0 L
.14304 0 L
.14415 0 L
.14533 0 L
.14656 0 L
.14762 0 L
.14877 0 L
.15002 0 L
.15072 0 L
.15136 0 L
.15261 0 L
.15376 0 L
.15484 0 L
.15599 0 L
.15714 0 L
.15841 0 L
Mistroke
.1595 0 L
.16067 0 L
.16178 0 L
.16279 0 L
.16406 0 L
.16477 0 L
.16541 0 L
.16666 0 L
.16784 0 L
.16851 0 L
.16922 0 L
.17049 0 L
.1712 0 L
.17186 0 L
.17258 0 L
.17335 0 L
.17464 0 L
.17537 0 L
.17605 0 L
.17729 0 L
.1786 0 L
.17978 0 L
.18088 0 L
.18208 0 L
.18339 0 L
.18464 0 L
.18579 0 L
.18711 0 L
.18835 0 L
.1895 0 L
.19057 0 L
.19172 0 L
.19297 0 L
.19422 0 L
.19539 0 L
.19611 0 L
.19678 0 L
.19806 0 L
.1987 0 L
.19939 0 L
.20063 0 L
.20139 0 L
.20211 0 L
.20275 0 L
.20344 0 L
.20476 0 L
.206 0 L
.2067 0 L
.20735 0 L
.20809 0 L
Mistroke
.2088 0 L
.20948 0 L
.2102 0 L
.2115 0 L
.21223 0 L
.2129 0 L
.21364 0 L
.21444 0 L
.21574 0 L
.21647 0 L
.21715 0 L
.21839 0 L
.21903 0 L
.21972 0 L
.22102 0 L
.22225 0 L
.22343 0 L
.22455 0 L
.22579 0 L
.22692 0 L
.22813 0 L
.22882 0 L
.22946 0 L
.23051 0 L
.23168 0 L
.2329 0 L
.23404 0 L
.23532 0 L
.23596 0 L
.23666 0 L
.23791 0 L
.23906 0 L
.23977 0 L
.24043 0 L
.24168 0 L
.24232 0 L
.24301 0 L
.24377 0 L
.24448 0 L
.24516 0 L
.24581 0 L
.24703 0 L
.24832 0 L
.24905 0 L
.24973 0 L
.25094 0 L
.25208 0 L
.25339 0 L
.25458 0 L
.25522 0 L
Mistroke
.25591 0 L
.25664 0 L
.25732 0 L
.25862 0 L
.25985 0 L
.26053 0 L
.26128 0 L
.26259 0 L
.26334 0 L
.26412 0 L
.2648 0 L
.26554 0 L
.26668 0 L
.26789 0 L
.26859 0 L
.26923 0 L
.27047 0 L
.27175 0 L
.27242 0 L
.27313 0 L
.27444 0 L
.27565 0 L
.27675 0 L
.27793 0 L
.27905 0 L
.28006 0 L
.28241 0 L
.2837 0 L
.28491 0 L
.28618 0 L
.28685 0 L
.28757 0 L
.28886 0 L
.29004 0 L
.29134 0 L
.29207 0 L
.29276 0 L
.29414 0 L
.29492 0 L
.29562 0 L
.29692 0 L
.29813 0 L
.29945 0 L
.30011 0 L
.30084 0 L
.30207 0 L
.30339 0 L
.30464 0 L
.30578 1e-05 L
.30707 1e-05 L
Mistroke
.30828 1e-05 L
.30937 1e-05 L
.31055 2e-05 L
.31183 3e-05 L
.31319 4e-05 L
.31435 5e-05 L
.31563 6e-05 L
.31682 8e-05 L
.31791 .00011 L
.31917 .00015 L
.32036 .00019 L
.32247 .0003 L
.32367 .00039 L
.32477 .00049 L
.32596 .00063 L
.32723 .00082 L
.32955 .00129 L
.33089 .00166 L
.3323 .00216 L
.33482 .0034 L
.3361 .00425 L
.33746 .00536 L
.33992 .008 L
.34142 .01013 L
.34284 .01258 L
.3455 .01851 L
.34789 .0257 L
.35013 .03435 L
.35258 .04635 L
.35522 .06258 L
.3606 .10765 L
.36552 .16272 L
.37445 .28189 L
.37681 .31205 L
.37936 .34127 L
.3816 .36291 L
.38397 .3804 L
.38526 .38729 L
.38599 .39031 L
.38667 .39253 L
.38787 .39502 L
.38915 .39564 L
.39041 .39418 L
.39161 .39094 L
.39268 .38652 L
.39384 .38015 L
.39615 .36307 L
.3986 .33929 L
.403 .28613 L
.41299 .15384 L
Mistroke
.4186 .09414 L
.42126 .07193 L
.42374 .05488 L
.42624 .04088 L
.42852 .03075 L
.43105 .02197 L
.43374 .015 L
.43609 .01055 L
.43864 .00706 L
.44104 .00474 L
.44325 .00323 L
.44545 .00218 L
.44749 .00149 L
.44867 .00119 L
.44974 .00096 L
.45099 .00075 L
.45215 .00059 L
.45446 .00037 L
.45568 .00028 L
.45697 .00021 L
.45802 .00017 L
.45915 .00013 L
.46039 .0001 L
.46155 7e-05 L
.4628 5e-05 L
.46394 4e-05 L
.46526 3e-05 L
.4665 2e-05 L
.46871 1e-05 L
.46996 1e-05 L
.47111 1e-05 L
.47236 0 L
.47353 0 L
.47481 0 L
.47553 0 L
.47619 0 L
.47751 0 L
.47826 0 L
.47895 0 L
.48022 0 L
.48093 0 L
.48157 0 L
.4822 0 L
.48289 0 L
.48362 0 L
.48429 0 L
.4855 0 L
.48679 0 L
.48752 0 L
.48831 0 L
Mistroke
.48906 0 L
.48975 0 L
.49041 0 L
.49113 0 L
.49244 0 L
.49367 0 L
.49479 0 L
.49606 0 L
.49671 0 L
.4974 0 L
.4987 0 L
.49991 0 L
.50066 0 L
.50135 0 L
.50266 0 L
.50382 0 L
.50506 0 L
.50623 0 L
.5073 0 L
.50855 0 L
.50921 0 L
.50992 0 L
.51121 0 L
.5124 0 L
.5227 0 L
.5251 0 L
.52576 0 L
.52645 0 L
.52769 0 L
.52885 0 L
.52993 0 L
.53112 0 L
.53239 0 L
.53352 0 L
.53475 0 L
.53591 0 L
.53698 0 L
.53795 0 L
.53901 0 L
.54012 0 L
.54116 0 L
.5424 0 L
.5431 0 L
.54373 0 L
.54497 0 L
.54612 0 L
.54677 0 L
.54746 0 L
.54821 0 L
.54891 0 L
Mistroke
.55016 0 L
.55082 0 L
.55154 0 L
.5528 0 L
.55352 0 L
.55419 0 L
.5554 0 L
.5567 0 L
.55785 0 L
.55893 0 L
.56012 0 L
.5614 0 L
.56257 0 L
.56365 0 L
.56484 0 L
.56611 0 L
.56675 0 L
.56744 0 L
.5687 0 L
.56993 0 L
.57106 0 L
.57205 0 L
.57311 0 L
.57428 0 L
.57537 0 L
.57659 0 L
.57775 0 L
.57888 0 L
.57992 0 L
.58117 0 L
.58183 0 L
.58252 0 L
.58369 0 L
.58497 0 L
.58611 0 L
.58733 0 L
.58848 0 L
.58953 0 L
.59084 0 L
.59205 0 L
.59269 0 L
.59338 0 L
.59411 0 L
.59479 0 L
.59604 0 L
.59719 0 L
.59844 0 L
.59977 0 L
.60092 0 L
.60197 0 L
Mistroke
.60318 0 L
.60432 0 L
.60531 0 L
.60636 0 L
.6075 0 L
.60856 0 L
.6097 0 L
.61093 0 L
.61208 0 L
.61314 0 L
.61437 0 L
.61507 0 L
.61572 0 L
.6169 0 L
.61817 0 L
.6193 0 L
.62054 0 L
.62184 0 L
.62304 0 L
.62417 0 L
.6252 0 L
.62639 0 L
.62752 0 L
.62874 0 L
.63003 0 L
.63114 0 L
.63236 0 L
.63366 0 L
.6344 0 L
.63507 0 L
.6363 0 L
.63761 0 L
.63883 0 L
.63993 0 L
.64104 0 L
.64209 0 L
.64331 0 L
.64444 0 L
.64567 0 L
.64698 0 L
.64804 0 L
.64917 0 L
.65024 0 L
.65122 0 L
.65237 0 L
.65361 0 L
.65479 0 L
.65588 0 L
.65706 0 L
.6583 0 L
Mistroke
.65936 0 L
.66052 0 L
.66177 0 L
.66247 0 L
.66311 0 L
.66434 0 L
.66551 0 L
.66661 0 L
.66777 0 L
.66876 0 L
.66985 0 L
.67102 0 L
.67228 0 L
.67347 0 L
.67455 0 L
.67583 0 L
.67654 0 L
.67718 0 L
.67843 0 L
.67961 0 L
.68029 0 L
.681 0 L
.68226 0 L
.68297 0 L
.68363 0 L
.68435 0 L
.68513 0 L
.68642 0 L
.68715 0 L
.68783 0 L
.68907 0 L
.69038 0 L
.69155 0 L
.69265 0 L
.69386 0 L
.69516 0 L
.69584 0 L
.69649 0 L
.69769 0 L
.69899 0 L
.69966 0 L
.70039 0 L
.70163 0 L
.70293 0 L
.70413 0 L
.70526 0 L
.70594 0 L
.70668 0 L
.70734 0 L
.70804 0 L
Mistroke
.70936 0 L
.71058 0 L
.71125 0 L
.71197 0 L
.71329 0 L
.71405 0 L
.71485 0 L
.71559 0 L
.71628 0 L
.71754 0 L
.71868 0 L
.71991 0 L
.72061 0 L
.72125 0 L
.7224 0 L
.72364 0 L
.7248 0 L
.72587 0 L
.72703 0 L
.7283 0 L
.72901 0 L
.72967 0 L
.73097 0 L
.73168 0 L
.73234 0 L
.73358 0 L
.73428 0 L
.73492 0 L
.73563 0 L
.73637 0 L
.73759 0 L
.73828 0 L
.73892 0 L
.74009 0 L
.74134 0 L
.7424 0 L
.74352 0 L
.74474 0 L
.74586 0 L
.74706 0 L
.74836 0 L
.74957 0 L
.7507 0 L
.75139 0 L
.75205 0 L
.75328 0 L
.7546 0 L
.75535 0 L
.75603 0 L
.75709 0 L
Mistroke
.75823 0 L
.7593 0 L
.76028 0 L
.76143 0 L
.76267 0 L
.76385 0 L
.76495 0 L
.76606 0 L
.76712 0 L
.76827 0 L
.76951 0 L
.77075 0 L
.77205 0 L
.77316 0 L
.77437 0 L
.77569 0 L
.7769 0 L
.77754 0 L
.77823 0 L
.77896 0 L
.77964 0 L
.7809 0 L
.78204 0 L
.78268 0 L
.78337 0 L
.78462 0 L
.78585 0 L
.78696 0 L
.78825 0 L
.78946 0 L
.79058 0 L
.79162 0 L
.79275 0 L
.79395 0 L
.79525 0 L
.79644 0 L
.7971 0 L
.79781 0 L
.79911 0 L
.80033 0 L
.80161 0 L
.80272 0 L
.80393 0 L
.80462 0 L
.80535 0 L
.80665 0 L
.80738 0 L
.80805 0 L
.80879 0 L
.80958 0 L
Mistroke
.81027 0 L
.81101 0 L
.81171 0 L
.81236 0 L
.81366 0 L
.81489 0 L
.81606 0 L
.81733 0 L
.81849 0 L
.81956 0 L
.82084 0 L
.82199 0 L
.82263 0 L
.82333 0 L
.82458 0 L
.82577 0 L
.82688 0 L
.82804 0 L
.82931 0 L
.83041 0 L
.83141 0 L
.83256 0 L
.83365 0 L
.83484 0 L
.83615 0 L
.83742 0 L
.83814 0 L
.83879 0 L
.83999 0 L
.84125 0 L
.84235 0 L
.84355 0 L
.84484 0 L
.84554 0 L
.8462 0 L
.84692 0 L
.8477 0 L
.84836 0 L
.84908 0 L
.84975 0 L
.85048 0 L
.85117 0 L
.8518 0 L
.85309 0 L
.85429 0 L
.85543 0 L
.85667 0 L
.85733 0 L
.85803 0 L
.85929 0 L
Mistroke
.8606 0 L
.86182 0 L
.86252 0 L
.86316 0 L
.8639 0 L
.8646 0 L
.86573 0 L
.86693 0 L
.86795 0 L
.86908 0 L
.87029 0 L
.87159 0 L
.87273 0 L
.87394 0 L
.87467 0 L
.87534 0 L
.87663 0 L
.87735 0 L
.87814 0 L
.87888 0 L
.87956 0 L
.88021 0 L
.8809 0 L
.88215 0 L
.88346 0 L
.88421 0 L
.88489 0 L
.88618 0 L
.88736 0 L
.88863 0 L
.88936 0 L
.89004 0 L
.89118 0 L
.8924 0 L
.89371 0 L
.89491 0 L
.89619 0 L
.8974 0 L
.89848 0 L
.89966 0 L
.90094 0 L
.90158 0 L
.90229 0 L
.90355 0 L
.90472 0 L
.9059 0 L
.90702 0 L
.90804 0 L
.90912 0 L
.9103 0 L
Mistroke
.91139 0 L
.91268 0 L
.91385 0 L
.91515 0 L
.91586 0 L
.91652 0 L
.9177 0 L
.91898 0 L
.91964 0 L
.92036 0 L
.92166 0 L
.92244 0 L
.92316 0 L
.92381 0 L
.92452 0 L
.92572 0 L
.92684 0 L
.92806 0 L
.92875 0 L
.92939 0 L
.93006 0 L
.93077 0 L
.93209 0 L
.93338 0 L
.93456 0 L
.93568 0 L
.93688 0 L
.9382 0 L
.93943 0 L
.94009 0 L
.94081 0 L
.94212 0 L
.94339 0 L
.94457 0 L
.94567 0 L
.9467 0 L
.94792 0 L
.94905 0 L
.95016 0 L
.95133 0 L
.95251 0 L
.9538 0 L
.95447 0 L
.9552 0 L
.95589 0 L
.95653 0 L
.95773 0 L
.95901 0 L
.95967 0 L
.96038 0 L
Mistroke
.96166 0 L
.96244 0 L
.96318 0 L
.96385 0 L
.96458 0 L
.96526 0 L
.9659 0 L
.9671 0 L
.96839 0 L
.96912 0 L
.96978 0 L
.971 0 L
.97213 0 L
.97332 0 L
.97461 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`0Rooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00GoA4A4o`000?l0003o<S8bomgMg@1Gooooo`05odA4A?l0003o0000oc8b<_oMgMd09oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo02Gooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool09?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00omgMgOo<S8booooo`1Iooooo`03ogMgMolb<S;ooooo02Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Uooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool6o`0000Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[
ooooo`03ogMgMolb<S;ooooo05Wooooo00?oMgMgoc8b<_ooool0:?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo02Gooooo000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0Eoooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001Wooooo
00?oEEEEofIVI_l000001Oooool4o`0002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo1?l0001Hooooo`Co0000:?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool00omEEEGoIVIVo`000005ooooo`Co00009oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooC_ooool2o`0000;ooooo0_l0000Eooooo`00oooooom>
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5Oooool00?ooooooCoooool01?oMgMgo0000oa0@
4?o<c<`Fooooo`005?ooooooo`00033o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hFooooo`006ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`03ooooo`?o000000?oooooo`000?ooool02?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00Co0000ooooool0003o00001Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo013ooooo00Co8B4QogMgMomgMgOo<S8b5_ooool001_ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0/ooooo`;o00007?ooool2o`00017ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool03oooool2o`0000;ooooo0_l0000Eooooo`00Noooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0^_ooool007_ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0;[ooooo001koooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`2joooo
o`00O?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0^_ooool007cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo0;[ooooo001mooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`2jooooo`00OOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0^_ooool007kooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0Cooooo`;o0000^oooool007kooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo0;[ooooo001nooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`2jooooo`00O_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0^_ooool007kooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0;[ooooo001noooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2joooo
o`00O_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0^_ooool007oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo0;[ooooo001oooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`2jooooo`00Ooooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01Cooooo0_l0002kooooo`00Ooooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0^_ooool007oooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo0;[ooooo001oooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`2jooooo`00P?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0^_ooool0083ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0;[ooooo0020oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2joooo
o`00P?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0^_ooool0083ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo0;[ooooo0020ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05_oo
ool2o`000;_ooooo0020ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`2jooooo`00POooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0^_ooool0087ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo0;[ooooo0021ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`2jooooo`00POooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0^_ooool0087ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0;[ooooo0021oooo
o`03o`000?oooooooooo00cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Kooooo00?o0000ooooooooool0^_ooool0087ooooo00?o0000ooooooooool03?ooool01Omg
MgOoV9RHo`000?nHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_oo
ool00ol0003oooooooooo`2jooooo`00POooool00ol0003oooooooooo`0<ooooo`05oa0@4?oooooo
0000ooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0;[ooooo0021
ooooo`03o`000?oooooooooo00cooooo00Go0000ooooool0003oooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Kooooo0ol0002jooooo`00POooool00ol0003oooooooooo`0<ooooo`;o00000_ooool0
0ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0^_ooool0
087ooooo00?o0000ooooooooool03?ooool01Ol@413o0000oooooooooooo410@00oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`2jooooo`00POooool00ol0003oooooooooo`0<oooo
o`05ogMgMol0003ooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o
0000ooooooooool0^_ooool008;ooooo00?o0000ooooooooool02oooool01Oo^k^ko0000o`000?lb
<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;[ooooo
0022ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`2jooooo`00P_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0^_ooool008;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo0;[ooooo0022ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`2jooooo`00P_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo01Oooooo0_l0002kooooo`00P_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0^_ooool008;ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0;[ooooo0022ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`2jooooo`00P_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0^_ooool008;ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0;[ooooo
0022ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`2jooooo`00P_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0^_ooool008;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo0;[ooooo0023ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool06?ooool2o`000;_ooooo0023ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`2jooooo`00Poooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0^_ooool008?ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0;[ooooo0023ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`2jooooo`00Poooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0^_ooool008?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0;[ooooo
0023ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`2jooooo`00Poooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0^_ooool008?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo0;[ooooo0023ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool06?ooool2o`000;_ooooo0023ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`2jooooo`00Q?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0^_ooool008Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0;[ooooo0024ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2jooooo`00Q?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0^_ooool008Cooooo
00?o0000ooooooooool02?ooool01_l0003ok^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`2jooooo`00Q?ooool00ol0003o
ooooooooo`08ooooo`06o`000?mgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2jooooo`00Q?ooool00ol0003oooooooooo`08oooo
o`03o`000?l@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000oooo
ooooool0^_ooool008Cooooo00?o0000ooooooooool02?ooool2o`0000?ooooo00?o0000oooooooo
ool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000^_ooool008Cooooo00?o0000oooooooo
ool02?ooool2o`0000?ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007oooo
o`03o`000?oooooooooo0;[ooooo0024ooooo`03o`000?oooooooooo00Sooooo00?o0000oa0@4?oo
ool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooooooo
ool0^_ooool008Cooooo00?o0000ooooooooool02?ooool01_l0003oMgMgoiRHV?ooooooV9RHogMg
M`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2jooooo`00Q?ooool00ol0003o
ooooooooo`08ooooo`06o`000?o^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06
ooooo`03o`000?oooooooooo0;[ooooo0025ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`2jooooo`00QOooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0^_ooool008Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0;[ooooo0025ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2jooooo`00QOooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo0_l0002kooooo`00QOooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0^_ooool008Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0;[o
oooo0025ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`2jooooo`00QOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0^_ooool008Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo0;[ooooo0025ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`2jooooo`00Q_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0^_ooool008Kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0;[ooooo0026ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`2jooooo`00Q_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01_ooooo0_l0002kooooo`00Q_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0^_ooool008Ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0;[o
oooo0026ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`2jooooo`00Q_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0^_ooool008Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo0;[ooooo0026ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`2jooooo`00Q_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0^_ooool008Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0;[ooooo0026ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool07?ooool2o`000;_ooooo0026ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`2jooooo`00Q_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0^_ooool008Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0;[o
oooo0027ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`2jooooo`00Qoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0^_ooool008Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo0;[ooooo0027ooooo`03o`000?oooooooooo00;ooooo00Wo0000oooo
ooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c006ooooo`03o`000?oooooooooo0;[ooooo0027ooooo`03o`000?oooooooooo00;ooooo
00Wo0000ooooooooooooooooogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEE
ogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;[ooooo0027ooooo`03o`000?oooooo
oooo00;ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Wooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000^_ooool008Sooooo00Co0000oooooooooooo0000
1?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo0;[ooooo0028ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooooooo
o`2jooooo`00R?ooool01?l0003oooooooooool00004ooooo`05oa0@4?ooooooooooooooool@4100
2oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0;[ooooo0028ooooo`04o`000?oo
ooooooooo`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00So
oooo00?o0000ooooooooool0^_ooool008Sooooo00Co0000oooooooooooo00001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2j
ooooo`00R?ooool00ol0003oooooo`00000Pooooo`03o`000?oooooooooo0;[ooooo0029ooooo`;o
00008?ooool00ol0003oooooooooo`2jooooo`00ROooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;[ooooo
002@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@06ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0^_ooool0093o
oooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3
o`000;[ooooo002@ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0
003oc<c<00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Go410@oooooooooooooooooa0@
400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`2jooooo`00T?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03
o`000?oooooooooo0;[ooooo002@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo
410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:7ooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo0;[ooooo002Sooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0^_ooool00:?ooooo00?o0000ooooooooool01Oooool3o`000;[ooooo002S
ooooo`03o`000?oooooooooo0<;ooooo002Sooooo`03o`000?oooooooooo0<;ooooo002Sooooo`03
o`000?oooooooooo0<;ooooo002Sooooo`03o`000?oooooooooo0<;ooooo002Qooooo`03oeEEEOmV
IVKo00000<Cooooo003oooooofWooooo001Yooooo`03ogMgMomVIVKooooo00Cooooo00?o0000oooo
ooooool00_ooool00onj^[[o<S8booooo`07ooooo`;o00002oooool00ol0003o^[Zjooooo`0<oooo
o`;o00001oooool00ol0003oooooooooo`02ooooo`03ofIVI_mgMgOooooo00cooooo00?o0000okZj
^_ooool0[Oooool006Sooooo00?ogMgMoa0@4?o^k^h01Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`03onk^k_l@413ogMgM00cooooo0_lb<S:^ooooo`00
J?ooool00omEEEGoV9RHooooo`05ooooo`06o`000?oooooooooooooooonHV9So410@0_l000000onY
ZJWoooooooooo`04ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7
o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`03ooooo`03ohN7QomVIVKooooo00_ooooo00?oQhN7o`000?nj^[X03?oo
ool01OnHV9So0000o`000?m4A4Co^[Zj013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<07Oooooo001Xooooo`03o`000?oooooooooo00Go
oooo00[o0000ooooooooooooooooo`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj1Oooool02_l0003ooooo
ooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go
410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00oo^k^ko0000ooooo`0;ooooo`03olc<c?l0003o410@00cooooo00Ko410@okZj^_o^k^ko
MgMgoa0@4?ooool6o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1Ol@413o^[ZjoooooomgMgOo<S8b07Oooooo001Xooooo`03oc8b<_oooooooooo00Gooooo00[o0000
oooooooooooooooooc8b<_o^k^koV9RHoeEEEOoMgMgo410@1Oooool00ol0003oooooooooo`02oooo
o`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0B
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`1eooooo`00J?ooool0
0olb<S;oooooooooo`05ooooo`0;o`000?oooooooooooooooonj^[[oA4A4olc<c?lQ8B7ooooooa0@
4?o<c<`01?ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`03ooooo`Ko00002Oooool01Ol0003ooooooooooooo
oooo000000kooooo00?oZJVYoa0@4?ooool0M_ooool006Sooooo00?o0000onk^k_ooool01Oooool0
2ol0003oooooooooooooooook^k^o`000?oooooo0000oooooomVIVKoQhN700Cooooo00?o0000oooo
ooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03onk^k_l0003ooooo01[ooooo00?o0000
ooooooooool04_ooool01Ol0003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X0Mooo
ool006Sooooo00?oEEEEogMgMoooool01Oooool02?l0003oooooooooooooooooIVIVoiRHV?oooooo
<S8b0_nj^[X00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`00
00Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00omgMgOoEEEEooooo`02ooooo`Co00004_ooool00ol@413o0000o`000003o`00
017ooooo00Go410@oooooooooooooooooa0@400>ooooo`03okZj^_lQ8B7ooooo07Kooooo001Xoooo
o`03omgMgOl@413ok^k^00Gooooo00?o0000ooooooooool01?ooool00omVIVKoQhN7ooooo`05oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?ok^k^oa0@4?oMgMd01?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9So
oooookZj^_l00000Moooool006Wooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`04
ooooo`03ojVYZOm4A4Cooooo00Gooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l00007
ooooo`03o`000?oooooooooo00;ooooo00?oIVIVogMgMoooool01Oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@
413o0000oa0@4?nYZJT0Moooool00;;ooooo00?o0000ooooooooool0/oooool00:oooooo00Co0000
oooooooooooo0000]Oooool00;3ooooo0_l0002fooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.8522, -0.080387, \
0.130126, 0.00668404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
176.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.03279 0 L
.03405 0 L
.03477 0 L
.03543 0 L
.03665 0 L
.03793 0 L
.03908 0 L
.04016 0 L
.04144 0 L
.04262 0 L
.04384 0 L
.04501 0 L
.04624 0 L
.04693 0 L
.04758 0 L
.0489 0 L
.05014 0 L
.05083 0 L
.05158 0 L
.05288 0 L
.05404 0 L
.0553 0 L
.05594 0 L
.05663 0 L
.05786 0 L
.05909 0 L
.06026 0 L
.06131 0 L
.06244 0 L
.0637 0 L
.06435 0 L
.06505 0 L
.06632 0 L
.06749 0 L
.06877 0 L
.06949 0 L
.07015 0 L
.07092 0 L
.07165 0 L
.07232 0 L
.07306 0 L
.07376 0 L
.07442 0 L
.07512 0 L
.07587 0 L
.07657 0 L
.07723 0 L
.07847 0 L
.08433 0 L
Mistroke
.08551 0 L
.08676 0 L
.08741 0 L
.08813 0 L
.08938 0 L
.09057 0 L
.09184 0 L
.09305 0 L
.09414 0 L
.09484 0 L
.09549 0 L
.09619 0 L
.09695 0 L
.09825 0 L
.09895 0 L
.09962 0 L
.10087 0 L
.10201 0 L
.10326 0 L
.10458 0 L
.10583 0 L
.10696 0 L
.10818 0 L
.1095 0 L
.11072 0 L
.11185 0 L
.11292 0 L
.11406 0 L
.11539 0 L
.11665 0 L
.11734 0 L
.1181 0 L
.11942 0 L
.12068 0 L
.12132 0 L
.12202 0 L
.12326 0 L
.12442 0 L
.1255 0 L
.12662 0 L
.1276 0 L
.12864 0 L
.12977 0 L
.13081 0 L
.13206 0 L
.13319 0 L
.13443 0 L
.13557 0 L
.13682 0 L
.13745 0 L
Mistroke
.13815 0 L
.13931 0 L
.14056 0 L
.14174 0 L
.14282 0 L
.14411 0 L
.14533 0 L
.14642 0 L
.1476 0 L
.14888 0 L
.14953 0 L
.15024 0 L
.15152 0 L
.15268 0 L
.15385 0 L
.15496 0 L
.15614 0 L
.15741 0 L
.15851 0 L
.15969 0 L
.1608 0 L
.16182 0 L
.16301 0 L
.16431 0 L
.165 0 L
.16564 0 L
.16632 0 L
.16705 0 L
.16777 0 L
.16845 0 L
.16973 0 L
.17039 0 L
.17109 0 L
.17187 0 L
.17259 0 L
.17391 0 L
.17511 0 L
.17577 0 L
.17648 0 L
.17778 0 L
.17898 0 L
.18026 0 L
.18146 0 L
.18255 0 L
.18376 0 L
.18489 0 L
.18613 0 L
.18681 0 L
.18745 0 L
.18812 0 L
Mistroke
.18884 0 L
.19015 0 L
.19135 0 L
.19261 0 L
.20185 0 L
.20302 0 L
.2043 0 L
.20551 0 L
.20663 0 L
.20793 0 L
.20865 0 L
.20931 0 L
.21058 0 L
.21177 0 L
.21245 0 L
.21318 0 L
.21448 0 L
.2152 0 L
.21587 0 L
.21661 0 L
.21741 0 L
.21809 0 L
.21883 0 L
.21952 0 L
.22017 0 L
.22139 0 L
.22269 0 L
.22383 0 L
.22507 0 L
.22628 0 L
.22758 0 L
.22879 0 L
.2299 0 L
.23101 0 L
.23206 0 L
.23337 0 L
.23461 0 L
.23589 0 L
.23658 0 L
.23731 0 L
.23861 0 L
.23984 0 L
.24095 0 L
.24215 0 L
.24331 0 L
.24436 0 L
.24548 0 L
.2467 0 L
.24784 0 L
.24888 0 L
Mistroke
.24987 0 L
.25092 0 L
.25206 0 L
.25327 0 L
.25441 0 L
.25546 0 L
.25668 0 L
.25733 0 L
.25801 0 L
.25927 0 L
.26043 0 L
.26167 0 L
.26282 0 L
.26402 0 L
.26533 0 L
.26647 0 L
.2675 0 L
.2687 0 L
.26982 0 L
.27105 0 L
.27235 0 L
.27347 0 L
.27467 0 L
.27597 0 L
.27718 0 L
.27993 0 L
.28107 0 L
.28228 0 L
.28361 0 L
.28484 0 L
.28598 0 L
.28705 0 L
.28824 0 L
.28949 0 L
.29054 0 L
.29168 0 L
.29272 0 L
.29369 0 L
.29588 0 L
.29822 0 L
.29955 0 L
.3008 0 L
.3021 0 L
.30279 0 L
.30354 0 L
.30485 0 L
.3061 1e-05 L
.30722 1e-05 L
.30844 1e-05 L
.3099 2e-05 L
Mistroke
.31123 2e-05 L
.31265 3e-05 L
.31419 4e-05 L
.31563 5e-05 L
.31694 6e-05 L
.3182 7e-05 L
.31953 .0001 L
.32079 .00012 L
.32193 .00015 L
.32316 .0002 L
.3245 .00025 L
.32688 .00038 L
.32914 .00056 L
.3304 .00069 L
.33179 .00087 L
.33315 .00107 L
.33461 .00135 L
.33597 .00166 L
.33722 .00201 L
.33967 .00291 L
.34216 .00415 L
.34442 .00567 L
.34702 .00799 L
.34948 .01087 L
.35176 .01428 L
.35386 .01818 L
.3586 .03041 L
.36108 .03905 L
.36339 .04871 L
.36866 .07663 L
.37379 .11227 L
.37931 .15903 L
.38944 .25236 L
.39222 .27481 L
.39517 .29528 L
.39796 .31073 L
.39917 .31604 L
.40049 .32078 L
.40175 .32418 L
.40244 .32555 L
.40308 .32651 L
.40423 .32747 L
.40547 .32743 L
.40616 .32693 L
.40691 .32601 L
.40763 .32477 L
.40828 .32332 L
.40953 .31975 L
.41085 .31479 L
.41324 .30276 L
Mistroke
.41548 .28827 L
.42059 .24747 L
.42955 .16479 L
.43911 .08796 L
.44461 .05638 L
.4472 .04384 L
.4496 .0343 L
.452 .02707 L
.45461 .02088 L
.45689 .01587 L
.45934 .01113 L
.46066 .0092 L
.46187 .00791 L
.46308 .007 L
.46423 .00638 L
.4696 .00365 L
.47212 .00227 L
.47339 .00175 L
.4748 .00131 L
.47631 .00097 L
.47773 .00074 L
.47903 .00056 L
.48045 .00041 L
.48172 .0003 L
.48291 .00022 L
.48416 .00017 L
.48486 .00014 L
.48549 .00012 L
.48663 .0001 L
.48787 8e-05 L
.49011 5e-05 L
.49137 3e-05 L
.49208 3e-05 L
.49275 2e-05 L
.49345 2e-05 L
.49409 2e-05 L
.49483 2e-05 L
.49554 1e-05 L
.49794 1e-05 L
.49929 1e-05 L
.50054 1e-05 L
.5018 0 L
.50243 0 L
.50313 0 L
.50439 0 L
.50557 0 L
.50673 0 L
.50778 0 L
.50892 0 L
.51014 0 L
Mistroke
.51144 0 L
.51265 0 L
.51396 0 L
.5147 0 L
.51539 0 L
.51665 0 L
.51781 0 L
.51903 0 L
.51968 0 L
.52036 0 L
.52161 0 L
.52279 0 L
.52384 0 L
.52498 0 L
.52606 0 L
.52719 0 L
.52816 0 L
.52922 0 L
.53046 0 L
.5316 0 L
.53282 0 L
.53351 0 L
.53415 0 L
.53529 0 L
.53651 0 L
.53769 0 L
.53876 0 L
.54815 0 L
.54943 0 L
.55063 0 L
.5513 0 L
.55202 0 L
.55328 0 L
.55449 0 L
.55577 0 L
.55686 0 L
.55806 0 L
.55935 0 L
.56008 0 L
.56074 0 L
.56203 0 L
.56325 0 L
.56456 0 L
.5653 0 L
.56596 0 L
.56675 0 L
.5675 0 L
.56818 0 L
.56893 0 L
.57014 0 L
Mistroke
.57142 0 L
.57262 0 L
.57372 0 L
.57501 0 L
.57573 0 L
.5764 0 L
.5776 0 L
.5789 0 L
.58004 0 L
.58124 0 L
.58255 0 L
.58375 0 L
.58488 0 L
.58592 0 L
.58707 0 L
.5883 0 L
.589 0 L
.58964 0 L
.59035 0 L
.5911 0 L
.59235 0 L
.59307 0 L
.59374 0 L
.59498 0 L
.59612 0 L
.59743 0 L
.59867 0 L
.59998 0 L
.6012 0 L
.60188 0 L
.60261 0 L
.60389 0 L
.60512 0 L
.60641 0 L
.60751 0 L
.60872 0 L
.60946 0 L
.61016 0 L
.61146 0 L
.61219 0 L
.61287 0 L
.61361 0 L
.61439 0 L
.6156 0 L
.61691 0 L
.61766 0 L
.61834 0 L
.61898 0 L
.61968 0 L
.62096 0 L
Mistroke
.62217 0 L
.62335 0 L
.62444 0 L
.62561 0 L
.6269 0 L
.62755 0 L
.62825 0 L
.62951 0 L
.6306 0 L
.63163 0 L
.6327 0 L
.63388 0 L
.63507 0 L
.63635 0 L
.63754 0 L
.63864 0 L
.63993 0 L
.64066 0 L
.64135 0 L
.64207 0 L
.64272 0 L
.64349 0 L
.6442 0 L
.6455 0 L
.64618 0 L
.64691 0 L
.64813 0 L
.64882 0 L
.64947 0 L
.65074 0 L
.65196 0 L
.65304 0 L
.65423 0 L
.65552 0 L
.65624 0 L
.65689 0 L
.65816 0 L
.65935 0 L
.66052 0 L
.66176 0 L
.66284 0 L
.66401 0 L
.66473 0 L
.66539 0 L
.66669 0 L
.66787 0 L
.66912 0 L
.67034 0 L
.67165 0 L
.67289 0 L
Mistroke
.67403 0 L
.67529 0 L
.676 0 L
.67667 0 L
.67737 0 L
.67801 0 L
.67869 0 L
.67944 0 L
.6806 0 L
.68182 0 L
.68296 0 L
.684 0 L
.68524 0 L
.68591 0 L
.68656 0 L
.6877 0 L
.68895 0 L
.69013 0 L
.6912 0 L
.69244 0 L
.6936 0 L
.69461 0 L
.69568 0 L
.69685 0 L
.69792 0 L
.69915 0 L
.69984 0 L
.70048 0 L
.70165 0 L
.7029 0 L
.70401 0 L
.70505 0 L
.70619 0 L
.70743 0 L
.70874 0 L
.70999 0 L
.7112 0 L
.71233 0 L
.71302 0 L
.71367 0 L
.71488 0 L
.71619 0 L
.71693 0 L
.71761 0 L
.71867 0 L
.71981 0 L
.72088 0 L
.72186 0 L
.72301 0 L
.72426 0 L
Mistroke
.72544 0 L
.72653 0 L
.72765 0 L
.7287 0 L
.72995 0 L
.7311 0 L
.73224 0 L
.73344 0 L
.73464 0 L
.73596 0 L
.73719 0 L
.73849 0 L
.73917 0 L
.73992 0 L
.74124 0 L
.74248 0 L
.74318 0 L
.74381 0 L
.74505 0 L
.74622 0 L
.74735 0 L
.74854 0 L
.74957 0 L
.75069 0 L
.752 0 L
.75324 0 L
.75445 0 L
.75556 0 L
.75686 0 L
.7581 0 L
.75879 0 L
.75953 0 L
.76083 0 L
.76207 0 L
.76338 0 L
.76451 0 L
.76575 0 L
.76702 0 L
.76774 0 L
.76839 0 L
.7696 0 L
.77088 0 L
.77155 0 L
.77227 0 L
.77356 0 L
.77436 0 L
.7751 0 L
.77577 0 L
.7765 0 L
.77774 0 L
Mistroke
.77887 0 L
.78017 0 L
.7814 0 L
.78254 0 L
.7836 0 L
.78474 0 L
.78598 0 L
.78722 0 L
.78838 0 L
.78905 0 L
.78976 0 L
.79103 0 L
.79167 0 L
.79236 0 L
.7936 0 L
.79435 0 L
.79507 0 L
.79571 0 L
.7964 0 L
.79771 0 L
.79893 0 L
.79963 0 L
.80027 0 L
.80101 0 L
.80172 0 L
.80239 0 L
.80311 0 L
.80441 0 L
.8052 0 L
.80595 0 L
.80662 0 L
.80735 0 L
.80799 0 L
.80867 0 L
.80991 0 L
.8112 0 L
.81194 0 L
.81261 0 L
.8138 0 L
.8151 0 L
.81632 0 L
.81746 0 L
.81863 0 L
.81987 0 L
.82093 0 L
.82209 0 L
.82334 0 L
.82403 0 L
.82468 0 L
.82594 0 L
Mistroke
.82708 0 L
.82818 0 L
.82934 0 L
.83033 0 L
.83142 0 L
.83259 0 L
.83385 0 L
.83504 0 L
.83612 0 L
.83739 0 L
.8381 0 L
.83875 0 L
.84001 0 L
.84118 0 L
.84184 0 L
.84254 0 L
.84325 0 L
.84402 0 L
.84469 0 L
.8454 0 L
.84669 0 L
.84799 0 L
.84872 0 L
.84939 0 L
.85063 0 L
.85194 0 L
.85312 0 L
.85422 0 L
.85543 0 L
.85673 0 L
.85799 0 L
.85913 0 L
.86045 0 L
.8617 0 L
.86286 0 L
.86392 0 L
.86509 0 L
.86632 0 L
.86757 0 L
.86827 0 L
.86891 0 L
.87014 0 L
.87132 0 L
.87198 0 L
.87268 0 L
.87395 0 L
.87465 0 L
.87531 0 L
.87603 0 L
.87681 0 L
Mistroke
.87745 0 L
.87813 0 L
.87937 0 L
.88012 0 L
.88083 0 L
.88147 0 L
.88217 0 L
.88291 0 L
.88359 0 L
.88431 0 L
.88511 0 L
.88641 0 L
.88714 0 L
.88782 0 L
.88911 0 L
.8898 0 L
.89052 0 L
.89122 0 L
.89187 0 L
.89309 0 L
.8943 0 L
.89541 0 L
.89663 0 L
.89792 0 L
.89914 0 L
.89983 0 L
.90047 0 L
.90164 0 L
.90288 0 L
.90399 0 L
.90504 0 L
.90618 0 L
.90741 0 L
.90864 0 L
.90934 0 L
.90999 0 L
.91131 0 L
.91205 0 L
.91271 0 L
.91391 0 L
.91522 0 L
.91644 0 L
.91758 0 L
.91863 0 L
.91977 0 L
.92084 0 L
.92182 0 L
.92297 0 L
.92421 0 L
.92539 0 L
Mistroke
.92649 0 L
.92772 0 L
.92888 0 L
.92993 0 L
.93105 0 L
.93229 0 L
.93359 0 L
.9348 0 L
.93591 0 L
.93714 0 L
.93779 0 L
.93848 0 L
.93963 0 L
.9409 0 L
.94202 0 L
.94324 0 L
.94438 0 L
.94543 0 L
.94672 0 L
.94792 0 L
.94924 0 L
.94992 0 L
.95065 0 L
.95135 0 L
.95199 0 L
.95325 0 L
.95439 0 L
.95561 0 L
.95676 0 L
.95781 0 L
.95886 0 L
.95986 0 L
.96102 0 L
.9621 0 L
.96328 0 L
.96453 0 L
.96564 0 L
.96684 0 L
.96798 0 L
.96901 0 L
.97016 0 L
.97142 0 L
.97274 0 L
.97396 0 L
.97513 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`0Rooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00GoA4A4o`000?l0003o<S8bomgMg@1Gooooo`05odA4A?l0003o0000oc8b<_oMgMd09oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo02Gooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool09?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00omgMgOo<S8booooo`1Iooooo`03ogMgMolb<S;ooooo02Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Uooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool6o`0000Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[
ooooo`03ogMgMolb<S;ooooo05Wooooo00?oMgMgoc8b<_ooool0:?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo02Gooooo000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0Eoooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001Wooooo
00?oEEEEofIVI_l000001Oooool4o`0002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo1?l0001Hooooo`Co0000:?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool00omEEEGoIVIVo`000005ooooo`Co00009oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooC_ooool2o`0000;ooooo0_l0000Eooooo`00oooooom>
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5Oooool00?ooooooCoooool01?oMgMgo0000oa0@
4?o<c<`Fooooo`005?ooooooo`00033o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hFooooo`006ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`?o00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool3o`0000Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?oo
ool01?lQ8B7oMgMgogMgMolb<S8Fooooo`006oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo02gooooo0_l0000Sooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03ooo
ool2o`0000;ooooo0_l0000Eooooo`00OOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0^_ooool007kooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo0;[ooooo001nooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2jooooo`00Ooooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0^_ooool007oooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0;[ooooo0020
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2j
ooooo`00P?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0^_ooool0083ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`;o
0000^oooool0087ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo0;[ooooo0021ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`2jooooo`00POooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0^_ooool008;ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo0;[ooooo0022ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2jooooo`00P_ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0^_ooool008;ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0;[ooooo0022
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2j
ooooo`00P_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00kooooo0_l0002koooo
o`00Poooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0^_ooool008?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo0;[ooooo0023ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`2jooooo`00Poooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0^_ooool008?ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0;[ooooo0023ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2jooooo`00Poooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0^_ooool008Cooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;[ooooo0024
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03oooool2o`000;_ooooo0024oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2joooo
o`00Q?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0^_ooool008Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo0;[ooooo0025ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`2jooooo`00QOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0^_ooool008Gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo0;[ooooo0025ooooo`03o`000?oooooooooo00So
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`04o`000?oooooo8B4Qob4Q8@Cooooo1Ol00006
ooooo`03o`000?oooooooooo0;[ooooo0025ooooo`03o`000?oooooooooo00Sooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`04o`000?oooooo8B4Qob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0;[ooooo0025ooooo`03o`000?oooooooooo00Sooooo00Go
410@oooooooooooooooooa0@4003ooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0
1oooool00ol0003oooooooooo`2jooooo`00QOooool00ol0003oooooooooo`08ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`07ooooo`03oiRHV?lQ8B7ok^k^00Kooooo
0ol0002jooooo`00QOooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`09ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0
^_ooool008Gooooo00?o0000ooooooooool02?ooool01Ol@413ooooooooooooooooo410@00;ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;[ooooo
0025ooooo`03o`000?oooooooooo00Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`03o`00
0?oooooooooo00Kooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0;[o
oooo0026ooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03
o`000?oooooooooo00Kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
0;[ooooo0026ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`2jooooo`00Q_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0^_ooool008Kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo0;[ooooo0026ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`2jooooo`00Q_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01;ooooo0_l0002kooooo`00Q_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0^_ooool008Kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0;[ooooo0026ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`2jooooo`00Q_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0^_ooool0
08Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
0;[ooooo0027ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`2jooooo`00Qoooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0^_ooool008Oooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo0;[ooooo0027ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04oooool2o`000;_ooooo0027ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`2jooooo`00Qoooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0^_ooool008Oooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0;[ooooo0028ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2jooooo`00R?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0^_ooool0
08Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
0;[ooooo0028ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`2jooooo`00R?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0^_ooool008Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo0;[ooooo0028ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool05?ooool2o`000;_ooooo0029ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`2jooooo`00ROooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0^_ooool008Wooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0;[ooooo0029ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2jooooo`00ROooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0^_ooool0
08Wooooo00?o0000ooooooooool01?ooool01Oo^k^ko<S8bo`000?l0003ok^k^00Gooooo0_lQ8B46
ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`2jooooo`00ROooool00ol0
003oooooooooo`04ooooo`05ogMgMonHV9Soooooo`000?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2jooooo`00R_ooool00ol0003oooooooooo`03oooo
o`05oa0@4?ooooooooooo`000?l@41002oooool5o`0000Kooooo00?o0000ooooooooool0^_ooool0
08[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02o`0000_ooooo00CoA4A4omgM
gOoooooo00001oooool3o`000;[ooooo002:ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_l0000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0^_ooool0
08[ooooo00?o0000ooooooooool00oooool01Ol@413oooooooooool0003o410@00cooooo00?oMgMg
olc<c?l000001oooool00ol0003oooooooooo`2jooooo`00R_ooool00ol0003oooooooooo`03oooo
o`05ogMgMonHV9Soooooo`000?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooo
oooo0;[ooooo002:ooooo`03o`000?oooooooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=
ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0^_ooool008[ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0;[ooooo002:ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`2jooooo`00
R_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
^_ooool008[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo0;[ooooo002:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool2
o`000;_ooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`2jooooo`00R_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0^_ooool008_ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo0;[ooooo002;ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`2jooooo`00Roooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0^_ooool008_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0;[ooooo002;ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`2jooooo`00
Roooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
^_ooool008cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo0;[ooooo002<ooooo`05o`000?ooooooooooooooool000006_ooool2o`000;_ooooo002<
ooooo`05o`000?ooooooooooooooool000006_ooool00ol0003oooooooooo`2jooooo`00S?ooool0
1Ol0003ooooooooooooooooo000001[ooooo00?o0000ooooooooool0^_ooool008gooooo00Co0000
oooooooooooo00006_ooool00ol0003oooooooooo`2jooooo`00SOooool00ol0003oooooo`00000K
ooooo`03o`000?oooooooooo0;[ooooo002=ooooo`?o00006oooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0;[ooooo002@oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q
8@06ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol0003ooooooooooooooooo000000Kooooo0ol0002jooooo`00T?ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;[o
oooo002@ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<
00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Go410@oooooooooooooooooa0@400;oooo
o`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0^_ooool0093o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000
^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0093ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0^_ooool0093ooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`2jooooo`00T?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRH
V?ooooooV9RHoc8b<P06ooooo`?o0000^_ooool0093ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`2jooooo`00T?ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`00
0?oooooooooo0;[ooooo002@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonj^[[o000000Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`00
0;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00XOooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0^_ooool00:?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`2jooooo`00Xoooool00ol0003ooooooooo
o`05ooooo`?o0000^_ooool00:?ooooo00?o0000ooooooooool0`_ooool00:?ooooo00?o0000oooo
ooooool0`_ooool00:?ooooo00?o0000ooooooooool0`_ooool00:?ooooo00?o0000ooooooooool0
`_ooool00:7ooooo00?oEEEEofIVI_l00000a?ooool00?ooooooJOooool006Wooooo00?oMgMgofIV
I_ooool01?ooool00ol0003oooooooooo`02ooooo`03okZj^_lb<S;ooooo00Oooooo0_l0000;oooo
o`03o`000?nj^[[ooooo00cooooo0_l00007ooooo`03o`000?oooooooooo00;ooooo00?oIVIVogMg
Moooool03?ooool00ol0003o^[Zjooooo`2]ooooo`00J?ooool00ooMgMgo410@onk^kP05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`;o
<S8b3_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?ok^k^oa0@4?oM
gMd03?ooool2oc8b<Zkooooo001Xooooo`03oeEEEOnHV9Sooooo00Gooooo00Ko0000oooooooooooo
oooooiRHV?l@4102o`000003ojVYZOoooooooooo00Cooooo00Co0000oooooooooooooooo0_l00002
ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?oQhN7ofIVI_ooool02ooo
ool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X04?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0MOooool006Sooooo
00?o0000ooooooooool01Oooool02_l0003ooooooooooooooooo0000ojVYZOmEEEGoV9RHoeEEEOnj
^[X5ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<
o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`03ooooo`03onk^k_l0003ooooo00_ooooo00?oc<c<o`000?l@41003?oo
ool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo07Kooooo001Xooooo`03oc8b<_oooooooooo00Go
oooo00[o0000oooooooooooooooooc8b<_o^k^koV9RHoeEEEOoMgMgo410@1Oooool00ol0003ooooo
ooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Booooo`05oa0@4?ooooooooooooooool@41002oooool5o`0007Oooooo001Xooooo`03
oc8b<_oooooooooo00Gooooo00_o0000oooooooooooooooookZj^_m4A4Coc<c<ob4Q8Ooooooo410@
olc<c004ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo1_l00009ooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool0001hooooo`00J?ooool00ol0003ok^k^ooooo`05oooo
o`0;o`000?ooooooooooooooooo^k^ko0000ooooool0003oooooofIVI_n7QhL01?ooool00ol0003o
ooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?ok^k^o`000?ooool06_ooool00ol0
003oooooooooo`0Booooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0
001hooooo`00J?ooool00omEEEGoMgMgooooo`05ooooo`08o`000?oooooooooooooooomVIVKoV9RH
oooooolb<S82okZj^P03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l00002oooo
o`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`03ogMgMomEEEGooooo00;ooooo1?l0000Booooo`03oa0@4?l0003o0000
00?o00004Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000N?ooool0
06Sooooo00?ogMgMoa0@4?o^k^h01Oooool00ol0003oooooooooo`04ooooo`03ofIVI_n7QhOooooo
00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool00oo^k^ko410@omgMg@04ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool04_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l00000N?ooool006Wooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`04oooo
o`03ojVYZOm4A4Cooooo00Gooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l00007oooo
o`03o`000?oooooooooo00;ooooo00?oIVIVogMgMoooool01Oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003o
oooo07Oooooo002booooo`03o`000?oooooooooo0;?ooooo002_ooooo`04o`000?ooooooooooo`00
0;Gooooo002`ooooo`;o0000]_ooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.8522, -0.080387, \
0.130126, 0.00668404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
176.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.03279 0 L
.03405 0 L
.03477 0 L
.03543 0 L
.03665 0 L
.03793 0 L
.03908 0 L
.04016 0 L
.04144 0 L
.04262 0 L
.04384 0 L
.04501 0 L
.04624 0 L
.04693 0 L
.04758 0 L
.04827 0 L
.04892 0 L
.05014 0 L
.05146 0 L
.0522 0 L
.05288 0 L
.05403 0 L
.0551 0 L
.05627 0 L
.05753 0 L
.05885 0 L
.0601 0 L
.06123 0 L
.06244 0 L
.06369 0 L
.06486 0 L
.06554 0 L
.06625 0 L
.06753 0 L
.06817 0 L
.06886 0 L
.07011 0 L
.07087 0 L
.07158 0 L
.07222 0 L
.07293 0 L
.0741 0 L
.07535 0 L
.0765 0 L
.07758 0 L
.07885 0 L
.08001 0 L
.08065 0 L
.08135 0 L
Mistroke
.08263 0 L
.08334 0 L
.08412 0 L
.0848 0 L
.08552 0 L
.08617 0 L
.08689 0 L
.08814 0 L
.08891 0 L
.08961 0 L
.09042 0 L
.09118 0 L
.09189 0 L
.09256 0 L
.09325 0 L
.09402 0 L
.09528 0 L
.096 0 L
.09665 0 L
.09783 0 L
.09908 0 L
.10035 0 L
.10106 0 L
.10171 0 L
.10247 0 L
.1032 0 L
.10392 0 L
.10458 0 L
.10574 0 L
.10698 0 L
.10815 0 L
.10922 0 L
.11048 0 L
.11114 0 L
.11184 0 L
.11302 0 L
.11433 0 L
.11928 0 L
.11994 0 L
.12063 0 L
.12189 0 L
.1232 0 L
.12389 0 L
.12463 0 L
.12533 0 L
.12597 0 L
.12723 0 L
.12838 0 L
.1296 0 L
.13072 0 L
Mistroke
.13177 0 L
.13292 0 L
.13415 0 L
.1353 0 L
.13655 0 L
.13773 0 L
.13883 0 L
.13989 0 L
.14089 0 L
.14205 0 L
.1431 0 L
.14426 0 L
.14551 0 L
.14669 0 L
.14776 0 L
.14902 0 L
.14973 0 L
.15038 0 L
.15167 0 L
.15287 0 L
.15402 0 L
.15525 0 L
.15592 0 L
.15662 0 L
.15788 0 L
.15919 0 L
.16042 0 L
.16112 0 L
.16176 0 L
.1625 0 L
.16319 0 L
.16426 0 L
.16543 0 L
.16666 0 L
.16781 0 L
.16888 0 L
.16986 0 L
.17092 0 L
.17206 0 L
.17328 0 L
.17442 0 L
.17512 0 L
.17577 0 L
.17699 0 L
.17816 0 L
.17924 0 L
.18042 0 L
.18167 0 L
.1829 0 L
.18359 0 L
Mistroke
.18423 0 L
.1854 0 L
.18665 0 L
.18776 0 L
.18881 0 L
.18995 0 L
.19118 0 L
.19248 0 L
.19322 0 L
.19391 0 L
.19516 0 L
.19586 0 L
.1965 0 L
.1977 0 L
.199 0 L
.20023 0 L
.20136 0 L
.20242 0 L
.20356 0 L
.20463 0 L
.20561 0 L
.20676 0 L
.20801 0 L
.20919 0 L
.21028 0 L
.2114 0 L
.21246 0 L
.21361 0 L
.21485 0 L
.21609 0 L
.21739 0 L
.2186 0 L
.21971 0 L
.22095 0 L
.2216 0 L
.22228 0 L
.22344 0 L
.22471 0 L
.22584 0 L
.22706 0 L
.2282 0 L
.22925 0 L
.23046 0 L
.23175 0 L
.2325 0 L
.23317 0 L
.23448 0 L
.23571 0 L
.2364 0 L
.23704 0 L
Mistroke
.2382 0 L
.23944 0 L
.2406 0 L
.24165 0 L
.24271 0 L
.24371 0 L
.24487 0 L
.24595 0 L
.24713 0 L
.24838 0 L
.24949 0 L
.25069 0 L
.25183 0 L
.25286 0 L
.25411 0 L
.25527 0 L
.25649 0 L
.25713 0 L
.25781 0 L
.25905 0 L
.25975 0 L
.26041 0 L
.26114 0 L
.26184 0 L
.26315 0 L
.26429 0 L
.26552 0 L
.26685 0 L
.26807 0 L
.26939 0 L
.27063 0 L
.27134 0 L
.27199 0 L
.27275 0 L
.27346 0 L
.2741 0 L
.27479 0 L
.27555 0 L
.27625 0 L
.27919 0 L
.28181 0 L
.2831 0 L
.28428 0 L
.28551 0 L
.28619 0 L
.28684 0 L
.28754 0 L
.28819 0 L
.28891 0 L
.28967 0 L
Mistroke
.29193 0 L
.29317 0 L
.29432 0 L
.29557 0 L
.29623 0 L
.29694 0 L
.2982 0 L
.29935 0 L
.30062 0 L
.30134 0 L
.302 0 L
.30322 0 L
.30452 1e-05 L
.30703 1e-05 L
.30939 2e-05 L
.31148 2e-05 L
.31265 2e-05 L
.31372 3e-05 L
.31483 4e-05 L
.31605 4e-05 L
.31732 6e-05 L
.3185 7e-05 L
.32121 .00011 L
.32376 .00017 L
.32606 .00023 L
.32855 .00032 L
.32984 .00039 L
.33126 .00048 L
.33265 .00058 L
.33413 .00073 L
.3368 .00105 L
.33928 .00147 L
.34183 .00202 L
.34454 .00278 L
.3471 .00373 L
.34942 .00488 L
.35215 .00667 L
.35511 .00924 L
.35766 .012 L
.36046 .01564 L
.36556 .02466 L
.36835 .03145 L
.37094 .03907 L
.38057 .07715 L
.39925 .19285 L
.40437 .2231 L
.40979 .25143 L
.41203 .26076 L
.41443 .2685 L
.4158 .27177 L
Mistroke
.41707 .27401 L
.41833 .27555 L
.41954 .27639 L
.42023 .27662 L
.42087 .27669 L
.42209 .27643 L
.4234 .27559 L
.42413 .27484 L
.42481 .27393 L
.42595 .27185 L
.42719 .26858 L
.42849 .2639 L
.42971 .25836 L
.43552 .22839 L
.43806 .21942 L
.4394 .21398 L
.44082 .20596 L
.44205 .19663 L
.44341 .18414 L
.44581 .16136 L
.44698 .15256 L
.44825 .146 L
.44944 .14232 L
.45054 .14006 L
.45179 .137 L
.45296 .13206 L
.45424 .12313 L
.45561 .10969 L
.45821 .0809 L
.45952 .06993 L
.46026 .06575 L
.46096 .06326 L
.46164 .06206 L
.4623 .06188 L
.46352 .06317 L
.46421 .06423 L
.46495 .06515 L
.46565 .06552 L
.46628 .06527 L
.46749 .06293 L
.46863 .0586 L
.46986 .05224 L
.47119 .04455 L
.474 .03019 L
.47542 .02494 L
.47697 .02045 L
.47972 .01431 L
.48228 .00986 L
.48354 .00818 L
.4849 .00675 L
Mistroke
.48618 .00573 L
.48737 .00497 L
.48977 .00373 L
.49201 .00274 L
.49326 .00228 L
.49441 .00193 L
.49569 .00163 L
.49706 .00138 L
.49988 .00097 L
.5011 .0008 L
.50243 .00063 L
.5037 .0005 L
.50487 .00042 L
.50599 .00035 L
.50718 .0003 L
.5098 .0002 L
.51108 .00015 L
.51225 .00011 L
.51332 9e-05 L
.51434 7e-05 L
.51542 6e-05 L
.5166 5e-05 L
.51906 3e-05 L
.52027 2e-05 L
.52137 2e-05 L
.52269 1e-05 L
.52338 1e-05 L
.52411 1e-05 L
.52529 1e-05 L
.52658 1e-05 L
.52731 1e-05 L
.52797 1e-05 L
.52945 0 L
.53011 0 L
.53082 0 L
.53212 0 L
.53332 0 L
.53464 0 L
.5353 0 L
.53601 0 L
.5373 0 L
.53858 0 L
.5398 0 L
.54089 0 L
.54208 0 L
.54332 0 L
.54463 0 L
.54532 0 L
.54607 0 L
.54739 0 L
Mistroke
.54864 0 L
.54934 0 L
.54998 0 L
.55122 0 L
.5524 0 L
.55353 0 L
.55472 0 L
.55575 0 L
.55688 0 L
.55809 0 L
.55939 0 L
.56062 0 L
.56175 0 L
.56297 0 L
.56428 0 L
.56551 0 L
.56663 0 L
.56795 0 L
.56864 0 L
.56938 0 L
.57002 0 L
.57072 0 L
.57197 0 L
.57268 0 L
.57337 0 L
.57465 0 L
.57536 0 L
.57602 0 L
.5768 0 L
.57752 0 L
.57885 0 L
.58004 0 L
.58133 0 L
.58206 0 L
.58272 0 L
.58388 0 L
.58514 0 L
.58634 0 L
.58744 0 L
.58872 0 L
.58936 0 L
.59008 0 L
.59132 0 L
.59248 0 L
.5936 0 L
.59477 0 L
.59577 0 L
.59686 0 L
.59805 0 L
.59931 0 L
Mistroke
.60041 0 L
.60158 0 L
.60225 0 L
.60298 0 L
.60426 0 L
.60498 0 L
.60576 0 L
.60649 0 L
.60716 0 L
.60845 0 L
.60918 0 L
.60986 0 L
.6111 0 L
.61242 0 L
.61358 0 L
.61483 0 L
.61591 0 L
.61709 0 L
.61841 0 L
.61912 0 L
.61979 0 L
.62098 0 L
.62226 0 L
.62349 0 L
.62419 0 L
.62484 0 L
.62616 0 L
.6269 0 L
.62757 0 L
.62878 0 L
.63009 0 L
.63133 0 L
.63248 0 L
.63318 0 L
.63393 0 L
.63464 0 L
.6353 0 L
.63654 0 L
.63785 0 L
.63853 0 L
.63926 0 L
.64058 0 L
.64139 0 L
.64215 0 L
.64288 0 L
.64358 0 L
.64473 0 L
.64601 0 L
.64725 0 L
.64795 0 L
Mistroke
.64859 0 L
.64967 0 L
.65085 0 L
.65208 0 L
.65323 0 L
.65388 0 L
.65459 0 L
.65588 0 L
.65714 0 L
.6583 0 L
.65955 0 L
.66027 0 L
.66093 0 L
.66163 0 L
.66228 0 L
.66297 0 L
.66372 0 L
.66501 0 L
.66623 0 L
.66732 0 L
.6685 0 L
.6698 0 L
.6705 0 L
.67116 0 L
.67234 0 L
.6736 0 L
.67478 0 L
.67606 0 L
.67727 0 L
.67839 0 L
.6794 0 L
.68051 0 L
.68167 0 L
.68275 0 L
.68403 0 L
.68475 0 L
.68543 0 L
.68611 0 L
.68676 0 L
.68797 0 L
.68908 0 L
.69028 0 L
.69156 0 L
.69274 0 L
.69793 0 L
.69859 0 L
.6993 0 L
.70007 0 L
.70079 0 L
.70207 0 L
Mistroke
.70281 0 L
.70349 0 L
.70477 0 L
.70594 0 L
.70723 0 L
.70787 0 L
.70858 0 L
.70974 0 L
.71099 0 L
.71216 0 L
.71322 0 L
.71431 0 L
.71546 0 L
.71673 0 L
.71789 0 L
.71898 0 L
.72 0 L
.72111 0 L
.72231 0 L
.72297 0 L
.72368 0 L
.72495 0 L
.72567 0 L
.72644 0 L
.72717 0 L
.72784 0 L
.72848 0 L
.72918 0 L
.72987 0 L
.7306 0 L
.73189 0 L
.7331 0 L
.73437 0 L
.73509 0 L
.73575 0 L
.73697 0 L
.73826 0 L
.73942 0 L
.7405 0 L
.74169 0 L
.74297 0 L
.74424 0 L
.7454 0 L
.74657 0 L
.74767 0 L
.74896 0 L
.75014 0 L
.75144 0 L
.75209 0 L
.75281 0 L
Mistroke
.75351 0 L
.75416 0 L
.7554 0 L
.75609 0 L
.75672 0 L
.75747 0 L
.75817 0 L
.75932 0 L
.76059 0 L
.76183 0 L
.76252 0 L
.76317 0 L
.76427 0 L
.76543 0 L
.76668 0 L
.76782 0 L
.76889 0 L
.77003 0 L
.77101 0 L
.77208 0 L
.77322 0 L
.77445 0 L
.77514 0 L
.77577 0 L
.77702 0 L
.77816 0 L
.77941 0 L
.78059 0 L
.78169 0 L
.78297 0 L
.78362 0 L
.78433 0 L
.78559 0 L
.78676 0 L
.78748 0 L
.78815 0 L
.78942 0 L
.79012 0 L
.79078 0 L
.79149 0 L
.79226 0 L
.79343 0 L
.7947 0 L
.79589 0 L
.79699 0 L
.7982 0 L
.79889 0 L
.79953 0 L
.80082 0 L
.80154 0 L
Mistroke
.80221 0 L
.80339 0 L
.80464 0 L
.80573 0 L
.80693 0 L
.80799 0 L
.80914 0 L
.81022 0 L
.81121 0 L
.81243 0 L
.81357 0 L
.81481 0 L
.81551 0 L
.81614 0 L
.8173 0 L
.81855 0 L
.81973 0 L
.82082 0 L
.82209 0 L
.82329 0 L
.82438 0 L
.82554 0 L
.82679 0 L
.82796 0 L
.82921 0 L
.82992 0 L
.83058 0 L
.83169 0 L
.83272 0 L
.83379 0 L
.83497 0 L
.83616 0 L
.83743 0 L
.83861 0 L
.83968 0 L
.84098 0 L
.84163 0 L
.84235 0 L
.84361 0 L
.8448 0 L
.84551 0 L
.84619 0 L
.84747 0 L
.84813 0 L
.84884 0 L
.84961 0 L
.85033 0 L
.85151 0 L
.85279 0 L
.85399 0 L
Mistroke
.8551 0 L
.85632 0 L
.85701 0 L
.85766 0 L
.85897 0 L
.85969 0 L
.86036 0 L
.86159 0 L
.86224 0 L
.86295 0 L
.86368 0 L
.86438 0 L
.86568 0 L
.8669 0 L
.86803 0 L
.86927 0 L
.87059 0 L
.87129 0 L
.87203 0 L
.87284 0 L
.87359 0 L
.87429 0 L
.87493 0 L
.87569 0 L
.87641 0 L
.87705 0 L
.87774 0 L
.87896 0 L
.87965 0 L
.88038 0 L
.88169 0 L
.88285 0 L
.88393 0 L
.88506 0 L
.8863 0 L
.88755 0 L
.88825 0 L
.88889 0 L
.89011 0 L
.89126 0 L
.89193 0 L
.89263 0 L
.89388 0 L
.89458 0 L
.89523 0 L
.89595 0 L
.89672 0 L
.89737 0 L
.89809 0 L
.89939 0 L
Mistroke
.90066 0 L
.90183 0 L
.90313 0 L
.90378 0 L
.90449 0 L
.90575 0 L
.90693 0 L
.90765 0 L
.90832 0 L
.90959 0 L
.9103 0 L
.91096 0 L
.91168 0 L
.91244 0 L
.91362 0 L
.91489 0 L
.91609 0 L
.91718 0 L
.91846 0 L
.91914 0 L
.91986 0 L
.92118 0 L
.92241 0 L
.92367 0 L
.92483 0 L
.9261 0 L
.92675 0 L
.92744 0 L
.92861 0 L
.9297 0 L
.93089 0 L
.93218 0 L
.93341 0 L
.93456 0 L
.93565 0 L
.93681 0 L
.93785 0 L
.93882 0 L
.93989 0 L
.94104 0 L
.94211 0 L
.94308 0 L
.94421 0 L
.94527 0 L
.94619 0 L
.94716 0 L
.94823 0 L
.94921 0 L
.95027 0 L
.95141 0 L
Mistroke
.95249 0 L
.95347 0 L
.95462 0 L
.95588 0 L
.95706 0 L
.95816 0 L
.95929 0 L
.96052 0 L
.96168 0 L
.96274 0 L
.9637 0 L
.96476 0 L
.96586 0 L
.96689 0 L
.9681 0 L
.96924 0 L
.97028 0 L
.97138 0 L
.97258 0 L
.97369 0 L
.97488 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`0Rooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00GoA4A4o`000?l0003o<S8bomgMg@1Gooooo`05odA4A?l0003o0000oc8b<_oMgMd09oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo02Gooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool09?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00omgMgOo<S8booooo`1Iooooo`03ogMgMolb<S;ooooo02Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Uooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool6o`0000Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[
ooooo`03ogMgMolb<S;ooooo05Wooooo00?oMgMgoc8b<_ooool0:?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo02Gooooo000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0Eoooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001Wooooo
00?oEEEEofIVI_l000001Oooool4o`0002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo1?l0001Hooooo`Co0000:?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool00omEEEGoIVIVo`000005ooooo`Co00009oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooC_ooool2o`0000;ooooo0_l0000Eooooo`00oooooom>
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5Oooool00?ooooooCoooool01?oMgMgo0000oa0@
4?o<c<`Fooooo`005?ooooooo`00033o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hFooooo`006ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`Co00001oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`Co00002Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?oo
ool01?lQ8B7oMgMgogMgMolb<S8Fooooo`006oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo02gooooo00Co0000ooooool0003o00009oooool2o`0000?ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
3oooool2o`0000;ooooo0_l0000Eooooo`00Ooooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0^_ooool0083ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;[ooooo0021ooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2jooooo`00POooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool008;ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;[ooooo
0022ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`2jooooo`00P_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0^_ooool008?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05oooo
o`;o0000^oooool008?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0;[ooooo0024ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`2jooooo`00Q?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0^_ooool008Cooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;[ooooo0025ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2jooooo`00QOooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0^_ooool008Gooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;[ooooo
0025ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`2jooooo`00Q_ooool00ol0003oooooooooo`0Fooooo`?o00002Oooool2o`000;_ooooo0026oooo
o`03o`000?oooooooooo01Kooooo0ol00009ooooo`03o`000?oooooooooo0;[ooooo0026ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2jooooo`00
Q_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
^_ooool008Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo0;[ooooo0027ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`2jooooo`00Qoooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0^_ooool008Oooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0;[ooooo0027ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2jooooo`00R?ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00[ooooo0_l0002kooooo`00R?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0^_ooool008Sooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0;[ooooo0028ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2jooooo`00
R?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
^_ooool008Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo0;[ooooo0029ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`2jooooo`00ROooool00ol0003oooooooooo`04ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@;ooooo00?o0000ooooool000001?l00006ooooo`03o`000?oooooo
oooo0;[ooooo0029ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q00Woooooo`000?oooooooooooiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`2jooooo`00ROooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
41002?ooool01ol0003oooooooooooooooooV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`2j
ooooo`00ROooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002?ooool0
0ol0003oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0002jooooo`00ROooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`03
ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0^_ooool008[ooooo00?o0000oooo
ooooool00oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;[ooooo002:ooooo`03o`000?oooooooooo
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`08o`000?ooooooooooo`000?nj^[[ooooo
oiRHV?l@4106ooooo`03o`000?oooooooooo0;[ooooo002:ooooo`03o`000?oooooooooo00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`09o`000?oooooooooooooooonHV9So410@o`000?lQ
8B7oc<c<00Kooooo00?o0000ooooooooool0^_ooool008[ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0;[ooooo002:ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2jooooo`00Roooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0^_ooool008_ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0;[ooooo
002;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool2o`000;_ooooo002;
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2j
ooooo`00Roooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0^_ooool008_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo0;[ooooo002<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`2jooooo`00S?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0^_ooool008cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0;[ooooo002<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2jooooo`00S?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0^_ooool008cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`;o0000^oooool008gooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0;[ooooo002=
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2j
ooooo`00SOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0^_ooool008gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo0;[ooooo002=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`2jooooo`00SOooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0^_ooool008gooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;[ooooo002>ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2jooooo`00S_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0^_ooool008kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`;o0000^oooool008kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0;[ooooo002>
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`2j
ooooo`00S_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0^_ooool008kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo0;[ooooo002?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`2jooooo`00Soooool01_l0003ok^k^oc8b<_l0003o<S8bonk^kP;o
oooo00?o0000ooooooooool00_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003o
ooooooooo`2jooooo`00Soooool01_l0003oMgMgoiRHV?ooooooV9RHogMgM`;ooooo00?o0000oooo
ooooool00_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^_ooool008oo
oooo00?o0000oa0@4?ooool00_ooool00ol@413oooooo`000009ooooo`Go00001_ooool00ol0003o
ooooooooo`2jooooo`00T?ooool01ol0003ooooooooooooooooo0000ooooool000002Oooool01?m4
A4CogMgMooooool00007ooooo`?o0000^_ooool0093ooooo00Oo0000ooooooooooooooooo`000?oo
oooo000000Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`2jooooo`00T?oo
ool01ol0003ooooooooooooooooo410@ooooool000002_ooool00omgMgOoc<c<o`000007ooooo`03
o`000?oooooooooo0;[ooooo002@ooooo`07o`000?nHV9SooooooiRHV?mgMgOoooooo`00000:oooo
o`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0^_ooool0093ooooo00Oo0000oc8b<_l0
003o<S8bonk^k_oooooo000000_ooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`2j
ooooo`00T?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0^_ooool0097ooooo00Go0000ooooooooooooooooo`00000Eooooo`03o`000?oooooooooo
0;[ooooo002Booooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool0^_ooool009;o
oooo00?o0000ooooool000005_ooool00ol0003oooooooooo`2jooooo`00T_ooool3o`0001Kooooo
0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0
^_ooool0093ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool0^_ooool0093ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooo
ooooool000001_ooool3o`000;[ooooo002@ooooo`05o`000?ooooooooooooooool000002oooool0
1Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Go0000
ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
2?ooool00ol0003oooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2jooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2j
ooooo`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9So
oooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;[ooooo
002@ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Ko
oooo0ol0002jooooo`00T?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0
003o0000olc<c006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0^_ooool0
093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_oo
ool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002Qooooo`Co000000?o
410@ooooooooool00oooool00ol0003oooooooooo`2jooooo`00Xoooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0;[ooooo002Sooooo`03o`000?oooooooooo00Gooooo0ol0002joooo
o`00Xoooool00ol0003oooooooooo`32ooooo`00Xoooool00ol0003oooooooooo`32ooooo`00Xooo
ool00ol0003oooooooooo`32ooooo`00Xoooool00ol0003oooooooooo`32ooooo`00XOooool00omE
EEGoIVIVo`000034ooooo`00oooooomYooooo`00JOooool00omgMgOoIVIVooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o^[Zjoc8b<_ooool01oooool2o`0000_ooooo00?o0000okZj^_ooool0
3?ooool2o`0000Oooooo00?o0000ooooooooool00_ooool00omVIVKoMgMgooooo`0<ooooo`03o`00
0?nj^[[ooooo0:gooooo001Xooooo`03omgMgOl@413ok^k^00Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool00oo^k^ko410@omgMg@0<ooooo`;o<S8b[_oo
ool006Sooooo00?oEEEEoiRHV?ooool01Oooool01_l0003oooooooooooooooooV9RHoa0@40;o0000
00?oZJVYooooooooool01?ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03
ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool00on7QhOoIVIVooooo`0;ooooo`03ohN7Qol0003o^[Zj
00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@1fooooo`00J?ooool00ol0003ooooooooo
o`05ooooo`0:o`000?ooooooooooooooool0003oZJVYoeEEEOnHV9SoEEEEokZj^PGooooo00[o0000
ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00?ok^k^o`000?ooool02oooool00oo<c<co0000oa0@400<ooooo`06oa0@4?nj^[[o
k^k^ogMgMol@413ooooo1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool0MOooool006Sooooo00?o<S8booooooooool01Oooool02_l0003ooooo
oooooooooooo<S8bonk^k_nHV9SoEEEEomgMgOl@4105ooooo`03o`000?oooooooooo00;ooooo00Co
gMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01;ooooo
00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo07Cooooo001Xooooo`03oc8b
<_oooooooooo00Gooooo00_o0000oooooooooooooooookZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<
c004ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00?ooooo1_l00009ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`1eooooo`00J?ooool00ol0003ok^k^ooooo`05ooooo`0;o`00
0?ooooooooooooooooo^k^ko0000ooooool0003oooooofIVI_n7QhL01?ooool00ol0003ooooooooo
o`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo00?ok^k^o`000?ooool06_ooool00ol0003ooooo
ooooo`0Booooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
07Kooooo001Xooooo`03oeEEEOmgMgOooooo00Gooooo00So0000ooooooooooooooooofIVI_nHV9So
oooooc8b<P;o^[Zj00?o0000ooooooooool00_ooool01?l0003oooooooooooooool2o`0000;ooooo
0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?oMgMgoeEEEOooool00_ooool4o`0001;ooooo00?o410@o`000?l00000
0ol0000Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`1hooooo`00
J?ooool00ooMgMgo410@onk^kP05ooooo`03o`000?oooooooooo00Cooooo00?oIVIVohN7Qoooool0
1Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`03onk^k_l@413ogMgM00Cooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0Booooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`1hooooo`00JOooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?oZJVYodA4A?ooool01Oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0000Oooooo
00?o0000ooooooooool00_ooool00omVIVKoMgMgooooo`05ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0001gooooo`00
/_ooool00ol0003oooooooooo`2cooooo`00[oooool01?l0003oooooooooool0002eooooo`00/?oo
ool2o`000;Kooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.8522, -0.080387, \
0.130126, 0.00668404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
176.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03053 0 L
.03163 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03638 0 L
.03746 0 L
.03873 0 L
.03944 0 L
.04011 0 L
.04141 0 L
.04262 0 L
.04386 0 L
.04452 0 L
.04521 0 L
.04637 0 L
.04765 0 L
.04879 0 L
.05001 0 L
.05116 0 L
.05221 0 L
.05343 0 L
.05473 0 L
.05541 0 L
.05615 0 L
.05747 0 L
.0587 0 L
.0594 0 L
.06003 0 L
.06127 0 L
.06244 0 L
.06373 0 L
.0649 0 L
.06616 0 L
.06687 0 L
.06752 0 L
.06862 0 L
.06982 0 L
.07107 0 L
.07225 0 L
.07291 0 L
.07363 0 L
.07495 0 L
.07623 0 L
Mistroke
.07742 0 L
.07814 0 L
.07883 0 L
.08011 0 L
.08078 0 L
.08148 0 L
.08226 0 L
.08297 0 L
.08366 0 L
.08432 0 L
.08555 0 L
.08687 0 L
.08762 0 L
.0883 0 L
.08945 0 L
.09072 0 L
.09204 0 L
.09328 0 L
.09394 0 L
.09466 0 L
.09542 0 L
.09612 0 L
.09738 0 L
.09808 0 L
.09872 0 L
.09947 0 L
.10017 0 L
.10093 0 L
.10174 0 L
.10244 0 L
.10309 0 L
.1038 0 L
.10458 0 L
.10584 0 L
.10653 0 L
.10717 0 L
.10834 0 L
.10958 0 L
.11023 0 L
.11094 0 L
.11219 0 L
.1129 0 L
.11365 0 L
.11437 0 L
.11501 0 L
.1162 0 L
.11745 0 L
.11811 0 L
.11883 0 L
.1201 0 L
Mistroke
.1213 0 L
.12258 0 L
.1238 0 L
.12491 0 L
.12605 0 L
.12727 0 L
.12832 0 L
.12946 0 L
.13015 0 L
.1308 0 L
.13206 0 L
.13321 0 L
.13442 0 L
.13549 0 L
.1365 0 L
.13767 0 L
.13873 0 L
.1399 0 L
.14117 0 L
.14236 0 L
.14346 0 L
.14464 0 L
.14588 0 L
.14694 0 L
.14809 0 L
.14935 0 L
.15005 0 L
.15068 0 L
.15194 0 L
.15309 0 L
.15418 0 L
.15533 0 L
.15648 0 L
.15774 0 L
.15884 0 L
.16001 0 L
.16112 0 L
.16213 0 L
.16341 0 L
.16412 0 L
.16476 0 L
.16602 0 L
.1672 0 L
.16787 0 L
.16858 0 L
.16985 0 L
.17055 0 L
.17121 0 L
.17194 0 L
.17271 0 L
Mistroke
.174 0 L
.17473 0 L
.17541 0 L
.17665 0 L
.17796 0 L
.17914 0 L
.18024 0 L
.18144 0 L
.18274 0 L
.18343 0 L
.18407 0 L
.18528 0 L
.18657 0 L
.18724 0 L
.18798 0 L
.18921 0 L
.19051 0 L
.19172 0 L
.19284 0 L
.19353 0 L
.19427 0 L
.19493 0 L
.19562 0 L
.19694 0 L
.19816 0 L
.19883 0 L
.19956 0 L
.20087 0 L
.20163 0 L
.20243 0 L
.20312 0 L
.20387 0 L
.20452 0 L
.20522 0 L
.2065 0 L
.20775 0 L
.2089 0 L
.21014 0 L
.21085 0 L
.21151 0 L
.2122 0 L
.21294 0 L
.21362 0 L
.21427 0 L
.21544 0 L
.21667 0 L
.21784 0 L
.2189 0 L
.22015 0 L
.22086 0 L
Mistroke
.22151 0 L
.22268 0 L
.22395 0 L
.22522 0 L
.22642 0 L
.22759 0 L
.22866 0 L
.22983 0 L
.23111 0 L
.23176 0 L
.23245 0 L
.23371 0 L
.23482 0 L
.23602 0 L
.23729 0 L
.23846 0 L
.23956 0 L
.24056 0 L
.24172 0 L
.24281 0 L
.244 0 L
.24532 0 L
.24598 0 L
.24669 0 L
.24797 0 L
.24925 0 L
.25046 0 L
.25155 0 L
.25273 0 L
.2534 0 L
.25413 0 L
.25544 0 L
.25615 0 L
.2568 0 L
.25759 0 L
.25831 0 L
.25951 0 L
.26083 0 L
.26212 0 L
.26277 0 L
.26348 0 L
.26413 0 L
.26483 0 L
.2661 0 L
.26736 0 L
.26852 0 L
.26917 0 L
.26986 0 L
.27061 0 L
.27132 0 L
Mistroke
.27204 0 L
.27272 0 L
.27398 0 L
.27519 0 L
.27646 0 L
.27755 0 L
.27875 0 L
.28004 0 L
.28076 0 L
.28142 0 L
.28269 0 L
.2839 0 L
.28498 0 L
.28598 0 L
.28702 0 L
.28816 0 L
.28931 0 L
.29055 0 L
.29169 0 L
.29274 0 L
.29398 0 L
.29532 0 L
.29776 0 L
.30248 1e-05 L
.30374 1e-05 L
.30492 1e-05 L
.30615 1e-05 L
.30681 1e-05 L
.30751 1e-05 L
.30993 2e-05 L
.31214 3e-05 L
.31466 4e-05 L
.31599 5e-05 L
.3174 6e-05 L
.31876 7e-05 L
.31999 8e-05 L
.32123 9e-05 L
.3224 .00011 L
.32464 .00016 L
.32701 .00022 L
.33125 .00036 L
.33362 .00047 L
.33582 .00061 L
.33823 .00081 L
.34082 .0011 L
.34339 .00148 L
.34612 .00198 L
.35102 .00325 L
.35374 .00423 L
.3563 .00539 L
Mistroke
.35909 .00702 L
.36211 .00928 L
.36749 .01457 L
.37262 .02144 L
.37722 .0302 L
.38224 .04231 L
.39255 .07638 L
.4019 .119 L
.41281 .16492 L
.4176 .19617 L
.41891 .20506 L
.41964 .20924 L
.42032 .21255 L
.42096 .21497 L
.42165 .21686 L
.42286 .21834 L
.42398 .21802 L
.42521 .21666 L
.4265 .21542 L
.42772 .21567 L
.42884 .21796 L
.42988 .22211 L
.43101 .22873 L
.43221 .23726 L
.43339 .24587 L
.43465 .25334 L
.43584 .25692 L
.43693 .25615 L
.4382 .24984 L
.43892 .24394 L
.43958 .23734 L
.44079 .22381 L
.44209 .21005 L
.44339 .20097 L
.44457 .1994 L
.44577 .2053 L
.4469 .21695 L
.44813 .2332 L
.44943 .2494 L
.45019 .25577 L
.45087 .25856 L
.45155 .25788 L
.4522 .25377 L
.45466 .21004 L
.45602 .17595 L
.4573 .147 L
.45803 .13481 L
.45882 .1263 L
.45954 .12332 L
.4602 .1246 L
Mistroke
.46151 .13697 L
.46217 .14683 L
.4629 .15912 L
.46409 .17903 L
.46533 .19532 L
.46598 .20059 L
.4667 .2033 L
.46795 .20032 L
.46913 .18965 L
.4704 .17268 L
.47268 .13807 L
.47402 .12003 L
.47546 .10399 L
.47809 .08253 L
.48043 .06758 L
.483 .0533 L
.48542 .04271 L
.48768 .03559 L
.49262 .02369 L
.49481 .01891 L
.49689 .01526 L
.49929 .01214 L
.50148 .00977 L
.50409 .00718 L
.50536 .0061 L
.50653 .00528 L
.50873 .00418 L
.50989 .00376 L
.51111 .00336 L
.51347 .00261 L
.51599 .00188 L
.51745 .00158 L
.51877 .00139 L
.52009 .00124 L
.52135 .00113 L
.52563 .0007 L
.52798 .0005 L
.53017 .00036 L
.53254 .00024 L
.5338 .00019 L
.53451 .00017 L
.53515 .00015 L
.53628 .00014 L
.53751 .00012 L
.53975 .0001 L
.54231 7e-05 L
.543 6e-05 L
.54374 5e-05 L
.54507 4e-05 L
.5463 4e-05 L
Mistroke
.54745 4e-05 L
.54871 4e-05 L
.54942 3e-05 L
.55007 3e-05 L
.55118 2e-05 L
.55237 2e-05 L
.55367 1e-05 L
.55487 1e-05 L
.55599 1e-05 L
.55704 1e-05 L
.55818 1e-05 L
.55942 1e-05 L
.56074 0 L
.56197 0 L
.56267 0 L
.56331 0 L
.56405 0 L
.56475 0 L
.56543 0 L
.56615 0 L
.56744 0 L
.56811 0 L
.56883 0 L
.56962 0 L
.57036 0 L
.57165 0 L
.57233 0 L
.57305 0 L
.57375 0 L
.57438 0 L
.5756 0 L
.57679 0 L
.57807 0 L
.57928 0 L
.58039 0 L
.58166 0 L
.58286 0 L
.58394 0 L
.58511 0 L
.58638 0 L
.58702 0 L
.58773 0 L
.58898 0 L
.59015 0 L
.59127 0 L
.59244 0 L
.59344 0 L
.59454 0 L
.59572 0 L
.59698 0 L
Mistroke
.59817 0 L
.59925 0 L
.60055 0 L
.6012 0 L
.60191 0 L
.60318 0 L
.60436 0 L
.60508 0 L
.60576 0 L
.60703 0 L
.60774 0 L
.6084 0 L
.60913 0 L
.6099 0 L
.61108 0 L
.61235 0 L
.61356 0 L
.61466 0 L
.61589 0 L
.61659 0 L
.61723 0 L
.6179 0 L
.61863 0 L
.61993 0 L
.62112 0 L
.62223 0 L
.62345 0 L
.62477 0 L
.62542 0 L
.62614 0 L
.62744 0 L
.62873 0 L
.62989 0 L
.63108 0 L
.6322 0 L
.63338 0 L
.63466 0 L
.63578 0 L
.63697 0 L
.63798 0 L
.63909 0 L
.63976 0 L
.64048 0 L
.6418 0 L
.64309 0 L
.64428 0 L
.64556 0 L
.64629 0 L
.64698 0 L
.64765 0 L
Mistroke
.64835 0 L
.64913 0 L
.64984 0 L
.65103 0 L
.65216 0 L
.65346 0 L
.65463 0 L
.65594 0 L
.65667 0 L
.65735 0 L
.65858 0 L
.65987 0 L
.66109 0 L
.66241 0 L
.66357 0 L
.66481 0 L
.66604 0 L
.66715 0 L
.66827 0 L
.66932 0 L
.67056 0 L
.67186 0 L
.67297 0 L
.67419 0 L
.67551 0 L
.67625 0 L
.67692 0 L
.67823 0 L
.67946 0 L
.68051 0 L
.68168 0 L
.68289 0 L
.68403 0 L
.68509 0 L
.68606 0 L
.68711 0 L
.68824 0 L
.68945 0 L
.69058 0 L
.69127 0 L
.69192 0 L
.69313 0 L
.69429 0 L
.69536 0 L
.69654 0 L
.69778 0 L
.69899 0 L
.69968 0 L
.70032 0 L
.70149 0 L
Mistroke
.70273 0 L
.70384 0 L
.70488 0 L
.70602 0 L
.70725 0 L
.70848 0 L
.70918 0 L
.70983 0 L
.71114 0 L
.71188 0 L
.71254 0 L
.71374 0 L
.71504 0 L
.71627 0 L
.7174 0 L
.71846 0 L
.71959 0 L
.72066 0 L
.72164 0 L
.72278 0 L
.72403 0 L
.72521 0 L
.7263 0 L
.72754 0 L
.7287 0 L
.72974 0 L
.73087 0 L
.7321 0 L
.7334 0 L
.73461 0 L
.73573 0 L
.73696 0 L
.7376 0 L
.73828 0 L
.73943 0 L
.7407 0 L
.74183 0 L
.74304 0 L
.74418 0 L
.74523 0 L
.74645 0 L
.7476 0 L
.74885 0 L
.74955 0 L
.75018 0 L
.75147 0 L
.7522 0 L
.75287 0 L
.75409 0 L
.7554 0 L
Mistroke
.75654 0 L
.75759 0 L
.75864 0 L
.75964 0 L
.7608 0 L
.76188 0 L
.76306 0 L
.76431 0 L
.76542 0 L
.76662 0 L
.76775 0 L
.76879 0 L
.76994 0 L
.7712 0 L
.77251 0 L
.77374 0 L
.77501 0 L
.77565 0 L
.77636 0 L
.77762 0 L
.77877 0 L
.77947 0 L
.78013 0 L
.78089 0 L
.78159 0 L
.78286 0 L
.78352 0 L
.78424 0 L
.78552 0 L
.78625 0 L
.78692 0 L
.78814 0 L
.78944 0 L
.7906 0 L
.79169 0 L
.79288 0 L
.79416 0 L
.7954 0 L
.79655 0 L
.79781 0 L
.79845 0 L
.79915 0 L
.80026 0 L
.80142 0 L
.8027 0 L
.80388 0 L
.80493 0 L
.80606 0 L
.80729 0 L
.80845 0 L
Mistroke
.8096 0 L
.81069 0 L
.81167 0 L
.81273 0 L
.81397 0 L
.81509 0 L
.81639 0 L
.81763 0 L
.81876 0 L
.81981 0 L
.82096 0 L
.8222 0 L
.82291 0 L
.82356 0 L
.82485 0 L
.82601 0 L
.82724 0 L
.82788 0 L
.82857 0 L
.82981 0 L
.83056 0 L
.83127 0 L
.83197 0 L
.83261 0 L
.83382 0 L
.83447 0 L
.83516 0 L
.83647 0 L
.83713 0 L
.83786 0 L
.83917 0 L
.84038 0 L
.8415 0 L
.8427 0 L
.84344 0 L
.84412 0 L
.84487 0 L
.84566 0 L
.84634 0 L
.84698 0 L
.84773 0 L
.84844 0 L
.84976 0 L
.85096 0 L
.85226 0 L
.85299 0 L
.85366 0 L
.85481 0 L
.85602 0 L
.85708 0 L
Mistroke
.85824 0 L
.8595 0 L
.8602 0 L
.86086 0 L
.86213 0 L
.8633 0 L
.86454 0 L
.86585 0 L
.86698 0 L
.86821 0 L
.8689 0 L
.86954 0 L
.87027 0 L
.87097 0 L
.8722 0 L
.8729 0 L
.87354 0 L
.8747 0 L
.87595 0 L
.87713 0 L
.87822 0 L
.87928 0 L
.88041 0 L
.88148 0 L
.88246 0 L
.88351 0 L
.88466 0 L
.8859 0 L
.88708 0 L
.88831 0 L
.88961 0 L
.89073 0 L
.89196 0 L
.89318 0 L
.89431 0 L
.895 0 L
.89566 0 L
.89688 0 L
.89808 0 L
.89939 0 L
.90006 0 L
.90078 0 L
.90206 0 L
.90316 0 L
.90434 0 L
.90545 0 L
.90647 0 L
.90766 0 L
.90896 0 L
.91019 0 L
Mistroke
.91132 0 L
.91264 0 L
.91338 0 L
.91406 0 L
.91528 0 L
.91598 0 L
.91663 0 L
.91776 0 L
.91896 0 L
.92025 0 L
.92143 0 L
.9221 0 L
.92281 0 L
.92408 0 L
.92479 0 L
.92545 0 L
.92617 0 L
.92696 0 L
.92762 0 L
.92835 0 L
.92904 0 L
.92969 0 L
.93088 0 L
.93218 0 L
.93347 0 L
.93417 0 L
.93482 0 L
.936 0 L
.93726 0 L
.93796 0 L
.93873 0 L
.93946 0 L
.94013 0 L
.9414 0 L
.94204 0 L
.94275 0 L
.94403 0 L
.94521 0 L
.94651 0 L
.94716 0 L
.94788 0 L
.94908 0 L
.95037 0 L
.95159 0 L
.9527 0 L
.95385 0 L
.95493 0 L
.95605 0 L
.95729 0 L
.95854 0 L
Mistroke
.95924 0 L
.95988 0 L
.9611 0 L
.96227 0 L
.96335 0 L
.96451 0 L
.9656 0 L
.96659 0 L
.96776 0 L
.96902 0 L
.97021 0 L
.9713 0 L
.97251 0 L
.97363 0 L
.97487 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`0Rooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00GoA4A4o`000?l0003o<S8bomgMg@1Gooooo`05odA4A?l0003o0000oc8b<_oMgMd09oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo02Gooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool09?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00omgMgOo<S8booooo`1Iooooo`03ogMgMolb<S;ooooo02Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Uooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool6o`0000Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[
ooooo`03ogMgMolb<S;ooooo05Wooooo00?oMgMgoc8b<_ooool0:?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo02Gooooo000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0Eoooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001Wooooo
00?oEEEEofIVI_l000001Oooool4o`0002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo1?l0001Hooooo`Co0000:?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool00omEEEGoIVIVo`000005ooooo`Co00009oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooC_ooool2o`0000;ooooo0_l0000Eooooo`00oooooom>
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5Oooool00?ooooooCoooool01?oMgMgo0000oa0@
4?o<c<`Fooooo`005?ooooooo`00033o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hFooooo`006ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`Go00001Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Co00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool04?ooool01?lQ8B7oMgMgogMgMolb<S8Fooooo`006oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Xooooo`?o0000;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool03oooool2o`0000;ooooo0_l0000Eooooo`00POooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo0;[ooooo0022ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0^_ooool008?ooooo00?o0000ooooooooool09?ooool2o`000;cooooo0023ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooool00000_?ooool008Cooooo00?o0000ooooooooool08_oo
ool00ol0003oooooo`00002looooo`00QOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
00000;cooooo0026ooooo`03o`000?oooooooooo01oooooo00Co0000oooooooooooo0000_?ooool0
08Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`02o`000;_ooooo0026ooooo`03
o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`00002looooo`00Qoooool00ol0003o
ooooooooo`0Mooooo`05o`000?ooooooooooooooool00000_?ooool008Oooooo00?o0000oooooooo
ool07Oooool01Ol0003ooooooooooooooooo00000;cooooo0027ooooo`03o`000?oooooooooo01go
oooo00Go0000ooooooooooooooooo`00002looooo`00Qoooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0^_ooool008Sooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;[ooooo0028ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2jooooo`00R?ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0^_ooool0
08Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`03ooooo`;o0000^oooool008Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;[o
oooo0029ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2jooooo`00R_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0^_ooool008[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo0;[ooooo002:ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`2jooooo`00R_ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool008_ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;[ooooo002;ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2jooooo`00Roooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo0_l0002kooooo`00Roooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool008co
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;[o
oooo002<ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2jooooo`00S?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0^_ooool008cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0;[ooooo002<ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`2jooooo`00SOooool02?l0003oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0;[ooooo002=
ooooo`08o`000?ooooooooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_l0003oA4A400Kooooo00?o0000ooooooooool0^_ooool008gooooo00Co0000oooooooo
oooo410@0oooool00ol@413oooooooooo`08ooooo`05o`000?ooooooV9RHob4Q8Ol000001oooool0
0ol0003oooooooooo`2jooooo`00SOooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo00Sooooo00Ko0000ooooooooooooV9RHo`000?o^k^h6ooooo`?o0000^_ooool008kooooo00?o
0000ooooool000000oooool00ol0003oooooooooo`08ooooo`06o`000?ooooooooooooooool0003o
IVIV1_ooool00ol0003oooooooooo`2jooooo`00S_ooool00ol0003ooooooa0@4003ooooo`03oa0@
4?oooooooooo00Oooooo0_l00003ooooo`;o00001_ooool00ol0003oooooooooo`2jooooo`00S_oo
ool01ol0003oooooogMgMonHV9SooooooiRHV?mgMgL02Oooool3o`000004okZj^_oooooo0000oa0@
40Kooooo00?o0000ooooooooool0^_ooool008oooooo00Ko0000onk^k_lb<S;o0000oc8b<_o^k^h9
ooooo`;o000000GoV9RHoa0@4?l0003o0000olc<c006ooooo`03o`000?oooooooooo0;[ooooo002?
ooooo`03o`000?oooooooooo00cooooo0_l00003ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0^_ooool008oooooo00?o0000ooooooooool03?ooool00ol0003oooooo`000002oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^_ooool008oooooo00?o0000oooooooo
ool03?ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0^_ooool0093ooooo00?o0000ooooooooool02oooool00ol0003oooooo`000002ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0^_ooool0093ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Gooooo0_l0002kooooo`00T?ooool0
0ol0003oooooooooo`0;ooooo`05o`000?oooooo0000ooooool000002?ooool00ol0003ooooooooo
o`2jooooo`00TOooool00ol0003oooooooooo`0:ooooo`05o`000?oooooo0000ooooool000002?oo
ool00ol0003oooooooooo`2jooooo`00TOooool00ol0003oooooooooo`0:ooooo`05o`000?oooooo
0000ooooool000002?ooool00ol0003oooooooooo`2jooooo`00TOooool00ol0003oooooooooo`0:
ooooo`05o`000?oooooo0000ooooool000002?ooool00ol0003oooooooooo`2jooooo`00TOooool0
0ol0003oooooooooo`0:ooooo`05o`000?oooooo0000ooooool000002?ooool00ol0003ooooooooo
o`2jooooo`00TOooool00ol0003oooooooooo`0:ooooo`05o`000?oooooo0000ooooool000002?oo
ool00ol0003oooooooooo`2jooooo`00TOooool00ol0003oooooooooo`0:ooooo`05o`000?oooooo
0000ooooool000002?ooool00ol0003oooooooooo`2jooooo`00TOooool00ol0003oooooooooo`0:
ooooo`05o`000?oooooo0000ooooool000002?ooool00ol0003oooooooooo`2jooooo`00T_ooool0
0ol0003oooooooooo`09ooooo`05o`000?oooooo0000ooooool000002?ooool2o`000;_ooooo002B
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_l00008ooooo`03o`000?oooooo
oooo0;[ooooo002Booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_l00008oooo
o`03o`000?oooooooooo0;[ooooo002Booooo`03o`000?oooooooooo00Sooooo00Co0000oooooooo
oooooooo0_l00008ooooo`03o`000?oooooooooo0;[ooooo002Booooo`03o`000?oooooooooo00Go
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0;[ooooo002Booooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;[ooooo002Booooo`03o`000?oooooooooo00Go
oooo0_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0^_ooool009?ooooo00?o0000ooooooooool00oooool01Ol0003oooooo`000?oooooo000000go
oooo00?o0000ooooooooool0^_ooool009?ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
o`000?oooooo000000gooooo00?o0000ooooooooool0^_ooool009?ooooo00?o0000ooooool00000
0oooool01Ol0003oooooo`000?oooooo000000gooooo00?o0000ooooooooool0^_ooool009?ooooo
0ol00003ooooo`05o`000?oooooo0000ooooool000003Oooool2o`000;_ooooo002Fooooo`08o`00
0?ooooooooooo`000?oooooo0000ooooool0000=ooooo`03o`000?oooooooooo0;[ooooo002Foooo
o`08o`000?ooooooooooo`000?oooooo0000ooooool0000=ooooo`03o`000?oooooooooo0;[ooooo
002Fooooo`08o`000?ooooooooooo`000?oooooo0000ooooool0000=ooooo`03o`000?oooooooooo
0;[ooooo002Fooooo`08o`000?ooooooooooo`000?oooooo0000ooooool0000=ooooo`03o`000?oo
oooooooo0;[ooooo002Fooooo`08o`000?ooooooooooo`000?oooooo0000ooooool0000=ooooo`03
o`000?oooooooooo0;[ooooo002@ooooo`07onk^k_lb<S;o0000oc8b<_o^k^koooooo`000002oooo
o`05o`000?lQ8B7o0000ooooool000001?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000
ooooooooool0^_ooool0093ooooo00OoMgMgoiRHV?ooooooV9RHogMgMooooooo000000;ooooo00Go
0000ob4Q8Ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
^_ooool0093ooooo00Go410@oooooooooooooooooa0@4002ooooo`03o`000?oooooo000000;ooooo
0_l00002ooooo`Go00001_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol0003ooooooooo
oooooooo000000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00CoA4A4omgMgOoooooo
00001oooool3o`000;[ooooo002@ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000?o
oooo0_l00002ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0^_ooool0093o
oooo00Go410@oooooooooooooooooa0@4002ooooo`;o00000oooool2o`0000?ooooo00?oMgMgolc<
c?l000001oooool00ol0003oooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00Go0000ooooooooooooooooo`000004ooooo`03onk^k_m4A4Co000000Oooooo00?o0000
ooooooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003o
oooo00Kooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0^_oo
ool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000;[ooooo002@ooooo`05o`00
0?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool0^_ooool0093ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000
oa0@4?o<c<`01_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo
410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2jooooo`00T?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`2j
ooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_oo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00T?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2joooo
o`00T?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05o`000?ooooooooooooooool000002oooool0
1Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002jooooo`00T?ooool01Ol0003ooooooooooooo
oooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo0;[ooooo
002@ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Ko
oooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0
002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002Qooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2joooo
o`00Xoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;[ooooo002Sooooo`03o`00
0?oooooooooo00Gooooo0ol0002jooooo`00Xoooool00ol0003oooooooooo`32ooooo`00Xoooool0
0ol0003oooooooooo`32ooooo`00Xoooool00ol0003oooooooooo`32ooooo`00Xoooool00ol0003o
ooooooooo`32ooooo`00XOooool00omEEEGoIVIVo`000034ooooo`00oooooomYooooo`00JOooool0
0omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o^[Zjoc8b<_ooool01oooool2
o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Oooooo00?o0000ooooooooool00_ooool0
0omVIVKoMgMgooooo`0<ooooo`03o`000?nj^[[ooooo0:gooooo001Xooooo`03omgMgOl@413ok^k^
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00oo^
k^ko410@omgMg@0<ooooo`;o<S8b[_ooool006Sooooo00?oEEEEoiRHV?ooool01Oooool01_l0003o
ooooooooooooooooV9RHoa0@40;o000000?oZJVYooooooooool01?ooool01?l0003ooooooooooooo
ool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4
okZj^P04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00on7QhOoIVIV
ooooo`0;ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0@ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c01g
ooooo`00J?ooool00ol0003oooooooooo`05ooooo`0:o`000?ooooooooooooooool0003oZJVYoeEE
EOnHV9SoEEEEokZj^PGooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM
0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?ok^k^o`000?ooool02oooool00oo<c<co
0000oa0@400<ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l00009ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@1gooooo`00J?oo
ool00olb<S;oooooooooo`05ooooo`0:o`000?oooooooooooooooolb<S;ok^k^oiRHV?mEEEGogMgM
oa0@40Gooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool04_ooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go0000ooooooooooooooooo`00001gooooo`00J?ooool00olb<S;oooooooooo`05ooooo`0;o`00
0?oooooooooooooooonj^[[oA4A4olc<c?lQ8B7ooooooa0@4?o<c<`01?ooool00ol0003ooooooooo
o`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`03ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oo
ooooV9RHob4Q8@1gooooo`00J?ooool00ol0003ok^k^ooooo`05ooooo`0;o`000?oooooooooooooo
ooo^k^ko0000ooooool0003oooooofIVI_n7QhL01?ooool00ol0003oooooooooo`02ooooo`04ob4Q
8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?ok^k^o`000?ooool06_ooool00ol0003oooooooooo`0Booooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<07Oooooo001Xoooo
o`03oeEEEOmgMgOooooo00Gooooo00So0000ooooooooooooooooofIVI_nHV9Sooooooc8b<P;o^[Zj
00?o0000ooooooooool00_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`03
oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo00?oMgMgoeEEEOooool00_ooool4o`0001;ooooo00?o410@o`000?l000000ol0000Aooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`1iooooo`00J?ooool00ooMgMgo
410@onk^kP05ooooo`03o`000?oooooooooo00Cooooo00?oIVIVohN7Qoooool01Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`03onk^k_l@413ogMgM00Cooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Booooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV01ioooo
o`00JOooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo00Cooooo00?oZJVYodA4A?oo
ool01Oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0000Oooooo00?o0000oooooooo
ool00_ooool00omVIVKoMgMgooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool04_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@Moooool0
0;;ooooo00?o0000ooooooooool0/oooool00:oooooo00Co0000oooooooooooo0000]Oooool00;3o
oooo0_l0002fooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.8522, -0.080387, \
0.130126, 0.00668404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
176.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02946 0 L
.03053 0 L
.0317 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03638 0 L
.03746 0 L
.03873 0 L
.03944 0 L
.04011 0 L
.04141 0 L
.04262 0 L
.04386 0 L
.04452 0 L
.04521 0 L
.04637 0 L
.04765 0 L
.04888 0 L
.05004 0 L
.05108 0 L
.05221 0 L
.05345 0 L
.05477 0 L
.05544 0 L
.05619 0 L
.05751 0 L
.05873 0 L
.06005 0 L
.06131 0 L
.06244 0 L
.06373 0 L
.06443 0 L
.06509 0 L
.06628 0 L
.06756 0 L
.06823 0 L
.06897 0 L
.06975 0 L
.07047 0 L
.07176 0 L
.07249 0 L
.07315 0 L
.07385 0 L
.07459 0 L
Mistroke
.07529 0 L
.07592 0 L
.07667 0 L
.07747 0 L
.07824 0 L
.07894 0 L
.08021 0 L
.08094 0 L
.08161 0 L
.08231 0 L
.08307 0 L
.08376 0 L
.08443 0 L
.08558 0 L
.08686 0 L
.0875 0 L
.0882 0 L
.08945 0 L
.09063 0 L
.09187 0 L
.09303 0 L
.09409 0 L
.09534 0 L
.09603 0 L
.09669 0 L
.09785 0 L
.0991 0 L
.09976 0 L
.10049 0 L
.10125 0 L
.10195 0 L
.10322 0 L
.10393 0 L
.10458 0 L
.10575 0 L
.10686 0 L
.10807 0 L
.10938 0 L
.11067 0 L
.11132 0 L
.11204 0 L
.1133 0 L
.11448 0 L
.11567 0 L
.1168 0 L
.11781 0 L
.11891 0 L
.1201 0 L
.12137 0 L
.12245 0 L
Mistroke
.12364 0 L
.1243 0 L
.12502 0 L
.12634 0 L
.12762 0 L
.12881 0 L
.12953 0 L
.13022 0 L
.13149 0 L
.13216 0 L
.13287 0 L
.13365 0 L
.13436 0 L
.13555 0 L
.13683 0 L
.13804 0 L
.13914 0 L
.14044 0 L
.14116 0 L
.14184 0 L
.14308 0 L
.14439 0 L
.14553 0 L
.14678 0 L
.14799 0 L
.14929 0 L
.15051 0 L
.15161 0 L
.15272 0 L
.15377 0 L
.15509 0 L
.15633 0 L
.15762 0 L
.1583 0 L
.15903 0 L
.16033 0 L
.16157 0 L
.16267 0 L
.16388 0 L
.16504 0 L
.16609 0 L
.16721 0 L
.16843 0 L
.16957 0 L
.17061 0 L
.1716 0 L
.17265 0 L
.1738 0 L
.17486 0 L
.17613 0 L
Mistroke
.17728 0 L
.17849 0 L
.17979 0 L
.18102 0 L
.18216 0 L
.18341 0 L
.18459 0 L
.18566 0 L
.18682 0 L
.18807 0 L
.18878 0 L
.18941 0 L
.19066 0 L
.19183 0 L
.19293 0 L
.19409 0 L
.1951 0 L
.19617 0 L
.19733 0 L
.19842 0 L
.19971 0 L
.20088 0 L
.20216 0 L
.20286 0 L
.20351 0 L
.20467 0 L
.20595 0 L
.20663 0 L
.20734 0 L
.20861 0 L
.20931 0 L
.20997 0 L
.21069 0 L
.21147 0 L
.21278 0 L
.21401 0 L
.21521 0 L
.21632 0 L
.21752 0 L
.21884 0 L
.2195 0 L
.22021 0 L
.2215 0 L
.22281 0 L
.22405 0 L
.22473 0 L
.22547 0 L
.22675 0 L
.22799 0 L
.22929 0 L
Mistroke
.23051 0 L
.23163 0 L
.23294 0 L
.23367 0 L
.23435 0 L
.23557 0 L
.23626 0 L
.23689 0 L
.23759 0 L
.23834 0 L
.23905 0 L
.23969 0 L
.24038 0 L
.24111 0 L
.24191 0 L
.24267 0 L
.24393 0 L
.24507 0 L
.24572 0 L
.24641 0 L
.24764 0 L
.2487 0 L
.24987 0 L
.25111 0 L
.25227 0 L
.25292 0 L
.25363 0 L
.25492 0 L
.25617 0 L
.25733 0 L
.25858 0 L
.2593 0 L
.25997 0 L
.26067 0 L
.26131 0 L
.26201 0 L
.26277 0 L
.26404 0 L
.26524 0 L
.26631 0 L
.26749 0 L
.26877 0 L
.26947 0 L
.27012 0 L
.27129 0 L
.27255 0 L
.27371 0 L
.27499 0 L
.27619 0 L
.27731 0 L
Mistroke
.27841 0 L
.27941 0 L
.28057 0 L
.28166 0 L
.28286 0 L
.28418 0 L
.28484 0 L
.28555 0 L
.28683 0 L
.28811 0 L
.28933 0 L
.29041 0 L
.2916 0 L
.29288 0 L
.29362 0 L
.2943 0 L
.29503 0 L
.29569 0 L
.29642 0 L
.29718 0 L
.29846 0 L
.29965 1e-05 L
.30096 1e-05 L
.30168 1e-05 L
.30235 1e-05 L
.3036 2e-05 L
.30426 2e-05 L
.30497 2e-05 L
.30624 2e-05 L
.3074 1e-05 L
.30809 1e-05 L
.30874 2e-05 L
.30945 2e-05 L
.31021 2e-05 L
.31093 2e-05 L
.31161 2e-05 L
.31287 3e-05 L
.31408 4e-05 L
.31536 5e-05 L
.31765 7e-05 L
.31884 8e-05 L
.32011 9e-05 L
.32151 .0001 L
.32281 .00011 L
.32405 .00012 L
.32521 .00013 L
.32647 .00015 L
.32711 .00016 L
.32781 .00018 L
.33025 .00026 L
Mistroke
.33254 .00035 L
.33713 .00054 L
.33937 .00065 L
.3414 .00079 L
.34263 .0009 L
.3438 .00102 L
.34635 .00136 L
.34917 .00179 L
.35177 .00221 L
.35402 .00264 L
.3565 .00328 L
.35899 .00417 L
.36163 .00532 L
.36625 .00741 L
.36879 .00869 L
.3712 .01037 L
.37344 .01256 L
.37588 .01551 L
.38015 .02079 L
.38466 .02547 L
.3859 .02701 L
.3872 .02904 L
.38953 .03402 L
.39209 .04143 L
.39488 .05041 L
.39614 .05408 L
.39748 .05737 L
.39875 .05976 L
.3999 .06134 L
.40242 .06377 L
.40369 .06539 L
.40441 .06675 L
.40508 .06845 L
.40582 .07084 L
.40649 .07359 L
.408 .08183 L
.4107 .10179 L
.41191 .11106 L
.4132 .11944 L
.41395 .12309 L
.41462 .12546 L
.41593 .12729 L
.41716 .12577 L
.41786 .12383 L
.41849 .1216 L
.41965 .11725 L
.4209 .11368 L
.42217 .11333 L
.42337 .11753 L
.42453 .12653 L
Mistroke
.42561 .13897 L
.42801 .17527 L
.42928 .19419 L
.42995 .20251 L
.43065 .20944 L
.43184 .21586 L
.43293 .21517 L
.43395 .20886 L
.43506 .19668 L
.43622 .1803 L
.43747 .16172 L
.43866 .14715 L
.43975 .13937 L
.44107 .1403 L
.44173 .1457 L
.44246 .15553 L
.44374 .18143 L
.44493 .21295 L
.4463 .25169 L
.4476 .28324 L
.44831 .29561 L
.44909 .3034 L
.4498 .30451 L
.45046 .30012 L
.45177 .27633 L
.45299 .23913 L
.45528 .15751 L
.45657 .12341 L
.45775 .10953 L
.45905 .11741 L
.4597 .13025 L
.46042 .15009 L
.46294 .24545 L
.46427 .29234 L
.46495 .31078 L
.46568 .32579 L
.46633 .33397 L
.46702 .33764 L
.46827 .33188 L
.46952 .31366 L
.47066 .29031 L
.473 .23819 L
.47429 .21317 L
.4755 .1936 L
.47785 .16536 L
.47999 .14622 L
.48512 .10645 L
.48781 .09041 L
.49072 .0772 L
.496 .05447 L
Mistroke
.49857 .04478 L
.50092 .03792 L
.50551 .02771 L
.51043 .01978 L
.51299 .01643 L
.51578 .01286 L
.51706 .01147 L
.51842 .01031 L
.51958 .00961 L
.52086 .00905 L
.52621 .00611 L
.52762 .00493 L
.52913 .00379 L
.52986 .00335 L
.53055 .003 L
.53185 .00255 L
.53305 .0023 L
.53415 .00214 L
.53666 .00179 L
.53797 .00159 L
.53869 .00148 L
.53938 .0014 L
.54001 .00133 L
.54071 .00127 L
.54192 .0012 L
.54639 .00091 L
.55132 .00064 L
.5526 .00061 L
.55382 .00056 L
.55521 .00049 L
.55648 .00042 L
.55768 .00037 L
.55878 .00034 L
.55999 .00033 L
.56126 .00031 L
.56374 .00025 L
.56505 .0002 L
.56577 .00019 L
.56644 .00017 L
.56765 .00016 L
.56829 .00015 L
.56898 .00015 L
.57021 .00014 L
.57134 .00013 L
.57276 .0001 L
.57409 8e-05 L
.57476 7e-05 L
.57547 7e-05 L
.57626 6e-05 L
.57698 6e-05 L
Mistroke
.57825 6e-05 L
.57897 6e-05 L
.57962 5e-05 L
.58084 5e-05 L
.58212 3e-05 L
.58334 3e-05 L
.58446 2e-05 L
.58574 2e-05 L
.58697 2e-05 L
.58809 2e-05 L
.58913 2e-05 L
.59027 1e-05 L
.59149 1e-05 L
.59272 1e-05 L
.59387 1e-05 L
.59453 1e-05 L
.59523 1e-05 L
.59649 1e-05 L
.5978 0 L
.59902 0 L
.59972 0 L
.60036 0 L
.6011 0 L
.60179 0 L
.60294 0 L
.60401 0 L
.60514 0 L
.60637 0 L
.60743 0 L
.6084 0 L
.60953 0 L
.61059 0 L
.61174 0 L
.61296 0 L
.61411 0 L
.61516 0 L
.61639 0 L
.61708 0 L
.61772 0 L
.6189 0 L
.62014 0 L
.62136 0 L
.62205 0 L
.62269 0 L
.62386 0 L
.6251 0 L
.62621 0 L
.62725 0 L
.62839 0 L
.62962 0 L
Mistroke
.63086 0 L
.63156 0 L
.63221 0 L
.63352 0 L
.63426 0 L
.63493 0 L
.63613 0 L
.63743 0 L
.63866 0 L
.63979 0 L
.64085 0 L
.64198 0 L
.64305 0 L
.64403 0 L
.64518 0 L
.64643 0 L
.6476 0 L
.6487 0 L
.64993 0 L
.65109 0 L
.65214 0 L
.65326 0 L
.6545 0 L
.6558 0 L
.65691 0 L
.65813 0 L
.65944 0 L
.66065 0 L
.66128 0 L
.66198 0 L
.66271 0 L
.66339 0 L
.66464 0 L
.66579 0 L
.66711 0 L
.66836 0 L
.66948 0 L
.67067 0 L
.67171 0 L
.67282 0 L
.67413 0 L
.67537 0 L
.67658 0 L
.67769 0 L
.6789 0 L
.68019 0 L
.68142 0 L
.68254 0 L
.68384 0 L
.68458 0 L
Mistroke
.68527 0 L
.68653 0 L
.68722 0 L
.68786 0 L
.68913 0 L
.6898 0 L
.6905 0 L
.69168 0 L
.69297 0 L
.69371 0 L
.69439 0 L
.69511 0 L
.6959 0 L
.69662 0 L
.6973 0 L
.69862 0 L
.69987 0 L
.70106 0 L
.70212 0 L
.70329 0 L
.70455 0 L
.70525 0 L
.70589 0 L
.70713 0 L
.7083 0 L
.70941 0 L
.71057 0 L
.71157 0 L
.71266 0 L
.71384 0 L
.7151 0 L
.71629 0 L
.71737 0 L
.71865 0 L
.7193 0 L
.72001 0 L
.72127 0 L
.72245 0 L
.72312 0 L
.72384 0 L
.72511 0 L
.72582 0 L
.72649 0 L
.72727 0 L
.72797 0 L
.72916 0 L
.73045 0 L
.73166 0 L
.73276 0 L
.73398 0 L
Mistroke
.73467 0 L
.73531 0 L
.73661 0 L
.73734 0 L
.738 0 L
.73918 0 L
.74028 0 L
.74149 0 L
.7428 0 L
.74409 0 L
.74474 0 L
.74545 0 L
.74672 0 L
.74789 0 L
.74908 0 L
.75021 0 L
.75122 0 L
.75232 0 L
.75351 0 L
.75478 0 L
.75586 0 L
.75705 0 L
.75771 0 L
.75843 0 L
.75975 0 L
.76103 0 L
.76221 0 L
.76294 0 L
.76362 0 L
.7649 0 L
.76557 0 L
.76628 0 L
.76705 0 L
.76776 0 L
.76895 0 L
.77007 0 L
.77137 0 L
.77255 0 L
.77385 0 L
.77458 0 L
.77526 0 L
.77649 0 L
.7778 0 L
.77894 0 L
.78018 0 L
.78139 0 L
.78269 0 L
.78391 0 L
.78501 0 L
.78612 0 L
Mistroke
.78717 0 L
.7884 0 L
.78969 0 L
.7908 0 L
.79202 0 L
.79333 0 L
.79406 0 L
.79473 0 L
.79604 0 L
.79727 0 L
.79843 0 L
.79947 0 L
.80068 0 L
.80181 0 L
.80287 0 L
.80383 0 L
.80489 0 L
.80602 0 L
.80716 0 L
.80823 0 L
.8095 0 L
.81066 0 L
.81186 0 L
.81317 0 L
.81441 0 L
.81555 0 L
.81674 0 L
.81798 0 L
.81904 0 L
.8202 0 L
.82146 0 L
.82216 0 L
.8228 0 L
.82404 0 L
.82521 0 L
.82631 0 L
.82747 0 L
.82847 0 L
.82955 0 L
.83071 0 L
.83179 0 L
.83308 0 L
.83426 0 L
.83553 0 L
.83623 0 L
.83689 0 L
.83805 0 L
.83932 0 L
.84062 0 L
.84127 0 L
Mistroke
.84198 0 L
.84275 0 L
.84347 0 L
.84413 0 L
.84484 0 L
.84615 0 L
.84738 0 L
.84848 0 L
.84969 0 L
.851 0 L
.85172 0 L
.85239 0 L
.85359 0 L
.85487 0 L
.85618 0 L
.85741 0 L
.8581 0 L
.85883 0 L
.86012 0 L
.86136 0 L
.86266 0 L
.86377 0 L
.86499 0 L
.86573 0 L
.86643 0 L
.86775 0 L
.86848 0 L
.86916 0 L
.86991 0 L
.8707 0 L
.87192 0 L
.87323 0 L
.87398 0 L
.87467 0 L
.87538 0 L
.87603 0 L
.8772 0 L
.87845 0 L
.87961 0 L
.8807 0 L
.88198 0 L
.88316 0 L
.88445 0 L
.8851 0 L
.88582 0 L
.88651 0 L
.88716 0 L
.88839 0 L
.88971 0 L
.89045 0 L
Mistroke
.89114 0 L
.89241 0 L
.89355 0 L
.89419 0 L
.89488 0 L
.89612 0 L
.89737 0 L
.89851 0 L
.89973 0 L
.90042 0 L
.90106 0 L
.90221 0 L
.90343 0 L
.90449 0 L
.90566 0 L
.90636 0 L
.90702 0 L
.90826 0 L
.90896 0 L
.9096 0 L
.91031 0 L
.91106 0 L
.91172 0 L
.91242 0 L
.91371 0 L
.91496 0 L
.91612 0 L
.91734 0 L
.91864 0 L
.91988 0 L
.921 0 L
.92232 0 L
.92302 0 L
.92376 0 L
.9244 0 L
.92511 0 L
.92637 0 L
.92705 0 L
.92777 0 L
.92906 0 L
.92977 0 L
.93044 0 L
.93117 0 L
.93195 0 L
.93263 0 L
.93337 0 L
.93406 0 L
.9347 0 L
.93592 0 L
.9372 0 L
Mistroke
.93841 0 L
.93973 0 L
.94097 0 L
.94213 0 L
.94327 0 L
.94431 0 L
.94551 0 L
.94663 0 L
.94787 0 L
.94917 0 L
.95028 0 L
.9515 0 L
.95282 0 L
.95356 0 L
.95423 0 L
.95553 0 L
.95677 0 L
.95791 0 L
.95898 0 L
.9601 0 L
.96133 0 L
.96232 0 L
.96336 0 L
.9645 0 L
.96554 0 L
.96668 0 L
.9679 0 L
.96905 0 L
.9701 0 L
.97133 0 L
.97202 0 L
.97266 0 L
.97381 0 L
.97508 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`0Rooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00GoA4A4o`000?l0003o<S8bomgMg@1Gooooo`05odA4A?l0003o0000oc8b<_oMgMd09oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo02Gooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool09?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00omgMgOo<S8booooo`1Iooooo`03ogMgMolb<S;ooooo02Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Uooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool6o`0000Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[
ooooo`03ogMgMolb<S;ooooo05Wooooo00?oMgMgoc8b<_ooool0:?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo02Gooooo000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0Eoooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001Wooooo
00?oEEEEofIVI_l000001Oooool4o`0002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo1?l0001Hooooo`Co0000:?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool00omEEEGoIVIVo`000005ooooo`Co00009oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooC_ooool2o`0000;ooooo0_l0000Eooooo`00oooooom>
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5Oooool00?ooooooCoooool01?oMgMgo0000oa0@
4?o<c<`Fooooo`005?ooooooo`00033o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hFooooo`006ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`Ko00001?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo1Ol00005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?oo
ool01?lQ8B7oMgMgogMgMolb<S8Fooooo`006oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool00oooool3o`0002Oooooo00?o0000ooooooooool01?oo
ool2o`0002Oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo00oooooo0_l00002ooooo`;o00005Oooool008?ooooo0_l0000Vooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0]?ooool008Gooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0;Gooooo0025ooooo`;o00009?ooool01Ol0003o
oooooooooooooooo00000;Sooooo0027ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooo
oooo0000^Oooool008Oooooo00?o0000ooooooooool08Oooool01?l0003oooooooooool0002ioooo
o`00R?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo00000;[ooooo0029ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooool00000^_ooool008[ooooo00?o0000ooooooooool07_oo
ool3o`000;[ooooo002:ooooo`03o`000?oooooooooo01kooooo0_l0002kooooo`00R_ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo0;[ooooo002:ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0^_ooool008[ooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`2jooooo`00Roooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0;[ooooo002;
ooooo`03o`000?oooooooooo01cooooo0_l0002looooo`00S?ooool00ol0003oooooooooo`0Koooo
o`;o0000_?ooool008cooooo00?o0000ooooooooool06oooool2o`000;cooooo002=ooooo`03o`00
0?oooooooooo01[ooooo0ol0002kooooo`00S_ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooo00000;cooooo002>ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooool00000_?ooool0
08kooooo0_l0000Iooooo`03o`000?oooooo00000;cooooo002?ooooo`03o`000?oooooooooo01Ko
oooo00Co0000oooooooooooo0000_?ooool008oooooo00?o0000ooooooooool05_ooool01?l0003o
ooooooooool0002looooo`00Soooool00ol0003oooooooooo`0Fooooo`04o`000?ooooooooooo`00
0;cooooo002?ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo0000_?ooool008oo
oooo00?o0000ooooooooool05Oooool01Ol0003ooooooooooooooooo00000;cooooo002?ooooo`03
o`000?oooooooooo01Gooooo00Co0000oooooooooooooooo0_l0002kooooo`00T?ooool00ol0003o
ooooooooo`0Dooooo`05o`000?ooooooooooooooool00000_?ooool0093ooooo00?o0000oooooooo
ool05?ooool01Ol0003ooooooooooooooooo00000;cooooo002@ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2jooooo`00T?ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0^_ooool0093ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0^_ooool0093ooooo00Co0000oooooooooooo00002_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0^_ooool0093ooooo00Go0000
oc8b<_l0003o0000onk^kP05ooooo`;o8B4Q0_ooool7o`000003ooooool0003ooooo00?ooooo00?o
0000ooooooooool0^_ooool0093ooooo00?oMgMgo`000?ooool00_l00005ooooo`;o8B4Q0_ooool2
o`000007oiRHV?lQ8B7ok^k^oooooom4A4Coooooo`000004ooooo`03o`000?oooooooooo0;[ooooo
002@ooooo`05oa0@4?l0003o0000ooooool000002Oooool2o`000004oooooonHV9So8B4Qonk^kP;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2jooooo`00T?ooool3o`000003oooo
ool0003ooooo00Sooooo0_l00002ooooo`05oiRHV?lQ8B7ok^k^ooooool000001?ooool3o`000;[o
oooo002@ooooo`05o`000?oooooo0000ooooool000002Oooool2o`0000?ooooo00?oMgMgofIVI_l0
00001Oooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo000000Wo
oooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`2jooooo`00T?ooool01OmgMgOoV9RH
oooooonHV9So000000Wooooo0ol000001Onj^[[ooooooiRHV?l@413o000000Gooooo00?o0000oooo
ooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0003o<S8bo`000004ooooo`03o`000?oooooooooo
00;ooooo0_l000001_nHV9So410@o`000?lQ8B7oc<c<o`0000Gooooo00?o0000ooooooooool0^_oo
ool009Cooooo00?o0000ooooooooool00_ooool01ol0003ooooooooooooooooo0000ooooool00000
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;[ooooo002Dooooo`04o`000?oo
ooooooooooooo`;o00000oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0^_ooool009Cooooo00Co0000oooooooooooooooo0_l00003ooooo`03o`00
0?oooooo000000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2jooooo`00U?oo
ool01ol0003ooooooooooooooooo0000ooooool000000_ooool00ol0003oooooo`000005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0^_ooool009Cooooo00Oo0000oooooooooooo
ooooo`000?oooooo000000;ooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`03oooo
o`;o0000^oooool009Gooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03o`000?oooooo
000000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2jooooo`00UOooool01_l0
003oooooooooool0003oooooo`0000;ooooo00?o0000ooooool000001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0;[ooooo002Eooooo`06o`000?ooooooooooo`000?oooooo0000
0_ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
^_ooool009Gooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03o`000?oooooo000000Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2jooooo`00UOooool01_l0003ooooo
ooooool0003oooooo`0000;ooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0;[ooooo002Eooooo`06o`000?ooooooooooo`000?oooooo00000_ooool0
0ol0003oooooo`000004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool0
09Gooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03o`000?oooooo000000Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`2jooooo`00UOooool01_l0003oooooooooool0
003oooooo`0000;ooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0;[ooooo002Eooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003o
ooooo`000004ooooo`03o`000?oooooooooo00Cooooo0_l0002kooooo`00U_ooool01Ol0003ooooo
o`000?oooooo000000;ooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0;[ooooo002Fooooo`;o00000_ooool01_l0003oooooooooool0003oooooo`00
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2jooooo`00U_ooool2o`0000;o
oooo00Ko0000oooooooooooo0000ooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0^_ooool009Kooooo0_l00002ooooo`06o`000?ooooooooooo`000?oooooo00001?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;[ooooo002Fooooo`;o00000_ooool0
1?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`2jooooo`00U_ooool2o`0000;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool0^_ooool009Kooooo0_l00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`2joooo
o`00U_ooool2o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007
ooooo`03o`000?oooooooooo0;[ooooo002Fooooo`;o00000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0^_ooool009[ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00007ooooo`;o0000^oooool009[ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo0;[o
oooo002Jooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0
003oooooooooo`2jooooo`00V_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Oooooo00?o0000ooooooooool0^_ooool009[ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooooooo0;[ooooo002Kooooo`03o`000?oooooo
000000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`2jooooo`00T?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00Co8B4Qo`000?oooooo00000_ooool01Ol0003ooooo
o`000?l0003o410@00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`04ob4Q8Ol0003oooooo`0000;ooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000
ooooool000000_ooool5o`0000Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooo000000;ooooo00Co0000omgMgOoooooo00001ooo
ool3o`000;[ooooo002@ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00
0002ooooo`04o`000?mEEEGoooooo`0000Oooooo00?o0000ooooooooool0^_ooool0093ooooo00Go
410@oooooooooooooooooa0@4006ooooo`03o`000?oooooo000000;ooooo00Co0000ogMgMoo<c<co
00001oooool00ol0003oooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo00?o0000ooooool000000_ooool01?l0003ok^k^odA4A?l00007ooooo`03o`000?oooooooooo
0;[ooooo002@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool2o`0000?ooooo00Co0000oooo
oomgMgOo00001oooool00ol0003oooooooooo`2jooooo`00Voooool2o`0000?ooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`2jooooo`00Voooool2o`0000?ooooo00?o0000oooo
ool000002?ooool00ol0003oooooooooo`2jooooo`00Voooool2o`0000?ooooo00?o0000ooooool0
00002?ooool00ol0003oooooooooo`2jooooo`00Voooool2o`0000?ooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`2jooooo`00Voooool2o`0000?ooooo00?o0000ooooool000002?oo
ool2o`000;_ooooo002Kooooo`;o00000oooool00ol0003oooooo`000008ooooo`03o`000?oooooo
oooo0;[ooooo002Kooooo`;o00000oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo
0;[ooooo002Kooooo`;o00000oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo0;[o
oooo002Kooooo`;o00000oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo0;[ooooo
002Kooooo`;o00000oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo0;[ooooo002K
ooooo`;o00000oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo0;[ooooo002Koooo
o`;o00000oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo0;[ooooo002Looooo`07
o`000?ooooooooooooooool0003oooooo`000008ooooo`03o`000?oooooooooo0;[ooooo002Poooo
o`03o`000?oooooo000000Sooooo00?o0000ooooooooool0^_ooool00:3ooooo00?o0000ooooool0
00002?ooool2o`000;_ooooo002Pooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0
^_ooool00:3ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`2jooooo`00XOooool2
o`0000Sooooo00?o0000ooooooooool0^_ooool00:7ooooo0_l00008ooooo`03o`000?oooooooooo
0;[ooooo002Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^_ooool00:7ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`2jooooo`00XOooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0;[ooooo002Qooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2jooooo`00T?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`000006ooooo`?o0000^_ooool0093ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2jooooo`00T?oo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03
o`000?oooooooooo0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGo
QhN7ooooo`08ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002k
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oo
oooooooo0;[ooooo002@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0^_ooool0093ooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRH
V?lb<S801_ooool3o`000;[ooooo002@ooooo`05o`000?ooooooooooooooool000002oooool01Oo<
c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zj
o`000006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:7ooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;[ooooo002Sooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0^_ooool00:?ooooo00?o0000ooooooooool01Oooool3
o`000;[ooooo002Sooooo`03o`000?oooooooooo0<;ooooo002Sooooo`03o`000?oooooooooo0<;o
oooo002Sooooo`03o`000?oooooooooo0<;ooooo002Sooooo`03o`000?oooooooooo0<;ooooo002Q
ooooo`03oeEEEOmVIVKo00000<Cooooo003oooooofWooooo001Yooooo`03ogMgMomVIVKooooo00Co
oooo00?o0000ooooooooool00_ooool00onj^[[o<S8booooo`07ooooo`;o00002oooool00ol0003o
^[Zjooooo`0<ooooo`;o00001oooool00ol0003oooooooooo`02ooooo`03ofIVI_mgMgOooooo00co
oooo00?o0000okZj^_ooool0[Oooool006Sooooo00?ogMgMoa0@4?o^k^h01Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03onk^k_l@413ogMgM00cooooo
0_lb<S:^ooooo`00J?ooool00omEEEGoV9RHooooo`05ooooo`06o`000?oooooooooooooooonHV9So
410@0_l000000onYZJWoooooooooo`04ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`00
00?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03ohN7QomVIVKooooo00_ooooo00?oQhN7
o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj013ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`1gooooo`00J?ooool00ol0003ooooooooo
o`05ooooo`0:o`000?ooooooooooooooool0003oZJVYoeEEEOnHV9SoEEEEokZj^PGooooo00[o0000
ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00?ok^k^o`000?ooool02oooool00oo<c<co0000oa0@400<ooooo`06oa0@4?nj^[[o
k^k^ogMgMol@413ooooo1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Ko
oooo00?oEEEEojVYZOooool0Moooool006Sooooo00?o<S8booooooooool01Oooool02_l0003ooooo
oooooooooooo<S8bonk^k_nHV9SoEEEEomgMgOl@4105ooooo`03o`000?oooooooooo00;ooooo00Co
gMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01;ooooo
00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo07Oooooo001Xooooo`03oc8b
<_oooooooooo00Gooooo00_o0000oooooooooooooooookZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<
c004ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00?ooooo1_l00009ooooo`05o`000?ooooooooooooooool0
00003_ooool00olQ8B7oooooooooo`1fooooo`00J?ooool00ol0003ok^k^ooooo`05ooooo`0;o`00
0?ooooooooooooooooo^k^ko0000ooooool0003oooooofIVI_n7QhL01?ooool00ol0003ooooooooo
o`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo00?ok^k^o`000?ooool06_ooool00ol0003ooooo
ooooo`0Booooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`1fooooo`00
J?ooool00omEEEGoMgMgooooo`05ooooo`08o`000?oooooooooooooooomVIVKoV9RHoooooolb<S82
okZj^P03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?oo
ool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03ogMgMomEEEGooooo00;ooooo1?l0000Booooo`03oa0@4?l0003o000000?o00004Ooo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool0M_ooool006Sooooo00?o
gMgMoa0@4?o^k^h01Oooool00ol0003oooooooooo`04ooooo`03ofIVI_n7QhOooooo00Gooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00oo^k^ko410@omgMg@04ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool04_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooo
oooooc8b<P1gooooo`00JOooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?oZJVYodA4A?ooool01Oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0000Oooooo
00?o0000ooooooooool00_ooool00omVIVKoMgMgooooo`05ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol0001gooooo`00
/_ooool00ol0003oooooooooo`2cooooo`00[oooool01?l0003oooooooooool0002eooooo`00/?oo
ool2o`000;Kooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.8522, -0.080387, \
0.130126, 0.00668404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
176.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03053 0 L
.03163 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03638 0 L
.03746 0 L
.03873 0 L
.03944 0 L
.04011 0 L
.04132 0 L
.04262 0 L
.04327 0 L
.04396 0 L
.04519 0 L
.04583 0 L
.04652 0 L
.04727 0 L
.04797 0 L
.04921 0 L
.04987 0 L
.05056 0 L
.05184 0 L
.05302 0 L
.05414 0 L
.05536 0 L
.05606 0 L
.0567 0 L
.05795 0 L
.05899 0 L
.06014 0 L
.06133 0 L
.06244 0 L
.06311 0 L
.06382 0 L
.06508 0 L
.06573 0 L
.06644 0 L
.06721 0 L
.06793 0 L
.0686 0 L
.06932 0 L
.07064 0 L
.07193 0 L
Mistroke
.07312 0 L
.07439 0 L
.07558 0 L
.07666 0 L
.07782 0 L
.07908 0 L
.07972 0 L
.08042 0 L
.08157 0 L
.08282 0 L
.08358 0 L
.08428 0 L
.08494 0 L
.08566 0 L
.08692 0 L
.08761 0 L
.08826 0 L
.08897 0 L
.08972 0 L
.09036 0 L
.09106 0 L
.09182 0 L
.09262 0 L
.09338 0 L
.09408 0 L
.09474 0 L
.09544 0 L
.09614 0 L
.09691 0 L
.09758 0 L
.09829 0 L
.09958 0 L
.10023 0 L
.10093 0 L
.1022 0 L
.10343 0 L
.10458 0 L
.10575 0 L
.10699 0 L
.10805 0 L
.1092 0 L
.11045 0 L
.11115 0 L
.11179 0 L
.11304 0 L
.11419 0 L
.11527 0 L
.11642 0 L
.11757 0 L
.11883 0 L
Mistroke
.11993 0 L
.1211 0 L
.12221 0 L
.12322 0 L
.12449 0 L
.1252 0 L
.12584 0 L
.12709 0 L
.12827 0 L
.12894 0 L
.12965 0 L
.13092 0 L
.13162 0 L
.13228 0 L
.13301 0 L
.13378 0 L
.13507 0 L
.1358 0 L
.13648 0 L
.13772 0 L
.13903 0 L
.1402 0 L
.1413 0 L
.14251 0 L
.14381 0 L
.14507 0 L
.14621 0 L
.14753 0 L
.14878 0 L
.14993 0 L
.15099 0 L
.15215 0 L
.15339 0 L
.15465 0 L
.15582 0 L
.15653 0 L
.15721 0 L
.15848 0 L
.15913 0 L
.15982 0 L
.16106 0 L
.16182 0 L
.16254 0 L
.16318 0 L
.16387 0 L
.16519 0 L
.16642 0 L
.16713 0 L
.16778 0 L
.16852 0 L
Mistroke
.16922 0 L
.16991 0 L
.17063 0 L
.17193 0 L
.17265 0 L
.17333 0 L
.17407 0 L
.17487 0 L
.17616 0 L
.17689 0 L
.17757 0 L
.17882 0 L
.17946 0 L
.18015 0 L
.18145 0 L
.18268 0 L
.18386 0 L
.18497 0 L
.18621 0 L
.18734 0 L
.18856 0 L
.18925 0 L
.18989 0 L
.19094 0 L
.19211 0 L
.19333 0 L
.19447 0 L
.19575 0 L
.19639 0 L
.19709 0 L
.19833 0 L
.19949 0 L
.2002 0 L
.20086 0 L
.20211 0 L
.20275 0 L
.20344 0 L
.2042 0 L
.2049 0 L
.20559 0 L
.20624 0 L
.20746 0 L
.20875 0 L
.20948 0 L
.21016 0 L
.21137 0 L
.21251 0 L
.21382 0 L
.21501 0 L
.21564 0 L
Mistroke
.21634 0 L
.21707 0 L
.21775 0 L
.21905 0 L
.22027 0 L
.22096 0 L
.22171 0 L
.22302 0 L
.22376 0 L
.22455 0 L
.22522 0 L
.22596 0 L
.2271 0 L
.22832 0 L
.22902 0 L
.22965 0 L
.23089 0 L
.23217 0 L
.2329 0 L
.23356 0 L
.23486 0 L
.23608 0 L
.23711 0 L
.23822 0 L
.23945 0 L
.24058 0 L
.24175 0 L
.24302 0 L
.24423 0 L
.24534 0 L
.24653 0 L
.24782 0 L
.24903 0 L
.25014 0 L
.25138 0 L
.25208 0 L
.25273 0 L
.2534 0 L
.25413 0 L
.25482 0 L
.25545 0 L
.25677 0 L
.25744 0 L
.25817 0 L
.25945 0 L
.26065 0 L
.26621 0 L
.26745 0 L
.26861 0 L
.26926 0 L
Mistroke
.26995 0 L
.27117 0 L
.27188 0 L
.27264 0 L
.27328 0 L
.27398 0 L
.27463 0 L
.27533 0 L
.27659 0 L
.27786 0 L
.27853 0 L
.27924 0 L
.28055 0 L
.28175 0 L
.28286 0 L
.28402 0 L
.28529 0 L
.28646 0 L
.28758 0 L
.28863 0 L
.28978 0 L
.291 0 L
.29527 1e-05 L
.29644 1e-05 L
.29771 1e-05 L
.29888 1e-05 L
.29999 1e-05 L
.30123 1e-05 L
.30237 1e-05 L
.30362 1e-05 L
.30433 1e-05 L
.30499 1e-05 L
.30757 3e-05 L
.30899 3e-05 L
.30968 3e-05 L
.31032 4e-05 L
.31156 4e-05 L
.31221 4e-05 L
.3129 4e-05 L
.31412 4e-05 L
.31523 4e-05 L
.31591 4e-05 L
.31656 4e-05 L
.31724 4e-05 L
.31798 5e-05 L
.31862 5e-05 L
.3193 6e-05 L
.32053 7e-05 L
.32196 .0001 L
.32329 .00012 L
Mistroke
.32634 .00019 L
.32758 .00021 L
.32894 .00023 L
.33022 .00024 L
.33141 .00025 L
.33256 .00026 L
.33365 .00027 L
.33491 .00029 L
.33605 .00031 L
.33731 .00035 L
.33795 .00038 L
.33866 .00042 L
.3399 .0005 L
.34106 .0006 L
.34388 .0009 L
.34649 .00118 L
.34892 .00139 L
.35014 .00147 L
.35149 .00154 L
.35277 .00159 L
.35411 .00164 L
.35481 .00168 L
.35558 .00174 L
.35628 .00181 L
.35693 .0019 L
.35822 .00213 L
.3594 .00244 L
.36075 .0029 L
.36203 .00345 L
.36436 .00465 L
.36683 .00599 L
.36789 .00649 L
.36903 .00692 L
.37028 .00722 L
.37145 .00733 L
.3726 .00729 L
.37368 .00717 L
.37466 .00707 L
.37572 .00705 L
.377 .00729 L
.37815 .00789 L
.37879 .00841 L
.37948 .00914 L
.38073 .01092 L
.38315 .0158 L
.38538 .02091 L
.38655 .02327 L
.38781 .02511 L
.38846 .02572 L
.38918 .02608 L
Mistroke
.39045 .0259 L
.39164 .02491 L
.39292 .02329 L
.39403 .02184 L
.39525 .02071 L
.39598 .02047 L
.39665 .02067 L
.39737 .02139 L
.39813 .02281 L
.39885 .02477 L
.39952 .02719 L
.40078 .03313 L
.40323 .04841 L
.40457 .05728 L
.40582 .06461 L
.40691 .06949 L
.40809 .07248 L
.40939 .0726 L
.41058 .06975 L
.41166 .06509 L
.41284 .0586 L
.41394 .05224 L
.41497 .04714 L
.41628 .04353 L
.41747 .04443 L
.41874 .0509 L
.41946 .0572 L
.42012 .0646 L
.42243 .09971 L
.42369 .1216 L
.42489 .14058 L
.42604 .15472 L
.42728 .16325 L
.42842 .16353 L
.42946 .1572 L
.43044 .14604 L
.43153 .12928 L
.43372 .09065 L
.43497 .07294 L
.43612 .06405 L
.43676 .06307 L
.43745 .06561 L
.43871 .08024 L
.43988 .10492 L
.44114 .14062 L
.44339 .21558 L
.44462 .25267 L
.44592 .28107 L
.4466 .28963 L
.44734 .29311 L
Mistroke
.44865 .28304 L
.44989 .25505 L
.45059 .2327 L
.45122 .20921 L
.45246 .15855 L
.45362 .11315 L
.45472 .07832 L
.4559 .05776 L
.45708 .05909 L
.45838 .08775 L
.4595 .13244 L
.46071 .19462 L
.46289 .31354 L
.46415 .36772 L
.46529 .40023 L
.4666 .41545 L
.46785 .40953 L
.469 .39043 L
.47006 .3653 L
.47246 .30049 L
.47488 .24575 L
.47626 .22337 L
.47754 .20756 L
.4789 .19483 L
.48014 .18535 L
.48293 .1664 L
.48811 .13252 L
.49375 .10245 L
.49633 .08915 L
.49775 .08265 L
.49908 .07753 L
.50033 .07375 L
.50168 .07061 L
.50403 .06622 L
.52361 .02612 L
.52897 .01453 L
.52971 .01307 L
.53052 .0117 L
.53123 .01072 L
.53198 .0099 L
.53266 .00937 L
.5334 .00896 L
.53472 .00856 L
.54508 .00574 L
.5549 .00351 L
.56006 .00247 L
.56131 .00225 L
.56265 .00208 L
.56412 .00194 L
.56548 .0018 L
Mistroke
.56817 .00144 L
.5695 .00127 L
.57072 .00115 L
.57182 .00107 L
.573 .00101 L
.57547 .00087 L
.58461 .00044 L
.58583 .00039 L
.58715 .00034 L
.5884 .0003 L
.58956 .00028 L
.59407 .00022 L
.5952 .00019 L
.59639 .00016 L
.5977 .00015 L
.59889 .00014 L
.6002 .00013 L
.60095 .00013 L
.60164 .00013 L
.60289 .00011 L
.60422 9e-05 L
.60537 8e-05 L
.60661 7e-05 L
.60779 7e-05 L
.60887 7e-05 L
.60985 7e-05 L
.61093 6e-05 L
.61205 5e-05 L
.6131 4e-05 L
.61432 4e-05 L
.61548 3e-05 L
.61652 3e-05 L
.61765 3e-05 L
.61888 3e-05 L
.62019 3e-05 L
.62141 2e-05 L
.62255 2e-05 L
.62379 1e-05 L
.62445 1e-05 L
.62515 1e-05 L
.62589 2e-05 L
.6266 2e-05 L
.62791 1e-05 L
.62914 1e-05 L
.6303 1e-05 L
.63151 1e-05 L
.63215 1e-05 L
.63284 1e-05 L
.63354 1e-05 L
.63429 1e-05 L
Mistroke
.63492 1e-05 L
.63561 1e-05 L
.63625 1e-05 L
.63694 0 L
.63817 0 L
.63892 0 L
.63973 0 L
.6405 0 L
.64121 0 L
.6419 0 L
.64255 0 L
.64323 0 L
.64397 0 L
.64513 0 L
.64636 0 L
.64707 0 L
.64771 0 L
.64896 0 L
.65013 0 L
.6514 0 L
.6526 0 L
.6537 0 L
.65497 0 L
.65568 0 L
.65635 0 L
.65706 0 L
.65771 0 L
.65845 0 L
.65916 0 L
.6604 0 L
.66155 0 L
.66281 0 L
.66344 0 L
.66414 0 L
.66534 0 L
.66663 0 L
.66736 0 L
.66803 0 L
.66933 0 L
.67056 0 L
.67188 0 L
.67302 0 L
.67427 0 L
.67548 0 L
.67662 0 L
.67781 0 L
.6791 0 L
.68029 0 L
.68142 0 L
.68244 0 L
Mistroke
.68354 0 L
.68483 0 L
.68604 0 L
.68673 0 L
.68736 0 L
.68811 0 L
.6888 0 L
.69009 0 L
.69078 0 L
.69152 0 L
.69229 0 L
.69302 0 L
.69367 0 L
.69438 0 L
.69559 0 L
.69628 0 L
.69692 0 L
.69758 0 L
.6983 0 L
.6996 0 L
.70078 0 L
.70207 0 L
.70329 0 L
.70441 0 L
.7057 0 L
.70635 0 L
.70707 0 L
.70833 0 L
.7095 0 L
.71022 0 L
.71089 0 L
.71216 0 L
.71286 0 L
.71352 0 L
.71424 0 L
.715 0 L
.71618 0 L
.71745 0 L
.71864 0 L
.71974 0 L
.72096 0 L
.72164 0 L
.72229 0 L
.72357 0 L
.7243 0 L
.72496 0 L
.72614 0 L
.72739 0 L
.72848 0 L
.72968 0 L
Mistroke
.73083 0 L
.73192 0 L
.7329 0 L
.73397 0 L
.73513 0 L
.73636 0 L
.737 0 L
.7377 0 L
.73894 0 L
.74009 0 L
.74133 0 L
.7425 0 L
.74358 0 L
.74485 0 L
.74605 0 L
.74715 0 L
.7483 0 L
.74956 0 L
.75073 0 L
.75198 0 L
.75269 0 L
.75336 0 L
.75453 0 L
.75565 0 L
.75665 0 L
.75775 0 L
.75893 0 L
.76019 0 L
.76139 0 L
.76247 0 L
.76376 0 L
.76442 0 L
.76513 0 L
.76642 0 L
.76758 0 L
.76829 0 L
.76897 0 L
.76968 0 L
.77045 0 L
.77112 0 L
.77184 0 L
.77312 0 L
.7743 0 L
.77558 0 L
.77678 0 L
.77789 0 L
.77911 0 L
.77981 0 L
.78045 0 L
.78176 0 L
Mistroke
.78248 0 L
.78315 0 L
.78439 0 L
.78504 0 L
.78574 0 L
.78648 0 L
.78718 0 L
.78848 0 L
.7897 0 L
.79084 0 L
.79208 0 L
.7934 0 L
.7941 0 L
.79484 0 L
.79565 0 L
.7964 0 L
.79711 0 L
.79786 0 L
.79858 0 L
.79923 0 L
.80052 0 L
.80174 0 L
.80307 0 L
.80381 0 L
.8045 0 L
.80566 0 L
.8069 0 L
.80808 0 L
.80915 0 L
.81035 0 L
.81165 0 L
.81231 0 L
.81302 0 L
.81428 0 L
.81498 0 L
.81563 0 L
.81633 0 L
.81708 0 L
.81834 0 L
.81905 0 L
.81972 0 L
.82096 0 L
.8221 0 L
.82341 0 L
.82465 0 L
.82579 0 L
.82702 0 L
.82817 0 L
.82923 0 L
.83041 0 L
Mistroke
.8317 0 L
.83235 0 L
.83304 0 L
.83429 0 L
.83498 0 L
.83562 0 L
.83632 0 L
.83705 0 L
.8383 0 L
.839 0 L
.83966 0 L
.84087 0 L
.84201 0 L
.84333 0 L
.84454 0 L
.8457 0 L
.84675 0 L
.84797 0 L
.84911 0 L
.85017 0 L
.85115 0 L
.85222 0 L
.85335 0 L
.85449 0 L
.85572 0 L
.85678 0 L
.85793 0 L
.85863 0 L
.85928 0 L
.86056 0 L
.86172 0 L
.86296 0 L
.86409 0 L
.86534 0 L
.86664 0 L
.86785 0 L
.86899 0 L
.87002 0 L
.87121 0 L
.87234 0 L
.87356 0 L
.87486 0 L
.87597 0 L
.87719 0 L
.8785 0 L
.87923 0 L
.8799 0 L
.88121 0 L
.88244 0 L
.8836 0 L
Mistroke
.88482 0 L
.88546 0 L
.88616 0 L
.88739 0 L
.88855 0 L
.8898 0 L
.89097 0 L
.89204 0 L
.89315 0 L
.89418 0 L
.89531 0 L
.89651 0 L
.89754 0 L
.89852 0 L
.89958 0 L
.90073 0 L
.90196 0 L
.90266 0 L
.9033 0 L
.90449 0 L
.90575 0 L
.90699 0 L
.90816 0 L
.90922 0 L
.91035 0 L
.91159 0 L
.91229 0 L
.91294 0 L
.91427 0 L
.91501 0 L
.91568 0 L
.91689 0 L
.9182 0 L
.91944 0 L
.92059 0 L
.92164 0 L
.92278 0 L
.92376 0 L
.92483 0 L
.92602 0 L
.92727 0 L
.92843 0 L
.92951 0 L
.93075 0 L
.93191 0 L
.93312 0 L
.93376 0 L
.93445 0 L
.93567 0 L
.93682 0 L
Mistroke
.93786 0 L
.939 0 L
.9402 0 L
.94149 0 L
.94271 0 L
.9438 0 L
.9451 0 L
.94582 0 L
.94649 0 L
.94772 0 L
.94902 0 L
.95015 0 L
.95135 0 L
.95249 0 L
.95353 0 L
.95475 0 L
.95544 0 L
.95608 0 L
.95724 0 L
.95848 0 L
.95957 0 L
.96057 0 L
.96167 0 L
.96283 0 L
.96384 0 L
.96478 0 L
.96581 0 L
.9669 0 L
.96811 0 L
.96941 0 L
.97064 0 L
.97177 0 L
.9728 0 L
.97392 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`0Rooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00GoA4A4o`000?l0003o<S8bomgMg@1Gooooo`05odA4A?l0003o0000oc8b<_oMgMd09oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo02Gooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool09?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00omgMgOo<S8booooo`1Iooooo`03ogMgMolb<S;ooooo02Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Uooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool6o`0000Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[
ooooo`03ogMgMolb<S;ooooo05Wooooo00?oMgMgoc8b<_ooool0:?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo02Gooooo000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0Eoooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001Wooooo
00?oEEEEofIVI_l000001Oooool4o`0002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo1?l0001Hooooo`Co0000:?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool00omEEEGoIVIVo`000005ooooo`Co00009oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooC_ooool2o`0000;ooooo0_l0000Eooooo`00oooooom>
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5Oooool00?ooooooCoooool01?oMgMgo0000oa0@
4?o<c<`Fooooo`005?ooooooo`00033o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hFooooo`006ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000Co00000oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool6o`0000Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool04?ooool01?lQ8B7oMgMgogMgMolb<S8Fooooo`006oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool01?ooool5o`0002Cooooo00?o
0000ooooooooool02Oooool4o`00023ooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo00oooooo0_l00002ooooo`;o00005Oooool008Kooooo0_l0000S
ooooo`03o`000?oooooooooo00Kooooo0ol0002aooooo`00Qoooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0/Oooool008Sooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;7ooooo0028ooooo`03o`00
0?oooooooooo00;o00007_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;7ooooo
0029ooooo`04o`000?oooooo0000o`0001kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2booooo`00ROooool2o`000003ooooool0003o000001gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`2cooooo`00SOooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0/oooool008gooooo00?o0000ooooooooool06oooool2o`00
00Cooooo00?o0000ooooooooool0]?ooool008gooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0;Cooooo002=ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`2eooooo`00S_ooool01Ol0003ooooooooo
oooooooo000001Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2eooooo`00S_oo
ool00ol0003oooooooooo`02o`0001Sooooo00Go0000ooooooooooooooooo`00002hooooo`00S_oo
ool00ol0003oooooooooo`02o`0001Sooooo00Go0000ooooooooooooooooo`00002hooooo`00S_oo
ool00ol0003oooooooooo`02o`0001Sooooo00Co0000oooooooooooo0000^Oooool008kooooo00Ko
0000oooooooooooo0000ooooool0000Gooooo`04o`000?ooooooooooo`000;Wooooo002>ooooo`06
o`000?ooooooooooo`000?oooooo00002_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
00000;[ooooo002>ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00[ooooo0ol0002jooooo`00S_ooool00ol0003oooooo`000002
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:
ooooo`;o0000^oooool008oooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0:ooooo`;o0000^oooool008oooooo0_l00002ooooo`04
o`000?ooooooooooooooo`;o00001?ooool2o`0000cooooo0_l0002kooooo`00Toooool01?l0003o
ooooooooooooool2o`0000Cooooo0_l0000<ooooo`03o`000?oooooooooo0;[ooooo002Cooooo`04
o`000?ooooooooooooooo`;o00001?ooool2o`0000cooooo00?o0000ooooooooool0^_ooool009?o
oooo00Co0000oooooooooooooooo0_l00004ooooo`;o00002oooool2o`000;cooooo002Dooooo`03
o`000?oooooooooo00;o00001?ooool2o`0000_ooooo0_l0002looooo`00U?ooool00ol0003ooooo
ooooo`02o`0000Cooooo0_l0000;ooooo`;o0000_?ooool009Cooooo00?o0000ooooooooool00_l0
0004ooooo`;o00002oooool3o`000;_ooooo002Dooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool2o`0000_ooooo0_l0002looooo`00U?ooool01_l0003oooooooooool0003oooooo`0000?o
oooo0_l0000:ooooo`03o`000?oooooo00000;cooooo002Dooooo`06o`000?ooooooooooo`000?oo
oooo00000oooool2o`0000[ooooo00?o0000ooooool00000_?ooool009Cooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`;o00002_ooool00ol0003oooooo`00002looooo`00U?ooool01_l0
003oooooooooool0003oooooo`0000?ooooo0_l0000:ooooo`03o`000?oooooo00000;cooooo002D
ooooo`03o`000?oooooo000000;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000Sooooo
00Co0000oooooooooooo0000_?ooool0093ooooo00Ook^k^oc8b<_l0003o<S8bo`000?oooooo0000
00;ooooo00Ko0000ob4Q8OlQ8B7oooooo`000?ooool6o`0000?ooooo00Co0000oooooooooooo0000
_?ooool0093ooooo00OoMgMgoiRHV?ooooooV9RHo`000?oooooo000000;ooooo00co0000ob4Q8OlQ
8B7oooooo`000?oooooo0000oiRHV?lQ8B7ok^k^oooooom4A4@3ooooo`04o`000?ooooooooooo`00
0;cooooo002@ooooo`07oa0@4?ooooooooooooooool0003oooooo`000002ooooo`0;o`000?oooooo
ooooooooool0003oooooo`000?ooooooV9RHob4Q8Oo^k^h01?ooool01?l0003oooooooooool0002l
ooooo`00T?ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool01ol0003ooooooooo
oooooooo0000ooooool000000_ooool00onHV9So8B4Qonk^kP03ooooo`03o`000?oooooooooo00?o
0000^_ooool0093ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Oo0000oooo
ooooooooooooo`000?oooooo000000?ooooo00GoMgMgofIVI_ooooooooooo`000003ooooo`03o`00
0?oooooooooo0;[ooooo002@ooooo`07oa0@4?ooooooooooooooool0003oooooo`000002ooooo`07
o`000?ooooooooooooooool0003oooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool0^_ooool0093ooooo00OoMgMgoiRHV?ooooooV9RHo`000?oooooo000000;ooooo
00Ko0000ooooooooooooooooo`000?ooool2o`000004okZj^_ooooooV9RHoa0@40;ooooo00Go0000
ooooooooooooooooo`00002looooo`00T?ooool01oo^k^ko<S8bo`000?lb<S;o0000ooooool00000
0_ooool03?l0003ooooooooooooooooo0000ooooool0003oV9RHoa0@4?l0003o8B4Qolc<c0;ooooo
00Go0000ooooooooooooooooo`00002looooo`00U?ooool00ol0003oooooo`000002ooooo`07o`00
0?ooooooooooooooool0003oooooo`000007ooooo`05o`000?ooooooooooooooool00000_?ooool0
09Cooooo00?o0000ooooool000000_ooool01ol0003ooooooooooooooooo0000ooooool000001ooo
ool01Ol0003ooooooooooooooooo00000;cooooo002Dooooo`03o`000?oooooo000000;ooooo00Oo
0000ooooooooooooooooo`000?oooooo000000Oooooo00Go0000ooooooooooooooooo`00002loooo
o`00UOooool2o`0000;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`2jooooo`00UOooool2o`0000;ooooo00Oo0000oooo
ooooooooooooo`000?oooooo000000Kooooo00?o0000ooooooooool00_ooool2o`000;_ooooo002E
ooooo`;o00000_ooool01ol0003ooooooooooooooooo0000ooooool000001_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0;[ooooo002Eooooo`;o00000_ooool01ol0003ooooooooo
oooooooo0000ooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;[o
oooo002Eooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000006ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0^_ooool009Wooooo00Oo0000oooooooooooo
ooooo`000?oooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2joooo
o`00VOooool01ol0003ooooooooooooooooo0000ooooool000001_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo0;[ooooo002Iooooo`07o`000?ooooooooooooooool0003oooooo`00
0006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0^_ooool009Wooooo00Oo0000
ooooooooooooooooo`000?oooooo000000Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2jooooo`00V_ooool01_l0003oooooooooool0003oooooo`0000Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`2jooooo`00V_ooool00ol0003oooooo`000002ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool2o`000;_ooooo002Jooooo`03o`000?oo
oooo000000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0;[ooooo002Jooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;[ooooo002Jooooo`03o`000?oooooo0000
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0;[ooooo002Jooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0;[ooooo002Jooooo`03o`000?oooooo000000;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;[ooooo
002Jooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0;[ooooo002Jooooo`03o`000?oooooo000000;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;[ooooo002Joooo
o`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0;[ooooo002Jooooo`03o`000?oooooo000000;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;[ooooo002Jooooo`03o`00
0?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`;o0000
^oooool009[ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0^_ooool009[ooooo00?o0000ooooool000000_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool0
09[ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0^_ooool009[ooooo00?o0000ooooool000000_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool009[ooooo
00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`00
0?lQ8B7o000000;ooooo00?o0000ooooooooool00_l000000ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo0;[ooooo002@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003o8B4Q
o`000002ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`2jooooo`00
T?ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooool000000_ooool6o`0000Ko
oooo00?o0000ooooooooool0^_ooool0093ooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooo000000;ooooo00Go0000odA4A?oMgMgoooooo`000007ooooo`?o0000^_ooool0093o
oooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo000000;ooooo00Go0000omgM
gOmEEEGoooooo`000007ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05oa0@4?oooooooooo
ooooool@41001Oooool00ol0003oooooo`000002ooooo`05o`000?ooooooMgMgolc<c?l000001ooo
ool00ol0003oooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o
0000ooooool000000oooool01?l0003ok^k^odA4A?l00007ooooo`03o`000?oooooooooo0;[ooooo
002@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooo`000003ooooo`04o`00
0?ooooooMgMgo`0000Oooooo00?o0000ooooooooool0^_ooool009[ooooo00?o0000ooooool00000
0oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo0;[ooooo002Jooooo`03o`00
0?oooooo000000?ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`2jooooo`00
Voooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooooooo
ool0^_ooool009_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03
o`000?oooooooooo0;[ooooo002Kooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00001oooool2o`000;_ooooo002Kooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`2jooooo`00Voooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0^_ooool009_ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo0;[ooooo002Kooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`2jooooo`00
Voooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooooooo
ool0^_ooool00:3ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`2jooooo`00
X?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo0;[ooooo002Pooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0^_ooool00:3ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`2jooooo`00X?ooool01?l0003oooooooooool00007ooooo`;o
0000^oooool00:3ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`2jooooo`00
X?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo0;[ooooo002Pooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0^_ooool00:3ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`2jooooo`00X?ooool01?l0003oooooooooool00007ooooo`03
o`000?oooooooooo0;[ooooo002Pooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooooooo
ool0^_ooool00:3ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`2jooooo`00
X?ooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo0;[ooooo002Pooooo`03o`000?oo
oooo000000Sooooo0_l0002kooooo`00X?ooool00ol0003oooooo`000008ooooo`03o`000?oooooo
oooo0;[ooooo002Pooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0^_ooool00:3o
oooo00?o0000ooooool000002?ooool00ol0003oooooooooo`2jooooo`00X?ooool00ol0003ooooo
o`000008ooooo`03o`000?oooooooooo0;[ooooo002Pooooo`03o`000?oooooo000000Sooooo00?o
0000ooooooooool0^_ooool00:3ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`2j
ooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05o`000?lb<S;o
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05o`000?mgMgOo0000oiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooool0003o
ooooo`000006ooooo`?o0000^_ooool0093ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?nHV9So0000oiRHV?lQ8B401_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooo
oooo0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0003oQhN7o`000008
ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
0ol0003o410@o`000008ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01Ol0003oc<c<o`000?l0003o410@00Kooooo00?o0000ooooooooool0^_oo
ool00:3ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`2jooooo`00X?ooool00ol0
003oooooo`000008ooooo`03o`000?oooooooooo0;[ooooo002Pooooo`03o`000?oooooo000000So
oooo00?o0000ooooooooool0^_ooool00:3ooooo00?o0000ooooool000002?ooool00ol0003ooooo
ooooo`2jooooo`00X?ooool2o`0000Wooooo0_l0002kooooo`00X?ooool2o`0000Wooooo00?o0000
ooooooooool0^_ooool00:7ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2joooo
o`00XOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;[ooooo002Qooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000;[ooooo002@
ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo
00?o0000ooooooooool0^_ooool0093ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@
4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`2jooooo`00T?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
0;[ooooo002@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413o
ZJVY00Kooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:7ooooo1?l000000ol@413oooooooooo`03oooo
o`03o`000?oooooooooo0;[ooooo002Sooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0^_ooool00:?ooooo00?o0000ooooooooool01Oooool3o`000;[ooooo002Sooooo`03o`000?oo
oooooooo0<;ooooo002Sooooo`03o`000?oooooooooo0<;ooooo002Sooooo`03o`000?oooooooooo
0<;ooooo002Sooooo`03o`000?oooooooooo0<;ooooo002Qooooo`03oeEEEOmVIVKo00000<Cooooo
003oooooofWooooo001Yooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool00_ooool0
0onj^[[o<S8booooo`07ooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001oooool0
0ol0003oooooooooo`02ooooo`03ofIVI_mgMgOooooo00cooooo00?o0000okZj^_ooool0[Oooool0
06Sooooo00?ogMgMoa0@4?o^k^h01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03onk^k_l@413ogMgM00cooooo0_lb<S:^ooooo`00J?ooool00omEEEGo
V9RHooooo`05ooooo`06o`000?oooooooooooooooonHV9So410@0_l000000onYZJWoooooooooo`04
ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?oo
ool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`03ohN7QomVIVKooooo00_ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000
o`000?m4A4Co^[Zj013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<
c<co8B4Qo`000?lQ8B7oc<c<07Oooooo001Xooooo`03o`000?oooooooooo00Gooooo00[o0000oooo
ooooooooooooo`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj1Oooool02_l0003oooooooooooooooook^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^ko
MgMgoa0@4004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00oo^k^ko
0000ooooo`0;ooooo`03olc<c?l0003o410@00cooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6
o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q07Oooooo001Xooooo`03oc8b<_oooooooooo00Gooooo00[o0000oooooooooooooooo
oc8b<_o^k^koV9RHoeEEEOoMgMgo410@1Oooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o
410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Booooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000007Oooooo001Xooooo`03oc8b
<_oooooooooo00Gooooo00_o0000oooooooooooooooookZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<
c004ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00?ooooo1_l00009ooooo`05o`000?ooooooooooooooool0
00002oooool01Olb<S;oV9RHoooooonHV9So<S8b07Oooooo001Xooooo`03o`000?o^k^kooooo00Go
oooo00_o0000ooooooooooooooooonk^k_l0003oooooo`000?ooooooIVIVohN7Q`04ooooo`03o`00
0?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00oo^k^ko0000ooooo`0Jooooo`03
o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0Moooool006Sooooo00?oEEEEogMgMoooool01Oooool02?l0003ooooooooooooooooo
IVIVoiRHV?oooooo<S8b0_nj^[X00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;o
00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00omgMgOoEEEEooooo`02ooooo`Co00004_ooool00ol@413o
0000o`000003o`00017ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooo
okZj^_l@4100Moooool006Sooooo00?ogMgMoa0@4?o^k^h01Oooool00ol0003oooooooooo`04oooo
o`03ofIVI_n7QhOooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00oo^k^ko410@omgMg@04oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00001gooooo`00JOooool00omgMgOoIVIVooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?oZJVYodA4A?ooool01Oooool2o`0001;ooooo00?o0000
ooooooooool01Oooool2o`0000Oooooo00?o0000ooooooooool00_ooool00omVIVKoMgMgooooo`05
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@1gooooo`00/_ooool00ol0003ooooooooo
o`2cooooo`00[oooool01?l0003oooooooooool0002eooooo`00/?ooool2o`000;Kooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.8522, -0.080387, \
0.130126, 0.00668404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
176.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03053 0 L
.03163 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03638 0 L
.03746 0 L
.03873 0 L
.03944 0 L
.04011 0 L
.04132 0 L
.04262 0 L
.04377 0 L
.04501 0 L
.04618 0 L
.04725 0 L
.04837 0 L
.04958 0 L
.0509 0 L
.05214 0 L
.05278 0 L
.05349 0 L
.05423 0 L
.05493 0 L
.05558 0 L
.05627 0 L
.05751 0 L
.05864 0 L
.05988 0 L
.06053 0 L
.06121 0 L
.06244 0 L
.06392 0 L
.06475 0 L
.06551 0 L
.06618 0 L
.06692 0 L
.0677 0 L
.06841 0 L
.0691 0 L
.06976 0 L
.07045 0 L
.07121 0 L
.07186 0 L
Mistroke
.07256 0 L
.07382 0 L
.07455 0 L
.07522 0 L
.07594 0 L
.07672 0 L
.07741 0 L
.07805 0 L
.07873 0 L
.07945 0 L
.08011 0 L
.08082 0 L
.08212 0 L
.08338 0 L
.08454 0 L
.08569 0 L
.08693 0 L
.088 0 L
.08917 0 L
.09046 0 L
.09117 0 L
.09183 0 L
.09301 0 L
.09427 0 L
.09496 0 L
.0956 0 L
.0963 0 L
.09705 0 L
.0983 0 L
.09901 0 L
.09967 0 L
.10091 0 L
.10204 0 L
.10334 0 L
.10458 0 L
.10572 0 L
.10694 0 L
.1081 0 L
.10916 0 L
.11033 0 L
.11162 0 L
.11227 0 L
.11297 0 L
.11422 0 L
.11486 0 L
.11554 0 L
.11629 0 L
.11698 0 L
.11822 0 L
.11892 0 L
Mistroke
.11958 0 L
.12081 0 L
.12194 0 L
.12323 0 L
.12446 0 L
.12562 0 L
.12668 0 L
.12789 0 L
.12903 0 L
.13009 0 L
.13107 0 L
.13214 0 L
.13327 0 L
.13451 0 L
.13516 0 L
.13585 0 L
.13712 0 L
.1383 0 L
.13934 0 L
.14047 0 L
.14171 0 L
.14288 0 L
.14403 0 L
.14529 0 L
.1466 0 L
.14783 0 L
.14898 0 L
.15002 0 L
.15116 0 L
.15236 0 L
.15367 0 L
.15487 0 L
.15617 0 L
.15691 0 L
.15759 0 L
.15882 0 L
.15997 0 L
.16061 0 L
.16131 0 L
.16253 0 L
.16378 0 L
.16495 0 L
.166 0 L
.16714 0 L
.16839 0 L
.1697 0 L
.17083 0 L
.17205 0 L
.17319 0 L
.17423 0 L
Mistroke
.17527 0 L
.17626 0 L
.17741 0 L
.17847 0 L
.17963 0 L
.18087 0 L
.18207 0 L
.18339 0 L
.18463 0 L
.18578 0 L
.18692 0 L
.18795 0 L
.18915 0 L
.19027 0 L
.1915 0 L
.19281 0 L
.19392 0 L
.19513 0 L
.19645 0 L
.19718 0 L
.19785 0 L
.19916 0 L
.20039 0 L
.20153 0 L
.2026 0 L
.20371 0 L
.20495 0 L
.20593 0 L
.20697 0 L
.20811 0 L
.20916 0 L
.2103 0 L
.21151 0 L
.21266 0 L
.21371 0 L
.21494 0 L
.21563 0 L
.21627 0 L
.21745 0 L
.21869 0 L
.2199 0 L
.22122 0 L
.22246 0 L
.22362 0 L
.22476 0 L
.2258 0 L
.227 0 L
.22812 0 L
.22936 0 L
.23066 0 L
Mistroke
.23177 0 L
.23299 0 L
.23431 0 L
.23504 0 L
.23572 0 L
.23702 0 L
.23826 0 L
.23931 0 L
.24047 0 L
.24168 0 L
.24282 0 L
.24388 0 L
.24485 0 L
.24703 0 L
.2482 0 L
.24944 0 L
.25061 0 L
.25168 0 L
.2528 0 L
.25401 0 L
.25533 0 L
.25657 0 L
.25778 0 L
.25893 0 L
.25957 0 L
.26026 0 L
.26147 0 L
.26262 0 L
.26385 0 L
.26489 0 L
.26605 0 L
.26731 0 L
.26799 0 L
.26863 0 L
.26933 0 L
.27009 0 L
.27073 0 L
.27142 0 L
.27207 0 L
.27278 0 L
.27407 0 L
.27532 0 L
.27647 0 L
.27768 0 L
.27898 0 L
.28021 0 L
.28134 0 L
.28265 0 L
.28408 0 L
.28669 0 L
Mistroke
.28941 1e-05 L
.2909 1e-05 L
.29164 1e-05 L
.29231 1e-05 L
.29362 1e-05 L
.29432 1e-05 L
.29505 1e-05 L
.29623 1e-05 L
.29753 0 L
.29883 0 L
.30004 0 L
.30067 0 L
.30136 0 L
.30209 0 L
.30277 1e-05 L
.30402 1e-05 L
.30516 2e-05 L
.30641 3e-05 L
.30773 4e-05 L
.30884 6e-05 L
.30988 7e-05 L
.31109 7e-05 L
.31218 8e-05 L
.31339 8e-05 L
.3147 7e-05 L
.31592 6e-05 L
.31704 6e-05 L
.31825 5e-05 L
.31954 4e-05 L
.32076 3e-05 L
.32188 3e-05 L
.32319 5e-05 L
.32392 6e-05 L
.32461 7e-05 L
.32587 .00011 L
.3272 .00017 L
.32993 .0003 L
.33142 .00038 L
.33281 .00045 L
.33399 .0005 L
.33526 .00053 L
.33599 .00054 L
.33667 .00054 L
.33796 .00052 L
.3392 .00048 L
.33983 .00044 L
.34053 .0004 L
.34177 .00033 L
.3429 .00027 L
.34359 .00025 L
Mistroke
.34424 .00024 L
.34492 .00025 L
.34567 .00029 L
.34633 .00034 L
.34702 .00043 L
.34827 .00065 L
.35103 .00145 L
.35248 .00198 L
.35401 .00255 L
.35535 .00296 L
.35611 .00313 L
.35682 .00324 L
.35807 .00328 L
.35878 .00321 L
.35942 .00311 L
.36007 .00295 L
.36077 .00273 L
.36202 .00228 L
.36348 .00171 L
.36419 .00147 L
.36485 .00129 L
.36603 .00112 L
.36729 .00123 L
.36861 .00174 L
.36927 .00218 L
.37 .00279 L
.3796 .01398 L
.38443 .00913 L
.38575 .00694 L
.38698 .0052 L
.38826 .00416 L
.38894 .00408 L
.38967 .00445 L
.39031 .00519 L
.391 .00649 L
.39226 .01017 L
.39349 .01528 L
.39462 .02109 L
.39698 .03426 L
.39813 .04007 L
.39919 .04431 L
.39984 .04621 L
.40053 .04752 L
.40122 .04806 L
.40198 .04772 L
.40328 .04486 L
.4045 .03985 L
.40746 .02257 L
.40876 .01564 L
.40949 .0127 L
Mistroke
.41016 .01091 L
.41136 .01044 L
.41264 .01445 L
.41375 .02205 L
.41498 .03468 L
.41744 .06961 L
.41874 .08968 L
.42014 .10881 L
.42082 .11649 L
.42147 .12225 L
.42269 .12835 L
.42383 .12779 L
.42506 .12006 L
.42637 .10447 L
.42776 .08198 L
.42896 .06045 L
.43024 .03887 L
.43143 .02373 L
.43252 .01653 L
.43362 .01742 L
.43465 .02665 L
.43586 .04758 L
.43697 .07568 L
.4395 .15801 L
.44082 .20161 L
.44151 .22212 L
.44224 .24079 L
.44288 .25405 L
.44358 .26461 L
.44481 .27165 L
.44601 .26322 L
.4473 .23768 L
.44851 .20015 L
.44961 .15823 L
.4509 .10616 L
.45226 .05631 L
.45297 .036 L
.45376 .02037 L
.45447 .01355 L
.45514 .01434 L
.45645 .03741 L
.45766 .08237 L
.45832 .11534 L
.45905 .15622 L
.46037 .23754 L
.46161 .31237 L
.46292 .37853 L
.4636 .40487 L
.46435 .42604 L
.46568 .44273 L
Mistroke
.46693 .43612 L
.46763 .4246 L
.46827 .41032 L
.47068 .33914 L
.47298 .27259 L
.47428 .24316 L
.47548 .22225 L
.47653 .2086 L
.47769 .19762 L
.4789 .18949 L
.48004 .18369 L
.48533 .15535 L
.48791 .13764 L
.49025 .12413 L
.49153 .11872 L
.49273 .11485 L
.49401 .11182 L
.49539 .10933 L
.50101 .10019 L
.52119 .05755 L
.52579 .04197 L
.52833 .03072 L
.52958 .02626 L
.53074 .02308 L
.53183 .02095 L
.53298 .01944 L
.53426 .01846 L
.53542 .01795 L
.53969 .01651 L
.54915 .01285 L
.55956 .00897 L
.57053 .00559 L
.57533 .00438 L
.5806 .0034 L
.58999 .00205 L
.59511 .00152 L
.59989 .00113 L
.60515 .00083 L
.60764 .0007 L
.60995 .00058 L
.61123 .00053 L
.6126 .00049 L
.61548 .00042 L
.61803 .00033 L
.61871 .00031 L
.61942 .0003 L
.62072 .00027 L
.62195 .00025 L
.62306 .00024 L
.62562 .0002 L
Mistroke
.62676 .00018 L
.62796 .00015 L
.62898 .00014 L
.63011 .00013 L
.63132 .00013 L
.63261 .00012 L
.63334 .00011 L
.63401 .0001 L
.63532 9e-05 L
.63652 8e-05 L
.63784 7e-05 L
.63908 6e-05 L
.64022 6e-05 L
.64902 3e-05 L
.65027 3e-05 L
.65143 2e-05 L
.65265 2e-05 L
.65333 2e-05 L
.65397 2e-05 L
.65512 1e-05 L
.65617 1e-05 L
.65729 1e-05 L
.65852 1e-05 L
.65967 1e-05 L
.66094 1e-05 L
.66158 1e-05 L
.66227 1e-05 L
.66351 1e-05 L
.66475 1e-05 L
.66592 1e-05 L
.66697 1e-05 L
.66812 1e-05 L
.66929 0 L
.67039 0 L
.67166 0 L
.67281 0 L
.6739 0 L
.6749 0 L
.67599 0 L
.67715 0 L
.67841 0 L
.67961 0 L
.68026 0 L
.68098 0 L
.68223 0 L
.68343 0 L
.68469 0 L
.68578 0 L
.68697 0 L
.68765 0 L
Mistroke
.68837 0 L
.68965 0 L
.69037 0 L
.69114 0 L
.69187 0 L
.69253 0 L
.69381 0 L
.69502 0 L
.69633 0 L
.69707 0 L
.69775 0 L
.699 0 L
.70019 0 L
.70126 0 L
.70242 0 L
.70369 0 L
.70439 0 L
.70503 0 L
.70628 0 L
.70745 0 L
.70855 0 L
.70972 0 L
.71073 0 L
.71181 0 L
.71297 0 L
.71406 0 L
.71535 0 L
.71652 0 L
.7178 0 L
.71845 0 L
.71916 0 L
.72042 0 L
.72161 0 L
.72226 0 L
.72297 0 L
.72427 0 L
.72504 0 L
.72576 0 L
.72642 0 L
.72713 0 L
.72844 0 L
.72968 0 L
.73078 0 L
.73198 0 L
.7333 0 L
.73401 0 L
.73468 0 L
.73588 0 L
.73716 0 L
.73839 0 L
Mistroke
.7397 0 L
.74095 0 L
.74209 0 L
.7433 0 L
.74458 0 L
.74589 0 L
.74663 0 L
.74733 0 L
.74808 0 L
.74877 0 L
.7495 0 L
.7503 0 L
.751 0 L
.75174 0 L
.75238 0 L
.75307 0 L
.75376 0 L
.7544 0 L
.75508 0 L
.75582 0 L
.75714 0 L
.75839 0 L
.75905 0 L
.75976 0 L
.76104 0 L
.76229 0 L
.76344 0 L
.76469 0 L
.7654 0 L
.76606 0 L
.76675 0 L
.7674 0 L
.76815 0 L
.76883 0 L
.77851 0 L
.77968 0 L
.78091 0 L
.78156 0 L
.78226 0 L
.7835 0 L
.78467 0 L
.78592 0 L
.78701 0 L
.78818 0 L
.7895 0 L
.79074 0 L
.79195 0 L
.79306 0 L
.79844 0 L
.7995 0 L
Mistroke
.8005 0 L
.80166 0 L
.80271 0 L
.80387 0 L
.80513 0 L
.80631 0 L
.8074 0 L
.80852 0 L
.80958 0 L
.81084 0 L
.81199 0 L
.81313 0 L
.81434 0 L
.81555 0 L
.81623 0 L
.81687 0 L
.81813 0 L
.81932 0 L
.82055 0 L
.8212 0 L
.82191 0 L
.82267 0 L
.82339 0 L
.82404 0 L
.82475 0 L
.8254 0 L
.82611 0 L
.82737 0 L
.82866 0 L
.82938 0 L
.83005 0 L
.83128 0 L
.83257 0 L
.83374 0 L
.83482 0 L
.83601 0 L
.83729 0 L
.83853 0 L
.83968 0 L
.84094 0 L
.84158 0 L
.84228 0 L
.84345 0 L
.84472 0 L
.84591 0 L
.84701 0 L
.84808 0 L
.84907 0 L
.85016 0 L
.85132 0 L
Mistroke
.85255 0 L
.85371 0 L
.85484 0 L
.85587 0 L
.85702 0 L
.85826 0 L
.85941 0 L
.8605 0 L
.86176 0 L
.86293 0 L
.86422 0 L
.86494 0 L
.86559 0 L
.86624 0 L
.86692 0 L
.86814 0 L
.86945 0 L
.87021 0 L
.87089 0 L
.87214 0 L
.87283 0 L
.87348 0 L
.87463 0 L
.87588 0 L
.87703 0 L
.8781 0 L
.87927 0 L
.88054 0 L
.88179 0 L
.88294 0 L
.88415 0 L
.88548 0 L
.88663 0 L
.88771 0 L
.88897 0 L
.8901 0 L
.89116 0 L
.89214 0 L
.89321 0 L
.89434 0 L
.89555 0 L
.89624 0 L
.89688 0 L
.89802 0 L
.89929 0 L
.90041 0 L
.90147 0 L
.90259 0 L
.9038 0 L
.90503 0 L
Mistroke
.90574 0 L
.90638 0 L
.90706 0 L
.90779 0 L
.9091 0 L
.91029 0 L
.91159 0 L
.91282 0 L
.91395 0 L
.91501 0 L
.91614 0 L
.91721 0 L
.91819 0 L
.91933 0 L
.92058 0 L
.92175 0 L
.92285 0 L
.92409 0 L
.92522 0 L
.92643 0 L
.92774 0 L
.92889 0 L
.93011 0 L
.93114 0 L
.93228 0 L
.93359 0 L
.93479 0 L
.93542 0 L
.93612 0 L
.93685 0 L
.93753 0 L
.93878 0 L
.93992 0 L
.94118 0 L
.9425 0 L
.94361 0 L
.9448 0 L
.94583 0 L
.94694 0 L
.94825 0 L
.94949 0 L
.9507 0 L
.95181 0 L
.95301 0 L
.95431 0 L
.95553 0 L
.95665 0 L
.95796 0 L
.95869 0 L
.95938 0 L
Mistroke
.96064 0 L
.96129 0 L
.96197 0 L
.9627 0 L
.96337 0 L
.96409 0 L
.96488 0 L
.96557 0 L
.9663 0 L
.96762 0 L
.96828 0 L
.96899 0 L
.97029 0 L
.97156 0 L
.97273 0 L
.97358 0 L
.97437 0 L
.97525 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`0Rooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00GoA4A4o`000?l0003o<S8bomgMg@1Gooooo`05odA4A?l0003o0000oc8b<_oMgMd09oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo02Gooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool09?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00omgMgOo<S8booooo`1Iooooo`03ogMgMolb<S;ooooo02Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Uooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool6o`0000Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[
ooooo`03ogMgMolb<S;ooooo05Wooooo00?oMgMgoc8b<_ooool0:?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo02Gooooo000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0Eoooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001Wooooo
00?oEEEEofIVI_l000001Oooool4o`0002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo1?l0001Hooooo`Co0000:?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool00omEEEGoIVIVo`000005ooooo`Co00009oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooC_ooool2o`0000;ooooo0_l0000Eooooo`00oooooom>
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5Oooool00?ooooooCoooool01?oMgMgo0000oa0@
4?o<c<`Fooooo`005?ooooooo`00033o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hFooooo`006ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00So00000oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`08o`0000Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo013ooooo00Co8B4QogMgMomgMgOo<S8b5_ooool001_ooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00ol0
000Pooooo`03o`000?oooooooooo017ooooo0_l0000Jooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`0001Gooooo0026
ooooo`05o`000?oooooo0000ooooool000001Oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00kooooo0ol0002Yooooo`00Qoooool01?l0003oooooooooool00005ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`?o0000[?oo
ool008_ooooo00Oo0000ooooooooooooooooo`000?oooooo000000Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo0_l0002_ooooo`00Rooo
ool01ol0003ooooooooooooooooo0000ooooool000001Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool2o`000;7ooooo002;ooooo`07o`00
0?ooooooooooooooool0003oooooo`000004ooooo`;o00001Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0/Oooool008_ooooo00Oo0000oooooooo
ooooooooo`000?oooooo000000Cooooo0_l00005ooooo`;o00003?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo0;7ooooo002;ooooo`07o`000?ooooooooooooooool0003oooooo`00
0004ooooo`;o00001Oooool2o`0000cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`2aooooo`00S?ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo0_l00005
ooooo`;o00003?ooool2o`0000Oooooo00?o0000ooooooooool0/Oooool008cooooo00?o0000oooo
ool000000_ooool00ol0003oooooooooo`02ooooo`;o00001Oooool2o`0000cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`2aooooo`00S?ooool00ol0003oooooo`000002ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooool000001?ooool2o`0000cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2booooo`00S?ooool00ol0003oooooo`000002ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooool000001?ooool2o`0000cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`2booooo`00S?ooool3o`0000;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooo`000004ooooo`;o00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0;;ooooo002=ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooo`00
0004ooooo`;o00003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;?ooooo002A
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`;o00003?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;?ooooo002Booooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool00_ooool2o`0000cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`2cooooo`00T_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo0_l0000<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0]?oo
ool009;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`;o00003?oo
ool2o`0000Cooooo00?o0000ooooooooool0]?ooool009;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`02ooooo`;o00003?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo0;Gooooo002Booooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_oo
ool2o`0000cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2eooooo`00T_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo0_l0000<ooooo`05o`000?oo
ooooooooooooool00000^?ooool009;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`02ooooo`;o00003?ooool01Ol0003ooooooooooooooooo00000;Sooooo002Booooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool2o`0000cooooo00Co0000oooooooo
oooo0000^Oooool009;ooooo00Co0000oooooooooooo00000_ooool01ol0003ooooooooooooooooo
0000ooooool000003?ooool01?l0003oooooooooool0002iooooo`00T_ooool01?l0003ooooooooo
ool00002ooooo`07o`000?ooooooooooooooool0003oooooo`00000<ooooo`03o`000?oooooo0000
0;[ooooo002Booooo`04o`000?ooooooooooo`0000;ooooo00Oo0000ooooooooooooooooo`000?oo
oooo000000cooooo00?o0000ooooool00000^_ooool009;ooooo00Co0000oooooooooooo00000_oo
ool01ol0003ooooooooooooooooo0000ooooool000003?ooool2o`000;_ooooo002Booooo`04o`00
0?ooooooooooo`0000;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000cooooo0_l0002k
ooooo`00T_ooool01?l0003oooooooooool00002ooooo`07o`000?ooooooooooooooool0003ooooo
o`00000<ooooo`03o`000?oooooooooo0;[ooooo002Cooooo`03o`000?oooooo000000;ooooo00Oo
0000ooooooooooooooooo`000?oooooo000000cooooo00?o0000ooooooooool0^_ooool009?ooooo
00?o0000ooooool000000_ooool01ol0003ooooooooooooooooo0000ooooool000002oooool2o`00
0;cooooo002Cooooo`03o`000?oooooo000000;ooooo00Oo0000ooooooooooooooooo`000?oooooo
000000_ooooo0_l0002looooo`00Toooool00ol0003oooooo`000002ooooo`07o`000?oooooooooo
ooooool0003oooooo`00000:ooooo`03o`000?oooooo00000;cooooo002@ooooo`03onk^k_lb<S;o
000000;o00000oooool02?l0003oooooob4Q8OlQ8B7o0000ooooool0003ooooo1Ol00004ooooo`03
o`000?oooooo00000;cooooo002@ooooo`03ogMgMonHV9Sooooo00;o00001?ooool03?l0003o8B4Q
ob4Q8Ol0003oooooo`000?ooooooV9RHob4Q8Oo^k^koooooodA4A0?ooooo00Co0000oooooooooooo
0000_?ooool0093ooooo00?o410@ooooooooool00_l00004ooooo`06o`000?ooooooooooo`000?oo
oooo00000_ooool00onHV9So8B4Qonk^kP04ooooo`04o`000?ooooooooooo`000;cooooo002@oooo
o`03o`000?oooooooooo00;o00001?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o
V9RHob4Q8Oo^k^h00oooool00ol0003oooooooooo`03o`000;[ooooo002@ooooo`05o`000?oooooo
ooooooooool000001?ooool01_l0003oooooooooool0003oooooo`0000Cooooo00?oMgMgofIVI_oo
ool00_ooool01?l0003oooooooooool0002looooo`00T?ooool01Ol@413ooooooooooooooooo410@
00Cooooo00Ko0000oooooooooooo0000ooooool00005ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo
00co0000oooooooooooo0000ooooool0003oooooo`000?nj^[[ooooooiRHV?l@4102ooooo`05o`00
0?ooooooooooooooool00000_?ooool0093ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`04
o`000?ooooooooooo`0000;ooooo00Ko0000oiRHV?l@413o0000ob4Q8Oo<c<`2ooooo`05o`000?oo
ooooooooooooool00000_?ooool009Wooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool00000_?ooool009Wooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000_?ooool009Wo
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooo
ooooool00000_?ooool009Wooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool00000_?ooool009Wooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooooooo`;o0000^oooool009Wooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool0
0000_?ooool009Wooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`05
o`000?ooooooooooooooool00000_?ooool009Wooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0^_ooool009Wo
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0^_ooool009Wooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0^_ooool009Wo
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0^_ooool009Wooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0^_ooool009Wo
oooo00?o0000ooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0^_ooool009Wooooo00?o0000ooooool000000oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0002kooooo`00VOooool00ol0003oooooo`00
0003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`2jooooo`00VOooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`2jooooo`00VOooool00ol0003oooooo`000003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2joooo
o`00VOooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`2jooooo`00VOooool00ol0003oooooo`000003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2jooooo`00VOoo
ool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`2jooooo`00VOooool00ol0003oooooo`000003ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2jooooo`00VOooool00ol0
003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`2jooooo`00VOooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2jooooo`00VOooool00ol0003ooooo
o`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool2o`000;_ooooo
002Iooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0;[ooooo002Iooooo`03o`000?oooooo000000?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;[ooooo002Ioooo
o`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0;[ooooo002Iooooo`03o`000?oooooo000000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;[ooooo002Jooooo`;o0000
0oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0^_ooool0093ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o00000oooool00ol0003oooooooooo`02o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool0^_ooool0093ooooo00Go410@oooooooooooooooooa0@4005ooooo`;o00000oooool6o`00
00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Go0000ooooooooooooooooo`000005oooo
o`;o00000oooool01Ol0003oA4A4omgMgOoooooo000000Oooooo0ol0002jooooo`00T?ooool01Ol0
003ooooooooooooooooo000000Gooooo0_l00003ooooo`05o`000?oMgMgoEEEEooooool000001ooo
ool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo410@00Gooooo0_l0
0003ooooo`05o`000?ooooooMgMgolc<c?l000001oooool00ol0003oooooooooo`2jooooo`00T?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00003ooooo`05o`000?ooooook^k^odA4A?l0
00001oooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_l00003ooooo`05o`000?ooooooooooogMgMol000001oooool00ol0003oooooooooo`2joooo
o`00V_ooool2o`0000?ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo
0;[ooooo002Jooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool0^_ooool009[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool0^_ooool009oooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooooooo0;[ooooo002Oooooo`05o`000?ooooooooooooooool000001oooool2o`00
0;_ooooo002Oooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`2joooo
o`00Woooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0^_ooool009oo
oooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo0;[ooooo002Oooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`2jooooo`00Woooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool0^_ooool009oooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo0;[ooooo002Oooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`2jooooo`00Woooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool0^_ooool009oooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooooooo0;[ooooo002Oooooo`04o`000?ooooooooooo`0000Sooooo0_l0002koooo
o`00Woooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo0;[ooooo002Oooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0^_ooool009oooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooooooo`2jooooo`00Woooool01?l0003oooooooooool00008oooo
o`03o`000?oooooooooo0;[ooooo002Oooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ooooool0^_ooool009oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`2joooo
o`00Woooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo0;[ooooo002Oooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0^_ooool009oooooo00Co0000oooooooo
oooo00002?ooool2o`000;_ooooo002Oooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ooooool0^_ooool009oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`2joooo
o`00X?ooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo0;[ooooo002Pooooo`03o`00
0?oooooo000000Sooooo00?o0000ooooooooool0^_ooool00:3ooooo00?o0000ooooool000002?oo
ool00ol0003oooooooooo`2jooooo`00X?ooool00ol0003oooooo`000008ooooo`03o`000?oooooo
oooo0;[ooooo002@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Go0000
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go0000ogMgMol0003oV9RHob4Q8@06ooooo`03o`00
0?oooooooooo0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
o`000?oooooo000000Kooooo0ol0002jooooo`00T?ooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000oiRHV?l0003oV9RHob4Q8@06ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05
o`000?ooooooooooooooool000002oooool3o`000003oa0@4?o<c<cooooo00Gooooo00?o0000oooo
ooooool0^_ooool0093ooooo00Go410@oooooooooooooooooa0@400;ooooo`;o00002Oooool00ol0
003oooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo0_l000000onH
V9Soooooooooo`06ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool2o`000003odA4A?l0003o410@00Kooooo00?o0000ooooooooool0^_ooool00:3o
oooo0_l00009ooooo`03o`000?oooooooooo0;[ooooo002Pooooo`;o00002Oooool00ol0003ooooo
ooooo`2jooooo`00X?ooool2o`0000Wooooo00?o0000ooooooooool0^_ooool00:3ooooo0_l00009
ooooo`03o`000?oooooooooo0;[ooooo002Pooooo`;o00002Oooool2o`000;_ooooo002Pooooo`;o
00002Oooool00ol0003oooooooooo`2jooooo`00X?ooool2o`0000Wooooo00?o0000ooooooooool0
^_ooool00:3ooooo0_l00009ooooo`03o`000?oooooooooo0;[ooooo002Pooooo`;o00002Oooool0
0ol0003oooooooooo`2jooooo`00X?ooool2o`0000Wooooo00?o0000ooooooooool0^_ooool00:3o
oooo0_l00009ooooo`03o`000?oooooooooo0;[ooooo002Pooooo`;o00002Oooool00ol0003ooooo
ooooo`2jooooo`00X?ooool2o`0000Wooooo00?o0000ooooooooool0^_ooool00:3ooooo0_l00009
ooooo`;o0000^oooool00:7ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2joooo
o`00XOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;[ooooo002Qooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0
002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_oo
ool00ol0003oooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2jooooo`00T?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo0;[ooooo002@ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;o
V9RHoooooonHV9So<S8b00Kooooo0ol0002jooooo`00T?ooool01Ol0003ooooooooooooooooo0000
00_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo0;[ooooo002@oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o
0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o
0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002koooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002Qooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2jooooo`00Xooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;[ooooo002Sooooo`03o`000?oooooo
oooo00Gooooo0ol0002jooooo`00Xoooool00ol0003oooooooooo`32ooooo`00Xoooool00ol0003o
ooooooooo`32ooooo`00Xoooool00ol0003oooooooooo`32ooooo`00Xoooool00ol0003ooooooooo
o`32ooooo`00XOooool00omEEEGoIVIVo`000034ooooo`00oooooomYooooo`00JOooool00omgMgOo
IVIVooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o^[Zjoc8b<_ooool01oooool2o`0000_o
oooo00?o0000okZj^_ooool03?ooool2o`0000Oooooo00?o0000ooooooooool00_ooool00omVIVKo
MgMgooooo`0<ooooo`03o`000?nj^[[ooooo0:gooooo001Xooooo`03omgMgOl@413ok^k^00Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo
0_lb<S8>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00oo^k^ko410@
omgMg@0<ooooo`;o<S8b[_ooool006Sooooo00?oEEEEoiRHV?ooool01Oooool01_l0003ooooooooo
ooooooooV9RHoa0@40;o000000?oZJVYooooooooool01?ooool01?l0003oooooooooooooool2o`00
00;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00on7QhOoIVIVooooo`0;
ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0@ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Co410@o`000?m4A4Coc<c<N?ooool006Sooooo
00?o0000ooooooooool01Oooool02_l0003ooooooooooooooooo0000ojVYZOmEEEGoV9RHoeEEEOnj
^[X5ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<
o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`03ooooo`03onk^k_l0003ooooo00_ooooo00?oc<c<o`000?l@41003?oo
ool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oiRHV?l@413ogMgM07Oooooo001Xooooo`03oc8b<_oooooooooo00Go
oooo00[o0000oooooooooooooooooc8b<_o^k^koV9RHoeEEEOoMgMgo410@1Oooool00ol0003ooooo
ooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Booooo`05oa0@4?ooooooooooooooool@41003_ooool00on7QhOoEEEEooooo`1foooo
o`00J?ooool00olb<S;oooooooooo`05ooooo`0;o`000?oooooooooooooooonj^[[oA4A4olc<c?lQ
8B7ooooooa0@4?o<c<`01?ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`03ooooo`Ko00002Oooool01Ol0003o
oooooooooooooooo000000_ooooo00Goc<c<ob4Q8Ol0003oEEEEo`00001gooooo`00J?ooool00ol0
003ok^k^ooooo`05ooooo`0;o`000?ooooooooooooooooo^k^ko0000ooooool0003oooooofIVI_n7
QhL01?ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?ok^k^o`00
0?ooool06_ooool00ol0003oooooooooo`0Booooo`05o`000?ooooooooooooooool000002oooool0
1OlQ8B7oQhN7oooooonHV9So000007Oooooo001Xooooo`03oeEEEOmgMgOooooo00Gooooo00So0000
ooooooooooooooooofIVI_nHV9Sooooooc8b<P;o^[Zj00?o0000ooooooooool00_ooool01?l0003o
ooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?oMgMgoeEEEOooool00_ooool4o`00
01;ooooo00?o410@o`000?l000000ol0000Aooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol0003ooooooooooooooooo000007Oooooo001Xooooo`03omgMgOl@413ok^k^00Gooooo00?o0000
ooooooooool01?ooool00omVIVKoQhN7ooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?ok^k^
oa0@4?oMgMd01?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05ob4Q8OnHV9SoooooogMgMomEEED0Moooool006Wooooo00?o
MgMgofIVI_ooool01?ooool00ol0003oooooooooo`04ooooo`03ojVYZOm4A4Cooooo00Gooooo0_l0
000Booooo`03o`000?oooooooooo00Gooooo0_l00007ooooo`03o`000?oooooooooo00;ooooo00?o
IVIVogMgMoooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05olc<c?l@413o0000oc8b<_o^k^h0Moooool00;;ooooo
00?o0000ooooooooool0/oooool00:oooooo00Co0000oooooooooooo0000]Oooool00;3ooooo0_l0
002fooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.8522, -0.080387, \
0.130126, 0.00668404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -55.625 0 ]
[.5 .63053 55.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -116.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
170.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02846 0 L
.02952 0 L
.03068 0 L
.03178 0 L
.03279 0 L
.03399 0 L
.03527 0 L
.03635 0 L
.03754 0 L
.0388 0 L
.03951 0 L
.04016 0 L
.04142 0 L
.04262 0 L
.04387 0 L
.045 0 L
.0463 0 L
.04753 0 L
.0486 0 L
.04973 0 L
.05096 0 L
.0521 0 L
.05333 0 L
.05465 0 L
.05589 0 L
.05703 0 L
.05772 0 L
.05836 0 L
.05906 0 L
.05981 0 L
.06106 0 L
.06178 0 L
.06244 0 L
.06374 0 L
.06444 0 L
.06511 0 L
.06642 0 L
.0676 0 L
.06884 0 L
.06954 0 L
.07019 0 L
.07084 0 L
.07157 0 L
.07231 0 L
.07302 0 L
.07428 0 L
.07544 0 L
.07668 0 L
.07738 0 L
Mistroke
.07803 0 L
.07923 0 L
.0803 0 L
.08155 0 L
.08272 0 L
.08399 0 L
.08471 0 L
.08539 0 L
.0861 0 L
.08674 0 L
.08749 0 L
.0882 0 L
.08945 0 L
.09061 0 L
.09188 0 L
.09252 0 L
.09323 0 L
.09395 0 L
.0947 0 L
.09535 0 L
.09605 0 L
.0968 0 L
.0975 0 L
.09833 0 L
.09909 0 L
.09975 0 L
.10044 0 L
.10121 0 L
.10191 0 L
.10318 0 L
.10386 0 L
.10458 0 L
.10588 0 L
.10708 0 L
.10838 0 L
.10912 0 L
.10981 0 L
.11107 0 L
.11176 0 L
.1124 0 L
.11353 0 L
.11477 0 L
.11588 0 L
.11693 0 L
.11814 0 L
.11924 0 L
.12044 0 L
.12155 0 L
.12277 0 L
.12407 0 L
Mistroke
.12536 0 L
.12654 0 L
.12782 0 L
.12854 0 L
.1292 0 L
.1304 0 L
.13167 0 L
.1329 0 L
.13402 0 L
.13534 0 L
.136 0 L
.13673 0 L
.13752 0 L
.13825 0 L
.13898 0 L
.13966 0 L
.1403 0 L
.141 0 L
.14222 0 L
.14292 0 L
.14366 0 L
.14497 0 L
.14609 0 L
.14731 0 L
.14861 0 L
.14983 0 L
.15098 0 L
.15203 0 L
.15324 0 L
.15438 0 L
.15564 0 L
.15628 0 L
.15697 0 L
.15821 0 L
.15936 0 L
.16006 0 L
.16072 0 L
.16197 0 L
.16272 0 L
.16343 0 L
.16407 0 L
.16476 0 L
.16608 0 L
.16729 0 L
.1686 0 L
.16926 0 L
.16998 0 L
.17119 0 L
.17248 0 L
.17371 0 L
Mistroke
.17482 0 L
.1755 0 L
.17622 0 L
.17752 0 L
.17825 0 L
.17903 0 L
.17977 0 L
.18045 0 L
.18175 0 L
.18298 0 L
.18367 0 L
.18432 0 L
.18502 0 L
.18577 0 L
.18701 0 L
.18772 0 L
.18838 0 L
.18907 0 L
.1897 0 L
.19044 0 L
.19113 0 L
.19234 0 L
.19366 0 L
.19481 0 L
.19605 0 L
.19737 0 L
.19862 0 L
.19933 0 L
.20009 0 L
.20074 0 L
.20145 0 L
.20218 0 L
.20288 0 L
.20368 0 L
.20441 0 L
.2051 0 L
.20574 0 L
.20649 0 L
.20718 0 L
.20834 0 L
.20958 0 L
.21075 0 L
.21184 0 L
.2131 0 L
.21376 0 L
.21447 0 L
.21578 0 L
.21697 0 L
.21822 0 L
.21954 0 L
Mistroke
.22023 0 L
.22099 0 L
.22167 0 L
.22231 0 L
.22359 0 L
.22474 0 L
.22538 0 L
.22608 0 L
.22734 0 L
.22857 0 L
.22968 0 L
.23091 0 L
.2322 0 L
.23333 0 L
.23438 0 L
.23553 0 L
.23676 0 L
.23746 0 L
.23811 0 L
.23882 0 L
.23956 0 L
.24082 0 L
.24154 0 L
.24221 0 L
.24343 0 L
.24459 0 L
.24523 0 L
.24593 0 L
.24715 0 L
.24844 0 L
.24966 0 L
.25036 0 L
.25099 0 L
.25174 0 L
.25244 0 L
.25374 0 L
.25443 0 L
.25517 0 L
.25595 0 L
.25668 0 L
.25734 0 L
.25806 0 L
.25927 0 L
.25997 0 L
.26061 0 L
.26128 0 L
.26201 0 L
.26331 0 L
.2645 0 L
.2658 0 L
Mistroke
.26703 0 L
.26817 1e-05 L
.26945 1e-05 L
.2701 1e-05 L
.27081 1e-05 L
.27207 1e-05 L
.27324 1e-05 L
.27396 1e-05 L
.27463 1e-05 L
.2759 0 L
.2766 1e-05 L
.27726 1e-05 L
.27797 1e-05 L
.27874 0 L
.27991 0 L
.28118 0 L
.28237 0 L
.28347 0 L
.28469 0 L
.28537 1e-05 L
.28602 1e-05 L
.28869 2e-05 L
.29332 4e-05 L
.29443 5e-05 L
.2956 5e-05 L
.29659 6e-05 L
.29769 5e-05 L
.29894 5e-05 L
.30011 4e-05 L
.30148 3e-05 L
.30273 2e-05 L
.30378 1e-05 L
.30493 1e-05 L
.30615 0 L
.3073 0 L
.30795 0 L
.30864 0 L
.30987 2e-05 L
.31119 4e-05 L
.31194 7e-05 L
.31264 9e-05 L
.31526 .0002 L
.31765 .00029 L
.31877 .00032 L
.31998 .00036 L
.32112 .00038 L
.32218 .00039 L
.32329 .00038 L
.32453 .00036 L
.32581 .0003 L
Mistroke
.32702 .00022 L
.32831 .00013 L
.329 9e-05 L
.32972 5e-05 L
.33042 2e-05 L
.33106 1e-05 L
.3323 1e-05 L
.33349 7e-05 L
.33478 .00019 L
.336 .00035 L
.33713 .00055 L
.33982 .0012 L
.34238 .00187 L
.34306 .00201 L
.34379 .00213 L
.34458 .00222 L
.34532 .00226 L
.3466 .00222 L
.34733 .00214 L
.34801 .00203 L
.35269 .0007 L
.35397 .00034 L
.35461 .00019 L
.35532 7e-05 L
.35657 1e-05 L
.35773 .00018 L
.35891 .00063 L
.36003 .00132 L
.36103 .00217 L
.36212 .00329 L
.36455 .00617 L
.36681 .0087 L
.36801 .00969 L
.3693 .01036 L
.37003 .01051 L
.37073 .01048 L
.37203 .00995 L
.3727 .00943 L
.3734 .00872 L
.37468 .00705 L
.37606 .0049 L
.37756 .00257 L
.37824 .00166 L
.37895 .00087 L
.38024 9e-05 L
.38144 .00028 L
.38276 .00168 L
.38394 .00403 L
.3852 .00764 L
.38747 .01648 L
Mistroke
.39004 .0279 L
.39145 .03338 L
.39276 .0371 L
.39388 .03871 L
.39509 .03854 L
.39574 .03757 L
.39643 .03589 L
.39766 .03138 L
.40022 .01787 L
.40162 .01013 L
.40231 .0068 L
.40295 .0042 L
.4037 .00184 L
.40452 .0004 L
.40521 .00022 L
.40595 .00118 L
.40663 .00322 L
.40727 .00617 L
.40798 .01056 L
.40873 .01659 L
.41132 .0457 L
.41413 .08314 L
.41542 .0975 L
.41614 .10378 L
.41679 .10809 L
.41806 .11217 L
.41925 .11031 L
.42043 .10307 L
.42166 .0902 L
.42387 .05794 L
.4251 .03832 L
.42644 .01917 L
.4277 .006 L
.42886 .00037 L
.43001 .0026 L
.43128 .01513 L
.43192 .02549 L
.4326 .03949 L
.43384 .07134 L
.43601 .13932 L
.43716 .17571 L
.43838 .21005 L
.43912 .2271 L
.43979 .23939 L
.4411 .25317 L
.44174 .25456 L
.44244 .252 L
.44369 .23684 L
.44493 .21008 L
.44623 .17177 L
Mistroke
.44856 .09104 L
.44968 .05437 L
.45074 .02582 L
.45197 .00483 L
.45308 .0004 L
.45413 .01119 L
.45511 .03473 L
.45617 .0748 L
.45731 .13099 L
.4595 .26041 L
.46066 .32612 L
.46187 .38375 L
.46252 .40745 L
.46323 .42683 L
.46447 .44325 L
.46573 .43782 L
.46691 .41602 L
.47196 .25432 L
.47334 .21727 L
.47481 .18693 L
.47606 .16789 L
.47676 .15954 L
.47743 .15299 L
.47872 .14335 L
.47991 .13706 L
.48118 .13191 L
.48256 .12723 L
.48508 .11956 L
.48627 .11633 L
.48736 .11383 L
.48852 .11191 L
.48977 .11084 L
.49087 .11076 L
.49204 .11138 L
.49326 .11245 L
.49441 .11338 L
.49566 .1138 L
.49637 .11357 L
.49701 .11299 L
.49815 .11101 L
.49921 .10808 L
.50037 .10376 L
.5016 .09825 L
.50368 .08809 L
.50595 .07811 L
.50719 .07394 L
.50834 .07111 L
.50956 .06932 L
.51085 .0688 L
.51207 .06956 L
Mistroke
.51321 .07127 L
.51423 .07344 L
.51534 .07619 L
.51667 .07946 L
.5179 .08185 L
.51919 .08293 L
.51988 .0827 L
.52061 .08174 L
.52191 .07809 L
.52314 .07246 L
.52546 .05802 L
.52766 .04368 L
.52887 .03726 L
.53001 .03266 L
.53097 .0299 L
.53201 .02796 L
.53316 .02678 L
.53422 .02625 L
.53536 .02595 L
.53643 .0257 L
.53886 .02495 L
.54007 .02459 L
.54122 .02434 L
.54186 .02424 L
.54255 .02415 L
.54375 .02399 L
.54498 .02375 L
.5461 .02343 L
.54863 .02243 L
.5532 .02084 L
.5636 .01602 L
.57451 .01155 L
.58463 .00843 L
.5946 .00589 L
.60363 .00398 L
.60845 .0031 L
.61366 .00238 L
.61917 .00178 L
.62167 .00157 L
.62305 .00143 L
.62436 .00131 L
.62693 .00115 L
.62928 .00103 L
.6315 .00091 L
.63387 .00077 L
.6351 .00072 L
.63647 .00068 L
.63887 .00061 L
.64171 .0005 L
.64295 .00046 L
Mistroke
.6436 .00044 L
.64431 .00042 L
.64563 .0004 L
.64685 .00038 L
.64954 .00032 L
.65517 .00022 L
.65792 .00019 L
.65927 .00016 L
.66052 .00015 L
.66165 .00013 L
.66285 .00013 L
.66537 .00011 L
.66769 9e-05 L
.66892 8e-05 L
.67022 7e-05 L
.67147 7e-05 L
.67261 6e-05 L
.67375 6e-05 L
.67482 5e-05 L
.67606 5e-05 L
.67737 4e-05 L
.67805 4e-05 L
.6788 3e-05 L
.68012 3e-05 L
.68133 3e-05 L
.68262 3e-05 L
.68385 2e-05 L
.68496 2e-05 L
.6861 2e-05 L
.68731 1e-05 L
.68834 1e-05 L
.68947 1e-05 L
.69069 1e-05 L
.692 1e-05 L
.69323 1e-05 L
.69437 1e-05 L
.69551 1e-05 L
.69676 1e-05 L
.69785 1e-05 L
.69902 1e-05 L
.70017 1e-05 L
.70125 0 L
.70231 0 L
.70328 0 L
.70444 0 L
.70568 0 L
.70685 0 L
.70793 0 L
.70918 0 L
.70984 0 L
Mistroke
.71055 0 L
.71173 0 L
.71303 0 L
.71368 0 L
.71437 0 L
.71559 0 L
.71691 0 L
.71765 0 L
.71835 0 L
.71959 0 L
.72076 0 L
.72141 0 L
.72211 0 L
.72334 0 L
.72449 0 L
.72556 0 L
.72674 0 L
.72801 0 L
.72864 0 L
.72933 0 L
.73059 0 L
.73183 0 L
.73295 0 L
.7341 0 L
.73517 0 L
.73631 0 L
.73755 0 L
.73863 0 L
.73977 0 L
.74074 0 L
.74181 0 L
.74312 0 L
.74433 0 L
.74496 0 L
.74565 0 L
.74638 0 L
.74706 0 L
.74823 0 L
.74946 0 L
.7501 0 L
.7508 0 L
.75203 0 L
.75326 0 L
.75437 0 L
.75565 0 L
.75686 0 L
.75798 0 L
.75901 0 L
.76023 0 L
.76135 0 L
Mistroke
.76255 0 L
.76385 0 L
.76505 0 L
.76619 0 L
.76683 0 L
.76751 0 L
.76874 0 L
.77006 0 L
.77081 0 L
.77151 0 L
.77283 0 L
.77349 0 L
.77421 0 L
.77549 0 L
.77669 0 L
.77741 0 L
.7781 0 L
.77938 0 L
.78006 0 L
.78077 0 L
.78155 0 L
.78227 0 L
.78347 0 L
.78479 0 L
.78603 0 L
.78719 0 L
.78831 0 L
.78936 0 L
.79058 0 L
.79168 0 L
.79291 0 L
.79422 0 L
.79533 0 L
.79655 0 L
.79786 0 L
.7986 0 L
.79927 0 L
.80057 0 L
.80181 0 L
.80286 0 L
.80401 0 L
.80522 0 L
.80636 0 L
.80742 0 L
.80841 0 L
.80944 0 L
.81057 0 L
.81173 0 L
.81297 0 L
.81412 0 L
Mistroke
.81516 0 L
.81638 0 L
.81707 0 L
.81771 0 L
.81887 0 L
.82011 0 L
.82132 0 L
.82264 0 L
.8238 0 L
.82504 0 L
.82627 0 L
.82738 0 L
.82849 0 L
.82955 0 L
.83078 0 L
.83209 0 L
.8332 0 L
.83442 0 L
.83574 0 L
.83647 0 L
.83714 0 L
.83845 0 L
.83968 0 L
.84074 0 L
.8419 0 L
.84311 0 L
.84425 0 L
.84531 0 L
.84628 0 L
.84733 0 L
.84846 0 L
.84961 0 L
.85068 0 L
.85196 0 L
.85311 0 L
.85432 0 L
.85563 0 L
.85686 0 L
.858 0 L
.85926 0 L
.86045 0 L
.86152 0 L
.86269 0 L
.86395 0 L
.86459 0 L
.8653 0 L
.86655 0 L
.86772 0 L
.86883 0 L
.87 0 L
Mistroke
.87101 0 L
.87209 0 L
.87325 0 L
.87434 0 L
.87563 0 L
.8768 0 L
.87809 0 L
.87879 0 L
.87945 0 L
.88061 0 L
.8819 0 L
.88255 0 L
.88326 0 L
.88456 0 L
.88533 0 L
.88605 0 L
.88671 0 L
.88742 0 L
.88873 0 L
.88997 0 L
.89107 0 L
.89228 0 L
.89359 0 L
.89431 0 L
.89498 0 L
.89617 0 L
.89746 0 L
.89809 0 L
.89878 0 L
.90002 0 L
.90132 0 L
.90206 0 L
.90275 0 L
.90389 0 L
.90513 0 L
.90643 0 L
.90764 0 L
.90833 0 L
.90909 0 L
.90979 0 L
.91045 0 L
.91169 0 L
.913 0 L
.91367 0 L
.9144 0 L
.91572 0 L
.91652 0 L
.91728 0 L
.91802 0 L
.91871 0 L
Mistroke
.91999 0 L
.92114 0 L
.92179 0 L
.92248 0 L
.92371 0 L
.92478 0 L
.92594 0 L
.92719 0 L
.92835 0 L
.929 0 L
.92971 0 L
.931 0 L
.93226 0 L
.93342 0 L
.93467 0 L
.93538 0 L
.93605 0 L
.93675 0 L
.93739 0 L
.93809 0 L
.93884 0 L
.94005 0 L
.94119 0 L
.94221 0 L
.94332 0 L
.94453 0 L
.94581 0 L
.94699 0 L
.9481 0 L
.94921 0 L
.95027 0 L
.95122 0 L
.95225 0 L
.95335 0 L
.95454 0 L
.95566 0 L
.9567 0 L
.95781 0 L
.95903 0 L
.96028 0 L
.9616 0 L
.96291 0 L
.96364 0 L
.96431 0 L
.96561 0 L
.96682 0 L
.96794 0 L
.96913 0 L
.97033 0 L
.97164 0 L
Mistroke
.97277 0 L
.97399 0 L
.97514 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`0Rooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00GoA4A4o`000?l0003o<S8bomgMg@1Gooooo`05odA4A?l0003o0000oc8b<_oMgMd09oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo02Gooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool09?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00omgMgOo<S8booooo`1Iooooo`03ogMgMolb<S;ooooo02Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Uooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool6o`0000Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[
ooooo`03ogMgMolb<S;ooooo05Wooooo00?oMgMgoc8b<_ooool0:?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo02Gooooo000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0Eoooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001Wooooo
00?oEEEEofIVI_l000001Oooool4o`0002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo1?l0001Hooooo`Co0000:?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool00omEEEGoIVIVo`000005ooooo`Co00009oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooC_ooool2o`0000;ooooo0_l0000Eooooo`00oooooom>
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5Oooool00?ooooooCoooool01?oMgMgo0000oa0@
4?o<c<`Fooooo`005?ooooooo`00033o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hFooooo`006ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`?o00000oooool01?l0003oooooooooooooool2o`000003oooo
ool0003ooooo00Cooooo0_l00005ooooo`;o000000?oooooo`000?ooool00oooool01Ol0003ooooo
oooooooooooo000000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Oooooo2_l00009ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool04?ooool01?lQ8B7oMgMgogMgMolb<S8Fooooo`006oooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooool000001Oooool2o`0000Gooooo0_l0000=oooo
o`03o`000?oooooooooo01Wooooo0_l0000Booooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`0001Gooooo0023ooooo`?o
00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Gooooo0_l00005ooooo`;o
00003Oooool00ol0003oooooooooo`0Fooooo`?o0000XOooool008Wooooo00Oo0000oooooooooooo
ooooo`000?oooooo000000Gooooo0_l00005ooooo`;o00003Oooool00ol0003oooooooooo`0Boooo
o`Co0000Y?ooool008Wooooo00Oo0000ooooooooooooooooo`000?oooooo000000Gooooo0_l00005
ooooo`;o00003Oooool00ol0003oooooooooo`0?ooooo`?o0000Z?ooool008Wooooo00Oo0000oooo
ooooooooooooo`000?oooooo000000Gooooo0_l00005ooooo`;o00003Oooool00ol0003ooooooooo
o`0=ooooo`;o0000Zoooool008Wooooo00Oo0000ooooooooooooooooo`000?oooooo000000Gooooo
0_l00005ooooo`;o00003Oooool00ol0003oooooooooo`0:ooooo`?o0000[Oooool008[ooooo00Ko
0000oooooooooooo0000ooooool00005ooooo`;o00001Oooool2o`0000gooooo00?o0000oooooooo
ool01oooool3o`000;3ooooo002:ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0
0oooool2o`0000Gooooo0_l0000=ooooo`03o`000?oooooooooo00Kooooo0_l0002booooo`00R_oo
ool00ol0003oooooo`000003ooooo`07o`000?ooooooooooooooool0003oooooo`000005ooooo`;o
00003Oooool2o`0000Oooooo00?o0000ooooooooool0/Oooool008_ooooo0_l00003ooooo`05o`00
0?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`;o00003Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0;7ooooo002;ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo0_l0000=ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0/Oooool0093ooooo00Go0000oooooooooooo
ooooo`000002ooooo`03o`000?oooooooooo00;ooooo0_l0000=ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0/_ooool0093ooooo00Go0000ooooooooooooooooo`000002ooooo`03
o`000?oooooooooo00;ooooo0_l0000=ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0/_ooool0093ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;o
oooo0_l0000=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool0093ooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo0_l0000=ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool0093ooooo00Go0000oooooooooooo
ooooo`000002ooooo`03o`000?oooooooooo00;ooooo0_l0000=ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0/_ooool0093ooooo00Go0000ooooooooooooooooo`000002ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0;;ooooo002@ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooo000000cooooo0_l00006ooooo`03o`000?oooooooooo0;;o
oooo002Aooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooo`00000<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool0097ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000co
oooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooooooo0;?ooooo002Aooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000<ooooo`03
o`000?oooooooooo00;o00000_ooool00ol0003oooooooooo`2cooooo`00TOooool00ol0003ooooo
o`000003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooo000000;ooooo00?o0000ooooool00000]Oooool0097ooooo00?o0000ooooool00000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooo`000002ooooo`03o`000?oooooo00000;Gooooo002Aooooo`03o`000?oooooo000000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool0
00000_ooool2o`000;Kooooo002Aooooo`03o`000?oooooo000000?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`03o`000?oooooooooo00[ooooo0_l0002kooooo`00TOooool00ol0003ooooo
o`000003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0:ooooo`;o
0000^oooool0097ooooo00?o0000ooooool000000oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool02_ooool2o`000;_ooooo002Aooooo`03o`000?oooooo000000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0^_ooool0097ooooo00?o0000ooooool000000oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2jooooo`00TOooool00ol0003ooooo
o`000003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo0;[ooooo002Booooo`;o00000oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2jooooo`00T_ooool2o`0000Cooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0;[o
oooo002Booooo`;o00001?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Oo
oooo1?l0002looooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Co0000oooooolQ
8B7o00000_ooool00ol0003oooooo`000004o`0000;ooooo00?o0000ooooooooool00_l0002loooo
o`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Co0000oooooolQ8B7o00000_ooool0
2Ol0003ooooooiRHV?lQ8B7ok^k^oooooom4A4Coooooo`000004ooooo`03o`000?oooooooooo0;[o
oooo002@ooooo`05oa0@4?ooooooooooooooool@41000oooool01?l0003oooooooooool00002oooo
o`06o`000?oooooooooooiRHV?lQ8B7ok^k^0_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo0;[ooooo002@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00002ooooo`09o`000?oooooooooooooooonHV9So8B4Qonk^k_oooooo000000Cooooo0ol0002j
ooooo`00T?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`02ooooo`04ogMgMomVIVKoooooo`0000Cooooo00?o0000ooooooooool0
^_ooool0093ooooo00Go410@oooooooooooooooooa0@4003ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00oooool2o`0000Gooooo00?o0000ooooooooool0^_ooool0093ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`04o`000?ooooooooooo`0000;ooooo00So0000oooo
ool0003o^[ZjoooooonHV9So410@o`0000Gooooo00?o0000ooooooooool0^_ooool0093ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`04o`000?ooooooooooo`0000;ooooo00So0000oooooonH
V9So410@o`000?lQ8B7oc<c<o`0000Gooooo00?o0000ooooooooool0^_ooool009Sooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0^_ooool009Sooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0^_ooool009Sooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0^_ooool009Sooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool009Sooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo0_l0
002kooooo`00V?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`2jooooo`00V?ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`2jooooo`00V?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`2jooooo`00V?ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`2jooooo`00V?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`2jooooo`00V?ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`2jooooo`00V?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`2jooooo`00V?ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2jooooo`00V?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool2o`000;_ooooo002Hooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;[ooooo002H
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0;[ooooo002Hooooo`03o`000?oooooo000000?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;[ooooo002Hoooo
o`03o`000?oooooo000000Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
oooo0;[ooooo002Hooooo`03o`000?oooooo000000Cooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooooooo0;[ooooo002Hooooo`03o`000?oooooo000000Cooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooooooo0;[ooooo002Hooooo`03o`000?oooooo0000
00Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo0;[ooooo002Hoooo
o`03o`000?oooooo000000Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
oooo0;[ooooo002Hooooo`03o`000?oooooo000000Cooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooooooo0;[ooooo002Hooooo`03o`000?oooooo000000Cooooo00Go0000oooo
ooooooooooooo`000007ooooo`;o0000^oooool009Wooooo0_l00004ooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`2jooooo`00VOooool2o`0000Cooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooooooo0;[ooooo002Iooooo`;o00001?ooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0^_ooool009Wooooo0_l00004oooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`2jooooo`00VOooool2o`00
00Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo0;[ooooo002@oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool2o`000005ob4Q8Oooooooooooooooool000000_oo
ool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`04ooooo`;o000000Go8B4Qooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0^_ooool0093ooooo00Go410@oooooooooooooooo
oa0@4004ooooo`;o00001?ooool6o`0000Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Go
0000ooooooooooooooooo`000004ooooo`;o00001?ooool01Ol0003oA4A4omgMgOoooooo000000Oo
oooo0ol0002jooooo`00T?ooool01Ol0003ooooooooooooooooo000000Cooooo0_l00004ooooo`05
o`000?oMgMgoEEEEooooool000001oooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413o
oooooooooooooooo410@00Cooooo00?o0000ooooooooool00oooool01Ol0003oooooogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:
ooooo`05o`000?ooooook^k^odA4A?l000001oooool00ol0003oooooooooo`2jooooo`00T?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo00Go0000ooooooooooooMgMgo`000007ooooo`03o`00
0?oooooooooo0;[ooooo002Oooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`2jooooo`00Woooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0
^_ooool009oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo0;[ooooo
002Oooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`2jooooo`00Wooo
ool01Ol0003ooooooooooooooooo000000Oooooo0_l0002kooooo`00Woooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooooooool0^_ooool009oooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooooooo0;[ooooo002Oooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooooooo`2jooooo`00Woooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool0^_ooool009oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooooooo0;[ooooo002Oooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0
^_ooool009oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`2jooooo`00Wooo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo0;[ooooo002Oooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooooooool0^_ooool009oooooo00Co0000oooooooooooo0000
2?ooool2o`000;_ooooo002Oooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0
^_ooool009oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`2jooooo`00Wooo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo0;[ooooo002Oooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooooooool0^_ooool009oooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooooooo`2jooooo`00Woooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooooooo0;[ooooo002Oooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0
^_ooool009oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`2jooooo`00Wooo
ool01?l0003oooooooooool00008ooooo`;o0000^oooool009oooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooooooo`2jooooo`00Woooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooooooo0;[ooooo002Oooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0
^_ooool009oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`2jooooo`00Wooo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo0;[ooooo002Oooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q0oooool01_l0003ok^k^oc8b<_l0003o410@olc<c0Kooooo00?o0000oooo
ooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q0oooool01_l0
003oEEEEogMgMol0003oV9RHob4Q8@Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Go410@
oooooooooooooooooa0@400:ooooo`;o000000Coooooo`000?oooooo00001_ooool3o`000;[ooooo
002@ooooo`05o`000?ooooooooooooooool000002_ooool2o`000004oiRHV?l0003oV9RHob4Q8@Ko
oooo00?o0000ooooooooool0^_ooool0093ooooo00Go0000ooooooooooooooooo`00000:ooooo`;o
000000CoEEEEo`000?l@413oc<c<1_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413o
oooooooooooooooo410@00[ooooo00?o0000oeEEEOl000002Oooool00ol0003oooooooooo`2joooo
o`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00Co0000omgMgOl0003oV9RH2?ooool0
0ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo00Ko0000
ooooool0003oA4A4o`000?l@4106ooooo`03o`000?oooooooooo0;[ooooo002Oooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooooooool0^_ooool009oooooo00?o0000ooooool000002Oooool0
0ol0003oooooooooo`2jooooo`00X?ooool2o`0000Wooooo00?o0000ooooooooool0^_ooool00:3o
oooo0_l00009ooooo`03o`000?oooooooooo0;[ooooo002Pooooo`;o00002Oooool2o`000;_ooooo
002Pooooo`;o00002Oooool00ol0003oooooooooo`2jooooo`00X?ooool2o`0000Wooooo00?o0000
ooooooooool0^_ooool00:3ooooo0_l00009ooooo`03o`000?oooooooooo0;[ooooo002Pooooo`;o
00002Oooool00ol0003oooooooooo`2jooooo`00X?ooool2o`0000Wooooo00?o0000ooooooooool0
^_ooool00:3ooooo0_l00009ooooo`03o`000?oooooooooo0;[ooooo002Pooooo`;o00002Oooool0
0ol0003oooooooooo`2jooooo`00X?ooool2o`0000Wooooo00?o0000ooooooooool0^_ooool00:3o
oooo0_l00009ooooo`;o0000^oooool00:3ooooo0_l00009ooooo`03o`000?oooooooooo0;[ooooo
002Pooooo`;o00002Oooool00ol0003oooooooooo`2jooooo`00X?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ
8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`2jooooo`00T?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P06ooooo`?o0000^_ooool0093ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<
c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooo
oooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo
0;[ooooo002@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o
000000Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00XOooool4
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0^_ooool00:?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`2jooooo`00Xoooool00ol0003oooooooooo`05ooooo`?o
0000^_ooool00:?ooooo00?o0000ooooooooool0`_ooool00:?ooooo00?o0000ooooooooool0`_oo
ool00:?ooooo00?o0000ooooooooool0`_ooool00:?ooooo00?o0000ooooooooool0`_ooool00:7o
oooo00?oEEEEofIVI_l00000a?ooool00?ooooooJOooool006gooooo00?oMgMgofIVI_ooool00ooo
ool00ol0003oooooooooo`03ooooo`03okZj^_lb<S;ooooo00Kooooo0_l0000;ooooo`03o`000?nj
^[[ooooo00cooooo0_l00008ooooo`06o`000?oooooooooooooooomVIVKoMgMg3_ooool00ol0003o
^[Zjooooo`2Yooooo`00K?ooool00ooMgMgo410@onk^kP04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003ooooo
ooooo`06ooooo`07o`000?ooooooooooooooooo^k^ko410@omgMg@0=ooooo`;o<S8bZ_ooool006co
oooo00?oEEEEoiRHV?ooool01?ooool00ol0003oooooooooo`02ooooo`05oiRHV?l@413o0000o`00
0?nYZJT01Oooool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000;ooooo00?oQhN7o`00
0?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`02ooooo`03ohN7QomVIVKooooo00cooooo00?oQhN7o`000?nj^[X03?ooool0
1OnHV9So0000o`000?m4A4Co^[Zj017ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4QO?oo
ool006cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`06o`000?nYZJWo
EEEEoiRHV?mEEEGo^[Zj1?ooool00ol0003oooooooooo`02ooooo`06onk^k_lQ8B7oQhN7okZj^_l0
003ogMgM0_ooool00oo<c<co0000oa0@4005ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?ok^k^o`000?ooool03?ooool0
0oo<c<co0000oa0@400<ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l0000<ooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B5looooo`00K?ooool00olb<S;oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00Ko<S8bonk^k_nHV9SoEEEEomgMgOl@4104ooooo`03o`000?oooooooooo00?o
oooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0P_ooool006cooooo00?o<S8booooooooool01?ooool00ol0003o
ooooooooo`02ooooo`07okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c003ooooo`03o`000?oooooo
oooo00?ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00?ooooo1_l0000<ooooo`03o`000?oooooooooo08;ooooo001/ooooo`03o`000?o^k^ko
oooo00Cooooo00?o0000ooooooooool00_ooool01oo^k^ko0000ooooool0003oooooofIVI_n7QhL0
0oooool00ol0003oooooooooo`03ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?ok^k^o`000?oo
ool06oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo08;ooooo001/ooooo`03oeEE
EOmgMgOooooo00Cooooo00?o0000ooooooooool00_ooool01?mVIVKoV9RHoooooolb<S82okZj^P05
o`000?ooooooooooooooool000001?ooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o0000
00?o00001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?oMgMgoeEE
EOooool00oooool4o`0001;ooooo00?o410@o`000?l000000ol0000Dooooo`03o`000?oooooooooo
08;ooooo001/ooooo`03omgMgOl@413ok^k^00Cooooo00?o0000ooooooooool01Oooool00omVIVKo
QhN7ooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`07o`000?ooooooooooooooooo^k^ko410@omgMg@05ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`22ooooo`00KOooool00omg
MgOoIVIVooooo`03ooooo`03o`000?oooooooooo00Gooooo00?oZJVYodA4A?ooool01?ooool2o`00
01?ooooo00?o0000ooooooooool01?ooool2o`0000Sooooo00Ko0000ooooooooooooooooofIVI_mg
MgL7ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00omEEEGoIVIVo`00
0024ooooo`00]_ooool00ol0003oooooooooo`2_ooooo`00/oooool01?l0003oooooooooool0002a
ooooo`00]?ooool2o`000;;ooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.8522, -0.080387, \
0.130126, 0.00668404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
176.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.03279 0 L
.03405 0 L
.03477 0 L
.03543 0 L
.03665 0 L
.03793 0 L
.03908 0 L
.04016 0 L
.04144 0 L
.04262 0 L
.04384 0 L
.04501 0 L
.04624 0 L
.04693 0 L
.04758 0 L
.04827 0 L
.04892 0 L
.05014 0 L
.05146 0 L
.0522 0 L
.05288 0 L
.05403 0 L
.0551 0 L
.05627 0 L
.05753 0 L
.05885 0 L
.0601 0 L
.06123 0 L
.06244 0 L
.06369 0 L
.06486 0 L
.06554 0 L
.06625 0 L
.06753 0 L
.06817 0 L
.06886 0 L
.07011 0 L
.07087 0 L
.07158 0 L
.07222 0 L
.07293 0 L
.0741 0 L
.07535 0 L
.0765 0 L
.07758 0 L
.07885 0 L
.08001 0 L
.08065 0 L
.08135 0 L
Mistroke
.08263 0 L
.08334 0 L
.08412 0 L
.0848 0 L
.08552 0 L
.08617 0 L
.08689 0 L
.08814 0 L
.0889 0 L
.08961 0 L
.09043 0 L
.09118 0 L
.09256 0 L
.09325 0 L
.09402 0 L
.09467 0 L
.09538 0 L
.09665 0 L
.09792 0 L
.09908 0 L
.09975 0 L
.10047 0 L
.10176 0 L
.10247 0 L
.10311 0 L
.10382 0 L
.10458 0 L
.10578 0 L
.1069 0 L
.10758 0 L
.10823 0 L
.10944 0 L
.11072 0 L
.11191 0 L
.11321 0 L
.11386 0 L
.11459 0 L
.11578 0 L
.11687 0 L
.11807 0 L
.11934 0 L
.12037 0 L
.12147 0 L
.12268 0 L
.1238 0 L
.12448 0 L
.1252 0 L
.12649 0 L
.12721 0 L
.12788 0 L
Mistroke
.12862 0 L
.12941 0 L
.13009 0 L
.13083 0 L
.13148 0 L
.13217 0 L
.13348 0 L
.1347 0 L
.13599 0 L
.13671 0 L
.13738 0 L
.13861 0 L
.1399 0 L
.14106 0 L
.14215 0 L
.14334 0 L
.14461 0 L
.14583 0 L
.14653 0 L
.14718 0 L
.14849 0 L
.14923 0 L
.1499 0 L
.15104 0 L
.15229 0 L
.15359 0 L
.1548 0 L
.15549 0 L
.15624 0 L
.15695 0 L
.1576 0 L
.15884 0 L
.16015 0 L
.16083 0 L
.16156 0 L
.16288 0 L
.16368 0 L
.16444 0 L
.16512 0 L
.16587 0 L
.16653 0 L
.16724 0 L
.16853 0 L
.16978 0 L
.17093 0 L
.17218 0 L
.17289 0 L
.17355 0 L
.17425 0 L
.17489 0 L
Mistroke
.17558 0 L
.17631 0 L
.17756 0 L
.1787 0 L
.17934 0 L
.18004 0 L
.18129 0 L
.18246 0 L
.18353 0 L
.18479 0 L
.18599 0 L
.18724 0 L
.18789 0 L
.18858 0 L
.18985 0 L
.19102 0 L
.19207 0 L
.19319 0 L
.19442 0 L
.19558 0 L
.19689 0 L
.19763 0 L
.19832 0 L
.19958 0 L
.20022 0 L
.20092 0 L
.20211 0 L
.20323 0 L
.20388 0 L
.20457 0 L
.20579 0 L
.20694 0 L
.20799 0 L
.2092 0 L
.21034 0 L
.21457 0 L
.22418 0 L
.22542 0 L
.22659 0 L
.22724 0 L
.22795 0 L
.22919 0 L
.23037 0 L
.23163 0 L
.23282 0 L
.23389 0 L
.2351 0 L
.23641 0 L
.23755 0 L
.23879 0 L
Mistroke
.2395 0 L
.24016 0 L
.24091 0 L
.2416 0 L
.24284 0 L
.24353 0 L
.24418 0 L
.24533 1e-05 L
.24641 1e-05 L
.24753 1e-05 L
.24877 1e-05 L
.24984 1e-05 L
.25082 1e-05 L
.25189 1e-05 L
.25302 1e-05 L
.25417 1e-05 L
.2554 1e-05 L
.25656 1e-05 L
.25761 1e-05 L
.25877 1e-05 L
.26 1e-05 L
.26071 1e-05 L
.26136 1e-05 L
.26263 1e-05 L
.26376 1e-05 L
.26496 1e-05 L
.26627 1e-05 L
.26749 1e-05 L
.26874 1e-05 L
.26946 1e-05 L
.27013 1e-05 L
.27133 2e-05 L
.27263 3e-05 L
.27384 4e-05 L
.27497 4e-05 L
.27615 4e-05 L
.27743 5e-05 L
.27855 5e-05 L
.27956 5e-05 L
.28074 6e-05 L
.28184 6e-05 L
.28304 7e-05 L
.28436 7e-05 L
.28503 7e-05 L
.28574 6e-05 L
.28703 5e-05 L
.28831 5e-05 L
.28953 4e-05 L
.29063 5e-05 L
.29182 5e-05 L
Mistroke
.29325 6e-05 L
.29454 7e-05 L
.29526 8e-05 L
.29603 9e-05 L
.29676 .00011 L
.29744 .00012 L
.29865 .00016 L
.29997 .00022 L
.30136 .00028 L
.30265 .00033 L
.30387 .00037 L
.30516 .0004 L
.30646 .00041 L
.3072 .00041 L
.30789 .00042 L
.30914 .00042 L
.31028 .00041 L
.31154 .00039 L
.31286 .00035 L
.31501 .00025 L
.31619 .0002 L
.31731 .00017 L
.31863 .00017 L
.31982 .00021 L
.32095 .00027 L
.32217 .00037 L
.32347 .00051 L
.32468 .00068 L
.32745 .00119 L
.32895 .00154 L
.33038 .00185 L
.33166 .00209 L
.33238 .00219 L
.33305 .00225 L
.33428 .0023 L
.33539 .00226 L
.33668 .00214 L
.33789 .00197 L
.34039 .00147 L
.3418 .00114 L
.34308 .00086 L
.34431 .00066 L
.34547 .00058 L
.34669 .00068 L
.34738 .00083 L
.34802 .00103 L
.34908 .00151 L
.35025 .00223 L
.35262 .00413 L
.35521 .00651 L
Mistroke
.35665 .00779 L
.35801 .00886 L
.35927 .00961 L
.35999 .00989 L
.36065 .01004 L
.36182 .01001 L
.36307 .00953 L
.36376 .00907 L
.36449 .00844 L
.3658 .00706 L
.36733 .00521 L
.36876 .00355 L
.36999 .00238 L
.37131 .00161 L
.37207 .00146 L
.37278 .00154 L
.37342 .00183 L
.37412 .00238 L
.37532 .00396 L
.376 .00523 L
.37664 .00668 L
.37933 .01496 L
.38182 .02426 L
.38304 .02844 L
.38415 .03163 L
.38531 .03409 L
.38641 .03541 L
.38757 .03563 L
.38883 .03448 L
.39013 .03182 L
.39078 .02996 L
.3915 .02755 L
.39397 .01738 L
.39529 .01168 L
.39654 .00702 L
.39723 .00506 L
.39799 .00361 L
.39931 .00322 L
.40056 .00587 L
.40127 .00872 L
.4019 .01217 L
.40314 .02108 L
.40431 .03178 L
.40863 .07944 L
.40969 .08965 L
.41081 .0985 L
.41205 .10487 L
.4132 .10699 L
.41384 .10642 L
.41455 .1043 L
Mistroke
.41582 .09658 L
.41706 .08476 L
.41821 .07095 L
.42045 .04072 L
.42167 .0256 L
.42281 .01442 L
.42397 .00725 L
.42523 .00552 L
.4263 .00976 L
.42745 .0204 L
.4281 .02919 L
.4288 .04088 L
.43007 .06729 L
.43245 .12929 L
.43474 .1908 L
.43599 .21834 L
.43716 .23677 L
.43815 .24542 L
.43922 .24657 L
.44041 .23771 L
.44149 .22081 L
.44656 .07908 L
.44794 .04305 L
.44872 .02757 L
.44942 .01738 L
.45007 .01166 L
.45078 .01014 L
.45207 .02095 L
.45328 .04803 L
.45397 .0705 L
.45462 .09565 L
.4573 .23084 L
.45963 .34896 L
.46081 .39232 L
.4621 .41993 L
.46275 .42491 L
.46345 .42362 L
.46472 .40519 L
.46598 .37018 L
.46713 .32885 L
.46975 .22861 L
.47113 .18316 L
.4726 .14497 L
.47331 .13045 L
.47398 .11901 L
.47523 .10286 L
.47641 .09293 L
.47768 .08664 L
.47891 .08382 L
.4802 .08326 L
Mistroke
.4813 .08406 L
.48252 .0857 L
.4849 .08958 L
.48715 .0927 L
.4884 .09398 L
.48905 .09452 L
.48975 .09498 L
.49098 .09547 L
.49212 .09549 L
.49318 .09501 L
.49432 .09384 L
.4954 .09202 L
.49639 .08969 L
.49868 .08208 L
.50109 .07248 L
.50233 .06805 L
.50297 .06609 L
.50366 .06439 L
.50493 .06246 L
.50609 .06223 L
.50721 .06343 L
.50825 .06572 L
.5094 .06932 L
.51063 .07408 L
.51337 .08552 L
.51471 .09034 L
.51596 .09362 L
.51709 .09528 L
.51829 .09542 L
.51898 .09466 L
.51962 .09338 L
.52083 .08948 L
.52506 .06361 L
.52739 .04719 L
.52853 .04048 L
.52959 .03558 L
.53084 .03161 L
.53149 .03028 L
.53219 .02936 L
.53332 .02874 L
.53456 .02882 L
.53574 .02915 L
.53698 .02937 L
.53804 .02935 L
.5392 .02916 L
.54037 .02894 L
.54163 .02884 L
.54234 .02888 L
.54298 .02897 L
.54425 .02923 L
Mistroke
.54542 .02942 L
.54668 .02941 L
.54788 .02915 L
.54898 .02874 L
.55931 .02515 L
.57779 .0188 L
.59819 .01137 L
.60815 .00831 L
.61724 .00619 L
.626 .00454 L
.63554 .00304 L
.64078 .00235 L
.64562 .00185 L
.65061 .00144 L
.65518 .00112 L
.6598 .00089 L
.66218 .0008 L
.66479 .00067 L
.66589 .00063 L
.66706 .00059 L
.66817 .00057 L
.66918 .00055 L
.67157 .00049 L
.67382 .00041 L
.675 .00038 L
.67631 .00036 L
.67697 .00035 L
.67767 .00035 L
.67895 .00033 L
.68022 .00031 L
.68143 .00028 L
.68262 .00025 L
.68369 .00024 L
.68498 .00022 L
.68569 .00021 L
.68635 .00021 L
.68882 .00019 L
.69021 .00017 L
.69098 .00016 L
.69171 .00015 L
.69239 .00014 L
.69312 .00013 L
.69441 .00012 L
.69907 9e-05 L
.70418 7e-05 L
.70482 7e-05 L
.70552 6e-05 L
.70678 6e-05 L
.70809 5e-05 L
.70878 4e-05 L
Mistroke
.70954 4e-05 L
.7108 4e-05 L
.71149 4e-05 L
.71213 4e-05 L
.71327 3e-05 L
.7145 3e-05 L
.71689 2e-05 L
.71754 2e-05 L
.71824 2e-05 L
.71948 2e-05 L
.72064 2e-05 L
.72172 2e-05 L
.7229 2e-05 L
.72418 1e-05 L
.72531 1e-05 L
.72654 1e-05 L
.7277 1e-05 L
.72878 1e-05 L
.72984 1e-05 L
.73081 1e-05 L
.73192 1e-05 L
.73297 1e-05 L
.73414 0 L
.73539 0 L
.73657 0 L
.73765 0 L
.73891 0 L
.73962 0 L
.74028 0 L
.74149 0 L
.74277 0 L
.74399 0 L
.74531 0 L
.74655 0 L
.74769 0 L
.74837 0 L
.74901 0 L
.74972 0 L
.75046 0 L
.75118 0 L
.75185 0 L
.7531 0 L
.75418 0 L
.75534 0 L
.75643 0 L
.75742 0 L
.75854 0 L
.75959 0 L
.76074 0 L
.76198 0 L
Mistroke
.76324 0 L
.76388 0 L
.76458 0 L
.76582 0 L
.76699 0 L
.76814 0 L
.7692 0 L
.77037 0 L
.77159 0 L
.77282 0 L
.77352 0 L
.77416 0 L
.77534 0 L
.77659 0 L
.7777 0 L
.77875 0 L
.77989 0 L
.78113 0 L
.78244 0 L
.78369 0 L
.78491 0 L
.78604 0 L
.78673 0 L
.78738 0 L
.7886 0 L
.78991 0 L
.79064 0 L
.79132 0 L
.79239 0 L
.79353 0 L
.7946 0 L
.79558 0 L
.79673 0 L
.79798 0 L
.79916 0 L
.80025 0 L
.80138 0 L
.80243 0 L
.80358 0 L
.80483 0 L
.80606 0 L
.80736 0 L
.80847 0 L
.80968 0 L
.81033 0 L
.81101 0 L
.81223 0 L
.81354 0 L
.81428 0 L
.81498 0 L
Mistroke
.81622 0 L
.81739 0 L
.81804 0 L
.81874 0 L
.81998 0 L
.82109 0 L
.82233 0 L
.82362 0 L
.82483 0 L
.82595 0 L
.82699 0 L
.82821 0 L
.82932 0 L
.83054 0 L
.83184 0 L
.83305 0 L
.83419 0 L
.83484 0 L
.83552 0 L
.83675 0 L
.83807 0 L
.83882 0 L
.83952 0 L
.84019 0 L
.84091 0 L
.84223 0 L
.84351 0 L
.84471 0 L
.84543 0 L
.84612 0 L
.8474 0 L
.84808 0 L
.84879 0 L
.84956 0 L
.85028 0 L
.8515 0 L
.85219 0 L
.85283 0 L
.854 0 L
.85524 0 L
.85635 0 L
.85739 0 L
.85853 0 L
.85976 0 L
.86099 0 L
.86169 0 L
.86234 0 L
.86307 0 L
.86377 0 L
.86506 0 L
Mistroke
.86619 0 L
.86741 0 L
.86872 0 L
.86992 0 L
.87097 0 L
.87196 0 L
.87311 0 L
.87416 0 L
.87531 0 L
.87657 0 L
.87774 0 L
.87883 0 L
.88006 0 L
.88122 0 L
.88227 0 L
.88339 0 L
.88463 0 L
.88593 0 L
.88704 0 L
.88825 0 L
.88956 0 L
.89077 0 L
.89146 0 L
.8921 0 L
.89277 0 L
.89351 0 L
.89476 0 L
.89591 0 L
.89717 0 L
.89849 0 L
.8996 0 L
.9008 0 L
.90192 0 L
.90294 0 L
.90414 0 L
.90544 0 L
.90667 0 L
.9078 0 L
.90901 0 L
.91031 0 L
.91154 0 L
.91265 0 L
.91396 0 L
.91465 0 L
.91539 0 L
.91603 0 L
.91673 0 L
.91798 0 L
.91866 0 L
.91937 0 L
Mistroke
.92065 0 L
.92136 0 L
.92202 0 L
.92279 0 L
.92352 0 L
.92484 0 L
.92604 0 L
.92733 0 L
.92806 0 L
.92873 0 L
.92988 0 L
.93113 0 L
.9323 0 L
.9334 0 L
.93467 0 L
.93538 0 L
.93602 0 L
.93725 0 L
.93841 0 L
.93952 0 L
.94068 0 L
.94168 0 L
.94277 0 L
.94394 0 L
.9452 0 L
.94631 0 L
.94748 0 L
.94813 0 L
.94886 0 L
.95013 0 L
.95085 0 L
.95162 0 L
.95235 0 L
.95302 0 L
.95366 0 L
.95435 0 L
.95558 0 L
.95686 0 L
.9576 0 L
.95827 0 L
.95953 0 L
.9607 0 L
.96198 0 L
.96262 0 L
.96333 0 L
.96452 0 L
.9658 0 L
.96701 0 L
.96811 0 L
.96908 0 L
Mistroke
.97012 0 L
.97109 0 L
.97198 0 L
.97302 0 L
.97415 0 L
.97521 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`0Rooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00GoA4A4o`000?l0003o<S8bomgMg@1Gooooo`05odA4A?l0003o0000oc8b<_oMgMd09oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo02Gooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool09?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00omgMgOo<S8booooo`1Iooooo`03ogMgMolb<S;ooooo02Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Uooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool6o`0000Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[
ooooo`03ogMgMolb<S;ooooo05Wooooo00?oMgMgoc8b<_ooool0:?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo02Gooooo000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0Eoooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001Wooooo
00?oEEEEofIVI_l000001Oooool4o`0002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo1?l0001Hooooo`Co0000:?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool00omEEEGoIVIVo`000005ooooo`Co00009oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooC_ooool2o`0000;ooooo0_l0000Eooooo`00oooooom>
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5Oooool00?ooooooCoooool01?oMgMgo0000oa0@
4?o<c<`Fooooo`005?ooooooo`00033o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hFooooo`006ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`03ooooo`Go000000?oooooo`000?l000001?ooool3o`0000Kooooo0ol0
0009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooo000000Ko000000?oooooo`000?ooool02?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0@ooooo`04ob4Q8OmgMgOoMgMgoc8b<QKooooo000Kooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool0;Oooool01Ol0003ooooooooooooooooo000000;ooooo0_l000000ooooooo0000
o`000005ooooo`;o00001_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01oooooo
1_l00008ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0?ooooo`;o00000_ooool2o`0001Gooooo0020ooooo`?o00000oooool00ol0003ooooooooo
o`03ooooo`;o00001_ooool2o`0000Kooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Mooooo`;o0000Voooool008Kooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000006
ooooo`;o00001_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01[ooooo0ol0002M
ooooo`00Q_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Kooooo0_l00006oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool05oooool3o`000:3ooooo0026ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool2o`0000Kooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Dooooo`?o0000Xoooool008Oooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Gooooo0_l0000>oooo
o`03o`000?oooooooooo017ooooo0ol0002Vooooo`00Qoooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooool000001Oooool2o`0000kooooo00?o0000oooo
ooooool03_ooool3o`000:Wooooo0028ooooo`03o`000?oooooo000000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooo`000005ooooo`;o00003_ooool00ol0003oooooooooo`07ooooo`Oo
0000[?ooool008Sooooo00?o0000ooooool000000oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooo000000Gooooo0_l0000>ooooo`;o00001oooool00ol0003oooooooooo`2aooooo`00ROoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001Ooo
ool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0/Ooo
ool008kooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000005ooooo`03o`000?oooooo
000000gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2aooooo`00S_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooo000000Gooooo00?o0000ooooool000003Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0;7ooooo002>ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooool000001Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0/_ooool008kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
o`000005ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2booooo`00S_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Gooooo00?o
0000ooooool000003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo002>
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001Oooool00ol0003oooooo`00000=
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool008oooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2booooo`00Soooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000003Oooool3o`0000Gooooo00?o0000
ooooooooool0/_ooool008oooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooo000000gooooo0ol00005ooooo`03o`000?oooooooooo0;;ooooo002?oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000=
ooooo`;o000000?oooooo`000?ooool00oooool00ol0003oooooooooo`2booooo`00Soooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000003Oooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo0;?ooooo002?ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000=ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool0/oooool008oooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000gooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`2cooooo`00Soooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`2cooooo`00T?ooool00ol0003o
ooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001_ooool3o`0000Co
oooo00Oo0000ooooooooooooooooo`000?oooooo00000;Kooooo002@ooooo`03o`000?oooooo0000
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo0000
00?ooooo0_l00003ooooo`03o`000?oooooo00000;Kooooo002@ooooo`03o`000?oooooo000000?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooo`000006ooooo`04o`000?ooooooooooo`00
00;ooooo0ol00003ooooo`;o0000]_ooool0093ooooo00?o0000ooooool000000oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool00ol000000ooooooo
0000ooooo`03ooooo`;o0000]_ooool0093ooooo00?o0000ooooool000000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2jooooo`00T?ooool2o`0000Gooooo00Oo0000ooooooooooooooooo`000?oooooo000000Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2jooooo`00T?ooool2o`0000Gooooo
00Oo0000ooooooooooooooooo`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`2jooooo`00TOooool00ol0003oooooooooo`03ooooo`07o`000?oooooooooooooo
ool0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^_ooool0
09Oooooo00Oo0000ooooooooooooooooo`000?oooooo000000Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00Oo
0000oooooooooooo8B4Qo`000?oooooo000000;ooooo1Ol00006ooooo`03o`000?oooooooooo0;[o
oooo002@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool01ol0003oooooooooool0003o8B4Q
ooooool000000_ooool01OnHV9So8B4Qonk^k_l0003oA4A400Kooooo00?o0000ooooooooool0^_oo
ool0093ooooo00Go410@oooooooooooooooooa0@4002ooooo`04o`000?ooooooooooo`0000;ooooo
00Oo0000oooooooooooooooooiRHV?lQ8B7o000000Oooooo00?o0000ooooooooool0^_ooool0093o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00_ooool00onHV9So0000onk^kP06ooooo`?o0000^_ooool0093ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00ooo
ool00ol0003oIVIVooooo`05ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05oa0@4?oooooo
ooooooooool@41000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo
0_l00006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0_ooool01?l0003oooooooooool00002ooooo`08o`000?ooooooooooo`000?nj^[[oooooo`000?l@
4106ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_oo
ool01?l0003oooooooooool00002ooooo`05o`000?oooooooooooiRHV?l@41000_l000000oo<c<co
ooooooooo`04ooooo`03o`000?oooooooooo0;[ooooo002Gooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;[o
oooo002Gooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0;[ooooo002Gooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;[o
oooo002Gooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0;[ooooo002Gooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`;o0000^oooool009Oooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0^_ooool009Oooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^_ooool009Oooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0^_ooool009Oooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool0^_ooool009Oooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0^_ooool0
09Oooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool0^_ooool009Oooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0^_ooool009Oooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0^_ooool009Oooooo
00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000Sooooo0_l0002koooo
o`00Uoooool00ol0003oooooo`000004ooooo`05o`000?ooooooooooooooool000002?ooool00ol0
003oooooooooo`2jooooo`00Uoooool00ol0003oooooo`000004ooooo`05o`000?oooooooooooooo
ool000002?ooool00ol0003oooooooooo`2jooooo`00Uoooool00ol0003oooooo`000004ooooo`05
o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`2jooooo`00Uoooool00ol0003o
ooooo`000004ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`2joooo
o`00Uoooool00ol0003oooooo`000004ooooo`05o`000?ooooooooooooooool000002?ooool00ol0
003oooooooooo`2jooooo`00Uoooool00ol0003oooooo`000004ooooo`05o`000?oooooooooooooo
ool000002?ooool00ol0003oooooooooo`2jooooo`00V?ooool2o`0000Cooooo00Go0000oooooooo
ooooooooo`000008ooooo`03o`000?oooooooooo0;[ooooo002Hooooo`;o00001?ooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool0^_ooool009Sooooo0_l00004ooooo`05
o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`2jooooo`00V?ooool2o`0000Co
oooo00Go0000ooooooooooooooooo`000008ooooo`;o0000^oooool009Sooooo0_l00004ooooo`05
o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`2jooooo`00V?ooool2o`0000Co
oooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0;[ooooo002Hooooo`;o
00001?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0^_ooool009So
oooo0_l00004ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`2joooo
o`00V?ooool2o`0000Cooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo
0;[ooooo002@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2o`0000;o8B4Q0_ooool01?l0
003oooooooooooooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool0
093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o00000_lQ8B42ooooo`04o`000?oooooo
ooooooooo`;o00001oooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooo
oooo410@00?ooooo0_l00004ooooo`03o`000?oooooo000000Co00001_ooool00ol0003ooooooooo
o`2jooooo`00T?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_oo
ool01?l0003oooooodA4A?oMgMd2o`0000Oooooo0ol0002jooooo`00T?ooool01Ol0003ooooooooo
oooooooo000000Wooooo00Co0000oooooooMgMgoEEEE0_l00007ooooo`03o`000?oooooooooo0;[o
oooo002@ooooo`05oa0@4?ooooooooooooooool@41002Oooool01?l0003ooooooooooomgMgL2o`00
00Oooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09oooo
o`04o`000?ooooooooooonk^kP;o00001oooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Wooooo00Co0000oooooooooooooooo0_l00007ooooo`03o`000?oo
oooooooo0;[ooooo002Nooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooooooo
o`2jooooo`00W_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0^_oo
ool009kooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0;[ooooo002N
ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`2jooooo`00W_ooool0
1Ol0003ooooooooooooooooo000000Sooooo0_l0002kooooo`00W_ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo0;[ooooo002Nooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool0^_ooool009kooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`2jooooo`00W_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo0;[ooooo002O
ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0^_ooool009oooooo00?o0000oooo
ool000002Oooool00ol0003oooooooooo`2jooooo`00Woooool00ol0003oooooo`000009ooooo`03
o`000?oooooooooo0;[ooooo002Oooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0
^_ooool009oooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`2jooooo`00Woooool0
0ol0003oooooo`000009ooooo`;o0000^oooool009oooooo00?o0000ooooool000002Oooool00ol0
003oooooooooo`2jooooo`00Woooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo0;[o
oooo002Oooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0^_ooool009oooooo00?o
0000ooooool000002Oooool00ol0003oooooooooo`2jooooo`00Woooool00ol0003oooooo`000009
ooooo`03o`000?oooooooooo0;[ooooo002Oooooo`03o`000?oooooo000000Wooooo00?o0000oooo
ooooool0^_ooool009oooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`2jooooo`00
Woooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo0;[ooooo002Oooooo`03o`000?oo
oooo000000Wooooo0_l0002kooooo`00Woooool00ol0003oooooo`000009ooooo`03o`000?oooooo
oooo0;[ooooo002Oooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0^_ooool009oo
oooo00?o0000ooooool000002Oooool00ol0003oooooooooo`2jooooo`00Woooool00ol0003ooooo
o`000009ooooo`03o`000?oooooooooo0;[ooooo002Oooooo`03o`000?oooooo000000Wooooo00?o
0000ooooooooool0^_ooool009oooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`2j
ooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B43ooooo`06o`000?o^k^ko
0000o`000?l@413oc<c<1_ooool00ol0003oooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B43ooooo`06o`000?mEEEGo0000oooooonHV9So8B4Q1_ooool00ol0
003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo410@00[ooooo0ol00002oooo
o`03o`000?oooooooooo00Cooooo0ol0002jooooo`00T?ooool01Ol0003ooooooooooooooooo0000
00[ooooo0ol000000oooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05
o`000?ooooooooooooooool000002_ooool4o`000003oa0@4?o<c<cooooo00Gooooo00?o0000oooo
ooooool0^_ooool0093ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?mEEEGo0000
00Wooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:oooo
o`04o`000?oMgMgo0000oiRHV0Sooooo00?o0000ooooooooool0^_ooool0093ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0:ooooo`06o`000?oooooo0000odA4A?l0003o410@1_ooool00ol0003ooooo
ooooo`2jooooo`00Woooool2o`0000[ooooo00?o0000ooooooooool0^_ooool009oooooo0_l0000:
ooooo`03o`000?oooooooooo0;[ooooo002Oooooo`;o00002_ooool00ol0003oooooooooo`2joooo
o`00Woooool2o`0000[ooooo00?o0000ooooooooool0^_ooool009oooooo0_l0000:ooooo`;o0000
^oooool009oooooo0_l0000:ooooo`03o`000?oooooooooo0;[ooooo002Pooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0^_ooool00:3ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`2jooooo`00X?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0;[o
oooo002Pooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0^_ooool00:3ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`2jooooo`00X?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o
0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002koooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0
003oooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo0;[ooooo002@ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooo
oonHV9So<S8b00Kooooo0ol0002jooooo`00T?ooool01Ol0003ooooooooooooooooo000000_ooooo
00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000oooo
ooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
okZj^_l000001_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^ooo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002Q
ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2jooooo`00Xoooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0;[ooooo002Sooooo`03o`000?oooooooooo00Go
oooo0ol0002jooooo`00Xoooool00ol0003oooooooooo`32ooooo`00Xoooool00ol0003ooooooooo
o`32ooooo`00Xoooool00ol0003oooooooooo`32ooooo`00Xoooool00ol0003oooooooooo`32oooo
o`00XOooool00omEEEGoIVIVo`000034ooooo`00oooooomYooooo`00JOooool00omgMgOoIVIVoooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o^[Zjoc8b<_ooool01oooool2o`0000_ooooo00?o
0000okZj^_ooool03?ooool2o`0000Oooooo00?o0000ooooooooool00_ooool00omVIVKoMgMgoooo
o`0<ooooo`03o`000?nj^[[ooooo0:gooooo001Xooooo`03omgMgOl@413ok^k^00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00oo^k^ko410@omgMg@0<
ooooo`;o<S8b[_ooool006Sooooo00?oEEEEoiRHV?ooool01Oooool01_l0003ooooooooooooooooo
V9RHoa0@40;o000000?oZJVYooooooooool01?ooool01?l0003oooooooooooooool2o`0000;ooooo
0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00on7QhOoIVIVooooo`0;ooooo`03
ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Aooooo`Co000000?o410@oooo
ooooool00_ooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`1dooooo`00J?ooool00ol0003o
ooooooooo`05ooooo`0:o`000?ooooooooooooooool0003oZJVYoeEEEOnHV9SoEEEEokZj^PGooooo
00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@
4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?ok^k^o`000?ooool02oooool00oo<c<co0000oa0@400<ooooo`06oa0@
4?nj^[[ok^k^ogMgMol@413ooooo1_l0000<ooooo`03o`000?oooooooooo00Cooooo0_lQ8B47oooo
o`03o`000?oooooooooo07Kooooo001Xooooo`03oc8b<_oooooooooo00Gooooo00[o0000oooooooo
oooooooooc8b<_o^k^koV9RHoeEEEOoMgMgo410@1Oooool00ol0003oooooooooo`02ooooo`04omgM
gOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0M_ooool006Sooooo00?o<S8booooooooool0
1Oooool02ol0003ooooooooooooooooo^[ZjodA4A?o<c<co8B4Qooooool@413oc<c<00Cooooo00?o
0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool00oooool6o`0000cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`1fooooo`00J?ooool00ol0003ok^k^ooooo`05ooooo`0;o`000?ooooooooooooooooo^k^ko
0000ooooool0003oooooofIVI_n7QhL01?ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOo
MgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?ok^k^o`000?ooool06_ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0M_ooool006Sooooo00?oEEEEogMgMoooool01Oooool0
2?l0003oooooooooooooooooIVIVoiRHV?oooooo<S8b0_nj^[X00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00omgMgOoEEEEooooo`02oooo
o`Co00004_ooool00ol@413o0000o`000003o`0001Cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`1fooooo`00J?ooool00ooMgMgo410@onk^kP05ooooo`03o`000?oooooooooo00Co
oooo00?oIVIVohN7Qoooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03onk^k_l@413ogMgM00Co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0M_ooool006Wooooo00?oMgMgofIVI_ooool01?ooool00ol0003ooooo
ooooo`04ooooo`03ojVYZOm4A4Cooooo00Gooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo
0_l00007ooooo`03o`000?oooooooooo00;ooooo00?oIVIVogMgMoooool01Oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?oEEEEofIVI_l000003Oooool00omEEEGoIVIV
o`00001hooooo`00/_ooool00ol0003oooooooooo`2cooooo`00[oooool01?l0003oooooooooool0
002eooooo`00/?ooool2o`000;Kooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.8522, -0.080387, \
0.130126, 0.00668404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
176.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03053 0 L
.03163 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03638 0 L
.03746 0 L
.03873 0 L
.03944 0 L
.04011 0 L
.04132 0 L
.04262 0 L
.04327 0 L
.04396 0 L
.04519 0 L
.04583 0 L
.04652 0 L
.04727 0 L
.04797 0 L
.04862 0 L
.04933 0 L
.05061 0 L
.05186 0 L
.05302 0 L
.05414 0 L
.05519 0 L
.05634 0 L
.05759 0 L
.05882 0 L
.06012 0 L
.06123 0 L
.06244 0 L
.06315 0 L
.06381 0 L
.06453 0 L
.06529 0 L
.06657 0 L
.06729 0 L
.06797 0 L
.06922 0 L
.0704 0 L
.07105 0 L
.07176 0 L
.073 0 L
Mistroke
.07376 0 L
.07448 0 L
.07513 0 L
.07583 0 L
.07659 0 L
.0773 0 L
.07804 0 L
.07885 0 L
.07956 0 L
.08021 0 L
.08091 0 L
.08167 0 L
.08237 0 L
.08301 0 L
.08427 0 L
.08544 0 L
.08669 0 L
.08787 0 L
.08896 0 L
.09016 0 L
.09148 0 L
.09214 0 L
.09285 0 L
.09413 0 L
.09483 0 L
.09548 0 L
.09619 0 L
.09695 0 L
.09821 0 L
.09893 0 L
.09961 0 L
.10084 0 L
.10201 0 L
.10265 0 L
.10335 0 L
.10458 0 L
.10579 0 L
.10691 0 L
.10813 0 L
.10942 0 L
.11054 0 L
.11159 0 L
.11273 0 L
.11396 0 L
.11467 0 L
.11531 0 L
.11659 0 L
.11775 0 L
.11897 0 L
.12029 0 L
Mistroke
.12152 0 L
.12223 0 L
.12288 0 L
.12362 0 L
.12433 0 L
.12501 0 L
.12565 0 L
.12685 0 L
.12814 0 L
.12881 0 L
.12954 0 L
.13076 0 L
.13206 0 L
.13326 0 L
.13437 0 L
.13505 0 L
.13579 0 L
.13645 0 L
.13714 0 L
.13845 0 L
.13966 0 L
.14096 0 L
.14169 0 L
.14236 0 L
.1431 0 L
.14389 0 L
.14464 0 L
.14533 0 L
.14657 0 L
.14722 0 L
.14791 0 L
.14906 0 L
.15034 0 L
.15147 0 L
.15269 0 L
.15384 0 L
.15488 0 L
.15618 0 L
.15739 0 L
.15871 0 L
.15945 0 L
.16012 0 L
.16135 0 L
.16204 0 L
.16268 0 L
.16385 0 L
.16509 0 L
.16623 0 L
.16728 0 L
.16848 0 L
Mistroke
.16962 0 L
.17068 0 L
.17165 0 L
.17272 0 L
.17385 0 L
.17499 0 L
.17621 0 L
.17737 0 L
.17842 0 L
.17966 0 L
.18031 0 L
.181 0 L
.18228 0 L
.18346 0 L
.1847 0 L
.1854 0 L
.18606 0 L
.18675 0 L
.18739 0 L
.18813 0 L
.18881 0 L
.19002 0 L
.19134 0 L
.1925 0 L
.19374 0 L
.19505 0 L
.19579 0 L
.19646 0 L
.1971 0 L
.19779 0 L
.19902 0 L
.19973 0 L
.20038 0 L
.20115 0 L
.20187 0 L
.2026 0 L
.20341 0 L
.20411 0 L
.20486 0 L
.20609 0 L
.20725 0 L
.20789 0 L
.20859 0 L
.20982 0 L
.21099 0 L
.21223 0 L
.2134 0 L
.21446 0 L
.21513 0 L
.21583 0 L
Mistroke
.21708 0 L
.21778 0 L
.21843 0 L
.21914 0 L
.21991 0 L
.22057 0 L
.22128 0 L
.22259 1e-05 L
.22503 1e-05 L
.22617 1e-05 L
.22724 1e-05 L
.22835 1e-05 L
.22956 1e-05 L
.2308 1e-05 L
.23211 1e-05 L
.23334 1e-05 L
.23445 1e-05 L
.23514 1e-05 L
.23577 1e-05 L
.23645 1e-05 L
.2372 1e-05 L
.23847 1e-05 L
.23916 1e-05 L
.23981 2e-05 L
.24097 2e-05 L
.24221 2e-05 L
.24286 2e-05 L
.24357 2e-05 L
.24483 2e-05 L
.24551 2e-05 L
.24623 2e-05 L
.24755 2e-05 L
.24821 2e-05 L
.2489 2e-05 L
.25013 3e-05 L
.25247 4e-05 L
.25497 4e-05 L
.25569 5e-05 L
.25638 5e-05 L
.25766 6e-05 L
.26016 8e-05 L
.26149 9e-05 L
.26215 9e-05 L
.26289 .0001 L
.26368 .0001 L
.26443 .0001 L
.26585 .0001 L
.26825 .00011 L
.26957 .00012 L
.27082 .00012 L
Mistroke
.27152 .00012 L
.27229 .00012 L
.27299 .00012 L
.27363 .00012 L
.27489 .00012 L
.27553 .00013 L
.27623 .00013 L
.27752 .00014 L
.2787 .00016 L
.28134 .00021 L
.2861 .00033 L
.28831 .00042 L
.28952 .00046 L
.29066 .0005 L
.29188 .00052 L
.29253 .00053 L
.29324 .00054 L
.29448 .00055 L
.29562 .00056 L
.2967 .00056 L
.29771 .00057 L
.29882 .00057 L
.30001 .00056 L
.30107 .00054 L
.30221 .00053 L
.30346 .00051 L
.30463 .00052 L
.30532 .00053 L
.30598 .00055 L
.30722 .00062 L
.30853 .00072 L
.30996 .00086 L
.31251 .00119 L
.31488 .0016 L
.31765 .00216 L
.31901 .0024 L
.32026 .00258 L
.32096 .00266 L
.3217 .00271 L
.32244 .00275 L
.32326 .00276 L
.32394 .00276 L
.32467 .00273 L
.32598 .00266 L
.32858 .00239 L
.32995 .00221 L
.3314 .00201 L
.33267 .00188 L
.33339 .00183 L
.33407 .00182 L
Mistroke
.33525 .0019 L
.33653 .00214 L
.33776 .00252 L
.3391 .00312 L
.34154 .0046 L
.34613 .00823 L
.34737 .00919 L
.34868 .01005 L
.34937 .0104 L
.35012 .01071 L
.35144 .01097 L
.35269 .0109 L
.35339 .01073 L
.35402 .01049 L
.35526 .00985 L
.35644 .00908 L
.35861 .00744 L
.3598 .00655 L
.36092 .00582 L
.36212 .00524 L
.36276 .00506 L
.36345 .005 L
.36467 .00528 L
.36579 .00606 L
.36708 .00766 L
.36781 .00891 L
.36849 .01027 L
.37104 .01699 L
.37398 .02635 L
.37536 .03059 L
.37665 .03409 L
.37777 .03654 L
.37898 .03835 L
.37967 .03892 L
.38033 .03912 L
.38156 .03855 L
.38285 .03662 L
.38404 .03372 L
.38676 .02462 L
.38794 .02041 L
.38923 .0164 L
.39044 .01356 L
.39156 .01209 L
.39257 .01193 L
.39367 .01318 L
.39483 .01624 L
.39591 .02078 L
.39718 .02813 L
.39837 .03694 L
.40062 .05691 L
Mistroke
.40302 .07935 L
.40438 .0904 L
.40566 .09843 L
.40686 .10329 L
.40816 .10517 L
.40884 .1047 L
.40954 .10311 L
.41081 .09762 L
.41199 .08972 L
.41309 .08039 L
.41558 .05516 L
.41698 .0411 L
.41767 .035 L
.41831 .03015 L
.4195 .02368 L
.42079 .02159 L
.42208 .02566 L
.42281 .03093 L
.42349 .03785 L
.42487 .05738 L
.42635 .0856 L
.42889 .14456 L
.43127 .19953 L
.43259 .22388 L
.43333 .23437 L
.43402 .24152 L
.43522 .2476 L
.4365 .24406 L
.43718 .23787 L
.43792 .22807 L
.43924 .203 L
.44224 .12441 L
.44358 .08848 L
.445 .05628 L
.44621 .03666 L
.4469 .02954 L
.44755 .02584 L
.4488 .0273 L
.4495 .03324 L
.45015 .04188 L
.45084 .05448 L
.45159 .07193 L
.45296 .11246 L
.45544 .20395 L
.4568 .25564 L
.45808 .29877 L
.45933 .33105 L
.46004 .34357 L
.46068 .35096 L
.46183 .3538 L
Mistroke
.46305 .34278 L
.46418 .3209 L
.46525 .29269 L
.46766 .21509 L
.47009 .14232 L
.47131 .1137 L
.47266 .08964 L
.47337 .08012 L
.47412 .0719 L
.47484 .06587 L
.47549 .06163 L
.47677 .05627 L
.47741 .05473 L
.47811 .05371 L
.47941 .05322 L
.48059 .05379 L
.48124 .05435 L
.48195 .05507 L
.48324 .05646 L
.48444 .05768 L
.48572 .05873 L
.48681 .05932 L
.48801 .05958 L
.48925 .05934 L
.49042 .0586 L
.49148 .05753 L
.49263 .05597 L
.49503 .05185 L
.49635 .04949 L
.49759 .04752 L
.49877 .04607 L
.50004 .04518 L
.50119 .04516 L
.50225 .04593 L
.50325 .04744 L
.50435 .05001 L
.50549 .05375 L
.50656 .05815 L
.51158 .08476 L
.51296 .091 L
.51365 .09351 L
.51442 .09566 L
.51507 .09692 L
.51577 .09766 L
.51704 .09731 L
.51824 .09498 L
.51956 .09039 L
.52094 .08368 L
.52221 .07612 L
.52465 .05983 L
Mistroke
.52695 .04497 L
.52805 .03896 L
.52921 .03378 L
.53049 .0297 L
.53166 .02746 L
.53271 .02654 L
.5337 .0264 L
.53478 .02676 L
.53593 .02739 L
.53717 .028 L
.53786 .02823 L
.53851 .02836 L
.53969 .02842 L
.54095 .02838 L
.54207 .02839 L
.54312 .02853 L
.54427 .02885 L
.54552 .02928 L
.54677 .02965 L
.54791 .02981 L
.54922 .02974 L
.55047 .02949 L
.55154 .02923 L
.55267 .02901 L
.55392 .02889 L
.55507 .0289 L
.55631 .02894 L
.55701 .02894 L
.55764 .02891 L
.55888 .02874 L
.56005 .02845 L
.56553 .02742 L
.58662 .02253 L
.62483 .01024 L
.63497 .00758 L
.64451 .00557 L
.65552 .00381 L
.66549 .00257 L
.67526 .00167 L
.67764 .00147 L
.68018 .00129 L
.68164 .00121 L
.68297 .00115 L
.68558 .00102 L
.68779 .00089 L
.69013 .00079 L
.69135 .00076 L
.69269 .00072 L
.69507 .00063 L
.70406 .0004 L
Mistroke
.70898 .00031 L
.71028 .0003 L
.71166 .00028 L
.71416 .00023 L
.71535 .00021 L
.71647 .0002 L
.71748 .00019 L
.71858 .00019 L
.7198 .00018 L
.7211 .00017 L
.72341 .00014 L
.72471 .00013 L
.72589 .00012 L
.72716 .00011 L
.72783 .00011 L
.72855 .00011 L
.72983 .0001 L
.73101 9e-05 L
.73223 8e-05 L
.73335 7e-05 L
.73404 7e-05 L
.73477 7e-05 L
.73557 7e-05 L
.73631 7e-05 L
.73695 6e-05 L
.73763 6e-05 L
.73908 5e-05 L
.74048 5e-05 L
.7418 4e-05 L
.74299 4e-05 L
.74428 4e-05 L
.75364 2e-05 L
.75633 2e-05 L
.75697 1e-05 L
.75766 1e-05 L
.7589 1e-05 L
.7601 1e-05 L
.7612 1e-05 L
.76249 1e-05 L
.76371 1e-05 L
.76504 1e-05 L
.76629 1e-05 L
.76759 1e-05 L
.76828 1e-05 L
.76902 1e-05 L
.76982 1e-05 L
.77058 1e-05 L
.77127 1e-05 L
.77201 1e-05 L
.7727 1e-05 L
Mistroke
.77344 0 L
.77413 0 L
.77476 0 L
.77599 0 L
.7773 0 L
.77846 0 L
.77969 0 L
.78034 0 L
.78103 0 L
.78228 0 L
.78305 0 L
.78377 0 L
.78442 0 L
.78512 0 L
.7863 0 L
.78757 0 L
.78876 0 L
.78986 0 L
.79113 0 L
.79185 0 L
.79253 0 L
.79375 0 L
.79506 0 L
.79577 0 L
.79643 0 L
.79715 0 L
.79791 0 L
.79857 0 L
.79929 0 L
.80058 0 L
.80183 0 L
.80297 0 L
.80361 0 L
.80431 0 L
.80559 0 L
.80677 0 L
.80804 0 L
.80924 0 L
.81034 0 L
.81149 0 L
.81274 0 L
.81403 0 L
.81474 0 L
.81539 0 L
.81658 0 L
.81769 0 L
.81869 0 L
.81978 0 L
.82096 0 L
.82221 0 L
Mistroke
.82328 0 L
.82446 0 L
.82576 0 L
.82696 0 L
.82828 0 L
.82895 0 L
.82968 0 L
.83084 0 L
.83207 0 L
.83271 0 L
.83341 0 L
.83464 0 L
.83584 0 L
.83712 0 L
.83833 0 L
.83943 0 L
.84054 0 L
.84174 0 L
.84288 0 L
.84393 0 L
.84513 0 L
.84642 0 L
.84754 0 L
.84876 0 L
.8495 0 L
.85018 0 L
.85084 0 L
.85154 0 L
.85222 0 L
.85287 0 L
.85408 0 L
.85539 0 L
.85605 0 L
.85677 0 L
.85805 0 L
.85924 0 L
.85997 0 L
.86066 0 L
.86194 0 L
.86266 0 L
.86333 0 L
.86406 0 L
.86483 0 L
.86597 0 L
.86722 0 L
.86851 0 L
.86972 0 L
.87086 0 L
.87189 0 L
.87308 0 L
Mistroke
.8742 0 L
.87543 0 L
.87673 0 L
.87783 0 L
.87905 0 L
.88036 0 L
.8811 0 L
.88177 0 L
.88307 0 L
.88431 0 L
.88546 0 L
.8865 0 L
.88763 0 L
.88885 0 L
.88998 0 L
.89101 0 L
.89201 0 L
.89305 0 L
.89419 0 L
.89541 0 L
.89656 0 L
.8976 0 L
.89883 0 L
.89948 0 L
.90016 0 L
.90142 0 L
.90259 0 L
.90373 0 L
.90498 0 L
.90628 0 L
.90749 0 L
.90863 0 L
.90967 0 L
.91086 0 L
.91198 0 L
.91321 0 L
.91451 0 L
.91562 0 L
.91684 0 L
.91815 0 L
.91887 0 L
.91956 0 L
.9202 0 L
.92089 0 L
.9221 0 L
.92315 0 L
.92429 0 L
.92553 0 L
.9267 0 L
.92795 0 L
Mistroke
.92926 0 L
.93037 0 L
.9316 0 L
.93275 0 L
.9338 0 L
.93493 0 L
.93615 0 L
.93729 0 L
.93833 0 L
.93933 0 L
.94039 0 L
.94153 0 L
.94278 0 L
.94396 0 L
.94505 0 L
.9461 0 L
.94724 0 L
.94831 0 L
.9493 0 L
.95049 0 L
.95174 0 L
.95279 0 L
.95394 0 L
.95517 0 L
.9565 0 L
.95774 0 L
.95888 0 L
.95995 0 L
.96109 0 L
.96207 0 L
.96314 0 L
.96429 0 L
.96553 0 L
.9666 0 L
.96777 0 L
.96888 0 L
.96991 0 L
.971 0 L
.97217 0 L
.97325 0 L
.97427 0 L
.97519 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`0Rooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00GoA4A4o`000?l0003o<S8bomgMg@1Gooooo`05odA4A?l0003o0000oc8b<_oMgMd09oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo02Gooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool09?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00omgMgOo<S8booooo`1Iooooo`03ogMgMolb<S;ooooo02Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Uooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool6o`0000Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[
ooooo`03ogMgMolb<S;ooooo05Wooooo00?oMgMgoc8b<_ooool0:?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo02Gooooo000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0Eoooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001Wooooo
00?oEEEEofIVI_l000001Oooool4o`0002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo1?l0001Hooooo`Co0000:?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool00omEEEGoIVIVo`000005ooooo`Co00009oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooC_ooool2o`0000;ooooo0_l0000Eooooo`00oooooom>
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5Oooool00?ooooooCoooool01?oMgMgo0000oa0@
4?o<c<`Fooooo`005?ooooooo`00033o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hFooooo`006ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool;o`0000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo2_l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo00Co8B4QogMgMomgMgOo<S8b
5_ooool001_ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo00;ooooo1?l0000Wooooo`03o`000?oooooooooo02Gooooo1_l00002ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0?ooooo`;o00000_oo
ool2o`0001Gooooo001looooo`Go00000_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo02;ooooo0ol0002Eooooo`00Poooool00ol0003oooooooooo`04ooooo`;o00007oooool00ol0
003oooooooooo`0Oooooo`?o0000V?ooool008Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooo`00000Oooooo`03o`000?oooooooooo01cooooo0ol0002Kooooo`00Q?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooo000001oooooo00?o0000ooooooooool06Oooool3o`0009kooooo
0025ooooo`07o`000?ooooooooooooooool0003oooooo`000007ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool05?ooool5o`000:7ooooo0025ooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`07ooooo`;o00001oooool4o`000:Kooooo0025ooooo`05o`00
0?ooooooooooooooool000000_ooool00ol0003oooooooooo`03ooooo`;o00001oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000001ol0002Zooooo`00
Q_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000
1_ooool2o`0000kooooo0_l00007ooooo`03o`000?oooooooooo0;7ooooo0026ooooo`03o`000?oo
oooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000006ooooo`;o00003_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;7ooooo0026ooooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooo000000Kooooo0_l0000>ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0/_ooool008cooooo00?o0000ooooooooool00oooool00ol0
003oooooo`000006ooooo`;o00003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0;;ooooo002<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001_ooool2o`0000ko
oooo0_l00006ooooo`03o`000?oooooooooo0;;ooooo002=ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooool000001Oooool00ol0003oooooo`00000=ooooo`?o00001_ooool00ol0003ooooo
ooooo`2booooo`00SOooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooo`000007ooooo`;o00000oooool01Ol0003oooooo`000?oooooo000000Go
oooo00?o0000ooooooooool0/_ooool008gooooo00Go0000ooooooooooooooooo`000002ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool3o`0000;ooooo00Go0000ooooool0
003oooooo`000004ooooo`03o`000?oooooooooo0;?ooooo002=ooooo`05o`000?oooooooooooooo
ool000000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000oooo
ool000000_l00002ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool0/oooool008go
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ool000001oooool00ol0003oooooooooo`04ooooo`?o00001?ooool00ol0003oooooooooo`2coooo
o`00SOooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00oooool00ol0
003oooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001?ooool00ol0
003oooooooooo`2cooooo`00S_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo0000
00Cooooo00?o0000ooooooooool0/oooool008kooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooo`000004ooooo`03o`000?oooooooooo0;?ooooo002>ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo
00Gooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`2cooooo`00S_ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001_ooool0
0ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0/ooo
ool008kooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooo000000Kooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo0;Cooooo002>ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`2dooooo`00S_ooool00ol0003oooooo`000004ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`05ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool0]?ooool008kooooo00?o0000ooooool000001?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool01Ooo
ool2o`0000;ooooo00?o0000ooooool00000]_ooool008kooooo00?o0000ooooool000001?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool01Ooo
ool01?l0003oooooooooooooool3o`000;Kooooo002>ooooo`03o`000?oooooo000000Cooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`2eooooo`00Soooool2o`0000Cooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0^_ooool008oooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`2jooooo`00UOooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`2jooooo`00UOooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`2jooooo`00T?ooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`0000Cooooo00Co0000ob4Q8Ooo
oooo00000_ooool5o`0000Kooooo00?o0000ooooooooool0^_ooool0093ooooo00KoMgMgoiRHV?oo
ooooV9RHogMgMol00004ooooo`04o`000?lQ8B7oooooo`0000;ooooo00GoV9RHob4Q8Ol0003ooooo
odA4A006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`06oa0@4?ooooooooooooooool@413o
00001?ooool01?l0003oooooooooool00003ooooo`03oiRHV?l0003ok^k^00Oooooo00?o0000oooo
ooooool0^_ooool0093ooooo00Co0000oooooooooooooooo0_l00004ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ob4Q8Oo^k^h01_ooool3o`000;[ooooo002@ooooo`04o`000?oooooooooo
ooooo`;o00001?ooool01?l0003oooooooooool00004ooooo`03o`000?mgMgOoIVIV00Kooooo00?o
0000ooooooooool0^_ooool0093ooooo00Ko410@oooooooooooooooooa0@4?l00004ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`2jooooo`00
T?ooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000Cooooo00Co0000oooooooooooo00000_ooool0
1Ol0003o^[Zjo`000?nHV9So410@00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Kok^k^
oc8b<_l0003o<S8bonk^k_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;[ooooo002Eooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0;[ooooo002Eooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0;[ooooo002Eooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0;[ooooo002Eooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0;[ooooo002Eooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`06ooooo`;o0000^oooool009Go
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0^_ooool009Gooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2joooo
o`00UOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0;[ooooo002Eooooo`05o`000?oooooooooooooo
ool000001?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0^_ooool0
09Gooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000002?oo
ool00ol0003oooooooooo`2jooooo`00U_ooool01?l0003oooooooooool00004ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`2jooooo`00U_ooool01?l0003ooooooooo
ool00004ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`2jooooo`00
U_ooool01?l0003oooooooooool00004ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ooooool0^_ooool009Kooooo00Co0000oooooooooooo00001?ooool01?l0003oooooooooool00009
ooooo`;o0000^oooool009Kooooo00Co0000oooooooooooo00001?ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo0;[ooooo002Fooooo`04o`000?ooooooooooo`0000Cooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`2jooooo`00U_ooool01?l0003ooooooooo
ool00004ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0^_ooool009Kooooo
00Co0000oooooooooooo00001?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo
0;[ooooo002Fooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooooooo`2jooooo`00U_ooool01?l0003oooooooooool00004ooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool0^_ooool009Kooooo00Co0000oooooooooooo00001?oo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo0;[ooooo002Fooooo`04o`000?oo
ooooooooo`0000Cooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`2jooooo`00
Uoooool00ol0003oooooo`000004ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooooooo
ool0^_ooool009Oooooo0_l00005ooooo`04o`000?ooooooooooo`0000Wooooo0_l0002kooooo`00
Uoooool2o`0000Gooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`2jooooo`00
Uoooool2o`0000Gooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`2jooooo`00
Uoooool2o`0000Gooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`2jooooo`00
Uoooool2o`0000Gooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`2jooooo`00
Uoooool2o`0000Gooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`2jooooo`00
T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l000000ooooooo8B4Qob4Q8@02ooooo`03
o`000?oooooooooo00?o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`2jooooo`00
T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0_l000000ooooooo8B4Qob4Q8@02ooooo`06
o`000?ooooooooooo`000?oooooo00001oooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@
413ooooooooooooooooo410@00;ooooo0_l00005ooooo`03o`000?oooooo000000Co00001_ooool0
0ol0003oooooooooo`2jooooo`00T?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000
ooooooooool01?ooool01_l0003oooooodA4A?l0003oooooo`0000Oooooo0ol0002jooooo`00T?oo
ool01Ol0003ooooooooooooooooo000000Wooooo00Ko0000oooooooMgMgo0000ooooool00007oooo
o`03o`000?oooooooooo0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@41002Oooool01_l0
003oooooooooool0003oc<c<o`0000Oooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`09ooooo`06o`000?oooooo0000onk^k_m4A4Co00001oooool00ol0003o
ooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Wooooo00Ko0000ooooool0
003oooooogMgMol00007ooooo`03o`000?oooooooooo0;[ooooo002Nooooo`03o`000?oooooo0000
00[ooooo00?o0000ooooooooool0^_ooool009kooooo00?o0000ooooool000002_ooool00ol0003o
ooooooooo`2jooooo`00W_ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo0;[ooooo
002Nooooo`03o`000?oooooo000000[ooooo00?o0000ooooooooool0^_ooool009kooooo00?o0000
ooooool000002_ooool2o`000;_ooooo002Nooooo`03o`000?oooooo000000[ooooo00?o0000oooo
ooooool0^_ooool009kooooo00?o0000ooooool000002_ooool00ol0003oooooooooo`2jooooo`00
W_ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo0;[ooooo002Nooooo`03o`000?oo
oooo000000[ooooo00?o0000ooooooooool0^_ooool009kooooo00?o0000ooooool000002_ooool0
0ol0003oooooooooo`2jooooo`00W_ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo
0;[ooooo002Nooooo`03o`000?oooooo000000[ooooo00?o0000ooooooooool0^_ooool009kooooo
00?o0000ooooool000002_ooool00ol0003oooooooooo`2jooooo`00W_ooool00ol0003oooooo`00
000:ooooo`03o`000?oooooooooo0;[ooooo002Nooooo`03o`000?oooooo000000[ooooo0_l0002k
ooooo`00W_ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo0;[ooooo002Oooooo`;o
00002_ooool00ol0003oooooooooo`2jooooo`00Woooool2o`0000[ooooo00?o0000ooooooooool0
^_ooool009oooooo0_l0000:ooooo`03o`000?oooooooooo0;[ooooo002Oooooo`;o00002_ooool0
0ol0003oooooooooo`2jooooo`00Woooool2o`0000[ooooo00?o0000ooooooooool0^_ooool009oo
oooo0_l0000:ooooo`03o`000?oooooooooo0;[ooooo002Oooooo`;o00002_ooool00ol0003ooooo
ooooo`2jooooo`00Woooool2o`0000[ooooo0_l0002kooooo`00Woooool2o`0000[ooooo00?o0000
ooooooooool0^_ooool009oooooo0_l0000:ooooo`03o`000?oooooooooo0;[ooooo002Oooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0^_ooool009oooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2jooooo`00T?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40
1_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go0000ooooooooooooooooo`000006ooooo`?o0000^_ooool0093ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2joooo
o`00T?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006
ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@41002oooool0
0omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0;[ooooo002@oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03
o`000?oooooooooo0;[ooooo002@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool0^_ooool0093ooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9So
oooooiRHV?lb<S801_ooool3o`000;[ooooo002@ooooo`05o`000?ooooooooooooooool000002ooo
ool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Go
410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003o
ooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
oooo^[Zjo`000006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002k
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:7ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;[ooooo002Sooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0^_ooool00:?ooooo00?o0000ooooooooool0
1Oooool3o`000;[ooooo002Sooooo`03o`000?oooooooooo0<;ooooo002Sooooo`03o`000?oooooo
oooo0<;ooooo002Sooooo`03o`000?oooooooooo0<;ooooo002Sooooo`03o`000?oooooooooo0<;o
oooo002Qooooo`03oeEEEOmVIVKo00000<Cooooo003oooooofWooooo001Yooooo`03ogMgMomVIVKo
oooo00Cooooo00?o0000ooooooooool00_ooool00onj^[[o<S8booooo`07ooooo`;o00002oooool0
0ol0003o^[Zjooooo`0<ooooo`;o00001oooool00ol0003oooooooooo`02ooooo`03ofIVI_mgMgOo
oooo00cooooo00?o0000okZj^_ooool0[Oooool006Sooooo00?ogMgMoa0@4?o^k^h01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool2oc8b
<Pkooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03onk^k_l@413ogMgM
00cooooo0_lb<S:^ooooo`00J?ooool00omEEEGoV9RHooooo`05ooooo`06o`000?oooooooooooooo
oonHV9So410@0_l000000onYZJWoooooooooo`04ooooo`04o`000?ooooooooooooooo`;o00000_oo
ool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03ohN7QomVIVKooooo00_ooooo
00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj017ooooo1?l000000ol@413o
ooooooooo`02ooooo`;o8B4Q1?ooool5o`0007Oooooo001Xooooo`03o`000?oooooooooo00Gooooo
00[o0000ooooooooooooooooo`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj1Oooool02_l0003ooooooooo
ooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@
okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool00oo^k^ko0000ooooo`0;ooooo`03olc<c?l0003o410@00cooooo00Ko410@okZj^_o^k^koMgMg
oa0@4?ooool6o`0000cooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A01gooooo`00J?ooool00olb<S;oooooooooo`05ooooo`0:o`000?oooooooooooooo
oolb<S;ok^k^oiRHV?mEEEGogMgMoa0@40Gooooo00?o0000ooooooooool00_ooool01?oMgMgo0000
oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^07Sooooo001Xooooo`03oc8b<_oooooooooo00Gooooo
00_o0000oooooooooooooooookZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c004ooooo`03o`000?oo
oooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00?ooooo1_l0000<ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h0
Moooool006Sooooo00?o0000onk^k_ooool01Oooool02ol0003oooooooooooooooook^k^o`000?oo
oooo0000oooooomVIVKoQhN700Cooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb
<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03onk^k_l0003ooooo01[ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0=ooooo`03ogMgMomVIVKooooo07Kooooo001Xooooo`03oeEEEOmgMgOooooo00Gooooo00So0000
ooooooooooooooooofIVI_nHV9Sooooooc8b<P;o^[Zj00?o0000ooooooooool00_ooool01?l0003o
ooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?oMgMgoeEEEOooool00_ooool4o`00
01;ooooo00?o410@o`000?l000000ol0000Dooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0MOooool006Sooooo00?ogMgMoa0@4?o^k^h01Oooool00ol0003oooooooooo`04ooooo`03
ofIVI_n7QhOooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00oo^k^ko410@omgMg@04ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0:ooooo`05
o`000?nj^[[ooooooiRHV?l@4100Moooool006Wooooo00?oMgMgofIVI_ooool01?ooool00ol0003o
ooooooooo`04ooooo`03ojVYZOm4A4Cooooo00Gooooo0_l0000Booooo`03o`000?oooooooooo00Go
oooo0_l00007ooooo`03o`000?oooooooooo00;ooooo00?oIVIVogMgMoooool01Oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?oEEEEofIVI_l000003?ooool01OnHV9So
410@o`000?lQ8B7oc<c<07Oooooo002booooo`03o`000?oooooooooo0;?ooooo002_ooooo`04o`00
0?ooooooooooo`000;Gooooo002`ooooo`;o0000]_ooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.8522, -0.080387, \
0.130126, 0.00668404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
176.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03053 0 L
.03163 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03638 0 L
.03746 0 L
.03873 0 L
.03944 0 L
.04011 0 L
.04132 0 L
.04262 0 L
.04327 0 L
.04396 0 L
.04519 0 L
.04583 0 L
.04652 0 L
.04727 0 L
.04797 0 L
.04862 0 L
.04933 0 L
.05061 0 L
.05186 0 L
.05302 0 L
.05414 0 L
.05519 0 L
.05634 0 L
.05759 0 L
.05882 0 L
.06012 0 L
.06123 0 L
.06244 0 L
.06315 0 L
.06381 0 L
.06453 0 L
.06529 0 L
.06657 0 L
.06729 0 L
.06797 0 L
.06924 0 L
.0704 0 L
.07103 0 L
.07173 0 L
.073 0 L
Mistroke
.07376 0 L
.07448 0 L
.07513 0 L
.07583 0 L
.0773 0 L
.07804 0 L
.07885 0 L
.07955 0 L
.08031 0 L
.08101 0 L
.08167 0 L
.08233 0 L
.08303 0 L
.08427 0 L
.08545 0 L
.08671 0 L
.08743 0 L
.08809 0 L
.08939 0 L
.09066 0 L
.09138 0 L
.09204 0 L
.09273 0 L
.09348 0 L
.09418 0 L
.09483 0 L
.09603 0 L
.0973 0 L
.09837 0 L
.09955 0 L
.10081 0 L
.10151 0 L
.10216 0 L
.10331 0 L
.10458 0 L
.10589 0 L
.10708 0 L
.1084 0 L
.10908 0 L
.10981 0 L
.11104 0 L
.11218 0 L
.11343 0 L
.11413 0 L
.11477 0 L
.11596 0 L
.11706 0 L
.11827 0 L
.11955 0 L
.12066 0 L
Mistroke
.1217 0 L
.12284 0 L
.12407 0 L
.12967 0 L
.13035 0 L
.131 0 L
.13175 0 L
.13243 0 L
.13366 0 L
.13429 0 L
.13499 0 L
.1362 0 L
.13747 0 L
.13866 0 L
.13976 0 L
.14108 0 L
.14228 0 L
.14295 0 L
.14367 0 L
.14497 0 L
.14617 0 L
.14726 0 L
.14847 0 L
.14978 0 L
.15107 0 L
.15227 0 L
.15354 0 L
.15425 0 L
.1549 0 L
.15722 0 L
.15838 0 L
.15967 0 L
.16077 0 L
.16194 0 L
.16306 0 L
.16407 0 L
.1692 0 L
.16986 0 L
.17056 0 L
.17134 0 L
.17205 0 L
.17278 0 L
.17347 0 L
.17476 0 L
.18484 0 L
.19464 1e-05 L
.19586 1e-05 L
.19702 1e-05 L
.19766 1e-05 L
.19835 1e-05 L
Mistroke
.19957 1e-05 L
.20102 1e-05 L
.20236 1e-05 L
.20497 1e-05 L
.20603 1e-05 L
.20717 1e-05 L
.20825 1e-05 L
.20924 1e-05 L
.21394 2e-05 L
.21893 3e-05 L
.22346 3e-05 L
.22464 3e-05 L
.22591 4e-05 L
.22822 4e-05 L
.23069 5e-05 L
.23204 5e-05 L
.2333 6e-05 L
.23557 7e-05 L
.23806 9e-05 L
.24244 .00012 L
.25307 .00018 L
.25561 .0002 L
.25831 .00021 L
.26061 .00023 L
.26192 .00025 L
.26316 .00026 L
.2656 .00031 L
.26784 .00037 L
.2729 .00054 L
.27796 .00074 L
.28083 .00082 L
.2835 .00087 L
.28593 .00091 L
.28823 .00094 L
.28924 .00096 L
.2903 .00098 L
.29146 .00101 L
.29254 .00106 L
.29367 .00112 L
.29473 .00119 L
.29714 .00142 L
.29951 .00173 L
.30205 .00213 L
.30696 .00298 L
.30837 .00319 L
.3097 .00334 L
.31089 .00345 L
.31218 .00352 L
.31287 .00355 L
.31363 .00356 L
Mistroke
.31442 .00356 L
.31516 .00355 L
.31586 .00353 L
.31649 .00351 L
.31791 .00344 L
.31921 .00337 L
.3199 .00334 L
.32063 .00331 L
.32127 .0033 L
.32198 .00331 L
.32322 .00338 L
.32449 .00353 L
.32513 .00364 L
.32582 .0038 L
.32706 .00416 L
.32821 .0046 L
.33081 .00592 L
.33359 .00779 L
.34332 .01319 L
.34456 .01321 L
.34526 .01314 L
.34589 .01303 L
.34713 .01268 L
.3483 .01223 L
.35082 .01112 L
.35214 .01064 L
.35289 .01046 L
.35358 .01039 L
.35427 .0104 L
.35491 .01052 L
.35562 .01078 L
.35638 .01122 L
.35714 .01182 L
.35794 .01266 L
.35936 .01465 L
.36191 .01968 L
.36469 .02672 L
.36729 .03348 L
.36856 .0364 L
.36974 .03862 L
.37038 .0396 L
.37109 .04046 L
.37181 .04107 L
.37256 .04142 L
.3732 .04148 L
.37389 .0413 L
.37513 .04034 L
.37638 .03864 L
.37774 .03607 L
.38021 .03027 L
Mistroke
.38139 .02747 L
.38263 .02486 L
.38369 .02315 L
.38485 .02207 L
.38618 .02215 L
.38741 .02371 L
.38811 .02529 L
.38874 .02718 L
.39017 .03304 L
.3914 .03979 L
.39274 .04872 L
.39518 .06795 L
.39753 .08766 L
.39882 .09754 L
.40004 .10545 L
.40107 .1107 L
.40217 .11448 L
.4034 .11608 L
.40453 .11497 L
.40576 .11099 L
.40706 .10384 L
.40829 .0949 L
.40941 .08553 L
.41076 .07367 L
.41219 .06181 L
.41341 .05341 L
.4141 .04975 L
.41475 .04722 L
.41603 .04525 L
.41675 .04611 L
.41741 .04822 L
.41811 .05196 L
.41888 .05776 L
.42028 .07275 L
.4216 .09134 L
.42299 .11466 L
.42551 .15978 L
.42686 .18215 L
.42812 .19955 L
.42944 .21268 L
.43014 .21714 L
.43088 .21982 L
.43152 .22032 L
.43221 .21894 L
.43347 .21138 L
.43469 .19808 L
.43582 .18123 L
.43838 .13237 L
.44112 .07746 L
.44193 .06385 L
Mistroke
.4427 .0528 L
.44339 .04475 L
.44414 .03827 L
.44485 .03458 L
.4456 .03338 L
.44632 .03496 L
.44697 .0387 L
.44823 .05224 L
.44939 .07166 L
.45066 .09976 L
.45201 .13557 L
.4543 .20377 L
.45556 .24022 L
.45676 .2704 L
.4574 .28384 L
.4581 .29572 L
.45932 .30839 L
.46056 .30936 L
.46171 .29914 L
.46296 .27676 L
.46368 .2596 L
.46435 .24123 L
.46715 .15386 L
.46942 .09075 L
.47068 .06411 L
.47184 .04604 L
.47249 .03824 L
.4732 .03161 L
.47449 .02366 L
.47578 .01972 L
.47697 .01841 L
.4782 .01845 L
.47936 .01918 L
.48063 .0203 L
.48199 .02157 L
.48342 .02279 L
.48477 .02375 L
.48599 .02438 L
.48667 .02462 L
.48731 .02477 L
.48848 .02481 L
.48973 .02456 L
.49092 .02409 L
.49201 .02357 L
.49308 .0231 L
.49408 .02283 L
.49513 .02286 L
.49627 .02339 L
.49751 .02469 L
.49868 .02669 L
Mistroke
.49973 .02914 L
.50088 .03251 L
.50344 .0425 L
.50581 .05415 L
.50807 .06637 L
.51045 .07851 L
.5117 .08372 L
.51236 .08598 L
.51306 .08793 L
.5143 .09007 L
.51545 .09043 L
.51662 .08914 L
.51789 .08594 L
.51909 .08139 L
.52019 .07614 L
.5245 .05083 L
.5268 .0381 L
.52806 .03239 L
.52927 .02812 L
.52995 .02624 L
.53068 .02464 L
.53198 .02289 L
.53329 .02226 L
.53451 .02241 L
.53518 .02267 L
.5359 .02302 L
.53721 .02368 L
.53848 .02417 L
.53964 .02444 L
.54511 .02545 L
.54627 .02587 L
.54753 .0263 L
.54873 .0266 L
.54983 .02676 L
.55111 .02681 L
.55176 .0268 L
.55247 .02679 L
.55372 .0268 L
.55488 .02689 L
.56399 .02749 L
.56526 .02753 L
.56599 .02758 L
.56666 .02766 L
.56799 .02782 L
.56919 .02794 L
.57038 .02799 L
.5715 .02796 L
.57268 .02787 L
.57395 .02775 L
.57461 .0277 L
Mistroke
.57533 .02766 L
.57663 .02764 L
.57741 .02765 L
.57813 .02766 L
.57879 .02766 L
.5795 .02764 L
.58077 .02754 L
.58196 .02736 L
.58467 .02681 L
.59418 .02506 L
.60461 .02254 L
.62567 .01638 L
.64414 .01114 L
.65461 .00853 L
.66435 .00644 L
.67485 .0046 L
.68439 .0033 L
.69459 .00225 L
.69988 .00183 L
.70549 .00145 L
.71024 .00117 L
.71547 .00094 L
.72467 .00062 L
.72733 .00054 L
.72985 .00047 L
.73124 .00044 L
.73276 .00042 L
.73541 .00037 L
.74025 .00028 L
.74547 .00022 L
.7508 .00017 L
.75324 .00015 L
.75457 .00014 L
.75581 .00012 L
.75693 .00012 L
.75814 .00011 L
.75945 .00011 L
.76069 .0001 L
.76304 9e-05 L
.76414 8e-05 L
.76518 7e-05 L
.76638 7e-05 L
.76702 7e-05 L
.76771 7e-05 L
.7684 7e-05 L
.76912 6e-05 L
.7704 6e-05 L
.77161 5e-05 L
.77274 5e-05 L
.77405 4e-05 L
Mistroke
.77523 4e-05 L
.77653 4e-05 L
.77726 4e-05 L
.77794 4e-05 L
.77916 3e-05 L
.78045 3e-05 L
.78113 3e-05 L
.78186 3e-05 L
.78317 2e-05 L
.78397 2e-05 L
.78473 2e-05 L
.78542 2e-05 L
.78616 2e-05 L
.78854 2e-05 L
.78985 2e-05 L
.79106 1e-05 L
.79237 1e-05 L
.79307 1e-05 L
.79381 1e-05 L
.79449 1e-05 L
.79514 1e-05 L
.79634 1e-05 L
.7975 1e-05 L
.79873 1e-05 L
.79977 1e-05 L
.80093 1e-05 L
.80217 1e-05 L
.80286 1e-05 L
.8035 1e-05 L
.80473 1e-05 L
.80591 1e-05 L
.8071 0 L
.80838 0 L
.80959 0 L
.81068 0 L
.81197 0 L
.81269 0 L
.81336 0 L
.81458 0 L
.81588 0 L
.81721 0 L
.81844 0 L
.81919 0 L
.81991 0 L
.82055 0 L
.82124 0 L
.82267 0 L
.82339 0 L
.82418 0 L
.82486 0 L
Mistroke
.82559 0 L
.82691 0 L
.82816 0 L
.82931 0 L
.83062 0 L
.83187 0 L
.83302 0 L
.83408 0 L
.83525 0 L
.83648 0 L
.83773 0 L
.83842 0 L
.83906 0 L
.8403 0 L
.84147 0 L
.84213 0 L
.84283 0 L
.8441 0 L
.84487 0 L
.8456 0 L
.84625 0 L
.84696 0 L
.84828 0 L
.84951 0 L
.85022 0 L
.85086 0 L
.85161 0 L
.85231 0 L
.85299 0 L
.85372 0 L
.85502 0 L
.85574 0 L
.85642 0 L
.85716 0 L
.85796 0 L
.85925 0 L
.85998 0 L
.86066 0 L
.8619 0 L
.8626 0 L
.86323 0 L
.86443 0 L
.86572 0 L
.86694 0 L
.86806 0 L
.86932 0 L
.87051 0 L
.87159 0 L
.87275 0 L
.87402 0 L
Mistroke
.87466 0 L
.87537 0 L
.87662 0 L
.87779 0 L
.8789 0 L
.88007 0 L
.88107 0 L
.88216 0 L
.88334 0 L
.8846 0 L
.88579 0 L
.88687 0 L
.88816 0 L
.88881 0 L
.88952 0 L
.89079 0 L
.89197 0 L
.89268 0 L
.89336 0 L
.89463 0 L
.8953 0 L
.896 0 L
.89678 0 L
.8975 0 L
.8988 0 L
.89953 0 L
.90021 0 L
.90145 0 L
.90276 0 L
.90394 0 L
.90504 0 L
.90624 0 L
.90753 0 L
.90875 0 L
.90945 0 L
.9101 0 L
.91141 0 L
.91215 0 L
.91283 0 L
.91397 0 L
.91521 0 L
.91651 0 L
.91772 0 L
.91842 0 L
.91917 0 L
.91988 0 L
.92053 0 L
.92177 0 L
.92308 0 L
.92376 0 L
Mistroke
.92449 0 L
.9258 0 L
.92656 0 L
.92736 0 L
.92804 0 L
.9288 0 L
.92944 0 L
.93013 0 L
.93138 0 L
.9321 0 L
.93285 0 L
.93349 0 L
.9342 0 L
.93548 0 L
.9362 0 L
.93685 0 L
.93812 0 L
.93932 0 L
.94048 0 L
.94172 0 L
.94278 0 L
.94393 0 L
.94516 0 L
.94631 0 L
.94701 0 L
.94767 0 L
.94893 0 L
.94981 0 L
.95078 0 L
.95168 0 L
.95252 0 L
.95327 0 L
.9541 0 L
.95496 0 L
.95577 0 L
.95672 0 L
.95761 0 L
.95843 0 L
.95929 0 L
.96023 0 L
.9611 0 L
.96203 0 L
.96307 0 L
.96389 0 L
.96477 0 L
.96551 0 L
.96632 0 L
.9672 0 L
.96814 0 L
.96903 0 L
Mistroke
.96984 0 L
.9706 0 L
.9714 0 L
.97229 0 L
.9731 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`0Rooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00GoA4A4o`000?l0003o<S8bomgMg@1Gooooo`05odA4A?l0003o0000oc8b<_oMgMd09oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo02Gooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool09?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00omgMgOo<S8booooo`1Iooooo`03ogMgMolb<S;ooooo02Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Uooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool6o`0000Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[
ooooo`03ogMgMolb<S;ooooo05Wooooo00?oMgMgoc8b<_ooool0:?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo02Gooooo000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0Eoooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001Wooooo
00?oEEEEofIVI_l000001Oooool4o`0002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo1?l0001Hooooo`Co0000:?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool00omEEEGoIVIVo`000005ooooo`Co00009oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooC_ooool2o`0000;ooooo0_l0000Eooooo`00oooooom>
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5Oooool00?ooooooCoooool01?oMgMgo0000oa0@
4?o<c<`Fooooo`005?ooooooo`00033o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hFooooo`006ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_oo
ool;o`0000?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`[o00000_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?oo
ool01?lQ8B7oMgMgogMgMolb<S8Fooooo`006oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo02Wooooo0_l00002ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;Ooo
ool7o`0002Wooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0?ooooo`;o00000_oo
ool2o`0001Gooooo001iooooo`?o00000_ooool2o`0002_ooooo00?o0000ooooooooool0:oooool3
o`0008cooooo001looooo`?o000000?oooooo`000?ooool0:Oooool00ol0003oooooooooo`0Voooo
o`Go0000Soooool0083ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Rooooo`Co
0000U?ooool0087ooooo00?o0000ooooooooool08?ooool2o`0000Gooooo00?o0000ooooooooool0
7oooool3o`0009Sooooo0021ooooo`03o`000?oooooooooo00Cooooo0_l0000Iooooo`05o`000?oo
ooooooooo`000?ooool01?l00009ooooo`?o00004Oooool4o`0009_ooooo0022ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooool000006Oooool01?l0003oooooooooooooool2o`000003oooo
ool0003o000000Sooooo00?o0000ooooooooool02Ol00003ooooo`Ko0000Woooool008;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooo`00000Iooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`Go0000Y?ooool008?ooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`2booooo`00Poooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo00gooooo0_l00007ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2booooo`00Q?ooool3
o`0000?ooooo00?o0000ooooooooool03Oooool2o`0000Oooooo00?o0000ooooooooool01Oooool2
o`0000Kooooo00?o0000ooooooooool0/_ooool008Cooooo0_l00004ooooo`03o`000?oooooooooo
00gooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo
0;;ooooo002;ooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`;o00001_ooool00ol0003o
ooooooooo`06ooooo`;o00001_ooool00ol0003oooooooooo`2booooo`00Roooool00ol0003ooooo
ooooo`03ooooo`;o00001oooool2o`0000Kooooo00?o0000ooooooooool01_ooool2o`0000Gooooo
00?o0000ooooooooool0/oooool008_ooooo00?o0000ooooooooool00oooool2o`0000Oooooo0_l0
0006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000001?ooool00ol0003ooooooooo
o`2cooooo`00Roooool00ol0003oooooooooo`03ooooo`;o00001oooool2o`0000Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo0;?ooooo002;oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`2coooo
o`00Roooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool0
00001_ooool00ol0003oooooooooo`06ooooo`?o00001?ooool00ol0003oooooooooo`2cooooo`00
Roooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Kooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo000000?ooooo00?o0000oooooooo
ool0]?ooool008_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool01_ooool00ol0003oooooo`000003oooo
o`03o`000?oooooooooo0;Cooooo002;ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00001Oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooool000000oooool00ol0003oooooooooo`2dooooo`00Roooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`06ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0]?ooool008_ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool01_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
0;Cooooo002<ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool01_ooool01ol0003ooooooooooooo
oooo0000ooooool00000]_ooool008cooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`06ooooo`04
o`000?ooooooooooooooo`;o0000]oooool008cooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`06
ooooo`04o`000?ooooooooooooooo`;o0000]oooool008cooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0
1_ooool2o`0000?ooooo00?o0000ooooooooool0]Oooool008cooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`2jooooo`00S?ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0;[ooooo002<ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0^_ooool008gooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2j
ooooo`00SOooool00ol0003oooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0^_ooool0
08gooooo0_l00005ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0^_ooool008gooooo0_l000001_oo
ooook^k^oc8b<_l0003o<S8bo`0000?ooooo00Go0000oooooolQ8B7o8B4Qo`000003ooooo`Go0000
1_ooool00ol0003oooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9So000000?ooooo
00Go0000oooooolQ8B7o8B4Qo`000003ooooo`05oiRHV?lQ8B7o0000oooooom4A4@01_ooool00ol0
003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000004ooooo`03oiRHV?l0003ok^k^00Oooooo00?o0000ooooooooool0^_ooool0
093ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001?oo
ool01?l0003oV9RHob4Q8Oo^k^h6ooooo`?o0000^_ooool0093ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooogMgMomVIVH6oooo
o`03o`000?oooooooooo0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00001_ooool00ol0003ooooooooo
o`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9So000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`;o000000?ooooooiRHV?l@41001_ooool00ol0003oooooooooo`2jooooo`00T?oo
ool01Oo^k^ko<S8bo`000?lb<S;o000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
oiRHV?l0003o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2jooooo`00U?ooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0;[ooooo002Dooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^_ooool009Co
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`2jooooo`00U?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0;[ooooo002Dooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo0_l0002kooooo`00U?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0;[ooooo002Dooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^_ooool009Cooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2jooooo`00U?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;[ooooo002Dooooo`05
o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000
ooooooooool0^_ooool009Gooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooo
oooo000000Wooooo00?o0000ooooooooool0^_ooool009Gooooo00Co0000oooooooooooo00001?oo
ool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool0^_ooool009Gooooo00Co
0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000oooooooo
ool0^_ooool009Gooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo0000
00Wooooo0_l0002kooooo`00UOooool01?l0003oooooooooool00004ooooo`05o`000?oooooooooo
ooooool000002Oooool00ol0003oooooooooo`2jooooo`00UOooool00ol0003oooooo`000005oooo
o`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`2jooooo`00UOooool00ol0
003oooooo`000005ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`2j
ooooo`00UOooool00ol0003oooooo`000005ooooo`05o`000?ooooooooooooooool000002Oooool0
0ol0003oooooooooo`2jooooo`00UOooool00ol0003oooooo`000005ooooo`04o`000?oooooooooo
o`0000[ooooo00?o0000ooooooooool0^_ooool009Gooooo00?o0000ooooool000001Oooool01?l0
003oooooooooool0000:ooooo`03o`000?oooooooooo0;[ooooo002Eooooo`03o`000?oooooo0000
00Gooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`2jooooo`00U_ooool2o`00
00Gooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`2jooooo`00U_ooool2o`00
00Gooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`2jooooo`00U_ooool00ol0
003oooooooooo`04ooooo`04o`000?ooooooooooo`0000[ooooo0_l0002kooooo`00U_ooool00ol0
003oooooooooo`04ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool0^_ooool0
09kooooo00?o0000ooooool000002_ooool00ol0003oooooooooo`2jooooo`00W_ooool00ol0003o
ooooo`00000:ooooo`03o`000?oooooooooo0;[ooooo002Nooooo`03o`000?oooooo000000[ooooo
00?o0000ooooooooool0^_ooool009kooooo00?o0000ooooool000002_ooool00ol0003ooooooooo
o`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B42ooooo`04o`000?oo
oooo0000ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`2jooooo`00T?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B42ooooo`03o`000?oooooo000000;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooo
oooooooo410@00Wooooo00?o0000ooooool000001?l00006ooooo`03o`000?oooooooooo0;[ooooo
002@ooooo`05o`000?ooooooooooooooool000002Oooool01_l0003oooooo`000?oMgMgoooooo`00
00Oooooo0ol0002jooooo`00T?ooool01Ol0003ooooooooooooooooo000000Wooooo00Ko0000oooo
ool0003oEEEEooooool00007ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05oa0@4?oooooo
ooooooooool@41002Oooool01_l0003oooooo`000?mgMgOoc<c<o`0000Oooooo00?o0000oooooooo
ool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`06o`000?oooooo0000onk^
k_m4A4Co00001oooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Wooooo00Ko0000ooooool0003oooooogMgMol00007ooooo`03o`000?oooooooooo0;[ooooo
002Nooooo`03o`000?oooooo000000[ooooo00?o0000ooooooooool0^_ooool009kooooo00?o0000
ooooool000002_ooool00ol0003oooooooooo`2jooooo`00W_ooool00ol0003oooooo`00000:oooo
o`03o`000?oooooooooo0;[ooooo002Nooooo`03o`000?oooooo000000[ooooo00?o0000oooooooo
ool0^_ooool009kooooo00?o0000ooooool000002_ooool2o`000;_ooooo002Nooooo`03o`000?oo
oooo000000[ooooo00?o0000ooooooooool0^_ooool009kooooo00?o0000ooooool000002_ooool0
0ol0003oooooooooo`2jooooo`00W_ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo
0;[ooooo002Nooooo`;o00002oooool00ol0003oooooooooo`2jooooo`00W_ooool2o`0000_ooooo
00?o0000ooooooooool0^_ooool009kooooo0_l0000;ooooo`03o`000?oooooooooo0;[ooooo002N
ooooo`;o00002oooool00ol0003oooooooooo`2jooooo`00Woooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo0;[ooooo002Oooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0^_ooool009oooooo00?o0000ooooooooool02Oooool2o`000;_ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0^_ooool0093ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000001_ooool3o`000;[ooooo002@ooooo`05o`000?oooooooooo
ooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0^_oo
ool0093ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
1_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo410@00_ooooo
00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`2jooooo`00T?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002k
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2jooooo`00T?ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo0;[ooooo002@ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RH
oooooonHV9So<S8b00Kooooo0ol0002jooooo`00T?ooool01Ol0003ooooooooooooooooo000000_o
oooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000
ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooookZj^_l000001_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000
^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002Qooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2jooooo`00Xoooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;[ooooo002Sooooo`03o`000?oooooooooo
00Gooooo0ol0002jooooo`00Xoooool00ol0003oooooooooo`32ooooo`00Xoooool00ol0003ooooo
ooooo`32ooooo`00Xoooool00ol0003oooooooooo`32ooooo`00Xoooool00ol0003oooooooooo`32
ooooo`00XOooool00omEEEGoIVIVo`000034ooooo`00oooooomYooooo`00JOooool00omgMgOoIVIV
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o^[Zjoc8b<_ooool01oooool2o`0000_ooooo
00?o0000okZj^_ooool03?ooool2o`0000Oooooo00?o0000ooooooooool00_ooool00omVIVKoMgMg
ooooo`0<ooooo`03o`000?nj^[[ooooo0:gooooo001Xooooo`03omgMgOl@413ok^k^00Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo0_lb
<S8>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00oo^k^ko410@omgM
g@0<ooooo`;o<S8b[_ooool006Sooooo00?oEEEEoiRHV?ooool01Oooool01_l0003ooooooooooooo
ooooV9RHoa0@40;o000000?oZJVYooooooooool01?ooool01?l0003oooooooooooooool2o`0000;o
oooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00on7QhOoIVIVooooo`0;oooo
o`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Aooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c01gooooo`00J?ooool0
0ol0003oooooooooo`05ooooo`0:o`000?ooooooooooooooool0003oZJVYoeEEEOnHV9SoEEEEokZj
^PGooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co
0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00?ok^k^o`000?ooool02oooool00oo<c<co0000oa0@400<oooo
o`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l0000<ooooo`03o`000?oooooooooo00Cooooo0_lQ
8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S80Moooool006Sooooo00?o<S8booooooooool01Ooo
ool02_l0003ooooooooooooooooo<S8bonk^k_nHV9SoEEEEomgMgOl@4105ooooo`03o`000?oooooo
oooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1eooooo`00J?ooool0
0olb<S;oooooooooo`05ooooo`0;o`000?oooooooooooooooonj^[[oA4A4olc<c?lQ8B7ooooooa0@
4?o<c<`01?ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`03ooooo`Ko00003?ooool00ol0003oooooooooo`0=
ooooo`03ojVYZOl@413ooooo07Kooooo001Xooooo`03o`000?o^k^kooooo00Gooooo00_o0000oooo
ooooooooooooonk^k_l0003oooooo`000?ooooooIVIVohN7Q`04ooooo`03o`000?oooooooooo00;o
oooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool00oo^k^ko0000ooooo`0Jooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool03?ooool00ol@413o0000okZj^P1gooooo`00J?ooool00omEEEGo
MgMgooooo`05ooooo`08o`000?oooooooooooooooomVIVKoV9RHoooooolb<S82okZj^P03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000
o`000003o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03ogMg
MomEEEGooooo00;ooooo1?l0000Booooo`03oa0@4?l0003o000000?o00005?ooool00ol0003ooooo
ooooo`0=ooooo`03okZj^_lQ8B7ooooo07Kooooo001Xooooo`03omgMgOl@413ok^k^00Gooooo00?o
0000ooooooooool01?ooool00omVIVKoQhN7ooooo`05ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o
k^k^oa0@4?oMgMd01?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool02_ooool01Ol@413oV9RHoooooonj^[[o000007Oooooo001Yooooo`03ogMgMomV
IVKooooo00Cooooo00?o0000ooooooooool01?ooool00onYZJWoA4A4ooooo`05ooooo`;o00004_oo
ool00ol0003oooooooooo`05ooooo`;o00001oooool00ol0003oooooooooo`02ooooo`03ofIVI_mg
MgOooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03oeEEEOmV
IVKo000000cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@1gooooo`00/_ooool00ol0003ooooooooo
o`2cooooo`00[oooool01?l0003oooooooooool0002eooooo`00/?ooool2o`000;Kooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.8522, -0.080387, \
0.130126, 0.00668404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
176.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03056 0 L
.03162 0 L
.03279 0 L
.03397 0 L
.03524 0 L
.03642 0 L
.0375 0 L
.03875 0 L
.03946 0 L
.04012 0 L
.04133 0 L
.04262 0 L
.04327 0 L
.04396 0 L
.04519 0 L
.04588 0 L
.04663 0 L
.04733 0 L
.04797 0 L
.04921 0 L
.05038 0 L
.05164 0 L
.05236 0 L
.05302 0 L
.05414 0 L
.05519 0 L
.05634 0 L
.05759 0 L
.05882 0 L
.06012 0 L
.06123 0 L
.06244 0 L
.06311 0 L
.06381 0 L
.06458 0 L
.06529 0 L
.06657 0 L
.0673 0 L
.06797 0 L
.06923 0 L
.06991 0 L
.07057 0 L
.07173 0 L
.073 0 L
Mistroke
.07376 0 L
.07448 0 L
.07583 0 L
.07659 0 L
.07728 0 L
.07804 0 L
.07885 0 L
.0801 0 L
.0808 0 L
.08144 0 L
.08219 0 L
.0829 0 L
.08427 0 L
.08544 0 L
.08673 0 L
.08737 0 L
.08807 0 L
.08933 0 L
.09052 0 L
.09177 0 L
.09294 0 L
.09401 0 L
.09527 0 L
.09597 0 L
.09663 0 L
.09779 0 L
.09906 0 L
.09972 0 L
.10046 0 L
.10117 0 L
.10193 0 L
.10265 0 L
.1033 0 L
.10458 0 L
.10575 0 L
.10686 0 L
.10807 0 L
.10938 0 L
.11067 0 L
.11138 0 L
.11204 0 L
.1132 0 L
.11448 0 L
.11567 0 L
.1168 0 L
.11781 0 L
.11891 0 L
.1201 0 L
.12137 0 L
.12245 0 L
Mistroke
.12364 0 L
.1243 0 L
.12502 0 L
.12634 0 L
.12762 0 L
.12881 0 L
.12953 0 L
.13022 0 L
.13149 0 L
.13221 0 L
.13289 0 L
.13359 0 L
.13436 0 L
.13557 0 L
.13687 0 L
.13918 0 L
.14037 0 L
.14166 0 L
.14239 0 L
.14307 0 L
.14371 0 L
.14439 0 L
.14572 0 L
.14696 0 L
.14826 0 L
.14895 0 L
.14968 0 L
.151 0 L
.15225 0 L
.15337 0 L
.15458 0 L
.15592 0 L
.15666 0 L
.15736 0 L
.15871 0 L
.15996 0 L
.16125 0 L
.16199 0 L
.16267 1e-05 L
.16565 1e-05 L
.16691 1e-05 L
.16826 1e-05 L
.16955 1e-05 L
.17072 1e-05 L
.1721 1e-05 L
.17356 1e-05 L
.17612 1e-05 L
.17727 1e-05 L
.17835 1e-05 L
.17959 1e-05 L
Mistroke
.18073 1e-05 L
.18334 2e-05 L
.18577 2e-05 L
.19038 2e-05 L
.19546 3e-05 L
.20041 4e-05 L
.20314 5e-05 L
.20574 6e-05 L
.20811 6e-05 L
.21071 7e-05 L
.21526 9e-05 L
.21749 .0001 L
.21988 .00012 L
.22418 .00015 L
.23445 .00024 L
.23986 .0003 L
.24282 .00033 L
.24426 .00035 L
.24558 .00037 L
.24799 .00043 L
.25058 .0005 L
.25608 .00069 L
.26575 .0011 L
.27051 .00128 L
.27285 .00134 L
.27499 .00141 L
.27724 .0015 L
.27966 .00165 L
.28218 .00184 L
.28482 .00211 L
.28749 .00247 L
.28997 .00287 L
.2956 .00376 L
.29808 .0041 L
.30042 .00435 L
.30172 .00445 L
.30312 .00452 L
.3044 .00457 L
.30558 .00461 L
.30683 .00466 L
.30802 .00472 L
.30908 .0048 L
.31025 .00491 L
.31151 .00506 L
.31285 .00528 L
.31412 .00556 L
.31527 .00589 L
.31751 .00678 L
.31994 .00811 L
.32433 .01121 L
Mistroke
.32704 .01323 L
.32956 .01492 L
.33094 .01566 L
.3322 .01617 L
.33291 .01638 L
.33359 .01653 L
.33431 .01663 L
.33509 .01667 L
.33627 .01662 L
.33758 .01643 L
.33823 .0163 L
.33894 .01614 L
.34022 .01582 L
.34143 .01554 L
.3427 .01531 L
.34378 .0152 L
.34497 .01523 L
.34561 .01533 L
.34629 .01551 L
.34751 .01607 L
.34883 .01703 L
.34957 .01776 L
.35027 .01856 L
.35268 .02218 L
.35526 .02722 L
.35974 .03693 L
.3621 .04141 L
.36329 .04321 L
.36461 .0447 L
.36533 .04527 L
.36611 .04566 L
.36685 .04582 L
.36753 .04579 L
.36885 .04528 L
.36951 .04482 L
.37023 .04417 L
.37281 .04112 L
.37423 .03931 L
.37492 .03849 L
.37557 .03782 L
.37687 .03685 L
.37755 .03661 L
.37828 .03663 L
.37945 .03735 L
.38075 .03932 L
.38195 .04242 L
.38324 .04719 L
.38446 .05305 L
.38557 .05947 L
.39034 .09338 L
Mistroke
.39159 .10222 L
.39295 .11073 L
.39424 .11726 L
.39542 .12159 L
.39653 .12393 L
.39775 .12436 L
.39902 .12235 L
.40021 .11827 L
.40131 .11282 L
.40231 .10669 L
.40456 .09049 L
.40703 .07275 L
.40828 .0655 L
.409 .06219 L
.40966 .05982 L
.41037 .05805 L
.41115 .05715 L
.41182 .0573 L
.41254 .05843 L
.41381 .06302 L
.41453 .06706 L
.4152 .07174 L
.41776 .09655 L
.42008 .1255 L
.42256 .15703 L
.42387 .1716 L
.4246 .17849 L
.42529 .18411 L
.4266 .19195 L
.42779 .19539 L
.42891 .19509 L
.43014 .19074 L
.43143 .18166 L
.43215 .17471 L
.4328 .16736 L
.43527 .13259 L
.43755 .09667 L
.43875 .07939 L
.44001 .06431 L
.44112 .05485 L
.44234 .04949 L
.44345 .04969 L
.44448 .05442 L
.44577 .06643 L
.4465 .07597 L
.44718 .08634 L
.44974 .13534 L
.45221 .18679 L
.45342 .20866 L
.45452 .22465 L
Mistroke
.45572 .23611 L
.457 .24041 L
.45768 .23907 L
.45841 .23476 L
.4591 .22802 L
.45974 .21958 L
.46114 .19472 L
.46242 .16648 L
.46528 .09705 L
.4676 .04939 L
.46891 .02961 L
.47014 .01631 L
.47144 .00722 L
.47262 .00255 L
.47328 .00112 L
.47399 .00027 L
.47529 .0001 L
.47639 .00078 L
.47761 .00191 L
.48007 .00423 L
.48117 .00506 L
.48236 .00579 L
.4845 .00674 L
.48724 .00759 L
.48858 .00802 L
.48979 .00853 L
.49108 .00927 L
.49178 .00982 L
.49245 .01045 L
.49384 .01221 L
.49536 .01491 L
.49656 .0177 L
.49787 .02146 L
.50054 .03109 L
.50532 .05242 L
.50781 .06319 L
.50912 .06806 L
.51052 .07228 L
.51122 .07391 L
.51187 .07514 L
.51309 .07655 L
.51423 .07677 L
.51547 .07575 L
.51659 .07373 L
.51782 .07037 L
.5191 .06576 L
.5203 .06063 L
.52475 .03868 L
.52605 .03273 L
.52746 .02718 L
Mistroke
.52879 .02307 L
.53002 .02036 L
.53113 .01879 L
.53236 .01792 L
.53363 .01773 L
.53483 .01799 L
.53999 .0198 L
.54563 .02134 L
.55548 .02324 L
.56584 .02468 L
.57041 .02548 L
.57536 .0261 L
.57763 .02637 L
.57888 .02651 L
.58004 .02663 L
.58103 .02671 L
.58209 .02677 L
.58327 .0268 L
.58435 .02681 L
.58566 .02682 L
.58687 .02682 L
.58758 .02682 L
.58821 .02682 L
.58894 .02683 L
.58963 .02682 L
.59088 .02681 L
.59204 .02678 L
.5933 .02672 L
.59464 .02663 L
.59915 .02633 L
.60034 .02626 L
.60163 .02617 L
.60398 .02594 L
.60669 .0256 L
.60916 .02528 L
.61398 .02452 L
.61968 .02331 L
.62494 .02207 L
.66428 .0117 L
.68404 .00729 L
.70211 .0043 L
.71206 .00308 L
.72152 .0022 L
.7315 .00151 L
.73711 .00121 L
.7424 .00098 L
.74735 .0008 L
.75271 .00063 L
.76207 .00041 L
.76738 .00032 L
Mistroke
.77299 .00025 L
.77778 .0002 L
.78304 .00015 L
.78555 .00013 L
.78828 .00012 L
.79324 9e-05 L
.79766 7e-05 L
.80254 6e-05 L
.80781 4e-05 L
.8105 4e-05 L
.81192 3e-05 L
.8134 3e-05 L
.81611 3e-05 L
.81859 2e-05 L
.82092 2e-05 L
.82215 2e-05 L
.82346 2e-05 L
.82479 2e-05 L
.82603 2e-05 L
.82846 1e-05 L
.833 1e-05 L
.83785 1e-05 L
.83918 1e-05 L
.83993 1e-05 L
.84061 1e-05 L
.84319 1e-05 L
.85209 0 L
.85332 0 L
.85465 0 L
.8559 0 L
.85706 0 L
.86156 0 L
.86636 0 L
.86763 0 L
.86834 0 L
.86898 0 L
.87016 0 L
.87143 0 L
.87259 0 L
.87367 0 L
.8747 0 L
.87579 0 L
.87697 0 L
.87807 0 L
.87928 0 L
.88058 0 L
.88189 0 L
.8831 0 L
.8838 0 L
.88443 0 L
Mistroke
.88517 0 L
.88586 0 L
.88715 0 L
.8878 0 L
.88852 0 L
.8893 0 L
.89002 0 L
.89068 0 L
.8914 0 L
.89269 0 L
.8939 0 L
.89499 0 L
.89619 0 L
.89748 0 L
.89818 0 L
.89885 0 L
.90004 0 L
.90132 0 L
.90257 0 L
.90371 0 L
.90502 0 L
.90626 0 L
.90741 0 L
.90847 0 L
.90964 0 L
.91087 0 L
.91211 0 L
.9128 0 L
.91344 0 L
.91469 0 L
.91585 0 L
.9165 0 L
.91719 0 L
.91796 0 L
.91866 0 L
.91932 0 L
.92003 0 L
.92133 0 L
.92265 0 L
.92388 0 L
.92458 0 L
.92523 0 L
.92598 0 L
.92667 0 L
.92735 0 L
.92806 0 L
.92878 0 L
.92957 0 L
.93025 0 L
.93099 0 L
Mistroke
.93168 0 L
.93231 0 L
.93353 0 L
.93467 0 L
.93591 0 L
.93661 0 L
.93724 0 L
.93852 0 L
.93924 0 L
.9399 0 L
.94113 0 L
.94242 0 L
.9435 0 L
.94468 0 L
.94579 0 L
.94682 0 L
.94784 0 L
.94876 0 L
.94983 0 L
.95083 0 L
.95194 0 L
.9531 0 L
.95409 0 L
.95518 0 L
.95635 0 L
.95761 0 L
.95878 0 L
.95987 0 L
.96089 0 L
.96197 0 L
.96306 0 L
.96426 0 L
.96529 0 L
.9664 0 L
.96745 0 L
.96841 0 L
.9694 0 L
.97032 0 L
.97133 0 L
.9724 0 L
.97342 0 L
.97439 0 L
.97525 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`0Rooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00GoA4A4o`000?l0003o<S8bomgMg@1Gooooo`05odA4A?l0003o0000oc8b<_oMgMd09oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo02Gooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool09?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00omgMgOo<S8booooo`1Iooooo`03ogMgMolb<S;ooooo02Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Uooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool6o`0000Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[
ooooo`03ogMgMolb<S;ooooo05Wooooo00?oMgMgoc8b<_ooool0:?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo02Gooooo000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0Eoooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001Wooooo
00?oEEEEofIVI_l000001Oooool4o`0002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo1?l0001Hooooo`Co0000:?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool00omEEEGoIVIVo`000005ooooo`Co00009oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooC_ooool2o`0000;ooooo0_l0000Eooooo`00oooooom>
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5Oooool00?ooooooCoooool01?oMgMgo0000oa0@
4?o<c<`Fooooo`005?ooooooo`00033o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hFooooo`006ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo2_l000000ooooooo0000oooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000000_l00005ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`oo00001?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo00Co8B4QogMgMomgMgOo<S8b
5_ooool001_ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Qooooo`Ko00001_oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00?o00000oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo00Cooooo1?l0000Uooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool03oooool2o`0000;ooooo0_l0000Eooooo`00MOooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo00?ooooo0_l000000ooooooo0000ooooo`0booooo`?o0000Q_ooool0
07Kooooo0_l0000Zooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool00000;oooool4o`00
08Wooooo001gooooo`Oo00009?ooool00ol0003oooooooooo`05ooooo`;o0000:oooool4o`0008go
oooo001mooooo`;o00008oooool00ol0003oooooooooo`05ooooo`;o00002?ooool5o`0001[ooooo
1?l0002Aooooo`00O_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo0_l0
0008ooooo`03o`000?oooooooooo00;ooooo1_l0000?ooooo`Go0000UOooool007oooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`05ooooo`;o00001oooool00ol0003oooooooooo`09
ooooo`oo0000V_ooool007oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool0083ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`06ooooo`;o00001_ooool00ol0003oooooooooo`2booooo`00
POooool00ol0003oooooooooo`02ooooo`;o00006_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool0087ooooo00Oo0000oooooooooooooooo
o`000?oooooo000001[ooooo00?o0000ooooooooool01_ooool2o`0000Gooooo00?o0000oooooooo
ool0/oooool0087ooooo0_l00002ooooo`03o`000?oooooo000001Wooooo00?o0000ooooooooool0
1oooool2o`0000Gooooo00?o0000ooooooooool0/oooool008;ooooo0ol00003ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool01oooool2o`0000Gooooo00?o0000ooooooooool0/ooo
ool008Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`2cooooo`00R?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0
003oooooo`000003ooooo`03o`000?oooooooooo0;Cooooo0028ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool2o`0000Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooo`000003ooooo`03o`000?oooooooooo0;Cooooo0028ooooo`03o`000?oooooooooo00Gooooo
0_l00007ooooo`;o00001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000?ooooo
00?o0000ooooooooool0]?ooool008Sooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00
0007ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01oooool3o`0000?ooooo00?o
0000ooooooooool0]?ooool008Sooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000007
ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01oooool00ol0003oooooo`000003
ooooo`03o`000?oooooooooo0;Cooooo0029ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ool000001oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Oooooo00Ko0000oooo
oooooooo0000ooooool0002gooooo`00ROooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
000000Oooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`07ooooo`06o`000?oooooo
ooooo`000?oooooo0000]oooool008Wooooo00?o0000ooooooooool00oooool00ol0003oooooo`00
0006ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`03o`000;Oooooo0029ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
^_ooool008Wooooo00?o0000ooooooooool00oooool00ol0003oooooo`000006ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2jooooo`00R_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0^_ooool008[ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0;[ooooo002:ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool02?ooool2o`000;_ooooo002:ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`2jooooo`00R_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0^_ooool008[ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`2jooooo`00R_ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo0;[ooooo002;ooooo`03o`000?oooooo000000Cooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0^_ooool008_ooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
0;[ooooo002;ooooo`03o`000?oooooo000000;ooooo00Gok^k^oc8b<_l0003o0000onk^kP02oooo
o`03o`000?oooooooooo00;o8B4Q00Co0000oooooooooooooooo1Ol00006ooooo`03o`000?oooooo
oooo0;[ooooo002;ooooo`03o`000?oooooo000000;ooooo00GoMgMgoiRHV?oooooo0000ogMgM`02
ooooo`03o`000?oooooooooo00;o8B4Q00Wo0000ooooooooooooooooo`000?lQ8B7ok^k^oooooom4
A4@01_ooool00ol0003oooooooooo`2jooooo`00Roooool2o`0000?ooooo00Go410@oooooooooooo
0000oa0@4002ooooo`03o`000?oooooooooo00;ooooo00So0000ooooooooooooooooo`000?nHV9So
8B4Qonk^kPOooooo00?o0000ooooooooool0^_ooool008cooooo00Go0000ooooooooooooooooo`00
0002ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`09o`000?ooooooooooooooool0003o
oooooiRHV?lQ8B7ok^k^00Kooooo0ol0002jooooo`00T?ooool00ol0003oooooooooo`02o`0000;o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00?oMgMgofIV
I_ooool01Oooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413oooooooooool0003o410@
00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHooooool0003o
MgMg00;ooooo00?o0000ooooooooool00_ooool02Ol0003ooooooooooooooooo0000okZj^_oooooo
V9RHoa0@4006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05onk^k_lb<S;o0000o`000?o^
k^h00_ooool00ol0003oooooooooo`02ooooo`09o`000?ooooooooooooooool0003o410@o`000?lQ
8B7oc<c<00Kooooo00?o0000ooooooooool0^_ooool009?ooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`2jooooo`00U?oo
ool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003o
ooooooooo`2jooooo`00U?ooool01?l0003oooooooooool00004ooooo`05o`000?oooooooooooooo
ool000002_ooool00ol0003oooooooooo`2jooooo`00U?ooool01?l0003oooooooooool00004oooo
o`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`2jooooo`00U?ooool01?l0
003oooooooooool00004ooooo`05o`000?ooooooooooooooool000002_ooool2o`000;_ooooo002D
ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`00
0?oooooooooo0;[ooooo002Dooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooooooo
ooooo`00000:ooooo`03o`000?oooooooooo0;[ooooo002Dooooo`04o`000?ooooooooooo`0000Go
oooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`2jooooo`00U?ooool01?l0003o
ooooooooool00005ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool0^_ooool0
09Cooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool0000:ooooo`03o`000?oo
oooooooo0;[ooooo002Dooooo`03o`000?oooooo000000Kooooo00Co0000oooooooooooo00002_oo
ool00ol0003oooooooooo`2jooooo`00U?ooool00ol0003oooooo`000006ooooo`04o`000?oooooo
ooooo`0000[ooooo00?o0000ooooooooool0^_ooool009Cooooo00?o0000ooooool000001_ooool0
1?l0003oooooooooool0000:ooooo`03o`000?oooooooooo0;[ooooo002Dooooo`03o`000?oooooo
000000Kooooo00?o0000ooooool000002oooool2o`000;_ooooo002Dooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooool000002oooool00ol0003oooooooooo`2jooooo`00UOooool2o`0000Ko
oooo00?o0000ooooool000002oooool00ol0003oooooooooo`2jooooo`00UOooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool0^_ooool009gooooo00?o
0000ooooool000002oooool00ol0003oooooooooo`2jooooo`00WOooool00ol0003oooooo`00000;
ooooo`03o`000?oooooooooo0;[ooooo002Mooooo`03o`000?oooooo000000_ooooo00?o0000oooo
ooooool0^_ooool009gooooo00?o0000ooooool000002oooool00ol0003oooooooooo`2jooooo`00
WOooool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo0;[ooooo002Mooooo`03o`000?oo
oooo000000_ooooo00?o0000ooooooooool0^_ooool009gooooo00?o0000ooooool000002oooool2
o`000;_ooooo002Mooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool0^_ooool009go
oooo00?o0000ooooool000002oooool00ol0003oooooooooo`2jooooo`00WOooool00ol0003ooooo
o`00000;ooooo`03o`000?oooooooooo0;[ooooo002Mooooo`03o`000?oooooo000000_ooooo00?o
0000ooooooooool0^_ooool009kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2j
ooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B42ooooo`04o`000?oooooo
ooooooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`2jooooo`00T?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B42ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05o`000?oooooo
ooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`?o0000^_ooool0093ooooo00Go
0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooooooo
ool0^_ooool0093ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oo
oooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0093ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0^_ooool0
093ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;[ooooo002@ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2jooooo`00
T?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003o
ooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nH
V9P02?ooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2jooooo`00T?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40
1_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002joooo
o`00T?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006
ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003ooooo
ooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@06ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002Qooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`2jooooo`00Xoooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0;[ooooo002Sooooo`03o`000?oooooooooo00Gooooo0ol0002jooooo`00Xoooool00ol0
003oooooooooo`32ooooo`00Xoooool00ol0003oooooooooo`32ooooo`00Xoooool00ol0003ooooo
ooooo`32ooooo`00Xoooool00ol0003oooooooooo`32ooooo`00XOooool00omEEEGoIVIVo`000034
ooooo`00oooooomYooooo`00JOooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o^[Zjoc8b<_ooool01oooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Oo
oooo00?o0000ooooooooool00_ooool00omVIVKoMgMgooooo`0<ooooo`03o`000?nj^[[ooooo0:go
oooo001Xooooo`03omgMgOl@413ok^k^00Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool00oo^k^ko410@omgMg@0<ooooo`;o<S8b[_ooool006Sooooo00?o
EEEEoiRHV?ooool01Oooool01_l0003oooooooooooooooooV9RHoa0@40;o000000?oZJVYoooooooo
ool01?ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj
00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00on7QhOoIVIVooooo`0;ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RH
o`000?l0003oA4A4okZj^P0Aooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo0_l0
00000ol@413oooooooooo`1eooooo`00J?ooool00ol0003oooooooooo`05ooooo`0:o`000?oooooo
ooooooooool0003oZJVYoeEEEOnHV9SoEEEEokZj^PGooooo00[o0000ooooooooooooooooonk^k_lQ
8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMg
Mol@41001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?ok^k^o`00
0?ooool02oooool00oo<c<co0000oa0@400<ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l0
000<ooooo`03o`000?oooooooooo00Cooooo0_lQ8B47ooooo`03o`000?oooooooooo07Kooooo001X
ooooo`03oc8b<_oooooooooo00Gooooo00[o0000oooooooooooooooooc8b<_o^k^koV9RHoeEEEOoM
gMgo410@1Oooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00[ooooo1Ol0001g
ooooo`00J?ooool00olb<S;oooooooooo`05ooooo`0;o`000?oooooooooooooooonj^[[oA4A4olc<
c?lQ8B7ooooooa0@4?o<c<`01?ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^
kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`03ooooo`Ko00003?ooool00ol0
003oooooooooo`0:ooooo`04odA4A?oMgMgoooooo`0007Sooooo001Xooooo`03o`000?o^k^kooooo
00Gooooo00_o0000ooooooooooooooooonk^k_l0003oooooo`000?ooooooIVIVohN7Q`04ooooo`03
o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00oo^k^ko0000ooooo`0Joooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool01?oMgMgoEEEEooooool0001h
ooooo`00J?ooool00omEEEGoMgMgooooo`05ooooo`08o`000?oooooooooooooooomVIVKoV9RHoooo
oolb<S82okZj^P03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o
00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03ogMgMomEEEGooooo00;ooooo1?l0000Booooo`03oa0@4?l0003o000000?o
00005?ooool00ol0003oooooooooo`0;ooooo`03ogMgMoo<c<co000007Sooooo001Xooooo`03omgM
gOl@413ok^k^00Gooooo00?o0000ooooooooool01?ooool00omVIVKoQhN7ooooo`05ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00?ok^k^oa0@4?oMgMd01?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool02oooool00oo^k^koA4A4o`00001hooooo`00JOoo
ool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo00Cooooo00?oZJVYodA4A?ooool01Ooo
ool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0000Oooooo00?o0000ooooooooool00_oo
ool00omVIVKoMgMgooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04ooo
ool00omEEEGoIVIVo`00000>ooooo`03ogMgMol0003ooooo07Oooooo002booooo`03o`000?oooooo
oooo0;?ooooo002_ooooo`04o`000?ooooooooooo`000;Gooooo002`ooooo`;o0000]_ooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.8522, -0.080387, \
0.130126, 0.00668404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
176.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03072 0 L
.03179 0 L
.03279 0 L
.03397 0 L
.03527 0 L
.03653 0 L
.03725 0 L
.0379 0 L
.03907 0 L
.04018 0 L
.04146 0 L
.04262 0 L
.04383 0 L
.04514 0 L
.04636 0 L
.04748 0 L
.04812 0 L
.04881 0 L
.05006 0 L
.05136 0 L
.0521 0 L
.05278 0 L
.05402 0 L
.05516 0 L
.05641 0 L
.05705 0 L
.05774 0 L
.0589 0 L
.05998 0 L
.06244 0 L
.07308 0 L
.07436 0 L
.07508 0 L
.07574 0 L
.07697 0 L
.07826 0 L
.07942 0 L
.0805 0 L
.08169 0 L
.08297 0 L
.08361 0 L
.08431 0 L
.08558 0 L
.08681 0 L
.08796 0 L
Mistroke
.08866 0 L
.08931 0 L
.09054 0 L
.09185 0 L
.0926 0 L
.09329 0 L
.09396 0 L
.09467 0 L
.09612 0 L
.09682 0 L
.09748 0 L
.09872 0 L
.09943 0 L
.10018 0 L
.10082 0 L
.10153 0 L
.10229 0 L
.1031 0 L
.10387 0 L
.10458 0 L
.10572 0 L
.10693 0 L
.10756 0 L
.10826 0 L
.10948 0 L
.11063 0 L
.11186 0 L
.11303 0 L
.11409 0 L
.1154 0 L
.11614 0 L
.11682 0 L
.11808 0 L
.11871 0 L
.11941 0 L
.12061 0 L
.1219 0 L
.12424 0 L
.12707 0 L
.12776 0 L
.12849 0 L
.1293 0 L
.13005 0 L
.13537 1e-05 L
.14076 1e-05 L
.14572 1e-05 L
.147 1e-05 L
.14821 1e-05 L
.14946 1e-05 L
.15084 1e-05 L
Mistroke
.15156 1e-05 L
.15224 1e-05 L
.15352 2e-05 L
.15424 2e-05 L
.15492 2e-05 L
.1557 2e-05 L
.1564 2e-05 L
.15761 2e-05 L
.15891 2e-05 L
.16123 2e-05 L
.16374 3e-05 L
.16443 3e-05 L
.16517 3e-05 L
.16587 3e-05 L
.1665 3e-05 L
.17129 4e-05 L
.17246 4e-05 L
.17371 4e-05 L
.17436 4e-05 L
.17508 4e-05 L
.17634 5e-05 L
.18099 6e-05 L
.1821 6e-05 L
.18327 7e-05 L
.18439 7e-05 L
.1854 7e-05 L
.18775 8e-05 L
.19032 .0001 L
.19153 .0001 L
.19281 .0001 L
.19421 .00011 L
.1955 .00012 L
.20026 .00015 L
.20147 .00016 L
.20261 .00017 L
.20476 .00018 L
.20723 .00021 L
.20989 .00024 L
.21469 .00029 L
.21992 .00036 L
.22562 .00046 L
.22819 .00051 L
.23096 .00057 L
.23357 .00065 L
.23597 .00074 L
.24535 .00116 L
.25621 .00165 L
.25894 .00177 L
.26151 .00186 L
.26383 .00198 L
Mistroke
.26513 .00206 L
.26634 .00216 L
.27076 .00256 L
.273 .00282 L
.27546 .00319 L
.28521 .00496 L
.29075 .0059 L
.29601 .00662 L
.30074 .00752 L
.30203 .00784 L
.30341 .00824 L
.3059 .0092 L
.3253 .01889 L
.32662 .01896 L
.32735 .01897 L
.32803 .01896 L
.32934 .01892 L
.33058 .01885 L
.33125 .0188 L
.33196 .01876 L
.33324 .01871 L
.33391 .01872 L
.33464 .01877 L
.33543 .01887 L
.33617 .01904 L
.33739 .0195 L
.33868 .02026 L
.33978 .02114 L
.34098 .02236 L
.34367 .02602 L
.34617 .03054 L
.35156 .04311 L
.3539 .04855 L
.35645 .0533 L
.35789 .05525 L
.35852 .05592 L
.35922 .05653 L
.36048 .05727 L
.36118 .05748 L
.36183 .05755 L
.36257 .05749 L
.36327 .05729 L
.3646 .05658 L
.36534 .05605 L
.36602 .05549 L
.36757 .05417 L
.36884 .05327 L
.36956 .05294 L
.37021 .05278 L
.37142 .05297 L
Mistroke
.3727 .05395 L
.37384 .0556 L
.37491 .05783 L
.37608 .06103 L
.37734 .06531 L
.38275 .09129 L
.38512 .10351 L
.38638 .10905 L
.38705 .11153 L
.38774 .11378 L
.38838 .11546 L
.38907 .11688 L
.39029 .11825 L
.39153 .11814 L
.39269 .11671 L
.39337 .11529 L
.39402 .11359 L
.39523 .10951 L
.39794 .09703 L
.40052 .08309 L
.40193 .07595 L
.40325 .07035 L
.40394 .06803 L
.40468 .06611 L
.4055 .06475 L
.40625 .06429 L
.40693 .06456 L
.40767 .06562 L
.40837 .06737 L
.40901 .06965 L
.41027 .07587 L
.41144 .08371 L
.41266 .09381 L
.414 .10681 L
.41681 .13825 L
.41939 .16675 L
.42066 .17833 L
.42186 .18672 L
.42293 .19161 L
.4241 .19371 L
.42537 .19195 L
.42602 .18947 L
.42672 .18553 L
.42797 .17568 L
.42914 .16354 L
.43375 .10093 L
.43484 .08613 L
.43601 .07213 L
.4371 .06152 L
.43812 .05412 L
Mistroke
.43938 .04897 L
.44053 .04835 L
.44179 .05197 L
.44251 .05581 L
.44316 .06032 L
.44777 .10519 L
.44897 .11621 L
.45024 .12597 L
.45145 .13265 L
.45255 .13626 L
.45384 .13728 L
.45457 .13629 L
.45524 .1344 L
.45648 .12859 L
.45779 .11948 L
.46331 .06434 L
.46572 .04212 L
.467 .03268 L
.46836 .02458 L
.4696 .0189 L
.47073 .01497 L
.47186 .012 L
.47293 .00991 L
.47413 .00819 L
.47524 .00703 L
.47645 .00605 L
.47774 .00523 L
.48006 .00399 L
.48255 .00284 L
.48328 .00256 L
.48398 .00234 L
.48528 .00211 L
.48651 .00219 L
.4872 .00238 L
.48784 .00268 L
.48899 .00352 L
.49024 .0049 L
.49141 .00668 L
.49249 .00874 L
.49454 .01373 L
.4967 .0204 L
.50154 .03881 L
.50392 .04808 L
.50612 .05561 L
.50726 .05883 L
.50851 .0617 L
.50977 .06376 L
.51045 .06451 L
.5111 .06495 L
.51224 .0651 L
Mistroke
.51328 .06454 L
.51448 .06307 L
.51563 .0609 L
.51685 .05783 L
.51815 .05383 L
.52049 .04524 L
.52304 .03496 L
.52581 .02461 L
.52706 .02073 L
.52838 .01744 L
.52952 .01537 L
.53076 .0139 L
.53192 .0132 L
.53317 .01304 L
.53435 .01326 L
.53543 .01361 L
.54415 .01618 L
.56322 .02014 L
.57308 .02228 L
.57563 .02281 L
.57832 .02334 L
.57973 .02355 L
.58127 .02373 L
.58397 .024 L
.59416 .02497 L
.59674 .02523 L
.59801 .02537 L
.59917 .02548 L
.60024 .02556 L
.60136 .02562 L
.60373 .02571 L
.60645 .02583 L
.60713 .02586 L
.60777 .02589 L
.60899 .02593 L
.61028 .02593 L
.61094 .02592 L
.61166 .02589 L
.6124 .02585 L
.61319 .02581 L
.61461 .02572 L
.61734 .02558 L
.61869 .0255 L
.61992 .02541 L
.62223 .02516 L
.62473 .02485 L
.63383 .02367 L
.64358 .02195 L
.65427 .01946 L
.66425 .01698 L
Mistroke
.68408 .01222 L
.70564 .0076 L
.71569 .0059 L
.72635 .00439 L
.73635 .00322 L
.74551 .00237 L
.75489 .00171 L
.765 .00119 L
.77391 .00085 L
.78329 .00058 L
.79285 .00039 L
.79819 .0003 L
.80305 .00025 L
.80759 .0002 L
.8125 .00016 L
.82142 .00011 L
.82632 8e-05 L
.8309 7e-05 L
.83635 5e-05 L
.83893 5e-05 L
.84132 4e-05 L
.84253 4e-05 L
.84381 4e-05 L
.84653 3e-05 L
.85147 2e-05 L
.85442 2e-05 L
.85587 2e-05 L
.85719 2e-05 L
.8584 2e-05 L
.85968 2e-05 L
.86237 1e-05 L
.87189 1e-05 L
.87722 1e-05 L
.87844 1e-05 L
.87974 0 L
.88094 0 L
.88207 0 L
.8831 0 L
.88422 0 L
.88546 0 L
.88659 0 L
.88779 0 L
.88911 0 L
.89036 0 L
.8915 0 L
.89265 0 L
.89374 0 L
.89489 0 L
.89613 0 L
.89721 0 L
Mistroke
.89836 0 L
.89934 0 L
.90042 0 L
.90172 0 L
.90293 0 L
.90356 0 L
.90425 0 L
.90498 0 L
.90566 0 L
.90682 0 L
.90805 0 L
.90869 0 L
.90939 0 L
.91062 0 L
.91184 0 L
.91295 0 L
.91423 0 L
.91544 0 L
.91656 0 L
.91759 0 L
.91873 0 L
.91993 0 L
.92122 0 L
.92241 0 L
.92306 0 L
.92377 0 L
.92507 0 L
.92628 0 L
.92757 0 L
.92878 0 L
.92989 0 L
.93121 0 L
.93187 0 L
.9326 0 L
.93339 0 L
.93413 0 L
.93485 0 L
.93553 0 L
.93617 0 L
.93687 0 L
.93809 0 L
.93879 0 L
.93953 0 L
.94084 0 L
.94181 0 L
.94287 0 L
.944 0 L
.94505 0 L
.94605 0 L
.94696 0 L
Mistroke
.94801 0 L
.949 0 L
.95009 0 L
.95125 0 L
.95223 0 L
.95332 0 L
.95448 0 L
.95573 0 L
.95691 0 L
.95799 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`0Rooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00GoA4A4o`000?l0003o<S8bomgMg@1Gooooo`05odA4A?l0003o0000oc8b<_oMgMd09oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo02Gooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool09?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00omgMgOo<S8booooo`1Iooooo`03ogMgMolb<S;ooooo02Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Uooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool6o`0000Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[
ooooo`03ogMgMolb<S;ooooo05Wooooo00?oMgMgoc8b<_ooool0:?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo02Gooooo000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0Eoooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001Wooooo
00?oEEEEofIVI_l000001Oooool4o`0002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo1?l0001Hooooo`Co0000:?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool00omEEEGoIVIVo`000005ooooo`Co00009oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooC_ooool2o`0000;ooooo0_l0000Eooooo`00oooooom>
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5Oooool00?ooooooCoooool01?oMgMgo0000oa0@
4?o<c<`Fooooo`005?ooooooo`00033o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hFooooo`006ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`co00001oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo00Co0000oooooooooooooooo1?l00002ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
3ol00004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo013ooooo00Co8B4QogMgMomgMgOo<S8b5_ooool001_ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Looooo`Ko00002oooool00ol0003ooooo
ooooo`0Uooooo`;o00000oooool01?l0003oooooooooool0000_ooooo`03o`000?oooooooooo00[o
oooo1_l0000Mooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03oooool2o`0000;o
oooo0_l0000Eooooo`00Koooool3o`00037ooooo00?o0000ooooooooool00oooool00ol0003ooooo
o`00000iooooo`?o0000P?ooool007;ooooo0_l0000^ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooool000002?ooool4o`0002Sooooo1Ol00023ooooo`00M?ooool2o`0002cooooo00?o0000
ooooooooool01?ooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooooooo`Co00008?oo
ool4o`0008Sooooo001fooooo`Go00009oooool00ol0003oooooooooo`05ooooo`;o00001oooool0
0ol0003oooooooooo`06ooooo`Go00005oooool4o`0008cooooo001kooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool01Oooool2o`0000Oooooo00?o0000ooooooooool02oooool6o`00
00_ooooo1_l0002@ooooo`00O?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Ko
oooo0_l00007ooooo`03o`000?oooooooooo017ooooo2ol0002Fooooo`00O?ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo00Kooooo0_l00007ooooo`03o`000?oooooooooo0;;ooooo
001looooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool2o`0000Gooooo00?o
0000ooooooooool0/oooool007gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/oooool007gooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0/oooool007kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0]?ooool007kooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`07ooooo`;o00001?ooool00ol0003oooooooooo`2dooooo`00Oooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01ooo
ool2o`0000Cooooo00?o0000ooooooooool0]?ooool0083ooooo00?o0000ooooooooool00_l0000D
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool2o`0000?ooooo00?o0000
ooooooooool0]Oooool0083ooooo1?l000000ooooooo0000ooooo`0Aooooo`03o`000?oooooo0000
00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo
0;Gooooo0021ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooo`000005oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`2eoooo
o`00QOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo000000Gooooo00?o0000oooooooo
ool02?ooool2o`000004ooooool0003o0000o`000;Oooooo0026ooooo`03o`000?oooooooooo00Go
oooo0_l00008ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`02o`000;Sooooo0026ooooo`03o`000?oooooooooo00Gooooo0_l00008ooooo`03o`00
0?oooooo000000Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2jooooo`00Q_oo
ool00ol0003oooooooooo`05ooooo`;o00002?ooool00ol0003oooooo`000005ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0^_ooool008Oooooo00?o0000ooooooooool00oooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`2jooooo`00Qoooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo0;[ooooo0027ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
^_ooool008Oooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00006ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0;[o
oooo0028ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001_ooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2joooo
o`00R?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool02Oooool2o`000;_ooooo0028oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0;[ooooo0028
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0;[ooooo
0028ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0;[o
oooo0028ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2joooo
o`00ROooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0^_ooool008Wo
oooo00?o0000ooooool000001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooool000003?ooool00ol0003oooooooooo`2jooooo`00ROooool00ol0003ooooo
o`000004ooooo`05onk^k_l0003o0000oc8b<_o^k^h00_ooool00ol0003oooooooooo`02ob4Q8@04
o`000?oooooo0000ooooo`Go00001_ooool00ol0003oooooooooo`2jooooo`00ROooool2o`0000Go
oooo00GoMgMgo`000?ooooooV9RHogMgM`02ooooo`03o`000?oooooooooo00;o8B4Q00Wo0000oooo
ool0003ooooooiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`2jooooo`00T?oo
ool01Ol@413o0000oooooooooooo410@00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
o`000002ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0^_ooool0093ooooo00Go
0000ooooool0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
0oooool00onHV9So8B4Qonk^kP06ooooo`?o0000^_ooool0093ooooo00Go0000ooooool0003ooooo
o`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001?ooool00omgMgOoIVIV
ooooo`05ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05oa0@4?oooooo0000ooooool@4100
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`2jooooo`00T?ooool01omgMgOoV9RHo`000?nHV9SoMgMgooooool0
00001_ooool02?l0003oooooooooool0003o^[ZjoooooonHV9So410@1_ooool00ol0003ooooooooo
o`2jooooo`00T?ooool01oo^k^ko<S8bo`000?lb<S;ok^k^ooooool000001_ooool02?l0003ooooo
oooooonHV9So410@o`000?lQ8B7oc<c<1_ooool00ol0003oooooooooo`2jooooo`00T_ooool01Ol0
003ooooooooooooooooo000001Cooooo00?o0000ooooooooool0^_ooool009;ooooo00Go0000oooo
ooooooooooooo`00000Dooooo`03o`000?oooooooooo0;[ooooo002Booooo`05o`000?oooooooooo
ooooool000005?ooool00ol0003oooooooooo`2jooooo`00T_ooool01Ol0003ooooooooooooooooo
000001Cooooo00?o0000ooooooooool0^_ooool009?ooooo00Co0000oooooooooooo00005?ooool2
o`000;_ooooo002Cooooo`04o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool0^_ooool0
09?ooooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`2jooooo`00Toooool01?l0
003oooooooooool0000Dooooo`03o`000?oooooooooo0;[ooooo002Cooooo`04o`000?oooooooooo
o`0001Cooooo00?o0000ooooooooool0^_ooool009?ooooo00?o0000ooooool000005Oooool00ol0
003oooooooooo`2jooooo`00Toooool00ol0003oooooo`00000Eooooo`03o`000?oooooooooo0;[o
oooo002Cooooo`03o`000?oooooo000001Gooooo00?o0000ooooooooool0^_ooool009?ooooo00?o
0000ooooool000005Oooool00ol0003oooooooooo`2jooooo`00Toooool00ol0003oooooo`00000E
ooooo`;o0000^oooool009?ooooo00?o0000ooooool000005Oooool00ol0003oooooooooo`2joooo
o`00U?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0;[ooooo002Dooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool0
0ol0003oooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^_ooool0093ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol0
003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool3o`000;[ooooo002@
ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`00
0?oooooooooo0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`000007ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000
^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo
000000Kooooo0ol0002jooooo`00T?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000
oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0
^_ooool0093ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo
00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgM
gOl@413oV9RH00Sooooo00?o0000ooooooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0^_ooool0
093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Go410@oooooooooooooooooa0@
400;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2jooooo`00T?oo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o
0000^_ooool0093ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`00
0?o<c<`01_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0;[ooooo002@oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o
0000ooooooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@
413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00XOooool4o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0^_ooool00:?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`2jooooo`00Xoooool00ol0003oooooooooo`05ooooo`?o0000^_ooool00:?o
oooo00?o0000ooooooooool0`_ooool00:?ooooo00?o0000ooooooooool0`_ooool00:?ooooo00?o
0000ooooooooool0`_ooool00:?ooooo00?o0000ooooooooool0`_ooool00:7ooooo00?oEEEEofIV
I_l00000a?ooool00?ooooooJOooool006Wooooo00?oMgMgofIVI_ooool01?ooool00ol0003ooooo
ooooo`02ooooo`03okZj^_lb<S;ooooo00Oooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo
0_l00007ooooo`03o`000?oooooooooo00;ooooo00?oIVIVogMgMoooool03?ooool00ol0003o^[Zj
ooooo`2]ooooo`00J?ooool00ooMgMgo410@onk^kP05ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00?ok^k^oa0@4?oMgMd03?ooool2oc8b<Zkooooo001X
ooooo`03oeEEEOnHV9Sooooo00Gooooo00Ko0000oooooooooooooooooiRHV?l@4102o`000003ojVY
ZOoooooooooo00Cooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo
0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00?oQhN7ofIVI_ooool02oooool00on7QhOo0000okZj^P0<oooo
o`05oiRHV?l0003o0000odA4A?nj^[X04Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd0M_ooool006Sooooo00?o0000ooooooooool01Oooool0
2_l0003ooooooooooooooooo0000ojVYZOmEEEGoV9RHoeEEEOnj^[X5ooooo`0:o`000?oooooooooo
ooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o
^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooo
o`03onk^k_l0003ooooo00_ooooo00?oc<c<o`000?l@41003?ooool01_l@413o^[Zjonk^k_mgMgOo
410@ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`1eooooo`00J?ooool00olb<S;oooooooooo`05ooooo`0:o`000?oooooooooooooooolb<S;ok^k^
oiRHV?mEEEGogMgMoa0@40Gooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo07Cooooo001Xooooo`03oc8b<_oooooooooo00Gooooo00_o0000oooo
oooooooooooookZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c004ooooo`03o`000?oooooooooo00;o
oooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00?ooooo1_l0000<ooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0MOooool006So
oooo00?o0000onk^k_ooool01Oooool02ol0003oooooooooooooooook^k^o`000?oooooo0000oooo
oomVIVKoQhN700Cooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03
onk^k_l0003ooooo01[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0;ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`0M_ooool006Sooooo00?oEEEEogMgMoooool01Oooool02?l0003o
ooooooooooooooooIVIVoiRHV?oooooo<S8b0_nj^[X00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool00omgMgOoEEEEooooo`02ooooo`Co0000
4_ooool00ol@413o0000o`000003o`0001Cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`1hooooo`00J?ooool00ooMgMgo410@onk^kP05ooooo`03o`000?oooooooooo00Cooooo00?o
IVIVohN7Qoooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03onk^k_l@413ogMgM00Cooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0N?ooool006Wooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`04
ooooo`03ojVYZOm4A4Cooooo00Gooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l00007
ooooo`03o`000?oooooooooo00;ooooo00?oIVIVogMgMoooool01Oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01?ooooo00?oEEEEofIVI_l000003Oooool4o`0007Oooooo002boooo
o`03o`000?oooooooooo0;?ooooo002_ooooo`04o`000?ooooooooooo`000;Gooooo002`ooooo`;o
0000]_ooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.8522, -0.080387, \
0.130126, 0.00668404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
176.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.03279 0 L
.03405 0 L
.03477 0 L
.03543 0 L
.03665 0 L
.03793 0 L
.03908 0 L
.04016 0 L
.04144 0 L
.04262 0 L
.04384 0 L
.04501 0 L
.04624 0 L
.04693 0 L
.04758 0 L
.04827 0 L
.04892 0 L
.05014 0 L
.05146 0 L
.0522 0 L
.05288 0 L
.05395 0 L
.0551 0 L
.05636 0 L
.05753 0 L
.05885 0 L
.0601 0 L
.06122 0 L
.06244 0 L
.0637 0 L
.0644 0 L
.06505 0 L
.06624 0 L
.06749 0 L
.06815 0 L
.06887 0 L
.07015 0 L
.07093 0 L
.07167 0 L
.07233 0 L
.07306 0 L
.07376 0 L
.07442 0 L
.07512 0 L
.07587 0 L
.07657 0 L
.07723 0 L
.07847 0 L
.07917 0 L
Mistroke
.07992 0 L
.08127 0 L
.0821 0 L
.08288 0 L
.08358 0 L
.08433 0 L
.08551 0 L
.08678 0 L
.08751 0 L
.08817 0 L
.08947 0 L
.09011 0 L
.0908 0 L
.09155 0 L
.09225 0 L
.0935 0 L
.09422 0 L
.09488 0 L
.09607 0 L
.09732 0 L
.09839 0 L
.09955 0 L
.10081 0 L
.10152 0 L
.10216 0 L
.1034 0 L
.10458 0 L
.10574 0 L
.10698 1e-05 L
.10806 1e-05 L
.10922 1e-05 L
.10994 1e-05 L
.11059 1e-05 L
.11189 1e-05 L
.11315 1e-05 L
.11433 1e-05 L
.11547 1e-05 L
.1167 1e-05 L
.11795 1e-05 L
.11866 1e-05 L
.11932 1e-05 L
.11997 1e-05 L
.12067 1e-05 L
.12141 1e-05 L
.12209 1e-05 L
.1234 1e-05 L
.12463 1e-05 L
.12681 2e-05 L
.12788 2e-05 L
.12887 2e-05 L
Mistroke
.13001 2e-05 L
.13125 2e-05 L
.1323 2e-05 L
.13342 2e-05 L
.13407 2e-05 L
.13477 2e-05 L
.13604 3e-05 L
.13718 3e-05 L
.13842 3e-05 L
.1396 3e-05 L
.14086 3e-05 L
.14202 3e-05 L
.1431 3e-05 L
.14818 5e-05 L
.14925 5e-05 L
.15039 5e-05 L
.15165 5e-05 L
.1528 5e-05 L
.15535 6e-05 L
.15777 7e-05 L
.15902 7e-05 L
.16033 8e-05 L
.16102 8e-05 L
.16177 8e-05 L
.16309 9e-05 L
.16761 .00011 L
.16876 .00011 L
.16984 .00011 L
.17081 .00012 L
.17186 .00012 L
.17428 .00014 L
.17687 .00016 L
.17812 .00016 L
.17931 .00017 L
.18037 .00018 L
.18153 .00019 L
.18389 .00021 L
.18643 .00024 L
.18883 .00026 L
.19101 .00028 L
.19363 .00033 L
.19641 .00037 L
.20142 .00045 L
.20664 .00057 L
.21227 .0007 L
.22247 .00105 L
.23282 .00152 L
.24246 .00198 L
.24773 .00229 L
.25003 .00244 L
Mistroke
.25252 .00266 L
.25526 .00297 L
.25785 .00329 L
.26355 .00426 L
.28337 .00857 L
.28819 .00953 L
.29085 .01011 L
.29338 .01082 L
.29635 .01196 L
.29907 .01317 L
.3044 .0159 L
.30933 .01856 L
.31398 .0204 L
.31934 .02201 L
.3217 .02259 L
.32299 .02294 L
.3242 .02334 L
.32525 .02378 L
.32639 .02439 L
.32879 .02618 L
.33101 .02849 L
.33303 .03122 L
.33538 .03524 L
.33793 .04071 L
.34258 .05223 L
.34491 .05765 L
.34743 .06257 L
.34858 .0644 L
.3498 .06595 L
.35084 .06694 L
.35197 .06763 L
.35267 .06784 L
.35334 .0679 L
.35457 .06765 L
.35526 .06732 L
.3559 .06692 L
.35735 .06578 L
.35993 .06345 L
.36119 .06246 L
.36235 .06177 L
.36355 .06134 L
.36469 .06127 L
.36589 .06165 L
.3672 .06267 L
.36791 .06351 L
.36855 .06445 L
.36998 .06724 L
.3713 .07061 L
.37255 .07438 L
.3777 .09306 L
Mistroke
.38043 .10241 L
.38193 .10674 L
.38335 .11005 L
.38462 .11217 L
.38534 .11296 L
.386 .11341 L
.38717 .11349 L
.38841 .11258 L
.38957 .11083 L
.39066 .10849 L
.39313 .10131 L
.39556 .09327 L
.39688 .08916 L
.39811 .08589 L
.39881 .08437 L
.39944 .08325 L
.40015 .08237 L
.4009 .08189 L
.40222 .0824 L
.40346 .08467 L
.40453 .08811 L
.4057 .09352 L
.40808 .10903 L
.41233 .14439 L
.41473 .16167 L
.41542 .16553 L
.41607 .16858 L
.4173 .17247 L
.41845 .17367 L
.41952 .17243 L
.42069 .16836 L
.42194 .16097 L
.42649 .11332 L
.42898 .08223 L
.43129 .05666 L
.4326 .04493 L
.4338 .03644 L
.43444 .03283 L
.43513 .02965 L
.43586 .02713 L
.43655 .02552 L
.43777 .02446 L
.43906 .02559 L
.44016 .02812 L
.44138 .03219 L
.44586 .05197 L
.44822 .06161 L
.45075 .07013 L
.45317 .07684 L
.45431 .07943 L
Mistroke
.45536 .08132 L
.45642 .08259 L
.45757 .08298 L
.45858 .08227 L
.45965 .08027 L
.46085 .07635 L
.46215 .07022 L
.46448 .0552 L
.46721 .03553 L
.46855 .02683 L
.46979 .02 L
.47089 .01502 L
.47211 .01073 L
.47334 .00753 L
.47464 .00512 L
.47574 .00367 L
.47692 .00255 L
.47804 .00178 L
.47906 .00125 L
.48028 .0008 L
.48158 .0005 L
.48281 .00041 L
.48392 .00052 L
.48523 .00091 L
.48597 .00128 L
.48665 .00173 L
.48791 .00286 L
.48923 .00452 L
.49051 .00659 L
.49187 .00937 L
.49433 .01578 L
.49994 .03448 L
.50249 .04283 L
.50389 .04688 L
.5052 .05021 L
.50643 .05279 L
.50708 .05392 L
.50776 .05492 L
.50897 .05617 L
.51008 .05669 L
.51139 .05648 L
.51213 .05596 L
.5128 .05524 L
.51411 .05319 L
.51535 .05053 L
.51812 .04261 L
.52112 .03246 L
.52374 .02384 L
.52619 .01702 L
.52743 .01431 L
Mistroke
.52875 .01204 L
.52951 .01107 L
.53023 .01036 L
.53087 .0099 L
.53157 .00956 L
.53284 .00934 L
.53399 .00946 L
.53463 .0096 L
.53532 .00979 L
.53658 .01015 L
.539 .01069 L
.54123 .01105 L
.56163 .01523 L
.58069 .01966 L
.599 .02278 L
.60427 .02346 L
.60687 .02373 L
.60927 .02404 L
.61039 .02416 L
.61144 .02424 L
.61254 .0243 L
.61375 .02434 L
.6149 .02437 L
.6161 .02441 L
.61742 .02449 L
.61864 .02457 L
.61987 .02466 L
.62052 .0247 L
.6212 .02473 L
.62247 .02477 L
.62363 .02477 L
.62475 .02477 L
.62579 .02476 L
.62694 .02478 L
.62817 .02481 L
.62948 .02486 L
.63016 .02488 L
.6309 .0249 L
.63161 .0249 L
.63224 .02489 L
.63349 .02485 L
.6347 .02479 L
.636 .02471 L
.63836 .02459 L
.63952 .02455 L
.64077 .02449 L
.64194 .02441 L
.64301 .02431 L
.64536 .02402 L
.64793 .02369 L
Mistroke
.65672 .02247 L
.67583 .01892 L
.69659 .01416 L
.716 .01004 L
.7374 .00621 L
.74716 .00486 L
.75768 .00363 L
.76753 .0027 L
.7767 .00201 L
.78628 .00146 L
.79676 .00102 L
.80697 .00071 L
.81264 .00056 L
.81786 .00046 L
.82275 .00038 L
.82812 .0003 L
.83352 .00024 L
.83923 .00019 L
.84426 .00015 L
.84965 .00012 L
.85939 8e-05 L
.86194 7e-05 L
.86334 7e-05 L
.86466 6e-05 L
.86589 6e-05 L
.86722 6e-05 L
.86953 5e-05 L
.87491 4e-05 L
.87633 4e-05 L
.87785 4e-05 L
.87926 3e-05 L
.88059 3e-05 L
.88184 3e-05 L
.88255 3e-05 L
.88321 3e-05 L
.88444 3e-05 L
.88559 2e-05 L
.88685 2e-05 L
.88825 2e-05 L
.88894 2e-05 L
.88969 2e-05 L
.89041 2e-05 L
.89107 2e-05 L
.89224 2e-05 L
.89349 2e-05 L
.89465 2e-05 L
.89571 1e-05 L
.90069 1e-05 L
.90557 1e-05 L
.90675 1e-05 L
Mistroke
.90802 1e-05 L
.90875 1e-05 L
.90941 1e-05 L
.91072 1e-05 L
.91189 1e-05 L
.91298 1e-05 L
.91416 0 L
.91545 0 L
.91657 0 L
.91763 0 L
.91874 0 L
.91994 0 L
.92112 0 L
.92241 0 L
.92362 0 L
.92474 0 L
.92605 0 L
.92677 0 L
.92743 0 L
.9286 0 L
.92988 0 L
.93055 0 L
.93127 0 L
.93196 0 L
.9326 0 L
.93333 0 L
.93412 0 L
.93485 0 L
.93551 0 L
.93681 0 L
.93754 0 L
.93821 0 L
.93944 0 L
.94076 0 L
.94184 0 L
.94283 0 L
.94383 0 L
.94476 0 L
.94584 0 L
.94702 0 L
.94915 0 L
.95014 0 L
.9512 0 L
.95236 0 L
.95345 0 L
.95802 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`0Rooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00GoA4A4o`000?l0003o<S8bomgMg@1Gooooo`05odA4A?l0003o0000oc8b<_oMgMd09oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo02Gooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool09?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00omgMgOo<S8booooo`1Iooooo`03ogMgMolb<S;ooooo02Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Uooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool6o`0000Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[
ooooo`03ogMgMolb<S;ooooo05Wooooo00?oMgMgoc8b<_ooool0:?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo02Gooooo000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0Eoooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001Wooooo
00?oEEEEofIVI_l000001Oooool4o`0002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo1?l0001Hooooo`Co0000:?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool00omEEEGoIVIVo`000005ooooo`Co00009oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooC_ooool2o`0000;ooooo0_l0000Eooooo`00oooooom>
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5Oooool00?ooooooCoooool01?oMgMgo0000oa0@
4?o<c<`Fooooo`005?ooooooo`00033o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hFooooo`006ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`02ooooo`co00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02o`000003ooooool0
003ooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`co00001ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?oo
ool01?lQ8B7oMgMgogMgMolb<S8Fooooo`006oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo01Sooooo0ol0000Booooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool0000_ooooo`03o`000?oooooooooo01;ooooo2?l0000Cooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool03oooool2o`0000;ooooo0_l0000Eooooo`00JOoo
ool4o`0003Kooooo00?o0000ooooooooool00oooool00ol0003oooooo`000008ooooo`Co0000<Ooo
ool7o`0007Sooooo001]ooooo`?o0000<oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
000000Oooooo0_l00002ooooo`Go0000:Oooool4o`0007oooooo001`ooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo
00Kooooo1_l0000Pooooo`?o0000Poooool0077ooooo0ol0000^ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooool000001oooool00ol0003oooooooooo`0<ooooo`Go00005_ooool5o`0008Ko
oooo001dooooo`?o0000:oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003ooooo
ooooo`0Booooo`Oo00002Oooool6o`0008_ooooo001fooooo`;o00008?ooool2o`0000Oooooo00?o
0000ooooooooool01_ooool2o`0000Kooooo00?o0000ooooooooool06?ooool:o`00097ooooo001h
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooool000001oooool00ol0003oooooooooo`06
ooooo`;o00001Oooool00ol0003oooooooooo`2dooooo`00N?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooo000000Oooooo00?o0000ooooooooool01oooool2o`0000Cooooo00?o0000oooo
ooooool0]?ooool007Wooooo00?o0000ooooooooool06oooool00ol0003oooooo`000007ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2dooooo`00
N_ooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;Gooooo001jooooo`03o`00
0?oooooooooo01[ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`07ooooo`;o
00000oooool00ol0003oooooooooo`2eooooo`00N_ooool00ol0003oooooooooo`0Jooooo`04o`00
0?ooooooooooo`0000Kooooo00?o0000ooooooooool01oooool2o`0000?ooooo00?o0000oooooooo
ool0]Oooool007_ooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool02?ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo0;Go
oooo001kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooool0003oooooo`00002hooooo`00
Noooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000;o0000^?ooool007cooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`2jooooo`00OOooool01?l0003ooooooooooooo
ool3o`0001;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Sooooo0_l0002kooooo`00OOooool4o`0000;ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`2jooooo`00O_ooool2o`0000Cooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`2j
ooooo`00Q?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`00000:ooooo`03o`000?oooooooooo0;[ooooo0024ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo
0;[ooooo0024ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooo`00000;ooooo`03o`000?oooooooooo0;[ooooo0025ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`;o00003?ooool00ol0003ooooo
ooooo`2jooooo`00QOooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000Oooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`2jooooo`00QOooool00ol0003oooooooooo`04
ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`2j
ooooo`00Q_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool04_ooool2o`000;_ooooo0026ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0;[ooooo0027oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0^_ooool008Oooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2j
ooooo`00Qoooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0;[ooooo0028ooooo`03o`000?oooooo0000
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
0;[ooooo0028ooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0^_ooool008oooooo00Oo0000onk^k_lb<S;o0000oc8b<_o^k^ko0000
00Cooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`2jooooo`00Soooool01ol0003o
MgMgoiRHV?ooooooV9RHogMgMol000001?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A006ooooo`03o`000?oooooooooo0;[ooooo002?ooooo`03o`000?l@413ooooo00;ooooo00?o410@
o`000?ooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0;[ooooo002?oooo
o`;o00000oooool2o`0000cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;[ooooo002@ooooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo
0;[ooooo002@ooooo`05o`000?ooooooooooooooool000003oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0;[ooooo002@ooooo`05o`000?nHV9SooooooiRHV?l000002oooool01Ol0
003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Go0000oc8b
<_l0003o<S8bo`00000;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooooooo
o`2jooooo`00T?ooool01Ol0003ooooooooooooooooo000001Kooooo00?o0000ooooooooool0^_oo
ool0093ooooo00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo0;[ooooo002@
ooooo`05o`000?ooooooooooooooool000005_ooool00ol0003oooooooooo`2jooooo`00T?ooool0
1?l0003oooooooooool0000Gooooo`03o`000?oooooooooo0;[ooooo002Aooooo`03o`000?oooooo
000001Oooooo0_l0002kooooo`00TOooool00ol0003oooooo`00000Gooooo`03o`000?oooooooooo
0;[ooooo002Aooooo`03o`000?oooooo000001Oooooo00?o0000ooooooooool0^_ooool0097ooooo
00?o0000ooooool000005oooool00ol0003oooooooooo`2jooooo`00T_ooool2o`0001Oooooo00?o
0000ooooooooool0^_ooool009;ooooo0_l0000Gooooo`03o`000?oooooooooo0;[ooooo002Boooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0;[ooooo002@
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
0006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05o`000?ooooooooooooooool000002ooo
ool01?m4A4CogMgMooooool00007ooooo`?o0000^_ooool0093ooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0^_ooool0093ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooooooo
ool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oo
oooo00?o0000ooooooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03
ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000;[ooooo002@
ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0^_ooool0093ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooo
oooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2jooooo`00
T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003o
ooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0
003o410@1_ooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05o`000?ooooooooooooooool0
00002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002jooooo`00T?ooool01Ol0003o
oooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooo
oooo0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj
^[[o410@00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`2jooooo`00T?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002Qooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`2jooooo`00Xoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;[ooooo002S
ooooo`03o`000?oooooooooo00Gooooo0ol0002jooooo`00Xoooool00ol0003oooooooooo`32oooo
o`00Xoooool00ol0003oooooooooo`32ooooo`00Xoooool00ol0003oooooooooo`32ooooo`00Xooo
ool00ol0003oooooooooo`32ooooo`00XOooool00omEEEGoIVIVo`000034ooooo`00oooooomYoooo
o`00JOooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o^[Zjoc8b<_oo
ool01oooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Oooooo00?o0000oooooooo
ool00_ooool00omVIVKoMgMgooooo`0<ooooo`03o`000?nj^[[ooooo0:gooooo001Xooooo`03omgM
gOl@413ok^k^00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00oo^k^ko410@omgMg@0<ooooo`;o<S8b[_ooool006Sooooo00?oEEEEoiRHV?ooool01Ooo
ool01_l0003oooooooooooooooooV9RHoa0@40;o000000?oZJVYooooooooool01?ooool01?l0003o
ooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`00
0?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool0
0on7QhOoIVIVooooo`0;ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj
^P0Aooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@
olc<c01gooooo`00J?ooool00ol0003oooooooooo`05ooooo`0:o`000?ooooooooooooooool0003o
ZJVYoeEEEOnHV9SoEEEEokZj^PGooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0
003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?ok^k^o`000?ooool02oooool0
0oo<c<co0000oa0@400<ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l0000<ooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40Moooool006Sooooo
00?o<S8booooooooool01Oooool02_l0003ooooooooooooooooo<S8bonk^k_nHV9SoEEEEomgMgOl@
4105ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool01Ol0003ooooo
oooooooooooo000007Oooooo001Xooooo`03oc8b<_oooooooooo00Gooooo00_o0000oooooooooooo
oooookZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c004ooooo`03o`000?oooooooooo00;ooooo00Co
k^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo
1_l0000<ooooo`03o`000?oooooooooo00[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@1gooooo`00
J?ooool00ol0003ok^k^ooooo`05ooooo`0;o`000?ooooooooooooooooo^k^ko0000ooooool0003o
ooooofIVI_n7QhL01?ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?ok^k^o`000?ooool06_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00[ooooo
00Go0000oeEEEOl0003o410@olc<c01gooooo`00J?ooool00omEEEGoMgMgooooo`05ooooo`08o`00
0?oooooooooooooooomVIVKoV9RHoooooolb<S82okZj^P03o`000?oooooooooo00;ooooo00Co0000
oooooooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03ogMgMomEEEGooooo00;ooooo1?l0
000Booooo`03oa0@4?l0003o000000?o00005?ooool00ol0003oooooooooo`0:ooooo`03oeEEEOn7
QhOooooo07Wooooo001Xooooo`03omgMgOl@413ok^k^00Gooooo00?o0000ooooooooool01?ooool0
0omVIVKoQhN7ooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?ok^k^oa0@4?oMgMd01?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool0
0ooMgMgo410@oiRHV01iooooo`00JOooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?oZJVYodA4A?ooool01Oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`00
00Oooooo00?o0000ooooooooool00_ooool00omVIVKoMgMgooooo`05ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool04oooool00omEEEGoIVIVo`00000=ooooo`04olc<c?m4A4Co0000
oa0@47Oooooo002booooo`03o`000?oooooooooo0;?ooooo002_ooooo`04o`000?ooooooooooo`00
0;Gooooo002`ooooo`;o0000]_ooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.8522, -0.080387, \
0.130126, 0.00668404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
176.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03056 0 L
.03162 0 L
.03279 0 L
.03397 0 L
.03524 0 L
.03642 0 L
.0375 0 L
.03875 0 L
.03942 0 L
.04012 0 L
.04142 0 L
.04262 0 L
.04387 0 L
.04519 0 L
.04588 0 L
.04664 0 L
.04733 0 L
.04797 0 L
.04925 0 L
.05041 0 L
.05105 0 L
.05175 0 L
.05302 0 L
.05414 0 L
.05539 0 L
.05669 0 L
.05791 0 L
.05905 0 L
.06009 0 L
.06124 0 L
.06244 0 L
.0631 0 L
.0638 0 L
.06509 0 L
.06623 0 L
.06748 0 L
.06819 0 L
.06885 0 L
.06954 0 L
.07029 0 L
.07098 0 L
.07164 0 L
.07287 0 L
.07404 0 L
Mistroke
.07528 1e-05 L
.07645 1e-05 L
.07751 1e-05 L
.07876 1e-05 L
.07947 1e-05 L
.08012 1e-05 L
.08131 1e-05 L
.08257 1e-05 L
.08327 1e-05 L
.08394 1e-05 L
.08519 1e-05 L
.08589 1e-05 L
.08654 1e-05 L
.08725 1e-05 L
.088 1e-05 L
.08925 1e-05 L
.09041 1e-05 L
.09169 1e-05 L
.09241 1e-05 L
.09307 1e-05 L
.09437 1e-05 L
.09508 1e-05 L
.09575 2e-05 L
.09655 2e-05 L
.09727 2e-05 L
.09795 2e-05 L
.09868 2e-05 L
.09939 2e-05 L
.10017 2e-05 L
.10099 2e-05 L
.10175 2e-05 L
.10458 2e-05 L
.10567 2e-05 L
.10682 2e-05 L
.10808 2e-05 L
.10923 2e-05 L
.11031 3e-05 L
.11132 3e-05 L
.11251 3e-05 L
.1136 3e-05 L
.11473 4e-05 L
.1158 4e-05 L
.11693 4e-05 L
.11816 4e-05 L
.11943 4e-05 L
.12007 4e-05 L
.12078 4e-05 L
.12319 5e-05 L
.12383 5e-05 L
.12454 5e-05 L
Mistroke
.12581 5e-05 L
.12657 5e-05 L
.12728 5e-05 L
.12793 6e-05 L
.12863 6e-05 L
.12929 6e-05 L
.13 6e-05 L
.1313 7e-05 L
.13371 8e-05 L
.14346 .00011 L
.1448 .00012 L
.14624 .00012 L
.14693 .00012 L
.14759 .00012 L
.14883 .00013 L
.15154 .00015 L
.15451 .00017 L
.15573 .00017 L
.15687 .00018 L
.15806 .00019 L
.15938 .0002 L
.16213 .00023 L
.16467 .00026 L
.16972 .00032 L
.17435 .0004 L
.18478 .0006 L
.19394 .00083 L
.20372 .00112 L
.21445 .00156 L
.22443 .00212 L
.22941 .00246 L
.23468 .00294 L
.23744 .00323 L
.24046 .00363 L
.24579 .00453 L
.26595 .00907 L
.27073 .00983 L
.27593 .01067 L
.27832 .01109 L
.28085 .01165 L
.28324 .01234 L
.28541 .01311 L
.29104 .01563 L
.29633 .01885 L
.30631 .02564 L
.31138 .02896 L
.31611 .03234 L
.32104 .03723 L
.32365 .04067 L
.32644 .04523 L
Mistroke
.34493 .07005 L
.34991 .06677 L
.35234 .06462 L
.35341 .06376 L
.35457 .06297 L
.35577 .06239 L
.35691 .06215 L
.35822 .06233 L
.35943 .06299 L
.36013 .06361 L
.36079 .06436 L
.36203 .0662 L
.36336 .0688 L
.36479 .0723 L
.37063 .09259 L
.37319 .10303 L
.37601 .11349 L
.37726 .11733 L
.37861 .12063 L
.37988 .12287 L
.38104 .12409 L
.38235 .1245 L
.38309 .12427 L
.38377 .12376 L
.38503 .12211 L
.38566 .12095 L
.38636 .11942 L
.3889 .11224 L
.39162 .10343 L
.39293 .0996 L
.39418 .09665 L
.39529 .09475 L
.3965 .09365 L
.39779 .09366 L
.39844 .09413 L
.39916 .09502 L
.40042 .09747 L
.4016 .10067 L
.40447 .11096 L
.40718 .12128 L
.4083 .12473 L
.40948 .12744 L
.41079 .12897 L
.41199 .12878 L
.41318 .12698 L
.4143 .12379 L
.4153 .11974 L
.41639 .11419 L
.4189 .09755 L
.42154 .07646 L
Mistroke
.42628 .03978 L
.42858 .02625 L
.42988 .02043 L
.43105 .01626 L
.43215 .01334 L
.43334 .01118 L
.43446 .01007 L
.4355 .00982 L
.43671 .01043 L
.43784 .01186 L
.43908 .01439 L
.44041 .01818 L
.44313 .02916 L
.44562 .04221 L
.44817 .05678 L
.44957 .06443 L
.45089 .0709 L
.45212 .07592 L
.45277 .07805 L
.45345 .07987 L
.45466 .08184 L
.45578 .08208 L
.45704 .0804 L
.45821 .07693 L
.4595 .07112 L
.46089 .06289 L
.46359 .04334 L
.46647 .02329 L
.46767 .0166 L
.46897 .01089 L
.46972 .00833 L
.4704 .00641 L
.47109 .00484 L
.47174 .00369 L
.47287 .00228 L
.47412 .00142 L
.47533 .00105 L
.47662 .00099 L
.47736 .00105 L
.47805 .00116 L
.4788 .00133 L
.4796 .00155 L
.48094 .00201 L
.48241 .00266 L
.48372 .00337 L
.48513 .00429 L
.48768 .00651 L
.48901 .00807 L
.49025 .00983 L
.49306 .01506 L
Mistroke
.49818 .02801 L
.50061 .03433 L
.50318 .04014 L
.50538 .04406 L
.50662 .04574 L
.50779 .04689 L
.50907 .04762 L
.51024 .04774 L
.51088 .04757 L
.51159 .04718 L
.51287 .04594 L
.51352 .04504 L
.51425 .04384 L
.51572 .04084 L
.51836 .034 L
.52315 .02042 L
.52567 .01446 L
.52704 .01188 L
.52832 .00999 L
.52947 .00871 L
.53071 .00781 L
.53141 .00749 L
.53208 .0073 L
.53332 .0072 L
.53447 .0073 L
.53553 .00748 L
.53791 .00791 L
.54692 .00911 L
.58634 .01615 L
.5965 .01835 L
.60614 .02026 L
.61553 .02174 L
.62009 .02234 L
.62423 .02285 L
.62874 .02325 L
.63124 .0235 L
.63234 .02359 L
.63354 .02368 L
.63476 .02374 L
.63605 .02379 L
.63877 .02387 L
.63998 .02391 L
.64129 .02396 L
.64254 .02401 L
.64368 .02403 L
.64431 .02403 L
.64501 .02403 L
.64574 .02402 L
.64642 .024 L
.64769 .02398 L
Mistroke
.64891 .02396 L
.64958 .02395 L
.65031 .02394 L
.6516 .02394 L
.65233 .02393 L
.6531 .02392 L
.65383 .02391 L
.6545 .02389 L
.65579 .02383 L
.65699 .02376 L
.65969 .0236 L
.66224 .02347 L
.66458 .02332 L
.66573 .02321 L
.66699 .02308 L
.66927 .02282 L
.6743 .02226 L
.68338 .02089 L
.70404 .01702 L
.72341 .01293 L
.7448 .00886 L
.76526 .00565 L
.78404 .00351 L
.79345 .00269 L
.80337 .00199 L
.81332 .00145 L
.82422 .00101 L
.83448 .00071 L
.84381 .00051 L
.84898 .00043 L
.85458 .00034 L
.85984 .00028 L
.86475 .00023 L
.87421 .00016 L
.87678 .00014 L
.87922 .00013 L
.88057 .00012 L
.88204 .00012 L
.88461 .0001 L
.8899 8e-05 L
.89552 7e-05 L
.90045 5e-05 L
.90565 4e-05 L
.90821 4e-05 L
.91101 3e-05 L
.9136 3e-05 L
.91472 3e-05 L
.91595 3e-05 L
.91669 3e-05 L
.91738 2e-05 L
Mistroke
.91873 2e-05 L
.92171 2e-05 L
.92304 2e-05 L
.92448 2e-05 L
.92514 2e-05 L
.92584 2e-05 L
.92708 2e-05 L
.93173 1e-05 L
.93302 1e-05 L
.93373 1e-05 L
.9344 1e-05 L
.93569 1e-05 L
.93687 1e-05 L
.93811 1e-05 L
.93925 1e-05 L
.94051 1e-05 L
.94114 1e-05 L
.94183 1e-05 L
.94253 1e-05 L
.94318 1e-05 L
.94394 1e-05 L
.94464 1e-05 L
.94589 1e-05 L
.9466 1e-05 L
.94726 1e-05 L
.94821 1e-05 L
.94922 1e-05 L
.95008 1e-05 L
.95102 0 L
.95204 0 L
.95313 0 L
.95415 0 L
.95509 0 L
.95597 0 L
.9569 0 L
.95792 0 L
.95887 0 L
.95975 0 L
.96059 0 L
.96156 0 L
.96245 0 L
.96328 0 L
.96406 0 L
.96499 0 L
.96582 0 L
.96661 0 L
.96735 0 L
.96814 0 L
.96899 0 L
.96986 0 L
Mistroke
.97081 0 L
.97181 0 L
.97274 0 L
.97359 0 L
.9744 0 L
.97534 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`0Rooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00GoA4A4o`000?l0003o<S8bomgMg@1Gooooo`05odA4A?l0003o0000oc8b<_oMgMd09oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo02Gooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool09?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00omgMgOo<S8booooo`1Iooooo`03ogMgMolb<S;ooooo02Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Uooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool6o`0000Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[
ooooo`03ogMgMolb<S;ooooo05Wooooo00?oMgMgoc8b<_ooool0:?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo02Gooooo000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0Eoooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001Wooooo
00?oEEEEofIVI_l000001Oooool4o`0002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo1?l0001Hooooo`Co0000:?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool00omEEEGoIVIVo`000005ooooo`Co00009oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooC_ooool2o`0000;ooooo0_l0000Eooooo`00oooooom>
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5Oooool00?ooooooCoooool01?oMgMgo0000oa0@
4?o<c<`Fooooo`005?ooooooo`00033o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hFooooo`006ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool;o`0000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo1_l00004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`03ooooo`ko00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo013ooooo00Co8B4QogMgMomgMgOo<S8b5_ooool001_ooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0@ooooo`Co00006Oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000008ooooo`?o00009?ooool00ol0003ooooo
ooooo`0Jooooo`Ko00003Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00oooooo
0_l00002ooooo`;o00005Oooool006;ooooo1_l0000_ooooo`;o00002Oooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000001_l0000eooooo`Ko0000
L?ooool006Sooooo1?l0000Zooooo`?o00002Oooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool01oooool6o`0002Wooooo1_l0001fooooo`00K?oo
ool00ol0003oooooooooo`0Wooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00gooooo1Ol0000Nooooo`Ko0000
O?ooool006gooooo0_l0000Wooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo01?ooooo1_l0000Cooooo`Go0000
P_ooool006oooooo00?o0000ooooooooool09?ooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`0Ioooooa?o0000
Qoooool0073ooooo0_l0000Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`06ooooo`;o00001_ooool00ol0003oooooooooo`2cooooo`00L_ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`06ooooo`;o00001Oooool00ol0003oooooooooo`2dooooo`00Loooool2o`00
023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Kooooo0ol00004ooooo`03o`000?oooooooooo0;Cooooo001eooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2dooooo`00M_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`08ooooo`;o00000oooool00ol0003oooooooooo`2eooooo`00M_ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`08ooooo`04o`000?oooooo0000ooooo`;o0000]oooool007Kooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooo`000002o`000;Sooooo001fooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00Co0000
oooooooooooo0000^Oooool007Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2j
ooooo`00N?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`00000;ooooo`03o`000?oooooooooo0;[ooooo001iooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000
ooooooooool0^_ooool007[ooooo00?o0000ooooooooool00_ooool3o`0001;ooooo00?o0000oooo
ooooool01Oooool01?l0003oooooooooool0000;ooooo`;o0000^oooool007_ooooo00Co0000oooo
ool0003o00000_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00002oooool00ol0003oooooooooo`2jooooo`00O?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool0
000;ooooo`03o`000?oooooooooo0;[ooooo0022ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01_ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo0;[ooooo0022
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool2o`0000cooooo00?o0000
ooooooooool0^_ooool008?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07oooo
o`;o00003?ooool00ol0003oooooooooo`2jooooo`00Poooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Oooooo0_l0000<ooooo`03o`000?oooooooooo0;[ooooo0023ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2jooooo`00Q?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0^_oo
ool008Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01Kooooo0_l0002kooooo`00Q?ooool00ol0003oooooooooo`04ooooo`;o00001Oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo0;[ooooo0025ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooool000001?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0;[o
oooo0025ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo0;[ooooo0025ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0;[o
oooo0025ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo0000
01Sooooo00?o0000ooooooooool0^_ooool008Gooooo00Go0000ooooooooooooooooo`000004oooo
o`05o`000?ooooooooooooooool000006?ooool00ol0003oooooooooo`2jooooo`00QOooool01Ol0
003ooooooooooooooooo000000Cooooo00Oo0000ooooooo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`2jooooo`00Q_ooool01?l0003ooooooooo
ool00005ooooo`06o`000?mgMgOo0000oooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0;[ooooo0026ooooo`?o00001_ooool00ol0
003o410@o`000002ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0
003oooooooooo`2jooooo`00Qoooool2o`0000Kooooo0ol00002ooooo`03o`000?oooooooooo00_o
oooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;[ooooo002@ooooo`;o00000_ooool00ol0003ooooo
ooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0^_ooool0093ooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41001_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2
o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0;[ooooo002@oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006
ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05o`000?ooooooooooooooool000002oooool0
1?m4A4CogMgMooooool00007ooooo`?o0000^_ooool0093ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0^_ooool0093ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0
^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo
00?o0000ooooooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMg
Mol0003ooooo00Kooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooooooo
ool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000;[ooooo002@oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool0^_ooool0093ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mE
EEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooo
oooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2jooooo`00T?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003ooooo
ooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o
410@1_ooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003ooooooooo
o`2jooooo`00T?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05o`000?ooooooooooooooool00000
2oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002jooooo`00T?ooool01Ol0003ooooo
oooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo
0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o
410@00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`2jooooo`00T?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002Qooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooooooo
o`2jooooo`00Xoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;[ooooo002Soooo
o`03o`000?oooooooooo00Gooooo0ol0002jooooo`00Xoooool00ol0003oooooooooo`32ooooo`00
Xoooool00ol0003oooooooooo`32ooooo`00Xoooool00ol0003oooooooooo`32ooooo`00Xoooool0
0ol0003oooooooooo`32ooooo`00XOooool00omEEEGoIVIVo`000034ooooo`00oooooomYooooo`00
JOooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o^[Zjoc8b<_ooool0
1oooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Oooooo00?o0000ooooooooool0
0_ooool00omVIVKoMgMgooooo`0<ooooo`03o`000?nj^[[ooooo0:gooooo001Xooooo`03omgMgOl@
413ok^k^00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool00oo^k^ko410@omgMg@0<ooooo`;o<S8b[_ooool006Sooooo00?oEEEEoiRHV?ooool01Oooool0
1_l0003oooooooooooooooooV9RHoa0@40;o000000?oZJVYooooooooool01?ooool01?l0003ooooo
ooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0
003oA4A4okZj^P04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00on7
QhOoIVIVooooo`0;ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0A
ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool0Moooool0
06Sooooo00?o0000ooooooooool01Oooool02_l0003ooooooooooooooooo0000ojVYZOmEEEGoV9RH
oeEEEOnj^[X5ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo
00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03onk^k_l0003ooooo00_ooooo00?oc<c<o`000?l@
41003?ooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00003?ooool00ol0003oooooooooo`04
ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`1gooooo`00J?ooool00olb<S;oooooooooo`05oooo
o`0:o`000?oooooooooooooooolb<S;ok^k^oiRHV?mEEEGogMgMoa0@40Gooooo00?o0000oooooooo
ool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo07Oooooo001Xooooo`03
oc8b<_oooooooooo00Gooooo00_o0000oooooooooooooooookZj^_m4A4Coc<c<ob4Q8Ooooooo410@
olc<c004ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo1_l0000<ooooo`03o`000?oooooooooo00go
oooo00?o8B4Qooooooooool0M_ooool006Sooooo00?o0000onk^k_ooool01Oooool02ol0003ooooo
ooooooooooook^k^o`000?oooooo0000oooooomVIVKoQhN700Cooooo00?o0000ooooooooool00_oo
ool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03onk^k_l0003ooooo01[ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo07Kooooo001Xooooo`03oeEEEOmg
MgOooooo00Gooooo00So0000ooooooooooooooooofIVI_nHV9Sooooooc8b<P;o^[Zj00?o0000oooo
ooooool00_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o
000000?o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?oMgMg
oeEEEOooool00_ooool4o`0001;ooooo00?o410@o`000?l000000ol0000Dooooo`03o`000?oooooo
oooo00gooooo00?oZJVYogMgMoooool0M_ooool006Sooooo00?ogMgMoa0@4?o^k^h01Oooool00ol0
003oooooooooo`04ooooo`03ofIVI_n7QhOooooo00Gooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00oo^
k^ko410@omgMg@04ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S80Moooool006Wooooo00?oMgMgofIV
I_ooool01?ooool00ol0003oooooooooo`04ooooo`03ojVYZOm4A4Cooooo00Gooooo0_l0000Boooo
o`03o`000?oooooooooo00Gooooo0_l00007ooooo`03o`000?oooooooooo00;ooooo00?oIVIVogMg
Moooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?oEEEEofIV
I_l000003?ooool5o`0007Oooooo002booooo`03o`000?oooooooooo0;?ooooo002_ooooo`04o`00
0?ooooooooooo`000;Gooooo002`ooooo`;o0000]_ooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.8522, -0.080387, \
0.130126, 0.00668404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
176.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 2e-05 m
.02499 2e-05 L
.02605 1e-05 L
.02729 1e-05 L
.02846 0 L
.02954 0 L
.03053 0 L
.03163 1e-05 L
.03279 1e-05 L
.03395 1e-05 L
.0352 1e-05 L
.03638 1e-05 L
.03746 0 L
.03873 0 L
.03944 0 L
.04011 0 L
.04132 1e-05 L
.04262 1e-05 L
.04327 1e-05 L
.04396 1e-05 L
.04519 1e-05 L
.04588 1e-05 L
.04652 1e-05 L
.04722 0 L
.04797 0 L
.04862 0 L
.04933 0 L
.05061 1e-05 L
.05175 1e-05 L
.05302 2e-05 L
.05424 1e-05 L
.05539 1e-05 L
.05671 0 L
.05791 0 L
.05898 0 L
.06009 1e-05 L
.06122 1e-05 L
.06244 2e-05 L
.06315 2e-05 L
.0638 2e-05 L
.06509 1e-05 L
.06625 1e-05 L
.06748 1e-05 L
.06812 1e-05 L
.06881 1e-05 L
.07005 2e-05 L
.0708 2e-05 L
.07152 2e-05 L
.07217 2e-05 L
.07287 2e-05 L
Mistroke
.07415 2e-05 L
.07531 2e-05 L
.07595 2e-05 L
.07664 1e-05 L
.0779 2e-05 L
.07908 2e-05 L
.08033 3e-05 L
.0814 3e-05 L
.08257 3e-05 L
.08328 3e-05 L
.08405 3e-05 L
.08473 3e-05 L
.08545 3e-05 L
.0861 2e-05 L
.08681 3e-05 L
.08807 3e-05 L
.08953 4e-05 L
.09036 4e-05 L
.09111 4e-05 L
.09177 5e-05 L
.0925 4e-05 L
.09326 4e-05 L
.09396 4e-05 L
.09462 4e-05 L
.09535 4e-05 L
.09665 4e-05 L
.09793 5e-05 L
.0991 5e-05 L
.10037 6e-05 L
.10109 6e-05 L
.10176 6e-05 L
.10247 6e-05 L
.10312 6e-05 L
.10382 6e-05 L
.10458 6e-05 L
.10575 6e-05 L
.10686 6e-05 L
.10817 7e-05 L
.10938 8e-05 L
.11056 8e-05 L
.11186 9e-05 L
.11252 9e-05 L
.11322 9e-05 L
.11448 9e-05 L
.11566 9e-05 L
.11694 .0001 L
.11808 .0001 L
.11928 .00011 L
.12036 .00012 L
.12155 .00012 L
Mistroke
.12263 .00012 L
.12364 .00013 L
.12492 .00013 L
.12565 .00013 L
.12632 .00014 L
.12886 .00016 L
.13006 .00017 L
.13118 .00018 L
.13247 .00018 L
.13364 .00019 L
.13495 .0002 L
.13561 .0002 L
.13633 .00021 L
.13881 .00025 L
.1417 .00027 L
.143 .00028 L
.14439 .0003 L
.14563 .00032 L
.147 .00034 L
.14941 .00038 L
.15485 .00046 L
.16476 .00065 L
.1738 .00085 L
.18332 .00109 L
.18815 .00125 L
.19342 .00146 L
.19822 .00171 L
.20268 .00199 L
.21277 .00286 L
.21842 .00349 L
.22354 .00419 L
.24436 .00816 L
.2535 .00974 L
.25834 .0104 L
.26101 .01079 L
.26355 .01123 L
.26596 .01172 L
.2686 .01239 L
.27099 .01317 L
.27321 .01407 L
.27759 .0164 L
.28225 .01971 L
.30203 .03729 L
.32206 .05696 L
.32755 .06333 L
.33031 .06568 L
.33107 .06617 L
.33187 .06663 L
.33263 .06698 L
.33333 .06725 L
Mistroke
.33398 .06743 L
.33467 .06758 L
.33536 .06767 L
.33612 .06772 L
.33677 .06771 L
.33748 .06767 L
.33875 .0675 L
.34007 .06724 L
.34133 .06696 L
.34246 .0667 L
.34369 .06647 L
.34499 .06631 L
.34621 .0663 L
.3474 .06648 L
.3485 .06685 L
.34969 .06753 L
.351 .06866 L
.35236 .07032 L
.35364 .07237 L
.35597 .0774 L
.35809 .08344 L
.36287 .10113 L
.36803 .12157 L
.36944 .12609 L
.37021 .12819 L
.37094 .1299 L
.37222 .13219 L
.3729 .133 L
.37363 .13355 L
.37487 .13368 L
.37557 .13329 L
.37622 .13264 L
.37754 .13047 L
.37828 .12879 L
.37895 .12698 L
.38383 .10827 L
.38633 .0975 L
.38867 .08874 L
.38995 .08489 L
.39111 .08205 L
.39241 .07971 L
.39312 .07878 L
.3938 .07812 L
.39491 .0775 L
.39608 .07738 L
.3972 .07768 L
.3982 .07821 L
.40054 .07983 L
.40181 .08061 L
.403 .08107 L
Mistroke
.40428 .08112 L
.40496 .08092 L
.40568 .08053 L
.40697 .07933 L
.40815 .07769 L
.40952 .07514 L
.41101 .07169 L
.41371 .06403 L
.41892 .04675 L
.4238 .03059 L
.42601 .02409 L
.42833 .01836 L
.42955 .01601 L
.43019 .015 L
.43088 .01411 L
.43209 .01309 L
.43321 .01284 L
.43391 .01306 L
.43456 .01352 L
.43527 .01433 L
.43602 .01554 L
.43727 .01836 L
.43866 .02253 L
.4436 .04291 L
.44489 .04821 L
.44629 .05327 L
.44761 .05706 L
.44884 .05955 L
.44952 .06046 L
.45026 .06108 L
.45105 .06128 L
.45178 .06106 L
.45307 .05978 L
.4538 .05858 L
.45446 .05721 L
.45682 .0506 L
.45941 .0413 L
.46462 .02233 L
.46714 .0154 L
.46857 .01245 L
.46989 .01032 L
.47104 .00889 L
.47231 .00774 L
.47294 .00731 L
.47363 .00694 L
.47487 .00651 L
.47606 .00635 L
.47737 .00642 L
.4786 .00666 L
.47974 .00702 L
Mistroke
.4819 .00791 L
.48419 .00904 L
.48691 .01065 L
.48834 .01171 L
.48985 .01308 L
.49263 .01639 L
.49518 .02025 L
.50039 .02898 L
.50285 .03268 L
.50513 .03547 L
.50626 .03654 L
.50747 .03739 L
.50867 .0379 L
.50936 .03802 L
.51 .03801 L
.51116 .0377 L
.51222 .03705 L
.51339 .03595 L
.51461 .03437 L
.51713 .02998 L
.51947 .02496 L
.5222 .01877 L
.52478 .01345 L
.52701 .0098 L
.52826 .00827 L
.52942 .00722 L
.5304 .0066 L
.53147 .00617 L
.53259 .00596 L
.53364 .00593 L
.53487 .00601 L
.53603 .00615 L
.53821 .0064 L
.54311 .00681 L
.55346 .00768 L
.55853 .00812 L
.56319 .00857 L
.57193 .00974 L
.58137 .01118 L
.60108 .01492 L
.62207 .01915 L
.63118 .02072 L
.6362 .02144 L
.64094 .02199 L
.64654 .0225 L
.65164 .02285 L
.65642 .02308 L
.65773 .02313 L
.65912 .02318 L
.66042 .02321 L
Mistroke
.66162 .02324 L
.66282 .02325 L
.66413 .02327 L
.66529 .02327 L
.66653 .02327 L
.66774 .02326 L
.66888 .02325 L
.66991 .02323 L
.67102 .02321 L
.67358 .02313 L
.67628 .02301 L
.68113 .02273 L
.68985 .02202 L
.69943 .02094 L
.70962 .01942 L
.71892 .0178 L
.73983 .01383 L
.76051 .00997 L
.77965 .00694 L
.79822 .00457 L
.80771 .00362 L
.81795 .00277 L
.8281 .00208 L
.83741 .00158 L
.84631 .0012 L
.85568 .00089 L
.86521 .00066 L
.8754 .00046 L
.88502 .00033 L
.89376 .00024 L
.8986 .0002 L
.90373 .00016 L
.91293 .00012 L
.92283 8e-05 L
.92412 7e-05 L
.92484 7e-05 L
.9255 6e-05 L
.92628 6e-05 L
.92701 6e-05 L
.92769 7e-05 L
.92841 7e-05 L
.92906 7e-05 L
.92976 6e-05 L
.93049 6e-05 L
.93118 6e-05 L
.9324 5e-05 L
.93308 5e-05 L
.93372 4e-05 L
.93504 4e-05 L
.93628 4e-05 L
Mistroke
.93742 5e-05 L
.93862 5e-05 L
.93991 4e-05 L
.94112 4e-05 L
.94246 3e-05 L
.94313 3e-05 L
.94387 3e-05 L
.94508 3e-05 L
.9462 3e-05 L
.9473 3e-05 L
.94834 3e-05 L
.94956 3e-05 L
.95067 3e-05 L
.95195 2e-05 L
.95315 2e-05 L
.95436 2e-05 L
.955 2e-05 L
.95569 2e-05 L
.95641 2e-05 L
.95709 2e-05 L
.95837 3e-05 L
.95956 2e-05 L
.96067 2e-05 L
.96188 1e-05 L
.96318 1e-05 L
.96391 1e-05 L
.96459 1e-05 L
.96532 1e-05 L
.96611 2e-05 L
.96681 2e-05 L
.96746 2e-05 L
.96814 2e-05 L
.96888 2e-05 L
.96954 1e-05 L
.97027 1e-05 L
.97158 0 L
.97286 0 L
.97404 1e-05 L
.97506 1e-05 L
.97619 2e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`0Rooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00GoA4A4o`000?l0003o<S8bomgMg@1Gooooo`05odA4A?l0003o0000oc8b<_oMgMd09oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo02Gooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool09?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00omgMgOo<S8booooo`1Iooooo`03ogMgMolb<S;ooooo02Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Uooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool6o`0000Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[
ooooo`03ogMgMolb<S;ooooo05Wooooo00?oMgMgoc8b<_ooool0:?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo02Gooooo000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0Eoooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001Wooooo
00?oEEEEofIVI_l000001Oooool4o`0002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo1?l0001Hooooo`Co0000:?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool00omEEEGoIVIVo`000005ooooo`Co00009oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooC_ooool2o`0000;ooooo0_l0000Eooooo`00oooooom>
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5Oooool00?ooooooCoooool01?oMgMgo0000oa0@
4?o<c<`Fooooo`005?ooooooo`00033o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hFooooo`006ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000003?l0
0004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`03ooooo`oo00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`04ob4Q8OmgMgOoMgMgoc8b<QKooooo
000Kooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03?ooool3o`0001kooooo00?o
0000ooooooooool09Oooool3o`0000Gooooo00?o0000ooooooooool01_ooool9o`0001kooooo00?o
0000ooooooooool07oooool:o`0000Cooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0?ooooo`;o00000_ooool2o`0001Gooooo001Mooooo`Oo0000?_ooool01?l0003ooooooooooooo
ool2o`0000?ooooo00?o0000ooooooooool01Oooool2o`0000Sooooo1ol0000cooooo`Ko0000Jooo
ool006?ooooo1Ol0000^ooooo`;o00002Oooool00ol0003oooooooooo`03ooooo`;o00000_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo1?l0000Zooooo`Go0000LOooool0
06Sooooo00?o0000ooooooooool0:oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`0Cooooo`Ko00008Oooool3o`00
07Kooooo001Yooooo`;o0000:_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo
00Kooooo0_l00006ooooo`03o`000?oooooooooo01Wooooo1_l0000Booooo`Wo0000NOooool006_o
oooo00?o0000ooooooooool09oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo
00Oooooo0_l00006ooooo`03o`000?oooooooooo01oooooo4_l00022ooooo`00K?ooool00ol0003o
ooooooooo`0Vooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0;Cooooo001]ooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2eooooo`00K_ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`08ooooo`;o00000oooool00ol0003oooooooooo`2eooooo`00Koooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`09ooooo`05o`000?oooooo0000ooooool00000^?ooool0073ooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Ooo
ool01?l0003oooooooooool0002iooooo`00LOooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo0;[ooooo001booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0^_ooool0
07?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooo
ooooool000003?ooool00ol0003oooooooooo`2jooooo`00M?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`2j
ooooo`00MOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ool000003Oooool00ol0003oooooooooo`2jooooo`00M_ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00Sooooo0_l0000=ooooo`03o`000?oooooooooo0;[ooooo001gooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`;o0000
^oooool007Sooooo00?o0000ooooooooool00ol0000Cooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0^_ooool007Wooooo0ol00002ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`2jooooo`00Ooooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0^_ooool007oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0;[ooooo001oooooo`03o`00
0?oooooooooo00Sooooo1?l000000ooooooo0000ooooo`0Jooooo`03o`000?oooooooooo0;[ooooo
0020ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_l0000Looooo`03o`000?oo
oooooooo0;[ooooo0020ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`2jooooo`00P?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0^_ooool0083ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Oooooo`;o0000^oooool0087ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo0;[ooooo0021ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`2jooooo`00POooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0^_ooool0087ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0;[ooooo0022ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2jooooo`00
P_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
^_ooool008;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0;[ooooo
0023ooooo`05o`000?ooooooooooooooool000002?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`2joooo
o`00Poooool01Ol0003ooooooooooooooooo000000Sooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0^_ooool008?ooooo00Co0000oooo
oooooooo00002Oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_oo
ool3o`000;[ooooo0024ooooo`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0^_ooool008Cooooo0ol00009
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0;[ooooo0025ooooo`03o`000?oooooooooo00Sooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`2jooooo`00T?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04oooo
o`03o`000?oooooooooo0;[ooooo002@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413o
oooooooooooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05
o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`?o0000^_ooool0
093ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool0^_ooool0093ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<
c<co000000Oooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0^_ooool0093ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0
002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool0093ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool0^_ooool0093ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool000001_ooool3o`000;[ooooo002@ooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooooooo
o`2jooooo`00T?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?oo
ool00ol0003oooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o
gMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2joooo
o`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B401_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;[ooooo002@
ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo
0ol0002jooooo`00T?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o
0000olc<c006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0^_ooool0093o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool0
0ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002Qooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooooooo`2jooooo`00Xoooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0;[ooooo002Sooooo`03o`000?oooooooooo00Gooooo0ol0002jooooo`00
Xoooool00ol0003oooooooooo`32ooooo`00Xoooool00ol0003oooooooooo`32ooooo`00Xoooool0
0ol0003oooooooooo`32ooooo`00Xoooool00ol0003oooooooooo`32ooooo`00XOooool00omEEEGo
IVIVo`000034ooooo`00oooooomYooooo`00JOooool00omgMgOoIVIVooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o^[Zjoc8b<_ooool01oooool2o`0000_ooooo00?o0000okZj^_ooool03?oo
ool2o`0000Oooooo00?o0000ooooooooool00_ooool00omVIVKoMgMgooooo`0<ooooo`03o`000?nj
^[[ooooo0:gooooo001Xooooo`03omgMgOl@413ok^k^00Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool00oo^k^ko410@omgMg@0<ooooo`;o<S8b[_ooool0
06Sooooo00?oEEEEoiRHV?ooool01Oooool01_l0003oooooooooooooooooV9RHoa0@40;o000000?o
ZJVYooooooooool01?ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7
Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00on7QhOoIVIVooooo`0;ooooo`03ohN7Qol0003o^[Zj00co
oooo00GoV9RHo`000?l0003oA4A4okZj^P0Aooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c01gooooo`00J?ooool00ol0003oooooooooo`05oooo
o`0:o`000?ooooooooooooooool0003oZJVYoeEEEOnHV9SoEEEEokZj^PGooooo00[o0000oooooooo
ooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@
4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo00?ok^k^o`000?ooool02oooool00oo<c<co0000oa0@400<ooooo`06oa0@4?nj^[[ok^k^ogMg
Mol@413ooooo1_l0000<ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05ob4Q8OnHV9So
oooooiRHV?lQ8B40Moooool006Sooooo00?o<S8booooooooool01Oooool02_l0003ooooooooooooo
oooo<S8bonk^k_nHV9SoEEEEomgMgOl@4105ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`00
0?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool02_ooool01Ol0003ooooooooooooooooo000007Oooooo001Xooooo`03oc8b<_oooooo
oooo00Gooooo00_o0000oooooooooooooooookZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c004oooo
o`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00?ooooo1_l0000<ooooo`03o`000?oooooooooo00[ooooo00Go<S8b
oiRHV?ooooooV9RHoc8b<P1gooooo`00J?ooool00ol0003ok^k^ooooo`05ooooo`0;o`000?oooooo
ooooooooooo^k^ko0000ooooool0003oooooofIVI_n7QhL01?ooool00ol0003oooooooooo`02oooo
o`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?ok^k^o`000?ooool06_ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00[ooooo00Goc<c<o`000?l0003o0000olc<c01gooooo`00J?ooool0
0omEEEGoMgMgooooo`05ooooo`08o`000?oooooooooooooooomVIVKoV9RHoooooolb<S82okZj^P03
o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool00ol@
413o0000o`000003o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooo
o`03ogMgMomEEEGooooo00;ooooo1?l0000Booooo`03oa0@4?l0003o000000?o00005?ooool00ol0
003oooooooooo`0:ooooo`05oa0@4?nj^[[ooooookZj^_l@4100Moooool006Sooooo00?ogMgMoa0@
4?o^k^h01Oooool00ol0003oooooooooo`04ooooo`03ofIVI_n7QhOooooo00Gooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool00oo^k^ko410@omgMg@04ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooookZj^_l00000Moooool0
06Wooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`04ooooo`03ojVYZOm4A4Cooooo
00Gooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l00007ooooo`03o`000?oooooooooo
00;ooooo00?oIVIVogMgMoooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01?ooooo00?oEEEEofIVI_l000003?ooool01OnYZJWo410@o`000?l@413oZJVY07Oooooo002boooo
o`03o`000?oooooooooo0;?ooooo002_ooooo`04o`000?ooooooooooo`000;Gooooo002`ooooo`;o
0000]_ooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.8522, -0.080387, \
0.130126, 0.00668404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
176.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 3e-05 m
.02499 5e-05 L
.02605 6e-05 L
.02729 7e-05 L
.02846 5e-05 L
.02954 3e-05 L
.03056 1e-05 L
.03162 0 L
.03279 1e-05 L
.03397 2e-05 L
.03524 5e-05 L
.03642 6e-05 L
.0375 6e-05 L
.03875 4e-05 L
.03946 3e-05 L
.04012 2e-05 L
.04133 0 L
.04262 0 L
.04387 2e-05 L
.04519 5e-05 L
.04588 6e-05 L
.04664 6e-05 L
.04733 6e-05 L
.04797 6e-05 L
.04933 3e-05 L
.05061 1e-05 L
.05176 0 L
.05302 1e-05 L
.05416 3e-05 L
.05538 6e-05 L
.05642 7e-05 L
.05757 7e-05 L
.05878 5e-05 L
.06008 2e-05 L
.06131 1e-05 L
.06244 1e-05 L
.07308 4e-05 L
.07436 6e-05 L
.07503 7e-05 L
.07574 8e-05 L
.07705 9e-05 L
.07826 8e-05 L
.07942 6e-05 L
.0805 5e-05 L
.08169 4e-05 L
.08297 5e-05 L
.08419 7e-05 L
.08484 9e-05 L
.08553 .0001 L
.08679 .00011 L
Mistroke
.08796 .0001 L
.08871 .0001 L
.08942 9e-05 L
.09011 8e-05 L
.09075 7e-05 L
.09197 7e-05 L
.09329 9e-05 L
.09466 .00012 L
.09542 .00013 L
.09613 .00014 L
.0968 .00014 L
.09752 .00014 L
.09878 .00014 L
.09948 .00013 L
.10013 .00012 L
.1008 .00012 L
.10155 .00012 L
.10231 .00013 L
.10312 .00014 L
.10388 .00015 L
.10458 .00017 L
.10586 .00019 L
.10707 .0002 L
.10816 .00021 L
.10934 .0002 L
.11062 .00019 L
.11127 .00019 L
.11198 .0002 L
.11323 .00022 L
.11441 .00024 L
.11559 .00027 L
.11671 .00029 L
.11772 .0003 L
.11881 .0003 L
.12 .00029 L
.12127 .0003 L
.12235 .00031 L
.12354 .00034 L
.14426 .00068 L
.15367 .00085 L
.1588 .00098 L
.16009 .001 L
.1613 .00102 L
.16239 .00104 L
.16358 .00108 L
.16609 .00117 L
.16877 .00126 L
.17153 .00135 L
.17292 .00141 L
.17445 .00149 L
Mistroke
.17964 .00181 L
.18443 .00214 L
.19457 .00314 L
.20385 .0043 L
.22473 .00744 L
.23393 .00886 L
.24373 .01046 L
.24664 .01103 L
.24937 .01168 L
.25449 .01333 L
.25928 .01548 L
.26198 .01709 L
.26446 .01883 L
.30397 .0483 L
.32385 .06572 L
.33253 .07281 L
.3371 .07609 L
.33961 .07818 L
.34196 .08077 L
.34444 .08439 L
.34717 .08954 L
.35199 .10168 L
.35662 .11554 L
.35914 .12214 L
.36037 .1247 L
.36149 .12655 L
.3627 .12798 L
.364 .12877 L
.36467 .12885 L
.36541 .12866 L
.3661 .12822 L
.36674 .12757 L
.36786 .12589 L
.36908 .12321 L
.37036 .11953 L
.37156 .11536 L
.37675 .09205 L
.37949 .07904 L
.38241 .06668 L
.38387 .06144 L
.38524 .05726 L
.38658 .05395 L
.38781 .05157 L
.38899 .04986 L
.39022 .0486 L
.39146 .04782 L
.39217 .04756 L
.39282 .04742 L
.39411 .04739 L
.39532 .0476 L
Mistroke
.39641 .04796 L
.3976 .04849 L
.40271 .05174 L
.40387 .0525 L
.40512 .0532 L
.40631 .05373 L
.40739 .05404 L
.4086 .05416 L
.40975 .05402 L
.41099 .05355 L
.41169 .05313 L
.41235 .05262 L
.41351 .05143 L
.41461 .04996 L
.41666 .04623 L
.41886 .04084 L
.42125 .0338 L
.4236 .02656 L
.42583 .02052 L
.42707 .01787 L
.42771 .01672 L
.42841 .01569 L
.42962 .01442 L
.43075 .01385 L
.43207 .0139 L
.43331 .01462 L
.43402 .0153 L
.43467 .01608 L
.43614 .01828 L
.44118 .02801 L
.44355 .03189 L
.44487 .03355 L
.44608 .03474 L
.44885 .03673 L
.45144 .03841 L
.4541 .04043 L
.45551 .04141 L
.45622 .04178 L
.45699 .04204 L
.45767 .04211 L
.4584 .04196 L
.45972 .04101 L
.46104 .03908 L
.46224 .03644 L
.46702 .02096 L
.46828 .01693 L
.46964 .01321 L
.47093 .01045 L
.47211 .00861 L
.47322 .00745 L
Mistroke
.47444 .00674 L
.47572 .00652 L
.47691 .00669 L
.47801 .00709 L
.47901 .00759 L
.48126 .00904 L
.49203 .01726 L
.49677 .02133 L
.49928 .02356 L
.50199 .02584 L
.50321 .02676 L
.50449 .02762 L
.50567 .02826 L
.50678 .02871 L
.50781 .02898 L
.50892 .02907 L
.51015 .02891 L
.51126 .02853 L
.51253 .02781 L
.51369 .02688 L
.51633 .02393 L
.5211 .01647 L
.52362 .0123 L
.52501 .01021 L
.52632 .00848 L
.52754 .00715 L
.52819 .00657 L
.52887 .00605 L
.53008 .00537 L
.5312 .00499 L
.53244 .0048 L
.53362 .00478 L
.5349 .00487 L
.53562 .00494 L
.53629 .00501 L
.54188 .00549 L
.56237 .00683 L
.58145 .00857 L
.59985 .01093 L
.61952 .01441 L
.6394 .01839 L
.64987 .02008 L
.6556 .02086 L
.66097 .02151 L
.66573 .02193 L
.66818 .0221 L
.67086 .02227 L
.67159 .02231 L
.67237 .02235 L
.67304 .02238 L
Mistroke
.67377 .0224 L
.67452 .02242 L
.67522 .02243 L
.67654 .02245 L
.67902 .02249 L
.68033 .02252 L
.68105 .02253 L
.68174 .02254 L
.68305 .02255 L
.68425 .02255 L
.68537 .02254 L
.6866 .02252 L
.68908 .02248 L
.69045 .02247 L
.69172 .02245 L
.69282 .02243 L
.69399 .0224 L
.6953 .02235 L
.6965 .02229 L
.70091 .02205 L
.70565 .02172 L
.71072 .02125 L
.71984 .02027 L
.74054 .01729 L
.78205 .01004 L
.80285 .00693 L
.82204 .00463 L
.84073 .00296 L
.85015 .00233 L
.86051 .00177 L
.87049 .00133 L
.87996 .00101 L
.89088 .00072 L
.90086 .00053 L
.91047 .00039 L
.91171 .00036 L
.91301 .00033 L
.91369 .00032 L
.91444 .00031 L
.91575 .0003 L
.91639 .00031 L
.91708 .00031 L
.91834 .00031 L
.91957 .0003 L
.92071 .00028 L
.92186 .00026 L
.92312 .00023 L
.92438 .00021 L
.92506 .00021 L
.92571 .00021 L
Mistroke
.92688 .00022 L
.92795 .00022 L
.92919 .00022 L
.93037 .00021 L
.93141 .00019 L
.93253 .00017 L
.93359 .00015 L
.93455 .00014 L
.93567 .00014 L
.9369 .00015 L
.93805 .00016 L
.93911 .00016 L
.94029 .00015 L
.94141 .00013 L
.94243 .00011 L
.94352 9e-05 L
.94469 9e-05 L
.94578 9e-05 L
.94695 .00011 L
.94825 .00012 L
.94935 .00012 L
.95036 .00011 L
.95148 9e-05 L
.95265 7e-05 L
.95367 6e-05 L
.95462 5e-05 L
.95567 6e-05 L
.95678 7e-05 L
.95809 9e-05 L
.95929 9e-05 L
.96061 8e-05 L
.96128 7e-05 L
.96201 6e-05 L
.96324 4e-05 L
.96456 3e-05 L
.96581 4e-05 L
.96695 6e-05 L
.96812 7e-05 L
.96921 8e-05 L
.97041 7e-05 L
.97169 5e-05 L
.9729 2e-05 L
.97405 1e-05 L
.97508 2e-05 L
.97619 3e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`0Rooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00GoA4A4o`000?l0003o<S8bomgMg@1Gooooo`05odA4A?l0003o0000oc8b<_oMgMd09oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo02Gooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool09?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00omgMgOo<S8booooo`1Iooooo`03ogMgMolb<S;ooooo02Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Uooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool6o`0000Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[
ooooo`03ogMgMolb<S;ooooo05Wooooo00?oMgMgoc8b<_ooool0:?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo02Gooooo000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0Eoooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001Wooooo
00?oEEEEofIVI_l000001Oooool4o`0002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo1?l0001Hooooo`Co0000:?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool00omEEEGoIVIVo`000005ooooo`Co00009oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooC_ooool2o`0000;ooooo0_l0000Eooooo`00oooooom>
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5Oooool00?ooooooCoooool01?oMgMgo0000oa0@
4?o<c<`Fooooo`005?ooooooo`00033o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hFooooo`006ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo4?l00008ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`04o`000?oo
ooooooooooooo`ko000000?oooooo`000?ooool02?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool04?ooool01?lQ8B7oMgMgogMgMolb<S8Fooooo`00
6oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo1?l0000Qooooo`03o`00
0?oooooooooo02Gooooo0ol00005ooooo`03o`000?oooooooooo00Gooooo3ol0000Iooooo`03o`00
0?oooooooooo02Kooooo2ol0000/ooooo`03o`000?oooooooooo00oooooo0_l00002ooooo`;o0000
5Oooool005[ooooo1Ol00013ooooo`;o000000?oooooo`000?l000001?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00cooooo2_l0000aooooo`Oo0000I?ooool005oooooo0ol0000d
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`?o0000:?ooool6o`0006_ooooo001Roooo
o`;o0000<Oooool3o`0000Wooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005oooo
o`03o`000?oooooooooo01_ooooo1?l0000Nooooo`Ko0000LOooool006Cooooo0_l0000_ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005oooo
o`03o`000?oooooooooo01oooooo2Ol0000Aooooo`Co0000Moooool006Kooooo00?o0000oooooooo
ool0;?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00Kooooo0_l00004oooo
o`03o`000?oooooooooo02Wooooo4Ol0001kooooo`00Ioooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`;o
00000_ooool00ol0003oooooooooo`2fooooo`00J?ooool2o`0002[ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo1Ol0002hooooo`00J_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`08ooooo`;o0000^oooool006_ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`05ooooo`;o00000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo0;[ooooo001/ooooo`;o00009?ooool00ol0003oooooooooo`07ooooo`;o000000?oooooo`00
0?ooool02_ooool00ol0003oooooooooo`2jooooo`00K_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00Wooooo0_l0000;ooooo`03o`000?oooooooooo0;[ooooo001_ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo0;[ooooo001`ooooo`;o00005oooool5o`0000?ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`2jooooo`00L_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00;ooooo1?l0000Iooooo`03o`000?oooooooooo0;[ooooo001cooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool01?ooool2o`0001[ooooo00?o0000ooooooooool0^_ooool007Co
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0;[o
oooo001eooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool08?ooool2o`000;_ooooo
001fooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`2jooooo`00Moooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0^_ooool007Sooooo0_l0000=ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0^_ooool007[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo0;[ooooo001jooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`2jooooo`00Noooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0^_ooool007cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0;[ooooo001mooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2jooooo`00OOooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo02;ooooo0_l0002kooooo`00OOooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0^_ooool007kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo0;[ooooo001n
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`2j
ooooo`00O_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool0^_ooool007oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo0;[ooooo001oooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`2jooooo`00P?ooool01Ol0003ooooooooooooooooo000000_ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000oooooooo
ool0^_ooool0083ooooo00Go0000ooooooooooooooooo`00000;ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo0;[ooooo0020ooooo`04o`000?ooooooooooo`0000cooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0^_ooool0087ooooo00?o0000
ooooool000003?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_oo
ool3o`000;[ooooo0021ooooo`?o00003?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool01Oooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2jooooo`00T?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo0;[ooooo002@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`00
0003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo00?o0000oooo
ooooool0^_ooool0093ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgooooo
o`0000Oooooo0ol0002jooooo`00T?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2jooooo`00T?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003ooooooooo
o`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_oo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2jooooo`00T?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B401_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go0000ooooooooooooooooo`000006ooooo`?o0000^_ooool0093ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2j
ooooo`00T?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<
c006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0;[ooooo002@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`00
0;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006oooo
o`03o`000?oooooooooo0;[ooooo002@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;[ooooo002@oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool0^_ooool0093ooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nH
V9SooooooiRHV?lb<S801_ooool3o`000;[ooooo002@ooooo`05o`000?ooooooooooooooool00000
2oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0^_ooool0093ooooo
00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0
003oooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0
002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:7ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;[ooooo002Soooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^_ooool00:?ooooo00?o0000oooooooo
ool01Oooool3o`000;[ooooo002Sooooo`03o`000?oooooooooo0<;ooooo002Sooooo`03o`000?oo
oooooooo0<;ooooo002Sooooo`03o`000?oooooooooo0<;ooooo002Sooooo`03o`000?oooooooooo
0<;ooooo002Qooooo`03oeEEEOmVIVKo00000<Cooooo003oooooofWooooo001Yooooo`03ogMgMomV
IVKooooo00Cooooo00?o0000ooooooooool00_ooool00onj^[[o<S8booooo`07ooooo`;o00002ooo
ool00ol0003o^[Zjooooo`0<ooooo`;o00001oooool00ol0003oooooooooo`02ooooo`03ofIVI_mg
MgOooooo00cooooo00?o0000okZj^_ooool0[Oooool006Sooooo00?ogMgMoa0@4?o^k^h01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool2
oc8b<Pkooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03onk^k_l@413o
gMgM00cooooo0_lb<S:^ooooo`00J?ooool00omEEEGoV9RHooooo`05ooooo`06o`000?oooooooooo
oooooonHV9So410@0_l000000onYZJWoooooooooo`04ooooo`04o`000?ooooooooooooooo`;o0000
0_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03ohN7QomVIVKooooo00_o
oooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj017ooooo1?l000000ol@
413oooooooooo`02ooooo`;o8B4Q1?ooool01?l@413o0000odA4A?o<c<ahooooo`00J?ooool00ol0
003oooooooooo`05ooooo`0:o`000?ooooooooooooooool0003oZJVYoeEEEOnHV9SoEEEEokZj^PGo
oooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000
oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?ok^k^o`000?ooool02oooool00oo<c<co0000oa0@400<ooooo`06
oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l0000<ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46
ooooo`03oiRHV?l@413ogMgM07Oooooo001Xooooo`03oc8b<_oooooooooo00Gooooo00[o0000oooo
oooooooooooooc8b<_o^k^koV9RHoeEEEOoMgMgo410@1Oooool00ol0003oooooooooo`02ooooo`04
omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00gooooo00?oQhN7oeEEEOooool0M_ooool006Sooooo00?o<S8boooooooo
ool01Oooool02ol0003ooooooooooooooooo^[ZjodA4A?o<c<co8B4Qooooool@413oc<c<00Cooooo
00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool00oooool6o`0000cooooo00?o0000ooooooooool02_ooool01Oo<c<co
8B4Qo`000?mEEEGo000007Oooooo001Xooooo`03o`000?o^k^kooooo00Gooooo00_o0000oooooooo
ooooooooonk^k_l0003oooooo`000?ooooooIVIVohN7Q`04ooooo`03o`000?oooooooooo00;ooooo
00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00oo^k^ko0000ooooo`0Jooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool02_ooool01OlQ8B7oQhN7oooooonHV9So000007Oooooo001Xooooo`03
oeEEEOmgMgOooooo00Gooooo00So0000ooooooooooooooooofIVI_nHV9Sooooooc8b<P;o^[Zj00?o
0000ooooooooool00_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@
4?l0003o000000?o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?oMgMgoeEEEOooool00_ooool4o`0001;ooooo00?o410@o`000?l000000ol0000Dooooo`03o`00
0?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00001gooooo`00J?ooool00ooMgMgo410@
onk^kP05ooooo`03o`000?oooooooooo00Cooooo00?oIVIVohN7Qoooool01Oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`03onk^k_l@413ogMgM00Cooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00[ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@1gooooo`00
JOooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo00Cooooo00?oZJVYodA4A?ooool0
1Oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0000Oooooo00?o0000ooooooooool0
0_ooool00omVIVKoMgMgooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
4oooool00omEEEGoIVIVo`00000<ooooo`05olc<c?l@413o0000oc8b<_o^k^h0Moooool00;;ooooo
00?o0000ooooooooool0/oooool00:oooooo00Co0000oooooooooooo0000]Oooool00;3ooooo0_l0
002fooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.8522, -0.080387, \
0.130126, 0.00668404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -55.625 0 ]
[.5 .63053 55.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -116.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
170.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 3e-05 m
.02605 .00011 L
.02729 .00018 L
.02846 .00022 L
.02954 .00021 L
.03072 .00016 L
.03179 9e-05 L
.03279 4e-05 L
.03397 1e-05 L
.03527 3e-05 L
.03653 9e-05 L
.03719 .00013 L
.0379 .00016 L
.03916 .0002 L
.04036 .00018 L
.04153 .00012 L
.04262 6e-05 L
.04386 1e-05 L
.04456 0 L
.04521 1e-05 L
.0464 5e-05 L
.04765 .00012 L
.04878 .00017 L
.04983 .00019 L
.05098 .00017 L
.05221 .00011 L
.05353 4e-05 L
.05427 2e-05 L
.05496 0 L
.05622 2e-05 L
.05686 5e-05 L
.05757 9e-05 L
.05878 .00015 L
.06008 .00019 L
.06131 .00019 L
.06244 .00014 L
.06371 8e-05 L
.0649 3e-05 L
.06556 2e-05 L
.06627 3e-05 L
.06752 7e-05 L
.06861 .00014 L
.06977 .0002 L
.07105 .00023 L
.07225 .00021 L
.07297 .00018 L
.07366 .00014 L
.07496 8e-05 L
.07567 7e-05 L
.07633 6e-05 L
Mistroke
.07705 8e-05 L
.07783 .00011 L
.07913 .00019 L
.07984 .00023 L
.08051 .00026 L
.08168 .00028 L
.08297 .00026 L
.08368 .00023 L
.08433 .0002 L
.08508 .00016 L
.08578 .00014 L
.08653 .00013 L
.08734 .00014 L
.08805 .00017 L
.08881 .00021 L
.09007 .00029 L
.09073 .00033 L
.09143 .00036 L
.0922 .00037 L
.09292 .00036 L
.09358 .00034 L
.09431 .00031 L
.09495 .00028 L
.09564 .00025 L
.09689 .00023 L
.09764 .00024 L
.09833 .00026 L
.09963 .00034 L
.10088 .00042 L
.10204 .00047 L
.10325 .00048 L
.10389 .00046 L
.10458 .00044 L
.1059 .00038 L
.10714 .00036 L
.10843 .00039 L
.10911 .00042 L
.10985 .00046 L
.11109 .00054 L
.1124 .0006 L
.11352 .00061 L
.11474 .00059 L
.11542 .00056 L
.11616 .00054 L
.11686 .00052 L
.1175 .00052 L
.11826 .00052 L
.11905 .00055 L
.11972 .00058 L
.12046 .00063 L
Mistroke
.12179 .00071 L
.12254 .00074 L
.12322 .00076 L
.12454 .00075 L
.12579 .00072 L
.12706 .00069 L
.12821 .00069 L
.12885 .0007 L
.12954 .00072 L
.13078 .00078 L
.13196 .00085 L
.1332 .00091 L
.13425 .00093 L
.13541 .00092 L
.13612 .00091 L
.13679 .0009 L
.13803 .00089 L
.13873 .0009 L
.13938 .00091 L
.14009 .00094 L
.14084 .00098 L
.14591 .0012 L
.15529 .00163 L
.15786 .00173 L
.15854 .00175 L
.15926 .00179 L
.16056 .00187 L
.16177 .00197 L
.16287 .00209 L
.16539 .00236 L
.18368 .00431 L
.2045 .00669 L
.21363 .0078 L
.21848 .00858 L
.22368 .00949 L
.22873 .01073 L
.23334 .01215 L
.23798 .01397 L
.24238 .01624 L
.25185 .02273 L
.26217 .03196 L
.2675 .03669 L
.27252 .04033 L
.27472 .04161 L
.27703 .04265 L
.27824 .04307 L
.27956 .04345 L
.28189 .04398 L
.28714 .04496 L
.28853 .0452 L
Mistroke
.29003 .04549 L
.29133 .04579 L
.29276 .04623 L
.2941 .04675 L
.29552 .04745 L
.29806 .04906 L
.30288 .05329 L
.30537 .05618 L
.30808 .05993 L
.31301 .06772 L
.32228 .08271 L
.32752 .08906 L
.33311 .09442 L
.34316 .10519 L
.34574 .1086 L
.34816 .11133 L
.34937 .11239 L
.35068 .11322 L
.35142 .11354 L
.35212 .11372 L
.35344 .11371 L
.35414 .11349 L
.35488 .11307 L
.35551 .11257 L
.35621 .11183 L
.35696 .11083 L
.35777 .10951 L
.35923 .10644 L
.36201 .09849 L
.36456 .08937 L
.36961 .06898 L
.37239 .058 L
.37501 .0489 L
.37745 .04209 L
.37874 .03925 L
.3801 .03679 L
.38125 .03515 L
.38251 .03379 L
.38366 .03295 L
.38473 .0325 L
.3859 .03237 L
.38717 .03265 L
.38838 .03333 L
.38949 .03428 L
.3906 .03551 L
.3916 .03685 L
.39385 .04041 L
.39633 .04484 L
.39895 .04943 L
.40119 .05273 L
Mistroke
.40246 .05415 L
.40364 .05507 L
.40494 .05553 L
.40612 .05539 L
.40677 .05506 L
.40748 .05449 L
.40877 .0529 L
.40943 .0518 L
.41017 .05039 L
.41165 .04693 L
.41431 .0392 L
.4191 .02368 L
.42182 .01605 L
.42314 .01303 L
.42434 .01079 L
.42557 .00902 L
.42673 .00781 L
.42795 .00701 L
.42864 .00676 L
.42927 .00663 L
.43047 .00667 L
.43179 .00707 L
.43245 .0074 L
.43317 .00784 L
.43445 .00886 L
.43564 .01005 L
.43694 .01165 L
.4393 .01547 L
.44159 .02046 L
.44372 .0262 L
.44623 .03394 L
.44893 .04243 L
.45017 .04593 L
.45149 .04905 L
.4526 .0511 L
.45383 .05252 L
.45511 .05291 L
.45582 .05259 L
.45648 .05193 L
.45774 .04966 L
.45894 .04632 L
.46035 .04105 L
.46165 .03522 L
.46458 .02081 L
.46573 .01565 L
.46697 .01079 L
.46815 .00712 L
.46924 .00458 L
.47051 .00266 L
.47122 .00203 L
Mistroke
.47186 .00169 L
.4731 .00159 L
.47426 .002 L
.47536 .00272 L
.47652 .00372 L
.47861 .00587 L
.48332 .01127 L
.48806 .01606 L
.49072 .018 L
.49315 .01933 L
.49602 .02052 L
.49873 .0214 L
.49994 .02171 L
.50123 .02199 L
.5019 .0221 L
.50264 .02221 L
.50394 .02233 L
.50516 .02237 L
.50629 .02232 L
.50754 .02217 L
.50823 .02204 L
.50886 .02188 L
.51014 .02146 L
.51153 .02083 L
.51283 .02005 L
.51404 .01918 L
.51854 .01477 L
.5233 .00914 L
.52577 .00657 L
.52713 .00543 L
.52843 .00459 L
.52963 .00404 L
.53094 .00368 L
.53213 .00354 L
.53323 .00353 L
.53392 .00357 L
.53466 .00363 L
.53601 .00376 L
.53852 .00399 L
.54415 .00446 L
.56375 .00569 L
.58522 .00722 L
.5951 .00803 L
.60568 .00912 L
.62476 .01165 L
.64462 .01524 L
.65508 .01726 L
.66619 .0192 L
.67605 .02049 L
.68167 .02103 L
Mistroke
.68436 .02129 L
.68693 .02147 L
.69175 .02174 L
.69388 .02185 L
.69507 .0219 L
.69616 .02192 L
.69742 .02194 L
.69862 .02194 L
.69972 .02194 L
.7009 .02194 L
.70222 .02194 L
.70288 .02194 L
.7036 .02194 L
.70489 .02193 L
.70609 .02191 L
.70735 .02188 L
.70869 .02184 L
.71109 .02175 L
.71389 .02168 L
.71527 .02163 L
.71653 .02158 L
.71879 .02147 L
.72123 .02133 L
.72392 .02118 L
.72642 .02102 L
.73074 .02065 L
.73546 .02022 L
.74497 .01914 L
.78399 .01324 L
.80389 .01006 L
.82547 .00698 L
.84625 .00467 L
.86543 .00303 L
.87446 .00242 L
.88417 .00187 L
.89483 .00141 L
.9048 .00105 L
.90602 .00106 L
.90733 .00105 L
.90857 .00102 L
.9097 .00096 L
.91103 .00087 L
.91176 .00082 L
.91244 .00079 L
.91362 .00076 L
.91492 .00076 L
.91567 .00077 L
.91637 .00078 L
.91769 .0008 L
.91842 .00079 L
Mistroke
.91911 .00077 L
.91985 .00073 L
.92065 .00069 L
.92186 .00061 L
.92317 .00055 L
.92392 .00053 L
.92461 .00053 L
.92527 .00054 L
.92596 .00056 L
.9272 .00059 L
.92837 .00061 L
.92901 .0006 L
.92971 .00058 L
.93093 .00052 L
.9321 .00045 L
.93334 .00039 L
.9344 .00036 L
.93556 .00038 L
.93626 .0004 L
.93693 .00042 L
.93818 .00046 L
.93887 .00047 L
.93952 .00047 L
.94023 .00045 L
.94098 .00041 L
.94236 .00033 L
.94365 .00027 L
.94481 .00024 L
.94606 .00026 L
.94697 .00029 L
.94781 .00033 L
.94877 .00036 L
.94968 .00037 L
.95052 .00036 L
.9513 .00033 L
.95215 .00028 L
.95306 .00022 L
.95396 .00018 L
.95494 .00015 L
.95586 .00015 L
.9567 .00017 L
.95771 .00022 L
.95879 .00027 L
.9598 .0003 L
.96072 .00029 L
.96166 .00026 L
.96268 .00021 L
.96355 .00015 L
.96451 .0001 L
.96556 8e-05 L
Mistroke
.96667 9e-05 L
.9677 .00014 L
.96865 .00019 L
.96963 .00023 L
.97056 .00025 L
.97139 .00024 L
.97229 .00021 L
.97619 3e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`0Rooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00GoA4A4o`000?l0003o<S8bomgMg@1Gooooo`05odA4A?l0003o0000oc8b<_oMgMd09oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo02Gooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool09?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00omgMgOo<S8booooo`1Iooooo`03ogMgMolb<S;ooooo02Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Uooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool6o`0000Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[
ooooo`03ogMgMolb<S;ooooo05Wooooo00?oMgMgoc8b<_ooool0:?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo02Gooooo000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0Eoooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001Wooooo
00?oEEEEofIVI_l000001Oooool4o`0002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo1?l0001Hooooo`Co0000:?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool00omEEEGoIVIVo`000005ooooo`Co00009oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooC_ooool2o`0000;ooooo0_l0000Eooooo`00oooooom>
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5Oooool00?ooooooCoooool01?oMgMgo0000oa0@
4?o<c<`Fooooo`005?ooooooo`00033o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hFooooo`006ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`05oooooa3o00001Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo1?l00006ooooo`03o`000?oooooooooo00Kooooo1?l00006ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooo000000co00001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool04?ooool01?lQ8B7oMgMgogMgMolb<S8Fooooo`006oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo00;ooooo1?l0000Wooooo`03o`000?oooooooooo01Oooooo0ol0
0009ooooo`;o00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo0_l0
0003oooooa3o00004oooool00ol0003oooooooooo`0/ooooo`go00009?ooool00ol0003ooooooooo
o`0?ooooo`;o00000_ooool2o`0001Gooooo001Dooooo`Ko0000>_ooool2o`000003ooooool0003o
000000Sooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool04oooool7o`0003Gooooo1_l0001Nooooo`00F_ooool3o`0003Oooooo00Go0000
ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo1_l0000Yooooo`Ko0000I?oo
ool005gooooo0_l0000dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001?ooool2o`0002?ooooo2?l0
000Kooooo`Ko0000J_ooool005oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool4o`0000;ooooo0_l0000]
ooooo`Go00003oooool7o`00073ooooo001Pooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo1?l0000coooo
o`oo0000Moooool0067ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2jooooo`00
H_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0;[ooooo001Sooooo`;o00008_oo
ool3o`0000Sooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000_ooooo
0_l0002kooooo`00IOooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000oooooooo
ool0^_ooool006Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool0000;ooooo`03
o`000?oooooooooo0;[ooooo001Wooooo`Co00006oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool0000;ooooo`03
o`000?oooooooooo0;[ooooo001[ooooo`?o00006?ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000002oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo
0;[ooooo001]ooooo`;o00005_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000002oooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo0;[ooooo001_ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool01?l0003oooooo`000?l0000<oooo
o`;o00003?ooool00ol0003oooooooooo`2jooooo`00L?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00Kooooo0ol0000Kooooo`03o`000?oooooooooo0;[ooooo001aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2jooooo`00LOoo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Cooooo0_l0002kooooo`00L_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0^_ooool0
07;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
0;[ooooo001booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`2jooooo`00Loooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0^_ooool007Cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo0;[ooooo001eooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`2jooooo`00M_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0^_ooool007Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0;[ooooo001gooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool09_ooool2o`000;_ooooo001hooooo`;o00001ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0;[ooooo001jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2jooooo`00Noooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0^_ooool007co
oooo00Go0000ooooooooooooooooo`00000Zooooo`03o`000?oooooooooo0;[ooooo001looooo`05
o`000?ooooooooooooooool00000:_ooool00ol0003oooooooooo`2jooooo`00OOooool4o`0002[o
oooo00?o0000ooooooooool0^_ooool007kooooo0_l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006oooo
o`03o`000?oooooooooo0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onH
V9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05o`000?oooooooooooooo
ool000003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000^_ooool0093ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0^_ooool0093o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^ooo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0;[ooooo
002@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo410@00_ooooo
1Ol00006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05o`000?ooooooooooooooool00000
2oooool01?m4A4CogMgMooooool00007ooooo`?o0000^_ooool0093ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0^_ooool0093o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co0000
00Oooooo00?o0000ooooooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=oooo
o`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`00
0;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Go410@
oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000;[ooooo
002@ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Ko
oooo00?o0000ooooooooool0^_ooool0093ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2joooo
o`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0
003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4
A?l0003o410@1_ooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ
8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003o
ooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05o`000?oooooooooooooo
ool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002jooooo`00T?ooool01Ol0
003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oo
oooooooo0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooo
oonj^[[o410@00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`2jooooo`00
T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002Qooooo`Co000000?o410@ooooooooool00oooool00ol0003o
ooooooooo`2jooooo`00Xoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;[ooooo
002Sooooo`03o`000?oooooooooo00Gooooo0ol0002jooooo`00Xoooool00ol0003oooooooooo`32
ooooo`00Xoooool00ol0003oooooooooo`32ooooo`00Xoooool00ol0003oooooooooo`32ooooo`00
Xoooool00ol0003oooooooooo`32ooooo`00XOooool00omEEEGoIVIVo`000034ooooo`00oooooomY
ooooo`00KOooool00omgMgOoIVIVooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o^[Zjoc8b
<_ooool01_ooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Sooooo00Ko0000oooo
ooooooooooooofIVI_mgMgL>ooooo`03o`000?nj^[[ooooo0:Wooooo001/ooooo`03omgMgOl@413o
k^k^00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo00Kooooo00Oo0000ooooooooooooooooonk^
k_l@413ogMgM00gooooo0_lb<S:Zooooo`00K?ooool00omEEEGoV9RHooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00GoV9RHoa0@4?l0003o0000ojVYZ@05ooooo`03o`000?oooooooooo00;ooooo
0_l00002ooooo`;o00000_ooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj
^[X00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?oQhN7ofIVI_oo
ool03?ooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X04?ooool5o`00
00Gooooo0_lQ8B5looooo`00K?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00Ko0000ojVYZOmEEEGoV9RHoeEEEOnj^[X4ooooo`03o`000?oooooooooo00;ooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03olc<c?l0003o410@00Gooooo00Go410@okZj^_o^k^ko
MgMgoa0@4003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00oo^k^ko
0000ooooo`0<ooooo`03olc<c?l0003o410@00cooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6
o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4QO?ooool006cooooo00?o<S8b
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`06oc8b<_o^k^koV9RHoeEEEOoMgMgo410@
1?ooool00ol0003oooooooooo`03ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Cooooo`03oiRHV?lQ8B7ok^k^08Cooooo001/ooooo`03oc8b
<_oooooooooo00Cooooo00?o0000ooooooooool00_ooool01onj^[[oA4A4olc<c?lQ8B7ooooooa0@
4?o<c<`00oooool00ol0003oooooooooo`03ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`03ooooo`Ko00002oooool00onHV9So8B4Qonk^kP23
ooooo`00K?ooool00ol0003ok^k^ooooo`04ooooo`03o`000?oooooooooo00;ooooo00Ook^k^o`00
0?oooooo0000oooooomVIVKoQhN700?ooooo00?o0000ooooooooool00oooool01?lQ8B7oMgMgogMg
Molb<S8;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`03onk^k_l0003ooooo01_ooooo00?o0000ooooooooool05Oooool00omgMgOoIVIV
ooooo`22ooooo`00K?ooool00omEEEGoMgMgooooo`04ooooo`03o`000?oooooooooo00;ooooo00Co
IVIVoiRHV?oooooo<S8b0_nj^[X01Ol0003ooooooooooooooooo000000Cooooo0_l00002ooooo`;o
00002?ooool00ol@413o0000o`000003o`0000Cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`02ooooo`03ogMgMomEEEGooooo00?ooooo1?l0000Booooo`03oa0@4?l0003o000000?o
00005Oooool00ol0003oooooooooo`21ooooo`00K?ooool00ooMgMgo410@onk^kP04ooooo`03o`00
0?oooooooooo00Gooooo00?oIVIVohN7Qoooool01?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool01ol0003oooooooooooooooook^k^oa0@
4?oMgMd01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo00Go0000okZj
^_ooooooV9RHoa0@4023ooooo`00KOooool00omgMgOoIVIVooooo`03ooooo`03o`000?oooooooooo
00Gooooo00?oZJVYodA4A?ooool01?ooool2o`0001?ooooo00?o0000ooooooooool01?ooool2o`00
00Sooooo00Ko0000ooooooooooooooooofIVI_mgMgL7ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04_ooool01OnHV9So410@o`000?lQ8B7oc<c<08?ooooo002fooooo`03o`000?oo
oooooooo0:oooooo002cooooo`04o`000?ooooooooooo`000;7ooooo002dooooo`;o0000/_ooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.8522, -0.080387, \
0.130126, 0.00668404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.1) show
176.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00021 m
.02846 .00034 L
.02952 .00047 L
.03068 .00055 L
.03178 .00053 L
.03279 .00043 L
.03399 .00026 L
.03527 .0001 L
.03635 3e-05 L
.03754 6e-05 L
.0388 .0002 L
.0395 .0003 L
.04016 .00039 L
.04144 .00051 L
.04262 .00051 L
.04387 .0004 L
.045 .00024 L
.0463 7e-05 L
.04753 0 L
.04867 5e-05 L
.04973 .00017 L
.05087 .00034 L
.0521 .00049 L
.05334 .00053 L
.0545 .00046 L
.0552 .00037 L
.05587 .00027 L
.05713 .0001 L
.05845 2e-05 L
.05968 7e-05 L
.06031 .00014 L
.06102 .00025 L
.06176 .00036 L
.06244 .00046 L
.06371 .00058 L
.06439 .00058 L
.0651 .00054 L
.06586 .00046 L
.06657 .00037 L
.06722 .00027 L
.0679 .00018 L
.06915 8e-05 L
.0703 .00011 L
.07154 .00025 L
.0729 .00047 L
.07366 .00057 L
.07437 .00064 L
.07501 .00066 L
.07571 .00065 L
.07647 .00059 L
Mistroke
.07728 .00049 L
.07873 .00029 L
.07944 .00021 L
.0802 .00018 L
.08092 .00019 L
.08159 .00024 L
.08285 .0004 L
.08353 .00051 L
.08418 .00061 L
.08545 .00074 L
.08661 .00075 L
.08786 .00064 L
.08856 .00055 L
.08921 .00046 L
.0903 .00034 L
.09149 .0003 L
.09274 .00038 L
.09391 .00054 L
.09522 .00073 L
.09587 .0008 L
.09659 .00085 L
.09787 .00083 L
.09905 .00073 L
.09971 .00065 L
.10043 .00056 L
.10172 .00046 L
.1025 .00045 L
.10322 .00048 L
.10388 .00054 L
.10458 .00062 L
.1058 .00079 L
.10644 .00087 L
.10712 .00094 L
.10837 .00098 L
.10953 .00093 L
.11058 .00082 L
.1117 .00071 L
.11292 .00064 L
.11404 .00066 L
.11523 .00076 L
.11653 .00094 L
.11775 .0011 L
.11887 .00118 L
.11955 .00119 L
.1202 .00118 L
.12088 .00114 L
.12162 .00108 L
.12226 .00103 L
.12295 .00098 L
.12419 .00094 L
Mistroke
.12534 .00099 L
.1264 .00111 L
.12765 .00129 L
.12882 .00146 L
.13002 .00157 L
.13134 .0016 L
.13249 .00155 L
.13372 .00148 L
.13487 .00145 L
.1361 .00151 L
.13727 .00166 L
.13834 .00184 L
.13939 .00203 L
.14037 .00218 L
.1414 .00227 L
.14252 .00231 L
.14377 .00229 L
.14495 .00226 L
.14618 .00229 L
.14683 .00235 L
.14753 .00243 L
.14825 .00255 L
.14901 .0027 L
.15036 .00298 L
.15161 .00319 L
.15232 .00327 L
.15298 .00331 L
.15427 .00335 L
.15549 .00334 L
.15659 .00337 L
.15777 .00347 L
.15906 .00367 L
.16043 .00395 L
.16172 .00421 L
.16289 .00438 L
.16402 .00447 L
.16509 .0045 L
.16622 .0045 L
.16746 .00453 L
.16853 .00461 L
.16967 .00475 L
.17173 .00512 L
.17299 .00532 L
.1737 .00541 L
.17436 .00546 L
.17556 .0055 L
.17683 .00551 L
.17797 .00551 L
.17903 .00555 L
.1802 .00566 L
Mistroke
.18145 .00583 L
.18268 .00602 L
.18336 .00612 L
.18401 .00621 L
.18526 .00633 L
.1864 .00638 L
.1876 .0064 L
.1889 .00643 L
.18959 .00646 L
.19033 .00652 L
.19103 .00659 L
.19166 .00668 L
.19742 .00756 L
.19877 .00768 L
.20019 .00784 L
.20141 .00802 L
.20274 .0083 L
.20772 .00968 L
.21032 .01034 L
.21311 .01121 L
.21575 .01235 L
.21816 .0135 L
.22288 .01567 L
.26271 .04093 L
.30103 .0716 L
.30557 .08112 L
.31035 .09045 L
.31286 .0943 L
.3156 .09754 L
.3168 .09866 L
.31809 .09966 L
.3193 .10041 L
.32041 .10092 L
.32109 .10115 L
.32182 .10132 L
.32313 .10147 L
.32386 .10147 L
.32453 .10143 L
.32528 .10133 L
.32608 .1012 L
.33144 .09992 L
.33422 .09908 L
.33685 .09802 L
.33922 .09683 L
.3418 .09513 L
.34308 .09405 L
.34447 .09262 L
.34698 .0892 L
.34942 .08481 L
.35166 .07997 L
Mistroke
.36217 .05242 L
.36446 .04687 L
.36692 .04175 L
.3692 .03786 L
.37136 .03496 L
.37252 .03372 L
.37378 .03264 L
.37492 .03192 L
.37598 .03147 L
.37715 .03124 L
.37844 .03131 L
.37909 .03146 L
.37979 .03172 L
.38106 .03242 L
.38609 .03764 L
.38885 .04156 L
.39146 .04527 L
.39264 .04674 L
.39389 .04805 L
.39454 .04859 L
.39526 .04907 L
.39653 .04956 L
.39767 .04958 L
.3989 .04912 L
.40006 .04823 L
.40113 .04704 L
.40241 .04515 L
.4036 .043 L
.4063 .037 L
.41121 .0243 L
.41397 .01781 L
.41655 .01289 L
.41925 .00917 L
.42069 .00774 L
.42223 .00658 L
.42349 .00592 L
.42462 .00554 L
.42594 .00535 L
.42718 .00546 L
.42833 .00584 L
.42939 .00646 L
.43055 .00748 L
.43178 .00898 L
.43302 .01096 L
.43435 .01364 L
.43676 .0199 L
.44224 .03841 L
.44494 .04668 L
.44568 .04846 L
.44647 .05002 L
Mistroke
.44721 .05116 L
.44789 .05187 L
.44858 .05227 L
.44922 .05233 L
.44991 .05205 L
.45065 .05136 L
.45189 .0493 L
.4526 .04766 L
.45326 .04584 L
.45849 .02509 L
.46079 .01549 L
.4621 .01079 L
.46333 .00712 L
.4645 .00439 L
.46576 .00228 L
.46641 .00152 L
.4671 .00094 L
.46834 .00043 L
.46899 .0004 L
.46969 .00051 L
.47094 .00103 L
.47171 .00151 L
.47243 .00204 L
.47379 .00321 L
.47894 .00885 L
.48369 .0145 L
.48592 .01673 L
.48801 .01836 L
.4902 .01958 L
.49135 .02005 L
.49259 .02043 L
.49383 .02071 L
.49453 .02082 L
.49518 .02089 L
.49637 .02095 L
.49764 .02091 L
.49888 .02075 L
.50006 .0205 L
.50111 .0202 L
.50225 .0198 L
.50711 .01754 L
.51171 .01499 L
.51701 .01113 L
.52184 .00706 L
.52442 .00511 L
.52584 .00421 L
.52716 .00352 L
.5286 .00295 L
.52935 .00273 L
.53017 .00255 L
Mistroke
.53092 .00244 L
.53162 .00238 L
.53226 .00235 L
.53295 .00235 L
.53365 .00238 L
.53431 .00242 L
.53555 .00252 L
.53832 .00274 L
.54331 .00308 L
.58286 .00577 L
.60122 .00711 L
.61164 .00789 L
.62138 .00874 L
.6413 .01112 L
.66236 .01468 L
.68098 .01796 L
.6908 .01945 L
.69576 .02005 L
.70125 .02056 L
.70398 .02076 L
.70693 .02095 L
.70953 .02108 L
.71226 .0212 L
.7148 .02128 L
.71615 .02132 L
.71758 .02135 L
.71827 .02136 L
.71891 .02137 L
.72011 .02138 L
.72124 .02139 L
.72247 .02139 L
.72372 .02138 L
.72488 .02136 L
.72617 .02134 L
.72755 .02131 L
.73031 .02123 L
.73293 .02113 L
.73797 .02088 L
.74258 .02062 L
.75218 .01994 L
.76241 .01897 L
.7808 .01669 L
.82241 .01046 L
.8433 .00761 L
.86251 .00549 L
.88246 .00363 L
.89221 .00282 L
.89327 .00284 L
.89427 .00286 L
.89531 .00284 L
Mistroke
.89646 .00276 L
.89762 .00261 L
.89886 .00243 L
.89992 .00228 L
.90108 .00217 L
.90227 .00214 L
.90352 .00217 L
.90469 .00222 L
.90576 .00225 L
.90687 .00222 L
.90805 .00211 L
.90915 .00196 L
.91018 .0018 L
.91137 .00166 L
.91262 .00159 L
.91369 .0016 L
.91486 .00167 L
.91612 .00175 L
.91683 .00177 L
.91748 .00177 L
.91874 .00168 L
.91993 .00153 L
.92121 .00133 L
.92242 .00119 L
.92309 .00115 L
.92381 .00114 L
.92506 .0012 L
.92627 .00131 L
.92754 .0014 L
.92863 .0014 L
.92982 .00131 L
.93121 .00111 L
.93252 .00092 L
.93324 .00084 L
.93403 .0008 L
.93474 .00079 L
.9354 .00083 L
.93679 .00096 L
.93748 .00103 L
.93812 .00108 L
.9393 .00112 L
.9406 .00105 L
.94167 .00091 L
.94264 .00075 L
.94376 .0006 L
.94481 .00053 L
.94594 .00054 L
.94699 .00063 L
.94821 .00077 L
.94934 .00088 L
Mistroke
.95026 .0009 L
.95124 .00086 L
.95233 .00073 L
.95333 .00058 L
.95436 .00043 L
.95549 .00034 L
.95655 .00033 L
.95753 .0004 L
.95854 .00052 L
.9596 .00065 L
.96077 .00073 L
.96183 .00073 L
.963 .00062 L
.96428 .00044 L
.96546 .00028 L
.96658 .00019 L
.96784 .00021 L
.96899 .00033 L
.97032 .0005 L
.97156 .00061 L
.97264 .00062 L
.97378 .00054 L
.97493 .00039 L
.97619 .00021 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`0Rooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00GoA4A4o`000?l0003o<S8bomgMg@1Gooooo`05odA4A?l0003o0000oc8b<_oMgMd09oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo02Gooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool09?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00omgMgOo<S8booooo`1Iooooo`03ogMgMolb<S;ooooo02Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Uooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool6o`0000Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[
ooooo`03ogMgMolb<S;ooooo05Wooooo00?oMgMgoc8b<_ooool0:?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo02Gooooo000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0Eoooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001Wooooo
00?oEEEEofIVI_l000001Oooool4o`0002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo1?l0001Hooooo`Co0000:?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool00omEEEGoIVIVo`000005ooooo`Co00009oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooC_ooool2o`0000;ooooo0_l0000Eooooo`00oooooom>
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5Oooool00?ooooooCoooool01?oMgMgo0000oa0@
4?o<c<`Fooooo`005?ooooooo`00033o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hFooooo`006ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooo`00000;o`0000Gooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Gooooo1?l00007ooooo`03o`000?oooooooooo00Gooooo3?l0
0009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`04oooooa;o00000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo00Co
8B4QogMgMomgMgOo<S8b5_ooool001_ooooo00?o0000ooooooooool09oooool<o`0002[ooooo00?o
0000ooooooooool05Oooool4o`0000Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02_ooool>o`0000kooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`02ooooo`co00007oooool00ol0003oooooooooo`0?ooooo`;o0000
0_ooool2o`0001Gooooo001@ooooo`Co0000?oooool00ol0003oooooooooo`02o`0000Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool06Oooool7o`0003Kooooo1_l0001Hooooo`00E?ooool3o`0003_ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo1_l0000Y
ooooo`Oo0000G_ooool005Oooooo0_l0000iooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`;o00000oooool00ol0003oooooo`000002o`00
02[ooooo1_l0000Mooooo`Ko0000IOooool005Wooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool6o`0003?o
oooo2ol00007ooooo`_o0000Joooool005[ooooo0_l0000eooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03cooooo
2?l0001fooooo`00G?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0;[ooooo001M
ooooo`;o0000<Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`2jooooo`00Goooool00ol0003oooooooooo`0Roooo
o`Co00001oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02_ooool2o`000;_ooooo001Pooooo`;o00008_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000cooooo00?o0000
ooooooooool0^_ooool006;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool0000=
ooooo`03o`000?oooooooooo0;[ooooo001Sooooo`;o00007_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0000=
ooooo`03o`000?oooooooooo0;[ooooo001Uooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool01Oooool2o`000003ooooool0003ooooo00_ooooo00Co0000oooooooooooo00003Oooool0
0ol0003oooooooooo`2jooooo`00I_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00Kooooo0ol0000=ooooo`?o00003Oooool00ol0003oooooooooo`2jooooo`00Ioooool2o`0001So
oooo00?o0000ooooooooool05oooool2o`0000kooooo00?o0000ooooooooool0^_ooool006Wooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0;[ooooo
001Zooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`2jooooo`00Joooool2o`0001?ooooo00?o0000ooooooooool0:?ooool2o`000;_ooooo001]oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`2joooo
o`00K_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool0^_ooool006oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo0;[ooooo001_ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`2jooooo`00L?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool0^_ooool0073ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo0;[ooooo001`ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`2jooooo`00LOooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0^_ooool007;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0/ooooo`;o0000^oooool007;ooooo00?o0000
ooooooooool01Oooool3o`0002kooooo00?o0000ooooooooool0^_ooool007?ooooo0_l00002oooo
o`Co0000<?ooool00ol0003oooooooooo`2jooooo`00M?ooool3o`0003Cooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o
0000ooooooooool0^_ooool0093ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?o0000ooooooooool0^_ooool0093ooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0002jooooo`00T?ooool01Ol0003ooooooooooooo
oooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`2jooooo`00T?ooool0
1Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RH
oa0@4006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool0093o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`00
00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002jooooo`00T?ooool01Ol0003ooooooooooooooooo
000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`2jooooo`00T?ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003ooooooooo
o`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001ooo
ool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?o
MgMgo`000?ooool01_ooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^ooo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEE
EOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooo
oooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000^_ooool0093o
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`2jooooo`00T?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000
oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05oa0@4?oooooo
ooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0;[ooooo002@
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oo
oooooooo0;[ooooo002@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`00
0?l@4106ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0
003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000;[ooooo002@ooooo`05o`000?oo
ooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000oooooooo
ool0^_ooool0093ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj
^_l@41001_ooool00ol0003oooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0;[ooooo002@oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:7ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo0;[ooooo002Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^_ooool00:?o
oooo00?o0000ooooooooool01Oooool3o`000;[ooooo002Sooooo`03o`000?oooooooooo0<;ooooo
002Sooooo`03o`000?oooooooooo0<;ooooo002Sooooo`03o`000?oooooooooo0<;ooooo002Soooo
o`03o`000?oooooooooo0<;ooooo002Qooooo`03oeEEEOmVIVKo00000<Cooooo003oooooofWooooo
001Yooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool00_ooool00onj^[[o<S8boooo
o`07ooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001oooool00ol0003ooooooooo
o`02ooooo`03ofIVI_mgMgOooooo00cooooo00?o0000okZj^_ooool0[Oooool006Sooooo00?ogMgM
oa0@4?o^k^h01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`03onk^k_l@413ogMgM00cooooo0_lb<S:^ooooo`00J?ooool00omEEEGoV9RHooooo`05oooo
o`06o`000?oooooooooooooooonHV9So410@0_l000000onYZJWoooooooooo`04ooooo`04o`000?oo
ooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000
o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03
ohN7QomVIVKooooo00_ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj
013ooooo1Ol00005ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo07Cooooo001Xooooo`03
o`000?oooooooooo00Gooooo00[o0000ooooooooooooooooo`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj
1Oooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0
003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool00oo^k^ko0000ooooo`0;ooooo`03olc<c?l0003o410@00cooooo
00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A005
ooooo`;o8B4Q1oooool00ol0003oooooooooo`1fooooo`00J?ooool00olb<S;oooooooooo`05oooo
o`0:o`000?oooooooooooooooolb<S;ok^k^oiRHV?mEEEGogMgMoa0@40Gooooo00?o0000oooooooo
ool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool04oooool00onHV9So8B4Qonk^kP0?ooooo`03o`000?oooooooooo07Kooooo001Xooooo`03
oc8b<_oooooooooo00Gooooo00_o0000oooooooooooooooookZj^_m4A4Coc<c<ob4Q8Ooooooo410@
olc<c004ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00ko
oooo00?o0000ooooooooool0M_ooool006Sooooo00?o0000onk^k_ooool01Oooool02ol0003ooooo
ooooooooooook^k^o`000?oooooo0000oooooomVIVKoQhN700Cooooo00?o0000ooooooooool00_oo
ool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03onk^k_l0003ooooo01[ooooo00?o0000ooooooooool0
5Oooool00omgMgOoIVIVooooo`0=ooooo`03o`000?oooooooooo07Kooooo001Xooooo`03oeEEEOmg
MgOooooo00Gooooo00So0000ooooooooooooooooofIVI_nHV9Sooooooc8b<P;o^[Zj00?o0000oooo
ooooool00_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o
000000?o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?oMgMg
oeEEEOooool00_ooool4o`0001;ooooo00?o410@o`000?l000000ol0000Eooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0M_ooool006Sooooo00?ogMgMoa0@4?o^k^h01Oooool00ol0
003oooooooooo`04ooooo`03ofIVI_n7QhOooooo00Gooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00oo^
k^ko410@omgMg@04ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04_ooool01Ol0
003o^[ZjoooooonHV9So410@00kooooo00?o0000ooooooooool0M_ooool006Wooooo00?oMgMgofIV
I_ooool01?ooool00ol0003oooooooooo`04ooooo`03ojVYZOm4A4Cooooo00Gooooo0_l0000Boooo
o`03o`000?oooooooooo00Gooooo0_l00007ooooo`03o`000?oooooooooo00;ooooo00?oIVIVogMg
Moooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000007Sooooo002booooo`03o`000?oooooooooo
0;?ooooo002_ooooo`04o`000?ooooooooooo`000;Gooooo002`ooooo`;o0000]_ooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.8522, -0.080387, \
0.130126, 0.00668404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
176.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00108 m
.02499 .00069 L
.02605 .00037 L
.02729 .00017 L
.02846 .00022 L
.02954 .00046 L
.03053 .00078 L
.03162 .00111 L
.03279 .00131 L
.03396 .00128 L
.03506 .00104 L
.03636 .0006 L
.03756 .00023 L
.0388 4e-05 L
.0395 6e-05 L
.04015 .00016 L
.04135 .0005 L
.04262 .00093 L
.04327 .00112 L
.04396 .00125 L
.04519 .00128 L
.04588 .00116 L
.04652 .00099 L
.04797 .00049 L
.04925 .00012 L
.05041 0 L
.05105 4e-05 L
.05175 .00018 L
.05302 .00057 L
.05424 .00099 L
.05539 .00125 L
.05659 .00127 L
.05723 .00117 L
.05791 .001 L
.05904 .00062 L
.0601 .00028 L
.06133 5e-05 L
.06244 7e-05 L
.06372 .00036 L
.06443 .00059 L
.06509 .00082 L
.06629 .00116 L
.06756 .0013 L
.06822 .00125 L
.06893 .00113 L
.07022 .00075 L
.07096 .00051 L
.07174 .0003 L
.07248 .00016 L
.07315 .00011 L
Mistroke
.0739 .00015 L
.0746 .00027 L
.07536 .00047 L
.07617 .00073 L
.0769 .00096 L
.07767 .00116 L
.07832 .00127 L
.07904 .00132 L
.07975 .00128 L
.08039 .00118 L
.08113 .001 L
.08183 .0008 L
.08306 .00045 L
.08377 .00031 L
.08443 .00025 L
.0856 .0003 L
.08686 .00057 L
.08812 .00095 L
.08881 .00115 L
.08945 .00129 L
.0906 .00142 L
.09187 .00132 L
.09294 .00109 L
.09409 .00078 L
.09475 .00063 L
.09545 .00051 L
.09621 .00046 L
.09692 .00049 L
.09819 .00072 L
.09891 .00093 L
.09959 .00114 L
.10082 .00149 L
.102 .00168 L
.10264 .00169 L
.10335 .00164 L
.10458 .00141 L
.10571 .00114 L
.10691 .00092 L
.10822 .00088 L
.10942 .00107 L
.11054 .0014 L
.11159 .00175 L
.11274 .00208 L
.11396 .00225 L
.11466 .00224 L
.1153 .00217 L
.11601 .00205 L
.11676 .00188 L
.11801 .00163 L
.11872 .00155 L
Mistroke
.11939 .00154 L
.12064 .00171 L
.12177 .00205 L
.12311 .00254 L
.12433 .00292 L
.12562 .0031 L
.12633 .00309 L
.127 .00301 L
.12819 .00279 L
.12948 .00255 L
.13016 .00249 L
.1309 .00249 L
.13168 .00259 L
.13241 .00277 L
.13371 .00322 L
.13443 .0035 L
.1351 .00373 L
.13642 .00405 L
.13711 .00411 L
.13785 .0041 L
.13909 .00393 L
.1398 .00379 L
.14045 .00367 L
.14166 .00354 L
.14297 .00363 L
.14412 .00391 L
.14533 .00432 L
.14657 .00474 L
.14726 .00491 L
.14791 .00502 L
.14909 .00505 L
.15034 .0049 L
.15138 .00471 L
.1525 .00453 L
.15373 .00449 L
.15488 .00464 L
.15619 .00497 L
.15762 .0054 L
.15827 .00557 L
.15897 .00569 L
.16022 .00577 L
.16153 .00565 L
.16277 .00544 L
.16389 .00529 L
.16509 .00524 L
.16624 .00536 L
.16731 .00559 L
.16859 .00594 L
.16975 .00624 L
.17097 .00644 L
Mistroke
.17212 .00649 L
.17334 .00642 L
.17466 .0063 L
.17572 .00626 L
.17688 .00633 L
.1781 .00657 L
.17924 .00691 L
.18346 .00812 L
.18586 .00831 L
.18655 .00836 L
.1872 .00844 L
.18842 .0087 L
.18912 .00892 L
.18977 .00917 L
.19122 .00987 L
.19383 .01116 L
.2037 .01554 L
.22222 .02615 L
.2313 .03158 L
.2363 .03392 L
.23749 .03461 L
.23876 .03528 L
.23993 .03578 L
.24103 .03615 L
.2423 .03646 L
.24371 .03675 L
.24662 .03751 L
.25172 .0391 L
.25402 .03944 L
.25528 .0396 L
.25648 .03982 L
.25716 .03998 L
.25789 .04019 L
.25918 .04066 L
.26169 .04176 L
.26418 .0429 L
.2668 .04421 L
.26905 .04574 L
.27152 .04805 L
.27686 .05452 L
.28187 .06247 L
.29072 .0807 L
.29539 .09042 L
.29795 .0951 L
.30037 .09853 L
.30173 .10003 L
.3032 .10132 L
.30454 .10223 L
.30576 .10282 L
.30693 .10316 L
Mistroke
.3082 .10324 L
.30884 .10316 L
.30953 .10299 L
.31077 .10243 L
.31204 .10157 L
.31342 .10036 L
.31594 .09768 L
.32065 .09169 L
.33918 .06592 L
.3494 .05223 L
.35898 .04241 L
.3638 .03866 L
.36627 .03707 L
.36898 .03573 L
.37043 .03521 L
.37113 .03501 L
.37178 .03486 L
.37253 .03473 L
.37321 .03466 L
.37394 .03462 L
.37473 .03464 L
.37537 .03469 L
.37607 .03479 L
.37679 .03493 L
.37748 .0351 L
.38 .03596 L
.38242 .0369 L
.38375 .03734 L
.38499 .03763 L
.38564 .03773 L
.38633 .03779 L
.38711 .03778 L
.38782 .0377 L
.38909 .03738 L
.38973 .03713 L
.39043 .03678 L
.39173 .03595 L
.3929 .03498 L
.39555 .03218 L
.40032 .0261 L
.40489 .02102 L
.40747 .01898 L
.40985 .01759 L
.41456 .01555 L
.41887 .01381 L
.42001 .01342 L
.42125 .01309 L
.42243 .01295 L
.42353 .013 L
.4248 .01334 L
Mistroke
.42595 .01397 L
.42659 .01446 L
.42728 .01511 L
.42854 .0166 L
.43083 .02036 L
.43326 .02545 L
.43553 .03066 L
.4376 .03507 L
.43877 .03715 L
.44005 .03887 L
.44075 .03954 L
.4414 .03995 L
.44268 .04014 L
.44378 .03963 L
.44499 .03834 L
.44625 .03625 L
.44743 .03368 L
.45259 .01917 L
.45531 .01237 L
.45684 .00958 L
.45756 .00856 L
.45822 .00779 L
.45948 .00675 L
.46014 .0064 L
.46085 .00616 L
.46202 .00601 L
.46332 .00608 L
.4645 .00625 L
.46577 .00647 L
.46806 .00679 L
.46939 .00693 L
.47009 .00701 L
.47084 .00712 L
.47155 .00724 L
.4722 .00739 L
.47347 .00779 L
.47469 .00834 L
.47602 .00914 L
.47841 .01111 L
.48311 .01586 L
.48567 .01808 L
.48692 .01894 L
.48806 .01957 L
.48904 .02002 L
.4901 .0204 L
.49122 .0207 L
.49229 .02089 L
.49345 .021 L
.49469 .02099 L
.49575 .02089 L
Mistroke
.49692 .02066 L
.4982 .02026 L
.4994 .01975 L
.50211 .01815 L
.50704 .01445 L
.51631 .00786 L
.52151 .00455 L
.52406 .00324 L
.52641 .00233 L
.52773 .00196 L
.5284 .00181 L
.52912 .00168 L
.52984 .00158 L
.53052 .00151 L
.53132 .00146 L
.53206 .00144 L
.53332 .00145 L
.53403 .00147 L
.53469 .00149 L
.53718 .00163 L
.57642 .00405 L
.61415 .00668 L
.6351 .0083 L
.64428 .00911 L
.65433 .01022 L
.67316 .01291 L
.69299 .01636 L
.70307 .01798 L
.71258 .01925 L
.71785 .01979 L
.72062 .02004 L
.72213 .02018 L
.72355 .02031 L
.72484 .0204 L
.72602 .02047 L
.72733 .02052 L
.72874 .02056 L
.73125 .02065 L
.73353 .02075 L
.73471 .02079 L
.73599 .02082 L
.73719 .02082 L
.7383 .02081 L
.73958 .02078 L
.74077 .02077 L
.74202 .02077 L
.74268 .02077 L
.74339 .02078 L
.74456 .0208 L
.74584 .02081 L
Mistroke
.74705 .02079 L
.74817 .02075 L
.74918 .02071 L
.75029 .02065 L
.75253 .02054 L
.77326 .01924 L
.79263 .01751 L
.81349 .01489 L
.83316 .0119 L
.85466 .00877 L
.8646 .0075 L
.87521 .00632 L
.87641 .00607 L
.87768 .00595 L
.87835 .00594 L
.87908 .00597 L
.88036 .00606 L
.88157 .0061 L
.88287 .00602 L
.8841 .00579 L
.88522 .00549 L
.8863 .00518 L
.88745 .00491 L
.88872 .00476 L
.88989 .00477 L
.89108 .00489 L
.89221 .00501 L
.89322 .00506 L
.89431 .00499 L
.91392 .00314 L
.91516 .00335 L
.91648 .00342 L
.91716 .00337 L
.91792 .00324 L
.91861 .00306 L
.91925 .00286 L
.9205 .00247 L
.92168 .0022 L
.92233 .00213 L
.92305 .00212 L
.9243 .00225 L
.92506 .0024 L
.92575 .00254 L
.92655 .00269 L
.92731 .00277 L
.92801 .00278 L
.92865 .00272 L
.92936 .0026 L
.93011 .00241 L
.93132 .00204 L
Mistroke
.93263 .00168 L
.93338 .00156 L
.93406 .00151 L
.93475 .00154 L
.9354 .00161 L
.93667 .00187 L
.93787 .00212 L
.93911 .00226 L
.93978 .00225 L
.94049 .00217 L
.94169 .00189 L
.94295 .00151 L
.94403 .00122 L
.94521 .00105 L
.94593 .00104 L
.94661 .00111 L
.94788 .00136 L
.9486 .00153 L
.94936 .0017 L
.95002 .00181 L
.95074 .00187 L
.95201 .00179 L
.9532 .00152 L
.95448 .00113 L
.95516 .00094 L
.95588 .00077 L
.95716 .00066 L
.95835 .00078 L
.95957 .00106 L
.96069 .00135 L
.96177 .00155 L
.96295 .00159 L
.96406 .00142 L
.96508 .00114 L
.96619 .00079 L
.96737 .00048 L
.96867 .00037 L
.96989 .00051 L
.97054 .00066 L
.97125 .00087 L
.97254 .00123 L
.9738 .00142 L
.97496 .00136 L
.97619 .00108 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`0Rooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00GoA4A4o`000?l0003o<S8bomgMg@1Gooooo`05odA4A?l0003o0000oc8b<_oMgMd09oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo02Gooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool09?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00omgMgOo<S8booooo`1Iooooo`03ogMgMolb<S;ooooo02Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Uooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool6o`0000Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[
ooooo`03ogMgMolb<S;ooooo05Wooooo00?oMgMgoc8b<_ooool0:?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo02Gooooo000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0Eoooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001Wooooo
00?oEEEEofIVI_l000001Oooool4o`0002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo1?l0001Hooooo`Co0000:?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool00omEEEGoIVIVo`000005ooooo`Co00009oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooC_ooool2o`0000;ooooo0_l0000Eooooo`00oooooom>
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5Oooool00?ooooooCoooool01?oMgMgo0000oa0@
4?o<c<`Fooooo`005?ooooooo`00033o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hFooooo`006ooo
ool01?l0003oooooooooool00002ooooo`;o000000?oooooo`000?l000000_ooool00ol0003ooooo
ooooo`02o`000003ooooool0003o000000;ooooo4?l00009ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01?oooolGo`0000Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Cooooo3Ol000001?oooooo0000o`000?ooool3o`000003
ooooool0003o000001;ooooo00Co8B4QogMgMomgMgOo<S8b5_ooool001_ooooo00?o0000oooooooo
ool08_ooool<o`0002oooooo00?o0000ooooooooool08Oooool5o`0000Oooooo00?o0000oooooooo
ool00oooool2o`0001Kooooo2Ol00009ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool02_ooool=o`0001Kooooo00?o0000ooooooooool03oooool2o`0000;ooooo0_l0000Eooooo`00
Boooool4o`0004oooooo00?o0000ooooooooool00_ooool2o`0000Kooooo00Co0000oooooooooooo
oooo0_l0000Qooooo`co0000=Oooool5o`00053ooooo001>ooooo`?o0000@Oooool4o`0000Oooooo
00?o0000ooooooooool01?ooool2o`0000Gooooo00Co0000oooooooooooo0000;oooool5o`0002[o
oooo1_l0001Eooooo`00DOooool2o`0003gooooo0_l00003ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000003Gooooo
1Ol0000Iooooo`co0000Foooool005?ooooo0_l0000jooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`Ko0000>ooooolIo`0006Oooooo001E
ooooo`;o0000=oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02Oooool00ol0003oooooo`00002looooo`00Eoooool2o`0003Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0^_ooool005Wooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2jooooo`00
F_ooool2o`0002oooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000oo
oooo0_l0002kooooo`00G?ooool2o`0002Gooooo2Ol0000<ooooo`04o`000?ooooooooooo`0000oo
oooo00?o0000ooooooooool0^_ooool005kooooo1Ol0000Nooooo`;o00001Oooool2o`0000oooooo
0_l0000@ooooo`03o`000?oooooooooo0;[ooooo001Sooooo`;o00006oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo0;[ooooo001Tooooo`;o00006Oooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo0;[ooooo001Vooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`2jooooo`00I_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool0^_ooool006Oooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo0;[ooooo001Xooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2jooooo`00JOooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02gooooo0_l0002kooooo`00JOooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0^_ooool006[o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo0;[o
oooo001Zooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`2jooooo`00Joooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0^_ooool006_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo0;[ooooo001/ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`2jooooo`00K?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool0^_ooool006gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo0;[ooooo001]ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0<oooool2o`000;_ooooo001^ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2jooooo`00Koooool01Ol0
003ooooooooooooooooo000003Oooooo00?o0000ooooooooool0^_ooool006oooooo1Ol0000goooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0;[ooooo002@
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05o`000?oo
ooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000^_ooool0093ooooo00Go
0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0
^_ooool0093ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002k
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooo
oooo0;[ooooo002@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05o`000?oooooooooo
ooooool000002oooool01?m4A4CogMgMooooool00007ooooo`?o0000^_ooool0093ooooo00Go0000
ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0
^_ooool0093ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo
00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^
k_m4A4Co000000Oooooo00?o0000ooooooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o
0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0093ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Ko
oooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0^_ooool0093o
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3
o`000;[ooooo002@ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2jooooo`00T?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003ooooo
ooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0
2?ooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_oo
ool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05o`000?oo
ooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002jooooo`00
T?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006oooo
o`03o`000?oooooooooo0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@
413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003ooooooooo
o`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@06ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002Qooooo`Co000000?o410@ooooooooool00ooo
ool00ol0003oooooooooo`2jooooo`00Xoooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0;[ooooo002Sooooo`03o`000?oooooooooo00Gooooo0ol0002jooooo`00Xoooool00ol0003o
ooooooooo`32ooooo`00Xoooool00ol0003oooooooooo`32ooooo`00Xoooool00ol0003ooooooooo
o`32ooooo`00Xoooool00ol0003oooooooooo`32ooooo`00XOooool00omEEEGoIVIVo`000034oooo
o`00oooooomYooooo`00JOooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o^[Zjoc8b<_ooool01oooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Oooooo
00?o0000ooooooooool00_ooool00omVIVKoMgMgooooo`0<ooooo`03o`000?nj^[[ooooo0:gooooo
001Xooooo`03omgMgOl@413ok^k^00Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00oo^k^ko410@omgMg@0<ooooo`;o<S8b[_ooool006Sooooo00?oEEEE
oiRHV?ooool01Oooool01_l0003oooooooooooooooooV9RHoa0@40;o000000?oZJVYooooooooool0
1?ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Co
oooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00on7QhOoIVIVooooo`0;ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`00
0?l0003oA4A4okZj^P0@ooooo`Go00001Oooool2ob4Q8@Cooooo1Ol0001gooooo`00J?ooool00ol0
003oooooooooo`05ooooo`0:o`000?ooooooooooooooool0003oZJVYoeEEEOnHV9SoEEEEokZj^PGo
oooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000
oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?ok^k^o`000?ooool02oooool00oo<c<co0000oa0@400<ooooo`06
oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Ooo
ool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A01gooooo`00J?ooool00olb<S;ooooooooo
o`05ooooo`0:o`000?oooooooooooooooolb<S;ok^k^oiRHV?mEEEGogMgMoa0@40Gooooo00?o0000
ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool04oooool00onHV9So8B4Qonk^kP0=ooooo`03oiRHV?lQ8B7ok^k^07Sooooo001X
ooooo`03oc8b<_oooooooooo00Gooooo00_o0000oooooooooooooooookZj^_m4A4Coc<c<ob4Q8Ooo
oooo410@olc<c004ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo1_l0000;ooooo`03oiRHV?lQ8B7o
k^k^00gooooo00?oV9RHob4Q8Oo^k^h0Moooool006Sooooo00?o0000onk^k_ooool01Oooool02ol0
003oooooooooooooooook^k^o`000?oooooo0000oooooomVIVKoQhN700Cooooo00?o0000oooooooo
ool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`03onk^k_l0003ooooo01[ooooo00?o0000oooo
ooooool05Oooool00omgMgOoIVIVooooo`0=ooooo`03ogMgMomVIVKooooo07Kooooo001Xooooo`03
oeEEEOmgMgOooooo00Gooooo00So0000ooooooooooooooooofIVI_nHV9Sooooooc8b<P;o^[Zj00?o
0000ooooooooool00_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@
4?l0003o000000?o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?oMgMgoeEEEOooool00_ooool4o`0001;ooooo00?o410@o`000?l000000ol0000Eooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0MOooool006Sooooo00?ogMgMoa0@4?o^k^h01Ooo
ool00ol0003oooooooooo`04ooooo`03ofIVI_n7QhOooooo00Gooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool00oo^k^ko410@omgMg@04ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04_oo
ool01Ol0003o^[ZjoooooonHV9So410@00_ooooo00Go0000okZj^_ooooooV9RHoa0@401gooooo`00
JOooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo00Cooooo00?oZJVYodA4A?ooool0
1Oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0000Oooooo00?o0000ooooooooool0
0_ooool00omVIVKoMgMgooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
4_ooool01OnHV9So410@o`000?lQ8B7oc<c<00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c01goooo
o`00/_ooool00ol0003oooooooooo`2cooooo`00[oooool01?l0003oooooooooool0002eooooo`00
/?ooool2o`000;Kooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.8522, -0.080387, \
0.130126, 0.00668404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.3) show
176.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00289 m
.03279 .00181 L
.03405 .00247 L
.03477 .00265 L
.03543 .00267 L
.03665 .00232 L
.03793 .00156 L
.03901 .00085 L
.04016 .00027 L
.04143 9e-05 L
.04262 .00039 L
.04325 .00071 L
.04395 .00113 L
.04521 .00189 L
.04644 .00238 L
.04758 .00243 L
.04827 .00225 L
.04892 .00197 L
.05014 .00125 L
.05148 .00046 L
.05215 .00019 L
.05288 2e-05 L
.05412 .00014 L
.05527 .00062 L
.0564 .00128 L
.05748 .00187 L
.05873 .00228 L
.05987 .00225 L
.06111 .0018 L
.0618 .00143 L
.06244 .00105 L
.0637 .00038 L
.06486 5e-05 L
.06612 .00013 L
.06676 .00034 L
.06745 .00067 L
.06872 .00141 L
.06992 .00202 L
.07099 .00232 L
.07216 .00226 L
.07283 .00205 L
.07355 .00172 L
.07484 .001 L
.0755 .00066 L
.07621 .00037 L
.07698 .00019 L
.07771 .00019 L
.07837 .00032 L
.07909 .00061 L
.08041 .00137 L
Mistroke
.08159 .00209 L
.08288 .0026 L
.08364 .00269 L
.08435 .0026 L
.08503 .00239 L
.08574 .00205 L
.08699 .00134 L
.08768 .00098 L
.08833 .00072 L
.08908 .00056 L
.08976 .00057 L
.0904 .00073 L
.0911 .00103 L
.09187 .00149 L
.09268 .00206 L
.09344 .00257 L
.09414 .00296 L
.09537 .00333 L
.09602 .00332 L
.0967 .00317 L
.09785 .00264 L
.0991 .0019 L
.09981 .00154 L
.10048 .00131 L
.10125 .0012 L
.10194 .00129 L
.10321 .00185 L
.10392 .00233 L
.10458 .00281 L
.10584 .00366 L
.10703 .00413 L
.1081 .00414 L
.10927 .00373 L
.11053 .00302 L
.11171 .0024 L
.11294 .00209 L
.11359 .00213 L
.1143 .00234 L
.1155 .00301 L
.11676 .00393 L
.11784 .0046 L
.11901 .005 L
.12011 .00496 L
.12128 .00452 L
.12238 .00391 L
.12338 .00339 L
.12467 .00302 L
.12532 .00303 L
.12603 .00319 L
.12729 .00381 L
Mistroke
.12847 .00457 L
.12919 .00501 L
.12987 .00535 L
.13114 .00565 L
.13185 .0056 L
.13251 .00544 L
.13323 .00514 L
.134 .00475 L
.1353 .00412 L
.13604 .00388 L
.13671 .00377 L
.13795 .0039 L
.13926 .00445 L
.14037 .00507 L
.14155 .00566 L
.14284 .00603 L
.14404 .00599 L
.14525 .00564 L
.14594 .00536 L
.14658 .00508 L
.14775 .00468 L
.149 .00452 L
.15015 .0047 L
.15136 .00519 L
.15249 .00579 L
.15352 .00632 L
.15474 .00675 L
.15604 .00687 L
.15724 .00669 L
.15838 .00638 L
.15902 .0062 L
.1597 .00605 L
.16093 .00597 L
.16224 .00626 L
.16299 .00659 L
.16369 .00698 L
.16482 .0077 L
.16606 .00845 L
.16723 .00895 L
.16831 .00919 L
.16938 .00921 L
.17036 .00911 L
.17148 .00901 L
.17253 .00903 L
.17369 .00933 L
.17491 .00999 L
.17595 .01077 L
.1771 .01174 L
.17833 .01273 L
.17965 .01351 L
Mistroke
.18089 .01391 L
.18203 .01405 L
.18313 .01411 L
.18432 .01428 L
.18563 .01479 L
.18686 .01564 L
.18948 .01816 L
.19077 .01927 L
.19198 .01998 L
.19309 .02034 L
.19427 .02051 L
.19556 .02066 L
.19677 .021 L
.19788 .02158 L
.19908 .02251 L
.20116 .02449 L
.20237 .02549 L
.20367 .02622 L
.20442 .02645 L
.2051 .02657 L
.20578 .02663 L
.20643 .02665 L
.2071 .02668 L
.20781 .02675 L
.20909 .02711 L
.2098 .02745 L
.21046 .02787 L
.21199 .02901 L
.2132 .02995 L
.21448 .03071 L
.21558 .03109 L
.21678 .03122 L
.21808 .03116 L
.2188 .03111 L
.21947 .0311 L
.22065 .03124 L
.22194 .03168 L
.22317 .03232 L
.22448 .03311 L
.22521 .03351 L
.22591 .03383 L
.22723 .03421 L
.22846 .0343 L
.22961 .03424 L
.23087 .03416 L
.23157 .03418 L
.23221 .03425 L
.23342 .03457 L
.23452 .03507 L
.23702 .0365 L
Mistroke
.23816 .03707 L
.23922 .03747 L
.24033 .03775 L
.24155 .03797 L
.24285 .03823 L
.24359 .03844 L
.24427 .03871 L
.24551 .03941 L
.24684 .04043 L
.25166 .04466 L
.26249 .05733 L
.27211 .07343 L
.27735 .08327 L
.28222 .09156 L
.28437 .09515 L
.28639 .09786 L
.28751 .09896 L
.28873 .09984 L
.28983 .1004 L
.29085 .10076 L
.29198 .10102 L
.29303 .10116 L
.29419 .10117 L
.29543 .10096 L
.29674 .1004 L
.29797 .09951 L
.29908 .09839 L
.30028 .09687 L
.30967 .08099 L
.31966 .06298 L
.32481 .05625 L
.32622 .05472 L
.32774 .0533 L
.32905 .05228 L
.33049 .05137 L
.33304 .05018 L
.33443 .04969 L
.33572 .0493 L
.33692 .049 L
.33804 .04877 L
.33934 .04857 L
.34053 .04845 L
.34167 .04837 L
.34291 .04831 L
.34398 .04826 L
.34514 .04816 L
.34585 .04808 L
.3465 .04797 L
.3478 .04769 L
.34897 .04732 L
Mistroke
.35023 .04682 L
.353 .04533 L
.35562 .04347 L
.36051 .03894 L
.36475 .03455 L
.3693 .03059 L
.37429 .02745 L
.37895 .02521 L
.38396 .023 L
.38643 .02203 L
.38752 .02168 L
.38872 .02139 L
.38997 .0212 L
.39066 .02116 L
.3913 .02116 L
.39201 .02121 L
.39265 .0213 L
.39336 .02146 L
.39411 .02168 L
.39533 .02216 L
.39646 .02272 L
.39903 .02427 L
.40144 .02578 L
.40262 .02641 L
.40371 .02687 L
.4047 .02717 L
.40575 .02733 L
.40681 .02732 L
.40796 .02709 L
.40921 .02662 L
.41034 .02598 L
.41289 .02399 L
.41751 .01982 L
.4188 .01888 L
.42002 .01821 L
.42111 .01783 L
.42229 .01767 L
.42358 .01781 L
.42423 .01801 L
.42494 .0183 L
.42621 .01901 L
.42738 .01983 L
.42965 .02154 L
.43077 .0223 L
.4318 .02288 L
.43299 .02334 L
.43428 .02355 L
.43537 .02345 L
.43654 .02305 L
.45727 .01616 L
Mistroke
.46667 .01244 L
.46915 .00917 L
.46983 .00847 L
.47056 .00786 L
.47186 .00712 L
.4725 .00694 L
.47319 .00687 L
.47444 .00707 L
.47567 .0076 L
.47679 .00833 L
.479 .01027 L
.48143 .01279 L
.4838 .01523 L
.48634 .01746 L
.48756 .01831 L
.48871 .01896 L
.48974 .01942 L
.49086 .01978 L
.49193 .02 L
.49306 .0201 L
.49402 .02008 L
.49509 .01995 L
.4963 .01967 L
.49743 .01928 L
.49867 .01873 L
.49999 .01799 L
.50517 .01405 L
.51441 .00676 L
.51711 .00511 L
.52003 .00359 L
.52279 .00243 L
.5241 .00199 L
.52533 .00164 L
.52653 .00137 L
.52763 .00117 L
.52885 .00102 L
.53016 .00091 L
.53141 .00086 L
.53212 .00085 L
.53278 .00085 L
.53398 .00086 L
.53526 .00089 L
.53787 .00097 L
.54063 .00107 L
.54556 .00126 L
.5567 .00168 L
.56632 .00218 L
.57687 .00282 L
.61733 .00558 L
.65626 .00848 L
Mistroke
.66645 .00942 L
.67752 .0106 L
.69765 .01353 L
.71706 .01676 L
.72736 .01828 L
.73277 .01878 L
.73572 .01912 L
.73715 .01931 L
.73846 .01946 L
.73972 .01956 L
.7409 .01962 L
.74216 .01967 L
.74351 .01972 L
.74418 .01975 L
.74491 .0198 L
.74639 .01992 L
.74778 .02005 L
.74904 .02016 L
.75028 .02024 L
.75146 .02028 L
.7527 .02028 L
.7534 .02027 L
.75405 .02026 L
.75524 .02024 L
.75632 .02023 L
.75756 .02026 L
.75873 .02031 L
.75994 .02037 L
.76105 .02041 L
.76222 .02042 L
.7635 .02039 L
.76461 .02032 L
.76562 .02024 L
.76672 .02015 L
.76788 .02008 L
.76915 .02005 L
.77031 .02006 L
.77157 .0201 L
.77229 .02012 L
.77296 .02013 L
.77416 .02011 L
.77527 .02004 L
.77654 .01991 L
.77775 .01977 L
.81594 .01644 L
.85658 .01212 L
.87538 .00856 L
.87666 .00874 L
.87738 .00891 L
.87804 .00906 L
Mistroke
.87931 .00924 L
.88052 .00917 L
.88177 .00882 L
.88247 .00852 L
.88312 .0082 L
.88382 .00786 L
.88459 .00752 L
.8853 .00727 L
.88596 .00713 L
.88706 .00708 L
.88821 .00726 L
.88939 .00757 L
.89069 .00787 L
.89195 .00792 L
.89265 .00782 L
.89329 .00764 L
.89453 .0071 L
.89571 .00652 L
.89694 .00601 L
.89765 .00582 L
.8983 .00575 L
.899 .00576 L
.89963 .00585 L
.90036 .00603 L
.90105 .00624 L
.90219 .00656 L
.90341 .00674 L
.90411 .00671 L
.90474 .00659 L
.90598 .00614 L
.90732 .00547 L
.90805 .00511 L
.90874 .00483 L
.90948 .00462 L
.91029 .00452 L
.91098 .00455 L
.91172 .00468 L
.91308 .00511 L
.91382 .00536 L
.91452 .00554 L
.91576 .00567 L
.91641 .00561 L
.91712 .00543 L
.91778 .00518 L
.91847 .00484 L
.91971 .00419 L
.92037 .00389 L
.92106 .00363 L
.92183 .00346 L
.92254 .00343 L
Mistroke
.9232 .00351 L
.92392 .0037 L
.92523 .00418 L
.9265 .00463 L
.92767 .00481 L
.92882 .00467 L
.9299 .00426 L
.93118 .00358 L
.93234 .00297 L
.93357 .00257 L
.93473 .00253 L
.93595 .00284 L
.93664 .00312 L
.93729 .00341 L
.93845 .00389 L
.93968 .00413 L
.94072 .00403 L
.94187 .00359 L
.9431 .00289 L
.94426 .00223 L
.9449 .00195 L
.9456 .00176 L
.94681 .00176 L
.94799 .00214 L
.94923 .00276 L
.95037 .00331 L
.95145 .0036 L
.95244 .00357 L
.95351 .00321 L
.95469 .00252 L
.95577 .00183 L
.95703 .00122 L
.95773 .00107 L
.95837 .00106 L
.95961 .00142 L
.96078 .00205 L
.96205 .00278 L
.9627 .00305 L
.9634 .00322 L
.96417 .00321 L
.96488 .00303 L
.96554 .00273 L
.96624 .00231 L
.96752 .00144 L
.9682 .00104 L
.96891 .00072 L
.97023 .00058 L
.97145 .00097 L
.97619 .00289 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`0Rooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00GoA4A4o`000?l0003o<S8bomgMg@1Gooooo`05odA4A?l0003o0000oc8b<_oMgMd09oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo02Gooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool09?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00omgMgOo<S8booooo`1Iooooo`03ogMgMolb<S;ooooo02Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Uooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool6o`0000Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[
ooooo`03ogMgMolb<S;ooooo05Wooooo00?oMgMgoc8b<_ooool0:?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo02Gooooo000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0Eoooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001Wooooo
00?oEEEEofIVI_l000001Oooool4o`0002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo1?l0001Hooooo`Co0000:?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool00omEEEGoIVIVo`000005ooooo`Co00009oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooC_ooool2o`0000;ooooo0_l0000Eooooo`00oooooom>
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5Oooool00?ooooooCoooool01?oMgMgo0000oa0@
4?o<c<`Fooooo`005?ooooooo`00033o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hFooooo`006ooo
ool5o`000005ooooool0003o0000o`000?ooool00_l000001Ooooooo0000o`000?l0003ooooo00oo
00000_ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`03ooooo`?o000000?oooooo`000?ooool00_ooool@o`0000Sooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ool000003_l00002ooooo`03o`000?oooooooooo013ooooo00Co8B4QogMgMomgMgOo<S8b5_ooool0
01_ooooo00?o0000ooooooooool06Oooool2o`0000;ooooo0_l000000ooooooo0000o`000007o`00
00Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Tooooo`?o00001_ooool01?l0
003oooooooooooooool2o`0001Sooooo3?l00006ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool04Oooool<o`000003ooooool0003o000000gooooo00?o0000ooooooooool03oooool2
o`0000;ooooo0_l0000Eooooo`00A_ooool4o`0005Sooooo00Co0000ooooool0003o00001Oooool0
1?l0003oooooooooool0000Voooooa3o0000=Oooool6o`000003ooooool0003o000004Gooooo0019
ooooo`?o0000E?ooool2o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooo`00000g
ooooo`Ko00009_ooool9o`0004kooooo001<ooooo`03o`000?oooooooooo04kooooo0ol00006oooo
o`;o00000oooool2o`0003kooooo1Ol0000Eooooo`co0000Eoooool004gooooo0ol00012ooooo`Co
00001?ooool3o`0000[ooooo1Ol00014oooooaGo0000Hoooool004oooooo0_l0000fooooo`Ko0000
1?ooool00ol0003oooooooooo`02ooooo`Co00004Oooool00ol0003oooooooooo`2jooooo`00DOoo
ool3o`00033ooooo0ol00005ooooo`Go00006_ooool00ol0003oooooooooo`2jooooo`00Doooool3
o`0002gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`2jooooo`00EOooool4o`00
0003ooooool0003ooooo02Oooooo00?o0000ooooooooool09Oooool2o`000;_ooooo001Hooooo`Go
00009Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0;[ooooo001Looooo`?o0000
8Oooool2o`0002Wooooo00?o0000ooooooooool0^_ooool005oooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0;[ooooo001Pooooo`03o`000?oooooo
oooo01[ooooo0ol0000[ooooo`03o`000?oooooooooo0;[ooooo001Pooooo`03o`000?oooooooooo
01Gooooo1_l0000]ooooo`03o`000?oooooooooo0;[ooooo001Qooooo`03o`000?oooooooooo01?o
oooo0_l0000booooo`03o`000?oooooooooo0;[ooooo001Rooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2jooooo`00Hoooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0^_ooool006?ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0dooooo`;o0000^oooool006Cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo0;[ooooo001Uooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2jooooo`00
I_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
^_ooool006Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo0;[ooooo001Wooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`2jooooo`00J?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0^_ooool006Sooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo0;[ooooo001Yooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`2jooooo`00JOooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo03Sooooo0_l0002kooooo`00J_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0^_ooool006[ooooo0_l00002oooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0^_ooool006_ooooo0ol0000mooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0;[ooooo002@oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000^_ooool0093ooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0^_oo
ool0093ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o
0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002koooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo
0;[ooooo002@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo410@
00_ooooo1Ol00006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool00007ooooo`?o0000^_ooool0093ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0^_oo
ool0093ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o
0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000000Oooooo00?o0000ooooooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000
^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0093ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0^_ooool0093ooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`00
0;[ooooo002@ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2jooooo`00T?ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003ooooooooo
o`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Co
c<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2jooooo`00T?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05o`000?oooooo
ooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002jooooo`00T?oo
ool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03
o`000?oooooooooo0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o
^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`2j
ooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@06ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002Qooooo`Co000000?o410@ooooooooool00oooool0
0ol0003oooooooooo`2jooooo`00Xoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0;[ooooo002Sooooo`03o`000?oooooooooo00Gooooo0ol0002jooooo`00Xoooool00ol0003ooooo
ooooo`32ooooo`00Xoooool00ol0003oooooooooo`32ooooo`00Xoooool00ol0003oooooooooo`32
ooooo`00Xoooool00ol0003oooooooooo`32ooooo`00XOooool00omEEEGoIVIVo`000034ooooo`00
oooooomYooooo`00JOooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
^[Zjoc8b<_ooool01oooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Oooooo00?o
0000ooooooooool00_ooool00omVIVKoMgMgooooo`0<ooooo`03o`000?nj^[[ooooo0:gooooo001X
ooooo`03omgMgOl@413ok^k^00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00oo^k^ko410@omgMg@0<ooooo`;o<S8b[_ooool006Sooooo00?oEEEEoiRH
V?ooool01Oooool01_l0003oooooooooooooooooV9RHoa0@40;o000000?oZJVYooooooooool01?oo
ool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo
00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00on7QhOoIVIVooooo`0;ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0
003oA4A4okZj^P0@ooooo`Go00001Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c01g
ooooo`00J?ooool00ol0003oooooooooo`05ooooo`0:o`000?ooooooooooooooool0003oZJVYoeEE
EOnHV9SoEEEEokZj^PGooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM
0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?ok^k^o`000?ooool02oooool00oo<c<co
0000oa0@400<ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l00009ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01Oooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P1gooooo`00J?oo
ool00olb<S;oooooooooo`05ooooo`0:o`000?oooooooooooooooolb<S;ok^k^oiRHV?mEEEGogMgM
oa0@40Gooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool04oooool00onHV9So8B4Qonk^kP0@ooooo`03o`000?oo
oooooooo07Gooooo001Xooooo`03oc8b<_oooooooooo00Gooooo00_o0000oooooooooooooooookZj
^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c004ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q
8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo1_l0000;
ooooo`03oiRHV?lQ8B7ok^k^00kooooo00?oZJVYoa0@4?ooool0M_ooool006Sooooo00?o0000onk^
k_ooool01Oooool02ol0003oooooooooooooooook^k^o`000?oooooo0000oooooomVIVKoQhN700Co
oooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03onk^k_l0003ooooo
01[ooooo00?o0000ooooooooool05Oooool00omgMgOoIVIVooooo`0<ooooo`03oa0@4?l0003o^[Zj
07Oooooo001Xooooo`03oeEEEOmgMgOooooo00Gooooo00So0000ooooooooooooooooofIVI_nHV9So
oooooc8b<P;o^[Zj00?o0000ooooooooool00_ooool01?l0003oooooooooooooool2o`0000;ooooo
0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?oMgMgoeEEEOooool00_ooool4o`0001;ooooo00?o410@o`000?l00000
0ol0000Eooooo`03o`000?oooooooooo00cooooo00?o^[Zjob4Q8Oooool0M_ooool006Sooooo00?o
gMgMoa0@4?o^k^h01Oooool00ol0003oooooooooo`04ooooo`03ofIVI_n7QhOooooo00Gooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00oo^k^ko410@omgMg@04ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool04_ooool01Ol0003o^[ZjoooooonHV9So410@00_ooooo00Go410@oiRHV?oooooo
^[Zjo`00001gooooo`00JOooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?oZJVYodA4A?ooool01Oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0000Oooooo
00?o0000ooooooooool00_ooool00omVIVKoMgMgooooo`05ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04_ooool01OnHV9So410@o`000?lQ8B7oc<c<00_ooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@1gooooo`00/_ooool00ol0003oooooooooo`2cooooo`00[oooool01?l0003ooooo
ooooool0002eooooo`00/?ooool2o`000;Kooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.8522, -0.080387, \
0.130126, 0.00668404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
176.250 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .0046 m
.02499 .00489 L
.02605 .00454 L
.02729 .00354 L
.02846 .00231 L
.02946 .00134 L
.03053 .00068 L
.0317 .00057 L
.03279 .00106 L
.03395 .00205 L
.0352 .00325 L
.03638 .00412 L
.03746 .00441 L
.03873 .00403 L
.03944 .00351 L
.04011 .0029 L
.04141 .00157 L
.04262 .00059 L
.04386 .00019 L
.04452 .00028 L
.04521 .00061 L
.04637 .00156 L
.04765 .00284 L
.04879 .0038 L
.05001 .00427 L
.05116 .00403 L
.05221 .00328 L
.05343 .00204 L
.05473 .00077 L
.05541 .0003 L
.05615 3e-05 L
.05747 .00028 L
.0587 .00127 L
.06003 .00274 L
.06129 .00397 L
.06244 .00455 L
.06373 .00433 L
.0649 .0034 L
.06616 .00201 L
.06682 .00129 L
.06752 .00066 L
.06879 .00011 L
.06995 .00044 L
.07105 .00139 L
.07225 .00285 L
.0729 .00366 L
.07362 .00441 L
.07492 .00515 L
.0757 .00512 L
.07642 .00476 L
Mistroke
.07708 .00419 L
.07779 .00342 L
.07846 .00261 L
.07919 .00177 L
.08051 .00072 L
.08179 .00063 L
.08297 .00145 L
.08539 .00446 L
.08609 .00518 L
.08675 .00566 L
.08799 .00582 L
.0887 .00549 L
.08935 .00494 L
.09083 .00323 L
.09212 .00187 L
.09277 .00143 L
.09349 .00123 L
.09419 .00135 L
.09492 .00179 L
.09624 .00321 L
.09699 .00417 L
.09778 .00513 L
.09853 .00586 L
.09921 .00628 L
.10053 .00629 L
.10178 .00542 L
.10248 .00467 L
.10312 .00393 L
.10382 .00316 L
.10458 .00248 L
.10584 .00195 L
.10703 .00228 L
.10819 .00327 L
.10927 .0045 L
.11053 .00583 L
.11171 .00656 L
.11294 .00654 L
.11359 .00621 L
.1143 .00565 L
.11549 .00446 L
.11661 .00339 L
.11777 .00269 L
.11904 .00266 L
.12014 .00327 L
.12114 .00419 L
.1222 .0053 L
.12338 .00632 L
.12467 .00685 L
.12537 .00681 L
.12603 .00657 L
Mistroke
.12721 .00576 L
.12847 .00464 L
.12918 .00408 L
.12995 .00362 L
.13068 .0034 L
.13136 .00342 L
.13264 .00401 L
.13335 .0046 L
.134 .00523 L
.13521 .00645 L
.13648 .00744 L
.13715 .00772 L
.13788 .00781 L
.13917 .00743 L
.14038 .00663 L
.14169 .00571 L
.14292 .00517 L
.14404 .00522 L
.14522 .00589 L
.14632 .00698 L
.14764 .00851 L
.14885 .00974 L
.15005 .01046 L
.15131 .01054 L
.15257 .01003 L
.15329 .00961 L
.15396 .00922 L
.15515 .00876 L
.15628 .00883 L
.1573 .00942 L
.1584 .01057 L
.15958 .01217 L
.16084 .01386 L
.16204 .01505 L
.16313 .01557 L
.16442 .01548 L
.16564 .01496 L
.16695 .01439 L
.1677 .01427 L
.16839 .01436 L
.16911 .01471 L
.1698 .01528 L
.17108 .01686 L
.17247 .01892 L
.17323 .01997 L
.17394 .02078 L
.17513 .02164 L
.17644 .02179 L
.17754 .02143 L
.17873 .02089 L
Mistroke
.1794 .02066 L
.18012 .02056 L
.18144 .02096 L
.18272 .02209 L
.1839 .02359 L
.18515 .02523 L
.18633 .02647 L
.18739 .02708 L
.18855 .02715 L
.18981 .02667 L
.19051 .02628 L
.19115 .02594 L
.19239 .02551 L
.19356 .0256 L
.19466 .0262 L
.19583 .02725 L
.19683 .02831 L
.19791 .02934 L
.19907 .03008 L
.20015 .0303 L
.20144 .02999 L
.20262 .02936 L
.20389 .02866 L
.20454 .02841 L
.20525 .02829 L
.20651 .02853 L
.20769 .02924 L
.20909 .03043 L
.20985 .03109 L
.21057 .03162 L
.21183 .03224 L
.21249 .03235 L
.21321 .03233 L
.21451 .03197 L
.21573 .03148 L
.21684 .03119 L
.21803 .03122 L
.21935 .03181 L
.22001 .03231 L
.22074 .03298 L
.22324 .03549 L
.22453 .03643 L
.22574 .03693 L
.22641 .03707 L
.22714 .03716 L
.22841 .03728 L
.22915 .03744 L
.22993 .03774 L
.2306 .03815 L
.23133 .03877 L
Mistroke
.23274 .04043 L
.23405 .04238 L
.24431 .05372 L
.25361 .06824 L
.25878 .07719 L
.26106 .08167 L
.26235 .08363 L
.26357 .08503 L
.26599 .08724 L
.26857 .09016 L
.26995 .09212 L
.2714 .09416 L
.27265 .09557 L
.27335 .09615 L
.274 .09653 L
.27521 .09684 L
.2763 .09675 L
.27757 .09638 L
.27876 .09597 L
.28125 .09533 L
.2819 .09518 L
.28261 .09499 L
.28388 .09445 L
.28503 .09359 L
.28608 .09245 L
.28732 .09065 L
.2885 .08861 L
.29276 .08067 L
.30238 .06211 L
.30695 .05475 L
.30956 .05172 L
.31201 .04911 L
.31326 .04792 L
.31458 .04684 L
.3157 .04613 L
.31694 .04559 L
.31763 .04541 L
.31827 .04531 L
.319 .04526 L
.31969 .04528 L
.32092 .04541 L
.32161 .04553 L
.32225 .04565 L
.33112 .04873 L
.33234 .04938 L
.33368 .05001 L
.33494 .05045 L
.33611 .05067 L
.33726 .0507 L
.33831 .05056 L
Mistroke
.33952 .05021 L
.34066 .04973 L
.34308 .04828 L
.34531 .04642 L
.34775 .04367 L
.35033 .03998 L
.35939 .02606 L
.36185 .02288 L
.36448 .01992 L
.36696 .01773 L
.36923 .01629 L
.37061 .01566 L
.37188 .01524 L
.37255 .01508 L
.37328 .01495 L
.37405 .01487 L
.37477 .01485 L
.37609 .01495 L
.3773 .01522 L
.37793 .01542 L
.37862 .01571 L
.38002 .01649 L
.38134 .01746 L
.38256 .01857 L
.38531 .02174 L
.3903 .02885 L
.39264 .03207 L
.39484 .03454 L
.39594 .03548 L
.39712 .03621 L
.39844 .03663 L
.39964 .03661 L
.40093 .03616 L
.40165 .0357 L
.40231 .03518 L
.40358 .03385 L
.40478 .03228 L
.41039 .02279 L
.41277 .01883 L
.41529 .01541 L
.41661 .01402 L
.41805 .01281 L
.41937 .012 L
.42059 .01145 L
.42186 .01104 L
.4232 .01074 L
.42561 .0103 L
.42687 .01003 L
.42821 .00965 L
.42969 .00913 L
Mistroke
.43107 .00854 L
.43234 .00797 L
.43373 .00739 L
.43503 .00694 L
.43625 .0067 L
.43745 .00668 L
.43854 .0069 L
.4398 .00748 L
.44099 .00836 L
.44526 .01422 L
.44984 .02269 L
.45119 .02479 L
.45247 .02633 L
.45361 .02723 L
.45486 .0276 L
.45605 .02733 L
.4573 .02634 L
.45837 .02494 L
.45956 .02286 L
.46425 .01164 L
.46671 .00636 L
.46795 .00444 L
.46866 .00361 L
.46931 .00302 L
.47001 .00257 L
.47065 .00233 L
.47139 .00222 L
.47208 .00227 L
.4733 .00269 L
.47399 .00308 L
.47462 .00352 L
.47705 .00569 L
.47962 .00848 L
.48385 .01321 L
.48619 .01546 L
.48841 .01709 L
.48966 .01774 L
.49036 .01802 L
.49102 .01823 L
.49217 .01846 L
.49341 .01853 L
.49467 .01843 L
.49586 .01819 L
.49693 .01787 L
.49808 .01742 L
.50753 .01071 L
.51273 .00672 L
.51765 .00385 L
.52044 .00262 L
.5219 .00209 L
Mistroke
.52346 .00162 L
.52477 .00129 L
.52621 .00101 L
.52752 .00082 L
.52876 .0007 L
.53002 .00062 L
.53066 .00059 L
.53136 .00057 L
.53259 .00055 L
.53374 .00056 L
.53444 .00056 L
.5351 .00057 L
.53634 .00059 L
.53912 .00064 L
.54833 .00081 L
.55337 .00091 L
.55808 .00102 L
.56318 .00119 L
.56878 .0014 L
.57863 .00184 L
.61748 .00423 L
.65879 .00727 L
.66879 .00798 L
.67944 .0088 L
.69857 .01081 L
.73685 .01626 L
.74717 .01779 L
.7526 .01841 L
.75403 .01868 L
.75482 .01881 L
.75556 .01891 L
.75625 .01898 L
.75701 .01902 L
.75832 .01904 L
.75959 .01901 L
.76023 .019 L
.76093 .019 L
.76218 .01904 L
.76334 .01916 L
.76482 .01938 L
.76622 .0196 L
.76747 .01975 L
.76818 .01979 L
.76885 .0198 L
.77003 .01976 L
.7711 .01967 L
.77235 .01956 L
.7735 .01951 L
.77474 .01954 L
.77539 .0196 L
Mistroke
.77608 .01969 L
.77734 .01988 L
.77851 .02004 L
.77973 .02013 L
.78037 .02014 L
.78105 .02011 L
.7822 .01998 L
.78347 .01979 L
.78459 .01962 L
.7858 .01951 L
.78694 .0195 L
.78798 .01957 L
.78922 .01972 L
.7899 .01981 L
.79055 .01988 L
.7918 .01994 L
.79293 .01988 L
.79413 .01971 L
.79542 .01943 L
.7961 .01927 L
.79683 .01912 L
.79814 .01894 L
.7993 .01891 L
.80035 .01898 L
.80159 .01914 L
.80278 .01929 L
.80399 .01936 L
.80512 .0193 L
.80636 .01908 L
.80768 .01873 L
.80882 .01842 L
.81006 .01816 L
.81123 .01807 L
.8123 .01812 L
.81327 .01825 L
.81433 .01843 L
.81544 .01859 L
.81648 .01864 L
.81774 .0185 L
.81838 .01835 L
.81909 .01814 L
.82034 .01768 L
.8215 .01729 L
.82216 .01712 L
.82285 .01701 L
.82355 .01696 L
.82431 .017 L
.82497 .01709 L
.82568 .01723 L
.82695 .01751 L
Mistroke
.82824 .01768 L
.82896 .01767 L
.82963 .01759 L
.83085 .01724 L
.83215 .01669 L
.83323 .01621 L
.8344 .01582 L
.83567 .01565 L
.83686 .01577 L
.8381 .01609 L
.83925 .01641 L
.84051 .01661 L
.84115 .01661 L
.84185 .0165 L
.84302 .01611 L
.84428 .01549 L
.84538 .01493 L
.84657 .01447 L
.84774 .01429 L
.84882 .01439 L
.84997 .01471 L
.85119 .01512 L
.85233 .01539 L
.85341 .01541 L
.85438 .0152 L
.85543 .01474 L
.85664 .01405 L
.85778 .01341 L
.8591 .0129 L
.86031 .01279 L
.86144 .01299 L
.8625 .01334 L
.86364 .01375 L
.86488 .01401 L
.86559 .01401 L
.86624 .0139 L
.86752 .01339 L
.86868 .0127 L
.86991 .01193 L
.87055 .0116 L
.87124 .01134 L
.87247 .01116 L
.87323 .01125 L
.87394 .01144 L
.87458 .01168 L
.87528 .01196 L
.87658 .01242 L
.8778 .01258 L
.8785 .01249 L
.87914 .0123 L
Mistroke
.87984 .01197 L
.88058 .01152 L
.88188 .01064 L
.88259 .0102 L
.88327 .00987 L
.88407 .00961 L
.88479 .00953 L
.88547 .0096 L
.88621 .0098 L
.88753 .01037 L
.88876 .01091 L
.89005 .01119 L
.89073 .01115 L
.89147 .01095 L
.89277 .01024 L
.894 .00934 L
.89521 .00851 L
.89631 .00801 L
.89757 .00791 L
.89822 .00805 L
.89892 .00832 L
.90018 .00898 L
.90136 .00957 L
.90242 .00984 L
.90354 .00974 L
.90479 .00915 L
.90593 .00828 L
.90716 .00729 L
.90846 .00651 L
.90913 .00631 L
.90988 .00629 L
.91119 .00672 L
.91253 .00754 L
.91379 .00831 L
.91493 .00869 L
.91617 .00855 L
.91732 .0079 L
.91854 .00685 L
.9196 .0059 L
.92075 .00511 L
.92144 .00486 L
.92208 .00481 L
.92333 .00521 L
.92447 .00599 L
.92567 .00694 L
.92673 .00758 L
.92787 .00779 L
.92894 .00745 L
.92991 .00673 L
.93107 .00558 L
Mistroke
.93232 .00436 L
.93349 .00364 L
.93457 .00353 L
.93569 .00401 L
.93686 .00497 L
.93816 .00614 L
.93938 .00687 L
.94055 .00693 L
.94181 .00621 L
.94253 .00553 L
.94321 .00479 L
.94448 .00343 L
.94559 .00263 L
.94677 .00244 L
.94777 .00285 L
.94888 .00376 L
.95006 .00494 L
.95134 .00592 L
.95255 .00621 L
.95365 .00579 L
.95493 .00465 L
.95629 .00313 L
.95757 .00199 L
.95874 .00159 L
.95946 .00171 L
.96011 .00205 L
.96084 .00262 L
.9616 .00336 L
.9629 .00463 L
.96363 .00516 L
.96429 .00545 L
.96557 .00534 L
.96679 .0045 L
.9679 .00334 L
.96911 .00205 L
.96975 .00152 L
.97045 .00113 L
.97118 .00098 L
.97186 .00111 L
.97309 .00186 L
.9744 .00313 L
.97619 .0046 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`0Rooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00GoA4A4o`000?l0003o<S8bomgMg@1Gooooo`05odA4A?l0003o0000oc8b<_oMgMd09oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo02Gooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool09?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00omgMgOo<S8booooo`1Iooooo`03ogMgMolb<S;ooooo02Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Uooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool6o`0000Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[
ooooo`03ogMgMolb<S;ooooo05Wooooo00?oMgMgoc8b<_ooool0:?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo02Gooooo000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0Eoooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001Wooooo
00?oEEEEofIVI_l000001Oooool4o`0002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo1?l0001Hooooo`Co0000:?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool00omEEEGoIVIVo`000005ooooo`Co00009oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooC_ooool2o`0000;ooooo0_l0000Eooooo`00oooooom>
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5Oooool00?ooooooCoooool01?oMgMgo0000oa0@
4?o<c<`Fooooo`005?ooooooo`00033o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hFooooo`006ooo
ool6o`000003ooooool0003o000000ko000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l0
0004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Kooooo0ol00007ooooo`03o`000?oooooooooo00;ooooo0ol0
0002ooooo`03o`000?oooooooooo00Kooooo6?l00005ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`;o000000Goooooo`000?l0003o0000
ooooo`03o`000004ooooool0003o0000o`0001;ooooo00Co8B4QogMgMomgMgOo<S8b5_ooool001_o
oooo0_l0000:ooooo`03o`000?oooooooooo00;o00000_ooool2o`000005ooooool0003o0000o`00
0?ooool00ol000000ooooooo0000o`000006o`0000[ooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0Iooooo`?o00001oooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
oooo00;o00009_ooool8o`0002gooooo00?o0000ooooooooool06?ooool3o`000003ooooool0003o
000000;o000000Goooooo`000?l0003o0000ooooo`03o`000003ooooool0003o000000;ooooo00?o
0000ooooooooool03oooool2o`0000;ooooo0_l0000Eooooo`00?Oooool00ol0003oooooooooo`05
o`0004kooooo1Ol000000ooooooo0000ooooo`06ooooo`05o`000?ooooooooooooooool000001Ooo
ool3o`00033ooooo3Ol0000dooooo`So000000?oooooo`000?l000000_ooool00ol0003ooooooooo
o`0iooooo`00A?ooool00ol0003oooooo`00001;ooooo`;o00001_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0m
ooooo`Ko00008oooool00ol0003oooooooooo`08o`0000;ooooo00?o0000ooooooooool0A?ooool0
04Gooooo0ol0000kooooo`Go00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02o`0004Gooooo1Ol0000Foooo
o`co0000D?ooool004Sooooo00Co0000ooooool0003o0000=_ooool2o`0000?ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000002?ooool4
o`0004[ooooo5ol000000ooooooo0000o`00001Hooooo`00BOooool00ol0003oooooo`00000eoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09oooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0^_ooool004cooooo1?l0000`oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09oooo
o`?o00003?ooool00ol0003oooooooooo`2jooooo`00Coooool5o`0002cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`2jooooo`00Doooool4o`0002Sooooo00?o0000ooooooooool0
2Oooool01?l0003oooooooooool0000Looooo`;o0000^oooool005Oooooo0ol0000Uooooo`03o`00
0?oooooooooo00Wooooo0ol0000Mooooo`03o`000?oooooooooo0;[ooooo001Iooooo`;o00008ooo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0;[ooooo001Kooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`2jooooo`00G?ooool00ol0
003oooooooooo`0Dooooo`Go00001?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
0;[ooooo001Mooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool5o`0002ko
oooo00?o0000ooooooooool0^_ooool005kooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo0;[ooooo001Nooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`2jooooo`00Goooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0^_ooool005oooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0iooooo`;o0000^oooool005oooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo0;[ooooo001Pooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`2jooooo`00H?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0^_oo
ool0067ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo001Rooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`00Hoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool0^_ooool006?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo0;[ooooo001Tooooo`;o00001Oooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo0;[ooooo001Uooooo`03o`000?oooooooooo00;ooooo0_l0000o
ooooo`;o0000^oooool006Kooooo1Ol00010ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006oooo
o`03o`000?oooooooooo0;[ooooo002@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0;[ooooo002@oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooo
oooo0;[ooooo002@ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000^_ooool0093ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKo
oooo00Gooooo00?o0000ooooooooool0^_ooool0093ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooooooo
o`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2jooooo`00
T?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo0;[o
oooo002@ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007oooo
o`?o0000^_ooool0093ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0000Oooooo00?o0000ooooooooool0^_ooool0093ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0^_ooool0
093ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool0
1Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0^_ooool0093ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`00
0?ooooooooooooooool000001_ooool3o`000;[ooooo002@ooooo`05o`000?ooooooooooooooool0
00002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0^_ooool0093o
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool0
0ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEE
ohN7Qoooool02?ooool00ol0003oooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000
^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003o
ooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo0;[ooooo002@ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonH
V9So<S8b00Kooooo0ol0002jooooo`00T?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go
c<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000oooooooo
ool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj
^_l000001_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002Qoooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2jooooo`00Xoooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0;[ooooo002Sooooo`03o`000?oooooooooo00Gooooo
0ol0002jooooo`00Xoooool00ol0003oooooooooo`32ooooo`00Xoooool00ol0003oooooooooo`32
ooooo`00Xoooool00ol0003oooooooooo`32ooooo`00Xoooool00ol0003oooooooooo`32ooooo`00
XOooool00omEEEGoIVIVo`000034ooooo`00oooooomYooooo`00JOooool00omgMgOoIVIVooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o^[Zjoc8b<_ooool01oooool2o`0000_ooooo00?o0000
okZj^_ooool03?ooool2o`0000Oooooo00?o0000ooooooooool00_ooool00omVIVKoMgMgooooo`0<
ooooo`03o`000?nj^[[ooooo0:gooooo001Xooooo`03omgMgOl@413ok^k^00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00oo^k^ko410@omgMg@0<oooo
o`;o<S8b[_ooool006Sooooo00?oEEEEoiRHV?ooool01Oooool01_l0003oooooooooooooooooV9RH
oa0@40;o000000?oZJVYooooooooool01?ooool01?l0003oooooooooooooool2o`0000;ooooo0_l0
0003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool00on7QhOoIVIVooooo`0;ooooo`03ohN7
Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0@ooooo`Go00001Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`1eooooo`00J?ooool00ol0003oooooooooo`05ooooo`0:o`00
0?ooooooooooooooool0003oZJVYoeEEEOnHV9SoEEEEokZj^PGooooo00[o0000oooooooooooooooo
onk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
k^k^o`000?ooool02oooool00oo<c<co0000oa0@400<ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413o
oooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool0M_ooool006Sooooo00?o<S8booooooooool01Oooool02_l0003ooooooooooooooooo<S8b
onk^k_nHV9SoEEEEomgMgOl@4105ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413o
c<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01?ooooo00?oV9RHob4Q8Oo^
k^h03?ooool5o`0007Oooooo001Xooooo`03oc8b<_oooooooooo00Gooooo00_o0000oooooooooooo
oooookZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c004ooooo`03o`000?oooooooooo00;ooooo00Co
k^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo
1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoA4A4omgMgOoooooo0000N?ooool006Sooooo
00?o0000onk^k_ooool01Oooool02ol0003oooooooooooooooook^k^o`000?oooooo0000oooooomV
IVKoQhN700Cooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03onk^
k_l0003ooooo01[ooooo00?o0000ooooooooool05Oooool00omgMgOoIVIVooooo`0:ooooo`04omgM
gOmEEEGoooooo`0007Sooooo001Xooooo`03oeEEEOmgMgOooooo00Gooooo00So0000oooooooooooo
ooooofIVI_nHV9Sooooooc8b<P;o^[Zj00?o0000ooooooooool00_ooool01?l0003ooooooooooooo
ool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?oMgMgoeEEEOooool00_ooool4o`0001;ooooo00?o
410@o`000?l000000ol0000Eooooo`03o`000?oooooooooo00[ooooo00?oMgMgolc<c?l00000N?oo
ool006Sooooo00?ogMgMoa0@4?o^k^h01Oooool00ol0003oooooooooo`04ooooo`03ofIVI_n7QhOo
oooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool00oo^k^ko410@omgMg@04ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool04_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o
k^k^odA4A?l00000N?ooool006Wooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`04
ooooo`03ojVYZOm4A4Cooooo00Gooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l00007
ooooo`03o`000?oooooooooo00;ooooo00?oIVIVogMgMoooool01Oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00=ooooo`03ogMgMol0
003ooooo07Oooooo002booooo`03o`000?oooooooooo0;?ooooo002_ooooo`04o`000?oooooooooo
o`000;Gooooo002`ooooo`;o0000]_ooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.8522, -0.080387, \
0.130126, 0.00668404}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "The plots of the wave packet in Cell ",
  ButtonBox["6.51",
    ButtonData:>"Cell 6.51",
    ButtonStyle->"Hyperlink"],
  " display several interesting effects. First, we can clearly see that \
dispersion causes the packet to spread, just as in the discussion of freely \
propagating packets in Sec. ",
  ButtonBox["5.1.2",
    ButtonData:>{"Chapter5.nb", "c:7"},
    ButtonStyle->"Hyperlink"],
  ".  Second, during the reflection, there is a complex interference pattern \
produced as the reflected packet travels back through the incident packet.  \
Third, a fair fraction of the wave packet is transmitted through the barrier, \
which runs from ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)]],
  " to 1. A classical particle with energy 12.5 would have been reflected \
from this barrier, which has potential 15. This is the well-known phenomenon \
of ",
  StyleBox["quantum tunneling",
    FontSlant->"Italic"],
  " through a classically forbidden region. "
}], "Text",
  CellTags->"i:16"],

Cell[TextData[{
  "\tOne can also see something else in this simulation: with a speed of 5 in \
our scaled units, the center of a freely propagating wave packet would have \
made it to position ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(\(-5\) + 5  \[Tau] = 7\)\)]],
  " in time ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau] = 2.4\)]],
  ". However, the center of the packet in our simulation has actually made it \
",
  StyleBox["farther",
    FontSlant->"Italic"],
  " than this: the animation clearly shows that the center of the packet is \
roughly at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 9\)]],
  "  at time ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau] = 2.4\)]],
  ". Adding a potential barrier that creates a classically forbidden region \
has actually ",
  StyleBox["increased",
    FontSlant->"Italic"],
  " the average group velocity of the transmitted part of the packet.  Note \
that the width of the potential barrier was ",
  Cell[BoxData[
      \(TraditionalForm\`2\)]],
  ", which is just the observed increase in position compared to free \
propagation.  It is as if the wave packet were ",
  "instantaneously transported ",
  "across the forbidden zone. "
}], "Text"],

Cell[TextData[{
  "\tThis phenomenon is referred to in the literature  as ",
  StyleBox["superluminal pulse propagation. ",
    FontSlant->"Italic"],
  "Actually, this  is something of a misnomer. A detailed analysis of the \
pulse propagation shows that it does not violate the tenets of special \
relativity, because the ",
  "wave packet",
  " has components that rapidly disperse (the leading edge of the packet is \
far in advance of the pulse center.).  These forward components already \
signal the arrival of the packet, and they are causal, always travelling at \
speeds less than or equal to that of light. "
}], "Text",
  CellTags->"i:15"],

Cell[TextData[{
  "\tSuperluminal propagation can also occur in classical systems, such as \
light travelling in a dispersive medium.  Although this phenomenon is \
well-known, it has recently received renewed attention [see, for example,  ",
  ButtonBox["Winful (2003)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "]."
}], "Text"],

Cell["\<\
\t The reader is invited to vary the parameters in this simulation \
in order to further study these phenomena. Questions that one might ask are: \
how does the mean group velocity of the transmitted packet vary with barrier \
height and width, and as a function of the initial packet speed and width? \
What fraction of the packet is transmitted as a function of these parameters? \
How is the dispersion of the packet affected by the barrier? (Caution: The \
simulation runs rather slowly on older machines, due to the large number of \
modes that must be kept.)\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 6.1", "Subsubtitle",
  CellTags->"c:12"],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  "  Use the Galerkin method to solve for the potential in the grounded \
charge-filled enclosure of Fig. ",
  ButtonBox["6.4",
    ButtonData:>"Fig. 6.4",
    ButtonStyle->"Hyperlink"],
  ". The potential satisfies ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\( \[Phi](x, y)\) = \ \(-x\)\)]],
  ", and is zero on the walls. Plot the resulting potential as a contour \
plot, and find the place where the potential is minimum. "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0000UB000`400?l00000o`00003oooooool]
ooooo`00ooooool]ooooo`00ooooool]ooooo`00ooooool]ooooo`002?oooooo0?oooa`0oooo2Ooo
ool000Soooooo`3ooolL0?ooo`Wooooo0008ooooool0oooo703oool9ooooo`002?oooooo0?oooa`0
oooo2Oooool000Sooooo203oool00`30`<00P8200<30`00F0?ooo`030<30`03oool0oooo01L0oooo
00<0`<300820P030`<00g@3oool9ooooo`002?ooool70?ooo`030820P0000000@41001L0oooo00<0
00000<30`03oool0603oool00`10@40000000820P03L0?ooo`Wooooo0008ooooo`H0oooo00<0@410
00000010@400603oool00`30`<0000000<30`00I0?ooo`030410@0000000@4100=/0oooo2Oooool0
00Sooooo1@3oool01020P800000000000020P80I0?ooo`0300000020P800oooo01P0oooo00@0P820
000000000000P820B@3oool00`20P80000000820P00F0?ooo`030820P03oool0oooo01L0oooo00<0
P820000000000000F`3oool9ooooo`002?ooool50?ooo`030410@0000000P82001X0oooo00<0P820
0000003oool06@3oool00`20P80000000410@0180?ooo`030<30`0000000@41001L0oooo00<0P820
0410@03oool0603oool00`10@40000000410@01J0?ooo`Wooooo0008ooooo`@0oooo00<0P8200000
0010@4002`3oool00`30`<00P82000000002000000030410@020P800oooo00L0oooo00<0P8200410
@00000002@3oool00`20P800@41000000002000000030820P030`<00oooo00X0oooo00<0@4100000
0020P800AP3oool00`20P80000000410@00I0?ooo`80@4106@3oool00`20P80000000410@01I0?oo
o`Wooooo0008ooooo`@0oooo0P0000000`30`<00oooo0?ooo`070?ooo`030<30`020P800000000H0
000000<0@4100<30`03oool01@3oool3000000L0oooo00<0`<300410@00000001P0000000`20P800
`<300?ooo`080?ooo`030<30`0000000000004D0oooo00@0P820000000000000`<306@3oool00`30
`<0000000820P00I0?ooo`030410@0000000P82005P0oooo2Oooool000Sooooo0`3oool00`20P800
00000000000:0?ooo`040410@000000000000410@0<0oooo00@0`<30000000000000@4101P3oool3
000000L0oooo00@0@410000000000000`<300`3oool01010@400000000000010@40:0?ooo`800000
00<0P8200?ooo`3oool0@@3oool01030`<00000000000020P80K0?ooo`8000002P3oool01030`<00
P8200820P030`<0<0?ooo`80000000<0`<300?ooo`3oool0E@3oool9ooooo`002?ooool30?ooo`03
0820P0000000P82000T0oooo00@0P82000000000000000001@3oool01020P8000000000000000005
0?ooo`<000001P3oool3000000030820P03oool0oooo00<0oooo0`0000000`20P800oooo0?ooo`07
0?ooo`030820P0000000P82004<0oooo00<0P8200000000000003P3oool3000000T0oooo00@0P820
0000000000000000203oool00`20P800000000000004000000030820P03oool0oooo00P0oooo00<0
P82000000020P800E`3oool9ooooo`002?ooool30?ooo`80000000<0P8200?ooo`3oool01`3oool0
1010@400000000000030`<060?ooo`040410@000000000000<30`0`0oooo00@0`<30000000000000
@4101P3oool01030`<00000000000010@4090?ooo`030820P0000000000004<0oooo0P0000000`20
P800oooo0?ooo`0<0?ooo`<000002@3oool01020P80000000000000000070?ooo`030820P0000000
000000H0000000<0P8200?ooo`3oool01`3oool00`30`<0000000000001G0?ooo`Wooooo0008oooo
o`<0oooo0P0000000`20P800oooo0?ooo`060?ooo`040<30`00000000000000000L0oooo00@0P820
000000000000@410303oool01010@400000000000020P8070?ooo`<0000000<0`<300?ooo`3oool0
1P3oool00`20P8000000000000120?ooo`030820P0000000000000l0oooo0`0000090?ooo`040820
P00000000000000000H0oooo00D0`<3000000000000000000<30`0020?ooo`050<30`00000000000
00000030`<002@3oool3000005H0oooo2Oooool000Sooooo0P3oool3000000T0oooo00<0P8200000
000000002@3oool3000000`0oooo0`0000090?ooo`80000000<0P8200?ooo`3oool01`3oool30000
0440oooo00<0@41000000020P8003`3oool3000000T0oooo00@0`<300820P020P800P8201P3oool2
000000030410@03oool0oooo00@0oooo00<0@4100000000000002@3oool01020P800000000000030
`<1E0?ooo`Wooooo0008ooooo`80oooo0`0000090?ooo`030410@0000000@41000T0oooo00@0@410
000000000000`<302P3oool01030`<00000000000010@4090?ooo`030410@0000000@41000T0oooo
0`0000110?ooo`80000000<0P8200?ooo`3oool03@3oool300000180oooo00<0P820000000000000
203oool2000000030820P03oool0oooo00H0oooo00@0P820000000000000P820E@3oool9ooooo`00
2?ooool20?ooo`<000002@3oool2000000030820P03oool0oooo00L0oooo00@0P820000000000000
P8202P3oool01020P800000000000020P8090?ooo`030820P0000000000000T0oooo0`0000110?oo
o`80000000<0P8200?ooo`3oool03@3oool300000180oooo0`0000080?ooo`<00000203oool01020
P800000000000020P81E0?ooo`Wooooo0008ooooo`80oooo0`0000090?ooo`80000000<0P8200?oo
o`3oool01`3oool01020P800000000000020P80:0?ooo`040820P000000000000820P0T0oooo00<0
P8200000000000002@3oool300000400oooo00<0P820000000000000403oool300000180oooo0P00
00000`20P800oooo0?ooo`060?ooo`030820P0000000000000T0oooo0`00001E0?ooo`Wooooo0008
ooooo`80oooo0`0000090?ooo`80000000<0P8200?ooo`3oool01`3oool01020P800000000000020
P80:0?ooo`040820P000000000000820P0T0oooo00<0P8200000000000002@3oool300000400oooo
00<0P820000000000000403oool300000140oooo00@0P820000000000000`<30203oool01030`<00
000000000020P8080?ooo`<00000E@3oool9ooooo`002?ooool20?ooo`<000002@3oool200000003
0820P03oool0oooo00L0oooo00@0P820000000000000P8202P3oool01020P800000000000020P809
0?ooo`030820P0000000000000T0oooo0`0000100?ooo`030820P000000000000100oooo0`00000A
0?ooo`<000002P3oool3000000P0oooo0`00001E0?ooo`Wooooo0008ooooo`80oooo00@0P8200000
00000000`<30203oool2000000030820P03oool0oooo00L0oooo00@0P820000000000000P8202P3o
ool01020P800000000000020P8090?ooo`030820P0000000000000P0oooo00@0`<30000000000000
P820@03oool00`20P80000000000000@0?ooo`<000004@3oool3000000X0oooo0`0000080?ooo`<0
0000E@3oool9ooooo`002?ooool30?ooo`80000000<0P8200?ooo`3oool01P3oool2000000030820
P03oool0oooo00L0oooo00@0P820000000000000P8202P3oool01020P800000000000020P8090?oo
o`030820P0000000000000P0oooo00<0P820000000000000@@3oool00`20P80000000000000@0?oo
o`<000004@3oool3000000X0oooo0`0000080?ooo`<00000E@3oool9ooooo`002?ooool30?ooo`80
000000<0P8200?ooo`3oool01P3oool00`10@40000000410@0090?ooo`040410@000000000000<30
`0X0oooo00@0`<30000000000000@4102@3oool00`10@40000000410@0080?ooo`030820P0000000
00000440oooo00<0P820000000000000403oool300000140oooo0`00000:0?ooo`<00000203oool3
000005D0oooo2Oooool000Sooooo0`3oool00`20P80000000410@0080?ooo`030820P00000000000
00T0oooo0`00000<0?ooo`<000002@3oool2000000030820P03oool0oooo00H0oooo00<0@4100000
0020P800@@3oool01030`<00000000000030`<0?0?ooo`<000004@3oool3000000X0oooo0`000007
0?ooo`040<30`000000000000410@5D0oooo2Oooool000Sooooo0`3oool00`30`<00000000000008
0?ooo`040<30`00000000000000000L0oooo00@0P820000000000000@410303oool01010@4000000
00000020P8070?ooo`<0000000<0`<300?ooo`3oool01P3oool2000000030<30`03oool0oooo0400
oooo0P0000000`20P800oooo0?ooo`0=0?ooo`<000004@3oool3000000X0oooo0`0000070?ooo`04
0820P000000000000820P5D0oooo2Oooool000Sooooo103oool2000000030820P03oool0oooo00H0
oooo0`0000070?ooo`040820P000000000000820P0`0oooo00@0P820000000000000P8201`3oool3
000000P0oooo00<0P820000000000000@`3oool2000000030820P03oool0oooo00d0oooo0`00000B
0?ooo`80000000<0P8200?ooo`3oool01P3oool00`20P8000000000000080?ooo`040820P0000000
00000820P5D0oooo2Oooool000Sooooo103oool00`20P80000000410@0080?ooo`040820P0000000
00000410@0D0oooo00@0`<3000000000000000003P3oool3000000030<30`03oool0oooo00<0oooo
00@0@410000000000000P820203oool00`10@40000000820P0130?ooo`030820P0000000@41000l0
oooo0`00000B0?ooo`80000000<0P8200?ooo`3oool01P3oool00`20P8000000000000080?ooo`03
0410@0000000000005H0oooo2Oooool000Sooooo1@3oool00`10@40000000820P0080?ooo`040410
@000000000000410@0<0oooo00@0`<30000000000000@410403oool01010@400000000000030`<03
0?ooo`040410@000000000000410@0P0oooo00<0P82000000010@400A03oool00`30`<0000000000
000?0?ooo`<000004P3oool00`10@4000000000000080?ooo`80000000<0@4100?ooo`3oool01P3o
ool2000000030820P03oool0oooo05@0oooo2Oooool000Sooooo1@3oool01030`<00000000000020
P8070?ooo`030<30`020P800000000H0000000<0@4100<30`03oool03`3oool00`30`<00@4100000
0006000000030820P030`<00oooo00H0oooo00@0P820000000000000`<30A@3oool00`10@4000000
0000000:0?ooo`0400000020P800`<300?ooo`<000004P3oool01030`<00000000000030`<060?oo
o`040<30`000000000000<30`0L0oooo00<0P82000000010@400E`3oool9ooooo`002?ooool60?oo
o`040<30`000000000000<30`0P0oooo00<0`<300410@00000000`0000000`20P800oooo0?ooo`0B
0?ooo`030820P000000000000080000000<0@4100<30`03oool01`3oool01030`<00000000000030
`<160?ooo`040<30`000000000000820P0T0oooo1`00000C0?ooo`040410@000000000000820P0@0
oooo00@0P820000000000000@410203oool2000000030<30`03oool0oooo05D0oooo2Oooool000So
oooo203oool200000380oooo0P0000190?ooo`030820P0000000000000T0oooo1`00000D0?ooo`<0
000000@0P8200?ooo`3oool0P8200`0000080?ooo`030820P0000000P82005P0oooo2Oooool000So
oooo203oool00`30`<00P8200<30`00`0?ooo`030<30`020P800`<3004T0oooo00@0`<3000000000
0000P820203oool00`30`<00P82000000004000001@0oooo00<0P8200000000000001P0000000`20
P800oooo0?ooo`060?ooo`80000000<0`<300?ooo`3oool0EP3oool9ooooo`002?oooon90?ooo`03
0410@0000000`<3000X0oooo00@0`<300820P020P800P8205@3oool00`30`<00P820000000030000
00030820P030`<00oooo00H0oooo00@0`<30000000000000`<30F@3oool9ooooo`002?oooon:0?oo
o`030410@0000000`<300300oooo00@0`<30000000000000`<30FP3oool9ooooo`002?oooooo0?oo
oa`0oooo2Oooool000Soooooo`3ooolL0?ooo`Wooooo0008ooooool0oooo703oool9ooooo`002?oo
oooo0?oooa`0oooo2Oooool000Soooooo`3ooolL0?ooo`Wooooo0008oooooaP0ooooR@00001j0?oo
o`Wooooo0008oooooaP0ooooRP0000000`20P800oooo0?ooo`1f0?ooo`Wooooo0008oooooaL0oooo
00@0`<30000000000000@410Q020P803000000030<30`03oool0oooo07H0oooo2Oooool000Sooooo
5`3oool00`10@400000000000002000000030<30`03oool0oooo07l0oooo00@0`<30000000000000
P820N@3oool9ooooo`002?oooolH0?ooo`030<30`000000000000080000000<0P8200?ooo`3oool0
OP3oool00`20P80000000410@01j0?ooo`Wooooo0008oooooaX0oooo00H0@4100000000000000000
0410@030`<1n0?ooo`80000000<0P8200?ooo`3oool0N03oool9ooooo`002?oooolL0?ooo`@00000
O@3oool00`20P80000000000001k0?ooo`Wooooo0008oooooa`0oooo00<0`<300000000000000P00
00000`10@400oooo0?ooo`1i0?ooo`030820P0000000@41007/0oooo2Oooool000Sooooo7P3oool0
1P10@4000000000000000000@4100<30`7T0oooo0P0000000`20P800oooo0?ooo`1i0?ooo`Wooooo
0008oooooal0oooo00<0`<300000000000000P0000000`20P800oooo0?ooo`1e0?ooo`<00000O03o
ool9ooooo`002?oooolQ0?ooo`030<30`000000000000080000000<0`<300?ooo`3oool0LP3oool0
1020P800000000000020P81l0?ooo`Wooooo0008ooooob80oooo00<0P8200000000000000P000000
0`20P800oooo0?ooo`1a0?ooo`030820P0000000000007d0oooo2Oooool000Sooooo8`3oool00`30
`<00000000000002000000030820P03oool0oooo0700oooo0`00001m0?ooo`Wooooo0008ooooobD0
oooo00D0P82000000000000000000410@01`0?ooo`040820P000000000000820P7d0oooo2Oooool0
00Sooooo9`3oool01@10@4000000000000000000@41006h0oooo0`00001n0?ooo`Wooooo0008oooo
obP0oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`1Y0?ooo`030<30`00000000000
07l0oooo2Oooool000Sooooo:@3oool00`20P800000000000002000006/0oooo00<0P82000000000
0000O`3oool9ooooo`002?ooool[0?ooo`050410@0000000000000000020P800J@3oool200000003
0820P03oool0oooo07d0oooo2Oooool000Sooooo;03oool00`30`<00000000000002000000030<30
`03oool0oooo06@0oooo00<0`<30000000000000P03oool9ooooo`002?ooool]0?ooo`030<30`010
@40000000080000000<0@4100?ooo`3oool0H`3oool00`10@40000000410@0200?ooo`Wooooo0008
ooooobl0oooo00H0P8200410@000000000000410@020P81R0?ooo`040820P000000000000<30`800
oooo2Oooool000Sooooo<@3oool4000000030820P03oool0oooo05l0oooo0`0000210?ooo`Wooooo
0008oooooc80oooo00D0@41000000000000000000410@01O0?ooo`040<30`000000000000820P840
oooo2Oooool000Sooooo<`3oool01P20P8000000000000000000@4100<30`5d0oooo00@0@4100000
00000000`<30P@3oool9ooooo`002?oooole0?ooo`060820P0000000000000000020P800`<30F`3o
ool2000000030410@03oool0oooo0800oooo2Oooool000Sooooo=P3oool00`30`<00@41000000002
000000030<30`03oool0oooo05L0oooo00@0P820000000000000P820PP3oool9ooooo`002?oooolh
0?ooo`@0000000<0P8200?ooo`3oool0EP3oool3000008<0oooo2Oooool000Sooooo>03oool00`30
`<00P82000000002000000030820P03oool0oooo05@0oooo00@0`<30000000000000P820P`3oool9
ooooo`002?oooolj0?ooo`030<30`010@40000000080000000<0P8200?ooo`3oool0DP3oool00`20
P80000000410@0240?ooo`Wooooo0008oooooc`0oooo00D0P82000000000000000000410@01C0?oo
o`80000000<0P8200?ooo`3oool0PP3oool9ooooo`002?oooolm0?ooo`030820P000000000000080
0000D@3oool00`20P8000000000000250?ooo`Wooooo0008oooooch0oooo00H0P8200410@0000000
00000410@020P81?0?ooo`030410@0000000@41008D0oooo2Oooool000Sooooo@03oool01@20P800
0000000000000000@41004h0oooo0P0000000`30`<00oooo0?ooo`230?ooo`Wooooo0008oooood40
oooo00<0`<300410@00000000P0000000`30`<00oooo0?ooo`190?ooo`<00000QP3oool9ooooo`00
2?oooom30?ooo`030820P000000000000080000000<0`<300?ooo`3oool0AP3oool01020P8000000
00000020P8260?ooo`Wooooo0008ooooodD0oooo100000180?ooo`030820P0000000000008L0oooo
2Oooool000SoooooA@3oool00`30`<00@41000000002000000030<30`03oool0oooo04@0oooo0`00
00270?ooo`Wooooo0008ooooodL0oooo00D0P8200410@000000000000410@0140?ooo`040820P000
000000000820P8L0oooo2Oooool000SoooooB@3oool01@10@4000000000000000000@4100480oooo
0`0000280?ooo`Wooooo0008ooooodX0oooo00H0`<3000000000000000000410@030`<0o0?ooo`03
0<30`0000000000008T0oooo2Oooool000SoooooC03oool4000003l0oooo00<0P820000000000000
R@3oool9ooooo`002?oooom=0?ooo`050820P0000000000000000020P800?@3oool2000000030820
P03oool0oooo08L0oooo2Oooool000SoooooCP3oool01P30`<000000000000000000@4100<30`3X0
oooo00<0P820000000000000RP3oool9ooooo`002?oooom@0?ooo`050410@0000000000000000020
P800>@3oool00`10@40000000820P02:0?ooo`Wooooo0008oooooe80oooo00@0@410000000000000
@410=`3oool01020P800000000000030`<2:0?ooo`Wooooo0008oooooe<0oooo00D0P82000000000
000000000820P00e0?ooo`<00000R`3oool9ooooo`002?oooomD0?ooo`050410@000000000000000
0020P800<`3oool01030`<00000000000020P82;0?ooo`Wooooo0008oooooeD0oooo00D0`<300000
0000000000000410@00b0?ooo`040410@000000000000<30`8/0oooo2Oooool000SoooooE`3oool0
1@30`<000000000000000000P82002l0oooo00@0`<30000000000000@410S03oool9ooooo`002?oo
oomI0?ooo`050410@0000000000000000030`<00;@3oool01020P800000000000030`<2<0?ooo`Wo
oooo0008oooooeX0oooo100000000`20P800oooo0?ooo`0Z0?ooo`<00000S@3oool9ooooo`002?oo
oomK0?ooo`050820P0000000000000000030`<00:P3oool01030`<00000000000020P82=0?ooo`Wo
oooo0008oooooed0oooo00D0@41000000000000000000<30`00X0?ooo`030410@0000000@41008h0
oooo2Oooool000SoooooGP3oool01@30`<000000000000000000@41002L0oooo0P0000000`30`<00
oooo0?ooo`2<0?ooo`Wooooo0008oooooel0oooo00H0`<300820P000000000000410@030`<0T0?oo
o`030820P0000000000008l0oooo2Oooool000SoooooH@3oool01020P800000000000000000T0?oo
o`80000000<0P8200?ooo`3oool0S@3oool9ooooo`002?oooomR0?ooo`050<30`000000000000000
0010@4008P3oool2000000030<30`03oool0oooo08d0oooo2Oooool000SoooooI03oool01@10@400
000000000010@400`<3001l0oooo0`00002@0?ooo`Wooooo0008ooooofD0oooo00D0P8200410@000
000000000820P00M0?ooo`040820P000000000000820P900oooo2Oooool000SoooooI`3oool01@20
P8000000000000000000P82001/0oooo0`00002A0?ooo`Wooooo0008ooooofP0oooo00D0P8200000
0000000000000820P00J0?ooo`80000000<0P8200?ooo`3oool0S`3oool9ooooo`002?oooomY0?oo
o`050<30`0000000000000000020P800603oool01020P800000000000020P82A0?ooo`Wooooo0008
ooooof/0oooo00D0P820000000000000@4100820P00F0?ooo`<00000TP3oool9ooooo`002?oooom/
0?ooo`050<30`010@400000000000010@400503oool00`30`<0000000000002C0?ooo`Wooooo0008
ooooofh0oooo00D0P82000000000000000000<30`00B0?ooo`030410@0000000@41009<0oooo2Ooo
ool000SoooooL03oool3000000030820P03oool0oooo00l0oooo0P0000000`20P800oooo0?ooo`2A
0?ooo`Wooooo0008ooooog00oooo00D0`<300410@000000000000820P00?0?ooo`030820P0000000
000009@0oooo2Oooool000SoooooLP3oool01@20P8000000000000000000`<3000d0oooo00<0@410
00000020P800U03oool9ooooo`002?oooomc0?ooo`050<30`020P800000000000010@4002`3oool0
1020P800000000000030`<2D0?ooo`Wooooo0008ooooogD0oooo00D0`<30000000000000@4100820
P0080?ooo`040<30`000000000000410@0P0oooo00<0@41000000030`<00=`3oool20820P4<0oooo
00@0`<30000000000000`<302P3oool9ooooo`002?oooomg0?ooo`<0000000<0P8200?ooo`3oool0
1@3oool01020P800000000000020P8070?ooo`80000000<0P8200?ooo`3oool0=P3oool00`20P800
00000820P0140?ooo`8000002P3oool9ooooo`002?oooomg0?ooo`050<30`010@400000000000010
@4001P3oool00`10@4000000000000070?ooo`030410@0000000@41003X0oooo00<0P82000000030
`<00@`3oool00`30`<0000000410@0090?ooo`Wooooo0008ooooogT0oooo00D0P8200410@0000000
00000<30`0030?ooo`040<30`000000000000410@0H0oooo00@0P820000000000000`<30>`3oool2
0410@4@0oooo00<0@41000000020P800203oool9ooooo`002?oooomk0?ooo`070410@00000000000
0820P030`<00oooo0820P002000000030<30`03oool0oooo00<0oooo00<0`<300000000000002`3o
ool50820P0P0oooo0`20P80R0?ooo`030820P0000000oooo01h0oooo0`20P80S0?ooo`80000000<0
P8200?ooo`3oool01@3oool9ooooo`002?ooooml0?ooo`050<30`0000000000000000020P8000`00
00060?ooo`030410@0000000P82000T0oooo00<0@4100000000000001@0000000`10@400oooo0?oo
o`040?ooo`040820P000000000000<30`1D0oooo0`0000070?ooo`040820P00000000000000001@0
oooo0`0000090?ooo`80000000<0`<300?ooo`3oool02`3oool=000000P0oooo00@0P82000000000
0000`<301P3oool9ooooo`002?oooomn0?ooo`D000001`3oool2000000T0oooo00<0P82000000000
0000200000060?ooo`80000000<0P8200?ooo`3oool04`3oool3000000L0oooo00@0P82000000000
00000000503oool3000000T0oooo00<0P82000000020P8003@3oool=000000T0oooo0P0000000`20
P800oooo0?ooo`040?ooo`Wooooo0008ooooogl0oooo00@0P820000000000000@4101P3oool00`20
P8000000000000080?ooo`050<30`0000000000000000020P800103oool01010@400000000000030
`<050?ooo`030820P0000000@41001D0oooo0`0000070?ooo`040820P00000000000000001@0oooo
0`0000090?ooo`030<30`0000000@41000d0oooo0P0000000`10@400P8200820P0080820P0T0oooo
0`0000060?ooo`Wooooo0008oooooh00oooo00<0P82000000030`<001P3oool00`10@40000000820
P0080?ooo`030820P0000000000000L0oooo00<0@4100000000000001P3oool00`10@40000000<30
`00D0?ooo`<000001`3oool01030`<00P8200820P020P80D0?ooo`<000002P3oool00`10@4000000
0<30`00<0?ooo`80000000<0P8200?ooo`3oool04@3oool01020P800000000000030`<050?ooo`Wo
oooo0008ooooohT0oooo0P0000000`20P800oooo0?ooo`0@0?ooo`040<30`000000000000820P0D0
oooo00<0`<3000000010@400503oool3000001l0oooo0`00000:0?ooo`030<30`0000000@41000`0
oooo00<0P82000000010@4004`3oool01020P800000000000020P8050?ooo`Wooooo0008ooooohT0
oooo0P0000000`20P800oooo0?ooo`0A0?ooo`<000001P3oool2000001@0oooo0`00000O0?ooo`<0
00002`3oool2000000`0oooo00<0P8200000000000004`3oool01020P800000000000020P8050?oo
o`Wooooo0008ooooohP0oooo0`00000D0?ooo`<000001P3oool00`20P80000000820P00:0?ooo`T0
P8200`0000030820P1`0oooo0`00000;0?ooo`030820P0000000000000`0oooo0`0000000`30`<00
oooo0?ooo`0@0?ooo`<000001@3oool9ooooo`002?oooon80?ooo`<00000503oool3000000H0oooo
00<0`<300000000000002P3oool?000001`0oooo0`00000;0?ooo`040<30`000000000000820P0/0
oooo00D0`<3000000000000000000<30`00A0?ooo`<000001@3oool9ooooo`002?oooon80?ooo`<0
00004`3oool00`10@4000000000000080?ooo`030410@0000000000000T0oooo0`0000060820P0<0
00000`20P80L0?ooo`<00000303oool00`10@40000000000000<0?ooo`050<30`000000000000000
0030`<00403oool3000000D0oooo2Oooool000SoooooR03oool300000180oooo00@0@41000000000
0000@410203oool01030`<00000000000020P8090?ooo`030410@0000000P82000D0oooo0`00000O
0?ooo`<00000303oool01030`<00000000000020P80=0?ooo`040410@000000000000820P0l0oooo
0`0000050?ooo`Wooooo0008ooooohP0oooo0`00000@0?ooo`030820P00000000000008000002P3o
ool3000000T0oooo00<0P8200000000000001@3oool3000001l0oooo0`00000=0?ooo`<000003P3o
ool4000000h0oooo0`0000050?ooo`Wooooo0008ooooohP0oooo0`00000=0?ooo`H0000000<0@410
0<30`03oool02@3oool01020P800000000000030`<090?ooo`030410@0000000P82000@0oooo0`00
000O0?ooo`<000003P3oool2000000030<30`03oool0oooo00/0oooo00D0`<300410@00000000000
0410@00=0?ooo`<000001@3oool9ooooo`002?oooon80?ooo`040820P000000000000<30`0`0oooo
1@0000000`20P800`<300?ooo`0;0?ooo`80000000<0@4100?ooo`3oool0203oool2000000040820
P03oool0oooo0?ooo`<000007`3oool3000000h0oooo00<0P82000000010@4003`3oool01010@400
000000000010@40;0?ooo`040<30`000000000000410@0D0oooo2Oooool000SoooooR@3oool20000
00030820P03oool0oooo00d0oooo00D0`<300820P000000000000<30`00<0?ooo`80000000<0`<30
0?ooo`3oool01`3oool01030`<00000000000020P8020?ooo`<000007`3oool3000000l0oooo0P00
00000`30`<00oooo0?ooo`0=0?ooo`040820P000000000000410@0X0oooo00@0P820000000000000
P8201@3oool9ooooo`002?oooon90?ooo`030410@0000000P8200140oooo00@0`<30000000000000
`<302`3oool00`20P80000000410@00:0?ooo`050410@000000000000<30`03oool00`00000O0?oo
o`<000003`3oool00`20P80000000410@00@0?ooo`030820P0000000000000X0oooo00@0P8200000
00000000`<301@3oool9ooooo`002?oooon90?ooo`030820P000000000000180oooo0P0000000`20
P800oooo0?ooo`0:0?ooo`8000002`3oool2000000030820P03oool00000008000007`3oool30000
0100oooo0P00000A0?ooo`80000000<0P8200?ooo`3oool01`3oool3000000H0oooo2Oooool000So
ooooR@3oool00`30`<0000000000000B0?ooo`030820P0000000000000`0oooo00<0@41000000030
`<002P3oool01020P800000000000030`<03000001l0oooo0`00000@0?ooo`030410@0000000P820
0100oooo0P0000000`20P800oooo0?ooo`070?ooo`80000000<0@4100?ooo`3oool0103oool9oooo
o`002?oooon:0?ooo`030410@0000000P82000L0oooo00<0`<300820P020P8001`3oool00`20P800
00000000000<0?ooo`030<30`0000000@41000/0oooo00<0P82000000010@4000`00000J0?ooo`05
0820P0000000P8200<30`03oool00`00000@0?ooo`040<30`000000000000<30`0D0oooo0P20P800
0`30`<00oooo0?ooo`050?ooo`80000000<0P8200?ooo`3oool01P3oool01020P800000000000030
`<060?ooo`Wooooo0008ooooohX0oooo00<0`<300000000000001`3oool01020P800000000000020
P8050?ooo`040<30`000000000000410@0d0oooo00<0@41000000020P8002`3oool00`10@4000000
00000002000001X0oooo00<0P8200000000000001@00000A0?ooo`030410@0000000@41000D0oooo
0P0000000`10@400oooo0?ooo`040?ooo`040410@000000000000<30`0P0oooo0P0000000`20P800
oooo0?ooo`050?ooo`Wooooo0008oooooh/0oooo00@0P820000000000000`<301P3oool01010@400
00000000000000030820P0@0000000<0`<300?ooo`3oool02`3oool01030`<00000000000030`<0;
0?ooo`@000006P3oool00`30`<0000000000000500000140oooo00@0`<30000000000000`<30103o
ool01@30`<000000000000000000@4100080P82000D0@41000000000000000000410@0080?ooo`03
0410@0000000P82000P0oooo2Oooool000SoooooS03oool2000000030820P03oool0oooo00D0oooo
2@0000000`20P800oooo0?ooo`0=0?ooo`80000000<0P8200?ooo`3oool02@3oool01020P8000000
00000000000M0?ooo`D000004P3oool2000000030820P03oool0oooo00<0oooo00<0P82000000000
00001`0000090?ooo`8000002@3oool9ooooo`002?oooon<0?ooo`040<30`000000000000<30`0H0
oooo00<0`<300820P010@400100000000`10@400P8200?ooo`0?0?ooo`030410@0000000000000`0
oooo0`20P80N0?ooo`040<30`020P800P8200820P180oooo00<0P8200000000000001P3oool20820
P0D0000000<0P8200<30`03oool01`3oool00`10@40000000<30`0090?ooo`Wooooo0008ooooohh0
oooo00<0@41000000030`<007P3oool01030`<00P8200820P030`<130?ooo`80P82000<0`<300?oo
o`3oool04P3oool01030`<00000000000030`<0:0?ooo`Wooooo0008ooooool0oooo703oool9oooo
o`002?oooooo0?oooa`0oooo2Oooool000Soooooo`3ooolL0?ooo`Wooooo0008ooooool0oooo703o
ool9ooooo`002?oooooo0?oooa`0oooo2Oooool00?oooooo;Oooool00?oooooo;Oooool00?oooooo
;Oooool00001\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{100.062, 49.9375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 6.4 Exercise (1).", "Caption",
  CellTags->"Fig. 6.4"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  " A grounded toroidal conducting shell has a shape given by the equation ",
  Cell[BoxData[
      \(TraditionalForm\`z\^2/2\  + \ \((r - R)\)\^2 = a\^2\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\((r, \[Theta], z)\)\)]],
  " are cylindrical coordinates, and ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(R = 1\ meter\), " ", ",", " ", Cell["a=0.75 meter"]}], 
        TraditionalForm]]],
  ". Plot this shell using a ",
  StyleBox["ParametricPlot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command. The shell is filled with a uniform charge density ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Rho]/\[Epsilon]\_o\), "=", 
          RowBox[{"10", " ", 
            StyleBox["V",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ". Find and plot the contours of constant electrostatic potential in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((r, z)\)\)]],
  "plane. At what ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " is the potential maximum, and what is its value, to three significant \
figures?  (Hint: Solve Poisson's equation in cylindrical coordinates.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " A hemispherical shell of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " sits in the base of a cylindrical tube of the same radius (see Fig. ",
  ButtonBox["6.5",
    ButtonData:>"Fig. 6.5",
    ButtonStyle->"Hyperlink"],
  "). The top of the tube at ",
  Cell[BoxData[
      \(TraditionalForm\`z = L\)]],
  " is flat, and the sides of the tube  are insulated. The interior of the \
tube is filled with material of some uniform thermal diffusivity. The \
hemisphere is held at fixed temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\_o\)]],
  ", and the top end of the tube is held at fixed temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\_1\)]],
  ". Use the Galerkin method to find the form of ",
  Cell[BoxData[
      \(TraditionalForm\`T(r, z)\)]],
  " in equilibrium within the tube, for ",
  Cell[BoxData[
      \(TraditionalForm\`a = 1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`L = 1.5\)]],
  ". (Hint: Try basis functions of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_\(n\ m\)\)(r, 
          z) = \((r\^\(\(n\)\(\ \)\)\  - A(z)\ )\)\ \((a\^2\  - \ r\^2\  - \ 
              z\^2)\) \((L - z)\)\ z\^m\)]],
  ", and find the form of ",
  Cell[BoxData[
      \(TraditionalForm\`A(z)\)]],
  " required to match the von Neumann  boundary conditions at ",
  Cell[BoxData[
      \(TraditionalForm\`r = a\)]],
  ".)"
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006W0001RB000`400?l00000o`00003ooooooonX
ooooo`00oooooonXooooo`00oooooonXooooo`00oooooonXooooo`00oooooonXooooo`00oooooonX
ooooo`00oooooonXooooo`00oooooonXooooo`00oooooonXooooo`00oooooonXooooo`00oooooonX
ooooo`002_oooooo0?oooi<0oooo2oooool000[oooooo`3ooonC0?ooo`_ooooo000:ooooool0oooo
T`3oool;ooooo`002_oooooo0?oooi<0oooo2oooool000[oooooo`3ooonC0?ooo`_ooooo000:oooo
ool0ooooT`3oool;ooooo`002_oooooo0?oooi<0oooo2oooool000[oooooo`3ooonC0?ooo`_ooooo
000:ooooool0ooooT`3oool;ooooo`002_oooooo0?oooi<0oooo2oooool000[oooooDP3oool40820
P0D0oooo0P20P83o0?ooocH0oooo2oooool000[oooooD@3oool6000000<0oooo1@00003o0?oooc@0
oooo2oooool000[oooooD03oool00`20P800000000000005000000030?ooo`20P800000000@00000
00<0P8200?ooo`3oool0o`3ooola0?ooo`_ooooo000:oooooe00oooo100000030?ooo`D0000000@0
P8200?ooo`3oool0P820o`3ooolc0?ooo`_ooooo000:oooooe00oooo0`0000000`30`<00oooo0?oo
o`030?ooo`040410@000000000000820P?l0oooo=P3oool;ooooo`002_oooom@0?ooo`<000001P3o
ool01020P800000000000020P83o0?ooocH0oooo2oooool000[oooooD03oool3000000H0oooo00@0
P820000000000000P820o`3ooolf0?ooo`_ooooo000:oooooe00oooo00@0`<30000000000000`<30
1@3oool01020P800000000000020P83o0?ooocH0oooo2oooool000[oooooDP3oool2000000D0oooo
00@0P820000000000000P820o`3ooolf0?ooo`_ooooo000:oooooe<0oooo0P0000040?ooo`040820
P000000000000820P?l0oooo=P3oool;ooooo`002_oooomE0?ooo`D0P8200P0000000`20P800oooo
0?ooo`3o0?oooc@0oooo2oooool000[oooooF@3oool3000000030820P03oool0oooo0?l0oooo=03o
ool;ooooo`002_oooomI0?ooo`040820P000000000000820P?l0oooo=P3oool;ooooo`002_oooom@
0?ooo`040<30`000000000000<30`0D0oooo00@0P820000000000000P820o`3ooolf0?ooo`_ooooo
000:oooooe00oooo00@0P820000000000000P8201@3oool01020P800000000000020P83o0?ooocH0
oooo2oooool000[oooooD03oool01020P800000000000020P8050?ooo`030820P000000000000?l0
oooo=`3oool;ooooo`002_oooomA0?ooo`030820P0000000@41000@0oooo00@0P820000000000000
P820o`3ooolg0?ooo`_ooooo000:oooooe@0oooo1@0000000`20P800oooo0?ooo`3o0?ooocL0oooo
2oooool000[oooooo`3ooonC0?ooo`_ooooo000:ooooool0ooooT`3oool;ooooo`002_oooooo0?oo
oi<0oooo2oooool000[oooooo`3ooonC0?ooo`_ooooo000:ooooobT0oooo0`20P83o0?ooofL0oooo
2oooool000[ooooo9`3oool500000?l0ooooI`3oool;ooooo`002_oooolT0?ooo`030820P0000000
000000D00000o`3ooomW0?ooo`_ooooo000:ooooob<0oooo2@00003o0?ooofL0oooo2oooool000[o
oooo7P3oool20820P0030410@0000000000000X00000o`3ooomV0?ooo`_ooooo000:oooooa`0oooo
4@00003o0?ooofH0oooo2oooool000[ooooo6P3ooolC000000030820P03oool0oooo0?l0ooooH`3o
ool;ooooo`002_oooolE0?ooo`80P82000<0@4100000000000004`0000000`20P800oooo0?ooo`3o
0?ooof<0oooo2oooool000[ooooo4`3ooolJ000000030820P03oool0oooo0?l0ooooH`3oool;oooo
o`002_oooolA0?ooo`030820P0000000000001T0000000<0P8200?ooo`3oool0o`3ooomS0?ooo`_o
oooo000:ooooo`d0oooo0P20P80O00000?l0ooooI@3oool;ooooo`002_ooool:0?ooo`030820P000
0000000009T00000k03oool;ooooo`002_ooool80?oooih00000k03oool;ooooo`002_ooool90?oo
o`@0P820V@00003/0?ooo`_ooooo000:ooooo`h0ooooV000003/0?ooo`_ooooo000:oooooa00oooo
7P00003o0?ooofD0oooo2oooool000[ooooo4@3oool01030`<00P8200820P010@40I00000?l0oooo
I@3oool;ooooo`002_oooolG0?oooaH0000000<0P8200?ooo`3oool0o`3ooomS0?ooo`_ooooo000:
oooooaT0oooo500000000`20P800oooo0?ooo`3o0?ooof<0oooo2oooool000[ooooo6P3oool00`30
`<00P8200820P00@000000030<30`03oool0oooo0?l0ooooH`3oool;ooooo`002_oooolO0?ooo`h0
0000o`3ooomV0?ooo`_ooooo000:ooooob00oooo00<0P8200000000000002P00003o0?ooofH0oooo
2oooool000[ooooo8`3oool20820P0L00000o`3ooomW0?ooo`_ooooo000:ooooobL0oooo00<0P820
0000000000000P00003o0?ooofL0oooo2oooool000[ooooo:P3oool00`000000oooo0?ooo`3o0?oo
ofH0oooo2oooool000[oooooo`3ooonC0?ooo`_ooooo000:ooooool0ooooT`3oool;ooooo`002_oo
oooo0?oooi<0oooo2oooool000[oooooo`3ooonC0?ooo`_ooooo000:ooooool0ooooT`3oool;oooo
o`002_oooooo0?oooi<0oooo2oooool000[oooooo`3ooonC0?ooo`_ooooo000:ooooool0ooooT`3o
ool;ooooo`002_oooooo0?oooi<0oooo2oooool000[oooooo`3ooonC0?ooo`_ooooo000:ooooool0
ooooT`3oool;ooooo`002_oooooo0?oooi<0oooo2oooool000[oooooo`3ooonC0?ooo`_ooooo000:
ooooool0ooooT`3oool;ooooo`002_oooooo0?oooi<0oooo2oooool000[oooooo`3ooonC0?ooo`_o
oooo000:ooooool0ooooT`3oool;ooooo`002_oooooo0?oooi<0oooo2oooool000[oooooo`3ooonC
0?ooo`_ooooo000:ooooool0oooo?`3oool60820P2T0oooo00<0`<300?ooo`3oool08P3oool;oooo
o`002_oooooo0?ooocl0oooo1P00000Y0?ooo`030000003oool0oooo0280oooo2oooool000[ooooo
o`3ooolo0?ooo`H00000:@3oool2000002<0oooo2oooool000[ooooo0`3oool60820P?l0oooo=P3o
ool6000002P0oooo00@0P820000000000000P8208P3oool;ooooo`002_ooool30?ooo`H00000o`3o
oolf0?ooo`H00000:03oool400000280oooo2oooool000[ooooo0`3oool600000?l0oooo=P3oool6
000002P0oooo1000000R0?ooo`_ooooo000:ooooo`T00000o`3ooolf0?ooo`H000009`3oool60000
0240oooo2oooool000[ooooo2@00003o0?ooocH0oooo1P00000W0?ooo`H000008@3oool;ooooo`00
2_ooool900000?l0oooo=P3oool6000002H0oooo00<0P820000000000000100000000`20P800oooo
0?ooo`0N0?ooo`_ooooo000:ooooo`T00000o`3ooole0?ooo`L000009P3oool00`20P80000000000
0004000000030820P03oool0oooo01h0oooo2oooool000[ooooo2@00003o0?ooocD0oooo1`00000V
0?ooo`030410@0000000000000@0000000<0@4100?ooo`3oool07P3oool;ooooo`002_ooool:0000
0?l0oooo=03oool7000002H0oooo2000000P0?ooo`_ooooo000:ooooo`X00000o`3ooold0?ooo`L0
00009P3oool9000001l0oooo2oooool000[ooooo2P00003o0?oooc@0oooo1`00000U0?ooo`X00000
7`3oool;ooooo`002_ooool:00000?l0oooo=03oool7000002D0oooo2`00000N0?ooo`_ooooo000:
ooooo`X00000o`3ooold0?ooo`L00000903oool<000001h0oooo2oooool000[ooooo2P00003o0?oo
oc@0oooo1`00000T0?ooo``0000000<0`<300?ooo`3oool06`3oool;ooooo`002_ooool:00000?l0
oooo=03oool7000002<0oooo00<0P8200000000000002P0000000`20P800oooo0?ooo`0K0?ooo`_o
oooo000:ooooo`X00000o`3ooold0?ooo`L000008`3oool00`20P80000000000000:000000030820
P03oool0oooo01/0oooo2oooool000[ooooo2P00003o0?oooc<0oooo2000000S0?ooo`030410@000
0000000000X0000000<0@4100?ooo`3oool06`3oool;ooooo`002_ooool:00000?l0oooo<`3oool8
000002<0oooo3P00000M0?ooo`_ooooo000:ooooo`X0000000<0P8200?ooo`3oool0o`3oool`0?oo
o`P000008P3oool?000001d0oooo2oooool000[ooooo2P0000000`20P800oooo0?ooo`3o0?oooc00
oooo2000000R0?ooo`l0000000<0P8200?ooo`3oool06P3oool;ooooo`002_ooool:000000030820
P03oool0oooo0?l0oooo<03oool800000240oooo4@00000L0?ooo`_ooooo000:ooooo`X0000000<0
P8200?ooo`3oool0o`3oool_0?ooo`030820P0000000000000H000008@3ooolB000001/0oooo2ooo
ool000[ooooo2`00003o0?oooc40oooo00<0P8200000000000001P00000P0?ooo`030<30`0000000
00000100000000<0`<300?ooo`3oool0603oool;ooooo`002_ooool;00000?l0oooo<@3oool00`20
P80000000000000600000200oooo00<0P820000000000000400000000`20P800oooo0?ooo`0H0?oo
o`_ooooo000:ooooo`/00000o`3ooola0?ooo`030820P0000000000000H00000803oool00`20P800
00000000000@000000030820P03oool0oooo01P0oooo2oooool000[ooooo2`00003o0?oooc40oooo
00<0P8200000000000001P00000P0?oooa@000006P3oool;ooooo`002_ooool<00000?l0oooo<03o
ool900000200oooo5000000J0?ooo`_ooooo000:ooooo``00000o`3oool`0?ooo`T000007`3ooolE
000001X0oooo2oooool000[ooooo3000003o0?oooc00oooo2@00000O0?oooaH000006@3oool;oooo
o`002_ooool<000000030820P03oool0oooo0?l0oooo;@3oool9000001h0oooo00<0P82000000000
00005000000I0?ooo`_ooooo000:ooooo`d00000o`3oool^0?ooo`X000007P3ooolH000001P0oooo
2oooool000[ooooo1P0000000`3oool000000000000400000?l0oooo;P3oool:000001h0oooo6000
000H0?ooo`_ooooo000:ooooo`H0000000<0oooo000000000000100000000`20P800oooo0?ooo`3o
0?ooobX0oooo00<0P8200000000000002000000M0?ooo`030820P0000000000001H0000000<0P820
0?ooo`3oool05@3oool;ooooo`002_ooool6000000030?ooo`000000000000D00000o`3oool/0?oo
o`/00000803ooolD000001X0oooo2oooool000[ooooo1P0000000`3oool0P8200000000500000?l0
oooo;03oool;00000280oooo4000000L0?ooo`_ooooo000:ooooo`H0000000<0oooo0820P0000000
1@0000000`30`<00oooo0?ooo`3o0?ooobP0oooo00<0`<300000000000002@00000V0?ooo`<0P820
0`0000000`20P800`<300?ooo`0O0?ooo`_ooooo000:ooooo`H0000000<0oooo0820P00000001@00
00000`20P800oooo0?ooo`3o0?ooobP0oooo00<0P8200000000000002@00000Y0?ooo`<000008P3o
ool;ooooo`002_ooool600000080oooo1P0000000`20P800oooo0?ooo`3o0?ooobP0oooo00<0P820
0000000000002@00000Y0?ooo`<000008P3oool;ooooo`002_ooool600000080oooo1P0000000`10
@400oooo0?ooo`3o0?ooobP0oooo00<0@4100000000000002@00000Y0?ooo`<000008P3oool;oooo
o`002_ooool600000080oooo1`00003o0?ooobX0oooo3000000Y0?ooo`<000008P3oool;ooooo`00
2_ooool6000000<0oooo1P00003o0?ooobX0oooo3000000Y0?ooo`<000008P3oool;ooooo`002_oo
ool6000000<0oooo1P0000000`20P800oooo0?ooo`3o0?ooobH0oooo00<0P8200000000000002P00
000Y0?ooo`<000008P3oool;ooooo`002_ooool6000000<0oooo1`00003o0?ooobP0oooo3@00000Y
0?ooo`<000008P3oool;ooooo`002_ooool6000000@0oooo1P00003o0?ooobP0oooo3@00000Y0?oo
o`<000008P3oool;ooooo`002_ooool6000000@0oooo1P0000000`20P800oooo0?ooo`3o0?ooob@0
oooo1`0000000`3oool0000000000004000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000
103oool700000?l0oooo9P3oool7000000030?ooo`000000000000@00000:@3oool300000280oooo
2oooool000[ooooo1P0000040?ooo`030820P0000000000000@00000o`3ooolU0?ooo`030820P000
0000000000@000000P3oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000103oool0
0`20P800000000000004000000030820P03oool0oooo0?l0oooo8P3oool00`10@400000000000004
00000080oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6000000@0oooo00<0P8200000
00000000100000000`20P800oooo0?ooo`3o0?ooob80oooo1P0000000`20P800oooo0?ooo`060000
02T0oooo0`00000R0?ooo`_ooooo000:ooooo`H000001@3oool700000?l0oooo903oool600000003
0820P03oool0oooo00H00000:@3oool300000280oooo2oooool000[ooooo1P0000050?ooo`L00000
o`3ooolS0?ooo`L000000`3oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H000001P3o
ool700000?l0oooo8P3oool7000000<0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6
000000L0oooo1P00003o0?ooob40oooo1`0000040?ooo`H00000:@3oool300000280oooo2oooool0
00[ooooo1P0000070?ooo`L00000o`3ooolP0?ooo`L00000103oool6000002T0oooo0`00000R0?oo
o`_ooooo000:ooooo`H000001`3oool00`20P80000000000000400000?l0oooo7`3oool00`30`<00
000000000004000000030820P03oool0oooo0080oooo1P00000Y0?ooo`<000008P3oool;ooooo`00
2_ooool6000000P0oooo1P0000000`20P800oooo0?ooo`3o0?oooa`0oooo00<0P820000000000000
100000050?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P0000080?ooo`030820P000
0000000000<0000000<0P8200?ooo`3oool0o`3ooolL0?ooo`L000001@3oool6000002T0oooo0`00
000R0?ooo`_ooooo000:ooooo`H00000203oool00`20P80000000000000400000?l0oooo7P3oool6
000000030820P03oool0oooo00<0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool60000
00T0oooo1P00003o0?oooad0oooo1`0000060?ooo`H00000:@3oool300000280oooo2oooool000[o
oooo1P0000090?ooo`L00000o`3ooolL0?ooo`L000001P3oool6000002T0oooo0`00000R0?ooo`_o
oooo000:ooooo`H000002P3oool6000000030820P03oool0oooo0?l0oooo603oool7000000030820
P03oool0oooo00@0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6000000/0oooo1P00
003o0?oooaT0oooo00<0P8200000000000001@0000070?ooo`H00000:@3oool300000280oooo2ooo
ool000[ooooo1P00000;0?ooo`H0000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P0000000
000000@00000203oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H000002`3oool00`20
P800000000000003000000030410@03oool0oooo0?l0oooo5P3oool6000000030410@03oool0oooo
00H0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6000000`0oooo1P00003o0?oooaP0
oooo1P0000000`20P800oooo0?ooo`060?ooo`H00000:@3oool300000280oooo2oooool000[ooooo
1P00000<0?ooo`L00000o`3ooolF0?ooo`L000002@3oool6000002T0oooo0`00000R0?ooo`_ooooo
000:ooooo`H000003@3oool6000000030820P03oool0oooo0?l0oooo4P3oool00`20P80000000000
0004000000030820P03oool0oooo00L0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6
000000h0oooo1P00003o0?oooa@0oooo1`00000:0?ooo`H00000:@3oool300000280oooo2oooool0
00[ooooo1P00000>0?ooo`H0000000<0P8200?ooo`3oool0o`3oool@0?ooo`L000002`3oool60000
02T0oooo0`00000R0?ooo`_ooooo000:ooooo`H000003P3oool00`20P80000000000000300000003
0410@03oool0oooo0?l0oooo3`3oool00`30`<00000000000004000000030410@03oool0oooo00T0
oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6000000l0oooo1P00003o0?oooa40oooo
1`0000000`20P800oooo0?ooo`090?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00
000?0?ooo`L00000o`3oool@0?ooo`L00000303oool6000002T0oooo0`00000R0?ooo`_ooooo000:
ooooo`H00000403oool600000?l0oooo3`3oool8000000`0oooo1P00000Y0?ooo`<000008P3oool;
ooooo`002_ooool600000100oooo00<0P820000000000000100000000`30`<00oooo0?ooo`3o0?oo
o`X0oooo2000000=0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00000A0?ooo`H0
000000<0P8200?ooo`3oool0o`3oool90?ooo`030820P0000000000000D000003P3oool6000002T0
oooo0`00000R0?ooo`_ooooo000:ooooo`H000004@3oool00`20P80000000000000400000?l0oooo
2`3oool00`20P800000000000005000000h0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_oo
ool600000140oooo00<0P8200000000000001@00003o0?ooo`T0oooo00<0P8200000000000001@00
00000`20P800oooo0?ooo`0<0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00000B
0?ooo`P00000o`3oool80?ooo`P000003`3oool6000002T0oooo0`00000R0?ooo`_ooooo000:oooo
o`H000004P3oool8000000030820P03oool0oooo0?l0oooo103oool9000000l0oooo1P00000Y0?oo
o`<000008P3oool;ooooo`002_ooool6000001<0oooo00<0P820000000000000100000000`10@400
oooo0?ooo`3o0?ooo`<0oooo00<0P8200000000000001@0000000`20P800oooo0?ooo`0>0?ooo`H0
0000:@3oool300000280oooo2oooool000[ooooo1P00000D0?ooo`L00000o`3oool50?ooo`P00000
4@3oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000503oool00`20P80000000000
000500000?l0oooo0`3oool800000180oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6
000001D0oooo2000003o0?ooo`40oooo00<0P8200000000000001@0000000`10@400oooo0?ooo`0@
0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00000F0?ooo`P00000o`3oool80000
01<0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6000001H0oooo200000000`20P800
oooo0?ooo`3l0?ooo`P000004`3oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000
5`3oool00`10@400000000000004000000030410@03oool0oooo0?/0oooo00<0@410000000000000
1@00000D0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00000G0?ooo`030820P000
0000000000H00000n`3oool8000001D0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6
000001P0oooo2@00003j0?ooo`L000005P3oool6000002T0oooo0`00000R0?ooo`_ooooo000:oooo
o`H000006@3oool8000000030<30`03oool0oooo0?D0oooo00<0`<300000000000001@0000000`20
P800oooo0?ooo`0D0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00000J0?ooo`P0
0000m`3oool7000001P0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6000001X0oooo
00<0P8200000000000001P00003f0?ooo`L00000603oool6000002T0oooo0`00000R0?ooo`_ooooo
000:ooooo`H000006`3oool8000000030820P03oool0oooo0?40oooo00<0P8200000000000001@00
00000`30`<00oooo0?ooo`0F0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00000L
0?ooo`P0000000<0P8200?ooo`3oool0k`3oool00`20P800000000000006000001T0oooo1P00000Y
0?ooo`<000008P3oool;ooooo`002_ooool6000001d0oooo2000003a0?ooo`030820P00000000000
00D000006P3oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H000007P3oool700000003
0820P03oool0oooo0>`0oooo0P20P806000000030410@03oool0oooo01T0oooo1P00000Y0?ooo`<0
00008P3oool;ooooo`002_ooool6000001h0oooo00<0P8200000000000001P00003/0?ooo`030820
P0000000000000H0000000<0P8200?ooo`3oool06@3oool6000002T0oooo0`00000R0?ooo`_ooooo
000:ooooo`H000007`3oool8000000030820P03oool0oooo0>T0oooo2@00000L0?ooo`H00000:@3o
ool300000280oooo2oooool000[ooooo1P00000P0?ooo`L0000000<0P8200?ooo`3oool0j@3oool8
000001d0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool600000200oooo00<0P8200000
000000001P0000000`20P800oooo0?ooo`3U0?ooo`030820P0000000000000H0000000<0P8200?oo
o`3oool06`3oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H000008@3oool00`20P800
000000000006000000030820P03oool0oooo0><0oooo2@00000O0?ooo`H00000:@3oool300000280
oooo2oooool000[ooooo1P00000R0?ooo`P0000000<0P8200?ooo`3oool0hP3oool00`20P8000000
0000000600000200oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool600000280oooo00<0
P8200000000000001P0000000`20P800oooo0?ooo`3P0?ooo`030820P0000000000000H000008@3o
ool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000903oool00`20P800000000000006
00000>40oooo200000000`20P800oooo0?ooo`0O0?ooo`H00000:@3oool300000280oooo2oooool0
00[ooooo1P00000U0?ooo`P0000000<0P8200?ooo`3oool0g@3oool900000280oooo1P00000Y0?oo
o`<000008P3oool;ooooo`002_ooool6000002H0oooo200000000`20P800oooo0?ooo`3K0?ooo`03
0410@0000000000000D0000000<0P8200?ooo`3oool08@3oool6000002T0oooo0`00000R0?ooo`_o
oooo000:ooooo`H000009`3oool900000=/0oooo200000000`20P800oooo0?ooo`0R0?ooo`H00000
:@3oool300000280oooo2oooool000[ooooo1P00000W0?ooo`030820P0000000000000H00000fP3o
ool9000002D0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6000002P0oooo00<0P820
0000000000001@0000000`10@400oooo0?ooo`1h0?ooo`030820P0000000000000D0P820EP3oool0
0`10@400000000000006000000030820P03oool0oooo02<0oooo1P00000Y0?ooo`<000008P3oool;
ooooo`002_ooool6000002X0oooo2000001g0?ooo`<000001P3oool2000000030820P03oool0oooo
0540oooo2@00000W0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00000Z0?ooo`03
0820P0000000000000H00000M@3oool01020P800000000000020P8070?ooo`800000DP3oool90000
02P0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6000002/0oooo2@0000000`30`<00
oooo0?ooo`1a0?ooo`<000002@3oool200000500oooo00<0@4100000000000001P0000000`30`<00
oooo0?ooo`0V0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00000/0?ooo`X00000
L@3oool3000000X0oooo00<0P820000000000000C@3oool:000002X0oooo1P00000Y0?ooo`<00000
8P3oool;ooooo`002_ooool6000002d0oooo2P00001`0?ooo`<000002P3oool00`20P80000000000
001<0?ooo`030820P0000000000000L00000:`3oool6000002T0oooo0`00000R0?ooo`_ooooo000:
ooooo`H00000;@3oool00`30`<00P82000000007000000030410@03oool0oooo06`0oooo0`000000
0`20P800oooo0?ooo`080?ooo`040820P00000000000000004X0oooo00<0P8200000000000001P00
00000`20P800oooo0?ooo`0Z0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00000`
0?ooo`T00000K@3oool3000000/0oooo00@0P8200000000000000000B@3oool9000002h0oooo1P00
000Y0?ooo`<000008P3oool;ooooo`002_ooool600000300oooo00<0P8200000000000001`00001/
0?ooo`<000002`3oool01020P80000000000000000180?ooo`030820P0000000000000H0000000<0
P8200?ooo`3oool0;03oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000<P3oool0
0`20P800000000000006000000030820P03oool0oooo05H0oooo00<0P8200410@000000010000000
0`10@400P8200?ooo`080?ooo`<000002`3oool01020P80000000000000000160?ooo`80P8202000
00000`20P800oooo0?ooo`0]0?ooo`H00000:@3oool3000000X0oooo00<0`<300820P00000004P00
00000`20P800oooo0?ooo`0;ooooo`002_ooool6000003@0oooo2@00001J0?ooo`<00000303oool3
000000/0oooo100000150?ooo`030820P0000000000000L00000<@3oool6000002T0oooo0`00000=
0?ooo`040820P00000000000000000X0oooo1@0000020?ooo`_ooooo000:ooooo`H00000=03oool0
0`20P800000000000006000000030820P03oool0oooo05L0oooo0`00000=0?ooo`8000002`3oool3
000004H0oooo2@00000b0?ooo`H00000:@3oool3000000d0oooo00@0P820000000000000P820303o
ool00`20P8000000000000020?ooo`_ooooo000:ooooo`H00000=@3oool9000005T0oooo0`00000=
0?ooo`8000002`3oool3000004@0oooo2P00000c0?ooo`H00000:@3oool3000000d0oooo00@0P820
000000000000P8203@3oool2000000030820P03ooooooooo00[ooooo000:ooooo`H00000=P3oool0
0`20P800@41000000007000000030<30`03oool0oooo05@0oooo0`00000>0?ooo`8000002@3oool3
000000030820P03oool0oooo0400oooo00<0`<300000000000002000000d0?ooo`H00000:@3oool3
000000d0oooo00@0P820000000000000P8203P3oool20820P0030?oooooooooooooo00Wooooo000:
ooooo`H00000>03oool:000005D0oooo0`00000>0?ooo`030820P0000000000000L0oooo0`000013
0?ooo`/0000000<0P8200?ooo`3oool0<P3oool6000002T0oooo0`00000=0?ooo`040820P0000000
00000820P0l0oooo00<000000?ooooooool02_ooool000[ooooo1P00000i0?ooo`X00000E03oool3
000000l0oooo0P0000000`20P800oooo0?ooo`030?ooo`040820P000000000000820P480oooo2`00
000f0?ooo`H00000:@3oool3000000d0oooo00@0P820000000000000P8204@3oool;ooooo`002_oo
ool6000003X0oooo00<0@4100000000000001`0000000`20P800oooo0?ooo`1@0?ooo`<00000403o
ool60820P00300000010@400P8200480oooo00<0P8200410@0000000200000000`10@400oooo0?oo
o`0e0?ooo`H00000:@3oool3000000d0oooo00@0P820000000000000P8204@3oool;ooooo`002_oo
ool6000003`0oooo2P0000000`20P800oooo0?ooo`1>0?ooo`<00000FP3oool;000003T0oooo1P00
000Y0?ooo`<000003@3oool01020P800000000000020P80A0?ooo`_ooooo000:ooooo`H00000?@3o
ool:00000500oooo0`00001I0?ooo`030820P0000000000000P00000>P3oool6000002T0oooo0`00
000=0?ooo`040820P000000000000820P140oooo2oooool000[ooooo1P00000m0?ooo`030<30`020
P800000000T0000000<0P8200?ooo`3oool0B`3oool3000005L0oooo0P20P809000000030820P030
`<00oooo03T0oooo1P00000Y0?ooo`<000003@3oool01020P800000000000020P80A0?ooo`_ooooo
000:ooooo`H00000@03oool;000004`0oooo0`00001F0?ooo`/00000?@3oool6000002T0oooo0`00
000=0?ooo`040820P000000000000820P140oooo2oooool000[ooooo1P0000100?ooo`030820P000
0000000000T00000B`3oool3000005D0oooo2`00000n0?ooo`H00000:@3oool3000000d0oooo00@0
P820000000000000P8204@3oool;ooooo`002_ooool600000480oooo00<0P8200000000000002000
00000`10@400P8200?ooo`170?ooo`<00000DP3oool00`20P800@41000000009000000030820P03o
ool0oooo03d0oooo1P00000Y0?ooo`<000003@3oool01020P800000000000020P80A0?ooo`_ooooo
000:ooooo`H00000@`3oool00`20P80000000000000:000000030820P03oool0oooo04@0oooo0`00
001@0?ooo`030820P0000000000000T0000000<0P8200?ooo`3oool0?`3oool6000002T0oooo0`00
000=0?ooo`040820P000000000000820P140oooo2oooool000[ooooo1P0000150?ooo``00000AP3o
ool300000500oooo300000120?ooo`H00000:@3oool3000000d0oooo00@0P820000000000000P820
4@3oool;ooooo`002_ooool6000004H0oooo00<0P8200000000000002P0000000`20P800oooo0?oo
o`110?ooo`<00000C@3oool00`20P800000000000009000000030820P03oool0oooo0480oooo1P00
000Y0?ooo`<000003@3oool01020P800000000000020P80A0?ooo`_ooooo000:ooooo`H00000B@3o
ool<00000480oooo0`00001;0?ooo`d00000AP3oool6000002T0oooo0`00000=0?ooo`040820P000
000000000820P140oooo2oooool000[ooooo1P00001:0?ooo``0000000<0P8200?ooo`3oool0?P3o
ool3000004T0oooo00<0P8200000000000002P0000000`20P800oooo0?ooo`150?ooo`H00000:@3o
ool3000000d0oooo00@0P820000000000000P8204@3oool;ooooo`002_ooool6000004/0oooo0P20
P80;00000080P820=03oool00`000000oooo0?ooo`060?ooo`<00000203oool00`20P800oooo0?oo
o`0k0?ooo`030<30`020P800000000X0000000<0@4100820P03oool0B03oool6000002T0oooo0`00
000=0?ooo`040820P000000000000820P140oooo2oooool000[ooooo1P00001>0?ooo`h00000<P3o
ool00`000000P8200?ooo`060?ooo`<00000203oool00`000000oooo0?ooo`0j0?ooo`h00000B`3o
ool6000002T0oooo0`00000=0?ooo`040820P000000000000820P140oooo2oooool000[ooooo1P00
001@0?ooo`d00000<@3oool00`000000P8200?ooo`060?ooo`<00000203oool00`000000oooo0?oo
o`0h0?ooo`030820P0000000000000/00000C@3oool6000002T0oooo0`00000=0?ooo`040820P000
000000000820P140oooo2oooool000[ooooo1P00001@0?ooo`030<30`020P800000000`000000P20
P80]0?ooo`8000000P20P8050?ooo`<000001@3oool20820P0800000=`3oool00`30`<00P8200000
000=000000030820P03oool0oooo04/0oooo1P00000Y0?ooo`<000003@3oool01010@40000000000
0010@40A0?ooo`_ooooo000:ooooo`H00000D`3oool00`20P80000000000000=000002/0oooo5@00
000f0?ooo`l00000D03oool6000002T0oooo0`00000<0?ooo`H00000403oool;ooooo`002_ooool6
000005<0oooo00<0P8200000000000003P00000Z0?oooaD00000=03oool00`20P80000000000000=
00000540oooo1P00000Y0?ooo`<000002P3oool00`20P800000000000006000000030820P03oool0
oooo00`0oooo2oooool000[ooooo1P00001E0?ooo`80P8203`0000000`10@400P8200?ooo`1Z0?oo
o`80P8203P0000000`10@400P8200?ooo`1B0?ooo`H00000:@3oool300000280oooo2oooool000[o
oooo1P00001I0?oooa400000I`3oool00`20P80000000000000>000005H0oooo1P00000Y0?ooo`<0
00008P3oool;ooooo`002_ooool6000005X0oooo4P0000000`20P800oooo0?ooo`1P0?oooa400000
00<0P8200?ooo`3oool0E@3oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000G03o
oolC000005h0oooo4P00001I0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00001N
0?ooo`80P820400000020820P0030<30`03oool0oooo0580oooo00<0`<300820P020P8004@000002
0820P0030<30`03oool0oooo05P0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool60000
0640oooo5000001?0?ooo`030820P0000000000001<00000GP3oool6000002T0oooo0`00000R0?oo
o`_ooooo000:ooooo`H00000I03ooolD000004T0oooo00<0P8200000000000004`0000000`20P800
oooo0?ooo`1N0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00001V0?ooo`80P820
4`0000030820P3d0oooo0`20P8000`10@40000000000000C000000030820P03oool0oooo0640oooo
1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6000006X0oooo5`00000f0?oooaX0000000<0
P8200?ooo`3oool0I03oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000K03oool0
0`20P80000000000000I000000030820P03oool0oooo02P0oooo7000001Y0?ooo`H00000:@3oool3
00000280oooo2oooool000[ooooo1P00001^0?ooo`80P8208000000O0820P1X000000`20P81/0?oo
o`H00000:@3oool300000280oooo2oooool000[ooooo1P00001c0?oooe<00000LP3oool6000002T0
oooo0`00000R0?ooo`_ooooo000:ooooo`H00000MP3oool00`20P80000000000001:000007D0oooo
1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6000007T0oooo00@0`<300820P020P800@410
@`00001h0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00001o0?ooo`030820P000
0000000003T00000O@3oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000Q@3oool0
0`20P80000000000000]000008<0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool60000
08X0oooo1@20P8000`10@40000000000000>00000100P820R03oool6000002T0oooo0`00000R0?oo
o`_ooooo000:ooooo`H00000o`3oooli0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo
1P00003o0?ooocT0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool600000?l0oooo>@3o
ool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000o`3oooli0?ooo`H00000:@3oool3
00000280oooo2oooool000[ooooo1P00003o0?ooocT0oooo1P00000Y0?ooo`<000008P3oool;oooo
o`002_ooool600000?l0oooo>@3oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000
o`3oooli0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00003o0?ooocT0oooo1P00
000Y0?ooo`<000008P3oool;ooooo`002_ooool600000?l0oooo>@3oool6000002T0oooo0`00000R
0?ooo`_ooooo000:ooooo`H00000o`3oooli0?ooo`H00000:@3oool300000280oooo2oooool000[o
oooo1P00003o0?ooocT0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool600000?l0oooo
>@3oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000o`3oooli0?ooo`H00000:@3o
ool300000280oooo2oooool000[ooooo1P00003o0?ooocT0oooo1P00000Y0?ooo`<000008P3oool;
ooooo`002_ooool600000?l0oooo>@3oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H0
0000o`3oooli0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00003o0?ooocT0oooo
1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool600000?l0oooo>@3oool6000002T0oooo0`00
000R0?ooo`_ooooo000:ooooo`H00000o`3oooli0?ooo`H00000:@3oool300000280oooo2oooool0
00[ooooo1P00003o0?ooocT0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool600000?l0
oooo>@3oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000o`3oooli0?ooo`H00000
:@3oool300000280oooo2oooool000[ooooo1P00003o0?ooocT0oooo1P00000Y0?ooo`<000008P3o
ool;ooooo`002_ooool600000?l0oooo>@3oool6000002T0oooo0`00000R0?ooo`_ooooo000:oooo
o`H00000o`3oooli0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00003o0?ooocT0
oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool600000?l0oooo>@3oool6000002T0oooo
0`00000R0?ooo`_ooooo000:ooooo`H00000o`3oooli0?ooo`H00000:@3oool300000280oooo2ooo
ool000[ooooo1P00003o0?ooocT0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool60000
0?l0oooo>@3oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000o`3oooli0?ooo`H0
0000:@3oool300000280oooo2oooool000[ooooo1P00003o0?ooocT0oooo1P00000Y0?ooo`<00000
8P3oool;ooooo`002_ooool600000?l0oooo>@3oool6000002T0oooo0`00000R0?ooo`_ooooo000:
ooooo`H00000o`3oooli0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00003o0?oo
ocT0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool600000?l0oooo>@3oool6000002T0
oooo0`00000R0?ooo`_ooooo000:ooooo`H00000o`3oooli0?ooo`H00000:@3oool300000280oooo
2oooool000[ooooo1P00003o0?ooocT0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6
00000?l0oooo>@3oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000o`3oooli0?oo
o`H00000:@3oool300000280oooo2oooool000[ooooo1P00003o0?ooocT0oooo1P00000Y0?ooo`<0
00008P3oool;ooooo`002_ooool600000?l0oooo>@3oool6000002T0oooo0`00000R0?ooo`_ooooo
000:ooooo`H00000o`3oooli0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00003o
0?ooocT0oooo1P00000P0?ooo`80P820400000020820P1X0oooo2oooool000[ooooo1P00003o0?oo
ocT0oooo1P00000N0?oooaP0000000<0P8200?ooo`3oool05@3oool;ooooo`002_ooool600000?l0
oooo>@3oool6000001d0oooo00<0P8200000000000005P0000000`20P800oooo0?ooo`0E0?ooo`_o
oooo000:ooooo`H00000o`3oooli0?ooo`H000007P3ooolH000001P0oooo2oooool000[ooooo1P00
003o0?ooocT0oooo1P00000N0?oooaP00000603oool;ooooo`002_ooool600000?l0oooo>@3oool6
000001l0oooo5P00000I0?ooo`_ooooo000:ooooo`H00000o`3oooli0?ooo`H000007`3ooolF0000
01T0oooo2oooool000[ooooo1P00003o0?ooocT0oooo1P00000P0?oooa@000006P3oool;ooooo`00
2_ooool600000?l0oooo>@3oool600000200oooo5000000J0?ooo`_ooooo000:ooooo`H00000o`3o
ooli0?ooo`H00000803oool00`10@40000000000000@000000030410@03oool0oooo01P0oooo2ooo
ool000[ooooo1P00003o0?ooocT0oooo1P00000P0?ooo`030820P000000000000100000000<0P820
0?ooo`3oool0603oool;ooooo`002_ooool600000?l0oooo>@3oool600000200oooo00<0P8200000
00000000400000000`20P800oooo0?ooo`0H0?ooo`_ooooo000:ooooo`H00000o`3oooli0?ooo`H0
00008@3ooolB000001/0oooo2oooool000[ooooo1P00003o0?ooocT0oooo1P00000Q0?oooa400000
00<0P8200?ooo`3oool06@3oool;ooooo`002_ooool600000?l0oooo>@3oool600000280oooo4000
000L0?ooo`_ooooo000:ooooo`H00000o`3oooli0?ooo`H000008P3oool@000001`0oooo2oooool0
00[ooooo1P00003o0?ooocT0oooo1P00000R0?ooo`030820P0000000000000`000007@3oool;oooo
o`002_ooool600000?l0oooo>@3oool6000002<0oooo3P00000M0?ooo`_ooooo000:ooooo`H00000
o`3oooli0?ooo`H000008`3oool=000000030820P03oool0oooo01/0oooo2oooool000[ooooo1P00
003o0?ooocT0oooo1P00000S0?ooo`030820P0000000000000X0000000<0P8200?ooo`3oool06`3o
ool;ooooo`002_ooool600000?l0oooo>@3oool6000002@0oooo300000000`20P800oooo0?ooo`0K
0?ooo`_ooooo000:ooooo`H00000o`3oooli0?ooo`H00000903oool<000001h0oooo2oooool000[o
oooo1P00003o0?ooocT0oooo1P00000T0?ooo`030820P0000000000000T000007P3oool;ooooo`00
2_ooool600000?l0oooo>@3oool6000002D0oooo2P00000O0?ooo`_ooooo000:ooooo`H00000o`3o
ooli0?ooo`H000009@3oool:000001l0oooo2oooool000[ooooo1P00003o0?ooocT0oooo1P00000V
0?ooo`P0000000<0P8200?ooo`3oool07@3oool;ooooo`002_ooool600000?l0oooo>@3oool60000
02H0oooo2000000P0?ooo`_ooooo000:ooooo`H00000o`3oooli0?ooo`H000009P3oool00`20P800
000000000004000000030820P03oool0oooo01h0oooo2oooool000[ooooo1P00003o0?ooocT0oooo
1P00000V0?ooo`030820P0000000000000@0000000<0P8200?ooo`3oool07P3oool;ooooo`002_oo
ool600000?l0oooo>@3oool6000002L0oooo1P00000Q0?ooo`_ooooo000:ooooo`H00000o`3oooli
0?ooo`H000009`3oool600000240oooo2oooool000[ooooo1P00003o0?ooocT0oooo1P00000W0?oo
o`030820P000000000000080000000<0P8200?ooo`3oool07`3oool;ooooo`002_ooool600000?l0
oooo>@3oool6000002P0oooo1000000R0?ooo`_ooooo000:ooooo`H00000o`3oooli0?ooo`H00000
:03oool400000280oooo2oooool000[oooooo`000015000002T0oooo0P00000S0?ooo`_ooooo000:
ooooool00000A@00000Y0?ooo`0300000020P800oooo0280oooo2oooool000[oooooo`0000150000
02T0oooo00<0P8200?ooo`3oool08P3oool;ooooo`002_oooooo000004D00000CP3oool;ooooo`00
2_oooooo000004D00000CP3oool;ooooo`002_oooooo000004D00000CP3oool;ooooo`002_oooooo
000004D00000CP3oool;ooooo`002_oooooo0?oooi<0oooo2oooool000[oooooo`3ooonC0?ooo`_o
oooo000:ooooool0ooooT`3oool;ooooo`002_oooooo0?oooi<0oooo2oooool000[oooooo`3ooonC
0?ooo`_ooooo000:ooooool0ooooT`3oool;ooooo`002_oooooo0?oooi<0oooo2oooool000[ooooo
o`3ooonC0?ooo`_ooooo000:ooooool0ooooT`3oool;ooooo`002_oooooo0?oooi<0oooo2oooool0
00[oooooo`3ooonC0?ooo`_ooooo000:ooooool0ooooT`3oool;ooooo`002_oooooo0?oooi<0oooo
2oooool000[oooooo`3ooonC0?ooo`_ooooo000:oooookL0oooo00<0P8200000000000002000003@
0?ooo`_ooooo000:oooookX0oooo00D0`<3000000000000000000410@03C0?ooo`_ooooo000:oooo
ok/0oooo0`0000000`20P800oooo0?ooo`3A0?ooo`_ooooo000:oooook/0oooo0`0000000`20P800
oooo0?ooo`3A0?ooo`_ooooo000:oooook/0oooo0`0000000`20P800oooo0?ooo`3A0?ooo`_ooooo
000:oooook/0oooo0`0000000`20P800oooo0?ooo`3A0?ooo`_ooooo000:oooook/0oooo0`000000
0`20P800oooo0?ooo`3A0?ooo`_ooooo000:oooook/0oooo0`0000000`20P800oooo0?ooo`3A0?oo
o`_ooooo000:oooook/0oooo0`0000000`20P800oooo0?ooo`3A0?ooo`_ooooo000:oooooj80oooo
2@0000000`20P800oooo0?ooo`0=0?ooo`<0000000<0P8200?ooo`3oool0d@3oool;ooooo`002_oo
oonT0?ooo`H000004@3oool3000000030820P03oool0oooo0=40oooo2oooool000[oooooY@3oool3
000000030820P03oool0oooo0100oooo0`0000000`20P800oooo0?ooo`3A0?ooo`_ooooo000:oooo
ojD0oooo0`0000000`20P800oooo0?ooo`0@0?ooo`<0000000<0P8200?ooo`3oool0d@3oool;oooo
o`002_oooonU0?ooo`<0000000<0P8200?ooo`3oool0403oool3000000030820P03oool0oooo0=40
oooo2oooool000[oooooY@3oool3000000030820P03oool0oooo0100oooo0`0000000`20P800oooo
0?ooo`3A0?ooo`_ooooo000:ooooojD0oooo0`0000000`20P800oooo0?ooo`0@0?ooo`<0000000<0
P8200?ooo`3oool0d@3oool;ooooo`002_oooonU0?ooo`<0000000<0P8200?ooo`3oool0403oool3
000000030820P03oool0oooo0=40oooo2oooool000[oooooY@3oool3000000030820P03oool0oooo
0100oooo0`0000000`20P800oooo0?ooo`3A0?ooo`_ooooo000:ooooojD0oooo0`0000000`20P800
oooo0?ooo`0@0?ooo`<0000000<0P8200?ooo`3oool0d@3oool;ooooo`002_oooonU0?ooo`<00000
00<0P8200?ooo`3oool0403oool3000000030820P03oool0oooo0=40oooo2oooool000[oooooY@3o
ool3000000030820P03oool0oooo0100oooo0`0000000`20P800oooo0?ooo`3A0?ooo`_ooooo000:
ooooojD0oooo0`0000000`20P800oooo0?ooo`0<0?ooo`040820P03oool0oooo0?ooo`<0000000<0
P8200?ooo`3oool0d@3oool;ooooo`002_oooonU0?ooo`<0000000<0P8200?ooo`3oool03@3oool6
000000030820P03oool0oooo0=40oooo2oooool000[oooooY@3oool3000000030820P03oool0oooo
00l0oooo00D0P82000000000000000000820P03C0?ooo`_ooooo000:ooooojD0oooo0`0000000`20
P800oooo0?ooo`0C0?ooo`030820P03oool0oooo0=40oooo2oooool000[oooooY@3oool300000003
0820P03oool0oooo0>L0oooo2oooool000[oooooY@3oool3000000030820P03oool0oooo0>L0oooo
2oooool000[oooooY@3oool3000000030820P03oool0oooo0>L0oooo2oooool000[oooooW03oool0
0`000000oooo0?ooo`060?ooo`<0000000<0P8200?ooo`3oool01P3oool00`20P800oooo0?ooo`3N
0?ooo`_ooooo000:oooooi`0oooo00<000000?ooo`3oool01P3oool3000000030820P03oool0oooo
00H0oooo00<0P8200?ooo`3oool0gP3oool;ooooo`002_oooonL0?ooo`8000001`3oool300000003
0820P03oool0oooo00D0oooo00<000000820P03oool0g`3oool;ooooo`002_oooonL0?ooo`800000
00<0P8200?ooo`3oool0103oool3000000030820P03oool0oooo00@0oooo0P0000000`20P800oooo
0?ooo`3N0?ooo`_ooooo000:oooooi`0oooo100000050?ooo`<0000000<0P8200?ooo`3oool00`3o
ool3000000030820P03oool0oooo0=h0oooo2oooool000[oooooW03ooolE000000030820P03oool0
oooo0=h0oooo2oooool000[oooooo`3ooonC0?ooo`_ooooo000:ooooool0ooooT`3oool;ooooo`00
2_oooooo0?oooi<0oooo2oooool000[oooooo`3ooonC0?ooo`_ooooo003oooooojSooooo003ooooo
ojSooooo003oooooojSooooo003oooooojSooooo003oooooojSooooo003oooooojSooooo003ooooo
ojSooooo003oooooojSooooo003oooooojSooooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{141.125, 131},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 6.5 Exercise (3).", "Caption",
  CellTags->"Fig. 6.5"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  "  A triaxial ellipsoid has a shape given by the equation ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2/a\^2 + y\^2/b\^2 + z\^2/c\^2 = 1\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`a\  = \ 2, \ 
      b = 3, \ \ \(\(and\ c\)\(=\)\(4\)\(\ \)\)\)]],
  ". The ellipsoid surface is at potential ",
  Cell[BoxData[
      \(TraditionalForm\`V\_o\)]],
  ". The ellipsoid  is filled with  a uniform negative charge of density ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Rho]\_o\)\)]],
  ".  Using the Galerkin method find the electrostatic potential inside the \
ellipsoid as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y, z)\)\)]],
  ". (Hint: the solution is a simple polynomial function of ",
  Cell[BoxData[
      \(TraditionalForm\`x, y, z\)]],
  ".)"
}], "Text"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " Use the Galerkin method to solve the following heat equation problem in \
1-D with inhomogeneous conductivity,  on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 1\)]],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 1/2\)]],
  ". Choose your own modes, and test to make sure you have kept enough modes. \
Plot the result as an animation:"
}], "Text"],

Cell[TextData[{
  "\t\t  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox["\[PartialD]", \(\[PartialD]x\),
              MultilineFunction->None], 
            RowBox[{"(", 
              RowBox[{\((4  x + 1)\), " ", 
                FractionBox["\[PartialD]", \(\[PartialD]x\),
                  MultilineFunction->None], \(T(x, t)\)}], ")"}]}], "=", 
          RowBox[{
            FractionBox["\[PartialD]", \(\[PartialD]t\),
              MultilineFunction->None], \(T(x, t)\)}]}], TraditionalForm]]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 1\)]],
  "\nwith\n\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`T(0, t)\  = \ 0, T(1, t) = 1, \)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, 0) = \ x\^6\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(6)",
    FontWeight->"Bold"],
  "  Solve the time-dependent (dimensionless) Schr\[ODoubleDot]dinger \
equation for the wave function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, t)\)]],
  " of a particle in a potential ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 1\)]],
  ", subject to boundary conditions ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](\(\[PlusMinus]a\), t) = 0\)]],
  " and initial condition  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, 0) = \(\[Psi]\_o\)(x)\)]],
  ":"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            FractionBox[\(\[PartialD]\(\[Psi](x, t)\)\), \(\[PartialD]t\),
              MultilineFunction->None]}], "=", 
          RowBox[{\(\(V(x)\)\ \(\[Psi](x, t)\)\), "-", 
            RowBox[{\(1\/2\), 
              
              FractionBox[\(\[PartialD]\^2\( \[Psi](x, 
                    t)\)\), \(\[PartialD]x\^2\),
                MultilineFunction->None]}]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "Take ",
  Cell[BoxData[
      \(TraditionalForm\`V(x) = x\^4/4\)]],
  ", use trigonometric functions for the modes in the Galerkin method, and \
work out the matrix elements of ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`V\_\(n\ m\)\)]],
  ", analytically for general ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ".  (Note: Check to make sure the integrals for ",
  Cell[BoxData[
      \(TraditionalForm\`V\_\(n\ n\)\)]],
  " are evaluated properly.) Take ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_o\)(x)\  = \ 
        exp[\(-2\) \((x - 1)\)\^2]\)]],
  ", and",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(a\  = \ 4\)\)\)]],
  ". Keep as many basis functions as necessary to obtain a converged answer. \
Plot the solution in time increments of 0.1 for ",
  Cell[BoxData[
      \(TraditionalForm\`0\  < t < 4\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(7)(a)",
    FontWeight->"Bold"],
  " Use the Galerkin method to solve for the dynamics of the string with the \
moving boundary condition, described in scaled coordinates by  Eq. ",
  ButtonBox["(5.2.64)",
    ButtonData:>{"Chapter5.nb", "(5.2.64)"},
    ButtonStyle->"Hyperlink"],
  ". Again take the case ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(L\_o = 1\ m\),
            "TraditionalForm"], ",", 
          FormBox[\(c = 300\ m/sec\),
            "TraditionalForm"], ",", 
          RowBox[{"and", 
            RowBox[{
              FormBox[\(v = 2\ m/sec\),
                "TraditionalForm"], "."}]}]}], TraditionalForm]]],
  "   For basis functions, use ",
  Cell[BoxData[
      \(TraditionalForm\`sin\ n\ \[Pi]\ x\&_\)]],
  ".   Plot ",
  Cell[BoxData[
      \(TraditionalForm\`y(x\&_ = 1/2, t)\)]],
  " and listen to the sound the string makes using the ",
  StyleBox["Play",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 0.45\ sec\)]],
  ". Compare the plot and the sound to the WKB solution, Eq. ",
  ButtonBox["(5.2.65)",
    ButtonData:>{"Chapter5.nb", "(5.2.65)"},
    ButtonStyle->"Hyperlink"],
  ".  (Hint: You will need to increase ",
  StyleBox["MaxSteps",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to around 5000. )"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Redo the problem , and make an animation of ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, t)\)]],
  ", for a case where the WKB solution fails :",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            RowBox[{\(L\_o\), "=", 
              RowBox[{"1", " ", 
                StyleBox["m",
                  FontSlant->"Plain"]}]}],
            "TraditionalForm"], ",", 
          FormBox[
            RowBox[{"c", "=", 
              RowBox[{"300", " ", 
                RowBox[{
                  StyleBox["m",
                    FontSlant->"Plain"], "/", 
                  StyleBox["s",
                    FontSlant->"Plain"]}]}]}],
            "TraditionalForm"], ",", 
          RowBox[{"and", 
            FormBox[
              RowBox[{"v", "=", 
                RowBox[{"200", " ", 
                  RowBox[{
                    StyleBox["m",
                      FontSlant->"Plain"], "/", 
                    StyleBox["s",
                      FontSlant->"Plain"]}]}]}],
              "TraditionalForm"]}]}], TraditionalForm]]],
  "  . Plot the solution over the time interval ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0", "<", "t", "<", 
          RowBox[{"0.0045", " ", 
            StyleBox["s",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Evaluate the energy variation of the string dynamics found in part (b), \
and use this to determine the force on the moving boundary vs. time."
}], "Text"],

Cell[TextData[{
  StyleBox["(8)",
    FontWeight->"Bold"],
  " A large sheet of cloth has an elliptical  shape given by ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2/a\^2 + y\^2/b\^2 = 1\)]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"a", "=", 
          RowBox[{"2", " ", 
            StyleBox["m",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"b", "=", 
          RowBox[{"1", " ", 
            StyleBox["m",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ".  The edge of the sheet is fixed at ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  ", and the propagation speed of waves on the sheet is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"c", "=", 
          RowBox[{"3", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ". Initially the sheet is flat and stationary, ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, y, 0) = \(\(z\& . \)(x, y, 0) = 0\)\)]],
  ". However, thanks to the acceleration of gravity ",
  Cell[BoxData[
      FormBox[
        RowBox[{"g", "=", 
          RowBox[{"9.8", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              SuperscriptBox[
                StyleBox["s",
                  FontSlant->"Plain"], "2"]}]}]}], TraditionalForm]]],
  ", the sheet begins to sag. The equation of motion for the sheet is the \
damped wave equation,"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\((\[PartialD]\^2\/\[PartialD]t\^2 + \ \[Gamma] \
\[PartialD]\/\[PartialD]t)\) \(z(x, y, 
            t)\) = \(c\^2\)\ [\[PartialD]\^2\/\[PartialD]x\^2 + \
\[PartialD]\^2\/\[PartialD]y\^2] \(z(x, y, t)\)\)]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = 10\ sec\^\(-1\)\)]],
  " due to air drag on the sheet.\n\tSolve for the dynamics of the sheet  \
using the Galerkin method, and plot the resulting motion as a series of ",
  StyleBox["ParametricPlot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics objects,   for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0", "<", "t", "<", 
          RowBox[{"1", " ", 
            StyleBox["s",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ".\t"
}], "Text"],

Cell[TextData[{
  StyleBox["(9)",
    FontWeight->"Bold"],
  " A circular wading pool of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a = 1\)]],
  "m has nonuniform depth, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(h(r, \[Theta])\)\(\ \)\(=\)\(\ \)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(h\_o\)(
        1 + 2 \( r\^\(\(2\)\(\ \)\)\) \(cos(
                2  \[Theta])\)/\((3\ a\^2)\)\ )\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`h\_o = 5\ cm\)]],
  " and coordinates are measured from the center of the pool.   \n\tAssuming \
potential flow, the horizontal fluid displacement vector can be expressed as  \
",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[Eta]",
            FontWeight->"Bold"], "=", \(\[Del]\(\[Phi](r, \[Theta], t)\)\)}], 
        TraditionalForm]]],
  ",  with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " satisfying the PDE"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(\[PartialD]\^2\), \(\[PartialD]t\^2\),
              MultilineFunction->None], "\[Phi]"}], 
          "=", \(\[Del]\(\(\[CenterDot]\)\(\(c\^2\)(r, \[Theta])\)\)\), 
          RowBox[{"\[Del]", 
            RowBox[{"\[Phi]", 
              StyleBox["(",
                FontWeight->"Plain"], 
              StyleBox[\(r, \[Theta], t\),
                FontWeight->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}]}]}], TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  "and where ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\^2\)(r, \[Theta])\  = \ 
        g\ \(h(r, \[Theta])\)\)]],
  " is the square of the wave speed. The wave height is ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(z(r, \[Theta], t)\), " ", "=", 
          RowBox[{
            RowBox[{\(-\[Del]\), "\[CenterDot]", 
              RowBox[{"[", 
                RowBox[{\(h(r, \[Theta])\), " ", 
                  StyleBox["\[Eta]",
                    FontWeight->"Bold"]}], "]"}]}], Cell[""]}]}], 
        TraditionalForm]]],
  ".  The boundary conditions are ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["\[Eta]",
                FontWeight->"Bold"], "\[CenterDot]", 
              StyleBox[
                OverscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "^"],
                FontWeight->"Bold"]}], \( | \_\(r = a\)\)}], "=", "0"}], 
        TraditionalForm]]],
  ". [See Eqs. ",
  ButtonBox["(4.2.50)",
    ButtonData:>{"Chapter4.nb", "(4.2.50)"},
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["(4.4.38)",
    ButtonData:>{"Chapter4.nb", "(4.4.38)"},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(4.4.39)",
    ButtonData:>{"Chapter4.nb", "(4.4.39)"},
    ButtonStyle->"Hyperlink"],
  " and the surrounding discussion.]"
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(a)",
    FontWeight->"Bold"],
  " We will use the Galerkin method to solve this problem. First, we must \
choose basis functions.  Show that functions of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_\(m\ n\)\)(
          r, \[Theta]) = \(\(\(r\^n\)(
            1 - b\_n\ r\^2)\) \(cos\)\(\ \)\(m\)\(\ \)\(\[Theta]\)\(\ \
\)\)\)]],
  " match the von Neumann  boundary conditions required at ",
  Cell[BoxData[
      \(TraditionalForm\`r = a\)]],
  ", provided that ",
  Cell[BoxData[
      \(TraditionalForm\`b\_n\)]],
  "is chosen properly. (Why don't we need ",
  Cell[BoxData[
      \(TraditionalForm\`sin\ m\ \[Theta]\)]],
  " basis functions?)"
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(b)",
    FontWeight->"Bold"],
  "  Boundary conditions at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  " must also be satisfied: the solution and its derivatives must be finite. \
By examining the form of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\)]],
  " in cylindrical coordinates, show that this leads to the requirement on \
the basis functions  that"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`lim\_\(r \[Rule] \ 0\)\((\[PartialD]v\_\(m\ n\)\/\
\[PartialD]r - \(m\^2\/r\) v\_\(m\ n\))\) = 0\)]],
  "."
}], "NumberedEquation",
  CellTags->{"i:37", "(6.1.37)"}],

Cell[TextData[{
  "Show that this equation implies that we must choose ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " in the range  ",
  Cell[BoxData[
      \(TraditionalForm\`n \[GreaterEqual] \ m\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Initially, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r, \[Theta], 
          0) = \(-\(\(J\_0\)(\(j\_\(1\ 1\)\) r/a)\)\)/10\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\& . \)(r, \[Theta], 0) = 0\)]],
  ". Find the wave motion and plot ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(z(r, \[Theta], t)\), Cell[""]}], TraditionalForm]]],
  "for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0", "<", "t", "<", 
          RowBox[{"3", " ", 
            StyleBox["s",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  "."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["6.2 Grid Methods", "Subtitle",
  CellTags->{"i:17", "c:13"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["6.2.1 Time-Dependent Problems", "Subsubtitle",
  CellTags->"c:14"],

Cell[CellGroupData[{

Cell["FTCS Method for the Heat Equation", "Section",
  CellTags->{"i:18", "c:15"}],

Cell[TextData[{
  "In Chapters ",
  ButtonBox["1",
    ButtonData:>{"Chapter1.nb", None},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["2",
    ButtonData:>{"Chapter2.nb", None},
    ButtonStyle->"Hyperlink"],
  ", we showed how  boundary- and initial-value ODE problems can be solved \
using grid methods, wherein the linear ODE is converted into a difference \
equation by discretizing the independent variable.  In this section, we apply \
analogous methods to partial differential equations. "
}], "Text"],

Cell[TextData[{
  "\tAs a first example of a grid method in the solution of a PDE, consider \
the heat equation in a slab running from ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < L\)]],
  ","
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\/\[PartialD]t\) \(T(x, 
            t)\) = \[Chi] \(\[PartialD]\^2\/\[PartialD]x\^2\) \(T(x, t)\) + 
          S(x, t)\)]],
  "."
}], "NE2",
  CellTags->"(6.2.1)"],

Cell[TextData[{
  "We solve for ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, t)\)]],
  " subject to the initial condition that ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, 0) = \(T\_o\)(x)\)]],
  " and the Dirichlet boundary conditions ",
  Cell[BoxData[
      \(TraditionalForm\`T(0, t) = \(T\_1\)(t)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`T(L, t) = \(T\_2\)(t)\)]],
  ". To solve this problem, we discretize both space and time, according to "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(t\_n\), "=", 
            RowBox[{"n", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}]}], ",", "  ", \(n = 0\), ",", 
          "1", ",", "2", ",", "...", ","}], TraditionalForm]]],
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(x\_j\), "=", 
            RowBox[{"j", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}]}], ",", " ", \(j = 0\), ",", 
          "1", ",", "2", ",", "...", ",", "M"}], TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(6.2.2)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], " "}], TraditionalForm]]],
  "is the stepsize in time, and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "=", \(L/M\)}], TraditionalForm]]],
  " is the stepsize in space.  We will solve Eq. ",
  ButtonBox["(6.2.1)",
    ButtonData:>"(6.2.1)",
    ButtonStyle->"Hyperlink"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(T(x, t)\)\(\ \)\)\)]],
  "only on this grid of points.  It is useful to introduce the notation ",
  Cell[BoxData[
      \(TraditionalForm\`T(x\_j, t\_n) = T\_j\%n\)]],
  " (subscripts refer to the spatial grid point, and superscripts refer to \
the time grid point)."
}], "Text"],

Cell[TextData[{
  "\t We must now discretize the space and time derivatives in Eq. ",
  ButtonBox["(6.2.1)",
    ButtonData:>"(6.2.1)",
    ButtonStyle->"Hyperlink"],
  ". There are many ways to do so, some better than others. To start with, we \
will discuss the FTCS method, where we use a forward-difference method for \
the time derivative and a centered-difference method for the space derivative \
(hence the name: forward time, centered space). That is, for the time \
derivative, we write"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          RowBox[{\(\(\[PartialD]T\/\[PartialD]t\) \((x\_j, t\_n)\)\), 
            "\[Rule]", 
            FractionBox[\(T(x\_j, t\_\(n + 1\)) - T(x\_j, t\_n)\), 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]]}], "=", 
          FractionBox[\(T\_j\%\(n + 1\) - T\_j\%n\), 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]], " "}], TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(6.2.3)"],

Cell["and for the space derivative, ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          RowBox[{\(\(\[PartialD]\^2 T\/\[PartialD]x\^2\) \((x\_j, t\_n)\)\), 
            "\[Rule]", 
            
            FractionBox[\(T(x\_\(j + 1\), t\_n) - 2 \( T(x\_j, t\_n)\) + 
                T(x\_\(j - 1\), t\_n)\), 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"]]}], "=", 
          FractionBox[\(T\_\(j + 1\)\%n - 2  T\_j\%n + T\_\(j - 1\)\%n\), 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], "2"]], " "}], 
        TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.4)"],

Cell[TextData[{
  "(See Sec. ",
  ButtonBox["2.4.5",
    ButtonData:>{"Chapter2.nb", "c:48"},
    ButtonStyle->"Hyperlink"],
  " for a discussion of finite-difference derivatives.) Substituting these \
expressions into Eq. ",
  ButtonBox["(6.2.1)",
    ButtonData:>"(6.2.1)",
    ButtonStyle->"Hyperlink"],
  ", we collect all terms on the ",
  "right-hand",
  " side except for the term involving ",
  Cell[BoxData[
      \(TraditionalForm\`T\_j\%\(n + 1\)\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\_j\%\(n + 1\)\), "=", 
          RowBox[{\(T\_j\%n\), "+", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], " ", \(S\_j\%n\)}], "+", 
            RowBox[{
              FractionBox[
                RowBox[{"\[Chi]", " ", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]]}], 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], "2"]], \((T\_\(j + 1\)\%n - 
                  2  T\_j\%n + T\_\(j - 1\)\%n)\)}]}]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.5)"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(6.2.5)",
    ButtonData:>"(6.2.5)",
    ButtonStyle->"Hyperlink"],
  " is a recursion relation that bears a distinct resemblance to Euler's \
method. If, at the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "'th time step, we know ",
  Cell[BoxData[
      \(TraditionalForm\`T\_j\%n\)]],
  " for all values of ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " on the spatial grid, then we can use Eq. ",
  ButtonBox["(6.2.5)",
    ButtonData:>"(6.2.5)",
    ButtonStyle->"Hyperlink"],
  " to determine ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " at the ",
  Cell[BoxData[
      \(TraditionalForm\`n + 1\)]],
  "'st ",
  "time step",
  " at each spatial gridpoint. The programming of this method in ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "is nearly as simple as for Euler's method. We refer to ",
  Cell[BoxData[
      \(TraditionalForm\`T\_j\%n\)]],
  " as the function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["T",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["j",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["n",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ", and write the recursion relation as"
}], "Text"],

Cell[BoxData[{
    \(\(\(Clear["\<Global`*\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(T[j_, n_]\  := \ \(T[j, n]\  = \ 
        T[j, n - 1] + \[CapitalDelta]t\ S[j, 
              n - 1]\  + \ \(\(\[Chi]\ \
\[CapitalDelta]t\)\/\[CapitalDelta]x\^2\) \((T[j + 1, n - 1]\  - 
                2  T[j, n - 1] + T[j - 1, n - 1])\)\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.52"],

Cell[TextData[{
  "Note the use of the double equality, in order to force ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to remember previously evaluated values of ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ", just as was done in Euler's method. \n\tHowever, Eq. ",
  ButtonBox["(6.2.5)",
    ButtonData:>"(6.2.5)",
    ButtonStyle->"Hyperlink"],
  " works ",
  StyleBox["only for the interior points",
    FontSlant->"Italic"],
  ". We cannot use it to determine ",
  Cell[BoxData[
      \(TraditionalForm\`T\_0\%n\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`T\_M\%n\)]],
  ", because the equation would require ",
  Cell[BoxData[
      \(TraditionalForm\`T\_\(-1\)\%n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`T\_\(M + 1\)\%n\)]],
  ", which are outside the range of the grid. Fortunately, these \
boundary-values can be specified by the boundary conditions ",
  Cell[BoxData[
      \(TraditionalForm\`T\_0\%n = \(T\_1\)(t\_n)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`T\_M\%n = \(T\_2\)(t\_n)\)]],
  " :"
}], "Text"],

Cell[BoxData[{
    \(\(T[0, n_]\  := \ T1[t] /. t \[Rule] n\ \[CapitalDelta]t;\)\), "\n", 
    \(M = 10; 
    T[M, n_]\  := \ T2[t] /. t \[Rule] n\ \[CapitalDelta]t\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.53"],

Cell["\<\
In grid methods, we determine the unknown function at the boundary \
points of the grid using the boundary conditions, and use the \
finite-differenced differential equation only at the interior points.\
\>", \
"Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell["\<\
In order to start the recursion, we must also specify the initial \
condition:\
\>", "Text"],

Cell[BoxData[
    \(T[j_, 0]\  := \ T0[x] /. x \[Rule] \ j\ \[CapitalDelta]x\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.54"],

Cell[TextData[{
  "To use this method, all we need do is choose ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ", and specify the source function ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  ", the initial and boundary conditions ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["T0",
            FontFamily->"Courier",
            FontWeight->"Bold"], ",", 
          StyleBox["T1",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["T2",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  StyleBox[" ",
    FontWeight->"Bold"],
  "respectively, ",
  " and the width ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " of the system and the thermal diffusivity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\)]],
  ".  We do so below for a specific case:"
}], "Text"],

Cell[BoxData[
    \(\(\(L = 1; \ \[Chi]\  = \ 1/4; \[CapitalDelta]t\  = \ 
      0.01; \[CapitalDelta]x\  = \ L/M; 
    S[j_, n_]\  = \ 0;\[IndentingNewLine]\[IndentingNewLine]
    \(T0[x_]\  = \ \(x\^2\) \((1 - x)\);\)\[IndentingNewLine]
    T1[t_]\  = \ t/\((1 + 3  t)\); T2[t_]\  = \ 0;\)\(\ \)\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.55"],

Cell[TextData[{
  "We now make a table of plots of the solution, evaluated at different \
times, as shown in Cell ",
  ButtonBox["6.56",
    ButtonData:>"Cell 6.56",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        ListPlot[Table[{\[CapitalDelta]x\ j, \ T[j, n]}, {j, 0, M}], 
          PlotJoined \[Rule] True, PlotRange \[Rule] {0,  .4}, 
          AxesLabel \[Rule] {"\<x\>", "\<\>"}, 
          PlotLabel \[Rule] "\<T[x,t],t=\>" <> 
              ToString[\[CapitalDelta]t\ n]], {n, 0, 200, 10}];\)\)], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 6.56"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -32 0 ]
[.5 .63053 32 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.11905 .01391 L
.21429 .04944 L
.30952 .09734 L
.40476 .14833 L
.5 .19314 L
.59524 .22249 L
.69048 .22713 L
.78571 .19777 L
.88095 .12515 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00;ooooo1ol00002ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool04?ooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`009_ooool00ol0003oooooooooo`09oooo
o`Oo00009oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0fooooo`;o00004Oooool2o`0000;ooooo0_l00009oooo
o`009_ooool00ol0003oooooooooo`0@ooooo`Oo0000ooooool6ooooo`03o`000?oooooooooo023o
oooo000Vooooo`03o`000?oooooooooo01Oooooo1Ol0003oooooo`03o`000?oooooooooo027ooooo
000Vooooo`;o00007Oooool3o`000?cooooo00?o0000ooooooooool08Oooool002Kooooo00?o0000
ooooooooool07oooool3o`000?Sooooo00?o0000ooooooooool08_ooool002Kooooo00?o0000oooo
ooooool08_ooool2o`000?Gooooo00?o0000ooooooooool08oooool002Kooooo00?o0000oooooooo
ool09?ooool3o`000?7ooooo00?o0000ooooooooool09?ooool002Kooooo00?o0000ooooooooool0
9oooool3o`000>kooooo00?o0000ooooooooool09?ooool002Kooooo0_l0000[ooooo`;o0000jooo
ool00ol0003oooooooooo`0Uooooo`009_ooool00ol0003oooooooooo`0/ooooo`?o0000ioooool0
0ol0003oooooooooo`0Vooooo`009_ooool00ol0003oooooooooo`0_ooooo`;o0000i?ooool00ol0
003oooooooooo`0Wooooo`009_ooool00ol0003oooooooooo`0aooooo`?o0000h?ooool00ol0003o
ooooooooo`0Xooooo`009_ooool2o`0003Gooooo0ol0003Mooooo`03o`000?oooooooooo02Sooooo
000Vooooo`03o`000?oooooooooo03Oooooo0_l0003Jooooo`03o`000?oooooooooo02Wooooo000V
ooooo`03o`000?oooooooooo03Wooooo0_l0003Gooooo`03o`000?oooooooooo02[ooooo000Voooo
o`03o`000?oooooooooo03_ooooo0_l0003Dooooo`03o`000?oooooooooo02_ooooo000Vooooo`03
o`000?oooooooooo03gooooo0_l0003Booooo`03o`000?oooooooooo02_ooooo000Vooooo`;o0000
@?ooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo02cooooo000Vooooo`03o`000?oo
oooooooo043ooooo0_l0003=ooooo`03o`000?oooooooooo02gooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`12ooooo`;o0000b_ooool00ol0003o
ooooooooo`0^ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
04Cooooo0_l00038ooooo`03o`000?oooooooooo02kooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`16ooooo`;o0000aOooool00ol0003oooooooooo`0_ooooo`000oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000007ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol00018ooooo`;o0000`_ooool00ol0003oooooooooo`0`ooooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1:ooooo`;o0000_oooool00ol0003o
ooooooooo`0aooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooo
oooooooooa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0C?ooool00ol0
003oooooooooo`2looooo`03o`000?oooooooooo037ooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1=ooooo`;o0000^oooool00ol0003oooooooooo`0booooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co00001_oo
ool2o`00053ooooo0_l0002hooooo`03o`000?oooooooooo03?ooooo000Vooooo`03o`000?oooooo
oooo057ooooo0_l0002eooooo`03o`000?oooooooooo03Cooooo000Vooooo`03o`000?oooooooooo
05?ooooo0_l0002booooo`03o`000?oooooooooo03Gooooo000Vooooo`03o`000?oooooooooo05Go
oooo0_l0002`ooooo`03o`000?oooooooooo03Gooooo000Vooooo`03o`000?oooooooooo05Oooooo
0_l0002]ooooo`03o`000?oooooooooo03Kooooo000Vooooo`;o0000F_ooool2o`000:[ooooo00?o
0000ooooooooool0=oooool002Kooooo00?o0000ooooooooool0Foooool2o`000:Oooooo00?o0000
ooooooooool0>?ooool002Kooooo00?o0000ooooooooool0GOooool2o`000:Gooooo00?o0000oooo
ooooool0>?ooool002Kooooo00?o0000ooooooooool0Goooool2o`000:;ooooo00?o0000oooooooo
ool0>Oooool002Kooooo00?o0000ooooooooool0HOooool2o`0009oooooo00?o0000ooooooooool0
>_ooool002Kooooo0_l0001Tooooo`03o`000?oooooooooo09[ooooo0_l0000mooooo`009_ooool0
0ol0003oooooooooo`1Tooooo`;o0000VOooool00ol0003oooooooooo`0mooooo`009_ooool00ol0
003oooooooooo`1Vooooo`;o0000U_ooool00ol0003oooooooooo`0nooooo`009_ooool00ol0003o
ooooooooo`1Xooooo`;o0000T_ooool2o`00047ooooo000Vooooo`;o0000Joooool2o`0008oooooo
00?o0000ooooooooool0@Oooool002Kooooo00?o0000ooooooooool0K?ooool2o`0008cooooo00?o
0000ooooooooool0@_ooool002Kooooo00?o0000ooooooooool0K_ooool2o`0008Sooooo0_l00015
ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooooooo`1`ooooo`;o0000QOooool00ol0003oooooooooo`15
ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0L_ooool2o`0008;ooooo00?o0000ooooooooool0A_ooool0
00_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo0ol0001d
ooooo`;o0000O_ooool2o`0004Wooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo07Kooooo0_l0001kooooo`03o`000?oooooo
oooo04Wooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo07Sooooo0_l0001hooooo`03o`000?oooooooooo04[ooooo000;oooo
o`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo07[ooooo0_l0001eooooo`03o`000?oooooooooo04_ooooo000;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07cooooo0_l0001a
ooooo`;o0000C_ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo
000000Oooooo0_l0001oooooo`?o0000KOooool00ol0003oooooooooo`1>ooooo`009_ooool00ol0
003oooooooooo`21ooooo`;o0000J_ooool00ol0003oooooooooo`1?ooooo`009_ooool00ol0003o
ooooooooo`23ooooo`;o0000I_ooool2o`0005;ooooo000Vooooo`03o`000?oooooooooo08Gooooo
0_l0001Sooooo`03o`000?oooooooooo05;ooooo000Vooooo`;o0000R?ooool2o`00063ooooo00?o
0000ooooooooool0Doooool002Kooooo00?o0000ooooooooool0ROooool2o`0005cooooo0_l0001F
ooooo`009_ooool00ol0003oooooooooo`2;ooooo`;o0000FOooool00ol0003oooooooooo`1Foooo
o`009_ooool00ol0003oooooooooo`2=ooooo`?o0000EOooool00ol0003oooooooooo`1Gooooo`00
9_ooool00ol0003oooooooooo`2@ooooo`?o0000Coooool3o`0005[ooooo000Vooooo`;o0000U?oo
ool3o`0004Wooooo0ol0001Mooooo`009_ooool00ol0003oooooooooo`2Fooooo`?o0000@oooool3
o`00063ooooo000Vooooo`03o`000?oooooooooo09Wooooo1?l0000looooo`?o0000Hoooool002Ko
oooo00?o0000ooooooooool0WOooool3o`0003Gooooo1?l0001Vooooo`009_ooool00ol0003ooooo
ooooo`2Pooooo`?o0000;oooool3o`0006[ooooo000Vooooo`;o0000Y?ooool3o`0002Wooooo0ol0
001]ooooo`009_ooool00ol0003oooooooooo`2Vooooo`?o00008oooool3o`00073ooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000001Ol@413ooooooooooooo
ooooA4A400;o000000?o<S8bomgMgOooool01?ooool00ol0003oooooooooo`2Yoooooa7o00003ooo
ool3o`0007?ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;[ooooo3ol0
001fooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`03ooooo`?o0000oooooom0ooooo`000oooool01Ol0003ooooooooooooo
oooo000000kooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo
@?ooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
00?oEEEEofIVI_l000001Oooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo
0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000
ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol00006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooooooo
ool0oooooom0ooooo`002oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h01oooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooom0ooooo`002oooool01Ol0003ooooo
oooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood3o
oooo000;ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000
ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003o
oooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@?ooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00?ooooo0ol0003ooooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooo
oom0ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom0ooooo`000ooo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@?ooool0
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[Zjoooooomg
MgOo<S8b00Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood3ooooo000;
ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000oooo
oom0ooooo`002oooool01Ol0003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01_oo
ool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@
o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo
@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0003o
oooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`06
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol0
003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooooooo
oooo410@00kooooo00?o^[Zjob4Q8Oooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nH
V9SooooookZj^_l000001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT01?ooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003o
ooooooooo`3ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4Co
gMgMooooool00007ooooo`?o0000oooooom0ooooo`002oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOoooooo0000oooooom:ooooo`002oooool01Ol@413ooooooooooooooooo
410@00cooooo00?oMgMgolc<c?l00000oooooom:ooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?ok^k^odA4A?l00000oooooom:ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00gooooo00?oMgMgo`000?ooool0oooooom9ooooo`00oooooomYooooo`00W?ooool2o`0000_o
oooo00?o0000okZj^_ooool03?ooool2o`0000Kooooo00?o0000okZj^_ooool0YOooool009cooooo
00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool01?ooool2oc8b<ZKooooo
002Booooo`05oa0@4?l0003o0000o`000?l@41001Oooool00ol0003oooooooooo`02ooooo`;o0000
0_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00?o
oooo00?o0000ooooooooool01?ooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4
A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08kooooo002Dooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?o
c<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000ooooooooool0
1?ooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool6o`000006
oooooomgMgOoV9RHoooooonHV9SoMgMgS_ooool009Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go410@oooooooooooooooooa0@
402>ooooo`00U?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Cok^k^
ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01?ooool6o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool0S?oo
ool009Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04ob4Q8OmgMgOo
MgMgoc8b<P_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00Go0000ooooooooooooooooo`00002>ooooo`00TOooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo
0_l00008ooooo`03oa0@4?l0003o000000?o00001?ooool00ol0003oooooooooo`09ooooo`03oa0@
4?l0003o000000?o00002_ooool01Ol@413ooooooooooooooooo410@08kooooo002Aooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0S_ooool0097ooooo1ol00004ooooo`;o00004oooool00ol0003o
ooooooooo`04ooooo`;o00003Oooool00ol0003oooooooooo`0;ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h0S_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .11885 m
.11905 .09012 L
.21429 .09029 L
.30952 .10881 L
.40476 .13415 L
.5 .15547 L
.59524 .16361 L
.69048 .15207 L
.78571 .11826 L
.88095 .06489 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooo`00000Boooo
o`04ob4Q8OmgMgOoMgMgoc8b<P[ooooo000Vooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool0<oooool2o`0000;ooooo00?o0000ooooooooool03oooool2o`0000;ooooo0_l00009oooo
o`009_ooool00ol0003oooooooooo`3ooooooa[ooooo00?o0000ooooooooool08oooool002Kooooo
00?o0000ooooooooool0oooooolHooooo`;o00009_ooool002Kooooo0_l0003ooooooaSooooo00?o
0000ooooooooool09_ooool002Kooooo00?o0000ooooooooool0oooooolFooooo`03o`000?oooooo
oooo02Oooooo000Vooooo`03o`000?oooooooooo0?oooooo5?ooool2o`0002[ooooo000Vooooo`03
o`000?oooooooooo0?oooooo4oooool00ol0003oooooooooo`0Zooooo`009_ooool00ol0003ooooo
ooooo`3ooooooa7ooooo0_l0000]ooooo`009_ooool2o`000?oooooo4Oooool00ol0003ooooooooo
o`0]ooooo`009_ooool00ol0003oooooooooo`3oooooo`kooooo0_l0000`ooooo`009_ooool00ol0
003oooooooooo`3oooooo`gooooo00?o0000ooooooooool0<?ooool002Kooooo00?o0000oooooooo
ool0ooooool;ooooo`;o0000<oooool002Kooooo0_l0003oooooo`_ooooo00?o0000ooooooooool0
<oooool002Kooooo00?o0000ooooooooool0ooooool9ooooo`03o`000?oooooooooo03Cooooo000V
ooooo`03o`000?oooooooooo0?oooooo1oooool2o`0003Oooooo000Vooooo`03o`000?oooooooooo
0?oooooo1_ooool00ol0003oooooooooo`0gooooo`009_ooool00ol0003oooooooooo`3oooooo`Co
oooo0_l0000jooooo`009_ooool2o`000?oooooo1?ooool00ol0003oooooooooo`0jooooo`009_oo
ool00ol0003oooooooooo`3oooooo`7ooooo0_l0000mooooo`000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0o_ooool2o`0003oooooo0003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0o?ooool2o`00047ooooo0003ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`3kooooo`03o`000?oooooooooo047ooooo0003oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000Oooooo00?o
MgMgoc8b<_ooool01?ooool3o`000?Wooooo0_l00014ooooo`000oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`3gooooo`;o0000A_ooool000?ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41001?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0?Gooooo0_l00018ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0loooool2o`0004[ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l00006ooooo`;o00006OoooolSo`000;Oooooo00?o
0000ooooooooool0B_ooool002Kooooo00?o0000ooooooooool05Oooool3o`0002?ooooo1Ol0002`
ooooo`;o0000COooool002Kooooo00?o0000ooooooooool04Oooool4o`0002_ooooo1_l0002Xoooo
o`;o0000Coooool002Kooooo00?o0000ooooooooool03Oooool4o`0003Gooooo1_l0002Pooooo`;o
0000DOooool002Kooooo00?o0000ooooooooool02_ooool3o`0003oooooo1Ol0002Iooooo`;o0000
Doooool002Kooooo0_l00007ooooo`Co0000Aoooool5o`0009?ooooo00?o0000ooooooooool0Dooo
ool002Kooooo00?o0000ooooooooool00_ooool4o`00053ooooo0ol0002>ooooo`;o0000E_ooool0
02Kooooo00?o0000ooooool000000_l0001Gooooo`Co0000R?ooool2o`0005Sooooo000Vooooo`;o
0000G_ooool4o`0008;ooooo0_l0001Jooooo`009_ooool00ol0003oooooooooo`1Qooooo`?o0000
O?ooool3o`0005cooooo000Vooooo`;o0000IOooool4o`0007Gooooo0ol0001Oooooo`009_ooool0
0ol0003oooooooooo`1Xooooo`Co0000K_ooool3o`0006;ooooo000Vooooo`03o`000?oooooooooo
06cooooo0ol0001Xooooo`?o0000IOooool002Kooooo00?o0000ooooooooool0Koooool4o`00067o
oooo0ol0001Xooooo`009_ooool2o`0007Cooooo1Ol0001Iooooo`?o0000Joooool002Kooooo00?o
0000ooooooooool0N?ooool5o`00057ooooo0ol0001^ooooo`009_ooool00ol0003oooooooooo`1m
ooooo`Go0000BOooool3o`00077ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo08;ooooo1Ol00011
ooooo`?o0000M?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Oooooo1Ol0000gooooo`Go0000Moooool0
00_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo0ol0002<
ooooo`Oo0000:Oooool7o`0007cooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo09?ooooo2_l0000Hooooo`Oo0000Poooool0
00_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0WOooool9o`0000Sooooo1ol0002:ooooo`002oooool01Ol@413ooooooooooooooooo
410@00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Vooooo`So0000TOooool0
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0oooooom0ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEE
ofIVI_l000001oooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000V
ooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000005oa0@4?oooooo
oooooooooom4A4@00_l000000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool0
1Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`03ooooo`?o0000oooooom0ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go
410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l00000
1Oooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?oo
ool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooo
od3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo
000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0
ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?oo
ool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooo
od3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo
000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`00
0?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom0ooooo`00
2oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003o
ooooooooo`3ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So
8B4Qonk^kP06ooooo`?o0000oooooom0ooooo`002oooool01Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@
4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oo
oooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom0
ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`00
9_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?oo
ool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo
000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`00
9_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?oo
ool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0
003ooooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooo
od7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1
ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooo
od3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@
4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o
0000ooooooooool0oooooom0ooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05o`000?oooooo
ooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000oooooom0ooooo`002oooool0
1Ol0003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01_ooool00ol0003ooooooooo
o`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qoooo
o`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooood3ooooo
000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Ko
oooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0003ooooood3ooooo0003oooo
o`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`06ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol0003ooooooooooooooooo
000000gooooo00?o410@o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o
^[Zjob4Q8Oooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l00000
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01?ooool4o`0000Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003o
ooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo
00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`3ooooood3o
oooo000;ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007oooo
o`?o0000oooooom0ooooo`002oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEE
EOoooooo0000oooooom:ooooo`002oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMg
olc<c?l00000oooooom:ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l00000oooooom:ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMg
o`000?ooool0oooooom9ooooo`00oooooomYooooo`00UOooool2o`0000_ooooo00?o0000okZj^_oo
ool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0[Oooool009Gooooo00?o0000ooooooooool0
2_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<Zkooooo002:ooooo`05oa0@4?l0
003o0000o`000?l@41001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03
ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo
00?ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00Wooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo08;ooooo002<
ooooo`03o`000?oooooooooo00Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0
003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool0
0ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko410@okZj^_o^k^koMgMgoa0@
4?ooool6o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003o
ooooooooo`24ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo
00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000oooo
ooooool0Q?ooool008cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04
onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00?ooooo1_l00002ooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`24ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000kooooo00?o
0000ooooooooool0Q?ooool008Wooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l00000
0ol00005ooooo`03o`000?oooooooooo00Wooooo00?o410@o`000?l000000ol0000:ooooo`05oa0@
4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`24ooooo`00ROooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool0Q?ooool008Wooooo1ol00005ooooo`;o
00004_ooool00ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003oooooooooo`0;ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000026ooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .19314 m
.11905 .15245 L
.21429 .1323 L
.30952 .12681 L
.40476 .1286 L
.5 .13012 L
.59524 .12503 L
.69048 .10922 L
.78571 .08148 L
.88095 .04363 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool2o`000003ooooool0003ooooo
017ooooo00Co8B4QogMgMomgMgOo<S8b2_ooool002Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0aooooo`?o00000oooool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`00
00Wooooo000Vooooo`03o`000?oooooooooo0?oooooo5oooool2o`0002Oooooo000Vooooo`03o`00
0?oooooooooo0?oooooo5Oooool2o`0002Wooooo000Vooooo`;o0000oooooolDooooo`;o0000:ooo
ool002Kooooo00?o0000ooooooooool0ooooool@ooooo`?o0000;Oooool002Kooooo00?o0000oooo
ooooool0ooooool>ooooo`;o0000<?ooool002Kooooo00?o0000ooooooooool0ooooool<ooooo`;o
0000<_ooool002Kooooo00?o0000ooooooooool0ooooool:ooooo`;o0000=?ooool002Kooooo0_l0
003oooooo`Wooooo0_l0000fooooo`009_ooool00ol0003oooooooooo`3oooooo`Gooooo0ol0000h
ooooo`009_ooool00ol0003oooooooooo`3oooooo`?ooooo0_l0000kooooo`009_ooool00ol0003o
ooooooooo`3oooooo`7ooooo0_l0000mooooo`009_ooool2o`000?kooooo0ol0000oooooo`009_oo
ool00ol0003oooooooooo`3kooooo`;o0000@_ooool002Kooooo00?o0000ooooooooool0nOooool2
o`0004Cooooo000Vooooo`03o`000?oooooooooo0?Kooooo0ol00016ooooo`009_ooool00ol0003o
ooooooooo`3dooooo`;o0000BOooool002Kooooo0_l0003booooo`?o0000Boooool002Kooooo00?o
0000ooooooooool0koooool2o`0004kooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`3/ooooo`?o0000D?ooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3Zooooo`;o0000Doooool000?ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo0>Sooooo0_l0001Eooooo`000oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go0000ooooooooooooooooo`000007ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
003Uooooo`?o0000Eoooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0h_ooool3o`0005[ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o
oooooooooooooooo410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3Ooooo
o`?o0000GOooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=_ooooo1?l0001P
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP04ooooo`Co00001_ooool2o`000=Sooooo1?l0001Tooooo`009_ooool00ol0003oooooooooo`3D
ooooo`?o0000J?ooool002Kooooo00?o0000ooooooooool0d?ooool4o`0006_ooooo000Vooooo`03
o`000?oooooooooo0<cooooo1?l0001_ooooo`009_ooool00ol0003oooooooooo`39ooooo`?o0000
Loooool002Kooooo0_l00035ooooo`Go0000M_ooool002Kooooo00?o0000ooooooooool0__ooool6
o`0007_ooooo000Vooooo`03o`000?oooooooooo0;Sooooo1_l00021ooooo`009_ooool00ol0003o
ooooooooo`2cooooo`Go0000Qoooool002Kooooo00?o0000ooooooooool0[Oooool6o`0008cooooo
000Vooooo`;o0000Y?ooool:o`0009;ooooo000Vooooo`03o`000?oooooooooo04Gooooo>ol0000D
ooooo`oo0000W?ooool002Kooooo00?o0000ooooooooool0=Oooool@o`0003_ooooo5?l0002[oooo
o`009_ooool00ol0003oooooooooo`0`ooooo`Go0000ooooool;ooooo`009_ooool2o`0002cooooo
1Ol0003ooooooa3ooooo000Vooooo`03o`000?oooooooooo02Kooooo1Ol0003ooooooaGooooo000V
ooooo`03o`000?oooooooooo027ooooo1Ol0003ooooooa[ooooo000;ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo01cooooo1Ol0003ooooooaoooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`?o0000oooooolT
ooooo`002oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool3
o`0001Oooooo0_l0003oooooobOooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo0ol0003oooooobWooooo000;oooo
o`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01;ooooo0_l0003oooooobcooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo0_l0003oooooobkooooo000;oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00kooooo0_l0003ooooooc3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool0
0omEEEGoIVIVo`000007ooooo`;o00003?ooool3o`000?oooooo<_ooool002Kooooo00?o0000oooo
ooooool02Oooool2o`000?oooooo=Oooool002Kooooo00?o0000ooooooooool01oooool2o`000?oo
oooo=oooool002Kooooo00?o0000ooooooooool01Oooool2o`000?oooooo>Oooool002Kooooo0_l0
0004ooooo`;o0000oooooolkooooo`009_ooool00ol0003oooooooooo`03o`000?oooooo?Oooool0
02Kooooo0ol0003ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000
ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000Go410@ooooooooooooooooodA4
A002o`000003oc8b<_oMgMgooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0ol0
003ooooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool0
1Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood3ooooo
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000005ooooo`Co0000
1_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`00
9_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0
oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?oo
oooo@?ooool000_ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Ko
oooo0ol0003ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`00
2oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006oooo
o`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2
o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003o
ooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2
o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000?oooooo@?oo
ool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom0ooooo`00
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`00
9_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?oo
ool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Ko
oooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo
000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`00
9_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?oo
ool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000_o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;o
c<c<00Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003ooooooooo
o`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ojVYZOl@413ooooo00Gooooo0ol0003ooooood3ooooo000;ooooo`05o`000?oooooo
ooooooooool000003Oooool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o
0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003o
ooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oo
oooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRH
V?l@413o0000oc8b<_o<c<`01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oa0@4?nj^[[oooooogMgMolb<S801oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0?oooooo@?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00oooool3o`000?oooooo@?ooool000?ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3ooooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003Oooool0
0ol@413o0000okZj^P04ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`3ooooood3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qoooo
o`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom0ooooo`000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000004ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@04ooooo`Co00001_ooool2o`000?oo
oooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooo
od7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Ol@413ooooo
oooooooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0003ooooo
od3ooooo000;ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0003o
oooood[ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00003o
oooood[ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00003o
oooood[ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`3o
ooooodWooooo003oooooofWooooo002Eooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o
00001Oooool00ol0003o^[Zjooooo`2]ooooo`00UOooool00ol0003oooooooooo`0:ooooo`;o<S8b
3_ooool00ol0003oooooooooo`03ooooo`;o<S8b[_ooool008[ooooo00Go410@o`000?l0003o0000
oa0@4006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj
^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7
QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000QOooool008cooooo00?o0000ooooooooool01_ooool0
2_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@
00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<
o`000?l@41001Oooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00000_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0QOooool008co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@olc<
c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^08Kooooo002<oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03
ooooo`Ko00000_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0QOoo
ool008cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOo
MgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo08Cooooo
0029ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool01?l0003ooooo
ooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003o
ooooooooo`09ooooo`03oa0@4?l0003o000000?o00002_ooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool0Poooool008Wooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooooiRHV?l@4100QOooool008Wooooo1ol00005ooooo`;o00004_ooool0
0ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003oooooooooo`0;ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<08Gooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24396 m
.11905 .19701 L
.21429 .16506 L
.30952 .14452 L
.40476 .13082 L
.5 .11916 L
.59524 .10543 L
.69048 .08683 L
.78571 .06233 L
.88095 .03266 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool3o`000003ooooool0003ooooo
017ooooo00Co8B4QogMgMomgMgOo<S8b2_ooool002Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0`ooooo`?o00001?ooool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`00
00Wooooo000Vooooo`03o`000?oooooooooo0?oooooo5Oooool3o`0002Sooooo000Vooooo`03o`00
0?oooooooooo0?oooooo4_ooool3o`0002_ooooo000Vooooo`;o0000ooooool@ooooo`?o0000;_oo
ool002Kooooo00?o0000ooooooooool0ooooool<ooooo`?o0000<Oooool002Kooooo00?o0000oooo
ooooool0ooooool9ooooo`?o0000=?ooool002Kooooo00?o0000ooooooooool0ooooool6ooooo`?o
0000=oooool002Kooooo00?o0000ooooooooool0ooooool3ooooo`?o0000>_ooool002Kooooo0_l0
003oooooo`7ooooo0ol0000mooooo`009_ooool00ol0003oooooooooo`3looooo`?o0000@?ooool0
02Kooooo00?o0000ooooooooool0nOooool3o`0004?ooooo000Vooooo`03o`000?oooooooooo0?Ko
oooo0ol00016ooooo`009_ooool2o`000??ooooo1?l00019ooooo`009_ooool00ol0003ooooooooo
o`3_ooooo`?o0000COooool002Kooooo00?o0000ooooooooool0k?ooool3o`00053ooooo000Voooo
o`03o`000?oooooooooo0>Wooooo0ol0001Cooooo`009_ooool00ol0003oooooooooo`3Vooooo`?o
0000E_ooool002Kooooo0_l0003Sooooo`Co0000FOooool002Kooooo00?o0000ooooooooool0gooo
ool3o`0005gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`3Kooooo`Co0000H?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3Gooooo`Co0000I?ooool000?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0=Cooooo0ol0001Xooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000
ooooooooooooooooo`000007ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003@ooooo`Co0000Jooo
ool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0c?ooool4o`0006oo
oooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`39ooooo`?o0000Loooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0<Cooooo1Ol0001fooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co00001_oo
ool2o`000;oooooo1_l0001kooooo`009_ooool00ol0003oooooooooo`2hooooo`Ko0000POooool0
02Kooooo00?o0000ooooooooool0/oooool5o`0008Oooooo000Vooooo`03o`000?oooooooooo0:go
oooo1_l0002<ooooo`009_ooool00ol0003oooooooooo`2Vooooo`Oo0000T_ooool002Kooooo0_l0
002Pooooo`Oo0000VOooool002Kooooo00?o0000ooooooooool0V?ooool7o`000:3ooooo000Voooo
o`03o`000?oooooooooo097ooooo1ol0002Wooooo`009_ooool00ol0003oooooooooo`29ooooo`So
0000[_ooool002Kooooo00?o0000ooooooooool0P_ooool7o`000;Kooooo000Vooooo`;o0000O?oo
ool7o`000;gooooo000Vooooo`03o`000?oooooooooo07Cooooo1ol00034ooooo`009_ooool00ol0
003oooooooooo`1/ooooo`So0000boooool002Kooooo00?o0000ooooooooool0IOooool7o`000=?o
oooo000Vooooo`;o0000Goooool7o`000=[ooooo000Vooooo`03o`000?oooooooooo05Oooooo1ol0
003Qooooo`009_ooool00ol0003oooooooooo`1Aooooo`Ko0000j?ooool000_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0C?ooool5o`000>kooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`17ooooo`Go0000loooool0
00_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo0ol00013
ooooo`Co0000n?ooool000_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0?_ooool5o`000?cooooo000;ooooo`05o`000?oooooooooo
ooooool000003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Wooooo1Ol0003o
ooooo`;ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo03Kooooo0ol0003oooooo`Oooooo000;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03?ooooo0ol0003o
ooooo`[ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000007
ooooo`;o0000<Oooool3o`000?oooooo3Oooool002Kooooo00?o0000ooooooooool0;Oooool3o`00
0?oooooo4?ooool002Kooooo00?o0000ooooooooool0:_ooool3o`000?oooooo4oooool002Kooooo
00?o0000ooooooooool09oooool3o`000?oooooo5_ooool002Kooooo0_l0000Uooooo`?o0000oooo
oolIooooo`009_ooool00ol0003oooooooooo`0Qooooo`?o0000oooooolLooooo`009_ooool00ol0
003oooooooooo`0Nooooo`?o0000oooooolOooooo`009_ooool00ol0003oooooooooo`0Kooooo`?o
0000oooooolRooooo`009_ooool00ol0003oooooooooo`0Iooooo`;o0000oooooolUooooo`009_oo
ool2o`0001Sooooo0_l0003oooooobOooooo000Vooooo`03o`000?oooooooooo01Gooooo0_l0003o
ooooobWooooo000Vooooo`03o`000?oooooooooo01?ooooo0_l0003oooooob_ooooo000Vooooo`03
o`000?oooooooooo017ooooo0_l0003oooooobgooooo000Vooooo`03o`000?oooooooooo00oooooo
0_l0003ooooooboooooo000Vooooo`;o00003_ooool2o`000?oooooo<Oooool002Kooooo00?o0000
ooooooooool02_ooool3o`000?oooooo<oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb<S;ogMgMoooo
o`04ooooo`03o`000?oooooooooo00Sooooo0_l0003oooooocKooooo0003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01_ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo00Kooooo0_l0003oooooocSooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0ol0
0004ooooo`;o0000ooooooljooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0
003ooooooccooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooooooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`02o`000?oooooo
?_ooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool3o`000?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3ooooood3ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIV
o`000005ooooo`Co00001_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo
@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo
00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3ooooood3o
oooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool0
00003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0oooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool3o`000?oooooo@?ooool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo@Oooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`00
0?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003o
oooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnH
V9So410@o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_oo
ool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Gooooo0ol0003ooooood3ooooo000;
ooooo`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj^P06ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03okZj^_lQ
8B7ooooo00Gooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?oooooo
@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT01_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0oooo
o`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool3o`000?oooooo@?ooool0
00?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Kooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05o`000?oooooooooo
ooooool000003Oooool00ol@413o0000okZj^P04ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onj^[[o8B4Qooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zj
o`000004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom0ooooo`000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@04ooooo`Co
00001_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom0ooooo`00
2oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo0?oo
oooo@?ooool000_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`00
00Oooooo0ol0003ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000002oooool01?oM
gMgoEEEEooooool0003ooooood[ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0omgMgOoc<c<o`00003ooooood[ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0oo^k^koA4A4o`00003ooooood[ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`3oooooodWooooo003oooooofWooooo002Eooooo`;o00002oooool00ol0003o
^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2]ooooo`00UOooool00ol0003ooooo
ooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b[_ooool008[ooooo00Go
410@o`000?l0003o0000oa0@4006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?o
oooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000oooo
ooooool00oooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`0
QOooool008cooooo00?o0000ooooooooool01_ooool02_l0003oooooooooooooooook^k^ob4Q8On7
QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@
4004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Oooool01_l@413o^[Zjonk^
k_mgMgOo410@ooooo`Ko00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oa0@4?nj^[[oooooogMgMolb<S80QOooool008cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo08?ooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`Ko00000_ooool01Ol0003ooooooooo
oooooooo000000kooooo00?oZJVYoa0@4?ooool0Q?ooool008cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oa0@4?l0003o^[Zj08Gooooo0029ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008oooo
o`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`09ooooo`03oa0@4?l0003o0000
00?o00002_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q8Oooool0Q?ooool0
08Wooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l00000
QOooool008Wooooo1ol00005ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o00003Ooo
ool00ol0003oooooooooo`0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@
o`000?l@413oZJVY08Gooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .28092 m
.11905 .23023 L
.21429 .19102 L
.30952 .16108 L
.40476 .13751 L
.5 .11724 L
.59524 .09754 L
.69048 .07643 L
.78571 .05295 L
.88095 .02717 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool3o`0000;ooooo00?o0000oooo
ooooool04?ooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`009_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo02kooooo1?l00005ooooo`03o`000?oooooooooo00oooooo0_l00002oooo
o`;o00002Oooool002Kooooo00?o0000ooooooooool0oooooolBooooo`Co0000:_ooool002Kooooo
00?o0000ooooooooool0ooooool?ooooo`?o0000;_ooool002Kooooo0_l0003oooooo`cooooo1?l0
000aooooo`009_ooool00ol0003oooooooooo`3oooooo`Oooooo1?l0000eooooo`009_ooool00ol0
003oooooooooo`3oooooo`Cooooo0ol0000iooooo`009_ooool00ol0003oooooooooo`3oooooo`Co
0000??ooool002Kooooo00?o0000ooooooooool0o?ooool3o`00043ooooo000Vooooo`;o0000nOoo
ool4o`0004?ooooo000Vooooo`03o`000?oooooooooo0?Cooooo1?l00017ooooo`009_ooool00ol0
003oooooooooo`3aooooo`?o0000Boooool002Kooooo00?o0000ooooooooool0kOooool4o`0004ko
oooo000Vooooo`;o0000j_ooool4o`0005;ooooo000Vooooo`03o`000?oooooooooo0>Kooooo0ol0
001Fooooo`009_ooool00ol0003oooooooooo`3Rooooo`Co0000FOooool002Kooooo00?o0000oooo
ooooool0g_ooool4o`0005gooooo000Vooooo`03o`000?oooooooooo0=[ooooo1?l0001Qooooo`00
9_ooool2o`000=Kooooo1Ol0001Uooooo`009_ooool00ol0003oooooooooo`3Aooooo`Co0000J_oo
ool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0<go
oooo1?l0001^ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0<Wooooo1?l0001booooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooo
oooooooooooooa0@4008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0aOooool4
o`0007Kooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooo
oooo000000Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000<7ooooo1?l0001jooooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2mooooo`Co0000O_ooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;Sooooo1Ol00022ooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0]?ooool4o`0008Oooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l00006ooooo`;o0000/Ooo
ool4o`0008_ooooo000Vooooo`03o`000?oooooooooo0:cooooo1?l0002?ooooo`009_ooool00ol0
003oooooooooo`2Xooooo`Co0000Toooool002Kooooo00?o0000ooooooooool0Xoooool5o`0009Oo
oooo000Vooooo`03o`000?oooooooooo09kooooo1Ol0002Looooo`009_ooool2o`0009[ooooo1Ol0
002Qooooo`009_ooool00ol0003oooooooooo`2Dooooo`Go0000Y_ooool002Kooooo00?o0000oooo
ooooool0Soooool5o`000:_ooooo000Vooooo`03o`000?oooooooooo08_ooooo1?l0002`ooooo`00
9_ooool00ol0003oooooooooo`26ooooo`Go0000]?ooool002Kooooo0_l00022ooooo`Go0000^Ooo
ool002Kooooo00?o0000ooooooooool0O?ooool5o`000;kooooo000Vooooo`03o`000?oooooooooo
07Oooooo1Ol00033ooooo`009_ooool00ol0003oooooooooo`1booooo`Go0000b?ooool002Kooooo
0_l0001_ooooo`Co0000cOooool002Kooooo00?o0000ooooooooool0J_ooool4o`000=7ooooo000V
ooooo`03o`000?oooooooooo06Kooooo1?l0003Eooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`1Q
ooooo`Go0000fOooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo05gooooo1?l0003Nooooo`002oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool3o`0005Wooooo1?l0003R
ooooo`002oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1Eooooo`Co0000i_ooool000_ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0DOooool4o`000>[ooooo000;oooo
o`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo04kooooo0ol0003^ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`?o0000lOooool000_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Oooooo0_l00019ooooo`?o0000m?ooool0
02Kooooo00?o0000ooooooooool0AOooool3o`000?Oooooo000Vooooo`03o`000?oooooooooo04;o
oooo0ol0003jooooo`009_ooool00ol0003oooooooooo`0oooooo`?o0000oOooool002Kooooo0_l0
000mooooo`?o0000ooooool1ooooo`009_ooool00ol0003oooooooooo`0iooooo`?o0000ooooool4
ooooo`009_ooool00ol0003oooooooooo`0fooooo`?o0000ooooool7ooooo`009_ooool00ol0003o
ooooooooo`0cooooo`?o0000ooooool:ooooo`009_ooool00ol0003oooooooooo`0aooooo`;o0000
ooooool=ooooo`009_ooool2o`00033ooooo0_l0003oooooo`oooooo000Vooooo`03o`000?oooooo
oooo02cooooo0ol0003ooooooa7ooooo000Vooooo`03o`000?oooooooooo02[ooooo0_l0003ooooo
oaCooooo000Vooooo`03o`000?oooooooooo02Oooooo0ol0003ooooooaKooooo000Vooooo`03o`00
0?oooooooooo02Gooooo0_l0003ooooooaWooooo000Vooooo`;o00008oooool3o`000?oooooo6ooo
ool002Kooooo00?o0000ooooooooool08?ooool2o`000?oooooo7_ooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l0
00000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo01kooooo0_l0003oooooob3ooooo0003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01_oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01_ooooo0ol0003oooooob;ooooo0003
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00?ooooo0ol0000Iooooo`;o0000oooooolUooooo`000oooool01Ol0003ooooooooooooo
oooo000000kooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo01Oooooo0_l0003oooooobOooooo0003ooooo`05o`000?ooooooooooooooool000003_oo
ool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`0Eooooo`;o0000oooooolYooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo
0_l0003oooooob_ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool2o`000?oooooo
;Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Gooooo
1?l00006ooooo`;o00004?ooool2o`000?oooooo;oooool002Kooooo00?o0000ooooooooool03Ooo
ool2o`000?oooooo<Oooool002Kooooo00?o0000ooooooooool02oooool2o`000?oooooo<oooool0
02Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3ooooooc?ooooo000Vooooo`03
o`000?oooooooooo00Sooooo0_l0003oooooocKooooo000Vooooo`;o00001oooool2o`000?oooooo
>?ooool002Kooooo00?o0000ooooooooool01?ooool2o`000?oooooo>_ooool002Kooooo00?o0000
ooooooooool00_ooool2o`000?oooooo??ooool002Kooooo00?o0000ooooooooool00_l0003ooooo
ockooooo000Vooooo`?o0000oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooood3ooooo000;ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003o
ooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2
o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003o
ooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom0
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o
0000ooooooooool00oooool3o`000?oooooo@?ooool000?ooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3ooooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood3ooooo
0003ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo@Oooool002Ko
oooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo
000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0
ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`00
9_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?oo
ool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo
000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0oooooom0
ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[o
ooooogMgMolb<S801_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?oooooo
ooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Gooooo0ol0
003ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj
^P06ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@
400>ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0oooooom0ooooo`002oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`00
0?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000
oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oo
oooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oo
oooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool3
o`000?oooooo@?ooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413o
oooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003oooo
o`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj^P04ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00onj^[[o8B4Qooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
410@oiRHV?oooooo^[Zjo`000004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@04ooooo`Co00001_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oo
oooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooo
od7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooom0ooooo`002oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo0ol0003ooooood3ooooo000;ooooo`05o`000?oooooooooooooo
ool000002oooool01?oMgMgoEEEEooooool0003ooooood[ooooo000;ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`00003ooooood[ooooo000;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00oo^k^koA4A4o`00003ooooood[ooooo000;ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`3oooooodWooooo003oooooofWooooo002Eooooo`;o
00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2]ooooo`00
UOooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b
[_ooool008[ooooo00Go410@o`000?l0003o0000oa0@4006ooooo`04o`000?ooooooooooooooo`;o
00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj
00Cooooo00?o0000ooooooooool00oooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000
odA4A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o
410@ooooooooool0Poooool008cooooo00?o0000ooooooooool01_ooool02_l0003ooooooooooooo
ooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj
^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Oooool0
1_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo08Cooooo002<ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`05oa0@4?oooooooooooooo
ool@41002oooool5o`0008Gooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`03ooooo`Ko00000_ooool01Ol0003ooooooooooooooooo
000000_ooooo00CoA4A4omgMgOoooooo0000Q_ooool008cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0008Kooooo0029ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008oooo
o`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`09ooooo`03oa0@4?l0003o0000
00?o00002_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000Q_ooool0
08Wooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000008Kooooo0029
ooooo`Oo00001Oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0000gooooo00?o0000
ooooooooool02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0QOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.11905 .25615 L
.21429 .21243 L
.30952 .17652 L
.40476 .14655 L
.5 .1205 L
.59524 .09648 L
.69048 .07304 L
.78571 .04926 L
.88095 .02486 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool3o`0000;ooooo00?o0000oooo
ooooool04?ooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`009_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo02kooooo1?l00005ooooo`03o`000?oooooooooo00oooooo0_l00002oooo
o`;o00002Oooool002Kooooo00?o0000ooooooooool0oooooolBooooo`Co0000:_ooool002Kooooo
00?o0000ooooooooool0ooooool?ooooo`?o0000;_ooool002Kooooo0_l0003oooooo`cooooo1?l0
000aooooo`009_ooool00ol0003oooooooooo`3oooooo`Oooooo1?l0000eooooo`009_ooool00ol0
003oooooooooo`3oooooo`Cooooo0ol0000iooooo`009_ooool00ol0003oooooooooo`3oooooo`Co
0000??ooool002Kooooo00?o0000ooooooooool0noooool4o`00043ooooo000Vooooo`;o0000n?oo
ool4o`0004Cooooo000Vooooo`03o`000?oooooooooo0?;ooooo1Ol00018ooooo`009_ooool00ol0
003oooooooooo`3^ooooo`Co0000COooool002Kooooo00?o0000ooooooooool0j_ooool4o`00057o
oooo000Vooooo`;o0000ioooool4o`0005Gooooo000Vooooo`03o`000?oooooooooo0>;ooooo1?l0
001Iooooo`009_ooool00ol0003oooooooooo`3Nooooo`Co0000GOooool002Kooooo00?o0000oooo
ooooool0f_ooool4o`00067ooooo000Vooooo`03o`000?oooooooooo0=Gooooo1Ol0001Uooooo`00
9_ooool2o`000=;ooooo1?l0001Zooooo`009_ooool00ol0003oooooooooo`3=ooooo`Co0000K_oo
ool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0<Wo
oooo1?l0001booooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0<Gooooo1?l0001fooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooo
oooooooooooooa0@4008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0`Oooool4
o`0007[ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooo
oooo000000Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000;gooooo1?l0001nooooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2hooooo`Go0000P_ooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;Cooooo1?l00027ooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0/?ooool4o`0008_ooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l00006ooooo`;o0000[Ooo
ool4o`0008oooooo000Vooooo`03o`000?oooooooooo0:Sooooo1?l0002Cooooo`009_ooool00ol0
003oooooooooo`2Uooooo`?o0000Uoooool002Kooooo00?o0000ooooooooool0XOooool4o`0009[o
oooo000Vooooo`03o`000?oooooooooo09gooooo1?l0002Nooooo`009_ooool2o`0009_ooooo0ol0
002Rooooo`009_ooool00ol0003oooooooooo`2Fooooo`Co0000YOooool002Kooooo00?o0000oooo
ooooool0T_ooool4o`000:Wooooo000Vooooo`03o`000?oooooooooo08oooooo0ol0002]ooooo`00
9_ooool00ol0003oooooooooo`2;ooooo`Co0000/?ooool002Kooooo0_l00029ooooo`?o0000]?oo
ool002Kooooo00?o0000ooooooooool0Q?ooool4o`000;Oooooo000Vooooo`03o`000?oooooooooo
083ooooo1?l0002kooooo`009_ooool00ol0003oooooooooo`1mooooo`?o0000_oooool002Kooooo
0_l0001jooooo`Co0000`_ooool002Kooooo00?o0000ooooooooool0MOooool4o`000<Kooooo000V
ooooo`03o`000?oooooooooo07;ooooo0ol0003:ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`1^
ooooo`Co0000cOooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo06_ooooo0ol0003Aooooo`002oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool3o`0006Sooooo0ol0003D
ooooo`002oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1Uooooo`?o0000eoooool000_ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool4o`000=[ooooo000;oooo
o`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05kooooo0ol0003Nooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1Kooooo`?o0000hOooool000_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Oooooo0_l0001Iooooo`?o0000i?ooool0
02Kooooo00?o0000ooooooooool0EOooool3o`000>Oooooo000Vooooo`03o`000?oooooooooo05;o
oooo0ol0003Zooooo`009_ooool00ol0003oooooooooo`1?ooooo`?o0000kOooool002Kooooo0_l0
001>ooooo`;o0000l?ooool002Kooooo00?o0000ooooooooool0B_ooool3o`000?;ooooo000Voooo
o`03o`000?oooooooooo04Sooooo0_l0003eooooo`009_ooool00ol0003oooooooooo`15ooooo`?o
0000moooool002Kooooo00?o0000ooooooooool0@_ooool3o`000?[ooooo000Vooooo`;o0000@Ooo
ool2o`000?gooooo000Vooooo`03o`000?oooooooooo03gooooo0ol0003oooooo`009_ooool00ol0
003oooooooooo`0kooooo`;o0000ooooool3ooooo`009_ooool00ol0003oooooooooo`0hooooo`?o
0000ooooool5ooooo`009_ooool00ol0003oooooooooo`0fooooo`;o0000ooooool8ooooo`009_oo
ool2o`0003Gooooo0_l0003oooooo`[ooooo000Vooooo`03o`000?oooooooooo037ooooo0ol0003o
ooooo`cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
1Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool01?ooool00ol0003ooooooooo
o`0_ooooo`;o0000ooooool?ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`0]ooooo`;o0000oooooolAooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`?o0000:oooool2o`000?oooooo4ooo
ool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Kooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Xooooo`?o0000oooooolEooooo`000oooool0
1Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool09_ooool2o`000?oooooo6?ooool000?ooooo00Go
410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Tooooo`;o0000oooooolJooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo02;ooooo0_l0003ooooooacooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool00omEEEGoIVIVo`000005ooooo`Co00001_ooool2o`00027ooooo0_l0003ooooooakooooo
000Vooooo`03o`000?oooooooooo01gooooo0ol0003oooooob3ooooo000Vooooo`03o`000?oooooo
oooo01_ooooo0_l0003oooooob?ooooo000Vooooo`03o`000?oooooooooo01Wooooo0_l0003ooooo
obGooooo000Vooooo`03o`000?oooooooooo01Oooooo0_l0003oooooobOooooo000Vooooo`;o0000
5_ooool2o`000?oooooo:Oooool002Kooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`3oooooobWooooo000Vooooo`03o`000?oooooooooo01;ooooo0_l0003oooooobcooooo000Voooo
o`03o`000?oooooooooo013ooooo0_l0003oooooobkooooo000Vooooo`03o`000?oooooooooo00ko
oooo0_l0003ooooooc3ooooo000Vooooo`;o00003Oooool2o`000?oooooo<_ooool002Kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`3ooooooc;ooooo000Vooooo`03o`000?oooooo
oooo00Wooooo0_l0003oooooocGooooo000Vooooo`03o`000?oooooooooo00Oooooo0_l0003ooooo
ocOooooo000Vooooo`;o00001_ooool2o`000?oooooo>Oooool002Kooooo00?o0000ooooooooool0
0oooool2o`000?oooooo>oooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooooc_ooooo
000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A006ooooo`03o`000?oooooooooo00;o0000oooooolnooooo`002oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`000?oooooo@?ooool000_ooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooood3o
oooo000;ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo
0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000?oooooo@?ooool000?ooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`3ooooood3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom0ooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`00
0?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000
ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003o
oooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000
ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`3ooooood3ooooo000;
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@
413ooooo00Gooooo0ol0003ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000003Ooo
ool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go410@
oooooooooooooooooa0@400>ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0oooo
oom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zj
o`000006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood3o
oooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0oooo
o`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0oooo
o`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<
c<`01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom0oooo
o`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S801oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool0
00?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00oooool3o`000?oooooo@?ooool000?ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ojVYZOl@413ooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3o
oooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj^P04
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood3ooooo0003
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qooooo`03ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000004ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@04ooooo`Co00001_ooool2o`000?oooooo@Oooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0oooo
o`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`00
2oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Ol@413ooooooooooooooooo410@00_o
oooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0003ooooood3ooooo000;ooooo`05
o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0003ooooood[ooooo000;oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00003ooooood[ooooo000;oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00003ooooood[ooooo000;oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`3oooooodWooooo003ooooo
ofWooooo002Eooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o
^[Zjooooo`2]ooooo`00UOooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003ooooo
ooooo`03ooooo`;o<S8b[_ooool008[ooooo00Go410@o`000?l0003o0000oa0@4006ooooo`04o`00
0?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So
0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7QhOo0000okZj^P05oooo
o`05oiRHV?l0003o0000odA4A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0Q?ooool008cooooo00?o0000ooooooooool01_oo
ool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o
410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo00?o
c<c<o`000?l@41001Oooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00000_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo08?ooooo002<ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`22ooooo`00S?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool6
o`0000;ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo08?ooooo002<
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb
<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0;ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<08Co
oooo0029ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0
003oooooooooo`09ooooo`03oa0@4?l0003o000000?o00002_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool0Q_ooool008Wooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo08Kooooo0029ooooo`Oo00001Oooool2o`0001;ooooo00?o0000
ooooooooool01Oooool2o`0000gooooo00?o0000ooooooooool02oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l00025ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .33109 m
.11905 .2771 L
.21429 .23064 L
.30952 .1909 L
.40476 .15666 L
.5 .12657 L
.59524 .09928 L
.69048 .07366 L
.78571 .04886 L
.88095 .02439 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool3o`0000;ooooo00?o0000oooo
ooooool04?ooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`009_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo02kooooo1?l00005ooooo`03o`000?oooooooooo00oooooo0_l00002oooo
o`;o00002Oooool002Kooooo00?o0000ooooooooool0oooooolBooooo`Co0000:_ooool002Kooooo
00?o0000ooooooooool0ooooool?ooooo`?o0000;_ooool002Kooooo0_l0003oooooo`cooooo1?l0
000aooooo`009_ooool00ol0003oooooooooo`3oooooo`Oooooo1?l0000eooooo`009_ooool00ol0
003oooooooooo`3oooooo`Cooooo0ol0000iooooo`009_ooool00ol0003oooooooooo`3oooooo`Co
0000??ooool002Kooooo00?o0000ooooooooool0noooool4o`00043ooooo000Vooooo`;o0000n?oo
ool4o`0004Cooooo000Vooooo`03o`000?oooooooooo0?;ooooo1Ol00018ooooo`009_ooool00ol0
003oooooooooo`3^ooooo`Co0000COooool002Kooooo00?o0000ooooooooool0j_ooool4o`00057o
oooo000Vooooo`;o0000ioooool4o`0005Gooooo000Vooooo`03o`000?oooooooooo0>;ooooo1?l0
001Iooooo`009_ooool00ol0003oooooooooo`3Oooooo`?o0000GOooool002Kooooo00?o0000oooo
ooooool0foooool4o`00063ooooo000Vooooo`03o`000?oooooooooo0=Oooooo1?l0001Tooooo`00
9_ooool2o`000=Gooooo0ol0001Xooooo`009_ooool00ol0003oooooooooo`3@ooooo`Co0000Jooo
ool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0<co
oooo1?l0001_ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0<Wooooo0ol0001cooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooo
oooooooooooooa0@4008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0aOooool4
o`0007Kooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooo
oooo000000Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000<7ooooo1?l0001jooooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2mooooo`Co0000O_ooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;Sooooo1Ol00022ooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0]?ooool4o`0008Oooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l00006ooooo`;o0000/Ooo
ool4o`0008_ooooo000Vooooo`03o`000?oooooooooo0:cooooo1?l0002?ooooo`009_ooool00ol0
003oooooooooo`2Xooooo`Co0000Toooool002Kooooo00?o0000ooooooooool0YOooool3o`0009Oo
oooo000Vooooo`03o`000?oooooooooo0:;ooooo0ol0002Jooooo`009_ooool2o`000:3ooooo0ol0
002Mooooo`009_ooool00ol0003oooooooooo`2Kooooo`Co0000X?ooool002Kooooo00?o0000oooo
ooooool0V?ooool3o`000:Cooooo000Vooooo`03o`000?oooooooooo09Gooooo0ol0002Wooooo`00
9_ooool00ol0003oooooooooo`2Booooo`?o0000Z_ooool002Kooooo0_l0002@ooooo`?o0000[Ooo
ool002Kooooo00?o0000ooooooooool0Roooool4o`000;3ooooo000Vooooo`03o`000?oooooooooo
08Sooooo0ol0002dooooo`009_ooool00ol0003oooooooooo`25ooooo`?o0000]oooool002Kooooo
0_l00023ooooo`?o0000^_ooool002Kooooo00?o0000ooooooooool0O_ooool4o`000;gooooo000V
ooooo`03o`000?oooooooooo07_ooooo0ol00031ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`1h
ooooo`?o0000a?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo07Gooooo0ol00037ooooo`002oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool3o`0007;ooooo0ol0003:
ooooo`002oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1_ooooo`?o0000cOooool000_ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0K?ooool3o`000=3ooooo000;oooo
o`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo06Wooooo0ol0003Cooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1Vooooo`?o0000e_ooool000_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Oooooo0_l0001Tooooo`?o0000fOooool0
02Kooooo00?o0000ooooooooool0H?ooool3o`000=cooooo000Vooooo`03o`000?oooooooooo05go
oooo0ol0003Oooooo`009_ooool00ol0003oooooooooo`1Jooooo`?o0000h_ooool002Kooooo0_l0
001Hooooo`?o0000iOooool002Kooooo00?o0000ooooooooool0E?ooool3o`000>Sooooo000Voooo
o`03o`000?oooooooooo05;ooooo0_l0003[ooooo`009_ooool00ol0003oooooooooo`1?ooooo`?o
0000kOooool002Kooooo00?o0000ooooooooool0COooool2o`000?3ooooo000Vooooo`;o0000C?oo
ool2o`000?;ooooo000Vooooo`03o`000?oooooooooo04Sooooo0ol0003dooooo`009_ooool00ol0
003oooooooooo`16ooooo`;o0000moooool002Kooooo00?o0000ooooooooool0A?ooool2o`000?Wo
oooo000Vooooo`03o`000?oooooooooo047ooooo0ol0003kooooo`009_ooool2o`00043ooooo0_l0
003nooooo`009_ooool00ol0003oooooooooo`0mooooo`;o0000ooooool1ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000Go410@ooooooooooooooooodA4
A002o`000003oc8b<_oMgMgooooo00Cooooo00?o0000ooooooooool0>_ooool3o`000?oooooo0ooo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0>?ooool2o`000?oooooo1_oo
ool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00oooool3o`0003Kooooo0_l0003oooooo`Sooooo0003ooooo`05o`000?oooooo
ooooooooool000003_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0=?ooool2o`000?oooooo2_ooool000?ooooo00Go0000ooooooooooooooooo`00
000>ooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo03;ooooo0_l0003oooooo`cooooo0003ooooo`05oa0@4?ooooooooooooooool@4100
3_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
<?ooool2o`000?oooooo3_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0^ooooo`;o0000
ooooool@ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l00000
1Oooool4o`0000Kooooo0_l0000]ooooo`;o0000oooooolBooooo`009_ooool00ol0003ooooooooo
o`0Zooooo`;o0000oooooolDooooo`009_ooool00ol0003oooooooooo`0Wooooo`?o0000oooooolF
ooooo`009_ooool00ol0003oooooooooo`0Uooooo`;o0000oooooolIooooo`009_ooool00ol0003o
ooooooooo`0Sooooo`;o0000oooooolKooooo`009_ooool2o`0002;ooooo0_l0003ooooooagooooo
000Vooooo`03o`000?oooooooooo01oooooo0_l0003ooooooaoooooo000Vooooo`03o`000?oooooo
oooo01gooooo0_l0003oooooob7ooooo000Vooooo`03o`000?oooooooooo01_ooooo0_l0003ooooo
ob?ooooo000Vooooo`03o`000?oooooooooo01Wooooo0_l0003oooooobGooooo000Vooooo`;o0000
6?ooool2o`000?oooooo9oooool002Kooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`3oooooobOooooo000Vooooo`03o`000?oooooooooo01Cooooo0_l0003oooooob[ooooo000Voooo
o`03o`000?oooooooooo01;ooooo0_l0003oooooobcooooo000Vooooo`;o00004_ooool00ol0003o
ooooooooo`3oooooobcooooo000Vooooo`03o`000?oooooooooo00oooooo0_l0003ooooooboooooo
000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`00
0?oooooooooo00gooooo0_l0003ooooooc7ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00_o
oooo0_l0003ooooooc?ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0oooooolcooooo`00
2oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0000So
oooo0_l0003oooooocKooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`05ooooo`03o`000?oooooooooo00Kooooo0_l0003oooooocSooooo000;ooooo`05oa0@
4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooolhooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo00?ooooo0_l0003ooooo
oc_ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Kooooo00Co0000oooooooooooooooo0_l0003oooooocgooooo000Vooooo`;o000000?ooooo
o`000?ooool0oooooolnooooo`009_ooool3o`000?oooooo@?ooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooo
oom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooo
oom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooom0ooooo`000ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood3o
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000
ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01_oo
ool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oooooo
@?ooool000_ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom0ooooo`002oooool01Ol0003ooooooooooooooooo000000kooooo
00?oZJVYoa0@4?ooool01Oooool3o`000?oooooo@?ooool000_ooooo00Go0000oooooooooooooooo
o`00000=ooooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000ooooooooool0oooooom0ooooo`002ooo
ool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003ooooo
ooooo`3ooooood3ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RH
oooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0
003o<S8bolc<c004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3o
oooood3ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go410@
okZj^_ooooooMgMgoc8b<P07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooo
oom0ooooo`000oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`03ooooo`?o0000oooooom0ooooo`000oooool01Ol0003ooooooooooooo
oooo000000kooooo00?oZJVYoa0@4?ooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oa0@4?l0
003o^[Zj00Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo
@?ooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03okZj^_lQ8B7ooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol@413oV9RHoooooonj^[[o000000Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Cooooo1?l00006ooooo`;o0000oooooom1oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooo
od3ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?oooooooooooooo
ool@41002oooool5o`0000Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Ol0003o
oooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool3o`000?oooooo@?ooool0
00_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`000?ooooooB_oo
ool000_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co00000?ooooooB_oo
ool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co00000?ooooooB_oo
ool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo0?ooooooBOoo
ool00?ooooooJOooool009Gooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00005oooo
o`03o`000?nj^[[ooooo0:gooooo002Eooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03
o`000?oooooooooo00?ooooo0_lb<S:^ooooo`00R_ooool01Ol@413o0000o`000?l0003o410@00Ko
oooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04oooo
o`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`03ooooo`03ohN7Qol0003o
^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c025ooooo`00S?ooool00ol0003ooooo
ooooo`06ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?o
c<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool0
0oooool00oo<c<co0000oa0@4005ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l00002oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q
8@25ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00CogMgM
o`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooo
ooooo`000025ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo
00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool00oooool6o`0000;ooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?nHV9SooooooiRHV?lQ8B40QOooool008cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0QOooool008Wooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000So
oooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo00Wooooo00?o410@o`000?l0
00000ol0000:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`27oooo
o`00ROooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qoooool0
08Wooooo1ol00005ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o00003Oooool00ol0
003oooooooooo`0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@
4125ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .34889 m
.11905 .29449 L
.21429 .24642 L
.30952 .20419 L
.40476 .16704 L
.5 .13403 L
.59524 .10416 L
.69048 .07651 L
.78571 .05032 L
.88095 .02497 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool3o`0000;ooooo00?o0000oooo
ooooool04?ooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`009_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo02kooooo1?l00005ooooo`03o`000?oooooooooo00oooooo0_l00002oooo
o`;o00002Oooool002Kooooo00?o0000ooooooooool0oooooolBooooo`Co0000:_ooool002Kooooo
00?o0000ooooooooool0ooooool?ooooo`?o0000;_ooool002Kooooo0_l0003oooooo`cooooo1?l0
000aooooo`009_ooool00ol0003oooooooooo`3oooooo`Oooooo1?l0000eooooo`009_ooool00ol0
003oooooooooo`3oooooo`Cooooo0ol0000iooooo`009_ooool00ol0003oooooooooo`3oooooo`Co
0000??ooool002Kooooo00?o0000ooooooooool0noooool4o`00043ooooo000Vooooo`;o0000n?oo
ool4o`0004Cooooo000Vooooo`03o`000?oooooooooo0?;ooooo1Ol00018ooooo`009_ooool00ol0
003oooooooooo`3^ooooo`Co0000COooool002Kooooo00?o0000ooooooooool0j_ooool4o`00057o
oooo000Vooooo`;o0000ioooool4o`0005Gooooo000Vooooo`03o`000?oooooooooo0>;ooooo1?l0
001Iooooo`009_ooool00ol0003oooooooooo`3Oooooo`?o0000GOooool002Kooooo00?o0000oooo
ooooool0foooool4o`00063ooooo000Vooooo`03o`000?oooooooooo0=Oooooo1?l0001Tooooo`00
9_ooool2o`000=Gooooo0ol0001Xooooo`009_ooool00ol0003oooooooooo`3@ooooo`Co0000Jooo
ool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0<co
oooo1?l0001_ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0<Wooooo0ol0001cooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooo
oooooooooooooa0@4008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0aOooool4
o`0007Kooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooo
oooo000000Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000<;ooooo0ol0001jooooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2oooooo`?o0000OOooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;cooooo0ol00020ooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0^?ooool4o`0008?ooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l00006ooooo`;o0000]_oo
ool3o`0008Oooooo000Vooooo`03o`000?oooooooooo0;;ooooo0ol0002:ooooo`009_ooool00ol0
003oooooooooo`2_ooooo`?o0000SOooool002Kooooo00?o0000ooooooooool0[?ooool3o`00093o
oooo000Vooooo`03o`000?oooooooooo0:Sooooo1?l0002Cooooo`009_ooool2o`000:Kooooo0ol0
002Gooooo`009_ooool00ol0003oooooooooo`2Rooooo`?o0000V_ooool002Kooooo00?o0000oooo
ooooool0Woooool3o`0009gooooo000Vooooo`03o`000?oooooooooo09_ooooo1?l0002Pooooo`00
9_ooool00ol0003oooooooooo`2Hooooo`?o0000Y?ooool002Kooooo0_l0002Fooooo`?o0000Yooo
ool002Kooooo00?o0000ooooooooool0T_ooool3o`000:[ooooo000Vooooo`03o`000?oooooooooo
08oooooo0ol0002]ooooo`009_ooool00ol0003oooooooooo`2<ooooo`?o0000/?ooool002Kooooo
0_l0002:ooooo`?o0000/oooool002Kooooo00?o0000ooooooooool0Q_ooool3o`000;Kooooo000V
ooooo`03o`000?oooooooooo08?ooooo0ol0002iooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`20
ooooo`?o0000_?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo07gooooo0ol0002oooooo`002oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool3o`0007[ooooo0ol00032
ooooo`002oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1gooooo`?o0000aOooool000_ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0M?ooool3o`000<Sooooo000;oooo
o`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo077ooooo0ol0003;ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1_ooooo`;o0000c_ooool000_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Oooooo0_l0001]ooooo`?o0000d?ooool0
02Kooooo00?o0000ooooooooool0JOooool3o`000=?ooooo000Vooooo`03o`000?oooooooooo06Oo
oooo0_l0003Fooooo`009_ooool00ol0003oooooooooo`1Tooooo`?o0000f?ooool002Kooooo0_l0
001Rooooo`?o0000foooool002Kooooo00?o0000ooooooooool0Goooool2o`000=kooooo000Voooo
o`03o`000?oooooooooo05cooooo0ol0003Pooooo`009_ooool00ol0003oooooooooo`1Jooooo`;o
0000hoooool002Kooooo00?o0000ooooooooool0Eoooool3o`000>Gooooo000Vooooo`;o0000EOoo
ool3o`000>Sooooo000Vooooo`03o`000?oooooooooo05;ooooo0_l0003[ooooo`009_ooool00ol0
003oooooooooo`1@ooooo`;o0000kOooool002Kooooo00?o0000ooooooooool0C_ooool2o`000>oo
oooo000Vooooo`03o`000?oooooooooo04_ooooo0ol0003aooooo`009_ooool2o`0004[ooooo0_l0
003dooooo`009_ooool00ol0003oooooooooo`17ooooo`;o0000m_ooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l0
00000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo04Gooooo0_l0003hooooo`000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`13ooooo`;o0000n_ooool000?ooooo00Go410@
oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00ooo
ool3o`00047ooooo0_l0003looooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo03oooooo0_l0
003nooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0??ooool3o`000?oooooo
0Oooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0jooooo`;o0000ooooool4ooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo03Sooooo0_l0003oooooo`Kooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000005ooooo`Co00001_ooool2o`0003Oooooo
0_l0003oooooo`Sooooo000Vooooo`03o`000?oooooooooo03Cooooo0_l0003oooooo`[ooooo000V
ooooo`03o`000?oooooooooo03;ooooo0_l0003oooooo`cooooo000Vooooo`03o`000?oooooooooo
033ooooo0_l0003oooooo`kooooo000Vooooo`03o`000?oooooooooo02kooooo0_l0003ooooooa3o
oooo000Vooooo`;o0000;Oooool2o`000?oooooo4_ooool002Kooooo00?o0000ooooooooool0:_oo
ool2o`000?oooooo5?ooool002Kooooo00?o0000ooooooooool0:?ooool2o`000?oooooo5_ooool0
02Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`3ooooooaKooooo000Vooooo`03
o`000?oooooooooo02Gooooo0_l0003ooooooaWooooo000Vooooo`;o00009?ooool2o`000?oooooo
6oooool002Kooooo00?o0000ooooooooool08Oooool2o`000?oooooo7Oooool002Kooooo00?o0000
ooooooooool07oooool2o`000?oooooo7oooool002Kooooo00?o0000ooooooooool07Oooool2o`00
0?oooooo8Oooool002Kooooo0_l0000Looooo`;o0000oooooolSooooo`009_ooool00ol0003ooooo
ooooo`0Iooooo`;o0000oooooolUooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`0Gooooo`;o0000oooooolWooooo`002ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool00ol0003oooooooooo`0Eooooo`;o0000oooooolYooooo`002oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo0?oooooo:Oooool000_ooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^00Kooooo0ol0000Booooo`;o0000ooooool/ooooo`002oooool01Ol0003ooooo
oooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0@ooooo`;o
0000ooooool^ooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0>ooooo`;o0000ooooool`ooooo`002oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo
00cooooo0_l0003ooooooc;ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnH
V9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3o
oooooc;ooooo000Vooooo`;o00002_ooool2o`000?oooooo=Oooool002Kooooo00?o0000oooooooo
ool01oooool2o`000?oooooo=oooool002Kooooo00?o0000ooooooooool01Oooool2o`000?oooooo
>Oooool002Kooooo00?o0000ooooooooool00oooool2o`000?oooooo>oooool002Kooooo0_l00003
ooooo`03o`000?oooooooooo0?oooooo>oooool002Kooooo00?o0000ooooooooool00_l0003ooooo
ockooooo000Vooooo`?o0000oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo
000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`00
9_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?oo
ool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0
003ooooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooo
od7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1
ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooo
od3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@
4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o
0000ooooooooool0oooooom0ooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05o`000?oooooo
ooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000oooooom0ooooo`002oooool0
1Ol0003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01_ooool00ol0003ooooooooo
o`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qoooo
o`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooood3ooooo
000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Ko
oooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0003ooooood3ooooo0003oooo
o`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`06ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol0003ooooooooooooooooo
000000gooooo00?o410@o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o
^[Zjob4Q8Oooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l00000
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01?ooool4o`0000Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003o
ooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo
00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`3ooooood3o
oooo000;ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007oooo
o`?o0000oooooom0ooooo`002oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEE
EOoooooo0000oooooom:ooooo`002oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMg
olc<c?l00000oooooom:ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l00000oooooom:ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMg
o`000?ooool0oooooom9ooooo`00oooooomYooooo`00UOooool2o`0000_ooooo00?o0000okZj^_oo
ool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0[Oooool009Gooooo00?o0000ooooooooool0
2_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<Zkooooo002:ooooo`05oa0@4?l0
003o0000o`000?l@41001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03
ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo
00?ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00Wooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`25ooooo`00S?ooool0
0ol0003oooooooooo`06ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgM
g@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000
ooooooooool00oooool00oo<c<co0000oa0@4005ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo
1_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOoo
ool0QOooool008cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04omgM
gOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo
08Gooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko
8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`03ooooo`Ko00000_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Q
ooooooooool0Q?ooool008cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02oooo
o`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<
c<cooooo08Cooooo0029ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o0000
1Oooool00ol0003oooooooooo`09ooooo`03oa0@4?l0003o000000?o00002_ooool01Ol@413ooooo
oooooooooooo410@00kooooo00?oZJVYogMgMoooool0Q?ooool008Wooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S80QOooool008Wooooo1ol00005oooo
o`;o00004_ooool00ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003oooooooooo`0;oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0008Gooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36355 m
.11905 .30919 L
.21429 .26022 L
.30952 .2164 L
.40476 .17722 L
.5 .14202 L
.59524 .11004 L
.69048 .08053 L
.78571 .05277 L
.88095 .02612 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool3o`0000;ooooo00?o0000oooo
ooooool04?ooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`009_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo02kooooo1?l00005ooooo`03o`000?oooooooooo00oooooo0_l00002oooo
o`;o00002Oooool002Kooooo00?o0000ooooooooool0oooooolBooooo`Co0000:_ooool002Kooooo
00?o0000ooooooooool0ooooool?ooooo`?o0000;_ooool002Kooooo0_l0003oooooo`cooooo1?l0
000aooooo`009_ooool00ol0003oooooooooo`3oooooo`Oooooo1?l0000eooooo`009_ooool00ol0
003oooooooooo`3oooooo`Cooooo0ol0000iooooo`009_ooool00ol0003oooooooooo`3oooooo`Co
0000??ooool002Kooooo00?o0000ooooooooool0o?ooool3o`00043ooooo000Vooooo`;o0000nOoo
ool4o`0004?ooooo000Vooooo`03o`000?oooooooooo0?Cooooo1?l00017ooooo`009_ooool00ol0
003oooooooooo`3aooooo`?o0000Boooool002Kooooo00?o0000ooooooooool0kOooool4o`0004ko
oooo000Vooooo`;o0000j_ooool4o`0005;ooooo000Vooooo`03o`000?oooooooooo0>Kooooo0ol0
001Fooooo`009_ooool00ol0003oooooooooo`3Rooooo`Co0000FOooool002Kooooo00?o0000oooo
ooooool0goooool3o`0005gooooo000Vooooo`03o`000?oooooooooo0=cooooo0ol0001Pooooo`00
9_ooool2o`000=[ooooo0ol0001Sooooo`009_ooool00ol0003oooooooooo`3Eooooo`Co0000I_oo
ool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0=;o
oooo0ol0001Zooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0<oooooo0ol0001]ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooo
oooooooooooooa0@4008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0c?ooool3
o`00073ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooo
oooo000000Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000<Wooooo0ol0001cooooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`35ooooo`Co0000M_ooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0<;ooooo0ol0001jooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0_oooool3o`0007gooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l00006ooooo`;o0000_Ooo
ool3o`00083ooooo000Vooooo`03o`000?oooooooooo0;Sooooo1?l00023ooooo`009_ooool00ol0
003oooooooooo`2eooooo`?o0000Qoooool002Kooooo00?o0000ooooooooool0/_ooool3o`0008[o
oooo000Vooooo`03o`000?oooooooooo0:oooooo0ol0002=ooooo`009_ooool2o`000:gooooo0ol0
002@ooooo`009_ooool00ol0003oooooooooo`2Xooooo`Co0000Toooool002Kooooo00?o0000oooo
ooooool0YOooool3o`0009Oooooo000Vooooo`03o`000?oooooooooo0:;ooooo0ol0002Jooooo`00
9_ooool00ol0003oooooooooo`2Oooooo`?o0000WOooool002Kooooo0_l0002Looooo`Co0000X?oo
ool002Kooooo00?o0000ooooooooool0V?ooool3o`000:Cooooo000Vooooo`03o`000?oooooooooo
09Gooooo0ol0002Wooooo`009_ooool00ol0003oooooooooo`2Booooo`?o0000Z_ooool002Kooooo
0_l0002@ooooo`?o0000[Oooool002Kooooo00?o0000ooooooooool0S?ooool3o`000;3ooooo000V
ooooo`03o`000?oooooooooo08Wooooo0ol0002cooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`26
ooooo`?o0000]_ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Cooooo0_l0002iooooo`002oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool3o`00087ooooo0ol0002k
ooooo`002oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1nooooo`?o0000__ooool000_ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0O?ooool2o`000<7ooooo000;oooo
o`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo07Wooooo0ol00033ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1gooooo`;o0000a_ooool000_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Oooooo0_l0001eooooo`?o0000b?ooool0
02Kooooo00?o0000ooooooooool0LOooool3o`000<_ooooo000Vooooo`03o`000?oooooooooo06oo
oooo0_l0003>ooooo`009_ooool00ol0003oooooooooo`1/ooooo`?o0000d?ooool002Kooooo0_l0
001[ooooo`;o0000doooool002Kooooo00?o0000ooooooooool0J?ooool2o`000=Gooooo000Voooo
o`03o`000?oooooooooo06Gooooo0ol0003Gooooo`009_ooool00ol0003oooooooooo`1Sooooo`;o
0000f_ooool002Kooooo00?o0000ooooooooool0H?ooool3o`000=cooooo000Vooooo`;o0000Gooo
ool2o`000=oooooo000Vooooo`03o`000?oooooooooo05_ooooo0ol0003Qooooo`009_ooool00ol0
003oooooooooo`1Iooooo`;o0000i?ooool002Kooooo00?o0000ooooooooool0Eoooool2o`000>Ko
oooo000Vooooo`03o`000?oooooooooo05Cooooo0ol0003Xooooo`009_ooool2o`0005?ooooo0_l0
003[ooooo`009_ooool00ol0003oooooooooo`1@ooooo`;o0000kOooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l0
00000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo04kooooo0_l0003_ooooo`000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1;ooooo`?o0000lOooool000?ooooo00Go410@
oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00ooo
ool3o`0004Wooooo0_l0003dooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04Oooooo0_l0
003fooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0AOooool2o`000?Sooooo
0003ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0@oooool2o`000?[ooooo0003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0@Oooool2o`000?cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool00omEEEGoIVIVo`000005ooooo`Co00001_ooool2o`00043ooooo0_l0003nooooo`009_oo
ool00ol0003oooooooooo`0looooo`?o0000ooooool1ooooo`009_ooool00ol0003oooooooooo`0j
ooooo`;o0000ooooool4ooooo`009_ooool00ol0003oooooooooo`0hooooo`;o0000ooooool6oooo
o`009_ooool00ol0003oooooooooo`0fooooo`;o0000ooooool8ooooo`009_ooool2o`0003Gooooo
0_l0003oooooo`[ooooo000Vooooo`03o`000?oooooooooo03;ooooo0_l0003oooooo`cooooo000V
ooooo`03o`000?oooooooooo033ooooo0_l0003oooooo`kooooo000Vooooo`03o`000?oooooooooo
02kooooo0_l0003ooooooa3ooooo000Vooooo`03o`000?oooooooooo02cooooo0_l0003ooooooa;o
oooo000Vooooo`;o0000:oooool2o`000?oooooo5?ooool002Kooooo00?o0000ooooooooool0:?oo
ool2o`000?oooooo5_ooool002Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`3o
oooooaKooooo000Vooooo`03o`000?oooooooooo02Gooooo0_l0003ooooooaWooooo000Vooooo`;o
00009?ooool2o`000?oooooo6oooool002Kooooo00?o0000ooooooooool08Oooool2o`000?oooooo
7Oooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo
00?o0000ooooooooool07oooool2o`000?oooooo7oooool000_ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooooooo
ool07Oooool2o`000?oooooo8Oooool000_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool06oooool2o`000?oooooo8oooool000_ooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0000Iooooo`;o
0000oooooolUooooo`002oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool01Oooool00ol0003oooooooooo`0Gooooo`;o0000oooooolWooooo`002oooool01Ol@413ooooo
oooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`;o
0000oooooolYooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4006ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0oooooolYoooo
o`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006
ooooo`03o`000?oooooooooo01;ooooo0_l0003oooooobcooooo000Vooooo`;o00004Oooool2o`00
0?oooooo;_ooool002Kooooo00?o0000ooooooooool03_ooool2o`000?oooooo<?ooool002Kooooo
00?o0000ooooooooool03?ooool2o`000?oooooo<_ooool002Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`3ooooooc;ooooo000Vooooo`;o00002_ooool2o`000?oooooo=Oooool0
02Kooooo00?o0000ooooooooool01oooool2o`000?oooooo=oooool002Kooooo00?o0000oooooooo
ool01Oooool2o`000?oooooo>Oooool002Kooooo00?o0000ooooooooool00oooool2o`000?oooooo
>oooool002Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooooc_ooooo000V
ooooo`;o000000?oooooo`000?l00000oooooolnooooo`009_ooool3o`000?oooooo@?ooool002Ko
oooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo
000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3ooooood3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP09ooooo`03o`000?oooooooooo00?ooooo0ol0003ooooood3ooooo0003ooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooom0ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
oooooom0ooooo`000oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0003ooooo
od7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooo
od3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1
ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooo
oooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool0
1Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@oooo
o`05ooooo`?o0000oooooom0ooooo`002oooool01Ol0003ooooooooooooooooo000000gooooo00?o
410@o`000?nj^[X01_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l00000
1_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom0ooooo`00
9_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@?ooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo
<S8b00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003oooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00?ooooo0ol0003ooooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool0
0onYZJWo410@ooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0
ooooo`000oooool01Ol0003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool0
1Ol@413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q8Oooool00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01?ooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003o
ooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool0
00002oooool01?m4A4CogMgMooooool00007ooooo`?o0000oooooom0ooooo`002oooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo0000oooooom:ooooo`002oooool01Ol@
413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000oooooom:ooooo`002oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000oooooom:ooooo`002oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0oooooom9ooooo`00oooooomYoooo
o`00UOooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj^_oo
ool0[Oooool009Gooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0
0oooool2oc8b<Zkooooo002:ooooo`05oa0@4?l0003o0000o`000?l@41001_ooool01?l0003ooooo
ooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0
003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X01Oooool01OnH
V9So0000o`000?m4A4Co^[Zj00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<08Gooooo002<ooooo`03o`000?oooooooooo00Kooooo00[o
0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0
003o410@00Gooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q08Gooooo002<oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000008Gooooo
002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@
4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`03ooooo`Ko00000_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P25ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;o
oooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<
o`000?l0003o0000olc<c025ooooo`00ROooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000
o`000003o`0000Gooooo00?o0000ooooooooool02Oooool00ol@413o0000o`000003o`0000[ooooo
00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@4100QOooool008Wo
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000QOoo
ool008Wooooo1ol00005ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o00003Oooool0
0ol0003oooooooooo`0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`00
0?l@413oZJVY08Gooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37583 m
.11905 .32179 L
.21429 .27239 L
.30952 .22754 L
.40476 .18691 L
.5 .15002 L
.59524 .11629 L
.69048 .08506 L
.78571 .05569 L
.88095 .02754 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool3o`0000;ooooo00?o0000oooo
ooooool04?ooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`009_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo02oooooo0ol00005ooooo`03o`000?oooooooooo00oooooo0_l00002oooo
o`;o00002Oooool002Kooooo00?o0000ooooooooool0oooooolDooooo`?o0000:Oooool002Kooooo
00?o0000ooooooooool0ooooool@ooooo`Co0000;?ooool002Kooooo0_l0003oooooo`kooooo0ol0
000`ooooo`009_ooool00ol0003oooooooooo`3oooooo`[ooooo0ol0000cooooo`009_ooool00ol0
003oooooooooo`3oooooo`Oooooo0ol0000fooooo`009_ooool00ol0003oooooooooo`3oooooo`Co
oooo0ol0000iooooo`009_ooool00ol0003oooooooooo`3oooooo`Co0000??ooool002Kooooo0_l0
003mooooo`?o0000@?ooool002Kooooo00?o0000ooooooooool0n?ooool4o`0004?ooooo000Voooo
o`03o`000?oooooooooo0?Cooooo1?l00017ooooo`009_ooool00ol0003oooooooooo`3aooooo`?o
0000Boooool002Kooooo0_l0003^ooooo`Co0000C_ooool002Kooooo00?o0000ooooooooool0jOoo
ool4o`0005;ooooo000Vooooo`03o`000?oooooooooo0>Kooooo0ol0001Fooooo`009_ooool00ol0
003oooooooooo`3Rooooo`Co0000FOooool002Kooooo00?o0000ooooooooool0goooool3o`0005go
oooo000Vooooo`;o0000gOooool3o`00063ooooo000Vooooo`03o`000?oooooooooo0=Wooooo0ol0
001Sooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0eOooool4o`0006Kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0d_ooool3o`0006[ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@
413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3?
ooooo`?o0000KOooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oooooo
ooooooooool000001oooool00omgMgOo<S8booooo`04ooooo`?o0000c?ooool3o`00073ooooo0003
ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000Cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0<Wooooo0ol0001cooooo`00
0oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4004oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0aOooool4o`0007Kooooo0003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`32ooooo`?o0000N_ooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool4o`0000Kooooo0_l0
0030ooooo`?o0000OOooool002Kooooo00?o0000ooooooooool0_?ooool3o`00083ooooo000Voooo
o`03o`000?oooooooooo0;Sooooo1?l00023ooooo`009_ooool00ol0003oooooooooo`2eooooo`?o
0000Qoooool002Kooooo00?o0000ooooooooool0/_ooool3o`0008[ooooo000Vooooo`;o0000/?oo
ool3o`0008gooooo000Vooooo`03o`000?oooooooooo0:cooooo0ol0002@ooooo`009_ooool00ol0
003oooooooooo`2Yooooo`?o0000Toooool002Kooooo00?o0000ooooooooool0Y_ooool3o`0009Ko
oooo000Vooooo`03o`000?oooooooooo0:?ooooo0ol0002Iooooo`009_ooool2o`000:;ooooo0_l0
002Looooo`009_ooool00ol0003oooooooooo`2Nooooo`?o0000W_ooool002Kooooo00?o0000oooo
ooooool0Voooool3o`000:7ooooo000Vooooo`03o`000?oooooooooo09Wooooo0_l0002Tooooo`00
9_ooool2o`0009Oooooo0ol0002Vooooo`009_ooool00ol0003oooooooooo`2Dooooo`;o0000ZOoo
ool002Kooooo00?o0000ooooooooool0TOooool3o`000:_ooooo000;ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo08kooooo0ol0002^ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0S?ooool2o`000;7ooooo000;oooo
o`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`?o0000ROooool3
o`000;?ooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo08Kooooo0ol0002fooooo`002oooool01Ol0003ooooooooooooooooo
000000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`24ooooo`;o0000^Oooool0
00_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0POooool3o`000;_ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo07kooooo0ol0002nooooo`002oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001oooool2o`0007gooooo0_l00031
ooooo`009_ooool00ol0003oooooooooo`1iooooo`?o0000`oooool002Kooooo00?o0000oooooooo
ool0Moooool2o`000<Kooooo000Vooooo`03o`000?oooooooooo07Cooooo0ol00038ooooo`009_oo
ool2o`0007;ooooo0ol0003;ooooo`009_ooool00ol0003oooooooooo`1_ooooo`;o0000c_ooool0
02Kooooo00?o0000ooooooooool0K?ooool3o`000=3ooooo000Vooooo`03o`000?oooooooooo06[o
oooo0_l0003Cooooo`009_ooool00ol0003oooooooooo`1Xooooo`;o0000eOooool002Kooooo0_l0
001Vooooo`?o0000eoooool002Kooooo00?o0000ooooooooool0Hoooool2o`000=[ooooo000Voooo
o`03o`000?oooooooooo063ooooo0ol0003Looooo`009_ooool00ol0003oooooooooo`1Nooooo`;o
0000goooool002Kooooo00?o0000ooooooooool0Foooool3o`000>7ooooo000Vooooo`;o0000F_oo
ool2o`000>Cooooo000Vooooo`03o`000?oooooooooo05Oooooo0_l0003Vooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000Go410@ooooooooooooooooodA4
A002o`000003oc8b<_oMgMgooooo00Cooooo00?o0000ooooooooool0E?ooool3o`000>Sooooo0003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01_oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo05;ooooo0_l0003[ooooo`000oooool0
1Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`03ooooo`?o0000D?ooool2o`000>gooooo0003ooooo`05o`000?ooooooooooooooool000003_oo
ool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0C_oo
ool2o`000>oooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooooooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1<ooooo`;o0000
lOooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1:ooooo`;o0000loooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`18ooooo`;o0000mOooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`03oeEEEOmVIVKo000000Gooooo1?l00006ooooo`;o0000Aoooool2o`000?Oooooo
000Vooooo`03o`000?oooooooooo04Cooooo0_l0003iooooo`009_ooool00ol0003oooooooooo`12
ooooo`;o0000noooool002Kooooo00?o0000ooooooooool0@?ooool2o`000?gooooo000Vooooo`03
o`000?oooooooooo03kooooo0_l0003oooooo`009_ooool2o`0003gooooo0_l0003oooooo`;ooooo
000Vooooo`03o`000?oooooooooo03[ooooo0_l0003oooooo`Cooooo000Vooooo`03o`000?oooooo
oooo03Sooooo0_l0003oooooo`Kooooo000Vooooo`03o`000?oooooooooo03Kooooo0_l0003ooooo
o`Sooooo000Vooooo`03o`000?oooooooooo03Cooooo0_l0003oooooo`[ooooo000Vooooo`;o0000
<oooool2o`000?oooooo3?ooool002Kooooo00?o0000ooooooooool0<?ooool2o`000?oooooo3_oo
ool002Kooooo00?o0000ooooooooool0;_ooool2o`000?oooooo4?ooool002Kooooo00?o0000oooo
ooooool0;?ooool2o`000?oooooo4_ooool002Kooooo0_l0000[ooooo`;o0000oooooolDooooo`00
9_ooool00ol0003oooooooooo`0Xooooo`;o0000oooooolFooooo`002oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo0?oooooo5_ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool09Oooool2o`000?oo
oooo6Oooool000_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?o0000ooooooooool08oooool2o`000?oooooo6oooool000_ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0000Qooooo`;o0000oooooolMooooo`00
2oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003o
ooooooooo`0Oooooo`;o0000oooooolOooooo`002oooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Mooooo`;o0000oooooolQooooo`00
2oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006oooo
o`03o`000?oooooooooo01_ooooo0_l0003oooooob?ooooo000;ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool06Oooool2
o`000?oooooo9Oooool002Kooooo0_l0000Hooooo`;o0000oooooolWooooo`009_ooool00ol0003o
ooooooooo`0Eooooo`;o0000oooooolYooooo`009_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo0?oooooo:Oooool002Kooooo00?o0000ooooooooool04_ooool2o`000?oooooo;?oo
ool002Kooooo0_l0000Aooooo`;o0000ooooool^ooooo`009_ooool00ol0003oooooooooo`0>oooo
o`;o0000ooooool`ooooo`009_ooool00ol0003oooooooooo`0<ooooo`;o0000oooooolbooooo`00
9_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0?oooooo<_ooool002Kooooo00?o
0000ooooooooool02Oooool2o`000?oooooo=Oooool002Kooooo0_l00008ooooo`;o0000oooooolg
ooooo`009_ooool00ol0003oooooooooo`05ooooo`;o0000ooooooliooooo`009_ooool00ol0003o
ooooooooo`03ooooo`;o0000oooooolkooooo`009_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0?oooooo>oooool002Kooooo00?o0000ooooooooool00_l0003oooooockooooo000V
ooooo`?o0000oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooo
oom0ooooo`000oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3ooooood3ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood3o
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00006ooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0oooo
o`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000
oc8b<_o<c<`01_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Ol0003ooooooooooooo
oooo000000kooooo00?oZJVYoa0@4?ooool01Oooool3o`000?oooooo@?ooool000_ooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000ooooooooool0oooo
oom0ooooo`002oooool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q8Oooool01Ooo
ool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol@413oV9RHoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooom0ooooo`002ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000
ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o
0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003ooooo
ooooo`3ooooood3ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
00GoV9RHoa0@4?l0003o<S8bolc<c004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`3ooooood3ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`03ooooo`?o0000oooooom0ooooo`000oooool01Ol0
003ooooooooooooooooo000000kooooo00?oZJVYoa0@4?ooool01_ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go0000ooooooooooooooooo`00000=
ooooo`03oa0@4?l0003o^[Zj00Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03okZj^_lQ
8B7ooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood3ooooo0003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RHoooooonj^[[o000000Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Cooooo1?l00006ooooo`;o
0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000
ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`00
0?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003o
ooooooooo`3ooooood3ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0000Kooooo00?o0000ooooooooool0oooooom0ooooo`00
2oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool3o`00
0?oooooo@?ooool000_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`000?ooooooB_ooool000_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co
00000?ooooooB_ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co
00000?ooooooB_ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003o
oooo0?ooooooBOooool00?ooooooJOooool009Gooooo0_l0000;ooooo`03o`000?nj^[[ooooo00co
oooo0_l00005ooooo`03o`000?nj^[[ooooo0:gooooo002Eooooo`03o`000?oooooooooo00[ooooo
0_lb<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:^ooooo`00R_ooool01Ol@413o0000o`00
0?l0003o410@00Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo
0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`03oooo
o`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Co410@o`000?m4A4Coc<c<Q_ooool008cooooo00?o
0000ooooooooool01_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3
ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oo
oooooooo00?ooooo00?oc<c<o`000?l@41001Oooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko
00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oiRHV?l@413ogMgM
08Gooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo
0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00on7QhOoEEEEooooo`24
ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q
8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool00oooool6o`0000;ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?lQ
8B7o0000oeEEEOl00000QOooool008cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
ob4Q8On7QhOooooooiRHV?l00000QOooool008Wooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@
o`000?l000000ol00005ooooo`03o`000?oooooooooo00Wooooo00?o410@o`000?l000000ol0000:
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000008Gooooo
0029ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OlQ8B7oV9RHoooooomgMgOoEEEE
08Gooooo0029ooooo`Oo00001Oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0000go
oooo00?o0000ooooooooool02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Goc<c<oa0@
4?l0003o<S8bonk^kP25ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .38627 m
.11905 .33269 L
.21429 .28316 L
.30952 .23764 L
.40476 .19596 L
.5 .15773 L
.59524 .1225 L
.69048 .08971 L
.78571 .05878 L
.88095 .02908 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool3o`0000;ooooo00?o0000oooo
ooooool04?ooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`009_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo02oooooo0ol00005ooooo`03o`000?oooooooooo00oooooo0_l00002oooo
o`;o00002Oooool002Kooooo00?o0000ooooooooool0oooooolDooooo`?o0000:Oooool002Kooooo
00?o0000ooooooooool0ooooool@ooooo`Co0000;?ooool002Kooooo0_l0003oooooo`kooooo0ol0
000`ooooo`009_ooool00ol0003oooooooooo`3oooooo`[ooooo0ol0000cooooo`009_ooool00ol0
003oooooooooo`3oooooo`Oooooo0ol0000fooooo`009_ooool00ol0003oooooooooo`3oooooo`Co
oooo0ol0000iooooo`009_ooool00ol0003oooooooooo`3oooooo`Co0000??ooool002Kooooo0_l0
003mooooo`?o0000@?ooool002Kooooo00?o0000ooooooooool0nOooool3o`0004?ooooo000Voooo
o`03o`000?oooooooooo0?Kooooo0ol00016ooooo`009_ooool00ol0003oooooooooo`3booooo`Co
0000BOooool002Kooooo0_l0003`ooooo`?o0000COooool002Kooooo00?o0000ooooooooool0k?oo
ool3o`00053ooooo000Vooooo`03o`000?oooooooooo0>Wooooo0ol0001Cooooo`009_ooool00ol0
003oooooooooo`3Vooooo`?o0000E_ooool002Kooooo00?o0000ooooooooool0h_ooool4o`0005Wo
oooo000Vooooo`;o0000h?ooool3o`0005gooooo000Vooooo`03o`000?oooooooooo0=cooooo0ol0
001Pooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0fOooool3o`0006?ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0eOooool4o`0006Kooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@
413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3B
ooooo`?o0000J_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oooooo
ooooooooool000001oooool00omgMgOo<S8booooo`04ooooo`?o0000coooool3o`0006gooooo0003
ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000Cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0<cooooo0ol0001`ooooo`00
0oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4004oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0bOooool3o`0007?ooooo0003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`36ooooo`?o0000M_ooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool4o`0000Kooooo0_l0
0034ooooo`?o0000NOooool002Kooooo00?o0000ooooooooool0`?ooool3o`0007cooooo000Voooo
o`03o`000?oooooooooo0;gooooo0ol0001oooooo`009_ooool00ol0003oooooooooo`2jooooo`?o
0000P_ooool002Kooooo00?o0000ooooooooool0]oooool3o`0008Gooooo000Vooooo`;o0000]Ooo
ool3o`0008Sooooo000Vooooo`03o`000?oooooooooo0;7ooooo0ol0002;ooooo`009_ooool00ol0
003oooooooooo`2^ooooo`?o0000S_ooool002Kooooo00?o0000ooooooooool0Zoooool3o`00097o
oooo000Vooooo`03o`000?oooooooooo0:Wooooo0_l0002Dooooo`009_ooool2o`000:Oooooo0ol0
002Fooooo`009_ooool00ol0003oooooooooo`2Sooooo`?o0000VOooool002Kooooo00?o0000oooo
ooooool0XOooool2o`0009cooooo000Vooooo`03o`000?oooooooooo09kooooo0ol0002Nooooo`00
9_ooool2o`0009cooooo0ol0002Qooooo`009_ooool00ol0003oooooooooo`2Iooooo`;o0000Y?oo
ool002Kooooo00?o0000ooooooooool0U_ooool3o`000:Kooooo000;ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo09Cooooo0_l0002Yooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0TOooool3o`000:_ooooo000;oooo
o`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`?o0000S_ooool3
o`000:kooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo08cooooo0_l0002aooooo`002oooool01Ol0003ooooooooooooooooo
000000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`29ooooo`?o0000/oooool0
00_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0Qoooool2o`000;Kooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Gooooo0_l0002hooooo`002oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001oooool2o`0008?ooooo0ol0002j
ooooo`009_ooool00ol0003oooooooooo`20ooooo`;o0000_Oooool002Kooooo00?o0000oooooooo
ool0OOooool3o`000;oooooo000Vooooo`03o`000?oooooooooo07_ooooo0_l00032ooooo`009_oo
ool2o`0007Wooooo0ol00034ooooo`009_ooool00ol0003oooooooooo`1fooooo`;o0000aoooool0
02Kooooo00?o0000ooooooooool0M?ooool2o`000<Wooooo000Vooooo`03o`000?oooooooooo077o
oooo0ol0003;ooooo`009_ooool00ol0003oooooooooo`1_ooooo`;o0000c_ooool002Kooooo0_l0
001]ooooo`?o0000d?ooool002Kooooo00?o0000ooooooooool0J_ooool2o`000=?ooooo000Voooo
o`03o`000?oooooooooo06Sooooo0_l0003Eooooo`009_ooool00ol0003oooooooooo`1Uooooo`?o
0000eoooool002Kooooo00?o0000ooooooooool0Hoooool2o`000=[ooooo000Vooooo`;o0000HOoo
ool3o`000=cooooo000Vooooo`03o`000?oooooooooo05kooooo0_l0003Oooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000Go410@ooooooooooooooooodA4
A002o`000003oc8b<_oMgMgooooo00Cooooo00?o0000ooooooooool0Foooool3o`000>7ooooo0003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01_oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo05Wooooo0_l0003Tooooo`000oooool0
1Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`03ooooo`?o0000Eoooool2o`000>Kooooo0003ooooo`05o`000?ooooooooooooooool000003_oo
ool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0E?oo
ool3o`000>Sooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooooooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1Booooo`;o0000
joooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1@ooooo`;o0000kOooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1>ooooo`;o0000koooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`03oeEEEOmVIVKo000000Gooooo1?l00006ooooo`;o0000COooool2o`000?7ooooo
000Vooooo`03o`000?oooooooooo04[ooooo0_l0003cooooo`009_ooool00ol0003oooooooooo`18
ooooo`;o0000mOooool002Kooooo00?o0000ooooooooool0A_ooool2o`000?Oooooo000Vooooo`03
o`000?oooooooooo04Cooooo0_l0003iooooo`009_ooool2o`0004?ooooo0_l0003kooooo`009_oo
ool00ol0003oooooooooo`10ooooo`;o0000oOooool002Kooooo00?o0000ooooooooool0?_ooool2
o`000?oooooo000Vooooo`03o`000?oooooooooo03cooooo0_l0003oooooo`;ooooo000Vooooo`03
o`000?oooooooooo03[ooooo0_l0003oooooo`Cooooo000Vooooo`;o0000>Oooool2o`000?oooooo
1_ooool002Kooooo00?o0000ooooooooool0=_ooool2o`000?oooooo2?ooool002Kooooo00?o0000
ooooooooool0=?ooool2o`000?oooooo2_ooool002Kooooo00?o0000ooooooooool0<_ooool2o`00
0?oooooo3?ooool002Kooooo0_l0000aooooo`;o0000ooooool>ooooo`009_ooool00ol0003ooooo
ooooo`0^ooooo`;o0000ooooool@ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`0/ooooo`;o0000oooooolBooooo`002ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool00ol0003oooooooooo`0Zooooo`;o0000oooooolDooooo`002oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`0Xooooo`;o
0000oooooolFooooo`002oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^
k^h01_ooool3o`0002Oooooo00?o0000ooooooooool0oooooolFooooo`002oooool01Ol0003ooooo
oooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0Uooooo`;o
0000oooooolIooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Sooooo`;o0000oooooolKooooo`002oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo
027ooooo0_l0003ooooooagooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnH
V9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool07oooool2o`000?oooooo7oooool0
02Kooooo0_l0000Nooooo`;o0000oooooolQooooo`009_ooool00ol0003oooooooooo`0Kooooo`;o
0000oooooolSooooo`009_ooool00ol0003oooooooooo`0Iooooo`;o0000oooooolUooooo`009_oo
ool00ol0003oooooooooo`0Gooooo`;o0000oooooolWooooo`009_ooool2o`0001Kooooo0_l0003o
ooooobWooooo000Vooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0oooooolYoooo
o`009_ooool00ol0003oooooooooo`0Booooo`;o0000ooooool/ooooo`009_ooool00ol0003ooooo
ooooo`0@ooooo`;o0000ooooool^ooooo`009_ooool00ol0003oooooooooo`0>ooooo`;o0000oooo
ool`ooooo`009_ooool2o`0000gooooo0_l0003ooooooc;ooooo000Vooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0oooooolbooooo`009_ooool00ol0003oooooooooo`09ooooo`;o
0000ooooooleooooo`009_ooool00ol0003oooooooooo`07ooooo`;o0000oooooolgooooo`009_oo
ool00ol0003oooooooooo`05ooooo`;o0000ooooooliooooo`009_ooool2o`0000Cooooo0_l0003o
oooooc_ooooo000Vooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooolkoooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool00_l0003oooooockooooo0003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A007ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003ooooood3ooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0
003ooooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooo
od7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1
ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooo
od3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@
4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o
0000ooooooooool0oooooom0ooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05o`000?oooooo
ooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000oooooom0ooooo`002oooool0
1Ol0003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01_ooool00ol0003ooooooooo
o`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qoooo
o`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooood3ooooo
000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Ko
oooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0003ooooood3ooooo0003oooo
o`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`06ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol0003ooooooooooooooooo
000000gooooo00?o410@o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o
^[Zjob4Q8Oooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l00000
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01?ooool4o`0000Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003o
ooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo
00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`3ooooood3o
oooo000;ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007oooo
o`?o0000oooooom0ooooo`002oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEE
EOoooooo0000oooooom:ooooo`002oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMg
olc<c?l00000oooooom:ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l00000oooooom:ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMg
o`000?ooool0oooooom9ooooo`00oooooomYooooo`00V?ooool2o`0000_ooooo00?o0000okZj^_oo
ool03?ooool2o`0000Kooooo00?o0000okZj^_ooool0ZOooool009Sooooo00?o0000ooooooooool0
2_ooool2oc8b<Pkooooo00?o0000ooooooooool01?ooool2oc8b<Z[ooooo002>ooooo`05oa0@4?l0
003o0000o`000?l@41001Oooool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000;ooooo
00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?o0000oooooooo
ool01?ooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X02_ooool4o`00
0003oa0@4?oooooooooo00;ooooo0_lQ8B6;ooooo`00T?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03olc<c?l0003o
410@00Gooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oooooooooo00Cooooo00?o
c<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo1_l00004ooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B6;ooooo`00T?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2Aooooo`00T?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Cok^k^ob4Q8Ol@413ok^k^
2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1?ooool6o`0000Cooooo00?o0000ooooooooool0TOooool0093ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`03ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
TOooool008gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Cooooo
00?o0000ooooooooool02Oooool00ol@413o0000o`000003o`0000gooooo00?o0000ooooooooool0
TOooool008gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0TOooool008gooooo1ol00004ooooo`;o00004ooo
ool00ol0003oooooooooo`04ooooo`;o00003Oooool00ol0003oooooooooo`0<ooooo`03oeEEEOmV
IVKo000009?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .39525 m
.11905 .34221 L
.21429 .2927 L
.30952 .24678 L
.40476 .20429 L
.5 .16499 L
.59524 .12847 L
.69048 .09427 L
.78571 .06184 L
.88095 .03062 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool3o`0000;ooooo00?o0000oooo
ooooool04?ooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`009_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo02oooooo0ol00005ooooo`03o`000?oooooooooo00oooooo0_l00002oooo
o`;o00002Oooool002Kooooo00?o0000ooooooooool0oooooolDooooo`?o0000:Oooool002Kooooo
00?o0000ooooooooool0ooooool@ooooo`Co0000;?ooool002Kooooo0_l0003oooooo`kooooo0ol0
000`ooooo`009_ooool00ol0003oooooooooo`3oooooo`[ooooo0ol0000cooooo`009_ooool00ol0
003oooooooooo`3oooooo`Oooooo0ol0000fooooo`009_ooool00ol0003oooooooooo`3oooooo`Co
oooo0ol0000iooooo`009_ooool00ol0003oooooooooo`3oooooo`7ooooo0ol0000looooo`009_oo
ool2o`000?kooooo0ol0000oooooo`009_ooool00ol0003oooooooooo`3jooooo`?o0000@_ooool0
02Kooooo00?o0000ooooooooool0moooool3o`0004Gooooo000Vooooo`03o`000?oooooooooo0?Co
oooo0ol00018ooooo`009_ooool2o`000?;ooooo0ol0001;ooooo`009_ooool00ol0003ooooooooo
o`3^ooooo`?o0000C_ooool002Kooooo00?o0000ooooooooool0joooool3o`00057ooooo000Voooo
o`03o`000?oooooooooo0>Sooooo0ol0001Dooooo`009_ooool00ol0003oooooooooo`3Uooooo`?o
0000Eoooool002Kooooo0_l0003Tooooo`;o0000F_ooool002Kooooo00?o0000ooooooooool0h?oo
ool3o`0005cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`3Mooooo`?o0000Goooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3Jooooo`?o0000H_ooool000?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0=Oooooo0ol0001Uooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000
ooooooooooooooooo`000007ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003Dooooo`?o0000J?oo
ool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0dOooool3o`0006_o
oooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3>ooooo`?o0000K_ooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0<_ooooo0ol0001aooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co00001_oo
ool2o`000<Wooooo0ol0001dooooo`009_ooool00ol0003oooooooooo`36ooooo`;o0000Moooool0
02Kooooo00?o0000ooooooooool0`oooool3o`0007Wooooo000Vooooo`03o`000?oooooooooo0<3o
oooo0ol0001looooo`009_ooool00ol0003oooooooooo`2mooooo`?o0000Ooooool002Kooooo0_l0
002kooooo`?o0000P_ooool002Kooooo00?o0000ooooooooool0]oooool3o`0008Gooooo000Voooo
o`03o`000?oooooooooo0;Cooooo0ol00028ooooo`009_ooool00ol0003oooooooooo`2aooooo`?o
0000Roooool002Kooooo00?o0000ooooooooool0[_ooool3o`0008kooooo000Vooooo`;o0000[?oo
ool3o`00097ooooo000Vooooo`03o`000?oooooooooo0:Wooooo0_l0002Dooooo`009_ooool00ol0
003oooooooooo`2Vooooo`?o0000U_ooool002Kooooo00?o0000ooooooooool0Xoooool3o`0009Wo
oooo000Vooooo`;o0000X_ooool2o`0009cooooo000Vooooo`03o`000?oooooooooo09kooooo0ol0
002Nooooo`009_ooool00ol0003oooooooooo`2Kooooo`?o0000XOooool000_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0VOooool2o`000:Cooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Fooooo`?o0000Y_ooool0
00_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo0ol0002D
ooooo`;o0000ZOooool000_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0TOooool3o`000:_ooooo000;ooooo`05o`000?oooooooooo
ooooool000003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08kooooo0ol0002^
ooooo`002oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`2<ooooo`;o0000/Oooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0ROooool3o`000;?ooooo000;oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000007ooooo`;o0000R?ooool2
o`000;Kooooo000Vooooo`03o`000?oooooooooo08Gooooo0_l0002hooooo`009_ooool00ol0003o
ooooooooo`22ooooo`?o0000^_ooool002Kooooo00?o0000ooooooooool0P?ooool2o`000;gooooo
000Vooooo`;o0000O_ooool3o`000;oooooo000Vooooo`03o`000?oooooooooo07_ooooo0_l00032
ooooo`009_ooool00ol0003oooooooooo`1hooooo`?o0000a?ooool002Kooooo00?o0000oooooooo
ool0M_ooool2o`000<Oooooo000Vooooo`03o`000?oooooooooo07Cooooo0_l00039ooooo`009_oo
ool2o`0007;ooooo0ol0003;ooooo`009_ooool00ol0003oooooooooo`1_ooooo`;o0000c_ooool0
02Kooooo00?o0000ooooooooool0KOooool2o`000=3ooooo000Vooooo`03o`000?oooooooooo06[o
oooo0ol0003Booooo`009_ooool00ol0003oooooooooo`1Xooooo`;o0000eOooool002Kooooo0_l0
001Wooooo`;o0000eoooool002Kooooo00?o0000ooooooooool0I?ooool2o`000=Wooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000001Ol@413ooooooooooooo
ooooA4A400;o000000?o<S8bomgMgOooool01?ooool00ol0003oooooooooo`1Qooooo`?o0000fooo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0Goooool2o`000=kooooo0003
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00?ooooo0ol0001Mooooo`;o0000h?ooool000?ooooo00Go0000ooooooooooooooooo`00
000>ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`1Kooooo`;o0000h_ooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo05Wooooo
0_l0003Tooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Kooooo0ol0003Vooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo05Cooooo0_l0003Yooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4o`0000Kooooo0_l0001Cooooo`;o0000
joooool002Kooooo00?o0000ooooooooool0D?ooool2o`000>gooooo000Vooooo`03o`000?oooooo
oooo04kooooo0_l0003_ooooo`009_ooool00ol0003oooooooooo`1<ooooo`;o0000lOooool002Ko
oooo00?o0000ooooooooool0B_ooool2o`000??ooooo000Vooooo`;o0000BOooool2o`000?Gooooo
000Vooooo`03o`000?oooooooooo04Kooooo0_l0003gooooo`009_ooool00ol0003oooooooooo`14
ooooo`;o0000nOooool002Kooooo00?o0000ooooooooool0@_ooool2o`000?_ooooo000Vooooo`03
o`000?oooooooooo043ooooo0_l0003mooooo`009_ooool2o`0003oooooo0_l0003oooooo`009_oo
ool00ol0003oooooooooo`0looooo`;o0000ooooool2ooooo`009_ooool00ol0003oooooooooo`0j
ooooo`;o0000ooooool4ooooo`009_ooool00ol0003oooooooooo`0hooooo`;o0000ooooool6oooo
o`009_ooool2o`0003Oooooo0_l0003oooooo`Sooooo000Vooooo`03o`000?oooooooooo03Cooooo
0_l0003oooooo`[ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol00006ooooo`03o`000?oooooooooo03;ooooo0_l0003oooooo`cooooo000;ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo033ooooo0_l0003oooooo`kooooo000;ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo02kooooo0_l0003ooooooa3o
oooo000;ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`?o
0000;?ooool2o`000?oooooo4_ooool000_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0:_ooool2o`000?oooooo5?ooool000_ooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0:?ooool2o`000?oooooo5_ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
0?oooooo5_ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Uooooo`;o0000oooooolIooooo`009_ooool2o`00
02Cooooo0_l0003ooooooa_ooooo000Vooooo`03o`000?oooooooooo027ooooo0_l0003ooooooago
oooo000Vooooo`03o`000?oooooooooo01oooooo0_l0003ooooooaoooooo000Vooooo`03o`000?oo
oooooooo01gooooo0_l0003oooooob7ooooo000Vooooo`;o00007?ooool2o`000?oooooo8oooool0
02Kooooo00?o0000ooooooooool06Oooool2o`000?oooooo9Oooool002Kooooo00?o0000oooooooo
ool05oooool2o`000?oooooo9oooool002Kooooo00?o0000ooooooooool05Oooool2o`000?oooooo
:Oooool002Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`3oooooobWooooo000V
ooooo`;o00004oooool2o`000?oooooo;?ooool002Kooooo00?o0000ooooooooool04?ooool2o`00
0?oooooo;_ooool002Kooooo00?o0000ooooooooool03_ooool2o`000?oooooo<?ooool002Kooooo
00?o0000ooooooooool03?ooool2o`000?oooooo<_ooool002Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`3ooooooc;ooooo000Vooooo`;o00002_ooool2o`000?oooooo=Oooool0
02Kooooo00?o0000ooooooooool01oooool2o`000?oooooo=oooool000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo00Gooooo0_l0003oooooocWooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool00oooool2o`000?oooooo>oooool000?ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool3o`0000;ooooo00?o0000ooooooooool0oooooolkooooo`000oooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo00;o0000oooooolnooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo0ol0003ooooood3ooooo
0003ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo@Oooool002Ko
oooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo
000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0
ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`00
9_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?oo
ool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo
000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0oooooom0
ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[o
ooooogMgMolb<S801_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?oooooo
ooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Gooooo0ol0
003ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj
^P06ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@
400>ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0oooooom0ooooo`002oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`00
0?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000
oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oo
oooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oo
oooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool3
o`000?oooooo@?ooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413o
oooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003oooo
o`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj^P04ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00onj^[[o8B4Qooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
410@oiRHV?oooooo^[Zjo`000004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@04ooooo`Co00001_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oo
oooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooo
od7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooom0ooooo`002oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo0ol0003ooooood3ooooo000;ooooo`05o`000?oooooooooooooo
ool000002oooool01?oMgMgoEEEEooooool0003ooooood[ooooo000;ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`00003ooooood[ooooo000;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00oo^k^koA4A4o`00003ooooood[ooooo000;ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`3oooooodWooooo003oooooofWooooo002Eooooo`;o
00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2]ooooo`00
UOooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b
[_ooool008[ooooo00Go410@o`000?l0003o0000oa0@4006ooooo`04o`000?ooooooooooooooo`;o
00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj
00Cooooo00?o0000ooooooooool00oooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000
odA4A?nj^[X02_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`Co000000?o410@
ooooooooool0P_ooool008cooooo00?o0000ooooooooool01_ooool02_l0003ooooooooooooooooo
k^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^
k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Oooool01_l@
413o^[Zjonk^k_mgMgOo410@ooooo`Ko00001Oooool00ol0003oooooooooo`04ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`24ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo08Cooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool0
1?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo08Cooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool0
1?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Q?oo
ool008Wooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`00
0?oooooooooo00Wooooo00?o410@o`000?l000000ol0000=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0Q?ooool008Wooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`24ooooo`00ROooool7o`0000Gooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0
000=ooooo`03o`000?oooooooooo00cooooo00?oEEEEofIVI_l000003Oooool00omEEEGoIVIVo`00
0026ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .40307 m
.11905 .35057 L
.21429 .30119 L
.30952 .255 L
.40476 .21191 L
.5 .17171 L
.59524 .13408 L
.69048 .09859 L
.78571 .06478 L
.88095 .0321 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool3o`000003ooooool0003ooooo
017ooooo00Co8B4QogMgMomgMgOo<S8b2_ooool002Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0`ooooo`?o00001?ooool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`00
00Wooooo000Vooooo`03o`000?oooooooooo0?oooooo5Oooool3o`0002Sooooo000Vooooo`03o`00
0?oooooooooo0?oooooo4_ooool3o`0002_ooooo000Vooooo`;o0000ooooool@ooooo`?o0000;_oo
ool002Kooooo00?o0000ooooooooool0ooooool<ooooo`?o0000<Oooool002Kooooo00?o0000oooo
ooooool0ooooool9ooooo`?o0000=?ooool002Kooooo00?o0000ooooooooool0ooooool6ooooo`?o
0000=oooool002Kooooo00?o0000ooooooooool0ooooool3ooooo`?o0000>_ooool002Kooooo0_l0
003oooooo`;ooooo0_l0000mooooo`009_ooool00ol0003oooooooooo`3mooooo`?o0000?oooool0
02Kooooo00?o0000ooooooooool0n_ooool3o`0004;ooooo000Vooooo`03o`000?oooooooooo0?Oo
oooo0ol00015ooooo`009_ooool2o`000?Gooooo0ol00018ooooo`009_ooool00ol0003ooooooooo
o`3aooooo`?o0000Boooool002Kooooo00?o0000ooooooooool0k_ooool3o`0004kooooo000Voooo
o`03o`000?oooooooooo0>_ooooo0ol0001Aooooo`009_ooool00ol0003oooooooooo`3Xooooo`?o
0000E?ooool002Kooooo0_l0003Vooooo`?o0000Eoooool002Kooooo00?o0000ooooooooool0hooo
ool2o`0005[ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`3Pooooo`?o0000G?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3Mooooo`?o0000Goooool000?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0=[ooooo0ol0001Rooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000
ooooooooooooooooo`000007ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003Gooooo`?o0000IOoo
ool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0e?ooool3o`0006So
oooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3Aooooo`?o0000Joooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0<kooooo0ol0001^ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co00001_oo
ool2o`000<cooooo0ol0001aooooo`009_ooool00ol0003oooooooooo`38ooooo`?o0000M?ooool0
02Kooooo00?o0000ooooooooool0a_ooool2o`0007Oooooo000Vooooo`03o`000?oooooooooo0<?o
oooo0ol0001iooooo`009_ooool00ol0003oooooooooo`30ooooo`?o0000O?ooool002Kooooo0_l0
002oooooo`;o0000Ooooool002Kooooo00?o0000ooooooooool0^oooool3o`00087ooooo000Voooo
o`03o`000?oooooooooo0;Sooooo0ol00024ooooo`009_ooool00ol0003oooooooooo`2fooooo`;o
0000Qoooool002Kooooo00?o0000ooooooooool0/oooool3o`0008Wooooo000Vooooo`;o0000/_oo
ool2o`0008cooooo000Vooooo`03o`000?oooooooooo0:kooooo0ol0002>ooooo`009_ooool00ol0
003oooooooooo`2[ooooo`?o0000TOooool002Kooooo00?o0000ooooooooool0ZOooool2o`0009Co
oooo000Vooooo`;o0000Yoooool3o`0009Kooooo000Vooooo`03o`000?oooooooooo0:?ooooo0ol0
002Iooooo`009_ooool00ol0003oooooooooo`2Qooooo`;o0000W?ooool000_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0W_ooool3o`0009kooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Kooooo`?o0000XOooool0
00_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo0ol0002I
ooooo`;o0000Y?ooool000_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0U_ooool3o`000:Kooooo000;ooooo`05o`000?oooooooooo
ooooool000003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09Cooooo0_l0002Y
ooooo`002oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`2Aooooo`?o0000Zoooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0S_ooool3o`000:kooooo000;oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000007ooooo`;o0000SOooool2
o`000;7ooooo000Vooooo`03o`000?oooooooooo08Wooooo0ol0002cooooo`009_ooool00ol0003o
ooooooooo`27ooooo`;o0000]_ooool002Kooooo00?o0000ooooooooool0QOooool2o`000;Sooooo
000Vooooo`;o0000Poooool3o`000;[ooooo000Vooooo`03o`000?oooooooooo083ooooo0_l0002m
ooooo`009_ooool00ol0003oooooooooo`1mooooo`?o0000_oooool002Kooooo00?o0000oooooooo
ool0Noooool2o`000<;ooooo000Vooooo`03o`000?oooooooooo07Sooooo0ol00034ooooo`009_oo
ool2o`0007Oooooo0_l00037ooooo`009_ooool00ol0003oooooooooo`1dooooo`;o0000bOooool0
02Kooooo00?o0000ooooooooool0LOooool3o`000<_ooooo000Vooooo`03o`000?oooooooooo06oo
oooo0_l0003>ooooo`009_ooool00ol0003oooooooooo`1]ooooo`;o0000d?ooool002Kooooo0_l0
001/ooooo`;o0000d_ooool002Kooooo00?o0000ooooooooool0JOooool2o`000=Cooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000001Ol@413ooooooooooooo
ooooA4A400;o000000?o<S8bomgMgOooool01?ooool00ol0003oooooooooo`1Wooooo`;o0000e_oo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0IOooool2o`000=Sooooo0003
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00?ooooo0ol0001Sooooo`;o0000f_ooool000?ooooo00Go0000ooooooooooooooooo`00
000>ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`1Pooooo`?o0000g?ooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo05kooooo
0_l0003Oooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05cooooo0_l0003Qooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo05[ooooo0_l0003Sooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4o`0000Kooooo0_l0001Iooooo`;o0000
iOooool002Kooooo00?o0000ooooooooool0E_ooool2o`000>Oooooo000Vooooo`03o`000?oooooo
oooo05Cooooo0_l0003Yooooo`009_ooool00ol0003oooooooooo`1Booooo`;o0000joooool002Ko
oooo00?o0000ooooooooool0D?ooool2o`000>gooooo000Vooooo`;o0000Coooool2o`000>oooooo
000Vooooo`03o`000?oooooooooo04cooooo0_l0003aooooo`009_ooool00ol0003oooooooooo`1:
ooooo`;o0000loooool002Kooooo00?o0000ooooooooool0B?ooool2o`000?Gooooo000Vooooo`03
o`000?oooooooooo04Kooooo0_l0003gooooo`009_ooool2o`0004Gooooo0_l0003iooooo`009_oo
ool00ol0003oooooooooo`12ooooo`;o0000noooool002Kooooo00?o0000ooooooooool0@?ooool2
o`000?gooooo000Vooooo`03o`000?oooooooooo03kooooo0_l0003oooooo`009_ooool2o`0003go
oooo0_l0003oooooo`;ooooo000Vooooo`03o`000?oooooooooo03[ooooo0_l0003oooooo`Cooooo
000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`00
0?oooooooooo03Sooooo0_l0003oooooo`Kooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo03Ko
oooo0_l0003oooooo`Sooooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`03o`000?oooooooooo03Cooooo0_l0003oooooo`[ooooo000;ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000<_ooool2o`000?oo
oooo3?ooool000_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0<?ooool2o`000?oooooo3_ooool000_ooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;_ooool2o`000?oo
oooo4?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001_ooool00ol0003oooooooooo`0/ooooo`;o0000oooooolBooooo`002oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooo
oooo02[ooooo0_l0003ooooooaCooooo000Vooooo`;o0000:Oooool2o`000?oooooo5_ooool002Ko
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`3ooooooaKooooo000Vooooo`03o`00
0?oooooooooo02Gooooo0_l0003ooooooaWooooo000Vooooo`03o`000?oooooooooo02?ooooo0_l0
003ooooooa_ooooo000Vooooo`;o00008_ooool2o`000?oooooo7Oooool002Kooooo00?o0000oooo
ooooool07oooool2o`000?oooooo7oooool002Kooooo00?o0000ooooooooool07Oooool2o`000?oo
oooo8Oooool002Kooooo00?o0000ooooooooool06oooool2o`000?oooooo8oooool002Kooooo00?o
0000ooooooooool06Oooool2o`000?oooooo9Oooool002Kooooo0_l0000Hooooo`;o0000oooooolW
ooooo`009_ooool00ol0003oooooooooo`0Eooooo`;o0000oooooolYooooo`009_ooool00ol0003o
ooooooooo`0Cooooo`;o0000ooooool[ooooo`009_ooool00ol0003oooooooooo`0Aooooo`;o0000
ooooool]ooooo`009_ooool00ol0003oooooooooo`0?ooooo`;o0000ooooool_ooooo`009_ooool2
o`0000kooooo0_l0003ooooooc7ooooo000Vooooo`03o`000?oooooooooo00_ooooo0_l0003ooooo
oc?ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo0?oooooo<oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`08ooooo`;o0000oooooolfooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o00001_ooool2o`000?oooooo>?oo
ool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`04ooooo`;o0000ooooooljooooo`000oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool00_ooool2o`000?oooooo??ooool000?ooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02o`000?oooooo?_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`?o
0000oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo@Oooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`00
0?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003o
oooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnH
V9So410@o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_oo
ool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Gooooo0ol0003ooooood3ooooo000;
ooooo`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj^P06ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03okZj^_lQ
8B7ooooo00Gooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?oooooo
@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT01_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0oooo
o`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool3o`000?oooooo@?ooool0
00?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Kooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05o`000?oooooooooo
ooooool000003Oooool00ol@413o0000okZj^P04ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onj^[[o8B4Qooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zj
o`000004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom0ooooo`000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@04ooooo`Co
00001_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom0ooooo`00
2oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo0?oo
oooo@?ooool000_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`00
00Oooooo0ol0003ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000002oooool01?oM
gMgoEEEEooooool0003ooooood[ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0omgMgOoc<c<o`00003ooooood[ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0oo^k^koA4A4o`00003ooooood[ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`3oooooodWooooo003oooooofWooooo002Eooooo`;o00002oooool00ol0003o
^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2]ooooo`00UOooool00ol0003ooooo
ooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b[_ooool008[ooooo00Go
410@o`000?l0003o0000oa0@4006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?o
oooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000oooo
ooooool00oooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X02_ooool4
o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go0000QOooool008cooooo00?o0000oooo
ooooool01_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03
olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo
00?ooooo00?oc<c<o`000?l@41001Oooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00001Ooo
ool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A408Gooooo
002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@
4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h0Q_ooool008cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo
1_l00005ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h0QOooool008cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool00omgMgOoIVIVooooo`24ooooo`00ROooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o
00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool02Oooool00ol@413o
0000o`000003o`0000gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`23ooooo`00
ROooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@4100QOooool008Wo
oooo1ol00005ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003o
ooooooooo`0<ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c025oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .40992 m
.11905 .35796 L
.21429 .30876 L
.30952 .2624 L
.40476 .21883 L
.5 .17787 L
.59524 .13926 L
.69048 .10263 L
.78571 .06753 L
.88095 .0335 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool3o`000003ooooool0003ooooo
017ooooo00Co8B4QogMgMomgMgOo<S8b2_ooool002Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0`ooooo`?o00001?ooool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`00
00Wooooo000Vooooo`03o`000?oooooooooo0?oooooo5Oooool3o`0002Sooooo000Vooooo`03o`00
0?oooooooooo0?oooooo4_ooool3o`0002_ooooo000Vooooo`;o0000ooooool@ooooo`?o0000;_oo
ool002Kooooo00?o0000ooooooooool0ooooool<ooooo`?o0000<Oooool002Kooooo00?o0000oooo
ooooool0ooooool9ooooo`?o0000=?ooool002Kooooo00?o0000ooooooooool0ooooool6ooooo`?o
0000=oooool002Kooooo00?o0000ooooooooool0ooooool3ooooo`?o0000>_ooool002Kooooo0_l0
003oooooo`;ooooo0_l0000mooooo`009_ooool00ol0003oooooooooo`3mooooo`?o0000?oooool0
02Kooooo00?o0000ooooooooool0n_ooool3o`0004;ooooo000Vooooo`03o`000?oooooooooo0?So
oooo0_l00015ooooo`009_ooool2o`000?Kooooo0ol00017ooooo`009_ooool00ol0003ooooooooo
o`3booooo`?o0000B_ooool002Kooooo00?o0000ooooooooool0l?ooool2o`0004gooooo000Voooo
o`03o`000?oooooooooo0>gooooo0ol0001?ooooo`009_ooool00ol0003oooooooooo`3[ooooo`;o
0000D_ooool002Kooooo0_l0003Yooooo`?o0000E?ooool002Kooooo00?o0000ooooooooool0iOoo
ool3o`0005Oooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`3Sooooo`;o0000F_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3Pooooo`?o0000G?ooool000?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0=gooooo0ol0001Oooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000
ooooooooooooooooo`000007ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003Jooooo`?o0000H_oo
ool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0eoooool3o`0006Go
oooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3Dooooo`?o0000J?ooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=7ooooo0ol0001[ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co00001_oo
ool2o`000<oooooo0ol0001^ooooo`009_ooool00ol0003oooooooooo`3;ooooo`?o0000LOooool0
02Kooooo00?o0000ooooooooool0b?ooool3o`0007Cooooo000Vooooo`03o`000?oooooooooo0<Ko
oooo0_l0001gooooo`009_ooool00ol0003oooooooooo`33ooooo`?o0000NOooool002Kooooo0_l0
0031ooooo`?o0000O?ooool002Kooooo00?o0000ooooooooool0__ooool2o`0007oooooo000Voooo
o`03o`000?oooooooooo0;_ooooo0ol00021ooooo`009_ooool00ol0003oooooooooo`2hooooo`?o
0000Q?ooool002Kooooo00?o0000ooooooooool0]_ooool2o`0008Oooooo000Vooooo`;o0000]?oo
ool3o`0008Wooooo000Vooooo`03o`000?oooooooooo0;7ooooo0_l0002<ooooo`009_ooool00ol0
003oooooooooo`2^ooooo`?o0000S_ooool002Kooooo00?o0000ooooooooool0Zoooool3o`00097o
oooo000Vooooo`;o0000Z_ooool2o`0009Cooooo000Vooooo`03o`000?oooooooooo0:Kooooo0ol0
002Fooooo`009_ooool00ol0003oooooooooo`2Tooooo`;o0000VOooool000_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0X_ooool2o`0009_ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Oooooo`?o0000WOooool0
00_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo0ol0002M
ooooo`;o0000X?ooool000_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0V_ooool3o`000:;ooooo000;ooooo`05o`000?oooooooooo
ooooool000003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09Sooooo0_l0002U
ooooo`002oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`2Eooooo`?o0000Yoooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Toooool2o`000:[ooooo000;oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000007ooooo`;o0000T_ooool2
o`000:cooooo000Vooooo`03o`000?oooooooooo08kooooo0ol0002^ooooo`009_ooool00ol0003o
ooooooooo`2<ooooo`;o0000/Oooool002Kooooo00?o0000ooooooooool0R_ooool2o`000;?ooooo
000Vooooo`;o0000R?ooool3o`000;Gooooo000Vooooo`03o`000?oooooooooo08Gooooo0_l0002h
ooooo`009_ooool00ol0003oooooooooo`23ooooo`;o0000^_ooool002Kooooo00?o0000oooooooo
ool0POooool2o`000;cooooo000Vooooo`03o`000?oooooooooo07kooooo0ol0002nooooo`009_oo
ool2o`0007gooooo0_l00031ooooo`009_ooool00ol0003oooooooooo`1jooooo`;o0000`oooool0
02Kooooo00?o0000ooooooooool0N?ooool2o`000<Gooooo000Vooooo`03o`000?oooooooooo07Ko
oooo0_l00037ooooo`009_ooool00ol0003oooooooooo`1cooooo`?o0000bOooool002Kooooo0_l0
001booooo`;o0000c?ooool002Kooooo00?o0000ooooooooool0Koooool2o`000<kooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000001Ol@413ooooooooooooo
ooooA4A400;o000000?o<S8bomgMgOooool01?ooool00ol0003oooooooooo`1]ooooo`;o0000d?oo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0J_ooool3o`000=;ooooo0003
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00?ooooo0ol0001Xooooo`;o0000eOooool000?ooooo00Go0000ooooooooooooooooo`00
000>ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`1Vooooo`;o0000eoooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo06Cooooo
0_l0003Iooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo067ooooo0ol0003Kooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo05oooooo0_l0003Nooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4o`0000Kooooo0_l0001Nooooo`;o0000
h?ooool002Kooooo00?o0000ooooooooool0Foooool2o`000>;ooooo000Vooooo`03o`000?oooooo
oooo05Wooooo0_l0003Tooooo`009_ooool00ol0003oooooooooo`1Fooooo`?o0000i_ooool002Ko
oooo00?o0000ooooooooool0E?ooool2o`000>Wooooo000Vooooo`;o0000Doooool2o`000>_ooooo
000Vooooo`03o`000?oooooooooo053ooooo0_l0003]ooooo`009_ooool00ol0003oooooooooo`1>
ooooo`;o0000koooool002Kooooo00?o0000ooooooooool0C?ooool2o`000?7ooooo000Vooooo`03
o`000?oooooooooo04[ooooo0_l0003cooooo`009_ooool2o`0004Wooooo0_l0003eooooo`009_oo
ool00ol0003oooooooooo`16ooooo`;o0000moooool002Kooooo00?o0000ooooooooool0A?ooool2
o`000?Wooooo000Vooooo`03o`000?oooooooooo04;ooooo0_l0003kooooo`009_ooool2o`00047o
oooo0_l0003mooooo`009_ooool00ol0003oooooooooo`0nooooo`;o0000ooooool000_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0
??ooool2o`000?oooooo0_ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0>_ooool2o`000?oo
oooo1?ooool000_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?o0000ooooooooool0>?ooool2o`000?oooooo1_ooool000_ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0000fooooo`;o0000ooooool8ooooo`00
2oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003o
ooooooooo`0dooooo`;o0000ooooool:ooooo`002oooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0booooo`;o0000ooooool<ooooo`00
2oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006oooo
o`03o`000?oooooooooo033ooooo0_l0003oooooo`kooooo000;ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0;_ooool2
o`000?oooooo4?ooool002Kooooo0_l0000]ooooo`;o0000oooooolBooooo`009_ooool00ol0003o
ooooooooo`0Zooooo`;o0000oooooolDooooo`009_ooool00ol0003oooooooooo`0Xooooo`;o0000
oooooolFooooo`009_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0?oooooo5_oo
ool002Kooooo0_l0000Vooooo`;o0000oooooolIooooo`009_ooool00ol0003oooooooooo`0Soooo
o`;o0000oooooolKooooo`009_ooool00ol0003oooooooooo`0Qooooo`;o0000oooooolMooooo`00
9_ooool00ol0003oooooooooo`0Oooooo`;o0000oooooolOooooo`009_ooool00ol0003ooooooooo
o`0Mooooo`;o0000oooooolQooooo`009_ooool2o`0001cooooo0_l0003oooooob?ooooo000Voooo
o`03o`000?oooooooooo01Wooooo0_l0003oooooobGooooo000Vooooo`03o`000?oooooooooo01Oo
oooo0_l0003oooooobOooooo000Vooooo`03o`000?oooooooooo01Gooooo0_l0003oooooobWooooo
000Vooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0oooooolYooooo`009_ooool2
o`0001?ooooo0_l0003oooooobcooooo000Vooooo`03o`000?oooooooooo013ooooo0_l0003ooooo
obkooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0>ooooo`;o0000ooooool`
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00cooooo0_l0
003ooooooc;ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP09ooooo`03o`000?oooooooooo00?ooooo0ol0000;ooooo`03o`000?oooooooooo0?oooooo<_oo
ool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`09ooooo`;o0000ooooooleooooo`000oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool01oooool2o`000?oooooo=oooool000?ooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`05ooooo`;o0000ooooooliooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00oooool2o`000?oooooo>oooool000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l00003oooo
o`03o`000?oooooooooo0?oooooo>oooool002Kooooo00?o0000ooooooooool00_l0003oooooocko
oooo000Vooooo`?o0000oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006
ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000ooooooooool0oooo
oom0ooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000003_oo
ool00onYZJWo410@ooooo`05ooooo`?o0000oooooom0ooooo`002oooool01Ol0003ooooooooooooo
oooo000000gooooo00?o410@o`000?nj^[X01_ooool00ol0003oooooooooo`3ooooood3ooooo000;
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nH
V9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@
o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@
413o^[ZjoooooomgMgOo<S8b00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3o
oooood3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00?ooooo0ol0003ooooood3ooooo0003ooooo`05o`000?oooooooooo
ooooool000003_ooool00onYZJWo410@ooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0oooooom0ooooo`000oooool01Ol0003ooooooooooooooooo000000gooooo00?o410@
o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooo
oom0ooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q8Oooool00ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01?ooool4o`0000Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oo
oooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05o`00
0?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`?o0000oooooom0oooo
o`002oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo0000oooooom:
ooooo`002oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000oooooom:
ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000oooooom:
ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0oooooom9
ooooo`00oooooomYooooo`00UOooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Go
oooo00?o0000okZj^_ooool0[Oooool009Gooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo
00?o0000ooooooooool00oooool2oc8b<Zkooooo002:ooooo`05oa0@4?l0003o0000o`000?l@4100
1_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Co
oooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?ooooo00?oQhN7o`00
0?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00[ooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<08Gooooo002<ooooo`03o`000?oooooo
oooo00Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<
c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`03
ooooo`03olc<c?l0003o410@00Gooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000Gooooo
00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P25ooooo`00
S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413o
c<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo08?ooooo002<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`Ko
00001Oooool00ol0003oooooooooo`0=ooooo`03ojVYZOl@413ooooo08Cooooo002<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00cooooo00?o410@o`000?nj^[X0QOooool008Wooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`00
00Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo00Wooooo00?o410@o`00
0?l000000ol0000=ooooo`03o`000?oooooooooo00gooooo00?o^[Zjob4Q8Oooool0Q?ooool008Wo
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool02_ooool01Ol@413oV9RHoooooonj^[[o000008Gooooo0029oooo
o`Oo00001Oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0000gooooo00?o0000oooo
ooooool03?ooool00omEEEGoIVIVo`00000<ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0QOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .41598 m
.11905 .36452 L
.21429 .31551 L
.30952 .26904 L
.40476 .22508 L
.5 .18348 L
.59524 .14401 L
.69048 .10634 L
.78571 .07008 L
.88095 .03479 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool3o`000003ooooool0003ooooo
017ooooo00Co8B4QogMgMomgMgOo<S8b2_ooool002Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0`ooooo`?o00001?ooool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`00
00Wooooo000Vooooo`03o`000?oooooooooo0?oooooo5_ooool2o`0002Sooooo000Vooooo`03o`00
0?oooooooooo0?oooooo4oooool3o`0002[ooooo000Vooooo`;o0000oooooolAooooo`?o0000;Ooo
ool002Kooooo00?o0000ooooooooool0ooooool>ooooo`;o0000<?ooool002Kooooo00?o0000oooo
ooooool0ooooool;ooooo`?o0000<_ooool002Kooooo00?o0000ooooooooool0ooooool9ooooo`;o
0000=Oooool002Kooooo00?o0000ooooooooool0ooooool6ooooo`?o0000=oooool002Kooooo0_l0
003oooooo`Cooooo0ol0000jooooo`009_ooool00ol0003oooooooooo`3oooooo`7ooooo0_l0000m
ooooo`009_ooool00ol0003oooooooooo`3mooooo`?o0000?oooool002Kooooo00?o0000oooooooo
ool0n_ooool3o`0004;ooooo000Vooooo`;o0000n?ooool3o`0004Gooooo000Vooooo`03o`000?oo
oooooooo0?Cooooo0ol00018ooooo`009_ooool00ol0003oooooooooo`3aooooo`?o0000Boooool0
02Kooooo00?o0000ooooooooool0k_ooool3o`0004kooooo000Vooooo`03o`000?oooooooooo0>_o
oooo0ol0001Aooooo`009_ooool2o`000>Wooooo0ol0001Dooooo`009_ooool00ol0003ooooooooo
o`3Uooooo`?o0000Eoooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0>?ooooo0_l0001Jooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0>3ooooo0ol0001Looooo`000oooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0gOooool3o`0005oooooo0003ooooo`05o`000?ooooooooooooooool000002oooool0
1Ol0003ooooooooooooooooo000000Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000=_ooooo0_l0
001Rooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooooooooooooooo
o`000004ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3Hooooo`?o
0000I?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?oooooooooooooo
ool@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=Gooooo0ol0001Woooo
o`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0doooool2o`0006[ooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l0
0006ooooo`;o0000dOooool3o`0006cooooo000Vooooo`03o`000?oooooooooo0<kooooo0_l0001_
ooooo`009_ooool00ol0003oooooooooo`3;ooooo`?o0000LOooool002Kooooo00?o0000oooooooo
ool0b?ooool3o`0007Cooooo000Vooooo`03o`000?oooooooooo0<Kooooo0_l0001gooooo`009_oo
ool2o`000<Cooooo0ol0001iooooo`009_ooool00ol0003oooooooooo`31ooooo`;o0000O?ooool0
02Kooooo00?o0000ooooooooool0_oooool2o`0007kooooo000Vooooo`03o`000?oooooooooo0;co
oooo0ol00020ooooo`009_ooool00ol0003oooooooooo`2jooooo`;o0000Poooool002Kooooo0_l0
002hooooo`?o0000QOooool002Kooooo00?o0000ooooooooool0]Oooool2o`0008Sooooo000Voooo
o`03o`000?oooooooooo0;;ooooo0ol0002:ooooo`009_ooool00ol0003oooooooooo`2`ooooo`;o
0000SOooool002Kooooo0_l0002_ooooo`;o0000Soooool002Kooooo00?o0000ooooooooool0Zooo
ool3o`00097ooooo000Vooooo`03o`000?oooooooooo0:Wooooo0_l0002Dooooo`002oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool0
0ol0003oooooooooo`2Vooooo`?o0000U_ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:Cooooo0_l0002I
ooooo`002oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool3
o`000:;ooooo0_l0002Kooooo`002oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2Oooooo`?o0000WOooool000_ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0WOooool2
o`000:3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo09[ooooo0ol0002Rooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Hooooo`;o0000YOooool0
00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Oooooo0_l0002F
ooooo`?o0000Yoooool002Kooooo00?o0000ooooooooool0Toooool2o`000:[ooooo000Vooooo`03
o`000?oooooooooo097ooooo0_l0002/ooooo`009_ooool00ol0003oooooooooo`2>ooooo`?o0000
[_ooool002Kooooo0_l0002=ooooo`;o0000/Oooool002Kooooo00?o0000ooooooooool0ROooool3
o`000;?ooooo000Vooooo`03o`000?oooooooooo08Oooooo0_l0002fooooo`009_ooool00ol0003o
ooooooooo`25ooooo`;o0000^?ooool002Kooooo00?o0000ooooooooool0P_ooool3o`000;[ooooo
000Vooooo`;o0000POooool2o`000;gooooo000Vooooo`03o`000?oooooooooo07gooooo0ol0002o
ooooo`009_ooool00ol0003oooooooooo`1kooooo`;o0000`_ooool002Kooooo00?o0000oooooooo
ool0N?ooool3o`000<Cooooo000Vooooo`03o`000?oooooooooo07Kooooo0_l00037ooooo`009_oo
ool2o`0007Gooooo0_l00039ooooo`009_ooool00ol0003oooooooooo`1aooooo`?o0000boooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000005oa0@4?oooooo
oooooooooom4A4@00_l000000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo06oooooo0_l0
003>ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oo
oooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1]ooooo`;o0000d?oo
ool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00oooool3o`0006_ooooo0_l0003Booooo`000oooool01Ol0003ooooooooooooo
oooo000000kooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo06Wooooo0_l0003Dooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o
0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
Ioooool2o`000=Kooooo0003ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0IOooool2o`000=Sooooo
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0Hoooool2o`000=[ooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000005ooooo`Co00001_ooool2o`00067ooooo
0ol0003Looooo`009_ooool00ol0003oooooooooo`1Nooooo`;o0000goooool002Kooooo00?o0000
ooooooooool0G?ooool2o`000>7ooooo000Vooooo`03o`000?oooooooooo05[ooooo0_l0003Soooo
o`009_ooool00ol0003oooooooooo`1Hooooo`;o0000iOooool002Kooooo0_l0001Gooooo`;o0000
ioooool002Kooooo00?o0000ooooooooool0E?ooool2o`000>Wooooo000Vooooo`03o`000?oooooo
oooo05;ooooo0_l0003[ooooo`009_ooool00ol0003oooooooooo`1@ooooo`;o0000kOooool002Ko
oooo00?o0000ooooooooool0C_ooool2o`000>oooooo000Vooooo`;o0000COooool2o`000?7ooooo
000Vooooo`03o`000?oooooooooo04[ooooo0_l0003cooooo`009_ooool00ol0003oooooooooo`18
ooooo`;o0000mOooool002Kooooo00?o0000ooooooooool0A_ooool2o`000?Oooooo000Vooooo`;o
0000AOooool2o`000?Wooooo000Vooooo`03o`000?oooooooooo04;ooooo0_l0003kooooo`002ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooo
ooooo`10ooooo`;o0000oOooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0?_ooool2o`000?oo
oooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`03
o`000?oooooooooo03cooooo0_l0003oooooo`;ooooo000;ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000>_ooool2o`000?oooooo1?ooool000_ooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000oooooooo
ool0>?ooool2o`000?oooooo1_ooool000_ooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0=_ooool2o`000?oooooo2?ooool000_ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0
003oooooooooo`0dooooo`;o0000ooooool:ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo03;ooooo0_l0003o
ooooo`cooooo000Vooooo`;o0000<Oooool2o`000?oooooo3_ooool002Kooooo00?o0000oooooooo
ool0;_ooool2o`000?oooooo4?ooool002Kooooo00?o0000ooooooooool0;?ooool2o`000?oooooo
4_ooool002Kooooo00?o0000ooooooooool0:_ooool2o`000?oooooo5?ooool002Kooooo0_l0000Y
ooooo`;o0000oooooolFooooo`009_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
0?oooooo5_ooool002Kooooo00?o0000ooooooooool09Oooool2o`000?oooooo6Oooool002Kooooo
00?o0000ooooooooool08oooool2o`000?oooooo6oooool002Kooooo00?o0000ooooooooool08Ooo
ool2o`000?oooooo7Oooool002Kooooo0_l0000Pooooo`;o0000oooooolOooooo`009_ooool00ol0
003oooooooooo`0Mooooo`;o0000oooooolQooooo`009_ooool00ol0003oooooooooo`0Kooooo`;o
0000oooooolSooooo`009_ooool00ol0003oooooooooo`0Iooooo`;o0000oooooolUooooo`009_oo
ool00ol0003oooooooooo`0Gooooo`;o0000oooooolWooooo`009_ooool2o`0001Kooooo0_l0003o
ooooobWooooo000Vooooo`03o`000?oooooooooo01?ooooo0_l0003oooooob_ooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Aooooo`;o0000ooooool]ooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00oooooo0_l0003ooooooboooooo0003
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00?ooooo0ol0000=ooooo`;o0000oooooolaooooo`000oooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo00_ooooo0_l0003ooooooc?ooooo0003ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo0?oooooo<oooool000?ooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`08ooooo`;o0000oooooolfooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool2o`000?oooooo>?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l00005ooooo`;o0000ooooooljoooo
o`009_ooool00ol0003oooooooooo`02ooooo`;o0000oooooollooooo`009_ooool00ol0003ooooo
ooooo`02o`000?oooooo?_ooool002Kooooo0ol0003ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooo
od3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1
ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooo
oooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool0
1Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@oooo
o`05ooooo`?o0000oooooom0ooooo`002oooool01Ol0003ooooooooooooooooo000000gooooo00?o
410@o`000?nj^[X01_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l00000
1_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom0ooooo`00
9_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@?ooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo
<S8b00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003oooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00?ooooo0ol0003ooooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool0
0onYZJWo410@ooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0
ooooo`000oooool01Ol0003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool0
1Ol@413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q8Oooool00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01?ooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003o
ooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool0
00002oooool01?m4A4CogMgMooooool00007ooooo`?o0000oooooom0ooooo`002oooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo0000oooooom:ooooo`002oooool01Ol@
413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000oooooom:ooooo`002oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000oooooom:ooooo`002oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0oooooom9ooooo`00oooooomYoooo
o`00UOooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj^_oo
ool0[Oooool009Gooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0
0oooool2oc8b<Zkooooo002:ooooo`05oa0@4?l0003o0000o`000?l@41001_ooool01?l0003ooooo
ooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0
003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X01Oooool01OnH
V9So0000o`000?m4A4Co^[Zj00[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool2
o`000003oa0@4?oooooooooo08?ooooo002<ooooo`03o`000?oooooooooo00Kooooo00[o0000oooo
ooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05
oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@
00Gooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000Gooooo00?o0000ooooooooool01?oo
ool2ob4Q8@Oooooo00?o0000ooooooooool0Q?ooool008cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_oo
ool5o`0008Gooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool0
1?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0003oooooooooo`0:ooooo`04odA4A?oM
gMgoooooo`0008Kooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oo
ool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00CogMgMoeEEEOoooooo
0000Q_ooool008Wooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005oooo
o`03o`000?oooooooooo00Wooooo00?o410@o`000?l000000ol0000=ooooo`03o`000?oooooooooo
00_ooooo00?oMgMgolc<c?l00000Q_ooool008Wooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool00oo^
k^koA4A4o`000026ooooo`00ROooool7o`0000Gooooo0_l0000Booooo`03o`000?oooooooooo00Go
oooo0_l0000=ooooo`03o`000?oooooooooo00cooooo00?oEEEEofIVI_l000003_ooool00omgMgOo
0000ooooo`25ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .42139 m
.11905 .37037 L
.21429 .32155 L
.30952 .27501 L
.40476 .23072 L
.5 .18856 L
.59524 .14833 L
.69048 .10972 L
.78571 .07241 L
.88095 .03598 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool3o`000003ooooool0003ooooo
017ooooo00Co8B4QogMgMomgMgOo<S8b2_ooool002Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0`ooooo`?o00001?ooool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`00
00Wooooo000Vooooo`03o`000?oooooooooo0?oooooo5_ooool2o`0002Sooooo000Vooooo`03o`00
0?oooooooooo0?oooooo4oooool3o`0002[ooooo000Vooooo`;o0000oooooolAooooo`?o0000;Ooo
ool002Kooooo00?o0000ooooooooool0ooooool>ooooo`;o0000<?ooool002Kooooo00?o0000oooo
ooooool0ooooool;ooooo`?o0000<_ooool002Kooooo00?o0000ooooooooool0ooooool9ooooo`;o
0000=Oooool002Kooooo00?o0000ooooooooool0ooooool6ooooo`?o0000=oooool002Kooooo0_l0
003oooooo`Cooooo0ol0000jooooo`009_ooool00ol0003oooooooooo`3oooooo`7ooooo0_l0000m
ooooo`009_ooool00ol0003oooooooooo`3mooooo`?o0000?oooool002Kooooo00?o0000oooooooo
ool0n_ooool3o`0004;ooooo000Vooooo`;o0000nOooool2o`0004Gooooo000Vooooo`03o`000?oo
oooooooo0?Gooooo0ol00017ooooo`009_ooool00ol0003oooooooooo`3booooo`?o0000B_ooool0
02Kooooo00?o0000ooooooooool0l?ooool2o`0004gooooo000Vooooo`03o`000?oooooooooo0>go
oooo0ol0001?ooooo`009_ooool2o`000>cooooo0_l0001Booooo`009_ooool00ol0003ooooooooo
o`3Xooooo`?o0000E?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0>Gooooo0ol0001Gooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0>?ooooo0_l0001Jooooo`000oooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0h?ooool3o`0005cooooo0003ooooo`05o`000?ooooooooooooooool000002oooool0
1Ol0003ooooooooooooooooo000000Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000=gooooo0ol0
001Oooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooooooooooooooo
o`000004ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3Kooooo`;o
0000H_ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?oooooooooooooo
ool@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=Sooooo0ol0001Toooo
o`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0eOooool3o`0006Oooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l0
0006ooooo`;o0000e?ooool2o`0006[ooooo000Vooooo`03o`000?oooooooooo0=3ooooo0ol0001/
ooooo`009_ooool00ol0003oooooooooo`3>ooooo`;o0000Koooool002Kooooo00?o0000oooooooo
ool0boooool3o`00077ooooo000Vooooo`03o`000?oooooooooo0<Sooooo0ol0001dooooo`009_oo
ool2o`000<Oooooo0_l0001gooooo`009_ooool00ol0003oooooooooo`33ooooo`?o0000NOooool0
02Kooooo00?o0000ooooooooool0`Oooool2o`0007cooooo000Vooooo`03o`000?oooooooooo0;oo
oooo0_l0001nooooo`009_ooool00ol0003oooooooooo`2looooo`?o0000P?ooool002Kooooo0_l0
002kooooo`;o0000Poooool002Kooooo00?o0000ooooooooool0]oooool3o`0008Gooooo000Voooo
o`03o`000?oooooooooo0;Gooooo0_l00028ooooo`009_ooool00ol0003oooooooooo`2booooo`?o
0000R_ooool002Kooooo0_l0002aooooo`;o0000SOooool002Kooooo00?o0000ooooooooool0[_oo
ool2o`0008oooooo000Vooooo`03o`000?oooooooooo0:_ooooo0ol0002Aooooo`002oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool0
0ol0003oooooooooo`2Yooooo`;o0000U?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:Kooooo0ol0002F
ooooo`002oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool3
o`000:Cooooo0_l0002Iooooo`002oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2Rooooo`;o0000Voooool000_ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Woooool3
o`0009gooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo09gooooo0_l0002Pooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Jooooo`?o0000X_ooool0
00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Oooooo0_l0002I
ooooo`;o0000YOooool002Kooooo00?o0000ooooooooool0UOooool3o`000:Oooooo000Vooooo`03
o`000?oooooooooo09?ooooo0_l0002Zooooo`009_ooool00ol0003oooooooooo`2Aooooo`;o0000
[?ooool002Kooooo0_l0002?ooooo`?o0000[_ooool002Kooooo00?o0000ooooooooool0S?ooool2
o`000;7ooooo000Vooooo`03o`000?oooooooooo08[ooooo0_l0002cooooo`009_ooool00ol0003o
ooooooooo`27ooooo`?o0000]Oooool002Kooooo00?o0000ooooooooool0QOooool2o`000;Sooooo
000Vooooo`;o0000Q?ooool2o`000;[ooooo000Vooooo`03o`000?oooooooooo087ooooo0_l0002l
ooooo`009_ooool00ol0003oooooooooo`1nooooo`?o0000__ooool002Kooooo00?o0000oooooooo
ool0O?ooool2o`000<7ooooo000Vooooo`03o`000?oooooooooo07[ooooo0_l00033ooooo`009_oo
ool2o`0007Wooooo0_l00035ooooo`009_ooool00ol0003oooooooooo`1fooooo`;o0000aoooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000005oa0@4?oooooo
oooooooooom4A4@00_l000000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo07?ooooo0ol0
0039ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oo
oooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1aooooo`;o0000c?oo
ool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00oooool3o`0006oooooo0_l0003>ooooo`000oooool01Ol0003ooooooooooooo
oooo000000kooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo06gooooo0_l0003@ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o
0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
Joooool2o`000=;ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0JOooool2o`000=Cooooo
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0Ioooool2o`000=Kooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000005ooooo`Co00001_ooool2o`0006Kooooo
0_l0003Hooooo`009_ooool00ol0003oooooooooo`1Sooooo`;o0000f_ooool002Kooooo00?o0000
ooooooooool0H?ooool3o`000=cooooo000Vooooo`03o`000?oooooooooo05kooooo0_l0003Ooooo
o`009_ooool00ol0003oooooooooo`1Looooo`;o0000hOooool002Kooooo0_l0001Kooooo`;o0000
hoooool002Kooooo00?o0000ooooooooool0F?ooool2o`000>Gooooo000Vooooo`03o`000?oooooo
oooo05Kooooo0_l0003Wooooo`009_ooool00ol0003oooooooooo`1Dooooo`;o0000jOooool002Ko
oooo00?o0000ooooooooool0D_ooool2o`000>_ooooo000Vooooo`;o0000DOooool2o`000>gooooo
000Vooooo`03o`000?oooooooooo04kooooo0_l0003_ooooo`009_ooool00ol0003oooooooooo`1<
ooooo`;o0000lOooool002Kooooo00?o0000ooooooooool0B_ooool2o`000??ooooo000Vooooo`;o
0000BOooool2o`000?Gooooo000Vooooo`03o`000?oooooooooo04Kooooo0_l0003gooooo`002ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooo
ooooo`14ooooo`;o0000nOooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0@_ooool2o`000?_o
oooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`03
o`000?oooooooooo043ooooo0_l0003mooooo`002oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0003kooooo0_l0003oooooo`002oooool01Ol0003ooooo
oooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0looooo`;o
0000ooooool2ooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0jooooo`;o0000ooooool4ooooo`002oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo
03Sooooo0_l0003oooooo`Kooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnH
V9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0=_ooool2o`000?oooooo2?ooool0
02Kooooo0_l0000eooooo`;o0000ooooool:ooooo`009_ooool00ol0003oooooooooo`0booooo`;o
0000ooooool<ooooo`009_ooool00ol0003oooooooooo`0`ooooo`;o0000ooooool>ooooo`009_oo
ool00ol0003oooooooooo`0^ooooo`;o0000ooooool@ooooo`009_ooool2o`0002gooooo0_l0003o
oooooa;ooooo000Vooooo`03o`000?oooooooooo02[ooooo0_l0003ooooooaCooooo000Vooooo`03
o`000?oooooooooo02Sooooo0_l0003ooooooaKooooo000Vooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0oooooolFooooo`009_ooool00ol0003oooooooooo`0Uooooo`;o0000oooo
oolIooooo`009_ooool2o`0002Cooooo0_l0003ooooooa_ooooo000Vooooo`03o`000?oooooooooo
027ooooo0_l0003ooooooagooooo000Vooooo`03o`000?oooooooooo01oooooo0_l0003ooooooaoo
oooo000Vooooo`03o`000?oooooooooo01gooooo0_l0003oooooob7ooooo000Vooooo`03o`000?oo
oooooooo01_ooooo0_l0003oooooob?ooooo000Vooooo`;o00006_ooool2o`000?oooooo9Oooool0
02Kooooo00?o0000ooooooooool05oooool2o`000?oooooo9oooool000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo01Gooooo0_l0003oooooobWooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool04oooool2o`000?oooooo:oooool000?ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool3o`00017ooooo0_l0003oooooobgooooo0003ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03ooo
ool2o`000?oooooo;oooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00gooooo
0_l0003ooooooc7ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool2o`000?oooooo
<oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0oooooolcooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co00001_ooool2o`0000Wooooo0_l0003oooooocKooooo000Vooooo`03
o`000?oooooooooo00Kooooo0_l0003oooooocSooooo000Vooooo`03o`000?oooooooooo00Cooooo
0_l0003ooooooc[ooooo000Vooooo`03o`000?oooooooooo00;ooooo0_l0003ooooooccooooo000V
ooooo`03o`000?oooooooooo00;o0000oooooolnooooo`009_ooool3o`000?oooooo@?ooool002Ko
oooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo
000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`00
9_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?oo
ool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000_o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;o
c<c<00Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003ooooooooo
o`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ojVYZOl@413ooooo00Gooooo0ol0003ooooood3ooooo000;ooooo`05o`000?oooooo
ooooooooool000003Oooool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o
0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003o
ooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oo
oooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRH
V?l@413o0000oc8b<_o<c<`01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oa0@4?nj^[[oooooogMgMolb<S801oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0?oooooo@?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00oooool3o`000?oooooo@?ooool000?ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3ooooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003Oooool0
0ol@413o0000okZj^P04ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`3ooooood3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qoooo
o`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom0ooooo`000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000004ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@04ooooo`Co00001_ooool2o`000?oo
oooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooo
od7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Ol@413ooooo
oooooooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0003ooooo
od3ooooo000;ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0003o
oooood[ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00003o
oooood[ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00003o
oooood[ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`3o
ooooodWooooo003oooooofWooooo002Eooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o
00001Oooool00ol0003o^[Zjooooo`2]ooooo`00UOooool00ol0003oooooooooo`0:ooooo`;o<S8b
3_ooool00ol0003oooooooooo`03ooooo`;o<S8b[_ooool008[ooooo00Go410@o`000?l0003o0000
oa0@4006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj
^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7
QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X02_ooool4o`000003oa0@4?oooooo
oooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0Q?ooool008cooooo00?o0000
ooooooooool01_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3oooo
o`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooo
oooo00?ooooo00?oc<c<o`000?l@41001Oooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko0000
1Oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`23ooooo`00S?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<
2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo08;ooooo002<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`Ko0000
1Oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo08?ooooo002<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c024ooooo`00ROooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002oooo
o`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool02Oooool00ol@
413o0000o`000003o`0000gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`26oooo
o`00ROooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo08Kooooo0029ooooo`Oo
00001Oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0000gooooo00?o0000oooooooo
ool03?ooool00omEEEGoIVIVo`00000=ooooo`Co0000QOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .42623 m
.11905 .37561 L
.21429 .32697 L
.30952 .28038 L
.40476 .23581 L
.5 .19316 L
.59524 .15224 L
.69048 .1128 L
.78571 .07453 L
.88095 .03706 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool3o`000003ooooool0003ooooo
017ooooo00Co8B4QogMgMomgMgOo<S8b2_ooool002Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0`ooooo`?o00001?ooool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`00
00Wooooo000Vooooo`03o`000?oooooooooo0?oooooo5_ooool2o`0002Sooooo000Vooooo`03o`00
0?oooooooooo0?oooooo4oooool3o`0002[ooooo000Vooooo`;o0000oooooolAooooo`?o0000;Ooo
ool002Kooooo00?o0000ooooooooool0ooooool>ooooo`;o0000<?ooool002Kooooo00?o0000oooo
ooooool0ooooool;ooooo`?o0000<_ooool002Kooooo00?o0000ooooooooool0ooooool9ooooo`;o
0000=Oooool002Kooooo00?o0000ooooooooool0ooooool6ooooo`?o0000=oooool002Kooooo0_l0
003oooooo`Cooooo0ol0000jooooo`009_ooool00ol0003oooooooooo`3oooooo`7ooooo0_l0000m
ooooo`009_ooool00ol0003oooooooooo`3mooooo`?o0000?oooool002Kooooo00?o0000oooooooo
ool0noooool2o`0004;ooooo000Vooooo`;o0000n_ooool2o`0004Cooooo000Vooooo`03o`000?oo
oooooooo0?Kooooo0ol00016ooooo`009_ooool00ol0003oooooooooo`3dooooo`;o0000BOooool0
02Kooooo00?o0000ooooooooool0lOooool3o`0004_ooooo000Vooooo`03o`000?oooooooooo0>oo
oooo0_l0001>ooooo`009_ooool2o`000>gooooo0ol0001@ooooo`009_ooool00ol0003ooooooooo
o`3Zooooo`;o0000Doooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0>Sooooo0_l0001Eooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0>Gooooo0ol0001Gooooo`000oooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0hoooool2o`0005[ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool0
1Ol0003ooooooooooooooooo000000Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000>3ooooo0ol0
001Looooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooooooooooooooo
o`000004ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3Mooooo`?o
0000Goooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?oooooooooooooo
ool@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=_ooooo0_l0001Roooo
o`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0f?ooool3o`0006Cooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l0
0006ooooo`;o0000e_ooool3o`0006Oooooo000Vooooo`03o`000?oooooooooo0=?ooooo0_l0001Z
ooooo`009_ooool00ol0003oooooooooo`3@ooooo`?o0000K?ooool002Kooooo00?o0000oooooooo
ool0c_ooool2o`0006oooooo000Vooooo`03o`000?oooooooooo0<_ooooo0ol0001aooooo`009_oo
ool2o`000<Wooooo0ol0001dooooo`009_ooool00ol0003oooooooooo`36ooooo`;o0000Moooool0
02Kooooo00?o0000ooooooooool0`oooool3o`0007Wooooo000Vooooo`03o`000?oooooooooo0<7o
oooo0_l0001looooo`009_ooool00ol0003oooooooooo`2oooooo`;o0000O_ooool002Kooooo0_l0
002mooooo`?o0000P?ooool002Kooooo00?o0000ooooooooool0^_ooool2o`0008?ooooo000Voooo
o`03o`000?oooooooooo0;Oooooo0ol00025ooooo`009_ooool00ol0003oooooooooo`2eooooo`;o
0000R?ooool002Kooooo0_l0002cooooo`?o0000R_ooool002Kooooo00?o0000ooooooooool0/?oo
ool2o`0008gooooo000Vooooo`03o`000?oooooooooo0:kooooo0_l0002?ooooo`002oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool0
0ol0003oooooooooo`2[ooooo`?o0000TOooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:Wooooo0_l0002D
ooooo`002oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool3
o`000:Oooooo0_l0002Fooooo`002oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2Tooooo`?o0000V?ooool000_ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0X_ooool2
o`0009_ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0:3ooooo0_l0002Mooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Nooooo`;o0000Woooool0
00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Oooooo0_l0002L
ooooo`?o0000XOooool002Kooooo00?o0000ooooooooool0VOooool2o`000:Cooooo000Vooooo`03
o`000?oooooooooo09Oooooo0_l0002Vooooo`009_ooool00ol0003oooooooooo`2Eooooo`;o0000
Z?ooool002Kooooo0_l0002Dooooo`;o0000Z_ooool002Kooooo00?o0000ooooooooool0T?ooool3
o`000:cooooo000Vooooo`03o`000?oooooooooo08kooooo0_l0002_ooooo`009_ooool00ol0003o
ooooooooo`2<ooooo`;o0000/Oooool002Kooooo00?o0000ooooooooool0R_ooool2o`000;?ooooo
000Vooooo`;o0000R?ooool3o`000;Gooooo000Vooooo`03o`000?oooooooooo08Gooooo0_l0002h
ooooo`009_ooool00ol0003oooooooooo`23ooooo`;o0000^_ooool002Kooooo00?o0000oooooooo
ool0POooool2o`000;cooooo000Vooooo`03o`000?oooooooooo07kooooo0ol0002nooooo`009_oo
ool2o`0007gooooo0_l00031ooooo`009_ooool00ol0003oooooooooo`1jooooo`;o0000`oooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000005oa0@4?oooooo
oooooooooom4A4@00_l000000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo07Sooooo0_l0
0035ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oo
oooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1fooooo`;o0000aooo
ool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00oooool3o`0007?ooooo0ol00039ooooo`000oooool01Ol0003ooooooooooooo
oooo000000kooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo077ooooo0_l0003<ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o
0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
Koooool2o`000<kooooo0003ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0KOooool2o`000=3ooooo
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0J_ooool3o`000=;ooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000005ooooo`Co00001_ooool2o`0006Wooooo
0_l0003Eooooo`009_ooool00ol0003oooooooooo`1Vooooo`;o0000eoooool002Kooooo00?o0000
ooooooooool0I?ooool2o`000=Wooooo000Vooooo`03o`000?oooooooooo067ooooo0ol0003Koooo
o`009_ooool00ol0003oooooooooo`1Oooooo`;o0000g_ooool002Kooooo0_l0001Nooooo`;o0000
h?ooool002Kooooo00?o0000ooooooooool0Foooool2o`000>;ooooo000Vooooo`03o`000?oooooo
oooo05Wooooo0_l0003Tooooo`009_ooool00ol0003oooooooooo`1Fooooo`?o0000i_ooool002Ko
oooo00?o0000ooooooooool0E?ooool2o`000>Wooooo000Vooooo`;o0000Doooool2o`000>_ooooo
000Vooooo`03o`000?oooooooooo053ooooo0_l0003]ooooo`009_ooool00ol0003oooooooooo`1>
ooooo`;o0000koooool002Kooooo00?o0000ooooooooool0C?ooool2o`000?7ooooo000Vooooo`;o
0000Boooool2o`000??ooooo000Vooooo`03o`000?oooooooooo04Sooooo0_l0003eooooo`002ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooo
ooooo`16ooooo`;o0000moooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0A?ooool2o`000?Wo
oooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`03
o`000?oooooooooo04;ooooo0_l0003kooooo`002oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool3o`00043ooooo0_l0003mooooo`002oooool01Ol0003ooooo
oooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0nooooo`;o
0000ooooool000_ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0??ooool2o`000?oooooo0_ooool000_ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0joooo
o`;o0000ooooool4ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo03Sooooo0_l0003oooooo`Kooooo000Voooo
o`;o0000=oooool2o`000?oooooo2?ooool002Kooooo00?o0000ooooooooool0=?ooool2o`000?oo
oooo2_ooool002Kooooo00?o0000ooooooooool0<_ooool2o`000?oooooo3?ooool002Kooooo00?o
0000ooooooooool0<?ooool2o`000?oooooo3_ooool002Kooooo0_l0000_ooooo`;o0000ooooool@
ooooo`009_ooool00ol0003oooooooooo`0/ooooo`;o0000oooooolBooooo`009_ooool00ol0003o
ooooooooo`0Zooooo`;o0000oooooolDooooo`009_ooool00ol0003oooooooooo`0Xooooo`;o0000
oooooolFooooo`009_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0?oooooo5_oo
ool002Kooooo0_l0000Vooooo`;o0000oooooolIooooo`009_ooool00ol0003oooooooooo`0Soooo
o`;o0000oooooolKooooo`009_ooool00ol0003oooooooooo`0Qooooo`;o0000oooooolMooooo`00
9_ooool00ol0003oooooooooo`0Oooooo`;o0000oooooolOooooo`009_ooool00ol0003ooooooooo
o`0Mooooo`;o0000oooooolQooooo`009_ooool2o`0001cooooo0_l0003oooooob?ooooo000Voooo
o`03o`000?oooooooooo01Wooooo0_l0003oooooobGooooo0003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`0Gooooo`;o0000oooooolWooooo`000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo01Gooooo0_l0003oooooobWooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0
000Dooooo`03o`000?oooooooooo0?oooooo:Oooool000?ooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`0Booooo`;o0000ooooool/ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
4?ooool2o`000?oooooo;_ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`;o0000
ooooool`ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool2o`000?oo
oooo<_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0000<ooooo`03o`000?oooooooooo0?oooooo<_ooool002Ko
oooo00?o0000ooooooooool02Oooool2o`000?oooooo=Oooool002Kooooo00?o0000ooooooooool0
1oooool2o`000?oooooo=oooool002Kooooo00?o0000ooooooooool01Oooool2o`000?oooooo>Ooo
ool002Kooooo00?o0000ooooooooool00oooool2o`000?oooooo>oooool002Kooooo0_l00003oooo
o`03o`000?oooooooooo0?oooooo>oooool002Kooooo00?o0000ooooooooool00_l0003oooooocko
oooo000Vooooo`?o0000oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@?ooool0
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[Zjoooooomg
MgOo<S8b00Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood3ooooo000;
ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000oooo
oom0ooooo`002oooool01Ol0003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01_oo
ool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@
o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo
@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0003o
oooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`06
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol0
003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooooooo
oooo410@00kooooo00?o^[Zjob4Q8Oooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nH
V9SooooookZj^_l000001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT01?ooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003o
ooooooooo`3ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4Co
gMgMooooool00007ooooo`?o0000oooooom0ooooo`002oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOoooooo0000oooooom:ooooo`002oooool01Ol@413ooooooooooooooooo
410@00cooooo00?oMgMgolc<c?l00000oooooom:ooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?ok^k^odA4A?l00000oooooom:ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00gooooo00?oMgMgo`000?ooool0oooooom9ooooo`00oooooomYooooo`00UOooool2o`0000_o
oooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0[Oooool009Gooooo
00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<Zkooooo
002:ooooo`05oa0@4?l0003o0000o`000?l@41001_ooool01?l0003oooooooooooooool2o`0000;o
oooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04oooo
o`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co
^[Zj00[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<08Gooooo002<ooooo`03o`000?oooooooooo00Kooooo00[o0000ooooooooooooooooonk^
k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^
ogMgMol@41001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko410@
okZj^_o^k^koMgMgoa0@4?ooool6o`0000Gooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo
00GoEEEEogMgMoooooooV9RHob4Q8@25ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`05
o`000?ooooooooooooooool00000QOooool008cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo1_l00005ooooo`03o`000?oooooooooo
00[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@25ooooo`00S?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:
ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0QOooool008Wooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo
00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo00Wooooo00?o410@o`000?l00000
0ol0000=ooooo`03o`000?oooooooooo00[ooooo00?oEEEEohN7Qoooool0Qoooool008Wooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool02_ooool00ooMgMgo410@oiRHV027ooooo`00ROooool7o`0000Gooooo0_l0
000Booooo`03o`000?oooooooooo00Gooooo0_l0000=ooooo`03o`000?oooooooooo00cooooo00?o
EEEEofIVI_l000003Oooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .4306 m
.11905 .38033 L
.21429 .33185 L
.30952 .28521 L
.40476 .24039 L
.5 .1973 L
.59524 .15577 L
.69048 .11558 L
.78571 .07645 L
.88095 .03804 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool3o`000003ooooool0003ooooo
017ooooo00Co8B4QogMgMomgMgOo<S8b2_ooool002Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0aooooo`;o00001?ooool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`00
00Wooooo000Vooooo`03o`000?oooooooooo0?oooooo5oooool2o`0002Oooooo000Vooooo`03o`00
0?oooooooooo0?oooooo5?ooool3o`0002Wooooo000Vooooo`;o0000oooooolCooooo`;o0000;?oo
ool002Kooooo00?o0000ooooooooool0ooooool?ooooo`?o0000;_ooool002Kooooo00?o0000oooo
ooooool0ooooool=ooooo`;o0000<Oooool002Kooooo00?o0000ooooooooool0ooooool:ooooo`?o
0000<oooool002Kooooo00?o0000ooooooooool0ooooool8ooooo`;o0000=_ooool002Kooooo0_l0
003oooooo`Oooooo0_l0000hooooo`009_ooool00ol0003oooooooooo`3oooooo`?ooooo0ol0000j
ooooo`009_ooool00ol0003oooooooooo`3oooooo`7ooooo0_l0000mooooo`009_ooool00ol0003o
ooooooooo`3mooooo`?o0000?oooool002Kooooo0_l0003kooooo`?o0000@_ooool002Kooooo00?o
0000ooooooooool0n?ooool2o`0004Gooooo000Vooooo`03o`000?oooooooooo0?Gooooo0ol00017
ooooo`009_ooool00ol0003oooooooooo`3booooo`?o0000B_ooool002Kooooo00?o0000oooooooo
ool0l?ooool2o`0004gooooo000Vooooo`;o0000k_ooool3o`0004oooooo000Vooooo`03o`000?oo
oooooooo0>_ooooo0_l0001Booooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool0j?ooool3o`0005Cooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0iOooool3o`0005Oooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`3Sooooo`;o0000F_ooool000?ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?ooooooooooooooool000001oooool00omgMgOo<S8booooo`04ooooo`?o0000h?oo
ool3o`0005cooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0=ko
oooo0_l0001Oooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooo
oooooooooa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0g?ooool2o`00
067ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3Iooooo`?o0000Hoooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?oo
ool4o`0000Kooooo0_l0003Hooooo`;o0000I_ooool002Kooooo00?o0000ooooooooool0e?ooool3
o`0006Sooooo000Vooooo`03o`000?oooooooooo0=;ooooo0_l0001[ooooo`009_ooool00ol0003o
ooooooooo`3?ooooo`?o0000KOooool002Kooooo00?o0000ooooooooool0cOooool2o`00073ooooo
000Vooooo`;o0000c?ooool2o`0007;ooooo000Vooooo`03o`000?oooooooooo0<Sooooo0ol0001d
ooooo`009_ooool00ol0003oooooooooo`36ooooo`;o0000Moooool002Kooooo00?o0000oooooooo
ool0`oooool3o`0007Wooooo000Vooooo`03o`000?oooooooooo0<7ooooo0_l0001looooo`009_oo
ool2o`000<3ooooo0_l0001nooooo`009_ooool00ol0003oooooooooo`2looooo`?o0000P?ooool0
02Kooooo00?o0000ooooooooool0^_ooool2o`0008?ooooo000Vooooo`03o`000?oooooooooo0;Oo
oooo0ol00025ooooo`009_ooool2o`000;Kooooo0_l00028ooooo`009_ooool00ol0003ooooooooo
o`2booooo`?o0000R_ooool002Kooooo00?o0000ooooooooool0/?ooool2o`0008gooooo000;oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo0:kooooo0_l0002?ooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Zoooool3
o`00097ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05
ooooo`?o0000ZOooool2o`0009Cooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:Oooooo0_l0002Fooooo`002oooool01Ol0
003ooooooooooooooooo000000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2T
ooooo`?o0000V?ooool000_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0X_ooool2o`0009_ooooo000;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:3ooooo0_l0002M
ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001oooool2
o`0009oooooo0_l0002Oooooo`009_ooool00ol0003oooooooooo`2Kooooo`?o0000XOooool002Ko
oooo00?o0000ooooooooool0VOooool2o`000:Cooooo000Vooooo`03o`000?oooooooooo09Oooooo
0_l0002Vooooo`009_ooool2o`0009Kooooo0_l0002Xooooo`009_ooool00ol0003oooooooooo`2C
ooooo`;o0000Z_ooool002Kooooo00?o0000ooooooooool0T?ooool3o`000:cooooo000Vooooo`03
o`000?oooooooooo08kooooo0_l0002_ooooo`009_ooool00ol0003oooooooooo`2<ooooo`;o0000
/Oooool002Kooooo0_l0002;ooooo`;o0000/oooool002Kooooo00?o0000ooooooooool0Qoooool3
o`000;Gooooo000Vooooo`03o`000?oooooooooo08Gooooo0_l0002hooooo`009_ooool00ol0003o
ooooooooo`23ooooo`;o0000^_ooool002Kooooo00?o0000ooooooooool0POooool2o`000;cooooo
000Vooooo`;o0000Ooooool3o`000;kooooo000Vooooo`03o`000?oooooooooo07cooooo0_l00031
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000Go410@
ooooooooooooooooodA4A002o`000003oc8b<_oMgMgooooo00Cooooo00?o0000ooooooooool0N_oo
ool2o`000<?ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo07Sooooo0_l0
0035ooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`03ooooo`?o0000M_ooool2o`000<Oooooo0003ooooo`05o`000?oooooo
ooooooooool000003_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0Loooool3o`000<Wooooo0003ooooo`05o`000?ooooooooooooooool000003_oo
ool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`1aooooo`;o0000c?ooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1_ooooo`;o0000
c_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1]ooooo`;o0000d?ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Gooooo1?l00006ooooo`;o0000
K?ooool2o`000=;ooooo000Vooooo`03o`000?oooooooooo06Wooooo0_l0003Dooooo`009_ooool0
0ol0003oooooooooo`1Wooooo`;o0000e_ooool002Kooooo00?o0000ooooooooool0IOooool2o`00
0=Sooooo000Vooooo`03o`000?oooooooooo06?ooooo0_l0003Jooooo`009_ooool2o`00067ooooo
0ol0003Looooo`009_ooool00ol0003oooooooooo`1Nooooo`;o0000goooool002Kooooo00?o0000
ooooooooool0G?ooool2o`000>7ooooo000Vooooo`03o`000?oooooooooo05[ooooo0_l0003Soooo
o`009_ooool00ol0003oooooooooo`1Hooooo`;o0000iOooool002Kooooo0_l0001Gooooo`;o0000
ioooool002Kooooo00?o0000ooooooooool0E?ooool2o`000>Wooooo000Vooooo`03o`000?oooooo
oooo05;ooooo0_l0003[ooooo`009_ooool00ol0003oooooooooo`1@ooooo`;o0000kOooool002Ko
oooo0_l0001?ooooo`;o0000koooool002Kooooo00?o0000ooooooooool0C?ooool2o`000?7ooooo
000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`00
0?oooooooooo04[ooooo0_l0003cooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`18ooooo`;o
0000mOooool000_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?o0000ooooooooool0A_ooool2o`000?Oooooo000;ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000A?ooool2o`000?Wooooo000;ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo04;o
oooo0_l0003kooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`10ooooo`;o0000oOooool000_ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0noooo
o`;o0000ooooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0looooo`;o0000ooooool2ooooo`009_ooool2o`00
03_ooooo0_l0003oooooo`Cooooo000Vooooo`03o`000?oooooooooo03Sooooo0_l0003oooooo`Ko
oooo000Vooooo`03o`000?oooooooooo03Kooooo0_l0003oooooo`Sooooo000Vooooo`03o`000?oo
oooooooo03Cooooo0_l0003oooooo`[ooooo000Vooooo`;o0000<oooool2o`000?oooooo3?ooool0
02Kooooo00?o0000ooooooooool0<?ooool2o`000?oooooo3_ooool002Kooooo00?o0000oooooooo
ool0;_ooool2o`000?oooooo4?ooool002Kooooo00?o0000ooooooooool0;?ooool2o`000?oooooo
4_ooool002Kooooo00?o0000ooooooooool0:_ooool2o`000?oooooo5?ooool002Kooooo0_l0000Y
ooooo`;o0000oooooolFooooo`009_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
0?oooooo5_ooool002Kooooo00?o0000ooooooooool09Oooool2o`000?oooooo6Oooool002Kooooo
00?o0000ooooooooool08oooool2o`000?oooooo6oooool002Kooooo00?o0000ooooooooool08Ooo
ool2o`000?oooooo7Oooool002Kooooo0_l0000Pooooo`;o0000oooooolOooooo`009_ooool00ol0
003oooooooooo`0Mooooo`;o0000oooooolQooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool06oooool2o`000?oooooo8oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`0Iooooo`;o0000oooooolUooooo`000oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o00005ooo
ool2o`000?oooooo9oooool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Eooooo`;o0000oooo
oolYooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool04oooool2o`000?oooooo
:oooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`;o0000ooooool]ooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool2o`000?oooooo;oooool000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
00Kooooo0_l0000>ooooo`;o0000oooooolaooooo`009_ooool00ol0003oooooooooo`0;ooooo`;o
0000oooooolcooooo`009_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0?oooooo
<oooool002Kooooo00?o0000ooooooooool02?ooool2o`000?oooooo=_ooool002Kooooo00?o0000
ooooooooool01_ooool2o`000?oooooo>?ooool002Kooooo0_l00005ooooo`;o0000ooooooljoooo
o`009_ooool00ol0003oooooooooo`02ooooo`;o0000oooooollooooo`009_ooool00ol0003ooooo
ooooo`02o`000?oooooo?_ooool002Kooooo0ol0003ooooood3ooooo000Vooooo`;o0000oooooom1
ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooo
od3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@
4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o
0000ooooooooool0oooooom0ooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05o`000?oooooo
ooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000oooooom0ooooo`002oooool0
1Ol0003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01_ooool00ol0003ooooooooo
o`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qoooo
o`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooood3ooooo
000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Ko
oooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0003ooooood3ooooo0003oooo
o`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`06ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol0003ooooooooooooooooo
000000gooooo00?o410@o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o
^[Zjob4Q8Oooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l00000
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01?ooool4o`0000Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003o
ooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo
00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`3ooooood3o
oooo000;ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007oooo
o`?o0000oooooom0ooooo`002oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEE
EOoooooo0000oooooom:ooooo`002oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMg
olc<c?l00000oooooom:ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l00000oooooom:ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMg
o`000?ooool0oooooom9ooooo`00oooooomYooooo`00UOooool2o`0000_ooooo00?o0000okZj^_oo
ool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0[Oooool009Gooooo00?o0000ooooooooool0
2_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<Zkooooo002:ooooo`05oa0@4?l0
003o0000o`000?l@41001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03
ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo
00?ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00[ooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`25ooooo`00S?ooool00ol0
003oooooooooo`06ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?o
oooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000oooo
ooooool00oooool00oo<c<co0000oa0@4005ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l0
0005ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo08Gooooo002<
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<
c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOooool0QOooool008cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo1_l0
0005ooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool0Q?ooool008cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03Oooool00omEEEGoc<c<ooooo`24ooooo`00ROooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o0000
2?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool02Oooool00ol@413o0000
o`000003o`0000gooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`24ooooo`00ROoo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S80QOooool008Wooooo
1ol00005ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003ooooo
ooooo`0<ooooo`03oeEEEOmVIVKo000000cooooo1Ol00025ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .43456 m
.11905 .38459 L
.21429 .33625 L
.30952 .28956 L
.40476 .24452 L
.5 .20103 L
.59524 .15896 L
.69048 .1181 L
.78571 .07818 L
.88095 .03892 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool3o`000003ooooool0003ooooo
017ooooo00Co8B4QogMgMomgMgOo<S8b2_ooool002Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0aooooo`;o00001?ooool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`00
00Wooooo000Vooooo`03o`000?oooooooooo0?oooooo5oooool2o`0002Oooooo000Vooooo`03o`00
0?oooooooooo0?oooooo5?ooool3o`0002Wooooo000Vooooo`;o0000oooooolCooooo`;o0000;?oo
ool002Kooooo00?o0000ooooooooool0ooooool?ooooo`?o0000;_ooool002Kooooo00?o0000oooo
ooooool0ooooool=ooooo`;o0000<Oooool002Kooooo00?o0000ooooooooool0ooooool:ooooo`?o
0000<oooool002Kooooo00?o0000ooooooooool0ooooool8ooooo`;o0000=_ooool002Kooooo0_l0
003oooooo`Oooooo0_l0000hooooo`009_ooool00ol0003oooooooooo`3oooooo`?ooooo0ol0000j
ooooo`009_ooool00ol0003oooooooooo`3oooooo`7ooooo0_l0000mooooo`009_ooool00ol0003o
ooooooooo`3mooooo`?o0000?oooool002Kooooo0_l0003looooo`;o0000@_ooool002Kooooo00?o
0000ooooooooool0nOooool2o`0004Cooooo000Vooooo`03o`000?oooooooooo0?Kooooo0ol00016
ooooo`009_ooool00ol0003oooooooooo`3dooooo`;o0000BOooool002Kooooo00?o0000oooooooo
ool0lOooool3o`0004_ooooo000Vooooo`;o0000l?ooool2o`0004kooooo000Vooooo`03o`000?oo
oooooooo0>cooooo0ol0001@ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool0j_ooool2o`0005?ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0j?ooool2o`0005Gooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`3Uooooo`?o0000Eoooool000?ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?ooooooooooooooool000001oooool00omgMgOo<S8booooo`04ooooo`?o0000hooo
ool2o`0005[ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0>3o
oooo0ol0001Looooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooo
oooooooooa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0g_ooool2o`00
05oooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3Looooo`;o0000HOooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?oo
ool4o`0000Kooooo0_l0003Jooooo`?o0000Hoooool002Kooooo00?o0000ooooooooool0eoooool2
o`0006Kooooo000Vooooo`03o`000?oooooooooo0=Cooooo0ol0001Xooooo`009_ooool00ol0003o
ooooooooo`3Booooo`;o0000Joooool002Kooooo00?o0000ooooooooool0coooool3o`0006gooooo
000Vooooo`;o0000c_ooool2o`00073ooooo000Vooooo`03o`000?oooooooooo0<_ooooo0_l0001b
ooooo`009_ooool00ol0003oooooooooo`38ooooo`?o0000M?ooool002Kooooo00?o0000oooooooo
ool0a_ooool2o`0007Oooooo000Vooooo`03o`000?oooooooooo0<?ooooo0ol0001iooooo`009_oo
ool2o`000<;ooooo0_l0001looooo`009_ooool00ol0003oooooooooo`2oooooo`;o0000O_ooool0
02Kooooo00?o0000ooooooooool0_?ooool3o`00083ooooo000Vooooo`03o`000?oooooooooo0;[o
oooo0_l00023ooooo`009_ooool2o`000;Sooooo0ol00025ooooo`009_ooool00ol0003ooooooooo
o`2eooooo`;o0000R?ooool002Kooooo00?o0000ooooooooool0/_ooool3o`0008[ooooo000;oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo0;3ooooo0_l0002=ooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0[_ooool2
o`0008oooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05
ooooo`?o0000Zoooool3o`00097ooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:Wooooo0_l0002Dooooo`002oooool01Ol0
003ooooooooooooooooo000000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2W
ooooo`;o0000U_ooool000_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0Y?ooool3o`0009Sooooo000;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:;ooooo0_l0002K
ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001oooool2
o`000:7ooooo0_l0002Mooooo`009_ooool00ol0003oooooooooo`2Nooooo`;o0000Woooool002Ko
oooo00?o0000ooooooooool0Voooool3o`000:7ooooo000Vooooo`03o`000?oooooooooo09Wooooo
0_l0002Tooooo`009_ooool2o`0009Sooooo0_l0002Vooooo`009_ooool00ol0003oooooooooo`2E
ooooo`;o0000Z?ooool002Kooooo00?o0000ooooooooool0Toooool2o`000:[ooooo000Vooooo`03
o`000?oooooooooo093ooooo0ol0002/ooooo`009_ooool00ol0003oooooooooo`2>ooooo`;o0000
[oooool002Kooooo0_l0002=ooooo`;o0000/Oooool002Kooooo00?o0000ooooooooool0R_ooool2
o`000;?ooooo000Vooooo`03o`000?oooooooooo08Oooooo0ol0002eooooo`009_ooool00ol0003o
ooooooooo`25ooooo`;o0000^?ooool002Kooooo00?o0000ooooooooool0Poooool2o`000;[ooooo
000Vooooo`;o0000P_ooool2o`000;cooooo000Vooooo`03o`000?oooooooooo07kooooo0ol0002n
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000Go410@
ooooooooooooooooodA4A002o`000003oc8b<_oMgMgooooo00Cooooo00?o0000ooooooooool0O?oo
ool2o`000<7ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo07[ooooo0_l0
0033ooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`03ooooo`?o0000N?ooool2o`000<Gooooo0003ooooo`05o`000?oooooo
ooooooooool000003_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0M_ooool2o`000<Oooooo0003ooooo`05o`000?ooooooooooooooool000003_oo
ool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`1cooooo`?o0000bOooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`;o0000
c?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1_ooooo`;o0000c_ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Gooooo1?l00006ooooo`;o0000
K_ooool2o`000=3ooooo000Vooooo`03o`000?oooooooooo06_ooooo0_l0003Booooo`009_ooool0
0ol0003oooooooooo`1Yooooo`;o0000e?ooool002Kooooo00?o0000ooooooooool0Ioooool2o`00
0=Kooooo000Vooooo`03o`000?oooooooooo06Gooooo0_l0003Hooooo`009_ooool2o`0006Cooooo
0_l0003Jooooo`009_ooool00ol0003oooooooooo`1Pooooo`?o0000g?ooool002Kooooo00?o0000
ooooooooool0G_ooool2o`000=oooooo000Vooooo`03o`000?oooooooooo05cooooo0_l0003Qoooo
o`009_ooool00ol0003oooooooooo`1Jooooo`;o0000hoooool002Kooooo0_l0001Iooooo`;o0000
iOooool002Kooooo00?o0000ooooooooool0E_ooool2o`000>Oooooo000Vooooo`03o`000?oooooo
oooo05Cooooo0_l0003Yooooo`009_ooool00ol0003oooooooooo`1Booooo`;o0000joooool002Ko
oooo0_l0001Aooooo`;o0000kOooool002Kooooo00?o0000ooooooooool0C_ooool2o`000>oooooo
000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`00
0?oooooooooo04cooooo0_l0003aooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1:ooooo`;o
0000loooool000_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?o0000ooooooooool0B?ooool2o`000?Gooooo000;ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000A_ooool2o`000?Oooooo000;ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo04Co
oooo0_l0003iooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`12ooooo`;o0000noooool000_ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`10oooo
o`;o0000oOooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0nooooo`;o0000ooooool002Kooooo0_l0000moooo
o`;o0000ooooool2ooooo`009_ooool00ol0003oooooooooo`0jooooo`;o0000ooooool4ooooo`00
9_ooool00ol0003oooooooooo`0hooooo`;o0000ooooool6ooooo`009_ooool00ol0003ooooooooo
o`0fooooo`;o0000ooooool8ooooo`009_ooool2o`0003Gooooo0_l0003oooooo`[ooooo000Voooo
o`03o`000?oooooooooo03;ooooo0_l0003oooooo`cooooo000Vooooo`03o`000?oooooooooo033o
oooo0_l0003oooooo`kooooo000Vooooo`03o`000?oooooooooo02kooooo0_l0003ooooooa3ooooo
000Vooooo`03o`000?oooooooooo02cooooo0_l0003ooooooa;ooooo000Vooooo`;o0000:oooool2
o`000?oooooo5?ooool002Kooooo00?o0000ooooooooool0:?ooool2o`000?oooooo5_ooool002Ko
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`3ooooooaKooooo000Vooooo`03o`00
0?oooooooooo02Gooooo0_l0003ooooooaWooooo000Vooooo`03o`000?oooooooooo02?ooooo0_l0
003ooooooa_ooooo000Vooooo`;o00008_ooool2o`000?oooooo7Oooool002Kooooo00?o0000oooo
ooooool07oooool2o`000?oooooo7oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo01gooooo0_l0003oooooob7ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool06oooool2o`000?oooooo8oooool000?ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`0001Wooooo0_l0
003oooooobGooooo0003ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool05oooool2o`000?oooooo9ooo
ool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01Gooooo0_l0003oooooobWooooo
0003ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool04oooool2o`000?oooooo:oooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo017ooooo0_l0003oooooobgooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006oooo
o`;o00004?ooool2o`000?oooooo;oooool002Kooooo00?o0000ooooooooool03Oooool2o`000?oo
oooo<Oooool002Kooooo00?o0000ooooooooool02oooool2o`000?oooooo<oooool002Kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`3ooooooc?ooooo000Vooooo`03o`000?oooooo
oooo00Sooooo0_l0003oooooocKooooo000Vooooo`;o00001oooool2o`000?oooooo>?ooool002Ko
oooo00?o0000ooooooooool01?ooool2o`000?oooooo>_ooool002Kooooo00?o0000ooooooooool0
0_ooool2o`000?oooooo??ooool002Kooooo00?o0000ooooooooool00_l0003oooooockooooo000V
ooooo`?o0000oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@?ooool0
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[Zjoooooomg
MgOo<S8b00Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood3ooooo000;
ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000oooo
oom0ooooo`002oooool01Ol0003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01_oo
ool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@
o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo
@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0003o
oooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`06
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol0
003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooooooo
oooo410@00kooooo00?o^[Zjob4Q8Oooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nH
V9SooooookZj^_l000001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT01?ooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003o
ooooooooo`3ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4Co
gMgMooooool00007ooooo`?o0000oooooom0ooooo`002oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOoooooo0000oooooom:ooooo`002oooool01Ol@413ooooooooooooooooo
410@00cooooo00?oMgMgolc<c?l00000oooooom:ooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?ok^k^odA4A?l00000oooooom:ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00gooooo00?oMgMgo`000?ooool0oooooom9ooooo`00oooooomYooooo`00UOooool2o`0000_o
oooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0[Oooool009Gooooo
00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<Zkooooo
002:ooooo`05oa0@4?l0003o0000o`000?l@41001_ooool01?l0003oooooooooooooool2o`0000;o
oooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04oooo
o`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co
^[Zj00[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<08Gooooo002<ooooo`03o`000?oooooooooo00Kooooo00[o0000ooooooooooooooooonk^
k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^
ogMgMol@41001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko410@
okZj^_o^k^koMgMgoa0@4?ooool6o`0000Gooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo
00Go8B4QoiRHV?ooooooV9RHob4Q8@25ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`05
o`000?ooooooooooooooool00000QOooool008cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo1_l00005ooooo`03o`000?oooooooooo
00[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P25ooooo`00S?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:
ooooo`05olc<c?l0003o0000o`000?o<c<`0QOooool008Wooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo
00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo00Wooooo00?o410@o`000?l00000
0ol0000=ooooo`03o`000?oooooooooo00[ooooo00Go410@okZj^_oooooo^[Zjoa0@4025ooooo`00
ROooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooookZj^_l00000QOooool008Wo
oooo1ol00005ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003o
ooooooooo`0<ooooo`03oeEEEOmVIVKo000000cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@25oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .43816 m
.11905 .38846 L
.21429 .34022 L
.30952 .29349 L
.40476 .24824 L
.5 .20441 L
.59524 .16184 L
.69048 .12037 L
.78571 .07975 L
.88095 .03972 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool3o`000003ooooool0003ooooo
017ooooo00Co8B4QogMgMomgMgOo<S8b2_ooool002Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0aooooo`;o00001?ooool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`00
00Wooooo000Vooooo`03o`000?oooooooooo0?oooooo5oooool2o`0002Oooooo000Vooooo`03o`00
0?oooooooooo0?oooooo5?ooool3o`0002Wooooo000Vooooo`;o0000oooooolCooooo`;o0000;?oo
ool002Kooooo00?o0000ooooooooool0ooooool?ooooo`?o0000;_ooool002Kooooo00?o0000oooo
ooooool0ooooool=ooooo`;o0000<Oooool002Kooooo00?o0000ooooooooool0ooooool:ooooo`?o
0000<oooool002Kooooo00?o0000ooooooooool0ooooool8ooooo`;o0000=_ooool002Kooooo0_l0
003oooooo`Oooooo0_l0000hooooo`009_ooool00ol0003oooooooooo`3oooooo`?ooooo0ol0000j
ooooo`009_ooool00ol0003oooooooooo`3oooooo`7ooooo0_l0000mooooo`009_ooool00ol0003o
ooooooooo`3mooooo`?o0000?oooool002Kooooo0_l0003looooo`;o0000@_ooool002Kooooo00?o
0000ooooooooool0nOooool2o`0004Cooooo000Vooooo`03o`000?oooooooooo0?Kooooo0ol00016
ooooo`009_ooool00ol0003oooooooooo`3dooooo`;o0000BOooool002Kooooo00?o0000oooooooo
ool0lOooool3o`0004_ooooo000Vooooo`;o0000l?ooool2o`0004kooooo000Vooooo`03o`000?oo
oooooooo0>cooooo0ol0001@ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool0j_ooool2o`0005?ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0j?ooool2o`0005Gooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`3Uooooo`?o0000Eoooool000?ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?ooooooooooooooool000001oooool00omgMgOo<S8booooo`04ooooo`?o0000hooo
ool2o`0005[ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0>7o
oooo0_l0001Looooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooo
oooooooooa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0g_ooool3o`00
05kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3Looooo`;o0000HOooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?oo
ool4o`0000Kooooo0_l0003Kooooo`;o0000Hoooool002Kooooo00?o0000ooooooooool0f?ooool2
o`0006Gooooo000Vooooo`03o`000?oooooooooo0=Gooooo0ol0001Wooooo`009_ooool00ol0003o
ooooooooo`3Cooooo`;o0000J_ooool002Kooooo00?o0000ooooooooool0dOooool2o`0006cooooo
000Vooooo`;o0000d?ooool2o`0006kooooo000Vooooo`03o`000?oooooooooo0<gooooo0_l0001`
ooooo`009_ooool00ol0003oooooooooo`3:ooooo`?o0000L_ooool002Kooooo00?o0000oooooooo
ool0b?ooool2o`0007Gooooo000Vooooo`03o`000?oooooooooo0<Kooooo0_l0001gooooo`009_oo
ool2o`000<Cooooo0ol0001iooooo`009_ooool00ol0003oooooooooo`31ooooo`;o0000O?ooool0
02Kooooo00?o0000ooooooooool0_oooool2o`0007kooooo000Vooooo`03o`000?oooooooooo0;co
oooo0ol00020ooooo`009_ooool2o`000;_ooooo0_l00023ooooo`009_ooool00ol0003ooooooooo
o`2gooooo`?o0000QOooool002Kooooo00?o0000ooooooooool0]Oooool2o`0008Sooooo000;oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo0;;ooooo0ol0002:ooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool2
o`0008gooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05
ooooo`?o0000[_ooool2o`0008oooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:_ooooo0ol0002Aooooo`002oooool01Ol0
003ooooooooooooooooo000000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Y
ooooo`;o0000U?ooool000_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0Yoooool2o`0009Kooooo000;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:Cooooo0ol0002H
ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001oooool2
o`000:?ooooo0_l0002Kooooo`009_ooool00ol0003oooooooooo`2Pooooo`;o0000WOooool002Ko
oooo00?o0000ooooooooool0W_ooool2o`0009oooooo000Vooooo`03o`000?oooooooooo09_ooooo
0ol0002Qooooo`009_ooool2o`0009[ooooo0_l0002Tooooo`009_ooool00ol0003oooooooooo`2G
ooooo`;o0000Y_ooool002Kooooo00?o0000ooooooooool0UOooool2o`000:Sooooo000Vooooo`03
o`000?oooooooooo09?ooooo0_l0002Zooooo`009_ooool00ol0003oooooooooo`2@ooooo`?o0000
[?ooool002Kooooo0_l0002?ooooo`;o0000[oooool002Kooooo00?o0000ooooooooool0S?ooool2
o`000;7ooooo000Vooooo`03o`000?oooooooooo08[ooooo0_l0002cooooo`009_ooool00ol0003o
ooooooooo`27ooooo`?o0000]Oooool002Kooooo00?o0000ooooooooool0QOooool2o`000;Sooooo
000Vooooo`;o0000Q?ooool2o`000;[ooooo000Vooooo`03o`000?oooooooooo087ooooo0_l0002l
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000Go410@
ooooooooooooooooodA4A002o`000003oc8b<_oMgMgooooo00Cooooo00?o0000ooooooooool0O_oo
ool3o`000;kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo07cooooo0_l0
0031ooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`03ooooo`?o0000N_ooool2o`000<?ooooo0003ooooo`05o`000?oooooo
ooooooooool000003_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0N?ooool2o`000<Gooooo0003ooooo`05o`000?ooooooooooooooool000003_oo
ool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`1fooooo`;o0000aoooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1cooooo`?o0000
bOooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`;o0000c?ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Gooooo1?l00006ooooo`;o0000
L?ooool2o`000<kooooo000Vooooo`03o`000?oooooooooo06gooooo0_l0003@ooooo`009_ooool0
0ol0003oooooooooo`1[ooooo`;o0000d_ooool002Kooooo00?o0000ooooooooool0JOooool2o`00
0=Cooooo000Vooooo`03o`000?oooooooooo06Oooooo0_l0003Fooooo`009_ooool2o`0006Kooooo
0_l0003Hooooo`009_ooool00ol0003oooooooooo`1Sooooo`;o0000f_ooool002Kooooo00?o0000
ooooooooool0H?ooool3o`000=cooooo000Vooooo`03o`000?oooooooooo05kooooo0_l0003Ooooo
o`009_ooool00ol0003oooooooooo`1Looooo`;o0000hOooool002Kooooo0_l0001Kooooo`;o0000
hoooool002Kooooo00?o0000ooooooooool0F?ooool2o`000>Gooooo000Vooooo`03o`000?oooooo
oooo05Kooooo0_l0003Wooooo`009_ooool00ol0003oooooooooo`1Dooooo`;o0000jOooool002Ko
oooo0_l0001Cooooo`;o0000joooool002Kooooo00?o0000ooooooooool0D?ooool2o`000>gooooo
000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`00
0?oooooooooo04kooooo0_l0003_ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1<ooooo`;o
0000lOooool000_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?o0000ooooooooool0B_ooool2o`000??ooooo000;ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000B?ooool2o`000?Gooooo000;ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo04Ko
oooo0_l0003gooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`14ooooo`;o0000nOooool000_ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`12oooo
o`;o0000noooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`10ooooo`;o0000oOooool002Kooooo0_l0000ooooo
o`;o0000ooooool002Kooooo00?o0000ooooooooool0??ooool2o`000?oooooo0_ooool002Kooooo
00?o0000ooooooooool0>_ooool2o`000?oooooo1?ooool002Kooooo00?o0000ooooooooool0>?oo
ool2o`000?oooooo1_ooool002Kooooo0_l0000gooooo`;o0000ooooool8ooooo`009_ooool00ol0
003oooooooooo`0dooooo`;o0000ooooool:ooooo`009_ooool00ol0003oooooooooo`0booooo`;o
0000ooooool<ooooo`009_ooool00ol0003oooooooooo`0`ooooo`;o0000ooooool>ooooo`009_oo
ool00ol0003oooooooooo`0^ooooo`;o0000ooooool@ooooo`009_ooool2o`0002gooooo0_l0003o
oooooa;ooooo000Vooooo`03o`000?oooooooooo02[ooooo0_l0003ooooooaCooooo000Vooooo`03
o`000?oooooooooo02Sooooo0_l0003ooooooaKooooo000Vooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0oooooolFooooo`009_ooool00ol0003oooooooooo`0Uooooo`;o0000oooo
oolIooooo`009_ooool2o`0002Cooooo0_l0003ooooooa_ooooo000Vooooo`03o`000?oooooooooo
027ooooo0_l0003ooooooagooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0O
ooooo`;o0000oooooolOooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo01gooooo0_l0003oooooob7ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0000Kooooo`;o0000oooo
oolSooooo`000oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01Wooooo0_l0003oooooobGooooo0003
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Gooooo`;o0000oooooolWooooo`000ooo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01Gooooo0_l0003oooooobWooooo0003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Cooooo`;o0000ooooool[ooooo`000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`00
01;ooooo0_l0003oooooobgooooo000Vooooo`03o`000?oooooooooo00oooooo0_l0003ooooooboo
oooo000Vooooo`03o`000?oooooooooo00gooooo0_l0003ooooooc7ooooo000Vooooo`03o`000?oo
oooooooo00_ooooo0_l0003ooooooc?ooooo000Vooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0oooooolcooooo`009_ooool2o`0000Wooooo0_l0003oooooocKooooo000Vooooo`03
o`000?oooooooooo00Kooooo0_l0003oooooocSooooo000Vooooo`03o`000?oooooooooo00Cooooo
0_l0003ooooooc[ooooo000Vooooo`03o`000?oooooooooo00;ooooo0_l0003ooooooccooooo000V
ooooo`;o000000?oooooo`000?l00000oooooolnooooo`009_ooool3o`000?oooooo@?ooool002Ko
oooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo
000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0oooooom0
ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[o
ooooogMgMolb<S801_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?oooooo
ooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Gooooo0ol0
003ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj
^P06ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@
400>ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0oooooom0ooooo`002oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`00
0?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000
oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oo
oooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oo
oooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool3
o`000?oooooo@?ooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413o
oooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003oooo
o`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj^P04ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00onj^[[o8B4Qooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
410@oiRHV?oooooo^[Zjo`000004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@04ooooo`Co00001_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oo
oooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooo
od7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooom0ooooo`002oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo0ol0003ooooood3ooooo000;ooooo`05o`000?oooooooooooooo
ool000002oooool01?oMgMgoEEEEooooool0003ooooood[ooooo000;ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`00003ooooood[ooooo000;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00oo^k^koA4A4o`00003ooooood[ooooo000;ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`3oooooodWooooo003oooooofWooooo002Eooooo`;o
00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2]ooooo`00
UOooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b
[_ooool008[ooooo00Go410@o`000?l0003o0000oa0@4006ooooo`04o`000?ooooooooooooooo`;o
00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj
00Cooooo00?o0000ooooooooool00oooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000
odA4A?nj^[X02_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`04oa0@4?l0003o
A4A4olc<c8Kooooo002<ooooo`03o`000?oooooooooo00Kooooo00[o0000ooooooooooooooooonk^
k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^
ogMgMol@41001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko410@
okZj^_o^k^koMgMgoa0@4?ooool6o`0000Gooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo
00?oV9RHoa0@4?oMgMd0QOooool008cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00on7QhOoEEEE
ooooo`24ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co
k^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool00oooool6o`0000Gooooo00?o0000ooooooooool02_ooool01Oo<c<co8B4Q
o`000?mEEEGo000008Gooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00Go8B4QohN7Qooo
ooooV9RHo`000025ooooo`00ROooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003
o`0000Gooooo00?o0000ooooooooool02Oooool00ol@413o0000o`000003o`0000gooooo00?o0000
ooooooooool02_ooool01Ol0003ooooooooooooooooo000008Gooooo0029ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00[ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@25ooooo`00ROooool7o`0000Gooooo0_l0
000Booooo`03o`000?oooooooooo00Gooooo0_l0000=ooooo`03o`000?oooooooooo00cooooo00?o
EEEEofIVI_l000003?ooool01Oo<c<co410@o`000?lb<S;ok^k^08Gooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .44145 m
.11905 .39197 L
.21429 .34382 L
.30952 .29704 L
.40476 .25161 L
.5 .20745 L
.59524 .16444 L
.69048 .12242 L
.78571 .08116 L
.88095 .04045 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->-20,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool3o`000003ooooool0003ooooo
017ooooo00Co8B4QogMgMomgMgOo<S8b2_ooool002Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0aooooo`;o00001?ooool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`00
00Wooooo000Vooooo`03o`000?oooooooooo0?oooooo5oooool2o`0002Oooooo000Vooooo`03o`00
0?oooooooooo0?oooooo5?ooool3o`0002Wooooo000Vooooo`;o0000oooooolCooooo`;o0000;?oo
ool002Kooooo00?o0000ooooooooool0ooooool?ooooo`?o0000;_ooool002Kooooo00?o0000oooo
ooooool0ooooool=ooooo`;o0000<Oooool002Kooooo00?o0000ooooooooool0ooooool:ooooo`?o
0000<oooool002Kooooo00?o0000ooooooooool0ooooool8ooooo`;o0000=_ooool002Kooooo0_l0
003oooooo`Oooooo0_l0000hooooo`009_ooool00ol0003oooooooooo`3oooooo`?ooooo0ol0000j
ooooo`009_ooool00ol0003oooooooooo`3oooooo`7ooooo0_l0000mooooo`009_ooool00ol0003o
ooooooooo`3nooooo`;o0000?oooool002Kooooo0_l0003looooo`?o0000@Oooool002Kooooo00?o
0000ooooooooool0nOooool2o`0004Cooooo000Vooooo`03o`000?oooooooooo0?Oooooo0_l00016
ooooo`009_ooool00ol0003oooooooooo`3eooooo`;o0000B?ooool002Kooooo00?o0000oooooooo
ool0l_ooool3o`0004[ooooo000Vooooo`;o0000lOooool2o`0004gooooo000Vooooo`03o`000?oo
oooooooo0>kooooo0_l0001?ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool0k?ooool2o`00057ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0j_ooool2o`0005?ooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`3Wooooo`?o0000EOooool000?ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?ooooooooooooooool000001oooool00omgMgOo<S8booooo`04ooooo`?o0000iOoo
ool2o`0005Sooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0>?o
oooo0_l0001Jooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooo
oooooooooa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0h?ooool3o`00
05cooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3Nooooo`;o0000Goooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?oo
ool4o`0000Kooooo0_l0003Mooooo`;o0000HOooool002Kooooo00?o0000ooooooooool0fOooool3
o`0006?ooooo000Vooooo`03o`000?oooooooooo0=Oooooo0_l0001Vooooo`009_ooool00ol0003o
ooooooooo`3Dooooo`?o0000J?ooool002Kooooo00?o0000ooooooooool0d_ooool2o`0006_ooooo
000Vooooo`;o0000d?ooool3o`0006gooooo000Vooooo`03o`000?oooooooooo0<gooooo0_l0001`
ooooo`009_ooool00ol0003oooooooooo`3;ooooo`;o0000L_ooool002Kooooo00?o0000oooooooo
ool0b?ooool3o`0007Cooooo000Vooooo`03o`000?oooooooooo0<Kooooo0_l0001gooooo`009_oo
ool2o`000<Gooooo0_l0001iooooo`009_ooool00ol0003oooooooooo`31ooooo`?o0000Noooool0
02Kooooo00?o0000ooooooooool0_oooool2o`0007kooooo000Vooooo`03o`000?oooooooooo0;go
oooo0_l00020ooooo`009_ooool2o`000;cooooo0_l00022ooooo`009_ooool00ol0003ooooooooo
o`2hooooo`?o0000Q?ooool002Kooooo00?o0000ooooooooool0]_ooool2o`0008Oooooo000;oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo0;Cooooo0_l00029ooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool2
o`0008_ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05
ooooo`?o0000/?ooool2o`0008gooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:gooooo0ol0002?ooooo`002oooool01Ol0
003ooooooooooooooooo000000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2[
ooooo`;o0000T_ooool000_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0ZOooool2o`0009Cooooo000;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:Oooooo0_l0002F
ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001oooool2
o`000:Gooooo0ol0002Hooooo`009_ooool00ol0003oooooooooo`2Rooooo`;o0000Voooool002Ko
oooo00?o0000ooooooooool0X?ooool2o`0009gooooo000Vooooo`03o`000?oooooooooo09kooooo
0_l0002Oooooo`009_ooool2o`0009cooooo0ol0002Qooooo`009_ooool00ol0003oooooooooo`2I
ooooo`;o0000Y?ooool002Kooooo00?o0000ooooooooool0Uoooool2o`000:Kooooo000Vooooo`03
o`000?oooooooooo09Gooooo0_l0002Xooooo`009_ooool00ol0003oooooooooo`2Cooooo`;o0000
Z_ooool002Kooooo0_l0002Aooooo`?o0000[?ooool002Kooooo00?o0000ooooooooool0S_ooool2
o`000:oooooo000Vooooo`03o`000?oooooooooo08cooooo0_l0002aooooo`009_ooool00ol0003o
ooooooooo`2:ooooo`;o0000/oooool002Kooooo00?o0000ooooooooool0R?ooool2o`000;Gooooo
000Vooooo`;o0000Qoooool2o`000;Oooooo000Vooooo`03o`000?oooooooooo08Cooooo0_l0002i
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000Go410@
ooooooooooooooooodA4A002o`000003oc8b<_oMgMgooooo00Cooooo00?o0000ooooooooool0P_oo
ool2o`000;_ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo083ooooo0_l0
002mooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`03ooooo`?o0000OOooool3o`000;oooooo0003ooooo`05o`000?oooooo
ooooooooool000003_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0Noooool2o`000<;ooooo0003ooooo`05o`000?ooooooooooooooool000003_oo
ool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`1iooooo`;o0000a?ooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1gooooo`;o0000
a_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1eooooo`;o0000b?ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Gooooo1?l00006ooooo`;o0000
M?ooool2o`000<[ooooo000Vooooo`03o`000?oooooooooo077ooooo0_l0003<ooooo`009_ooool0
0ol0003oooooooooo`1_ooooo`;o0000c_ooool002Kooooo00?o0000ooooooooool0KOooool2o`00
0=3ooooo000Vooooo`03o`000?oooooooooo06[ooooo0ol0003Booooo`009_ooool2o`0006Wooooo
0_l0003Eooooo`009_ooool00ol0003oooooooooo`1Vooooo`;o0000eoooool002Kooooo00?o0000
ooooooooool0I?ooool2o`000=Wooooo000Vooooo`03o`000?oooooooooo067ooooo0ol0003Koooo
o`009_ooool00ol0003oooooooooo`1Oooooo`;o0000g_ooool002Kooooo0_l0001Nooooo`;o0000
h?ooool002Kooooo00?o0000ooooooooool0Foooool2o`000>;ooooo000Vooooo`03o`000?oooooo
oooo05Wooooo0_l0003Tooooo`009_ooool00ol0003oooooooooo`1Fooooo`?o0000i_ooool002Ko
oooo0_l0001Eooooo`;o0000jOooool002Kooooo00?o0000ooooooooool0D_ooool2o`000>_ooooo
000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`00
0?oooooooooo053ooooo0_l0003]ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1>ooooo`;o
0000koooool000_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?o0000ooooooooool0C?ooool2o`000?7ooooo000;ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000B_ooool2o`000??ooooo000;ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo04So
oooo0_l0003eooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`16ooooo`;o0000moooool000_ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`14oooo
o`;o0000nOooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`12ooooo`;o0000noooool002Kooooo0_l00011oooo
o`;o0000oOooool002Kooooo00?o0000ooooooooool0?_ooool2o`000?oooooo000Vooooo`03o`00
0?oooooooooo03cooooo0_l0003oooooo`;ooooo000Vooooo`03o`000?oooooooooo03[ooooo0_l0
003oooooo`Cooooo000Vooooo`;o0000>Oooool2o`000?oooooo1_ooool002Kooooo00?o0000oooo
ooooool0=_ooool2o`000?oooooo2?ooool002Kooooo00?o0000ooooooooool0=?ooool2o`000?oo
oooo2_ooool002Kooooo00?o0000ooooooooool0<_ooool2o`000?oooooo3?ooool002Kooooo00?o
0000ooooooooool0<?ooool2o`000?oooooo3_ooool002Kooooo0_l0000_ooooo`;o0000ooooool@
ooooo`009_ooool00ol0003oooooooooo`0/ooooo`;o0000oooooolBooooo`009_ooool00ol0003o
ooooooooo`0Zooooo`;o0000oooooolDooooo`009_ooool00ol0003oooooooooo`0Xooooo`;o0000
oooooolFooooo`009_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0?oooooo5_oo
ool002Kooooo0_l0000Vooooo`;o0000oooooolIooooo`009_ooool00ol0003oooooooooo`0Soooo
o`;o0000oooooolKooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool08Oooool2
o`000?oooooo7Oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`0Oooooo`;o0000oooooolOooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o00007Oooool2o`000?oooooo8Ooo
ool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Kooooo`;o0000oooooolSooooo`000oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool06Oooool2o`000?oooooo9Oooool000?ooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Gooooo`;o0000oooooolWooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool05Oooool2o`000?oooooo:Oooool000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0000Doooo
o`;o0000ooooool[ooooo`009_ooool00ol0003oooooooooo`0Aooooo`;o0000ooooool]ooooo`00
9_ooool00ol0003oooooooooo`0?ooooo`;o0000ooooool_ooooo`009_ooool00ol0003ooooooooo
o`0=ooooo`;o0000oooooolaooooo`009_ooool00ol0003oooooooooo`0;ooooo`;o0000oooooolc
ooooo`009_ooool2o`0000_ooooo00?o0000ooooooooool0oooooolcooooo`009_ooool00ol0003o
ooooooooo`08ooooo`;o0000oooooolfooooo`009_ooool00ol0003oooooooooo`06ooooo`;o0000
oooooolhooooo`009_ooool00ol0003oooooooooo`04ooooo`;o0000ooooooljooooo`009_ooool2
o`0000?ooooo0_l0003ooooooccooooo000Vooooo`03o`000?oooooooooo00;o0000oooooolnoooo
o`009_ooool3o`000?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@?ooool0
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[Zjoooooomg
MgOo<S8b00Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood3ooooo000;
ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000oooo
oom0ooooo`002oooool01Ol0003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01_oo
ool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@
o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo
@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0003o
oooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`06
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol0
003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooooooo
oooo410@00kooooo00?o^[Zjob4Q8Oooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nH
V9SooooookZj^_l000001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT01?ooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003o
ooooooooo`3ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4Co
gMgMooooool00007ooooo`?o0000oooooom0ooooo`002oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOoooooo0000oooooom:ooooo`002oooool01Ol@413ooooooooooooooooo
410@00cooooo00?oMgMgolc<c?l00000oooooom:ooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?ok^k^odA4A?l00000oooooom:ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00gooooo00?oMgMgo`000?ooool0oooooom9ooooo`00oooooomYooooo`00V?ooool2o`0000_o
oooo00?o0000okZj^_ooool03?ooool2o`0000Kooooo00?o0000okZj^_ooool0ZOooool009Sooooo
00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool01?ooool2oc8b<Z[ooooo
002>ooooo`05oa0@4?l0003o0000o`000?l@41001Oooool00ol0003oooooooooo`02ooooo`;o0000
0_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00?o
oooo00?o0000ooooooooool01?ooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4
A?nj^[X02Oooool5o`0000Gooooo0_lQ8B6;ooooo`00T?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03olc<c?l0003o
410@00Gooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oooooooooo00Cooooo00?o
c<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo1_l000001_ooooooV9RH
ob4Q8Oo^k^koooooodA4A0Gooooo0_lQ8B6;ooooo`00T?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP2Coooo
o`00T?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Cok^k^ob4Q8Ol@
413ok^k^2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01?ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h0T_ooool0093ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?oMgMgofIV
I_ooool0TOooool008gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`00
00Cooooo00?o0000ooooooooool02Oooool00ol@413o0000o`000003o`0000kooooo00?o0000oooo
ooooool0T?ooool008gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00_ooooo00Go0000okZj^_ooooooV9RHoa0@402Booooo`00SOooool7o`00
00Cooooo0_l0000Cooooo`03o`000?oooooooooo00Cooooo0_l0000=ooooo`03o`000?oooooooooo
00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02Booooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "Note, however, the rather small time step size that we took, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], " ", "=", " ", "0.01"}], 
        TraditionalForm]]],
  ". In part, this is because the forward-difference method used for the time \
derivative is only first-order accurate in ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", so small steps are required to achieve reasonable accuracy. But there is \
also another reason. If we attempt to run the code with a larger time step \
size, we run into an immediate problem: ",
  StyleBox["numerical instability",
    FontSlant->"Italic"],
  ". This is shown in Cell ",
  ButtonBox["6.57",
    ButtonData:>"Cell 6.57",
    ButtonStyle->"Hyperlink"],
  " for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "=", "0.05"}], TraditionalForm]]],
  ".  So that we need not reevaluate previous cells defining ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ", we use an ",
  StyleBox["Unset ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "command to clear only specific values of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["T",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["j",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["n",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ". "
}], "Text",
  CellTags->"i:70"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{\(Do[Unset[T[j, n]], {j, 1, M - 1}, {n, 1, 200}];\), 
      "\[IndentingNewLine]"}], "\n", 
    RowBox[{
      RowBox[{
        StyleBox[\(\[CapitalDelta]t\  = \ 0.05\),
          FontColor->RGBColor[0, 0, 1]], ";"}], 
      "\n"}], "\[IndentingNewLine]", \(Table[
        ListPlot[Table[{\[CapitalDelta]x\ j, \ T[j, n]}, {j, 0, M}], 
          PlotJoined \[Rule] True, PlotRange \[Rule] {0,  .4}, 
          AxesLabel \[Rule] {"\<x\>", "\<\>"}, 
          PlotLabel \[Rule] "\<T[x,t],t=\>" <> 
              ToString[\[CapitalDelta]t\ n]], {n, 0, 10, 2}];\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.57"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -32 0 ]
[.5 .63053 32 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.11905 .01391 L
.21429 .04944 L
.30952 .09734 L
.40476 .14833 L
.5 .19314 L
.59524 .22249 L
.69048 .22713 L
.78571 .19777 L
.88095 .12515 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00;ooooo1ol00002ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool04?ooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`009_ooool00ol0003oooooooooo`09oooo
o`Oo00009oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0fooooo`;o00004Oooool2o`0000;ooooo0_l00009oooo
o`009_ooool00ol0003oooooooooo`0@ooooo`Oo0000ooooool6ooooo`03o`000?oooooooooo023o
oooo000Vooooo`03o`000?oooooooooo01Oooooo1Ol0003oooooo`03o`000?oooooooooo027ooooo
000Vooooo`;o00007Oooool3o`000?cooooo00?o0000ooooooooool08Oooool002Kooooo00?o0000
ooooooooool07oooool3o`000?Sooooo00?o0000ooooooooool08_ooool002Kooooo00?o0000oooo
ooooool08_ooool2o`000?Gooooo00?o0000ooooooooool08oooool002Kooooo00?o0000oooooooo
ool09?ooool3o`000?7ooooo00?o0000ooooooooool09?ooool002Kooooo00?o0000ooooooooool0
9oooool3o`000>kooooo00?o0000ooooooooool09?ooool002Kooooo0_l0000[ooooo`;o0000jooo
ool00ol0003oooooooooo`0Uooooo`009_ooool00ol0003oooooooooo`0/ooooo`?o0000ioooool0
0ol0003oooooooooo`0Vooooo`009_ooool00ol0003oooooooooo`0_ooooo`;o0000i?ooool00ol0
003oooooooooo`0Wooooo`009_ooool00ol0003oooooooooo`0aooooo`?o0000h?ooool00ol0003o
ooooooooo`0Xooooo`009_ooool2o`0003Gooooo0ol0003Mooooo`03o`000?oooooooooo02Sooooo
000Vooooo`03o`000?oooooooooo03Oooooo0_l0003Jooooo`03o`000?oooooooooo02Wooooo000V
ooooo`03o`000?oooooooooo03Wooooo0_l0003Gooooo`03o`000?oooooooooo02[ooooo000Voooo
o`03o`000?oooooooooo03_ooooo0_l0003Dooooo`03o`000?oooooooooo02_ooooo000Vooooo`03
o`000?oooooooooo03gooooo0_l0003Booooo`03o`000?oooooooooo02_ooooo000Vooooo`;o0000
@?ooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo02cooooo000Vooooo`03o`000?oo
oooooooo043ooooo0_l0003=ooooo`03o`000?oooooooooo02gooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`12ooooo`;o0000b_ooool00ol0003o
ooooooooo`0^ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
04Cooooo0_l00038ooooo`03o`000?oooooooooo02kooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`16ooooo`;o0000aOooool00ol0003oooooooooo`0_ooooo`000oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000007ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol00018ooooo`;o0000`_ooool00ol0003oooooooooo`0`ooooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1:ooooo`;o0000_oooool00ol0003o
ooooooooo`0aooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooo
oooooooooa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0C?ooool00ol0
003oooooooooo`2looooo`03o`000?oooooooooo037ooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1=ooooo`;o0000^oooool00ol0003oooooooooo`0booooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co00001_oo
ool2o`00053ooooo0_l0002hooooo`03o`000?oooooooooo03?ooooo000Vooooo`03o`000?oooooo
oooo057ooooo0_l0002eooooo`03o`000?oooooooooo03Cooooo000Vooooo`03o`000?oooooooooo
05?ooooo0_l0002booooo`03o`000?oooooooooo03Gooooo000Vooooo`03o`000?oooooooooo05Go
oooo0_l0002`ooooo`03o`000?oooooooooo03Gooooo000Vooooo`03o`000?oooooooooo05Oooooo
0_l0002]ooooo`03o`000?oooooooooo03Kooooo000Vooooo`;o0000F_ooool2o`000:[ooooo00?o
0000ooooooooool0=oooool002Kooooo00?o0000ooooooooool0Foooool2o`000:Oooooo00?o0000
ooooooooool0>?ooool002Kooooo00?o0000ooooooooool0GOooool2o`000:Gooooo00?o0000oooo
ooooool0>?ooool002Kooooo00?o0000ooooooooool0Goooool2o`000:;ooooo00?o0000oooooooo
ool0>Oooool002Kooooo00?o0000ooooooooool0HOooool2o`0009oooooo00?o0000ooooooooool0
>_ooool002Kooooo0_l0001Tooooo`03o`000?oooooooooo09[ooooo0_l0000mooooo`009_ooool0
0ol0003oooooooooo`1Tooooo`;o0000VOooool00ol0003oooooooooo`0mooooo`009_ooool00ol0
003oooooooooo`1Vooooo`;o0000U_ooool00ol0003oooooooooo`0nooooo`009_ooool00ol0003o
ooooooooo`1Xooooo`;o0000T_ooool2o`00047ooooo000Vooooo`;o0000Joooool2o`0008oooooo
00?o0000ooooooooool0@Oooool002Kooooo00?o0000ooooooooool0K?ooool2o`0008cooooo00?o
0000ooooooooool0@_ooool002Kooooo00?o0000ooooooooool0K_ooool2o`0008Sooooo0_l00015
ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooooooo`1`ooooo`;o0000QOooool00ol0003oooooooooo`15
ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0L_ooool2o`0008;ooooo00?o0000ooooooooool0A_ooool0
00_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo0ol0001d
ooooo`;o0000O_ooool2o`0004Wooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo07Kooooo0_l0001kooooo`03o`000?oooooo
oooo04Wooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo07Sooooo0_l0001hooooo`03o`000?oooooooooo04[ooooo000;oooo
o`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo07[ooooo0_l0001eooooo`03o`000?oooooooooo04_ooooo000;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07cooooo0_l0001a
ooooo`;o0000C_ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo
000000Oooooo0_l0001oooooo`?o0000KOooool00ol0003oooooooooo`1>ooooo`009_ooool00ol0
003oooooooooo`21ooooo`;o0000J_ooool00ol0003oooooooooo`1?ooooo`009_ooool00ol0003o
ooooooooo`23ooooo`;o0000I_ooool2o`0005;ooooo000Vooooo`03o`000?oooooooooo08Gooooo
0_l0001Sooooo`03o`000?oooooooooo05;ooooo000Vooooo`;o0000R?ooool2o`00063ooooo00?o
0000ooooooooool0Doooool002Kooooo00?o0000ooooooooool0ROooool2o`0005cooooo0_l0001F
ooooo`009_ooool00ol0003oooooooooo`2;ooooo`;o0000FOooool00ol0003oooooooooo`1Foooo
o`009_ooool00ol0003oooooooooo`2=ooooo`?o0000EOooool00ol0003oooooooooo`1Gooooo`00
9_ooool00ol0003oooooooooo`2@ooooo`?o0000Coooool3o`0005[ooooo000Vooooo`;o0000U?oo
ool3o`0004Wooooo0ol0001Mooooo`009_ooool00ol0003oooooooooo`2Fooooo`?o0000@oooool3
o`00063ooooo000Vooooo`03o`000?oooooooooo09Wooooo1?l0000looooo`?o0000Hoooool002Ko
oooo00?o0000ooooooooool0WOooool3o`0003Gooooo1?l0001Vooooo`009_ooool00ol0003ooooo
ooooo`2Pooooo`?o0000;oooool3o`0006[ooooo000Vooooo`;o0000Y?ooool3o`0002Wooooo0ol0
001]ooooo`009_ooool00ol0003oooooooooo`2Vooooo`?o00008oooool3o`00073ooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000001Ol@413ooooooooooooo
ooooA4A400;o000000?o<S8bomgMgOooool01?ooool00ol0003oooooooooo`2Yoooooa7o00003ooo
ool3o`0007?ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;[ooooo3ol0
001fooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`03ooooo`?o0000oooooom0ooooo`000oooool01Ol0003ooooooooooooo
oooo000000kooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo
@?ooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
00?oEEEEofIVI_l000001Oooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo
0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000
ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol00006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooooooo
ool0oooooom0ooooo`002oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h01oooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooom0ooooo`002oooool01Ol0003ooooo
oooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood3o
oooo000;ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000
ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003o
oooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@?ooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00?ooooo0ol0003ooooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooo
oom0ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom0ooooo`000ooo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@?ooool0
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[Zjoooooomg
MgOo<S8b00Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood3ooooo000;
ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000oooo
oom0ooooo`002oooool01Ol0003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01_oo
ool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@
o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo
@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0003o
oooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`06
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol0
003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooooooo
oooo410@00kooooo00?o^[Zjob4Q8Oooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nH
V9SooooookZj^_l000001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT01?ooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003o
ooooooooo`3ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4Co
gMgMooooool00007ooooo`?o0000oooooom0ooooo`002oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOoooooo0000oooooom:ooooo`002oooool01Ol@413ooooooooooooooooo
410@00cooooo00?oMgMgolc<c?l00000oooooom:ooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?ok^k^odA4A?l00000oooooom:ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00gooooo00?oMgMgo`000?ooool0oooooom9ooooo`00oooooomYooooo`00W?ooool2o`0000_o
oooo00?o0000okZj^_ooool03?ooool2o`0000Kooooo00?o0000okZj^_ooool0YOooool009cooooo
00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool01?ooool2oc8b<ZKooooo
002Booooo`05oa0@4?l0003o0000o`000?l@41001Oooool00ol0003oooooooooo`02ooooo`;o0000
0_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00?o
oooo00?o0000ooooooooool01?ooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4
A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08kooooo002Dooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?o
c<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000ooooooooool0
1?ooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool6o`000006
oooooomgMgOoV9RHoooooonHV9SoMgMgS_ooool009Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go410@oooooooooooooooooa0@
402>ooooo`00U?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Cok^k^
ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01?ooool6o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool0S?oo
ool009Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04ob4Q8OmgMgOo
MgMgoc8b<P_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00Go0000ooooooooooooooooo`00002>ooooo`00TOooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo
0_l00008ooooo`03oa0@4?l0003o000000?o00001?ooool00ol0003oooooooooo`09ooooo`03oa0@
4?l0003o000000?o00002_ooool01Ol@413ooooooooooooooooo410@08kooooo002Aooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0S_ooool0097ooooo1ol00004ooooo`;o00004oooool00ol0003o
ooooooooo`04ooooo`;o00003Oooool00ol0003oooooooooo`0;ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h0S_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .11885 m
.11905 .10367 L
.21429 .08034 L
.30952 .10507 L
.40476 .13288 L
.5 .15451 L
.59524 .16069 L
.69048 .14215 L
.78571 .08961 L
.88095 .09039 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooo`00000Boooo
o`04ob4Q8OmgMgOoMgMgoc8b<P[ooooo000Vooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool0=?ooool01?l0003oooooooooool0000Aooooo`;o00000_ooool2o`0000Wooooo000Voooo
o`03o`000?oooooooooo0?oooooo6oooool00ol0003oooooooooo`0Rooooo`009_ooool00ol0003o
ooooooooo`3ooooooa[ooooo00?o0000ooooooooool08oooool002Kooooo0_l0003ooooooa[ooooo
00?o0000ooooooooool09?ooool002Kooooo00?o0000ooooooooool0oooooolHooooo`03o`000?oo
oooooooo02Gooooo000Vooooo`03o`000?oooooooooo0?oooooo5oooool00ol0003oooooooooo`0V
ooooo`009_ooool00ol0003oooooooooo`3ooooooaKooooo00?o0000ooooooooool09oooool002Ko
oooo00?o0000ooooooooool0oooooolEooooo`03o`000?oooooooooo02Sooooo000Vooooo`;o0000
oooooolEooooo`03o`000?oooooooooo02Wooooo000Vooooo`03o`000?oooooooooo0?oooooo4ooo
ool00ol0003oooooooooo`0Zooooo`009_ooool00ol0003oooooooooo`3ooooooa;ooooo00?o0000
ooooooooool0:oooool002Kooooo00?o0000ooooooooool0oooooolAooooo`03o`000?oooooooooo
02cooooo000Vooooo`;o0000oooooolAooooo`03o`000?oooooooooo02gooooo000Vooooo`03o`00
0?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0^ooooo`009_ooool00ol0003ooooooooo
o`3oooooo`kooooo00?o0000ooooooooool0;oooool002Kooooo00?o0000ooooooooool0ooooool=
ooooo`03o`000?oooooooooo033ooooo000Vooooo`03o`000?oooooooooo0?oooooo3?ooool00ol0
003oooooooooo`0aooooo`009_ooool2o`000?oooooo3?ooool00ol0003oooooooooo`0booooo`00
9_ooool00ol0003oooooooooo`3oooooo`[ooooo00?o0000ooooooooool0<oooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo2Oooool00ol0
003oooooooooo`0dooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0?oooooo2?ooool00ol0003oooooooooo`0eooooo`000oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo03Kooooo0003ooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003ooooooooooooooooo000000Oooooo00?oMgMgoc8b<_ooool0
1?ooool3o`000?oooooo1_ooool00ol0003oooooooooo`0gooooo`000oooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`0eooooo`Go0000b_ooool00ol0003oooooooooo`0hoooo
o`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4004
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<Oooool4o`0000Gooooo1?l00035
ooooo`03o`000?oooooooooo03Wooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0]ooooo`Co00003Oooool4o`000:7ooooo4Ol0000>ooooo`03o`000?oooooooooo03[ooooo0003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo
1?l00006ooooo`;o0000:Oooool5o`0001Gooooo1?l0002Kooooo`;o00004Oooool>o`0003gooooo
000Vooooo`03o`000?oooooooooo02Cooooo1?l0000Nooooo`Co0000UOooool2o`0005kooooo000V
ooooo`03o`000?oooooooooo023ooooo1?l0000Vooooo`Co0000T?ooool00ol0003oooooooooo`1N
ooooo`009_ooool00ol0003oooooooooo`0Looooo`Co0000;_ooool4o`0008[ooooo0_l0001Qoooo
o`009_ooool00ol0003oooooooooo`0Fooooo`Ko0000=_ooool4o`0008Cooooo0_l0001Sooooo`00
9_ooool2o`00013ooooo1ol00010ooooo`?o0000Ooooool2o`0006Gooooo000Vooooo`03o`000?oo
oooooooo00Sooooo1ol0001:ooooo`Co0000NOooool2o`0006Oooooo000Vooooo`04o`000?oooooo
ooooooooo`Oo0000EOooool4o`0007Cooooo00?o0000ooooooooool0Ioooool002Kooooo1?l0001P
ooooo`?o0000Koooool2o`0006[ooooo000Vooooo`03o`000?oooooooooo06Cooooo1?l0001Yoooo
o`;o0000K?ooool002Kooooo0_l0001Yooooo`Co0000Hoooool2o`0006kooooo000Vooooo`03o`00
0?oooooooooo06cooooo0ol0001Nooooo`;o0000L?ooool002Kooooo00?o0000ooooooooool0Kooo
ool4o`0005Wooooo00?o0000ooooooooool0L?ooool002Kooooo00?o0000ooooooooool0Loooool4
o`0005?ooooo0_l0001cooooo`009_ooool2o`0007Sooooo1?l0001=ooooo`;o0000MOooool002Ko
oooo00?o0000ooooooooool0Noooool5o`0004Gooooo0ol0001gooooo`009_ooool00ol0003ooooo
ooooo`20ooooo`Co0000??ooool5o`0007[ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo08Cooooo
1?l0000cooooo`Go0000Ooooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Sooooo1?l0000Zooooo`Go0000
Q?ooool000_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo
0ol0002<ooooo`Wo00007?ooool5o`0008Wooooo000;ooooo`05o`000?ooooooooooooooool00000
3_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09Gooooo3ol00008ooooo`Go0000
S_ooool000_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0Y?ooool8o`0009?ooooo000;ooooo`05oa0@4?ooooooooooooooool@4100
3_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooom0ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l00000
1oooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000005oa0@4?oooooooooooooooom4
A4@00_l000000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`06ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooo
oooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`?o
0000oooooom0ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000oooooooo
ool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo
00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go410@oooooooo
oooooooooa0@400>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`3ooooood3ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom0oooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4o`00
00Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo
0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3o
oooood3ooooo000;ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000oooooom0ooooo`002oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMg
ofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool0
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_oo
ool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo
0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000
ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo
0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0003ooooood3o
oooo0003ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol0003ooooo
oooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?ooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?oo
ool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000V
ooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000;
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8b
olc<c006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000oooooooo
ool0oooooom0ooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool0
00003_ooool00onYZJWo410@ooooo`05ooooo`?o0000oooooom0ooooo`002oooool01Ol0003ooooo
oooooooooooo000000gooooo00?o410@o`000?nj^[X01_ooool00ol0003oooooooooo`3ooooood3o
oooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qooooo`05ooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000
ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003o
oooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnH
V9So410@o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01Ol@413o^[ZjoooooomgMgOo<S8b00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`3ooooood3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0003ooooood3ooooo0003ooooo`05o`000?oo
ooooooooooooool000003_ooool00onYZJWo410@ooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol0003ooooooooooooooooo000000gooooo
00?o410@o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0oooooom0ooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q8Ooo
ool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01?ooool4o`0000Kooooo0_l0003o
oooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooo
oom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooo
oooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`3ooooood3ooooo000;oooo
o`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`?o0000oooo
oom0ooooo`002oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo0000
oooooom:ooooo`002oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000
oooooom:ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
oooooom:ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0
oooooom9ooooo`00oooooomYooooo`00UOooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2
o`0000Gooooo00?o0000okZj^_ooool0[Oooool009Gooooo00?o0000ooooooooool02_ooool2oc8b
<Pkooooo00?o0000ooooooooool00oooool2oc8b<Zkooooo002:ooooo`05oa0@4?l0003o0000o`00
0?l@41001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o
^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?ooooo00?o
QhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00Wooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo08;ooooo002<ooooo`03o`00
0?oooooooooo00Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0ooo
ool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ooooo
ooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`00
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`24
ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`00
0?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0Q?oo
ool008cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o
410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00?ooooo1_l00002ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooo
ooooo`24ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co
8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000oooooooo
ool0Q?ooool008Wooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005oooo
o`03o`000?oooooooooo00Wooooo00?o410@o`000?l000000ol0000:ooooo`05oa0@4?oooooooooo
ooooool@41003_ooool00ol0003oooooooooo`24ooooo`00ROooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00kooooo00?o0000ooooooooool0Q?ooool008Wooooo1ol00005ooooo`;o00004_ooool0
0ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003oooooooooo`0;ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000026ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .19314 m
.11905 .23507 L
.21429 .04241 L
.30952 .16855 L
.40476 .11743 L
.5 .11588 L
.59524 .09889 L
.69048 .20806 L
s
.69048 .20806 m
.74753 0 L
s
.82157 0 m
.88095 .23065 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool0
000>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0@ooooo`04ob4Q8OmgMgOoMgMgoc8b<P[ooooo000Vooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02_ooooo0_l0
000Aooooo`;o00000_ooool2o`0000Wooooo000Vooooo`03o`000?oooooooooo0=Oooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01oooooo000Voooo
o`03o`000?oooooooooo0=Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo01oooooo000Vooooo`;o0000f?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool08?ooool002Kooooo00?o0000ooooooooool0
eoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
8?ooool002Kooooo00?o0000ooooooooool0e_ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool08Oooool002Kooooo00?o0000ooooooooool0e_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool08Oooool0
02Kooooo00?o0000ooooooooool0e_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool08_ooool002Kooooo0_l0003Fooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Rooooo`009_ooool00ol0003ooooo
ooooo`3Eooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Rooooo`009_ooool00ol0003oooooooooo`3Eooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0Sooooo`009_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo02?ooooo000Vooooo`;o0000>?ooool00ol0003oooooooooo`2Joooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Toooo
o`009_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo000009_ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02Cooooo000Vooooo`03o`00
0?oooooooooo03Kooooo00Co0000oooooooooooo0000V_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool09?ooool002Kooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo09Oooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Gooooo000Vooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Fooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Uooooo`009_ooool2
o`0003Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Eooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Vooooo`009_ooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0U?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09_ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0Vooooo`000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2Booooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Wooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooo
oooooa0@4008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo02Oooooo0003ooooo`05o`000?ooooooooooooooool0
00002oooool01Ol0003ooooooooooooooooo000000Oooooo00?oMgMgoc8b<_ooool01?ooool3o`00
03;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Xooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0Soooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0:?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?oo
ooooooooooooool@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Yooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo08go
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Wo
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Cooooo1?l00006ooooo`;o0000<Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
08cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
02Wooooo000Vooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`2;ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Zooooo`009_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0HOooool4o`0002Gooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo02[ooooo000Vooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`1Jooooo`Ko00000oooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0[ooooo`009_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0Doooool6o`0000[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:oooool002Kooooo0_l0000^oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0C_ooool5o`00017ooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0:oooool002Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo04Oooooo1_l0000Gooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02cooooo000Vooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0eoooooa7o0000
7_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0/ooooo`009_ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool09?ooool@o`00033ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;Ooo
ool002Kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo02;ooooo0_l00011ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02gooooo000Vooooo`;o0000;?ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo0_l00014ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
02kooooo000Vooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Looooo`;o0000A_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0^ooooo`009_ooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06Oooool2o`0004Wooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0;_ooool002Kooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo01Oooooo0_l0001<ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02oooooo000V
ooooo`;o0000:_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Cooooo0_l0001?
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo02oooooo000Vooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0Aooooo`;o0000D_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0`oooo
o`009_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo033ooooo000;ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0=ooooo`;o
0000Eoooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0`ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00[ooooo0_l0001Jooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo037o
oooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`?o
00009_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Oooooo0_l0001Mooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo037ooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`05ooooo`;o0000Goooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0booooo`002oooool01Ol0003ooooo
oooooooooooo000000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool00_ooool2o`0006;ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0<_ooool000_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Zooooo`04o`000?oooooo0000o`00
06Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0<oooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo06Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<oooool000_ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Oooooo0_l0000Uooooo`03o`000?oooooooooo
09Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0<oooool002Kooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`2Hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo03Cooooo000Vooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0VOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0dooooo`009_ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=Oooool002Kooooo0_l0000S
ooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=Oooool002Kooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Gooooo000Vooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0fooooo`00
9_ooool2o`00027ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0fooooo`009_oo
ool00ol0003oooooo`000002o`0001kooooo00?o0000ooooooooool0XOooool01Ol0003ooooooooo
oooooooo000003Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0gooooo`009_oo
ool2o`0000?ooooo0_l0000Kooooo`03o`000?oooooooooo0:?ooooo00Co0000oooooooooooo0000
=_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Oooooo000Vooooo`03o`000?oo
oooooooo00Cooooo0_l0000Iooooo`03o`000?oooooooooo0:Cooooo0_l0000gooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0=oooool002Kooooo00?o0000ooooooooool01_ooool3
o`0001Gooooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0>?ooool002Kooooo00?o0000ooooooooool02Oooool2o`00
01?ooooo00?o0000ooooooooool0g_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
03Sooooo000Vooooo`03o`000?oooooooooo00_ooooo0ol0000?ooooo`03o`000?oooooooooo0>3o
oooo00Co0000oooooooooooo0000>oooool002Kooooo0_l0000?ooooo`;o00003Oooool00ol0003o
ooooooooo`3Pooooo`04o`000?ooooooooooo`0003_ooooo000Vooooo`03o`000?oooooooooo013o
oooo0ol00009ooooo`03o`000?oooooooooo0>7ooooo00?o0000ooooool00000??ooool000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000005oa0@4?oooooooooooooo
oom4A4@00_l000000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo01?ooooo0_l00007oooo
o`03o`000?oooooooooo0>7ooooo00?o0000ooooool00000??ooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool05Oooool2o`0000Cooooo00?o0000ooooooooool0hoooool2o`00
03cooooo0003ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00?ooooo0ol0000Gooooo`?o000000?oooooo`000?ooool0i?ooool00ol0
003oooooooooo`0kooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0oooooolSooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000oooo
ooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom0
ooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3ooooood3ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool0
0omEEEGoIVIVo`000005ooooo`Co00001_ooool2o`000?oooooo@Oooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2
o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003o
ooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooooooo
o`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP07ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooood3ooooo000;ooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000_ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003o
ooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oo
oooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom0ooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000?o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooo
ooooool00oooool3o`000?oooooo@?ooool000?ooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooo
od3ooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood3ooooo0003oooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo@Oooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`00
9_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0oooooom0ooooo`00
2oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMg
Molb<S801_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?oooooooooooooo
ool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000_o
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Gooooo0ol0003ooooo
od3ooooo000;ooooo`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj^P06oooo
o`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@400>oooo
o`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooo
oooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o
0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1
ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Ooo
ool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooo
od3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0
ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Ooo
ool002Kooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool3o`000?oo
oooo@?ooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Ko
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05o`00
0?ooooooooooooooool000003Oooool00ol@413o0000okZj^P04ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41003_ooool00onj^[[o8B4Qooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRH
V?oooooo^[Zjo`000004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom0
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@04ooooo`Co00001_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0
ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Ooo
ool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooo
od3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo
000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0
ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?oo
ool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooo
oom0ooooo`002oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oM
gMgoooooo`0000Oooooo0ol0003ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool0003ooooood[ooooo000;ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00omgMgOoc<c<o`00003ooooood[ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00oo^k^koA4A4o`00003ooooood[ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03Oooool00omgMgOo0000ooooo`3oooooodWooooo003oooooofWooooo002Eooooo`;o00002ooo
ool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2]ooooo`00UOooool0
0ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b[_ooool0
08[ooooo00Go410@o`000?l0003o0000oa0@4006ooooo`04o`000?ooooooooooooooo`;o00000_oo
ool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo
00?o0000ooooooooool00oooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj
^[X02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000QOooool008co
oooo00?o0000ooooooooool01_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`00
0?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03
o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Oooool01_l@413o^[Zjonk^k_mgMgOo410@
ooooo`Ko00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0QOooool008cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03
oiRHV?lQ8B7ok^k^08Kooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`03ooooo`Ko00000_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0QOooool008cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo08Cooooo0029ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0
003o000000?o00001Oooool00ol0003oooooooooo`09ooooo`03oa0@4?l0003o000000?o00002_oo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0Poooool008Wooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100QOooool008Wo
oooo1ol00005ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003o
ooooooooo`0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<08Gooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24396 m
0 0 rlineto s
.02381 .24396 m
.07696 .61803 L
s
.1355 .61803 m
.16983 0 L
s
.26033 0 m
.29589 .61803 L
s
.33062 .61803 m
.38565 0 L
s
.43802 0 m
.5 .40014 L
s
.5 .40014 m
.5341 0 L
s
.62226 0 m
.64554 .61803 L
s
.71853 .61803 m
.73306 0 L
s
.83949 0 m
.85433 .61803 L
s
.9421 .61803 m
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`;o00003Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02?ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool2
o`0000kooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`04ob4Q8OmgMgOo
MgMgoc8b<P[ooooo000Vooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03oooool2
o`0000;ooooo0_l00009ooooo`009_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0Nooooo`009_ooool2o`0002[ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo000V
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo000Vooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo01kooooo000Vooooo`;o0000:Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool07oooool002Kooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07ooo
ool002Kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool07oooool002Kooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07oooool002Ko
oooo0_l0000Yooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Oooooo`009_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Oooooo`009_ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Oooooo`009_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0Oooooo`009_ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Ooooo
o`009_ooool2o`0002Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo01oooooo000Vooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01oooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Oooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01oooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Oooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000ooooooooooooooooo`000007ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Xooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Oooooo`000ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Oooooo`000oooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4004ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo023ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Cooooo1?l00006ooooo`;o0000:Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool08?ooool002Kooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool08?oo
ool002Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool08?ooool002Kooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool08?ooool002Ko
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool08?ooool002Kooooo0_l0000Xooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Pooooo`009_ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Pooooo`009_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0Pooooo`009_ooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Poooo
o`009_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0Pooooo`009_ooool2o`0002Sooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo023ooooo000Vooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo023ooooo000Vooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo023ooooo000Vooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
023ooooo000Vooooo`;o0000:?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool08?ooool002Kooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool08?ooool002Kooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool08Oooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08Oooool000_ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo027ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003ooooooooo
o`05ooooo`?o00009oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool08Oooool000_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool08Oooool000_ooooo00Go0000ooooooooooooooooo`00
000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08Oooool000_ooooo00Go410@
oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08Ooo
ool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool08Oooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmV
IVKo000000Oooooo0_l0000Wooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0Qooooo`009_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Qooooo`009_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0Qooooo`009_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Qooooo`009_ooool2o`0002Oooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo027ooooo
000Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo027ooooo000Vooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo027ooooo000Voooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo027ooooo000Vooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo027ooooo000Vooooo`;o0000
9oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
8_ooool002Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool08_ooool002Kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08_ooool0
02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool08_ooool002Kooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08_ooool002Kooooo
0_l0000Wooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0Rooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0Rooooo`000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000Go410@ooooooooooooooooodA4A002o`000003oc8b
<_oMgMgooooo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool08_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool08_ooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00oooool3o`0002Gooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo0003ooooo`05o`000?oo
ooooooooooooool000003_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool08_ooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02;o
oooo0003ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool08_ooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Rooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l0
00001Oooool4o`0000Kooooo0_l0000Vooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Rooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Rooooo`009_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Rooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Sooooo`009_ooool2o`00
02Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
02?ooooo000Vooooo`;o00009_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool08oooool002Kooooo0_l0000Vooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Sooooo`009_ooool2o`0002Kooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02?ooooo000V
ooooo`;o00009_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool08oooool002Kooooo0_l0000Vooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0Sooooo`009_ooool2o`0002Kooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02?ooooo000Vooooo`03o`00
0?oooooo000002Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo02?ooooo000Vooooo`03o`000?oooooo000002Cooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02?ooooo000Vooooo`03o`000?oooooo
000002Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo02?ooooo000Vooooo`?o00009?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool08oooool002Kooooo00?o0000ooooool000009?ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08oooool000_ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooool0
00009?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool08oooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooool000009?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool08oooool000_ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00Co0000oooooooooooo00008oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08oooool0
00_ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo1?l0000S
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0S
ooooo`002oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool0
1?l0003oooooooooool0000Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Tooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooool0000Sooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`002oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`04o`000?ooooooooooo`00
02?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
02Cooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Kooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool09?ooool002Kooooo0_l000000ooooooo0000ooooo`0R
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0T
ooooo`009_ooool01Ol0003ooooooooooooooooo000002;ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo000Vooooo`05o`000?oooooooooo
ooooool000008_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool09?ooool002Kooooo00Go0000ooooooooooooooooo`00000Rooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`009_ooool2o`00
00;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool09?ooool002Kooooo00Go0000ooooooooooooooooo`00000Qoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Toooo
o`009_ooool01Ol0003ooooooooooooooooo0000027ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo000Vooooo`05o`000?oooooooooooooo
ool000008Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool09_ooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09?ooool0
02Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Wooooo`04o`000?oooooooooo
o`0002Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool09?ooool002Kooooo0_l00003ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
02Oooooo00Co0000oooooooooooo00009oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`009_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo02Oooooo00Co0000oooooooooooo00009oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Tooooo`009_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
02Oooooo00Co0000oooooooooooo00009oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`009_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo02Oooooo00Co0000oooooooooooo00009oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Tooooo`009_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
02Oooooo00Co0000oooooooooooo00009oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`009_ooool2o`00
00?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooo`00000Wooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
02Gooooo000Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooo`00000Wooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo02Sooooo00?o0000ooooool000009oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Uooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooo`00000Wooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02Gooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09
ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Wooooo0_l0000X
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo02Gooooo0003ooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Yooooo`;o0000:?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`000oooool01Ol0
003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Yooooo`;o0000:?oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Uooooo`000oooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo0003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`0000Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Go
oooo000Vooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0E?ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Uooooo`009_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo05Cooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool09Oooool002Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo02Gooooo000Vooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Uooooo`009_ooool2o`0000Gooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0E?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Uooooo`009_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo05Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool09Oooool002Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Kooooo000Vooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Vooooo`009_ooool2o`00
00Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Vooooo`009_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09_ooool002Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Kooooo
000Vooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0EOooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Vooooo`009_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool09_ooool002Kooooo0_l00007ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool09_ooool002Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo02Kooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0EOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Vooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09_ooool000_ooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1Fooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Kooooo000;ooooo`05o`000?oooooooooo
ooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o00001_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1F
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo02Kooooo000;ooooo`05o`000?ooooooooooooooool000003Oooool0
0ol@413o0000okZj^P06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0E_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Vooooo`002oooool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zj
ob4Q8Oooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05Kooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool09_ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9So
oooookZj^_l000001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05Kooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool09_ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@
413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool09_ooool002Kooooo0_l00008ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05Kooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool09oooool002Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1F
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo02Oooooo000Vooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0E_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Wooooo`009_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo05Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool09oooool002Kooooo0_l00009ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo05Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool09oooool002Kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Oooooo000Vooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Wooooo`009_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool09oooool002Ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Oo
oooo000Vooooo`;o00002Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Oooooo
000Vooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0F?ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Wooooo`009_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05Sooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool09oooool002Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Hoooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo02Oooooo000Vooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0F?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Wooooo`009_ooool2o`0000[ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
F?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Wooooo`009_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo05Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool09oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0FOooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Wooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oa0@4?nj^[[oooooogMgMolb<S801oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Xooooo`000oooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03oooo
o`?o00002_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Sooooo0003ooooo`05
o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`06ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
02Sooooo0003ooooo`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj^P04oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo05Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0:?ooool000?ooooo00Go410@oooooooooooooooooa0@400>
ooooo`03okZj^_lQ8B7ooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:?ooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0FOooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Xooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@04ooooo`Co00001_ooool2o`0000_ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0FOooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Xooooo`009_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Wooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0:?ooool002Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1I
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo02Sooooo000Vooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0F_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Xooooo`009_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo05[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0:?ooool002Kooooo0_l0000<ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo05[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0:?ooool002Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Sooooo000Vooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Xooooo`009_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:?ooool002Ko
oooo0_l0000=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:?ooool002Kooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Sooooo
000Vooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Yooooo`009_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05_ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0:Oooool002Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Koooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo02Wooooo000Vooooo`;o00003Oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Looooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo02Wooooo000Vooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
G?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Yooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo05cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0:Oooool000_ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Yooooo`002oooool01Ol@413ooooooooo
oooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
G?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Yooooo`002oooool01Ol0003ooooooooooooooooo000000_ooooo
00CoA4A4omgMgOoooooo00001oooool3o`0000gooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Yooooo`002oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoo
oooo0000oooooom:ooooo`002oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<
c?l00000oooooom:ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4
A?l00000oooooom:ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`00
0?ooool0oooooom9ooooo`00oooooomYooooo`00UOooool2o`0000_ooooo00?o0000okZj^_ooool0
3?ooool2o`0000Gooooo00?o0000okZj^_ooool0[Oooool009Gooooo00?o0000ooooooooool02_oo
ool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<Zkooooo002:ooooo`05oa0@4?l0003o
0000o`000?l@41001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7
Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?o
oooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00Wooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<08Gooooo002<
ooooo`03o`000?oooooooooo00Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0
003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool0
0ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko410@okZj^_o^k^koMgMgoa0@
4?ooool6o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o
^[ZjoooooomgMgOo<S8b08Gooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`23ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00oooool6o`0000;ooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ojVYZOl@413ooooo08Cooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool00000
3Oooool00ol@413o0000okZj^P25ooooo`00ROooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o
0000o`000003o`0000Gooooo00?o0000ooooooooool02Oooool00ol@413o0000o`000003o`0000[o
oooo00Go410@oooooooooooooooooa0@400>ooooo`03okZj^_lQ8B7ooooo08Cooooo0029ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RHoooooonj^[[o000008Gooooo0029
ooooo`Oo00001Oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0000gooooo00?o0000
ooooooooool02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@25ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .28092 m
0 0 rlineto s
.02381 .28092 m
.02814 .61803 L
s
.15531 .61803 m
.15848 0 L
s
.26288 0 m
.26563 .61803 L
s
.35966 .61803 m
.36281 0 L
s
.44821 0 m
.45147 .61803 L
s
.53395 .61803 m
.53623 0 L
s
.63317 0 m
.63464 .61803 L
s
.73479 .61803 m
.73595 0 L
s
.84261 0 m
.84394 .61803 L
s
.97289 .61803 m
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooo000000kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooool000002oooool00ol0003oooooooooo`0;oooo
o`;o00003Oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000003Oooool0
0ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo0000
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
4?ooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`009_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00oooooo0_l00002ooooo`;o00002Oooool002Kooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_oo
ool002Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool07_ooool002Kooooo0_l0000Wooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Nooooo`009_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`009_ooool2o`0002Oooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo000Vooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo01kooooo000Vooooo`;o00009oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool002Ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool002Kooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool07_ooool002Kooooo0_l0000Wooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Noooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_oo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`000ooo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4008ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool000?ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05o`000?ooooooooooooooool000001oooool00omgMgOo<S8booooo`04oooo
o`?o00009_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool07_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oooooooooo
ooooool000001?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_oo
ool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@4100
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo0003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Nooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co00001_ooool2o`0002Oooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo000Vooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo01kooooo000Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo000Vooooo`;o00009oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool002Ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool002Kooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool002Kooooo0_l0000Woooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Noooo
o`009_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`009_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Nooooo`009_ooool2o`0002Oooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
01kooooo000Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo01kooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01ko
oooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Nooooo`002oooool01Ol@413ooooooooooooooooo410@00ko
oooo00?o0000ooooooooool01Oooool3o`0002Kooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo01kooooo000;ooooo`05o`000?ooooooooooooooool0
00003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo000;ooooo`05o`00
0?ooooooooooooooool000003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01ko
oooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo01kooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo01kooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool00omEEEGoIVIVo`000007ooooo`;o00009oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
7_ooool002Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool0
02Kooooo0_l0000Wooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0N
ooooo`009_ooool2o`0002Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo01kooooo000Vooooo`;o00009oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000005oa0@4?oooooooooooooo
oom4A4@00_l000000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo0003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41003_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0ol0000Voooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Noooo
o`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo0003ooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Nooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo0003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool07_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`03oeEEEOmVIVKo000000Gooooo1?l00006ooooo`;o00009oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool07_ooool002Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
7_ooool002Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool07_ooool002Kooooo0_l0000Wooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`009_ooool2o`0002Oooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo000Voooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01kooooo000Vooooo`;o00009oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool0
00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool07_ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool000_ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_oo
ool000_ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0
000Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Nooooo`002oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Oooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`002oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo
000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool07oooool002Kooooo0_l0000Vooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`009_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Oooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`009_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Ooooo
o`009_ooool2o`0002Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo01oooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo000Vooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo01oooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo000Vooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
01oooooo000Vooooo`;o00009_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool07oooool002Kooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool002Kooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool07oooool002Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool002Kooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool07oooool002Kooooo0_l0000Vooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0Oooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Oooooo`000oooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o00009Oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool000?o
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Oooooo`000oooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool07oooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool07oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0000Vooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`009_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Oooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`009_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0Oooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`009_ooool2o`0002Kooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo
000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo01oooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo000Voooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo01oooooo000Vooooo`;o00009_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool002Kooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
7oooool002Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool07oooool002Kooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool0
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool07oooool002Kooooo0_l0000Vooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`009_ooool2o`0002Kooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo
000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o
<S8bolc<c006ooooo`;o00009_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool07oooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo0_l0000Vooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`002oooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool2o`0002Kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo000;ooooo`05
o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o00009Oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool000_o
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oa0@4?l0003o^[Zj00Kooooo0_l0000Voooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Ooooo
o`002oooool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q8Oooool01Oooool2o`00
02Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
01oooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RHoooooonj^[[o
000000Kooooo0_l0000Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0Oooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@06ooooo`;o00009_ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool07oooool002Kooooo0_l0000Vooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`009_ooool2o`00
02Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
01oooooo000Vooooo`;o00009_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool07oooool002Kooooo0_l0000Vooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`009_ooool2o`0002Kooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo000V
ooooo`;o00009_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool07oooool002Kooooo0_l0000Vooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Oooooo`009_ooool2o`0002Kooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo000Vooooo`;o0000
9_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
7oooool002Kooooo0_l0000Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Oooooo`009_ooool2o`0002Kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo000Vooooo`;o00009_ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool002Ko
oooo0_l0000Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0Oooooo`009_ooool2o`0002Kooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo01oooooo000Vooooo`;o00009_ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool002Kooooo0_l0000V
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0O
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o
0000oc8b<_o<c<`01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l0000Vooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb
<S801oooool00omgMgOo<S8booooo`04ooooo`;o00009_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool000?ooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool3o`0002Go
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oo
oooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`06ooooo`03
ogMgMolb<S;ooooo00Cooooo0_l0000Vooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0Oooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?o410@o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo0_l0000Voooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Ooooo
o`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q8Oooool00oooool00ol0
003oooooooooo`07ooooo`;o00009_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool07oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05oa0@4?nHV9SooooookZj^_l000001?ooool00ol0003oooooooooo`07ooooo`;o00009_ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01?oo
ool4o`0000Kooooo0_l0000Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Oooooo`009_ooool2o`0002Kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo000Vooooo`;o00009_ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool002Ko
oooo0_l0000Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0Oooooo`009_ooool2o`0002Kooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo01oooooo000Vooooo`;o00009_ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool002Kooooo0_l0000V
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0O
ooooo`009_ooool2o`0002Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo01oooooo000Vooooo`;o00009_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool002Kooooo0_l0000Vooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`009_oo
ool2o`0002Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo01oooooo000Vooooo`;o00009_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool07oooool002Kooooo0_l0000Vooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`009_ooool2o`0002Ko
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oo
oooo000Vooooo`;o00009_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool07oooool002Kooooo0_l0000Vooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`002oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool2o`0002Kooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo000;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Ooo
ool2o`0002Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo01oooooo000;ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0_l0
000Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Oooooo`002oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
1oooool3o`0002Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo01oooooo000;ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEE
ooooool0003ooooood[ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOo
c<c<o`00003ooooood[ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`00003ooooood[ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo
0000ooooo`3oooooodWooooo003oooooofWooooo002Eooooo`;o00002oooool00ol0003o^[Zjoooo
o`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2]ooooo`00UOooool00ol0003oooooooooo`0:
ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b[_ooool008[ooooo00Go410@o`00
0?l0003o0000oa0@4006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?o
QhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool0
0oooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0Poooool008co
oooo00?o0000ooooooooool01_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`00
0?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03
o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Oooool01_l@413o^[Zjonk^k_mgMgOo410@
ooooo`Ko00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oo
oooooooo08Cooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool0
1?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0008Gooooo
002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@
4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`03ooooo`Ko00000_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoo
oooo0000Q_ooool008cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04
ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0008Kooooo0029ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o0000
1Oooool00ol0003oooooooooo`09ooooo`03oa0@4?l0003o000000?o00002_ooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oMgMgolc<c?l00000Q_ooool008Wooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000008Kooooo0029ooooo`Oo00001Oooool2o`0001;o
oooo00?o0000ooooooooool01Oooool2o`0000gooooo00?o0000ooooooooool02oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0QOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
0 0 rlineto s
.02381 .30902 m
.02415 .61803 L
s
.15528 .61803 m
.15554 0 L
s
.25928 0 m
.25948 .61803 L
s
.35591 .61803 m
.3561 0 L
s
.4477 0 m
.44786 .61803 L
s
.54035 .61803 m
.54047 0 L
s
.63773 0 m
.63783 .61803 L
s
.73856 .61803 m
.73865 0 L
s
.8441 0 m
.84421 .61803 L
s
.9759 .61803 m
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08oooo
o`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool02_ooool2o`0000gooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooool000003Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo000000gooooo00?o0000
ooooooooool02_ooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00_ooooo0_l0000=
ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`04ob4Q8Omg
MgOoMgMgoc8b<P[ooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03ooo
ool2o`0000;ooooo0_l00009ooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Nooooo`009_ooool2o`0002Kooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo
000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Voooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01kooooo000Vooooo`;o00009_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7_ooool002Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool0
02Kooooo0_l0000Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0N
ooooo`009_ooool2o`0002Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Nooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000ooooooooooooooooo`000007ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Uooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`00
0oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`000oooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4004ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01kooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Cooooo1?l00006ooooo`;o00009_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7_ooool002Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool0
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07_ooool002Kooooo0_l0000Vooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0N
ooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool2o`0002Kooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01kooooo000Vooooo`;o00009_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07_ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool000_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01kooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003ooooo
ooooo`05ooooo`?o00009Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07_ooool000_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07_ooool000_ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool000_ooooo00Go
410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7_ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07_ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEE
EOmVIVKo000000Oooooo0_l0000Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool2o`0002Ko
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01ko
oooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000V
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`;o
00009_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07_ooool002Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_oo
ool002Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Ko
oooo0_l0000Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000Go410@ooooooooooooooooodA4A002o`000003
oc8b<_oMgMgooooo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07_ooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool3o`0002Gooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07_ooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01kooooo0003ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Nooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIV
I_l000001Oooool4o`0000Kooooo0_l0000Vooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`00
9_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Nooooo`009_ooool2o`0002Kooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01ko
oooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000V
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01kooooo000Vooooo`;o00009_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07_ooool002Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_oo
ool002Kooooo0_l0000Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`002oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Noooo
o`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`002oooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`002oooool01Ol0
003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0002Gooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000;oooo
o`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01kooooo000;ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01kooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool000_ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Nooooo`009_ooool2o`0002Kooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Voooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`;o0000
9_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7_ooool002Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool0
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo
0_l0000Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0N
ooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`00
9_ooool2o`0002Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Nooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01kooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0000Uooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`000oooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01kooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Noooo
o`000oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Nooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`0002Kooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01ko
oooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`;o00009_ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07_ooool002Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07_ooool002Kooooo0_l0000Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Nooooo`009_ooool2o`0002Kooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000;
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8b
olc<c006ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01kooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01ko
oooo000;ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01kooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo
410@ooooo`05ooooo`?o00009Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07_ooool000_ooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oa0@4?l0003o^[Zj00Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool000_ooooo00Go410@oooooooooooo
oooooa0@400>ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool000_ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Nooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`;o00009_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Ko
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07_ooool002Kooooo0_l0000Vooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Noooo
o`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Nooooo`009_ooool2o`0002Kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01kooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo
000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`;o00009_ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnH
V9So410@o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
410@okZj^_ooooooMgMgoc8b<P07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7_ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00oooool3o`0002Gooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01kooooo0003ooooo`05o`000?ooooooooooooooool00000
3_ooool00onYZJWo410@ooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7_ooool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oa0@4?l0003o^[Zj00Cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo0003ooooo`05oa0@
4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qooooo`03ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
oa0@4?nHV9SooooookZj^_l000001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01kooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413o
ZJVY00Cooooo1?l00006ooooo`;o00009_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Ko
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07_ooool002Kooooo0_l0000Vooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Noooo
o`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_oo
ool2o`0002Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01kooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo
000Vooooo`;o00009_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool000_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07_ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000;ooooo`05oa0@4?oooooooooo
ooooool@41002oooool5o`0000Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool000_ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000Uooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`002oooool0
1Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo0000oooooom:ooooo`002ooo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000oooooom:ooooo`002ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000oooooom:ooooo`002ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0oooooom9ooooo`00oooo
oomYooooo`00UOooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000
okZj^_ooool0[Oooool009Gooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000oooo
ooooool00oooool2oc8b<Zkooooo002:ooooo`05oa0@4?l0003o0000o`000?l@41001_ooool01?l0
003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RH
o`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X01Ooo
ool01OnHV9So0000o`000?m4A4Co^[Zj00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM08Cooooo002<ooooo`03o`000?oooooooooo00Ko
oooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000
oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`03ooooo`03
olc<c?l0003o410@00Gooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`23ooooo`00S?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0P_ooool008cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo
1_l00002ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`23ooooo`00
S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo
<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c024
ooooo`00ROooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o
0000ooooooooool02Oooool00ol@413o0000o`000003o`0000[ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo08Kooooo0029ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooooooo`26ooooo`00ROooool7o`0000Gooooo0_l0000Booooo`03o`00
0?oooooooooo00Gooooo0_l0000=ooooo`03o`000?oooooooooo00_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co0000QOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}]
}, Closed]]
}, Open  ]],

Cell["\<\
\tThe result shows that the solution immediately blows up. What \
happened? \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Von Neumann Stability Analysis", "Section",
  CellTags->{"i:19", "c:16"}],

Cell[TextData[{
  "The problem encountered in the previous example is one of numerical \
instability caused by an overly large step size ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ". ",
  StyleBox[ButtonBox["Von Neumann",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Von_Neumann.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[" stability analysis",
    FontSlant->"Italic"],
  " provides us with the tools we need to understand and overcome this \
problem. The analysis relies on the idea that certain short-wavelength \
spatial modes in the numerical solution can be unstable. In the stability \
analysis for these modes, it suffices to neglect boundary conditions and \
source terms, if any, and  solve the recursion relation analytically, using \
Fourier modes. That is, keeping only one mode, we write ",
  Cell[BoxData[
      \(TraditionalForm\`T\_j\%n = \(a\_n\) \[ExponentialE]\^\(\[ImaginaryI]\ \
k\ \ x\_j\)\)]],
  ",where ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " is the wavenumber of the mode. Applying this ansatz to the FTCS method ",
  ButtonBox["(6.2.5)",
    ButtonData:>"(6.2.5)",
    ButtonStyle->"Hyperlink"],
  ",  and neglecting the source term, we find that we can divide out a factor \
of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ k\ \ x\_j\)\)]],
  "from both sides, leaving us with the following difference equation for ",
  Cell[BoxData[
      \(TraditionalForm\`a\_n\)]],
  ":"
}], "Text",
  CellTags->"i:58"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(a\_\(n + 1\)\), "=", 
          RowBox[{\(a\_n\), "+", 
            RowBox[{
              FractionBox[
                RowBox[{"\[Chi]", " ", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]]}], 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], "2"]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                      RowBox[{"\[ImaginaryI]", " ", "k", "  ", 
                        StyleBox[
                          RowBox[{"\[CapitalDelta]", 
                            StyleBox["x",
                              FontSlant->"Italic"]}]]}]], \(a\_n\)}], 
                  "-", \(2  a\_n\), "+", 
                  RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                      RowBox[{\(-\[ImaginaryI]\), " ", "k", "  ", 
                        StyleBox[
                          RowBox[{"\[CapitalDelta]", 
                            StyleBox["x",
                              FontSlant->"Italic"]}]]}]], \(a\_n\)}]}], 
                ")"}]}]}]}], TraditionalForm]]],
  "."
}], "UNNEQ"],

Cell["\<\
Using a trigonometric identity, this equation can be rewritten as\
\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(a\_\(n + 1\)\), "=", 
          RowBox[{\(a\_n\), "[", 
            RowBox[{"1", "-", 
              RowBox[{"4", 
                FractionBox[
                  RowBox[{"\[Chi]", " ", 
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["t",
                          FontSlant->"Italic"]}]]}], 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["x",
                          FontSlant->"Italic"]}]], "2"]], 
                RowBox[{\(sin\^2\), "(", 
                  RowBox[{"k", " ", 
                    RowBox[{
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]], "/", "2"}]}], ")"}]}]}], 
            "]"}]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.6)"],

Cell["\<\
Linear homogeneous difference equations of this sort have a general \
solution of the form \
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`a\_n = A\ \[Xi]\^n\)]],
  ", "
}], "NE2",
  CellTags->"(6.2.7)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(A\)\(\ \)\)\)]],
  " is an undetermined constant, dependent on the initial condition. The \
parameter ",
  Cell[BoxData[
      \(TraditionalForm\`\[Xi]\)]],
  " is called the amplification factor, since it is the factor by which the \
solution is amplified in a single ",
  "time step",
  ". This parameter can be determined by substitution of Eq. ",
  ButtonBox["(6.2.7)",
    ButtonData:>"(6.2.7)",
    ButtonStyle->"Hyperlink"],
  " into Eq. ",
  ButtonBox["(6.2.6)",
    ButtonData:>"(6.2.6)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{"\[Xi]", "=", 
        RowBox[{"1", "-", 
          RowBox[{"4", 
            FractionBox[
              RowBox[{"\[Chi]", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]]}], 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"]], 
            RowBox[{\(sin\^2\), "(", 
              RowBox[{"k", " ", 
                RowBox[{
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], "/", "2"}]}], ")"}]}]}]}], 
      TraditionalForm]]]], "NE2",
  CellTags->"(6.2.8)"],

Cell[TextData[{
  "The amplification factor  depends on the step size in both time and space, \
and on the wavenumber ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " of the mode in question. The important issue facing us is that, for \
certain choices of these parameters, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(\[Xi]\)\(|\)\)\)]],
  " can be larger that unity. If this is so, the solution is unstable, \
because as the time step ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " increases, the solution blows up like ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Xi]\^n\) \[ExponentialE]\^\(\[ImaginaryI]\ \
k\ \ x\_j\)\)]],
  ". However, if ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\(|\)\(\[Xi]\)\(|\)\),
            "TraditionalForm"], "<", "1"}], TraditionalForm]]],
  " for all values of ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ", then each mode will decay in time rather than grow, and the solution \
will be well behaved. (The decay of these modes does not necessarily imply \
that the solution to the heat equation goes to zero, because boundary \
conditions and source terms neglected here can keep the solution finite. \
Rather, it implies that any short-wavelength noise in the solution will decay \
away. This is just what we want to happen in order to obtain a smooth \
solution.)"
}], "Text"],

Cell[TextData[{
  "\tThese considerations lead us to the condition that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(\[Xi]\)\(|\)\(\(\[LessEqual]\)\(\ \)\(1\)\)\
\)\)]],
  " for all wavenumbers ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "  in order for our numerical solution to be stable. In Fig. ",
  ButtonBox["6.6",
    ButtonData:>"Fig. 6.6",
    ButtonStyle->"Hyperlink"],
  ", we graph Eq. ",
  ButtonBox["(6.2.8)",
    ButtonData:>"(6.2.8)",
    ButtonStyle->"Hyperlink"],
  "  vs. ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " for several values of the parameter ",
  Cell[BoxData[
      FormBox[
        FractionBox[
          RowBox[{"\[Chi]", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}], 
          SuperscriptBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], "2"]], TraditionalForm]]],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.456168 0.147151 [
[.17539 .44367 -3 -9 ]
[.17539 .44367 3 0 ]
[.32696 .44367 -3 -9 ]
[.32696 .44367 3 0 ]
[.47854 .44367 -3 -9 ]
[.47854 .44367 3 0 ]
[.63011 .44367 -3 -9 ]
[.63011 .44367 3 0 ]
[.78169 .44367 -3 -9 ]
[.78169 .44367 3 0 ]
[.93327 .44367 -3 -9 ]
[.93327 .44367 3 0 ]
[1.025 .45617 0 -6 ]
[1.025 .45617 28 6 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -12 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .45617 m
.17539 .46242 L
s
[(1)] .17539 .44367 0 1 Mshowa
.32696 .45617 m
.32696 .46242 L
s
[(2)] .32696 .44367 0 1 Mshowa
.47854 .45617 m
.47854 .46242 L
s
[(3)] .47854 .44367 0 1 Mshowa
.63011 .45617 m
.63011 .46242 L
s
[(4)] .63011 .44367 0 1 Mshowa
.78169 .45617 m
.78169 .46242 L
s
[(5)] .78169 .44367 0 1 Mshowa
.93327 .45617 m
.93327 .46242 L
s
[(6)] .93327 .44367 0 1 Mshowa
.125 Mabswid
.05412 .45617 m
.05412 .45992 L
s
.08444 .45617 m
.08444 .45992 L
s
.11476 .45617 m
.11476 .45992 L
s
.14507 .45617 m
.14507 .45992 L
s
.2057 .45617 m
.2057 .45992 L
s
.23602 .45617 m
.23602 .45992 L
s
.26633 .45617 m
.26633 .45992 L
s
.29665 .45617 m
.29665 .45992 L
s
.35728 .45617 m
.35728 .45992 L
s
.38759 .45617 m
.38759 .45992 L
s
.41791 .45617 m
.41791 .45992 L
s
.44822 .45617 m
.44822 .45992 L
s
.50885 .45617 m
.50885 .45992 L
s
.53917 .45617 m
.53917 .45992 L
s
.56948 .45617 m
.56948 .45992 L
s
.5998 .45617 m
.5998 .45992 L
s
.66043 .45617 m
.66043 .45992 L
s
.69074 .45617 m
.69074 .45992 L
s
.72106 .45617 m
.72106 .45992 L
s
.75138 .45617 m
.75138 .45992 L
s
.81201 .45617 m
.81201 .45992 L
s
.84232 .45617 m
.84232 .45992 L
s
.87264 .45617 m
.87264 .45992 L
s
.90295 .45617 m
.90295 .45992 L
s
.96358 .45617 m
.96358 .45992 L
s
.9939 .45617 m
.9939 .45992 L
s
.25 Mabswid
0 .45617 m
1 .45617 L
s
gsave
1.025 .45617 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01471 m
.03006 .01471 L
s
[(-3)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-2)] .01131 .16186 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-1)] .01131 .30902 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03465 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01923 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01564 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38343 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .60332 m
.02499 .60331 L
.02605 .6033 L
.02729 .60328 L
.02846 .60325 L
.03053 .60317 L
.03279 .60306 L
.03527 .6029 L
.0379 .60268 L
.04262 .60219 L
.04749 .60153 L
.05205 .60077 L
.06244 .59856 L
.07305 .59562 L
.08274 .59234 L
.10458 .58292 L
.14429 .55923 L
.18248 .52979 L
.22313 .4934 L
.26226 .45583 L
.30384 .41598 L
.34391 .38039 L
.38246 .35109 L
.402 .33871 L
.42346 .32738 L
.44388 .31899 L
.45301 .31603 L
.46295 .31339 L
.46838 .31221 L
.4734 .31128 L
.4781 .31055 L
.4833 .30991 L
.48553 .30969 L
.48794 .30948 L
.49002 .30934 L
.4923 .30921 L
.49473 .30911 L
.49605 .30907 L
.49728 .30904 L
.49844 .30902 L
.49949 .30902 L
.50071 .30902 L
.50186 .30903 L
.50301 .30905 L
.50425 .30907 L
.50542 .30911 L
.50648 .30915 L
.5091 .30928 L
.51158 .30945 L
.5165 .30989 L
Mistroke
.52187 .31055 L
.53144 .31217 L
.54032 .31419 L
.56088 .32073 L
.5795 .3288 L
.61962 .35251 L
.65822 .38217 L
.69928 .4189 L
.73882 .45687 L
.77684 .49338 L
.81732 .52963 L
.85628 .55963 L
.87613 .5724 L
.89769 .58402 L
.91843 .59276 L
.92832 .59604 L
.93759 .59857 L
.94643 .60049 L
.95595 .60201 L
.9611 .60259 L
.96369 .60282 L
.96652 .60302 L
.96894 .60315 L
.9703 .60321 L
.97153 .60325 L
.97268 .60328 L
.97393 .6033 L
.97511 .60332 L
.97619 .60332 L
Mfstroke
.02381 .60332 m
.02499 .60332 L
.02605 .60331 L
.02729 .6033 L
.02846 .60328 L
.03053 .60325 L
.03279 .60319 L
.03527 .60311 L
.0379 .603 L
.04262 .60275 L
.04749 .60242 L
.05205 .60205 L
.06244 .60094 L
.07305 .59947 L
.08274 .59783 L
.10458 .59312 L
.14429 .58128 L
.18248 .56656 L
.22313 .54836 L
.26226 .52957 L
.30384 .50965 L
.34391 .49185 L
.38246 .4772 L
.402 .47102 L
.42346 .46535 L
.44388 .46115 L
.45301 .45967 L
.46295 .45835 L
.46838 .45776 L
.4734 .4573 L
.4781 .45693 L
.4833 .45661 L
.48553 .4565 L
.48794 .4564 L
.49002 .45633 L
.4923 .45626 L
.49473 .45621 L
.49605 .45619 L
.49728 .45618 L
.49844 .45617 L
.49949 .45617 L
.50071 .45617 L
.50186 .45617 L
.50301 .45618 L
.50425 .4562 L
.50542 .45621 L
.50648 .45623 L
.5091 .4563 L
.51158 .45638 L
.5165 .4566 L
Mistroke
.52187 .45693 L
.53144 .45774 L
.54032 .45876 L
.56088 .46202 L
.5795 .46606 L
.61962 .47791 L
.65822 .49274 L
.69928 .51111 L
.73882 .5301 L
.77684 .54835 L
.81732 .56647 L
.85628 .58147 L
.87613 .58786 L
.89769 .59367 L
.91843 .59804 L
.92832 .59968 L
.93759 .60095 L
.94643 .60191 L
.95595 .60266 L
.9611 .60295 L
.96369 .60307 L
.96652 .60317 L
.96894 .60323 L
.9703 .60326 L
.97153 .60328 L
.97268 .6033 L
.97393 .60331 L
.97511 .60332 L
.97619 .60332 L
Mfstroke
gsave
.47854 .52974 -85.5938 -14.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 29.5 translate 1 -1 scale
63.000 17.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.250 11.500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
74.875 11.500 moveto
(D) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.750 17.438 moveto
(\\200\\200\\200\\200\\200\\200\\200\\200) show
81.750 17.438 moveto
(\\200\\200) show
85.875 17.438 moveto
(\\200) show
67.875 24.500 moveto
(D) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
79.875 21.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
90.000 17.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
99.062 11.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
97.750 17.438 moveto
(\\200\\200) show
102.000 17.438 moveto
(\\200) show
104.062 17.438 moveto
(\\200) show
99.062 23.688 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
108.188 17.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47854 .23544 -85.5938 -14.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 29.5 translate 1 -1 scale
63.000 17.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.250 11.500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
74.875 11.500 moveto
(D) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.750 17.438 moveto
(\\200\\200\\200\\200\\200\\200\\200\\200) show
81.750 17.438 moveto
(\\200\\200) show
85.875 17.438 moveto
(\\200) show
67.875 24.500 moveto
(D) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
79.875 21.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
90.000 17.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
99.062 11.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
97.750 17.438 moveto
(\\200\\200) show
102.000 17.438 moveto
(\\200) show
104.062 17.438 moveto
(\\200) show
99.062 23.688 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
108.188 17.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.7059 .08829 -82.5 -14.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 28.9375 translate 1 -1 scale
63.000 16.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.250 10.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
74.875 10.938 moveto
(D) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.750 16.875 moveto
(\\200\\200\\200\\200\\200\\200\\200\\200) show
81.750 16.875 moveto
(\\200\\200) show
85.875 16.875 moveto
(\\200) show
67.875 23.938 moveto
(D) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
79.875 20.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
90.000 16.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
96.000 16.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
102.000 16.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`004_ooool00ol0003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?oo
ooooE?ooool000Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oo
ooooE?ooool000Sooooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`03o`000?oooooooooo0?oo
ooooE?ooool000Ko00001_ooool00ol0003oooooooooo`03ooooo`?o0000SOooool4o`000<;ooooo
000;ooooo`03ojVYZOl@413ooooo00Cooooo00?o0000ooooooooool0Qoooool6o`0000Cooooo1ol0
002kooooo`002_ooool00ol@413o0000okZj^P05ooooo`03o`000?oooooooooo08Cooooo0ol0000A
ooooo`;o0000^Oooool000_ooooo00?o^[Zjob4Q8Oooool01?ooool00ol0003oooooooooo`22oooo
o`;o00005_ooool00ol0003oooooooooo`2fooooo`002?ooool01Ol@413oV9RHoooooonj^[[o0000
00Gooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`0Gooooo`;o0000]_ooool000So
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@05ooooo`03o`000?oooooooooo07oooooo0_l0000Loooo
o`03o`000?oooooooooo0;?ooooo000Booooo`03o`000?oooooooooo07gooooo0_l0000Oooooo`;o
0000/oooool001;ooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo0;3ooooo000Booooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool08ooo
ool2o`000;3ooooo000Booooo`;o0000Noooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo0:gooooo000Booooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0:?ooool2o`00
0:gooooo000Booooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`2Zooooo`004_ooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool04Oooool00olb<S;o0000o`000003o`000003oc8b<_oooooooooo00;o0000
0_ooool2o`0008Wooooo000Booooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0Aooooo`03oiRHV?m4A4Cooooo00;ooooo00[oA4A4oiRHV?oooooooooo
onk^k_lQ8B7oQhN7okZj^_l0003ogMgMROooool001;ooooo00?o0000ooooooooool0MOooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo017ooooo00Go410@omgMgOoooooogMgMoa0@4004
ooooo`04omgMgOl0003o410@olc<c8[ooooo000Booooo`03o`000?oooooooooo07Cooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`0@ooooo`05ohN7QomgMgOoooooofIVI_n7QhL01?oo
ool01?o^k^ko8B4Qoa0@4?o^k^j:ooooo`004_ooool00ol0003oooooooooo`1cooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool03oooool01Oo^k^ko410@onk^k_l@413ok^k^00Cooooo
00Go8B4QogMgMomgMgOo<S8booooo`04o`0008Gooooo000Booooo`03o`000?oooooooooo07;ooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0?ooooo`03ogMgMolQ8B7oEEEE00Cooooo
0_l00002ooooo`;o000000?oooooo`000?ooool0Q_ooool001;ooooo0_l0001booooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool03oooool00ooMgMgo0000omgMg@0<ooooo`03o`000?oo
oooooooo08Cooooo000Booooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`0?ooooo`03ojVYZOoooooooooo00cooooo00?o0000ooooooooool0Poooool0
01;ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
01[ooooo00Co0000oooooooooooo0000QOooool001;ooooo00?o0000ooooooooool0Koooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo01[ooooo0_l0000Cooooo`Co000000?o410@oooo
ooooool0K?ooool001;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo02Kooooo1_l00004ooooo`03o`000?oooooooooo06kooooo000Booooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`05oooooago0000
3_ooool00ol0003oooooooooo`1^ooooo`004_ooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool09Oooool6o`0000Cooooo00?o0000ooooooooool0K_oo
ool001;ooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool0K_ooool001;ooooo00?o0000ooooooooool0Joooool00ol0
003oooooooooo`14ooooo`03o`000?oooooooooo00Cooooo00GoEEEEoiRHV?ooooooooooolc<c002
o`000003oiRHV?oooooooooo01oooooo00?o0000ooooooooool0K_ooool001;ooooo0_l0001/oooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool01?ooool01OmEEEGoV9RHoooooomEEEGo
QhN702?ooooo00?o0000ooooooooool0K_ooool001;ooooo00?o0000ooooooooool0J_ooool00ol0
003oooooooooo`16ooooo`03o`000?oooooooooo00Cooooo00Gok^k^oc8b<_o<c<co8B4Qolc<c005
ooooo`03oc8b<_l0003o000000?o000000Go<S8boooooooooooooooooiRHV002o`000003odA4A?nj
^[[ooooo00cooooo00?oEEEEofIVI_l00000L?ooool001;ooooo00?o0000ooooooooool0JOooool0
0ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Cooooo00?ok^k^oc8b<_l000001_ooool0
0onHV9SoA4A4ooooo`02ooooo`03odA4A?nHV9Sooooo00;ooooo00Go410@okZj^_o^k^koMgMgoa0@
4020ooooo`004_ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo04Wooooo00?o0000
ooooooooool01?ooool00onYZJWo410@onk^kP06ooooo`05oa0@4?oMgMgoooooomgMgOl@41001?oo
ool00ol0003oooooooooo`22ooooo`004_ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooo
oooo04[ooooo00?o0000ooooooooool01?ooool01?mgMgOoA4A4oc8b<_o^k^h5ooooo`05ohN7Qomg
MgOoooooofIVI_n7QhL01?ooool00ol0003oooooooooo`22ooooo`004_ooool00ol0003ooooooooo
o`1Wooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool00oooool01?lb<S;oZJVYoiRH
V?mEEED5ooooo`05onk^k_l@413ok^k^oa0@4?o^k^h01?ooool00ol0003oooooooooo`22ooooo`00
4_ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo04gooooo00[o0000oooooooooooo
<S8bo`000?lQ8B7ok^k^oooooonHV9SoEEEE1Oooool00omgMgOo8B4QoeEEE@03ooooo`03oa0@4?l0
003o000000?o0000POooool001;ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo00cooooo00?ogMgMo`000?oMgMd01Oooool00ol0003oooooooooo`22
ooooo`004_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo053ooooo00?o0000oooo
ooooool03?ooool00onYZJWoooooooooo`04ooooo`03o`000?oooooooooo08;ooooo000Booooo`;o
0000I_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo09Oooooo000Booooo`03o`00
0?oooooooooo06Cooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`2Gooooo`004_oo
ool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0U_oo
ool001;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`1Eooooo`03o`000?oooooo
oooo09Gooooo000Booooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0E_ooool00ol0
003oooooooooo`2Eooooo`004_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo05So
oooo00?o0000ooooooooool0U?ooool001;ooooo00?o0000ooooooooool0HOooool00ol0003ooooo
ooooo`1Iooooo`03o`000?oooooooooo09?ooooo0008ooooo`Go00001Oooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0Toooool000Sooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0G?oo
ool00ol0003oooooooooo`2Booooo`001_l00003ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001O
ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0TOooool000[ooooo00?oV9RHob4Q
8Oo^k^h01Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo05kooooo00?o0000oooo
ooooool0TOooool000_ooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`1Nooooo`03
o`000?oooooooooo05oooooo00?o0000ooooooooool0T?ooool000cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
T?ooool000Sooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo05gooooo
00?o0000ooooooooool0HOooool00ol0003oooooooooo`2?ooooo`002?ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`1Rooooo`03o`00
0?oooooooooo08oooooo000Booooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0I?oo
ool00ol0003oooooooooo`2>ooooo`004_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool0SOooool001;ooooo00?o0000ooooooooool0F_ooool00ol0
003oooooooooo`1Vooooo`03o`000?oooooooooo08gooooo000Booooo`;o0000Foooool00ol0003o
ooooooooo`1Wooooo`03o`000?oooooooooo08cooooo000Booooo`03o`000?oooooooooo05Wooooo
00?o0000ooooooooool0J?ooool00ol0003oooooooooo`2<ooooo`004_ooool00ol0003ooooooooo
o`1Iooooo`03o`000?oooooooooo01Kooooo00?o<S8bo`000?l000000ol000000olb<S;ooooooooo
o`02o`0000;ooooo0_l00014ooooo`03o`000?oooooooooo08_ooooo000Booooo`03o`000?oooooo
oooo05Sooooo00?o0000ooooooooool05oooool00onHV9SoA4A4ooooo`02ooooo`0:odA4A?nHV9So
ooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMgDCooooo00?o0000ooooooooool0Roooool001;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Hooooo`05oa0@4?oMgMgoooooomgM
gOl@41001?ooool01?oMgMgo0000oa0@4?o<c<`Jooooo`Go00009oooool00ol0003oooooooooo`2:
ooooo`004_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01Wooooo00GoQhN7ogMg
MoooooooIVIVohN7Q`04ooooo`04onk^k_lQ8B7o410@onk^kQ[ooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Wooooo`03o`000?oooooooooo08[ooooo000Booooo`03o`000?oooooooooo05Oooooo00?o
0000ooooooooool06Oooool01Oo^k^ko410@onk^k_l@413ok^k^00Cooooo00Co8B4QogMgMomgMgOo
<S8b6oooool00onHV9So8B4Qonk^kP0Yooooo`03o`000?oooooooooo08Wooooo000Booooo`03o`00
0?oooooooooo05Kooooo00?o0000ooooooooool06oooool00omgMgOo8B4QoeEEE@04ooooo`;o0000
0_ooool6o`0001Oooooo00?oV9RHob4Q8Oo^k^h0:?ooool00ol0003oooooooooo`29ooooo`004_oo
ool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01cooooo00?ogMgMo`000?oMgMd02ooo
ool00ol0003oooooooooo`0Hooooo`03ogMgMomVIVKooooo02Sooooo00?o0000ooooooooool0R?oo
ool001;ooooo0_l0001Fooooo`03o`000?oooooooooo01gooooo00?oZJVYooooooooool02oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0Qoooool0
01;ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
01?ooooo00Go0000okZj^_ooooooV9RHoa0@400Zooooo`03o`000?oooooooooo08Oooooo000Boooo
o`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0:_ooool01?l0003oooooooooool0000E
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0:oooool00ol0003oooooooooo`26ooooo`004_ooool0
0ol0003oooooooooo`1Cooooo`03o`000?oooooooooo02cooooo0_l0000:ooooo`Ko0000=_ooool0
0ol0003oooooooooo`26ooooo`004_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo
01Sooooo7Ol0000<ooooo`_o0000:Oooool00ol0003oooooooooo`25ooooo`004_ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo03Wooooo1_l0000gooooo`03o`000?oooooooooo08Go
oooo000Booooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0Moooool00ol0003ooooo
ooooo`24ooooo`004_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo07Sooooo00?o
0000ooooooooool0Q?ooool001;ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0L
ooooo`05oeEEEOnHV9Soooooooooooo<c<`00_l000000onHV9Soooooooooo`1Cooooo`03o`000?oo
oooooooo08?ooooo000Booooo`;o0000DOooool00ol0003oooooooooo`0Nooooo`05oeEEEOnHV9So
oooooeEEEOn7QhL0Eoooool00ol0003oooooooooo`23ooooo`004_ooool00ol0003oooooooooo`1?
ooooo`03o`000?oooooooooo01oooooo00Gok^k^oc8b<_o<c<co8B4Qolc<c004ooooo`03oc8b<_l0
003o000000?o000000Go<S8boooooooooooooooooiRHV002o`000003odA4A?nj^[[ooooo017ooooo
1?l000000ol@413oooooooooo`0/ooooo`03o`000?oooooooooo08;ooooo000Booooo`03o`000?oo
oooooooo04oooooo00?o0000ooooooooool08?ooool00oo^k^ko<S8bo`000005ooooo`03oiRHV?m4
A4Cooooo00;ooooo00?oA4A4oiRHV?ooool00_ooool01Ol@413o^[Zjonk^k_mgMgOo410@01Cooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`22ooooo`004_ooool00ol0003ooooooooo
o`1>ooooo`03o`000?oooooooooo02;ooooo00?oZJVYoa0@4?o^k^h01Oooool01Ol@413ogMgMoooo
oooMgMgo410@00Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo087ooooo000Booooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool08_oo
ool01?mgMgOoA4A4oc8b<_o^k^h4ooooo`05ohN7QomgMgOoooooofIVI_n7QhL01?ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0POooool001;ooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`0Sooooo`04oc8b<_nYZJWoV9RHoeEEE@Co
oooo00Gok^k^oa0@4?o^k^ko410@onk^kP04ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`20ooooo`004_ooool00ol0003oooooooooo`1=ooooo`03
o`000?oooooooooo027ooooo00Oo<S8bo`000?lQ8B7ok^k^oooooonHV9SoEEEE00Cooooo00?oMgMg
ob4Q8OmEEED00oooool00ol@413o0000o`000003o`0001Gooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`20ooooo`004_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
02gooooo00?ogMgMo`000?oMgMd01Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool0Ooooool001;ooooo00?o0000ooooooooool0C?ooool00ol0003o
ooooooooo`0^ooooo`03ojVYZOoooooooooo00Cooooo00?o0000ooooooooool05?ooool00omEEEGo
IVIVo`00000cooooo`03o`000?oooooooooo07oooooo000Booooo`;o0000C?ooool00ol0003ooooo
ooooo`24ooooo`03o`000?oooooooooo07kooooo000Booooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool0Q?ooool00ol0003oooooooooo`1nooooo`004_ooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0OOooool001;ooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo07gooooo000Booooo`03
o`000?oooooooooo04Wooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`1looooo`00
4_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0
O?ooool001;ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`2:ooooo`03o`000?oo
oooooooo07_ooooo0009ooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`17
ooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool0Noooool000_ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo08cooooo00?o0000oooo
ooooool0N_ooool000Ko00001Oooool00ol0003oooooooooo`04ooooo`?o0000A_ooool00ol0003o
ooooooooo`10ooooo`co0000@Oooool00ol0003oooooooooo`1jooooo`002oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0>Oooool7o`0000cooooo
1_l0000looooo`03o`000?oooooooooo07Wooooo000;ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`0gooooo`?o00006Oooool3o`0003Wooooo00?o
0000ooooooooool0NOooool000_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo03Cooooo0ol0000Oooooo`?o0000=oooool00ol0003oooooooooo`1h
ooooo`002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Cooooo00?o0000oooo
ooooool0<oooool2o`0002Gooooo0ol0000dooooo`03o`000?oooooooooo07Sooooo0009ooooo`03
oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0aooooo`;o
0000:_ooool3o`0003;ooooo00?o0000ooooooooool0Moooool001;ooooo00?o0000ooooooooool0
@oooool00ol0003oooooooooo`0`ooooo`;o0000;oooool2o`00033ooooo00?o0000ooooooooool0
Moooool001;ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0^ooooo`;o0000<ooo
ool2o`0002oooooo00?o0000ooooooooool0M_ooool001;ooooo00?o0000ooooooooool0@_ooool0
0ol0003oooooooooo`0]ooooo`;o0000=oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo07Gooooo000Booooo`;o0000@oooool00ol0003oooooooooo`0[ooooo`;o0000>_ooool2o`00
02gooooo00?o0000ooooooooool0MOooool001;ooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo03cooooo0_l0000/ooooo`03o`000?oooooooooo07Co
oooo000Booooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0:Oooool2o`00047ooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1dooooo`004_ooool00ol0003ooooooooo
o`10ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0@_ooool2o`0002[ooooo00?o
0000ooooooooool0Loooool001;ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0X
ooooo`;o0000Aoooool2o`0002Sooooo00?o0000ooooooooool0Loooool001;ooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04Wooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`1booooo`004_ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo07;ooooo000Booooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
9Oooool2o`0004oooooo0_l0000Vooooo`03o`000?oooooooooo077ooooo000Booooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Aooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool0LOooool001;ooooo0_l0000nooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo073ooooo000Booooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08oooool2o`00
05Oooooo0_l0000Tooooo`03o`000?oooooooooo06oooooo000Booooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0Koooool001;ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`1^ooooo`004_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo023ooooo0_l0
001Oooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0K_ooool001;ooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo063ooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`1]ooooo`004_ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo06gooooo000Booooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool0K?ooool001;ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo06Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1/ooooo`004_oo
ool2o`0003Wooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Xooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool0Joooool001;ooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`1[ooooo`004_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
06[ooooo000Booooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`1^ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0JOooool001;ooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Yooooo`004_ooool00ol0003ooooooooo
o`0Zooooo`Co000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo00Go0000:Oooool01OnHV9So410@o`000?lb<S;oc<c<02_ooooo0_l000000ol@413ooooo
ooooo`0?ooooo`03o`000?oooooooooo01Kooooo00OoA4A4o`000?l0003o<S8bomgMgOoooooo0000
02Oooooo00Gok^k^oc8b<_l0003o410@olc<c00nooooo`004_ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool2o`0000?ooooo00GoV9RHob4Q
8Oo^k^koooooodA4A00Yooooo`05oa0@4?nj^[[oooooogMgMolb<S80;?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01Sooooo00CoMgMgoc8b<_oooooo00009oooool01OmEEEGoMgMg
oooooonHV9So8B4Q03kooooo000Booooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h0
;_ooool00ol0003oooooooooo`0Wooooo`Go00004oooool2o`0001Wooooo00Co0000oooooooooooo
00009_ooool01Ol0003ooooooooooooooooo000003kooooo000Booooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Ko
oooo00?oV9RHob4Q8Oo^k^h0;?ooool00onYZJWo410@ooooo`0Xooooo`04odA4A?oMgMgoooooo`00
01Kooooo00?o0000ooooooooool05Oooool01OmgMgOo<S8boooooooooooo000002Kooooo00Go0000
oiRHV?ooooooV9RHob4Q8@0nooooo`004_ooool2o`0002gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Sooooo00?oMgMgofIVI_ooool0:_ooool0
0ol@413o0000okZj^P0Yooooo`04omgMgOmEEEGoooooo`0001Oooooo00?o0000ooooooooool04Ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00?ooooo00?o0000ooooooooool08oooool01Ol0003oEEEE
o`000?l@413oc<c<03kooooo000Booooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
:_ooool00onj^[[o8B4Qooooo`0Yooooo`03ogMgMoo<c<co000001Sooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02?ooooo00?oEEEEohN7Qoooool0
@?ooool001;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool01oooool01Ol0003o^[ZjoooooonHV9So410@02Wooooo
00Go410@oiRHV?oooooo^[Zjo`00000Zooooo`03onk^k_m4A4Co000001Wooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02;ooooo00?ogMgMoa0@4?nH
V9P0@?ooool001;ooooo00?o0000ooooooooool0:_ooool00omEEEGoIVIVo`000005ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool02?ooool01OnHV9So410@o`000?lQ8B7oc<c<02Wo
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@0[ooooo`03ogMgMol0003ooooo01Wooooo00?o0000oooo
ooooool03_ooool4o`0000Gooooo00?o0000ooooooooool08oooool01?o<c<coA4A4o`000?l@410n
ooooo`004_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0Q?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo06Cooooo000Booooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`26ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0Hoooool001;ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`12ooooo`;o00000_ooool00ol@413o0000o`000007ooooo`03oc8b
<_l0003o000000?o000000?o<S8booooooooool00_l00002ooooo`;o00001?ooool001;ooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo08[ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`12ooooo`05o`000?ooooook^k^oc8b<_o<c<`0
2?ooool00onHV9SoA4A4ooooo`02ooooo`0:odA4A?nHV9Soooooooooooo^k^ko8B4QohN7Qonj^[[o
0000omgMg@Cooooo000Booooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`2<ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@_ooool0
1?l0003oV9RHoc8b<_o<c<`:ooooo`05oa0@4?oMgMgoooooomgMgOl@41001?ooool01?oMgMgo0000
oa0@4?o<c<`5ooooo`002oooooooo`0003?o00002oooool00ol0003o410@oiRHV00;ooooo`05ohN7
QomgMgOoooooofIVI_n7QhL01?ooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`004_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000001_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo2?l00004ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool5o`0000Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000002?ooool00ol0
003oooooooooo`07ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02oooool01?l0003ok^k^oeEEEOn7QhL:ooooo`05onk^k_l@413o
k^k^oa0@4?o^k^h01?ooool01?lQ8B7oMgMgogMgMolb<S85ooooo`004_ooool00ol0003ooooooooo
o`0/ooooo`;o00005Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01cooooo0ol0
000<ooooo`03o`000?oooooooooo01Cooooo1_l0000Aooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool07Oooool01Ol0003oooooodA4A?l0003o410@00[ooooo00?oMgMgob4Q8OmEEED0
1?ooool2o`0000;ooooo0_l00004ooooo`004_ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0;oooool5o`0002cooooo1Ol0000aooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0<ooooo`03omgMgOl0
003ogMgM00kooooo000Booooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0/ooooo`Co0000=_ooool3o`0002oooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00gooooo00?oZJVYooooooooool03Oooool0
01;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
02[ooooo0ol0000mooooo`?o0000;Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
03gooooo0_l0000Oooooo`004_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0:?ooool3o`0004?ooooo0ol0000[ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0GOooool001;ooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo02Kooooo0ol00019ooooo`?o0000:Oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo05gooooo000Booooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Uooooo`;o0000Coooool3o`0002Oooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1Looooo`004_ooool2o`0002Wooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Tooooo`;o0000E?ooool3o`0002Gooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`1Kooooo`004_ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool08_ooool3o`0005Wooooo0ol0000Soooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Foooool001;ooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0?ooooo`;o00008oooool2o`0001;ooooo00?o<S8bo`000?l0
00000ol000000olb<S;oooooooooo`02o`0000;ooooo0_l0000nooooo`;o00008_ooool2o`00017o
oooo00?o0000ooooooooool0F_ooool001;ooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo023ooooo0ol0000Dooooo`03oiRHV?m4A4Cooooo00;ooooo
00[oA4A4oiRHV?ooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM6oooool2o`000003oa0@4?oo
oooooooo023ooooo0_l0000Rooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0FOoo
ool001;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo01oooooo0_l0000Hooooo`05oa0@4?oMgMgoooooomgMgOl@41001?ooool01?oMgMgo0000oa0@
4?o<c<`Mooooo`03o`000?oooooooooo02?ooooo0_l0000Qooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0FOooool001;ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo01kooooo0_l0000Jooooo`05ohN7QomgMgOoooooofIVI_n7QhL0
1?ooool01?o^k^ko8B4Qoa0@4?o^k^hJooooo`Go00009_ooool2o`00023ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`1Hooooo`004_ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool07?ooool3o`0001cooooo00Gok^k^oa0@4?o^k^ko
410@onk^kP04ooooo`04ob4Q8OmgMgOoMgMgoc8b<Q[ooooo00CoA4A4omgMgOoooooo0000:Oooool2
o`0001oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Gooooo`004_ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06oooool2o`00
023ooooo00?oMgMgob4Q8OmEEED01?ooool2o`0000;ooooo1_l0000Eooooo`04omgMgOmEEEGooooo
o`0002_ooooo0_l0000Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Eoooool0
01;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01[ooooo0_l0000Rooooo`03omgMgOl0003ogMgM00_ooooo00?o0000ooooooooool05_ooool00omg
MgOoc<c<o`00000]ooooo`;o00007Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
05Kooooo000Booooo`;o00008oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Wo
oooo0_l0000Uooooo`03ojVYZOoooooooooo00_ooooo00?o0000ooooooooool05Oooool00oo^k^ko
A4A4o`00000_ooooo`?o00006oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05Go
oooo000Booooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Gooooo`?o0000=_ooool00ol0003oooooooooo`0Eooooo`03ogMgMol0003ooooo037ooooo
0_l0000Jooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0EOooool001;ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Kooooo0_l0
000fooooo`04o`000?ooooooooooo`0004gooooo0_l0000Iooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0E?ooool001;ooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo01Gooooo0_l0000iooooo`;o00002_ooool6o`00043ooooo0ol0
000Gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Doooool001;ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0;ooooo`;o00005_ooool2o`0002Oooooo7Ol0000<
ooooo`_o0000=Oooool2o`0001Kooooo0_l0000=ooooo`03o`000?oooooooooo05;ooooo000Boooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Doooo
o`;o0000BOooool6o`0004Gooooo0_l0000Fooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0D_ooool001;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo01?ooooo0_l0002Hooooo`;o00005Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo057ooooo000Booooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
2_ooool2o`0001Cooooo0_l0000_ooooo`05oeEEEOnHV9Soooooooooooo<c<`00_l000000onHV9So
ooooooooo`1Sooooo`;o00005?ooool2o`0000_ooooo00?o0000ooooooooool0D?ooool001;ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01;ooooo
0_l0000booooo`05oeEEEOnHV9SooooooeEEEOn7QhL0JOooool2o`0001Cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`1?ooooo`004_ooool2o`0001cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Aooooo`;o0000=?ooool01Oo^k^ko<S8bolc<c?lQ8B7oc<c<00Co
oooo00?o<S8bo`000?l000000ol000001Olb<S;oooooooooooooooooV9RH00;o000000?oA4A4okZj
^_ooool04Oooool4o`000003oa0@4?oooooooooo03oooooo0_l0000Cooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0C_ooool001;ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`08ooooo`;o00004_ooool2o`0003Oooooo00?ok^k^oc8b<_l000001Oooool00onHV9So
A4A4ooooo`02ooooo`03odA4A?nHV9Sooooo00;ooooo00Go410@okZj^_o^k^koMgMgoa0@400Doooo
o`03o`000?oooooooooo04?ooooo0_l0000Booooo`;o00002_ooool00ol0003oooooooooo`1=oooo
o`004_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool04?ooool2o`0003[ooooo00?oZJVYoa0@4?o^k^h01Oooool01Ol@413ogMgMoooooooMgMgo410@
00Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`15ooooo`;o00004_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo04cooooo000Booooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`;o0000??ooool01?mgMgOo
A4A4oc8b<_o^k^h4ooooo`05ohN7QomgMgOoooooofIVI_n7QhL01?ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo04Oooooo0_l0000Aooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0Boooool001;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`07oooo
o`;o00004?ooool2o`0003kooooo00Co<S8bojVYZOnHV9SoEEEE1?ooool01Oo^k^ko410@onk^k_l@
413ok^k^00Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`19ooooo`;o00004?oo
ool2o`0000Wooooo00?o0000ooooooooool0B_ooool001;ooooo00?o0000ooooooooool05Oooool2
o`0000Wooooo00?o0000ooooooooool03_ooool2o`0003kooooo00Oo<S8bo`000?lQ8B7ok^k^oooo
oonHV9SoEEEE00Cooooo00?oMgMgob4Q8OmEEED00oooool00ol@413o0000o`000003o`0001Gooooo
00?o0000ooooooooool0Boooool2o`00013ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`19ooooo`004_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo0_l0
000?ooooo`;o0000Boooool00ooMgMgo0000omgMg@05ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0COooool2o`0000oooooo0_l00008ooooo`;o0000BOooool001;ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo0_l0001>
ooooo`03ojVYZOoooooooooo00Cooooo00?o0000ooooooooool05?ooool00omEEEGoIVIVo`00001A
ooooo`?o00003_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Kooooo000Boooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool2o`0000gooooo0ol00035oooo
o`?o00003?ooool2o`0000Sooooo00?o0000ooooooooool0AOooool001;ooooo0_l0000Booooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool3o`000<_ooooo0ol0000;ooooo`;o
00001oooool00ol0003oooooooooo`14ooooo`004_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00Gooooo0_l0000:ooooo`?o0000dOooool3o`0000[ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`13ooooo`004_ooool00ol0003oooooooooo`0>ooooo`;o00001ooo
ool00ol0003oooooooooo`07ooooo`?o0000eoooool3o`0000Sooooo0_l00006ooooo`;o0000@ooo
ool001;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`?o00001oooool3
o`000=gooooo0ol00007ooooo`;o00001_ooool00ol0003oooooooooo`10ooooo`004_ooool00ol0
003oooooooooo`0;ooooo`;o00001?ooool3o`0000Oooooo0ol0003Sooooo`?o00001_ooool2o`00
00Gooooo0_l00010ooooo`004_ooool00ol0003oooooooooo`0:ooooo`04o`000?oooooooooooooo
o`?o00001oooool3o`000>Wooooo0ol00005ooooo`;o00001Oooool00ol0003oooooooooo`0moooo
o`002Oooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool02?ooool2o`000004
ooooool0003o0000o`0000Gooooo1Ol0003_ooooo`Go00000_ooool3o`0000?ooooo0ol0000loooo
o`002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo1Ol00003ooooo`Go
0000nOooool=o`0003[ooooo000;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool<o`000?oooooo1?ooool;o`0003Oooooo000;ooooo`03o`000?oooooooooo00Cooooo2Ol0
003ooooooaCooooo2?l0000booooo`002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?ooooooE?ooool000_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooo
oeCooooo000;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooomDooooo`00
2Oooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0017ooooo00Co
8B4Qo`000?l0003oV9RHoooooomDooooo`004oooool00onj^[[o0000ooooo`3ooooooe?ooooo000@
ooooo`05oiRHV?l@413o0000o`000?nHV9P0oooooomDooooo`004?ooool00ol0003oZJVYooooo`3o
oooooeKooooo000@ooooo`03o`000?o^k^kooooo0?ooooooE_ooool0013ooooo00?oV9RHodA4A?oM
gMd0oooooomFooooo`004Oooool00onHV9So0000o`00003ooooooeGooooo000Aooooo`03o`000?o<
c<cooooo0?ooooooEOooool0017ooooo00Go410@ohN7Qoooooook^k^ofIVIP3ooooooe?ooooo000A
ooooo`05olc<c?m4A4Co0000o`000?nHV9P0oooooomCooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.312, 0}} -> {-0.407144, -3.22755, \
0.0270539, 0.0278675}}],

Cell["\<\
Fig. 6.6 Von Neumann stability analysis for the heat equation\
\>", \
"Caption",
  CellTags->"Fig. 6.6"],

Cell[TextData[{
  "From the figure, one can see that the most unstable wavenumber satisfies \
",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"k", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}], "=", "\[Pi]"}], 
        TraditionalForm]]],
  ". For this wavenumber, Eq. ",
  ButtonBox["(6.2.8)",
    ButtonData:>{"Chapter6.nb", "(6.2.8)"},
    ButtonStyle->"Hyperlink"],
  " becomes ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Xi]", "=", 
          RowBox[{"1", "-", 
            RowBox[{"4", " ", 
              FractionBox[
                RowBox[{"\[Chi]", " ", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]]}], 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], "2"]]}]}]}], 
        TraditionalForm]]],
  ", and the solution is stable for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Xi] \[GreaterEqual] \ \(-1. \)\)]],
  " This implies"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[
            RowBox[{"\[Chi]", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}], 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], "2"]], "\[LessEqual]", 
          " ", \(1\/2\)}], TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(6.2.9)"],

Cell[TextData[{
  " in order for the FTCS method to be stable.  This inequality is known as a \
",
  ButtonBox["Courant",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Courant.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " condition. The Courant condition sets a rather stringent limit on the \
maximum time step size ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " for a given value of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ". For example, in  the problem solved in the previous section, we took ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi] = 1/4\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], " ", "=", " ", "0.1"}], 
        TraditionalForm]]],
  ", implying a maximum time step size given by ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "\[LessEqual]", " ", "0.02"}], 
        TraditionalForm]]],
  ".  Thus, the first solution, with ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "=", "0.01"}], TraditionalForm]]],
  ", worked well, but the second solution, with ",
  Cell[BoxData[
      FormBox[Cell[TextData[{
          "\[CapitalDelta]",
          StyleBox["t ",
            FontSlant->"Italic"],
          "= 0.05"
        }]], TraditionalForm]]],
  ", violated the Courant condition and the method failed. \t"
}], "Text",
  CellTags->"i:65"]
}, Closed]],

Cell[CellGroupData[{

Cell["CTCS Method", "Section",
  CellTags->{"i:20", "c:17"}],

Cell[TextData[{
  "The FTCS method uses a forward-difference approximation for the time \
derivative, which is only first-order accurate in ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ". A higher-accuracy difference approximation to the time derivative would \
be preferable. One simple approach is the CTCS method, where both the time \
and space derivatives are center-differenced. For the heat equation, this \
corresponds to the difference equation"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\_j\%\(n + 1\)\), "=", 
          RowBox[{\(T\_j\%\(n - 1\)\), "+", 
            RowBox[{"2", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], " ", \(S\_j\%n\)}], "+", 
            RowBox[{
              FractionBox[
                RowBox[{"2", "\[Chi]", " ", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]]}], 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], "2"]], \((T\_\(j + 1\)\%n - 
                  2  T\_j\%n + T\_\(j - 1\)\%n)\)}]}]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.10)"],

Cell[TextData[{
  "Unfortunately, however, von Neumann stability analysis of this equation \
leads us to the conclusion that the CTCS method is unstable for ",
  StyleBox["any",
    FontSlant->"Italic"],
  " time step size. For, when we substitute in  ",
  Cell[BoxData[
      \(TraditionalForm\`T\_j\%n = \(\[Xi]\^n\) \[ExponentialE]\^\(\
\[ImaginaryI]\ k\ x\_j\)\)]],
  ", we obtain a quadratic equation for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Xi]\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Xi]\^2 + \[Alpha]\ \[Xi] - 1 \[Equal] 0\)]],
  ","
}], "NE2",
  CellTags->"(6.2.11)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Alpha]", "=", 
          RowBox[{
            FractionBox[
              RowBox[{"8", "\[Chi]", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]]}], 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"]], 
            RowBox[{\(sin\^2\), "(", 
              RowBox[{"k", " ", 
                RowBox[{
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], "/", "2"}]}], ")"}]}]}], 
        TraditionalForm]]],
  ". The two solutions for \[Xi] are plotted in Cell ",
  ButtonBox["6.58",
    ButtonData:>"Cell 6.58",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(sol\  = 
        Solve[\[Xi]\^\(\(2\)\(\ \)\) + \[Alpha]\ \[Xi]\  - \ 1 \[Equal] 
            0, \[Xi]];\)\), "\n", 
    \(\(Plot[Evaluate[\[Xi] /. sol], {\[Alpha], 0, 1}, 
        AxesLabel \[Rule] {"\<\[Alpha]\>", "\<\[Xi]\>"}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.58"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.378492 0.224827 [
[.21429 .36599 -9 -9 ]
[.21429 .36599 9 0 ]
[.40476 .36599 -9 -9 ]
[.40476 .36599 9 0 ]
[.59524 .36599 -9 -9 ]
[.59524 .36599 9 0 ]
[.78571 .36599 -9 -9 ]
[.78571 .36599 9 0 ]
[.97619 .36599 -3 -9 ]
[.97619 .36599 3 0 ]
[1.025 .37849 0 -6 ]
[1.025 .37849 10 6 ]
[.01131 .04125 -24 -4.5 ]
[.01131 .04125 0 4.5 ]
[.01131 .15367 -12 -4.5 ]
[.01131 .15367 0 4.5 ]
[.01131 .26608 -24 -4.5 ]
[.01131 .26608 0 4.5 ]
[.01131 .49091 -18 -4.5 ]
[.01131 .49091 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .37849 m
.21429 .38474 L
s
[(0.2)] .21429 .36599 0 1 Mshowa
.40476 .37849 m
.40476 .38474 L
s
[(0.4)] .40476 .36599 0 1 Mshowa
.59524 .37849 m
.59524 .38474 L
s
[(0.6)] .59524 .36599 0 1 Mshowa
.78571 .37849 m
.78571 .38474 L
s
[(0.8)] .78571 .36599 0 1 Mshowa
.97619 .37849 m
.97619 .38474 L
s
[(1)] .97619 .36599 0 1 Mshowa
.125 Mabswid
.07143 .37849 m
.07143 .38224 L
s
.11905 .37849 m
.11905 .38224 L
s
.16667 .37849 m
.16667 .38224 L
s
.2619 .37849 m
.2619 .38224 L
s
.30952 .37849 m
.30952 .38224 L
s
.35714 .37849 m
.35714 .38224 L
s
.45238 .37849 m
.45238 .38224 L
s
.5 .37849 m
.5 .38224 L
s
.54762 .37849 m
.54762 .38224 L
s
.64286 .37849 m
.64286 .38224 L
s
.69048 .37849 m
.69048 .38224 L
s
.7381 .37849 m
.7381 .38224 L
s
.83333 .37849 m
.83333 .38224 L
s
.88095 .37849 m
.88095 .38224 L
s
.92857 .37849 m
.92857 .38224 L
s
.25 Mabswid
0 .37849 m
1 .37849 L
s
gsave
1.025 .37849 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .04125 m
.03006 .04125 L
s
[(-1.5)] .01131 .04125 1 0 Mshowa
.02381 .15367 m
.03006 .15367 L
s
[(-1)] .01131 .15367 1 0 Mshowa
.02381 .26608 m
.03006 .26608 L
s
[(-0.5)] .01131 .26608 1 0 Mshowa
.02381 .49091 m
.03006 .49091 L
s
[(0.5)] .01131 .49091 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .06373 m
.02756 .06373 L
s
.02381 .08622 m
.02756 .08622 L
s
.02381 .1087 m
.02756 .1087 L
s
.02381 .13118 m
.02756 .13118 L
s
.02381 .17615 m
.02756 .17615 L
s
.02381 .19863 m
.02756 .19863 L
s
.02381 .22111 m
.02756 .22111 L
s
.02381 .2436 m
.02756 .2436 L
s
.02381 .28856 m
.02756 .28856 L
s
.02381 .31104 m
.02756 .31104 L
s
.02381 .33353 m
.02756 .33353 L
s
.02381 .35601 m
.02756 .35601 L
s
.02381 .40097 m
.02756 .40097 L
s
.02381 .42346 m
.02756 .42346 L
s
.02381 .44594 m
.02756 .44594 L
s
.02381 .46842 m
.02756 .46842 L
s
.02381 .51339 m
.02756 .51339 L
s
.02381 .53587 m
.02756 .53587 L
s
.02381 .55835 m
.02756 .55835 L
s
.02381 .58084 m
.02756 .58084 L
s
.02381 .01877 m
.02756 .01877 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .15367 m
.06244 .14906 L
.10458 .14393 L
.14415 .13901 L
.18221 .13419 L
.22272 .12897 L
.26171 .12384 L
.30316 .11829 L
.34309 .11284 L
.3815 .10752 L
.42237 .10175 L
.46172 .09611 L
.49955 .09061 L
.53984 .08465 L
.57861 .07884 L
.61984 .07256 L
.65954 .06644 L
.69774 .06046 L
.73838 .05402 L
.77751 .04774 L
.81909 .04099 L
.85916 .0344 L
.89771 .02798 L
.93871 .02109 L
.97619 .01472 L
s
.02381 .60332 m
.06244 .5988 L
.10458 .59399 L
.14415 .58956 L
.18221 .5854 L
.22272 .58106 L
.26171 .57699 L
.30316 .57275 L
.34309 .56877 L
.3815 .56503 L
.42237 .56114 L
.46172 .5575 L
.49955 .55407 L
.53984 .55051 L
.57861 .54718 L
.61984 .54372 L
.65954 .54047 L
.69774 .53743 L
.73838 .53428 L
.77751 .53132 L
.81909 .52826 L
.85916 .52539 L
.89771 .5227 L
.93871 .51992 L
.97619 .51744 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooolUooooo`Co00007?ooool0027ooooo0ol0
003ooooooaoooooo1_l0000Pooooo`008Oooool00ol0003oooooooooo`3ooooooaWooooo1_l0000V
ooooo`008Oooool00ol0003oooooooooo`3ooooooa;ooooo1ol0000/ooooo`008Oooool00ol0003o
ooooooooo`3oooooo`cooooo1_l0000cooooo`002?ooool4o`000003oa0@4?oooooooooo00;ooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooo`Ko
oooo1_l0000iooooo`002_ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo0?oooooo1_l0000oooooo`001Ol00005ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3iooooo`Ko0000AOoo
ool000[ooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`03ooooo`?o0000loooool6
o`0004_ooooo000:ooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004
ooooo`03o`000?oooooooooo0>cooooo1ol0001Aooooo`002_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0i_ooool6o`0005Sooooo000:ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3Pooooo`Ko
0000G_ooool000Sooooo00?oEEEEofIVI_l000003Oooool4o`0000Gooooo00?o0000ooooooooool0
f_ooool6o`0006Cooooo000Qooooo`03o`000?oooooooooo0=?ooooo1ol0001Zooooo`008Oooool0
0ol0003oooooooooo`3=ooooo`Ko0000LOooool0027ooooo0ol00037ooooo`Ko0000Moooool0027o
oooo00?o0000ooooooooool0`Oooool6o`0007gooooo000Qooooo`03o`000?oooooooooo0;_ooooo
1_l00023ooooo`008Oooool00ol0003oooooooooo`2eooooo`Ko0000ROooool0027ooooo00?o0000
ooooooooool0[_ooool7o`0008oooooo000Qooooo`03o`000?oooooooooo0:Gooooo2Ol0002Foooo
o`008Oooool00ol0003oooooooooo`2Looooo`Wo0000Woooool0027ooooo0ol0002Eooooo`Oo0000
Z?ooool0027ooooo00?o0000ooooooooool0Soooool6o`000:oooooo000Qooooo`03o`000?oooooo
oooo08Wooooo1_l0002eooooo`008Oooool00ol0003oooooooooo`23ooooo`Ko0000^oooool0027o
oooo00?o0000ooooooooool0OOooool6o`000<7ooooo000Qooooo`03o`000?oooooooooo07Cooooo
2Ol00037ooooo`008Oooool00ol0003oooooooooo`1Zooooo`[o0000d?ooool0027ooooo0ol0001T
ooooo`Ko0000f_ooool0027ooooo00?o0000ooooooooool0G_ooool6o`000>3ooooo000Qooooo`03
o`000?oooooooooo05Sooooo1_l0003Vooooo`008Oooool00ol0003oooooooooo`1Booooo`Ko0000
k?ooool0027ooooo00?o0000ooooooooool0Boooool7o`000?;ooooo000Qooooo`03o`000?oooooo
oooo04;ooooo2Ol0003iooooo`008Oooool00ol0003oooooooooo`0iooooo`Wo0000ooooool3oooo
o`008Oooool3o`0003;ooooo1ol0003oooooo`cooooo000Qooooo`03o`000?oooooooooo02Wooooo
2Ol0003ooooooa?ooooo000Qooooo`03o`000?oooooooooo023ooooo2Ol0003ooooooacooooo000Q
ooooo`03o`000?oooooooooo01[ooooo1_l0003oooooobGooooo000Hooooo`Co000000?o410@oooo
ooooool00_ooool00ol0003oooooooooo`0@ooooo`[o0000ooooool[ooooo`006_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Kooooo2_l0003oooooocGooooo000?ooooo`Ko0000
1Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Ko0000ooooooloooooo`006_oo
ool00ol0003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?ooooooAOooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo0?ooooooAOooool000Go00000_ooool01Ol@413ooooooooooooooooo
410@013ooooo00?o0000ooooooooool00_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooooom5
ooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo02kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo02Gooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<02Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<033ooooo1?l00000
0ol@413oooooooooo`0Hooooo`008Oooool00ol0003oooooooooo`0^ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Vooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B409_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40<_oo
ool00ol0003oooooooooo`0Jooooo`008Oooool00ol0003oooooooooo`0^ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Wooooo`05oa0@4?ooooooooooooooool@4100
2oooool5o`0002Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool000009_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00
000booooo`03o`000?oooooooooo01[ooooo000Qooooo`03o`000?oooooooooo02kooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02Kooooo00Go0000oooooooooooooooo
o`00000;ooooo`04odA4A?oMgMgoooooo`0002Sooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?nHV9SooooooiRHV?lQ8B409_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go
<S8boiRHV?ooooooV9RHoc8b<P0booooo`03o`000?oooooooooo01[ooooo000Qooooo`03o`000?oo
oooooooo02kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo02Gooooo
00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Sooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00booooo`03o`000?oooooooooo01[o
oooo000Qooooo`03o`000?oooooooooo02kooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo02Cooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co0000
02Sooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo02Sooooo00Go410@
oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@4100<_ooool00ol0003ooooo
ooooo`0Jooooo`008Oooool3o`0002kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41009_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4
A?l00000:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000booooo`03o`00
0?oooooooooo01[ooooo000Qooooo`03o`000?oooooooooo02kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`09_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00gooooo00?oMgMgo`000?ooool09oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<
odA4A?l0003o410@9_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0`ooooo`03oeEEEOmVIVKo000001cooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
oooooc_ooooo00OoV9RHo`000?l0003oEEEEonk^k_mVIVKo000000?ooooo000Qooooo`03o`000?oo
oooooooo0?oooooo>oooool01_l0003oZJVYoooooon7QhOo<S8bofIVIPCooooo000Qooooo`03o`00
0?oooooooooo0?oooooo>oooool01_l0003oooooooooooooooooQhN7odA4A0Cooooo000Joooooooo
0000>_l0000;ooooo`06ob4Q8Oo<c<cooooooooooonHV9So<S8b1?ooool0027ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo013ooooo00OoZJVYob4Q
8OoMgMgok^k^oc8b<_mEEEGo^[Zj00?ooooo000Qooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`0Aooooo`06oiRHV?l0003o0000oiRHV?nj^[[o<S8b
0oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooo
oooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Cooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo8_ooool7o`0001cooooo000Q
ooooo`03o`000?oooooooooo0?oooooo5_ooool<o`0002?ooooo000Qooooo`03o`000?oooooooooo
0?oooooo2Oooool=o`0002oooooo000Qooooo`03o`000?oooooooooo0?cooooo3?l0000looooo`00
8Oooool00ol0003oooooooooo`3`ooooo`co0000B?ooool0027ooooo00?o0000ooooooooool0hooo
ool=o`0005Cooooo000Qooooo`?o0000eoooool<o`00067ooooo000Qooooo`03o`000?oooooooooo
0<[ooooo3Ol0001]ooooo`008Oooool00ol0003oooooooooo`2nooooo`co0000N_ooool0027ooooo
00?o0000ooooooooool0/_ooool<o`0008Kooooo000Qooooo`03o`000?oooooooooo0:Gooooo3Ol0
002Booooo`008Oooool00ol0003oooooooooo`2Iooooo`co0000Woooool0027ooooo00?o0000oooo
ooooool0S?ooool=o`000:_ooooo000Qooooo`?o0000P?ooool<o`000;Sooooo000Qooooo`03o`00
0?oooooooooo07Cooooo3?l00034ooooo`008Oooool00ol0003oooooooooo`1Zooooo`[o0000d?oo
ool0027ooooo00?o0000ooooooooool0I?ooool6o`000=[ooooo000Qooooo`03o`000?oooooooooo
05_ooooo2Ol0003Pooooo`008Oooool00ol0003oooooooooo`1?ooooo`co0000jOooool0027ooooo
00?o0000ooooooooool0@_ooool=o`000?Gooooo000Qooooo`?o0000>Oooool9o`000?oooooo0ooo
ool0027ooooo00?o0000ooooooooool0<_ooool7o`000?oooooo3?ooool0027ooooo00?o0000oooo
ooooool0:Oooool9o`000?oooooo4oooool0027ooooo00?o0000ooooooooool07Oooool<o`000?oo
oooo7?ooool0027ooooo00?o0000ooooooooool05?ooool9o`000?oooooo:?ooool001Sooooo1?l0
00000ol@413oooooooooo`02ooooo`03o`000?oooooooooo00gooooo1ol0003ooooooc7ooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool:o`000?oooooo>?ooool0
01[ooooo00?o0000ooooooooool01?ooool6o`000?oooooo@_ooool001[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
ooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008?ooool01?lQ
8B7o0000o`000?nHV9SoooooodGooooo000Rooooo`03okZj^_l0003ooooo0?ooooooA?ooool001oo
oooo00GoV9RHoa0@4?l0003o0000oiRHV03oooooodGooooo000Oooooo`03o`000?nYZJWooooo0?oo
ooooAoooool001oooooo00?o0000onk^k_ooool0oooooom7ooooo`007oooool00onHV9SoA4A4omgM
g@3oooooodOooooo000Pooooo`03oiRHV?l0003o00000?ooooooA_ooool0023ooooo00?o0000olc<
c?ooool0oooooom6ooooo`008?ooool01Ol@413oQhN7ooooooo^k^koIVIV0?ooooooA?ooool0023o
oooo00Goc<c<odA4A?l0003o0000oiRHV03oooooodCooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.114019, -1.72342, \
0.00420373, 0.0178073}}]
}, Open  ]],

Cell[TextData[{
  "One of the two solutions has ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(\[Xi]\)\(|\)\(\(>\)\(1\)\)\)\)]],
  " for all possible ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " values, corresponding to all possible ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", so the CTCS method does not work for the heat equation. However, the \
CTCS method does work for other equations, such as the wave equation and the \
Schr\[ODoubleDot]dinger equation. (See the exercises.) "
}], "Text"],

Cell["\<\
\tA way to modify the CTCS method so that it works for the heat \
equation is discussed in the next sub-subsection.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Lax Method", "Section",
  CellTags->{"i:21", "c:18"}],

Cell[TextData[{
  "Finding a stable, efficient algorithm for the solution of a PDE is \"more \
of an art than a science\", in the words of Press, Flannery, Teukolsky, and \
Vetterling (",
  ButtonBox["1992",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "). Nowhere is this more evident than in the Lax method. In this method, we \
make a seemingly trivial modification to the previous CTCS method for the \
heat equation, and completely change the equations stability properties. The \
change that we make is as follows: in the differenced  time derivative,\n",
  Cell[BoxData[
      FormBox[
        FractionBox[\(T\_j\%\(n + 1\) - T\_j\%\(n - 1\)\), 
          RowBox[{"2", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]], TraditionalForm]]],
  ", we replace ",
  Cell[BoxData[
      \(TraditionalForm\`T\_j\%\(n - 1\)\)]],
  " by its average value from surrounding grid points: ",
  Cell[BoxData[
      FormBox[
        FractionBox[\(T\_j\%\(n + 1\) - \(1\/2\) \((T\_\(j + 1\)\%\(n - 1\) + 
                  T\_\(j - 1\)\%\(n - 1\))\)\), 
          RowBox[{"2", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]], TraditionalForm]]],
  ". The resulting difference equation is"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(T\_j\%\(n + 1\)\), "=", 
        RowBox[{\(\(1\/2\) \((T\_\(j + 1\)\%\(n - 1\) + 
                T\_\(j - 1\)\%\(n - 1\))\)\), "+", 
          RowBox[{"2", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], " ", \(S\_j\%n\)}], "+", 
          RowBox[{
            FractionBox[
              RowBox[{"2", "\[Chi]", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]]}], 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], 
                "2"]], \(\((T\_\(j + 1\)\%n - 2  T\_j\%n + 
                  T\_\(j - 1\)\%n)\)\(.\)\)}]}]}], TraditionalForm]]]], "NE2",\

  CellTags->"(6.2.12)"],

Cell[TextData[{
  "Von Neumann stability analysis of this equation leads to the following \
quadratic equation for the amplification factor ",
  Cell[BoxData[
      \(TraditionalForm\`\[Xi]\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[Xi]\^2\), "+", " ", 
            RowBox[{"8", "\[Delta]", " ", 
              RowBox[{\(sin\^2\), "(", 
                RowBox[{"k", " ", 
                  RowBox[{
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["x",
                          FontSlant->"Italic"]}]], "/", "2"}]}], ")"}], 
              "\[Xi]"}], "-", 
            RowBox[{"cos", " ", "k", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}]}], "=", "0"}], 
        TraditionalForm]]],
  ","
}], "UNNEQ"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Delta]\)\(=\)\)\)]],
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Chi]", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], "/", 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], "2"]}]}], TraditionalForm]]],
  ". This is the same as Eq. ",
  ButtonBox["(6.2.11)",
    ButtonData:>"(6.2.11)",
    ButtonStyle->"Hyperlink"],
  ", except that ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", " ", "k", " ", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  " replaces the constant term. But this makes a big difference .  The \
magnitude of the solution to this quadratic is plotted in Cell ",
  ButtonBox["6.59",
    ButtonData:>"Cell 6.59",
    ButtonStyle->"Hyperlink"],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta] = 1/5\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(sol\  = 
        Solve[\[Xi]\^\(\(2\)\(\ \)\) + 
              8  \[Delta]\ Sin[\((k\ /2)\)]^2  \[Xi] - Cos[\ k]\  \[Equal] 
            0, \[Xi]];\)\), "\n", 
    \(\(Plot[
        Evaluate[Abs[\((\[Xi] /. sol)\)] /. \[Delta] \[Rule] 1/5], {k, 0, 
          2  Pi}, AxesLabel \[Rule] {"\<k\>", "\<|\[Xi]|\>"}, 
        PlotLabel \[Rule] \*"\"\<|\[Xi]|, for \[Chi] \[CapitalDelta]t/\!\(\
\[CapitalDelta]x\^2\)=1/5\>\""];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.59"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.0147151 0.588604 [
[.17539 .00222 -3 -9 ]
[.17539 .00222 3 0 ]
[.32696 .00222 -3 -9 ]
[.32696 .00222 3 0 ]
[.47854 .00222 -3 -9 ]
[.47854 .00222 3 0 ]
[.63011 .00222 -3 -9 ]
[.63011 .00222 3 0 ]
[.78169 .00222 -3 -9 ]
[.78169 .00222 3 0 ]
[.93327 .00222 -3 -9 ]
[.93327 .00222 3 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 10 6 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -11 0 ]
[.02381 .64303 11 12 ]
[.5 .63053 -64.7188 0 ]
[.5 .63053 64.7188 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .01472 m
.17539 .02097 L
s
[(1)] .17539 .00222 0 1 Mshowa
.32696 .01472 m
.32696 .02097 L
s
[(2)] .32696 .00222 0 1 Mshowa
.47854 .01472 m
.47854 .02097 L
s
[(3)] .47854 .00222 0 1 Mshowa
.63011 .01472 m
.63011 .02097 L
s
[(4)] .63011 .00222 0 1 Mshowa
.78169 .01472 m
.78169 .02097 L
s
[(5)] .78169 .00222 0 1 Mshowa
.93327 .01472 m
.93327 .02097 L
s
[(6)] .93327 .00222 0 1 Mshowa
.125 Mabswid
.05412 .01472 m
.05412 .01847 L
s
.08444 .01472 m
.08444 .01847 L
s
.11476 .01472 m
.11476 .01847 L
s
.14507 .01472 m
.14507 .01847 L
s
.2057 .01472 m
.2057 .01847 L
s
.23602 .01472 m
.23602 .01847 L
s
.26633 .01472 m
.26633 .01847 L
s
.29665 .01472 m
.29665 .01847 L
s
.35728 .01472 m
.35728 .01847 L
s
.38759 .01472 m
.38759 .01847 L
s
.41791 .01472 m
.41791 .01847 L
s
.44822 .01472 m
.44822 .01847 L
s
.50885 .01472 m
.50885 .01847 L
s
.53917 .01472 m
.53917 .01847 L
s
.56948 .01472 m
.56948 .01847 L
s
.5998 .01472 m
.5998 .01847 L
s
.66043 .01472 m
.66043 .01847 L
s
.69074 .01472 m
.69074 .01847 L
s
.72106 .01472 m
.72106 .01847 L
s
.75138 .01472 m
.75138 .01847 L
s
.81201 .01472 m
.81201 .01847 L
s
.84232 .01472 m
.84232 .01847 L
s
.87264 .01472 m
.87264 .01847 L
s
.90295 .01472 m
.90295 .01847 L
s
.96358 .01472 m
.96358 .01847 L
s
.9939 .01472 m
.9939 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(\\310) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(\\310) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -125.719 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.4375 translate 1 -1 scale
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(\\310) show
69.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.438 moveto
(\\310) show
81.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
93.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(for) show
117.188 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
129.188 13.438 moveto
(D) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
141.188 13.438 moveto
(\\220) show
147.188 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
159.188 9.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
164.438 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
170.438 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
176.438 13.438 moveto
(\\220) show
182.438 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
188.438 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60332 L
.02605 .60331 L
.02729 .6033 L
.02846 .60329 L
.03053 .60326 L
.03279 .60322 L
.03527 .60315 L
.0379 .60306 L
.04262 .60286 L
.04749 .6026 L
.05205 .60229 L
.06244 .60139 L
.07305 .60017 L
.08274 .59877 L
.10458 .59461 L
.12357 .58973 L
.14429 .58288 L
.16396 .57464 L
.18493 .56357 L
.20635 .54916 L
.22652 .5317 L
.24659 .50882 L
.26507 .47988 L
.2748 .4594 L
.28389 .43431 L
.28911 .41525 L
.29386 .39193 L
.29905 .34654 L
.30031 .3094 L
.30102 .31205 L
.30166 .31445 L
.30316 .31988 L
.30455 .32488 L
.31447 .35786 L
.32364 .38517 L
.3444 .43825 L
.36493 .48136 L
.38402 .51461 L
.40363 .54269 L
.42213 .56402 L
.44259 .58208 L
.45144 .58815 L
.46118 .59364 L
.4709 .59789 L
.47622 .59969 L
.48119 .60105 L
.48584 .60203 L
.49009 .60269 L
.49243 .60295 L
Mistroke
.49367 .60306 L
.49499 .60316 L
.49626 .60323 L
.4974 .60328 L
.49856 .60331 L
.49964 .60332 L
.50081 .60331 L
.50206 .60329 L
.50324 .60325 L
.50431 .6032 L
.50557 .60312 L
.50694 .60301 L
.50943 .60275 L
.51204 .60239 L
.5148 .60192 L
.51976 .60082 L
.52855 .59809 L
.53825 .59392 L
.54837 .58827 L
.55763 .58191 L
.5785 .56337 L
.59746 .54128 L
.61818 .51108 L
.63947 .47281 L
.65879 .43077 L
.67915 .37716 L
.68808 .34977 L
.69315 .33289 L
.69563 .32423 L
.69789 .31609 L
.699 .312 L
.7002 .33169 L
.70125 .3508 L
.7024 .36406 L
.70361 .37481 L
.70491 .38422 L
.70723 .39807 L
.71233 .42099 L
.71711 .4375 L
.72712 .46387 L
.73792 .4853 L
.75794 .5146 L
.77903 .53696 L
.79875 .55293 L
.81711 .56477 L
.83582 .57453 L
.85612 .58303 L
.87744 .59002 L
.89759 .59509 L
.91744 .5988 L
Mistroke
.92745 .60023 L
.93847 .60148 L
.94797 .60229 L
.95665 .60283 L
.96144 .60304 L
.96397 .60313 L
.96667 .6032 L
.968 .60323 L
.96926 .60326 L
.97048 .60328 L
.97161 .60329 L
.97268 .6033 L
.97381 .60331 L
.97494 .60332 L
.97619 .60332 L
Mfstroke
.02381 .60332 m
.02499 .6033 L
.02605 .60326 L
.02729 .60318 L
.02846 .60307 L
.03053 .6028 L
.03279 .60239 L
.03527 .60181 L
.0379 .60103 L
.04262 .59924 L
.04749 .59686 L
.05205 .59414 L
.06244 .58618 L
.07305 .57554 L
.08274 .56363 L
.10458 .52932 L
.14429 .4418 L
.18248 .32972 L
.22313 .18323 L
.24192 .10578 L
.25181 .06206 L
.25721 .03711 L
.25985 .02461 L
.261 .01908 L
.26226 .01642 L
.26357 .02287 L
.26482 .02904 L
.26757 .04285 L
.27341 .07336 L
.28367 .13266 L
.28875 .16654 L
.29153 .1874 L
.29415 .20947 L
.29875 .26283 L
.30003 .29335 L
.30074 .31102 L
.30139 .31343 L
.30384 .32233 L
.30853 .33861 L
.31367 .35535 L
.32402 .38625 L
.34253 .43389 L
.36333 .47829 L
.38251 .51219 L
.40238 .54107 L
.42097 .56283 L
.43974 .5799 L
.45033 .58744 L
.46038 .59323 L
.47008 .59758 L
Mistroke
.47521 .59938 L
.48066 .60092 L
.48571 .60201 L
.49028 .60271 L
.49249 .60296 L
.49365 .60306 L
.49488 .60315 L
.49595 .60321 L
.49713 .60327 L
.4982 .6033 L
.4992 .60331 L
.50047 .60332 L
.50111 .60331 L
.50181 .6033 L
.50306 .60326 L
.50422 .6032 L
.5056 .60312 L
.50685 .60302 L
.50968 .60272 L
.51199 .6024 L
.51451 .60197 L
.51959 .60086 L
.52425 .59955 L
.52922 .59784 L
.53816 .59397 L
.54843 .58823 L
.55955 .58045 L
.57971 .56211 L
.59963 .53843 L
.62068 .50698 L
.65862 .43118 L
.67811 .38017 L
.68896 .34689 L
.69374 .33085 L
.69646 .32127 L
.69779 .31644 L
.69901 .31193 L
.70017 .2862 L
.70138 .26062 L
.7026 .24351 L
.70394 .22821 L
.70917 .18192 L
.72023 .10904 L
.72526 .08057 L
.73065 .05198 L
.73326 .03865 L
.73572 .02633 L
.7368 .02103 L
.73794 .01547 L
.73919 .02001 L
Mistroke
.74034 .02554 L
.7782 .18845 L
.81851 .33294 L
.8573 .44589 L
.87702 .49267 L
.89854 .53485 L
.91915 .56611 L
.92834 .57707 L
.93827 .5868 L
.94361 .59111 L
.94852 .59451 L
.95312 .59719 L
.95816 .59958 L
.9627 .60122 L
.96693 .60233 L
.96927 .60277 L
.9714 .60305 L
.97258 .60317 L
.97386 .60326 L
.97507 .6033 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00C_ooool4o`000003oa0@4?oooooooooo02Kooooo1Ol0000Yooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0:oooool2o`000003oa0@4?oooooooooo02Sooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Xooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0<?ooool0053ooooo00?o0000
ooooooooool0:?ooool01OnHV9So8B4Qonk^k_ooooooA4A402Wooooo00Go410@okZj^_ooooooMgMg
oc8b<P0/ooooo`03o`000?oooooooooo02cooooo00?oMgMgoc8b<_ooool09oooool01OmEEEGoMgMg
oooooonHV9So8B4Q033ooooo001@ooooo`03o`000?oooooooooo02Wooooo00?oV9RHob4Q8Oo^k^h0
;_ooool00ol0003oooooooooo`0Wooooo`Go0000;_ooool00ol0003oooooooooo`0Vooooo`05o`00
0?ooooooooooooooool00000<?ooool0053ooooo00?o0000ooooooooool0:_ooool00onHV9So8B4Q
onk^kP0/ooooo`03ojVYZOl@413ooooo02Sooooo00CoA4A4omgMgOoooooo0000;_ooool00omgMgOo
<S8booooo`0Wooooo`05o`000?nHV9SooooooiRHV?lQ8B40<?ooool0053ooooo00?o0000oooooooo
ool0:oooool00omgMgOoIVIVooooo`0Zooooo`03oa0@4?l0003o^[Zj02Wooooo00CogMgMoeEEEOoo
oooo0000:oooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Sooooo00Go0000oeEEEOl0003o410@olc<
c00`ooooo`00D?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02[ooooo00?o^[Zj
ob4Q8Oooool0:Oooool00omgMgOoc<c<o`00000[ooooo`03o`000?oooooooooo02[ooooo00?oEEEE
ohN7Qoooool0<_ooool0053ooooo00?o0000ooooooooool0:?ooool01Ol0003o^[ZjoooooonHV9So
410@02Wooooo00Go410@oiRHV?oooooo^[Zjo`00000Zooooo`03onk^k_m4A4Co000002_ooooo00?o
0000ooooooooool0:_ooool00ooMgMgo410@oiRHV00booooo`00C_ooool00omEEEGoIVIVo`00000Z
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0:Oooool01OnYZJWo410@o`000?l@413oZJVY02_ooooo
00?oMgMgo`000?ooool0:_ooool4o`0002[ooooo00Coc<c<odA4A?l0003o410@<?ooool00?oooooo
JOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
oooooc?ooooo0_l00002ooooo`03oa0@4?l0003o000000_ooooo000Qooooo`03o`000?oooooooooo
0?oooooo=?ooool01Ol0003oooooonk^k_lb<S;oc<c<00cooooo000Qooooo`03o`000?oooooooooo
0?oooooo=?ooool01?l0003oV9RHoc8b<_o<c<`=ooooo`006_ooooooo`0003?o00002oooool00ol0
003o410@oiRHV00>ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo0_l00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00_ooooo00Co0000onk^k_mEEEGoQhN73Oooool0027ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01kooooo00Go0000oooo
oom4A4Co0000oa0@400<ooooo`008Oooool00ol0003oooooooooo`15ooooo`;o0000T?ooool2o`00
05[ooooo00?o0000ooooooooool03_ooool0027ooooo00?o0000ooooooooool0AOooool2o`0008oo
oooo00?o0000ooooool00000F_ooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooo000008kooooo00?o0000ooooool00000FOooool2o`00013ooooo
000Qooooo`03o`000?oooooooooo04Gooooo00?o0000ooooool00000S_ooool01?l0003ooooooooo
ool0001Zooooo`008Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooo000008kooooo00Co
0000oooooooooooo0000J_ooool0027ooooo00?o0000ooooooooool0AOooool01?l0003ooooooooo
ool0002=ooooo`04o`000?ooooooooooo`0006[ooooo000Qooooo`?o0000AOooool01?l0003ooooo
ooooool0002=ooooo`04o`000?ooooooooooo`0006[ooooo000Qooooo`03o`000?oooooooooo04Co
oooo00Go0000ooooooooooooooooo`00002<ooooo`05o`000?ooooooooooooooool00000J_ooool0
027ooooo00?o0000ooooooooool0A?ooool01Ol0003ooooooooooooooooo000008cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Wooooo`008Oooool00ol0003oooooooooo`14oooo
o`05o`000?ooooooooooooooool00000S?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo06Oooooo000Qooooo`03o`000?oooooooooo04Cooooo00Go0000ooooooooooooooooo`00002<
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Ioooool0027ooooo00?o0000oooo
ooooool0@oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Wooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Wooooo`008Oooool00ol0003oooooooooo`13ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo06Kooooo000Qooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
I_ooool0027ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo08Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Vooooo`008Oooool3
o`0004;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`28ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0I_ooool0027ooooo00?o0000ooooooooool0@_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Vooooo`008Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Go
oooo000Qooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`26ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0IOooool0027ooooo00?o
0000ooooooooool0@Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`1Uooooo`008Oooool00ol0003oooooooooo`11
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo06Gooooo000Qooooo`03o`000?oooooooooo047ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0I?ooool0027ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo08Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Tooooo`00
8Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
Q?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06Cooooo000Qooooo`?o0000@?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`1Tooooo`008Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo06Cooooo000Qooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`24ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Hoooool0027o
oooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo08?o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Sooooo`008Oooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Poooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo06?ooooo000Qooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0Hoooool0027ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1S
ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0P_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06;ooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`21ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0H_ooool000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0000nooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0POooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06;ooooo0007
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`21ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0H_ooool000Oooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`1Qooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0P?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo067ooooo0007ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0
?Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`1Qooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0HOooool0027ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Qooooo`008Ooo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Oooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo063ooooo000Qooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1nooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0H?ooool0027ooooo0ol0000looooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
063ooooo000Qooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0H?ooool0027ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo07kooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`008Oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0O_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo05oooooo000Qooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0Goooool0027ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo07cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Ooooo
o`008Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0O?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo05oooooo000Qooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1looooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0G_ooool0027ooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`1Nooooo`008Oooool3o`0003Wooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`1looooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0G_ooool0
027ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
07cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Nooooo`008Oooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0O?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo05gooooo000Qooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0GOooool0027ooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`1Mooooo`008Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0N_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05cooooo000Qoooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1joooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G?ooool0027ooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo07[ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`1Looooo`008Oooool00ol0003oooooooooo`0gooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo05cooooo000Qooooo`?o0000=oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo07[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Kooooo`008Oooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0N_ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo05_ooooo000Qooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0Foooool0027ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`1Kooooo`008Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo05[ooooo
000Qooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`1hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0F_ooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo07Sooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`1Jooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`1Iooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
0005ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`1hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0FOooool000Oooooo00Go0000
ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo0ol0000eooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo05Wooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEE
ooooool00006ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`1hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0FOooool000Oooooo
00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo07Sooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`1Hooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?ok^k^odA4A?l000001_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05So
oooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1hooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0F?ooool0027ooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`1Hooooo`008Oooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo05Oooooo000Qooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`1hooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Eoooool0
027ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
07Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Gooooo`008Oooool3o`0003;o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0E_ooool0027ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`1Fooooo`008Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0M_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05Kooooo000Q
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1f
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0E_ooool0027ooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo07Kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`1Eooooo`008Oooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo05Gooooo000Qooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
EOooool0027ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo07Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Eooooo`008Oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0M_ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo05Cooooo000Qooooo`?o0000<?ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`1Dooooo`008Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo05Co
oooo000Qooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`1fooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Doooool0027ooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0Pooooo`;o0000Moooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo05?ooooo000Qooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool08?ooool2o`0007Kooooo0_l0000Rooooo`03o`000?oooooooooo05?ooooo000Qoooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool08Oooool2o`0007Kooooo0_l0000Roooo
o`03o`000?oooooooooo05?ooooo000Qooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool08?ooool00ol0003oooooo`00001eooooo`03o`000?oooooo000002?ooooo00?o0000oooooooo
ool0D_ooool0027ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Pooooo`04o`00
0?oooooo0000o`0007Cooooo00?o0000ooooool000008oooool00ol0003oooooooooo`1Booooo`00
8Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo
0000M?ooool00ol0003oooooo`00000Sooooo`03o`000?oooooooooo05;ooooo000Qooooo`?o0000
;Oooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0007?ooooo0_l000000ooooooo
0000ooooo`0Sooooo`03o`000?oooooooooo057ooooo000Qooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool08Oooool01?l0003oooooooooool0001cooooo`04o`000?ooooooooooo`00
02Cooooo00?o0000ooooooooool0DOooool0027ooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`0Rooooo`05o`000?ooooooooooooooool00000L_ooool01Ol0003ooooooooooooooooo
000002?ooooo00?o0000ooooooooool0DOooool0027ooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0Rooooo`05o`000?ooooooooooooooool00000L_ooool01Ol0003ooooooooooooo
oooo000002Cooooo00?o0000ooooooooool0D?ooool0027ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0Rooooo`05o`000?ooooooooooooooool00000L_ooool01Ol0003ooooooooo
oooooooo000002Cooooo00?o0000ooooooooool0D?ooool0027ooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0D?oo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`00
0?l@413oc<c<00Gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool0Coooool000Oooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Gooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00;ooooo0_l0001_ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1?ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo06cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo04oooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003oV9RHoooooonHV9So8B4Q00Gooooo0ol0000Zooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`1>ooooo`001oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go0000oeEEEOl0003o410@olc<c005ooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`04ooooo`;o0000KOooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0C_ooool000Oooooo00Go410@
oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Oooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0J_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0C_oo
ool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Oooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0J_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0COooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4
A4Co0000oa0@40Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo00Gooooo0_l0001[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1=ooooo`008Oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Xooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1=ooooo`008Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1<ooooo`008Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1<ooooo`008Oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1Vooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1;ooooo`008Oooool3o`0002Oooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo04_ooooo000Qooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo06Gooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo04_ooooo000Q
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo04[ooooo000Qooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`09ooooo`;o0000IOooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0B_ooool0027ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0H_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0B_ooool0027ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0BOooool0027ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0HOoo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0BOoo
ool0027ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool0BOooool0027ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo00cooooo0_l0001Qooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`18ooooo`008Oooool3o`0002Co
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05oo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04So
oooo000Qooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo04Sooooo000Qooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0>ooooo`;o0000Goooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Aoooool0027ooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0G?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0Aoooool0027ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo013ooooo0_l0001Mooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`17ooooo`008Oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Jooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`16ooooo`00
8Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
4Oooool2o`0005_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo04Kooooo000Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04Gooooo000Qooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Cooooo`;o0000FOooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0AOooool0
027ooooo0ol0000Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`1Fooooo`;o00005_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
04Gooooo000Qooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo04Cooooo000Qooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Eooooo`;o0000E_ooool2o`0001Sooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`14ooooo`008Oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1Dooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`13ooooo`008Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool05oooool2o`0005Cooooo0_l0000Jooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0@oooool0027ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0DOooool2o`0001_ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`13ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06Oooool2o`0005;ooooo0_l0000L
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0@_ooool000Oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Gooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0Coooool2o`0001gooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`12ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooooooo
o`000005ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0Kooooo`;o0000D?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool0@Oooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b
<_nHV9SooooooiRHV?lb<S801Oooool3o`0001cooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo04gooooo0_l0000Oooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0@Oooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05
olc<c?l0003o0000o`000?o<c<`01Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`11ooooo`001oooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4005ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo043ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj
^[[o000000Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0@?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01Oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool08_ooool2o`0004[ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03oooooo000Qooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo03oooooo000Qooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03kooooo000Qooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
04Gooooo0_l0000Xooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0?_ooool0027o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0?Oooool0027ooooo0ol0000Hooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0looooo`008Oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`11ooooo`;o0000;?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03cooooo000Q
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo03_ooooo000Qooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0]ooooo`;o0000@?ooool2o`0002oooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0kooooo`008Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`00
8Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo027ooooo0_l0000cooooo`03o`00
0?oooooooooo03cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo03[ooooo000Qooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0cooooo`;o0000??ooool2o`0003Cooooo0_l0000Sooooo`03o`000?oo
oooooooo03Wooooo000Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0eooooo`;o0000>oooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0>Oooool0027ooooo0ol0000Dooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0hooooo`;o0000>?ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo03Sooooo000Qooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03Ko
oooo0_l0000jooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0=oooool0027ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Oooooo`;o0000?Oooool00ol0003ooooo
ooooo`0dooooo`;o0000??ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo03;ooooo0_l0000nooooo`;o00008?ooool00ol0003ooooooooo
o`0fooooo`008Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01gooooo0_l00011
ooooo`;o0000<_ooool2o`00047ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0e
ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0@_ooool2o`00033ooooo0_l00013ooooo`;o00007_ooool00ol0003oooooooooo`0eoooo
o`008Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo0_l00016ooooo`;o
0000;_ooool2o`0004Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0dooooo`00
8Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo0_l0001:ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0Aoooool2o`0001gooooo00?o0000ooooooooool0
<oooool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1:ooooo`;o00007?oo
ool00ol0003oooooooooo`0booooo`008Oooool3o`0000gooooo00?o0000ooooooooool06Oooool2
o`0004oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1=ooooo`;o00006oooool0
0ol0003oooooooooo`0aooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
01Sooooo0_l0001Booooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D?ooool3o`00
01Wooooo00?o0000ooooooooool0<?ooool0027ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Fooooo`?o0000EOooool00ol0003oooooooooo`0Qooooo`;o0000E_ooool3o`0001Oo
oooo00?o0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Dooooo`?o0000FOooool2o`00023ooooo0_l0001Jooooo`?o00005Oooool00ol0003ooooo
ooooo`0^ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01;ooooo0ol0
001Mooooo`;o00007_ooool00ol0003oooooooooo`1Mooooo`?o00004oooool00ol0003ooooooooo
o`0]ooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo0ol0001Q
ooooo`Co00006Oooool2o`0006?ooooo0ol0000Aooooo`03o`000?oooooooooo02cooooo000Qoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool3o`0006Oooooo0ol0000Foooo
o`03o`000?oooooooooo06Kooooo0ol0000?ooooo`03o`000?oooooooooo02_ooooo000Hooooo`Co
000000?o410@ooooooooool00_ooool00ol0003oooooooooo`04ooooo`?o00003?ooool5o`0006co
oooo0_l0000Cooooo`;o0000K?ooool5o`0000_ooooo00?o0000ooooooooool0:_ooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo
2?l0001booooo`Co00003?ooool4o`0007?ooooo2?l00004ooooo`?o0000:Oooool001[ooooo00?o
0000ooooooooool01?ooool>o`0007kooooo3Ol0001nooooo`co00009?ooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooo
oom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00J?ooool00ol0003oooooooooo`03ooooo`04ob4Q8Ol0003o0000oiRHV0Gooooo00?o
0000ooooooooool00oooool00ol0003o^[Zjooooo`0Xooooo`05oeEEEOnHV9Soooooooooooo<c<`0
0_l000000onHV9Soooooooooo`2fooooo`00J?ooool00ol0003oooooooooo`05ooooo`03okZj^_l0
003ooooo00Cooooo00?o0000ooooooooool00oooool2oc8b<R[ooooo00GoEEEEoiRHV?ooooooEEEE
ohN7Q`0Jooooo`03ob4Q8OoMgMgooooo02Wooooo00?o8B4QomgMgOooool0LOooool006Sooooo00?o
0000ooooooooool00_ooool01OnHV9So410@o`000?l0003oV9RH00Gooooo00?o0000ooooooooool0
0oooool00on7QhOo0000okZj^P0;ooooo`03oa0@4?l0003o000000;o000000Go410@oooooooooooo
k^k^oeEEE@02o`000004oeEEEOo^k^kooooooa0@40Go00002Oooool01Oo^k^ko<S8bolc<c?lQ8B7o
c<c<00Wooooo00?o<S8bo`000?l000000ol000001Olb<S;oooooooooooooooooV9RH00;o000000Ko
A4A4okZj^_oooooooooooiRHV?mEEED3ooooo`03oc8b<_l0003o000000?o000000?o<S8boooooooo
ool00_l00002ooooo`;o00004?ooool4o`000006oa0@4?oooooooooooooooonHV9SoEEEE1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM06Sooooo001Xooooo`03o`000?oooooooooo00;ooooo00?o0000
ojVYZOooool01oooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00gooooo00?o0000
ooooooooool00oooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@?ooooo00?o0000ooooooooool0
2oooool00oo^k^ko<S8bo`00000:ooooo`03oiRHV?m4A4Cooooo00;ooooo00?oA4A4oiRHV?ooool0
0_ooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00Ko0000omgMgOoooooooooooiRHV?m4A4@3
ooooo`0:odA4A?nHV9Soooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@Sooooo1_l00004oooo
o`03o`000?oooooooooo00Cooooo00?o0000omgMgOooool01_ooool00omgMgOo<S8booooo`1Woooo
o`006_ooool00ol0003oooooooooo`03ooooo`04ob4Q8Ol0003o0000oiRHV0Gooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`02ooooo`03o`000?o^k^kooooo00Oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ojVYZOl@413ok^k^00[ooooo00Go410@omgMgOoooooogMgMoa0@
4004ooooo`03o`000?oooooooooo00Gooooo0_mgMgL3ooooo`05oa0@4?oMgMgoooooomgMgOl@4100
1?ooool01?oMgMgo0000oa0@4?o<c<`Cooooo`03o`000?oooooooooo00Cooooo0_mgMgL8ooooo`03
o`000?oooooooooo06Kooooo000Jooooo`03o`000?oooooooooo00Gooooo00?o^[Zjo`000?ooool0
1?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00;ooooo00?oV9RHodA4A?oMgMd0
1oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000kooooo00CoMgMgodA4A?lb<S;ok^k^2Oooool01On7
QhOoMgMgoooooomVIVKoQhN700Cooooo00?o0000ooooooooool01Oooool00oo^k^ko410@onk^kP02
ooooo`05ohN7QomgMgOoooooofIVI_n7QhL01?ooool01?o^k^ko8B4Qoa0@4?o^k^h9ooooo`Ko0000
1?ooool00ol0003oooooooooo`04ooooo`03onk^k_l@413ok^k^00Kooooo00?oMgMgoc8b<_ooool0
Ioooool001[ooooo00?o0000ooooooooool00_ooool01OnHV9So410@o`000?l0003oV9RH00Gooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`03ooooo`03oiRHV?l0003o000000Kooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`06oeEEEOmgMgOooooooooooomg
MgOoEEEE0oooool00ol0003o<S8bomgMg@0<ooooo`04oc8b<_nYZJWoV9RHoeEEE@Wooooo00Gok^k^
oa0@4?o^k^ko410@onk^kP04ooooo`03o`000?oooooooooo00Kooooo00WoEEEEoiRHV?oooooooooo
onk^k_l@413ok^k^oa0@4?o^k^h01?ooool01?lQ8B7oMgMgogMgMolb<S8Cooooo`03o`000?oooooo
oooo00Gooooo00?oEEEEoiRHV?ooool00_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<06Sooooo000J
ooooo`03o`000?oooooooooo00;ooooo00?o0000ojVYZOooool01oooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo00?ooooo00?o0000olc<c?ooool01_ooool00ol0003oooooooooo`0A
ooooo`03oa0@4?l0003o000000?o00000_ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kP;ooooo
0_l000001?nYZJWo8B4Qo`000?lQ8B48ooooo`07oc8b<_l0003o8B4Qonk^k_ooooooV9RHoeEEE@09
ooooo`03ogMgMolQ8B7oEEEE00?ooooo00?o410@o`000?l000000ol00005ooooo`03omgMgOl@413o
oooo00;ooooo00?oMgMgob4Q8OmEEED01?ooool2o`0000;ooooo1_l0000>ooooo`03o`000?oooooo
oooo00Gooooo00?ogMgMoa0@4?ooool00_ooool00ol0003oooooooooo`1Zooooo`006_ooool00ol0
003oooooooooo`02ooooo`03o`000?o^k^kooooo00Oooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`03ooooo`05oa0@4?n7QhOoooooonk^k_mVIVH01?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo02Wooooo00?ogMgMo`000?oMgMd01Oooool00ol0003oooooooooo`07
ooooo`07oeEEEOnHV9SooooooooooooMgMgo0000omgMg@0;ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool01_ooool01OmEEEGoV9RHoooooooooooo000006cooooo000Jooooo`03o`00
0?oooooooooo00;ooooo00?oV9RHodA4A?oMgMd01oooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo00?ooooo00Goc<c<odA4A?l0003o0000oiRHV004ooooo`03o`000?oooooooooo01?o
oooo00?o410@okZj^_ooool0:_ooool00onYZJWoooooooooo`04ooooo`03o`000?oooooooooo00Oo
oooo00?o^[ZjodA4A?ooool00_ooool00onYZJWoooooooooo`0;ooooo`03o`000?oooooooooo00_o
oooo00?oEEEEofIVI_l000002?ooool01?nj^[[oA4A4ooooooooool4o`0006Wooooo000Jooooo`03
o`000?oooooooooo00?ooooo00?oV9RHo`000?l000001_ooool00ol0003oooooooooo`1Qooooo`04
okZj^_l@413o0000oa0@44kooooo00?o0000ooooooooool0Q_ooool001[ooooo00?o0000oooooooo
ool00oooool00ol0003oc<c<ooooo`06ooooo`03o`000?oooooooooo0;3ooooo00Co0000oooooooo
oooo0000R?ooool001[ooooo00?o0000ooooooooool00oooool01Ol@413oQhN7ooooooo^k^koIVIV
00Cooooo00?o0000ooooooooool0/Oooool2o`0008Wooooo000Jooooo`03o`000?oooooooooo00?o
oooo00Goc<c<odA4A?l0003o0000oiRHV004ooooo`03o`000?oooooooooo0?oooooo?Oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.736113, -0.0840035, \
0.0270832, 0.00697441}}]
}, Open  ]],

Cell[TextData[{
  "For this value of \[Delta], one can see that the solution is stable since \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(\[Xi]\)\(|\)\(\(\[LessEqual]\)\(\ \)\(1\)\)\
\)\)]],
  ".  In fact, by varying the value of \[Delta], one finds that the maximum \
possible value of \[Delta] is ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(1/4\)\)\)]],
  ".  Thus, the Courant condition for Eq. ",
  ButtonBox["(6.2.12)",
    ButtonData:>{"Chapter6.nb", "(6.2.12)"},
    ButtonStyle->"Hyperlink"],
  " is "
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[Chi]", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], "/", 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], "2"]}]}], "\[LessEqual]", 
        " ", \(1/4. \)}], TraditionalForm]]]], "NE2",
  CellTags->"(6.2.13)"],

Cell[TextData[{
  "\tThe Lax modification to the CTCS method has improved matters over the \
original FTCS method: the new method is now second-order accurate in both \
time and space. However,  the Courant condition of Eq. ",
  ButtonBox["(6.2.13)",
    ButtonData:>"(6.2.13)",
    ButtonStyle->"Hyperlink"],
  "  is still a rather stringent criterion for ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", making this method impractical for real-world problems. It would be \
better if we could find a method that loosens this condition. One such method \
is discussed below."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Implicit methods. The Crank-Nicolson algorithm.", "Section",
  CellTags->{"i:22", "c:19"}],

Cell[TextData[{
  "Problems that exhibit diffusive behavior, such as the heat equation,  are \
often best treated by ",
  StyleBox["implicit",
    FontSlant->"Italic"],
  " methods. As an example of an implicit method, take the FTCS method \
applied to the heat equation, Eq. ",
  ButtonBox["(6.2.5)",
    ButtonData:>"(6.2.5)",
    ButtonStyle->"Hyperlink"],
  ", and replace the forward-differenced time derivative with a ",
  "backward-difference",
  ",\n",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(\[PartialD]T/\[PartialD]t\)\( | \_\(t\_n\)\)\), "\[Rule]",
           " ", 
          RowBox[{\((T\_j\%n - T\_j\%\(n - 1\))\), "/", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  " . Then the heat equation becomes"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\_j\%n - T\_j\%\(n - 1\)\), "=", 
          RowBox[{
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], " ", \(S\_j\%n\)}], "+", 
            RowBox[{
              FractionBox[
                RowBox[{"\[Chi]", " ", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]]}], 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], "2"]], \((T\_\(j + 1\)\%n - 
                  2  T\_j\%n + T\_\(j - 1\)\%n)\)}]}]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.14)"],

Cell[TextData[{
  "This algorithm could be called the BTCS (backward time centered space) \
method, but instead it is referred to as an ",
  StyleBox["implicit",
    FontSlant->"Italic"],
  " method. The reason is that Eq. ",
  ButtonBox["(6.2.14)",
    ButtonData:>"(6.2.14)",
    ButtonStyle->"Hyperlink"],
  " does not explicitly provide ",
  Cell[BoxData[
      \(TraditionalForm\`T\_j\%n\)]],
  ", given ",
  Cell[BoxData[
      \(TraditionalForm\`T\_j\%\(n - 1\)\)]],
  ". Rather, since ",
  Cell[BoxData[
      \(TraditionalForm\`T\_j\%n\)]],
  " now appears on both sides of Eq. ",
  ButtonBox["(6.2.14)",
    ButtonData:>"(6.2.14)",
    ButtonStyle->"Hyperlink"],
  ", it provides a set of coupled linear equations for ",
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            \(TraditionalForm\`T\_j\%n\)]]]], TraditionalForm]]],
  "which we must solve. This is as opposed to previous methods such as FTCS, \
where ",
  Cell[BoxData[
      \(TraditionalForm\`T\_j\%n\)]],
  "is given explicitly without needing to solve any equations. These previous \
methods are called ",
  StyleBox["explicit ",
    FontSlant->"Italic"],
  " methods."
}], "Text",
  CellTags->"i:25"],

Cell[TextData[{
  "\tThe added complexity of Eq. ",
  ButtonBox["(6.2.14)",
    ButtonData:>"(6.2.14)",
    ButtonStyle->"Hyperlink"],
  "  is offset by its superior stability properties. Von Neumann stability \
analysis applied to Eq. ",
  ButtonBox["(6.2.14)",
    ButtonData:>"(6.2.14)",
    ButtonStyle->"Hyperlink"],
  " yields the following amplification factor:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Xi]", "=", 
          SuperscriptBox[
            RowBox[{"[", 
              RowBox[{"1", "+", 
                RowBox[{"4", " ", "\[Delta]", " ", 
                  RowBox[{\(sin\^2\), "(", 
                    RowBox[{"k", " ", 
                      RowBox[{
                        StyleBox[
                          RowBox[{"\[CapitalDelta]", 
                            StyleBox["x",
                              FontSlant->"Italic"]}]], "/", "2"}]}], 
                    ")"}]}]}], "]"}], \(-1\)]}], TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(6.2.15)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Delta]\)\(=\)\)\)]],
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Chi]", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], "/", 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], "2"]}]}], TraditionalForm]]],
  ".  Thus, |",
  Cell[BoxData[
      \(TraditionalForm\`\[Xi] | \(\(\[LessEqual]\)\(\ \)\(1\)\)\)]],
  " for any value of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\)]],
  ". This method is stable for ",
  StyleBox["any",
    FontSlant->"Italic"],
  " choice of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tHowever, the method is still only first-order accurate in ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", because of the backward time difference. A second-order method can now \
be easily obtained by taking the average of the ",
  "right-hand",
  " side in Eq. ",
  ButtonBox["(6.2.14)",
    ButtonData:>"(6.2.14)",
    ButtonStyle->"Hyperlink"],
  " between time steps ",
  Cell[BoxData[
      \(TraditionalForm\`n - 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\_j\%n - T\_j\%\(n - 1\)\), "=", 
          RowBox[{\(1\/2\), "[", 
            RowBox[{
              RowBox[{
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]], 
                " ", \((S\_j\%n + S\_j\%\(n - 1\))\)}], "+", 
              RowBox[{
                FractionBox[
                  RowBox[{"\[Chi]", " ", 
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["t",
                          FontSlant->"Italic"]}]]}], 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["x",
                          FontSlant->"Italic"]}]], 
                    "2"]], \((T\_\(j + 1\)\%n - 2  T\_j\%n + 
                    T\_\(j - 1\)\%n + T\_\(j + 1\)\%\(n - 1\) - 
                    2  T\_j\%\(n - 1\) + T\_\(j - 1\)\%\(n - 1\))\)}]}], 
            "]"}]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.16)"],

Cell[TextData[{
  "Now the right-hand and left-hand sides are both centered at time step ",
  Cell[BoxData[
      \(TraditionalForm\`n - 1/2\)]],
  ", so the time derivative is now second-order accurate in ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ".  Equation ",
  ButtonBox["(6.2.16)",
    ButtonData:>"(6.2.16)",
    ButtonStyle->"Hyperlink"],
  " is called the",
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox[ButtonBox["Crank",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Crank.html"]\
, None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[" -",
    FontSlant->"Italic"],
  StyleBox[ButtonBox["Nicolson",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Nicolson.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  " scheme.  ",
  "Von",
  " Neumann analysis of this equation leads to the following amplification \
factor:"
}], "Text",
  CellTags->"i:23"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Xi]", "=", 
          FractionBox[
            RowBox[{"1", "-", 
              RowBox[{"2", " ", "\[Delta]", " ", 
                RowBox[{\(sin\^2\), "(", 
                  RowBox[{"k", " ", 
                    RowBox[{
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]], "/", "2"}]}], ")"}]}]}], 
            
            RowBox[{"1", "+", 
              RowBox[{"2", " ", "\[Delta]", " ", 
                RowBox[{\(sin\^2\), "(", 
                  RowBox[{"k", " ", 
                    RowBox[{
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]], "/", "2"}]}], 
                  ")"}]}]}]]}], TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(6.2.17)"],

Cell[TextData[{
  "which also exhibits stability for any choice of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ". The Crank-Nicolson method is an implicit scheme  that is very useful for \
solving linear problems with diffusive behavior. Below, we implement the \
Crank-",
  "Nicolson",
  " scheme in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  "
}], "Text"],

Cell["\tFirst, we choose values for the parameters:", "Text"],

Cell[BoxData[{
    \(\(Clear["\<Global`*\>"];\)\), "\n", 
    \(L = 1; 
    M = 10; \[CapitalDelta]t = 0.05; \[CapitalDelta]x = L/M; \[Chi]\  = \ 
      1/4;\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.60"],

Cell[TextData[{
  "Note the large time step size relative to the Courant condition for the \
FTCS  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], "\[LessEqual]", " ", "0.02"}], 
          ")"}], TraditionalForm]]],
  "or the CTCS-Lax ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], "\[LessEqual]", " ", "0.01"}], 
          ")"}], TraditionalForm]]],
  " method. "
}], "Text"],

Cell["\<\
\tNext, we choose initial and boundary conditions, and a source \
term:\
\>", "Text"],

Cell[BoxData[{
    \(\(T0[x_]\  = \ Sin[Pi\ x/L]\  // N;\)\), "\n", 
    \(\(T[0, n_]\  := 0;\)\), "\n", 
    \(\(T[M, n_]\  := \ 0;\)\), "\n", 
    \(\(S[j_, n_]\  = \ 0;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.61"],

Cell["\<\
These initial and boundary conditions correspond to a single \
Fourier mode, which should decay away according to\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`T(x, 
          t)\  = \ \(\[ExponentialE]\^\(\(-\[Chi]\)\ \(\[Pi]\^2\) 
                t/\ L\^2\)\) sin\ \((\[Pi]\ x/L)\)\)]],
  "."
}], "NE2",
  CellTags->"(6.2.18)"],

Cell[TextData[{
  "Now we solve Eq. ",
  ButtonBox["(6.2.16)",
    ButtonData:>"(6.2.16)",
    ButtonStyle->"Hyperlink"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`T\_j\%n\)]],
  ". This equation couples the different ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " values together, so we need to solve a set of linear equations. This can \
be easily done using ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", particularly since the equations are \"sparse\" (most elements are \
zero), and the method of ",
  StyleBox["Gaussian elimination",
    FontSlant->"Italic"],
  " can be employed. (These details need not concern us; ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " takes care of them.  Those who wish to learn about Gaussian elimination \
and sparse-matrix solution techniques are referred to ",
  ButtonBox["Press et. al. (1992)",
    ButtonData:>{"Chapter1.nb", "refs"},
    ButtonStyle->"Hyperlink"],
  ", or any other book on basic numerical techniques.]"
}], "Text"],

Cell[TextData[{
  "\t  Since the output of ",
  StyleBox["Solve ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a list of substitutions, it is more convenient to write the recursion \
relation in terms of  this list of substitutions rather than ",
  Cell[BoxData[
      \(TraditionalForm\`T\_j\%n\)]],
  " itself .  To this end, we define  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"sol", "[", 
          StyleBox["n",
            FontSlant->"Plain"], "]"}], TraditionalForm]],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "as this list of substitutions for the solution at time step ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  StyleBox[". ",
    FontWeight->"Bold"],
  "For instance, the initial condition is given by the following list:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol[0]\  = \ 
      Table[T[j, 0] \[Rule] \ T0[j\ \[CapitalDelta]x], {j, 1, 
          M - 1}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.62"],

Cell[BoxData[
    \({T[1, 0] \[Rule] 0.30901699437494745`, 
      T[2, 0] \[Rule] 0.5877852522924731`, 
      T[3, 0] \[Rule] 0.8090169943749475`, 
      T[4, 0] \[Rule] 0.9510565162951535`, T[5, 0] \[Rule] 1.`, 
      T[6, 0] \[Rule] 0.9510565162951536`, 
      T[7, 0] \[Rule] 0.8090169943749475`, 
      T[8, 0] \[Rule] 0.5877852522924732`, 
      T[9, 0] \[Rule] 0.30901699437494756`}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Note that we need not add the end points to the list, since they are \
already determined by the boundary conditions. We can then write the \
Crank-Nicolson method as the following recursion relation on ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["sol",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["n",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{\(sol[n_]\), " ", ":=", " ", 
      RowBox[{\(sol[n]\), " ", "=", " ", "\[IndentingNewLine]", 
        RowBox[{"Module", "[", 
          RowBox[{\({vars, eqns}\), ",", "\[IndentingNewLine]", 
            StyleBox[\( (*define\ the\ variables*) \),
              FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", " ", 
            
            RowBox[{\(vars = \ Table[T[j, n], {j, 1, M - 1}]\), ";", " ", 
              "\[IndentingNewLine]", 
              
              StyleBox[\( (*define\ the\ equations\ \((Eqs . \ 6  .2  .16)\), 
                  substituting\ for\ the\ values\ of\ T\ determined\ at\ the\ \
last\ time\ step\ \ *) \),
                FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
              RowBox[{"eqns", "=", " ", 
                
                RowBox[{\(Table[
                    T[j, n] - 
                        T[j, n - 
                            1]\  == \(1\/2\) \((\[CapitalDelta]t\ \((S[j, 
                                    n] + S[j, 
                                    n - 1])\) + \(\(\[Chi]\ \
\[CapitalDelta]t\)\/\[CapitalDelta]x\^2\) \((T[j + 1, n] - 2  T[j, n] + 
                                  T[j - 1, n] + T[j + 1, n - 1] - 
                                  2  T[j, n - 1] + T[j - 1, n - 1])\))\), {j, 
                      1, M - 1}]\), 
                  StyleBox["/.",
                    FontColor->RGBColor[0, 0, 1]], 
                  StyleBox[\(sol[n - 1]\),
                    FontColor->RGBColor[0, 0, 1]]}]}], ";", 
              "\[IndentingNewLine]", 
              StyleBox[
                RowBox[{"(*", 
                  RowBox[{
                  "solve", " ", "the", " ", "equations", " ", Cell[""]}], 
                  "*)"}],
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(\(Solve[eqns, vars]\)[\([1]\)]\)}]}], 
          "]"}]}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.63"],

Cell[TextData[{
  "The recursion comes about because ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["sol",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["n",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  " calls ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["sol",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[\(n - 1\),
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ";",
  StyleBox[" ",
    FontWeight->"Bold"],
  " see the substitution command (in blue) in the definition of ",
  StyleBox["eqns",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". We can now evaluate the solution and animate the result. In Cell ",
  ButtonBox["6.64",
    ButtonData:>"Cell 6.64",
    ButtonStyle->"Hyperlink"],
  " we compare this solution with the exact solution, Eq. ",
  ButtonBox["(6.2.18)",
    ButtonData:>"(6.2.18)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(CrankNicolson = \ 
        Table[ListPlot[
            Table[{\[CapitalDelta]x\ j, \ T[j, n]}, {j, 0, M}] /. sol[n], 
            PlotJoined \[Rule] True, PlotRange \[Rule] {{0, L}, {0, 1}}, 
            AxesLabel \[Rule] {"\<x\>", "\<\>"}, 
            PlotLabel \[Rule] "\<T[x,t],t=\>" <> 
                ToString[\[CapitalDelta]t\ n], 
            DisplayFunction \[Rule] Identity], {n, 0, 40, 5}];\)\), "\n", 
    \(\(exact\  = 
        Table[Plot[\(\[ExponentialE]\^\(\(-\[Pi]\^\(\(2\)\(\ \)\)\) \[Chi]\ t/
                      L\^2\)\) Sin[Pi\ x/L], {x, 0, L}, 
            DisplayFunction \[Rule] Identity, 
            PlotStyle \[Rule] RGBColor[1, 0, 0]], {t, 0, 
            40\ \[CapitalDelta]t, 5\ \[CapitalDelta]t}];\)\ \), "\n", 
    \(\(Table[
        Show[CrankNicolson[\([n]\)], exact[\([n]\)], 
          DisplayFunction \[Rule] $DisplayFunction], {n, 1, 
          Length[exact]}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.64"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -32 0 ]
[.5 .63053 32 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.1 .19098 L
.2 .36327 L
.3 .5 L
.4 .58779 L
.5 .61803 L
.6 .58779 L
.7 .5 L
.8 .36327 L
.9 .19098 L
1 0 L
s
1 0 0 r
0 0 m
.04057 .07855 L
.08481 .16272 L
.12636 .23895 L
.16632 .30843 L
.20885 .37703 L
.2498 .43673 L
.29331 .49226 L
.33524 .53707 L
.37557 .57141 L
.39599 .58533 L
.41848 .59788 L
.43982 .60702 L
.44937 .61023 L
.4598 .61311 L
.46545 .6144 L
.4707 .61542 L
.47614 .6163 L
.48106 .61694 L
.48591 .61743 L
.48813 .6176 L
.49048 .61776 L
.49299 .61788 L
.4941 .61793 L
.4953 .61797 L
.49658 .618 L
.49778 .61802 L
.49852 .61803 L
.49921 .61803 L
.50051 .61803 L
.50171 .61803 L
.503 .61801 L
.50421 .61798 L
.50533 .61795 L
.50792 .61784 L
.51065 .61769 L
.51331 .61749 L
.51579 .61727 L
.52142 .61664 L
.53077 .61515 L
.54076 .61297 L
.55151 .60996 L
.56317 .6059 L
.58433 .59647 L
.6273 .56927 L
.66867 .53328 L
.70845 .49018 L
.75081 .43591 L
.79157 .37638 L
.83491 .30636 L
Mistroke
.87666 .23353 L
.91682 .15967 L
.95955 .07832 L
1 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00D?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0<Oooool4o`000003oa0@4?oooooooooo01Gooooo001@ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00X
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B40:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<oooool00ol0003oooooooooo`0Gooooo`00D?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h0:Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Wooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002So
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<oooool0
0ol0003oooooooooo`0Gooooo`00D?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h0:?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
:?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Xoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03?ooooo00?o
0000ooooooooool05oooool0053ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002So
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0:?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00cooooo`03o`00
0?oooooooooo01Oooooo001@ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Vooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Xooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Zooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03?ooooo00?o0000ooooooooool05ooo
ool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000:?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000cooooo`03o`000?oooooooooo01Oooooo001@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<Oooool00omEEEGoIVIVo`00000Iooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Nooooo`03ool00?l0003o00000?oo0000;_l000000ooo003oooooooooo`09oooo
o`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03ool00?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ooo003oooooooooo`09ooooo`04ob4Q8OmgMgOoMgMgoc8b<P[ooooo000Noooo
o`03o`000?oo003ooooo03[ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>Oooool00ooo003o0000ooooo`09oooo
o`;o00000_ooool2o`0000Wooooo000Nooooo`03o`000?oo003ooooo0?oooooo;Oooool00ooo003o
ooooooooo`0Hooooo`007_ooool00ol0003oooooool0003oooooobcooooo00?oo`00ooooooooool0
6Oooool001kooooo00?o0000oooooooo0000ooooool/ooooo`03ool00?oooooooooo01Wooooo000N
ooooo`04o`000?ooooooooooool00?oooooo:_ooool00ooo003oooooooooo`0Jooooo`007_ooool0
1Ol0003oooooooooool0003oo`000?oooooo:Oooool00ooo003oooooooooo`0Jooooo`007_ooool0
1Ol0003oooooooooooooooooo`000?oooooo:?ooool00ooo003oooooooooo`0Kooooo`007_ooool0
0ol0003oooooooooo`02ooooo`03ool00?oooooooooo0?oooooo9?ooool00ol0003oo`00ooooo`0L
ooooo`007_ooool3o`0000;ooooo00?oo`00ooooooooool0oooooolTooooo`03ool00?oooooooooo
01cooooo000Nooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0oooooolRooooo`03
o`000?oo003ooooo01gooooo000Nooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0
oooooolRooooo`03ool00?oooooooooo01gooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o
o`00ooooooooool0oooooolPooooo`03o`000?oo003ooooo01kooooo000Nooooo`03o`000?oooooo
oooo00Cooooo00?oo`00ooooooooool0oooooolPooooo`03ool00?oooooooooo01kooooo000Noooo
o`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool0oooooolNooooo`03o`000?oo003ooooo
01oooooo000Nooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool0oooooolNooooo`03
ool00?oooooooooo01oooooo000Nooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool0
oooooolLooooo`03o`000?oo003ooooo023ooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o
o`00ooooooooool0oooooolLooooo`03ool00?oooooooooo023ooooo000Nooooo`?o00001oooool0
0ooo003oooooooooo`3ooooooa[ooooo00?o0000ool00?ooool08Oooool001kooooo00?o0000oooo
ooooool01oooool00ol0003oo`00ooooo`3ooooooa[ooooo00?oo`00ooooooooool08Oooool001ko
oooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`3ooooooaSooooo00?o0000ool00?oo
ool08_ooool001kooooo00?o0000ooooooooool02?ooool00ol0003oo`00ooooo`3ooooooaSooooo
00?oo`00ooooooooool08_ooool001kooooo00?o0000ooooooooool02Oooool00ooo003ooooooooo
o`3ooooooaKooooo00?o0000ool00?ooool08oooool001kooooo00?o0000ooooooooool02_ooool0
0ooo003oooooooooo`3ooooooaCooooo00?o0000ool00?ooool09?ooool001kooooo00?o0000oooo
ooooool02_ooool00ooo003oooooooooo`3ooooooaCooooo00?o0000ool00?ooool09?ooool001ko
oooo00?o0000ooooooooool02oooool00ooo003oooooooooo`3ooooooa;ooooo00?o0000ool00?oo
ool09Oooool001kooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`3ooooooa;ooooo
00?o0000ool00?ooool09Oooool001kooooo0ol0000<ooooo`03ool00?oooooooooo0?oooooo4?oo
ool00ol0003oo`00ooooo`0Vooooo`007_ooool00ol0003oooooooooo`0<ooooo`03ool00?oooooo
oooo0?oooooo4?ooool00ol0003oo`00ooooo`0Vooooo`007_ooool00ol0003oooooooooo`0=oooo
o`03ool00?oooooooooo0?oooooo3_ooool00ol0003oo`00ooooo`0Wooooo`007_ooool00ol0003o
ooooooooo`0=ooooo`03ool00?oooooooooo0?oooooo3_ooool00ol0003oo`00ooooo`0Wooooo`00
7_ooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo0?oooooo3?ooool00ol0003oo`00
ooooo`0Xooooo`007_ooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo0?oooooo3?oo
ool00ol0003oo`00ooooo`0Xooooo`007_ooool00ol0003oooooooooo`0?ooooo`03ool00?oooooo
oooo0?oooooo2_ooool00ol0003oo`00ooooo`0Yooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool00ol0003oooooooooo`0?ooooo`03ool00?oooooo
oooo0?oooooo2_ooool00ol0003oo`00ooooo`0Yooooo`001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003ooooooooo
o`0@ooooo`03ool00?oooooooooo0?oooooo2?ooool00ol0003oo`00ooooo`0Zooooo`001?ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003ooooooooo
o`0@ooooo`03ool00?l0003ooooo0?oooooo1oooool00ol0003oo`00ooooo`0[ooooo`001?ooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`00017ooooo00?o
o`00ooooooooool0ooooool6ooooo`03o`000?oo003ooooo02_ooooo0004ooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo017ooooo00?o
o`00o`000?ooool0ooooool5ooooo`03o`000?oo003ooooo02cooooo0004ooooo`05oa0@4?oooooo
ooooooooool@41003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o
o`00ooooooooool0ooooool4ooooo`03o`000?oo003ooooo02cooooo0004ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0
4_ooool00ooo003o0000ooooo`3oooooo`?ooooo00?o0000ool00?ooool0;Oooool000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003o
ooooooooo`0Cooooo`03ool00?oooooooooo0?oooooo0_ooool00ol0003oo`00ooooo`0]ooooo`00
7_ooool00ol0003oooooooooo`0Cooooo`03ool00?l0003ooooo0?oooooo0Oooool00ol0003oo`00
ooooo`0^ooooo`007_ooool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo0?oooooo00?o
0000ool00?ooool0;_ooool001kooooo00?o0000ooooooooool05?ooool00ooo003o0000ooooo`3n
ooooo`03o`000?oo003ooooo02oooooo000Nooooo`03o`000?oooooooooo01Gooooo00?oo`00oooo
ooooool0oOooool00ol0003oo`00ooooo`0_ooooo`007_ooool3o`0001Gooooo00?oo`00o`000?oo
ool0o?ooool00ol0003oo`00ooooo`0`ooooo`007_ooool00ol0003oooooooooo`0Fooooo`03ool0
0?oooooooooo0?_ooooo00?o0000ool00?ooool0<?ooool001kooooo00?o0000ooooooooool05_oo
ool00ooo003o0000ooooo`3jooooo`03o`000?oo003ooooo037ooooo000Nooooo`03o`000?oooooo
oooo01Oooooo00?oo`00ooooooooool0nOooool00ol0003oo`00ooooo`0aooooo`007_ooool00ol0
003oooooooooo`0Gooooo`03ool00?l0003ooooo0?Sooooo00?o0000ool00?ooool0<_ooool001ko
oooo00?o0000ooooooooool06?ooool00ooo003o0000ooooo`3fooooo`03o`000?ooooooo`0003?o
oooo000Nooooo`03o`000?oooooooooo01Sooooo00?oo`00o`000?ooool0m_ooool00ol0003oo`00
ooooo`0cooooo`007_ooool00ol0003oooooooooo`0Iooooo`03ool00?l0003ooooo0?Cooooo00?o
0000ool00?ooool0=?ooool001kooooo00?o0000ooooooooool06_ooool00ooo003oooooooooo`3c
ooooo`03o`000?oo003ooooo03Cooooo000Nooooo`?o00006_ooool00ooo003o0000ooooo`3boooo
o`03o`000?oo003ooooo03Gooooo000Nooooo`03o`000?oooooooooo01_ooooo00?oo`00oooooooo
ool0lOooool00ol0003oo`00ooooo`0eooooo`007_ooool00ol0003oooooooooo`0Kooooo`03ool0
0?l0003ooooo0?3ooooo00?o0000ool00?ooool0=_ooool001kooooo00?o0000ooooooooool07?oo
ool00ooo003oooooooooo`3_ooooo`03ool00?oooooooooo03Kooooo000Nooooo`03o`000?oooooo
oooo01cooooo00?oo`00o`000?ooool0k_ooool00ol0003oo`00ooooo`0gooooo`007_ooool00ol0
003oooooooooo`0Mooooo`03ool00?oooooooooo0>gooooo00?oo`00ooooooooool0=oooool001ko
oooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`3[ooooo`03o`000?oo003ooooo03So
oooo000Nooooo`03o`000?oooooooooo01kooooo00?oo`00o`000?ooool0j_ooool00ol0003oo`00
ooooo`0iooooo`007_ooool00ol0003oooooooooo`0Oooooo`03ool00?oooooooooo0>Wooooo00?o
o`00ooooooooool0>Oooool001kooooo00?o0000ooooooooool07oooool00ooo003o0000ooooo`3X
ooooo`03o`000?oo003ooooo03[ooooo000Nooooo`?o00008?ooool00ooo003oooooooooo`3Woooo
o`03ool00?oooooooooo03[ooooo000Nooooo`03o`000?oooooooooo023ooooo00?oo`00o`000?oo
ool0i_ooool00ol0003oo`00ooooo`0kooooo`007_ooool00ol0003oooooooooo`0Qooooo`03ool0
0?oooooooooo0>Gooooo00?oo`00ooooooooool0>oooool001kooooo00?o0000ooooooooool08Ooo
ool00ooo003o0000ooooo`3Tooooo`03ool00?oooooooooo03cooooo000Nooooo`03o`000?oooooo
oooo02;ooooo00?oo`00o`000?ooool0h_ooool00ol0003oo`00ooooo`0mooooo`007_ooool00ol0
003oooooooooo`0Sooooo`03ool00?oooooooooo0>7ooooo00?oo`00ooooooooool0?Oooool001ko
oooo00?o0000ooooooooool08oooool00ooo003o0000ooooo`3Pooooo`03o`000?oo003ooooo03ko
oooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo02Cooooo00?oo`00ooooooooool0goooool00ooo003o
ooooooooo`0nooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool09?ooool00ooo003o0000ooooo`3Nooooo`03
o`000?oo003ooooo03oooooo0004ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Go
oooo0ol0000Uooooo`03ool00?l0003ooooo0=cooooo00?o0000ool00?ooool0@?ooool000Cooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000oooo
ooooool09Oooool00ooo003o0000ooooo`3Looooo`03o`000?oo003ooooo043ooooo0004ooooo`05
o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00006ooooo`03o`000?oooooo
oooo02Kooooo00?oo`00o`000?ooool0f_ooool00ol0003oo`00ooooo`11ooooo`001?ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo0=Wooooo00?oo`00ooooooooool0@Oooool000Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo00?o0000ooooooooool09oooool0
0ooo003o0000ooooo`3Hooooo`03o`000?oo003ooooo04;ooooo0004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05ooooo`03o`000?oooooooooo02Sooooo00?oo`00
ooooooooool0eoooool00ooo003oooooooooo`12ooooo`007_ooool00ol0003oooooooooo`0Xoooo
o`03ool00?l0003ooooo0=Kooooo00?o0000ool00?ooool0@oooool001kooooo00?o0000oooooooo
ool0:Oooool00ooo003o0000ooooo`3Dooooo`03o`000?oo003ooooo04Cooooo000Nooooo`03o`00
0?oooooooooo02Wooooo00?oo`00o`000?ooool0e?ooool00ol0003oo`00ooooo`14ooooo`007_oo
ool00ol0003oooooooooo`0Zooooo`03ool00?l0003ooooo0=;ooooo00?o0000ool00?ooool0AOoo
ool001kooooo0ol0000[ooooo`03ool00?oooooooooo0=7ooooo00?o0000ool00?ooool0AOooool0
01kooooo00?o0000ooooooooool0:oooool00ooo003o0000ooooo`3@ooooo`03o`000?oo003ooooo
04Kooooo000Nooooo`03o`000?oooooooooo02cooooo00?oo`00ooooooooool0coooool00ol0003o
o`00ooooo`16ooooo`007_ooool00ol0003oooooooooo`0/ooooo`03ool00?l0003ooooo0<kooooo
00?o0000ool00?ooool0Aoooool001kooooo00?o0000ooooooooool0;Oooool00ooo003o0000oooo
o`3<ooooo`03o`000?oo003ooooo04Sooooo000Nooooo`03o`000?oooooooooo02gooooo00?oo`00
o`000?ooool0c?ooool00ol0003oo`00ooooo`18ooooo`007_ooool00ol0003oooooooooo`0^oooo
o`03ool00?l0003ooooo0<[ooooo00?o0000ool00?ooool0BOooool001kooooo00?o0000oooooooo
ool0;oooool00ooo003oooooooooo`39ooooo`03o`000?oo003ooooo04Wooooo000Nooooo`03o`00
0?oooooooooo02oooooo00?oo`00o`000?ooool0b?ooool00ol0003oo`00ooooo`1:ooooo`007_oo
ool3o`00033ooooo00?oo`00ooooooooool0aoooool00ol0003oo`00ooooo`1:ooooo`007_ooool0
0ol0003oooooooooo`0`ooooo`03ool00?l0003ooooo0<Kooooo00?o0000ool00?ooool0Boooool0
01kooooo00?o0000ooooooooool0<Oooool00ooo003o0000ooooo`34ooooo`03o`000?oo003ooooo
04cooooo000Nooooo`03o`000?oooooooooo03;ooooo00?oo`00ooooooooool0`oooool00ol0003o
o`00ooooo`1<ooooo`007_ooool00ol0003oooooooooo`0booooo`03ool00?l0003ooooo0<;ooooo
00?o0000ool00?ooool0COooool001kooooo00?o0000ooooooooool0<oooool00ooo003ooooooooo
o`31ooooo`03o`000?oo003ooooo04gooooo000Nooooo`03o`000?oooooooooo03?ooooo00?oo`00
o`000?ooool0`?ooool00ol0003oo`00ooooo`1>ooooo`007_ooool00ol0003oooooooooo`0doooo
o`03ool00?l0003ooooo0;kooooo00?o0000ool00?ooool0Coooool001kooooo00?o0000oooooooo
ool0=Oooool00ooo003oooooooooo`2mooooo`03o`000?oo003ooooo04oooooo000Nooooo`?o0000
=Oooool00ooo003o0000ooooo`2looooo`03o`000?oo003ooooo053ooooo000Nooooo`03o`000?oo
oooooooo03Kooooo00?oo`00ooooooooool0^oooool00ooo003oooooooooo`1@ooooo`007_ooool0
0ol0003oooooooooo`0gooooo`03ool00?oooooooooo0;Wooooo00?o0000ool00?ooool0DOooool0
01kooooo00?o0000ooooooooool0=oooool00ooo003oooooooooo`2iooooo`03ool00?oooooooooo
057ooooo000Nooooo`03o`000?oooooooooo03Sooooo00?oo`00ooooooooool0]oooool00ol0003o
o`00ooooo`1Booooo`007_ooool00ol0003oooooooooo`0hooooo`03ool00?l0003ooooo0;Kooooo
00?o0000ool00?ooool0Doooool001kooooo00?o0000ooooooooool0>Oooool00ooo003ooooooooo
o`2eooooo`03ool00?oooooooooo05?ooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c005ooooo`03o`000?oooooooooo03[ooooo
00?oo`00ooooooooool0/oooool00ol0003oo`00ooooo`1Dooooo`001?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401Oooool00ol0003o
ooooooooo`0jooooo`03ool00?oooooooooo0;?ooooo00?oo`00ooooooooool0E?ooool000Cooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool00ol0
003oooooooooo`0kooooo`03ool00?oooooooooo0;7ooooo00?o0000ool00?ooool0EOooool000Co
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401Oooool3
o`0003_ooooo00?oo`00o`000?ooool0/?ooool00ol0003oo`00ooooo`1Fooooo`001?ooool01Ol0
003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c005ooooo`03o`000?oo
oooooooo03cooooo00?oo`00o`000?ooool0[_ooool00ol0003oo`00ooooo`1Gooooo`001?ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool01oooool00ol0003ooooooooo
o`0mooooo`03ool00?oooooooooo0:gooooo00?o0000ool00?ooool0Eoooool000Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Oooooo00?o0000ooooooooool0?Ooo
ool00ooo003o0000ooooo`2/ooooo`03o`000?oo003ooooo05Sooooo0004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4105ooooo`03o`000?oooooooooo03kooooo
00?oo`00o`000?ooool0Z_ooool00ol0003oo`00ooooo`1Iooooo`007_ooool00ol0003ooooooooo
o`0oooooo`03ool00?oooooooooo0:Wooooo00?oo`00ooooooooool0FOooool001kooooo00?o0000
ooooooooool0?oooool00ooo003o0000ooooo`2Xooooo`03o`000?oo003ooooo05[ooooo000Noooo
o`03o`000?oooooooooo043ooooo00?oo`00o`000?ooool0Y_ooool00ol0003oo`00ooooo`1Koooo
o`007_ooool00ol0003oooooooooo`11ooooo`03ool00?l0003ooooo0:Cooooo00?o0000ool00?oo
ool0G?ooool001kooooo0ol00011ooooo`03ool00?l0003ooooo0:Cooooo00?o0000ool00?ooool0
G?ooool001kooooo00?o0000ooooooooool0@_ooool00ooo003o0000ooooo`2Rooooo`03o`000?oo
003ooooo05gooooo000Nooooo`03o`000?oooooooooo04?ooooo00?oo`00o`000?ooool0X?ooool0
0ol0003oo`00ooooo`1Nooooo`007_ooool00ol0003oooooooooo`13ooooo`03ool00?l0003ooooo
0:3ooooo00?oo`00ooooooooool0G_ooool001kooooo00?o0000ooooooooool0A?ooool00ooo003o
0000ooooo`2Nooooo`03o`000?oo003ooooo05oooooo000Nooooo`03o`000?oooooooooo04Gooooo
00?oo`00o`000?ooool0W?ooool00ol0003oo`00ooooo`1Pooooo`007_ooool00ol0003ooooooooo
o`15ooooo`03ool00?oooooo000009_ooooo00?o0000ool00?ooool0HOooool001kooooo00?o0000
ooooooooool0A_ooool00ooo003o0000ooooo`2Jooooo`03o`000?oo003ooooo067ooooo000Noooo
o`03o`000?oooooooooo04Oooooo00?oo`00o`000?ooool0V?ooool00ol0003oo`00ooooo`1Roooo
o`007_ooool3o`0004Oooooo00?oo`00ooooool00000Uoooool00ol0003oo`00ooooo`1Sooooo`00
7_ooool00ol0003oooooooooo`18ooooo`03ool00?l0003ooooo09Kooooo00?oo`00ooooooooool0
Hoooool001kooooo00?o0000ooooooooool0BOooool00ooo003o0000ooooo`2Dooooo`03o`000?oo
003ooooo06Cooooo000Nooooo`03o`000?oooooooooo04Wooooo00?oo`00ooooool00000Toooool0
0ol0003oo`00ooooo`1Uooooo`007_ooool00ol0003oooooooooo`1:ooooo`03ool00?oooooo0000
097ooooo00?o0000ool00?ooool0I_ooool001kooooo00?o0000ooooooooool0Boooool00ooo003o
0000ooooo`2@ooooo`03ool00?oooooooooo06Kooooo000Nooooo`03o`000?oooooooooo04cooooo
00?oo`00o`000?ooool0S_ooool00ol0003oo`00ooooo`1Wooooo`007_ooool00ol0003ooooooooo
o`1<ooooo`03ool00?oooooo000008gooooo00?o0000ool00?ooool0J?ooool001kooooo00?o0000
ooooooooool0COooool00ooo003o0000ooooo`2<ooooo`03ool00?oooooooooo06Sooooo000Noooo
o`03o`000?oooooooooo04kooooo00?oo`00o`000?ooool0R_ooool00ooo003oooooooooo`1Yoooo
o`007_ooool3o`0004oooooo00?oo`00o`000?ooool0R?ooool00ooo003oooooooooo`1Zooooo`00
7_ooool00ol0003oooooooooo`1@ooooo`03ool00?l0003ooooo08Kooooo00?o0000ool00?ooool0
Joooool001kooooo00?o0000ooooooooool0D?ooool00ooo003o0000ooooo`26ooooo`03ool00?oo
oooooooo06_ooooo000Nooooo`03o`000?oooooooooo057ooooo00?oo`00o`000?ooool0Q?ooool0
0ooo003oooooooooo`1/ooooo`007_ooool00ol0003oooooooooo`1Booooo`03ool00?l0003ooooo
08;ooooo00?oo`00ooooooooool0KOooool001kooooo00?o0000ooooooooool0Doooool00ooo003o
ooooooooo`21ooooo`03ool00?oooooooooo06gooooo000Nooooo`03o`000?oooooooooo05?ooooo
00?oo`00o`000?ooool0P?ooool00ooo003oooooooooo`1^ooooo`001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool00ol0003o
ooooooooo`1Dooooo`03ool00?l0003ooooo07kooooo00?oo`00ooooooooool0Koooool000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q
00Gooooo00?o0000ooooooooool0EOooool00ooo003o0000ooooo`1looooo`03ool00?oooooooooo
073ooooo0004ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo
000000Gooooo0ol0001Fooooo`03ool00?oooooooooo07_ooooo00?oo`00ooooooooool0L?ooool0
00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801Ooo
ool00ol0003oooooooooo`1Gooooo`03ool00?oooooooooo07Wooooo00?oo`00ooooooooool0LOoo
ool000Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0
1Oooool00ol0003oooooooooo`1Hooooo`03ool00?l0003ooooo07Kooooo00?o0000ool00?ooool0
Loooool000Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
41001Oooool00ol0003oooooooooo`1Iooooo`03ool00?l0003ooooo07Cooooo00?o0000ool00?oo
ool0M?ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj
^_l000001Oooool00ol0003oooooooooo`1Jooooo`03ool00?l0003ooooo07;ooooo00?o0000ool0
0?ooool0MOooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000
oa0@4?nYZJT01Oooool00ol0003oooooooooo`1Kooooo`03ool00?l0003ooooo073ooooo00?o0000
ool00?ooool0M_ooool001kooooo00?o0000ooooooooool0G?ooool00ooo003o0000ooooo`1^oooo
o`03o`000?oo003ooooo07Oooooo000Nooooo`03o`000?oooooooooo05gooooo00?oo`00o`000?oo
ool0K?ooool00ol0003oo`00ooooo`1hooooo`007_ooool00ol0003oooooooooo`1Nooooo`03ool0
0?l0003ooooo06[ooooo00?o0000ool00?ooool0NOooool001kooooo00?o0000ooooooooool0Gooo
ool00ooo003o0000o`00001Wooooo`;o000000?oo`00ooooooooool0NOooool001kooooo0ol0001P
ooooo`03ool00?oooooo000006Gooooo00?o0000oooooooo0000O?ooool001kooooo00?o0000oooo
ooooool0HOooool00ooo003oooooo`00001Sooooo`03o`000?ooooooo`0007gooooo000Nooooo`03
o`000?oooooooooo06;ooooo00?oo`00ooooool00000HOooool00ol0003oo`00ool0001nooooo`00
7_ooool00ol0003oooooooooo`1Sooooo`;oo`0000?o0000ooooooooool0GOooool00ol0003oo`00
ooooo`1oooooo`007_ooool00ol0003oooooooooo`1Uooooo`03ool00?l0003ooooo05cooooo00?o
0000ool00?ooool0P?ooool001kooooo00?o0000ooooooooool0I_ooool00ooo003o0000o`00001I
ooooo`;o000000?oo`00ooooooooool0P?ooool001kooooo00?o0000ooooooooool0Ioooool00ooo
003oooooo`00001Gooooo`03o`000?ooooooo`0008?ooooo000Nooooo`03o`000?oooooooooo06So
oooo00?oo`00ooooool00000EOooool00ol0003oooooool00024ooooo`007_ooool00ol0003ooooo
ooooo`1Yooooo`03ool00?oooooo000005?ooooo00?o0000oooooooo0000QOooool001kooooo0ol0
001Zooooo`03ool00?oooooo0000057ooooo00?o0000oooooooo0000Q_ooool001kooooo00?o0000
ooooooooool0Joooool00ooo003oooooo`00001?ooooo`03o`000?ooooooo`0008Oooooo000Noooo
o`03o`000?oooooooooo06cooooo00?oo`00ooooool00000COooool00ol0003oooooool00028oooo
o`007_ooool00ol0003oooooooooo`1]ooooo`04ool00?oooooo0000o`0004Wooooo0_l000000ooo
ooooo`00ooooo`28ooooo`007_ooool00ol0003oooooooooo`1^ooooo`04ool00?ooooooooooo`00
04Oooooo00Co0000oooooooo003oo`00R_ooool001kooooo00?o0000ooooooooool0Koooool2ool0
0003ooooool0003ooooo04Cooooo00?o0000oooooooo0000S?ooool001kooooo00?o0000oooooooo
ool0LOooool2ool00003o`000?oooooooooo047ooooo00?o0000ool00?oo0000SOooool001kooooo
00?o0000ooooooooool0Loooool00ooo003o0000ooooo`10ooooo`;oo`00Soooool001kooooo00?o
0000ooooooooool0M?ooool2ool003oooooo00?oo`00ooooooooool0Soooool001kooooo0ol0001f
ooooo`;oo`00>oooool2ool009;ooooo000Nooooo`03o`000?oooooooooo07Oooooo00?o0000ool0
0?l00000=oooool2ool00003o`000?oooooooooo097ooooo000Nooooo`03o`000?oooooooooo07Wo
oooo0_oo0002o`00037ooooo0_l000000ooo003oooooooooo`2Dooooo`007_ooool00ol0003ooooo
ooooo`1kooooo`03ool00?oooooo000000;o0000:oooool3o`0000;oo`00Uoooool001kooooo00?o
0000ooooooooool0O?ooool3ool00003ooooool0003o000000;o00008oooool4o`0000?oo`00VOoo
ool001kooooo00?o0000ooooooooool0Ooooool3ool000;ooooo0ol0000Mooooo`?o00000_ooool2
ool009cooooo000Nooooo`03o`000?oooooooooo08;ooooo1?oo00001?oooooo0000o`000?l0000G
ooooo`?o00000oooool2ool009kooooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0
003oooooooooo`26ooooo`?oo`0000?oooooo`000?l000000_l0000?ooooo`Co00000_ooool4ool0
0:3ooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ROooool2ool000?o
oooo0ol00009ooooo`?o00000oooool3ool00:Cooooo000Gooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0Roooool6ool000?o00000oooool3o`0000Koo`00Yoooool001Oooooo00?o
0000ooooooooool01?ooool3o`00097ooooo2Ooo002]ooooo`005oooool00ol0003oooooooooo`3o
ooooodoooooo000Gooooo`03o`000?oooooooooo0?ooooooCoooool001Oooooo00?o0000oooooooo
ool0oooooom?ooooo`005Oooool00omEEEGoIVIVo`00003ooooooe7ooooo003oooooofWooooo002L
ooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001_ooool00ol0003o^[Zjooooo`2U
ooooo`00W?ooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`04oooo
o`;o<S8bY_ooool009;ooooo00Go410@o`000?l0003o0000oa0@4005ooooo`03o`000?oooooooooo
00;ooooo0_l00002ooooo`;o00000_ooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000
odA4A?nj^[X00oooool00ol0003oooooooooo`04ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RH
o`000?l0003oA4A4okZj^P09ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0S_ooool009Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003o
gMgM0_ooool00oo<c<co0000oa0@4005ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0
003oooooooooo`04ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4002
ooooo`Ko000000KoooooogMgMonHV9SooooooiRHV?mgMgN>ooooo`00U?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool01Ol@413ooooo
oooooooooooo410@08kooooo002Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`04ooooo`Ko000000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`2<ooooo`00U?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000008kooooo002Aooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00004ooooo`03o`000?oooooooooo
00Wooooo00?o410@o`000?l000000ol0000:ooooo`05oa0@4?ooooooooooooooool@4100S_ooool0
097ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2>ooooo`00TOooool7o`0000Cooooo0_l0000C
ooooo`03o`000?oooooooooo00Cooooo0_l0000=ooooo`03o`000?oooooooooo00_ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP2>ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.101772, -0.0802184, \
0.00411939, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.1 .10351 L
.2 .19688 L
.3 .27098 L
.4 .31856 L
.5 .33495 L
.6 .31856 L
.7 .27098 L
.8 .19688 L
.9 .10351 L
1 0 L
s
1 0 0 r
0 0 m
.04057 .04239 L
.08481 .08781 L
.12636 .12895 L
.16632 .16644 L
.20885 .20346 L
.2498 .23568 L
.29331 .26564 L
.33524 .28983 L
.37557 .30836 L
.39599 .31587 L
.41848 .32264 L
.43982 .32757 L
.44937 .32931 L
.4598 .33086 L
.46545 .33155 L
.4707 .3321 L
.47614 .33258 L
.48106 .33293 L
.48591 .33319 L
.48813 .33328 L
.49048 .33337 L
.49299 .33344 L
.4941 .33346 L
.4953 .33348 L
.49658 .3335 L
.49778 .33351 L
.49852 .33351 L
.49921 .33352 L
.50051 .33352 L
.50171 .33351 L
.503 .3335 L
.50421 .33349 L
.50533 .33347 L
.50792 .33341 L
.51065 .33333 L
.51331 .33323 L
.51579 .33311 L
.52142 .33276 L
.53077 .33196 L
.54076 .33079 L
.55151 .32916 L
.56317 .32697 L
.58433 .32188 L
.6273 .3072 L
.66867 .28778 L
.70845 .26452 L
.75081 .23523 L
.79157 .20311 L
.83491 .16532 L
Mistroke
.87666 .12602 L
.91682 .08617 L
.95955 .04227 L
1 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00D?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0<Oooool4o`000003oa0@4?oooooooooo01Gooooo001@ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00X
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B40:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<oooool00ol0003oooooooooo`0Gooooo`00D?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h0:Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Wooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002So
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<oooool0
0ol0003oooooooooo`0Gooooo`00D?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h0:?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
:?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Xoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03?ooooo00?o
0000ooooooooool05oooool0053ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002So
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0:?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00cooooo`03o`00
0?oooooooooo01Oooooo001@ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Vooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Xooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Zooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03?ooooo00?o0000ooooooooool05ooo
ool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000:?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000cooooo`03o`000?oooooooooo01Oooooo001@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<Oooool00omEEEGoIVIVo`00000Iooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Nooooo`03ool00?l0003o00000?oo0000;_l000000ooo003oooooooooo`09oooo
o`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oo003ooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ooo003oooooooooo`09ooooo`04ob4Q8OmgMgOoMgMgoc8b<P[ooooo000Noooo
o`;o000000?oo`00ooooooooool0>?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0iooooo`03ool00?l0003ooooo
00Wooooo0_l00002ooooo`;o00002Oooool001kooooo00Co0000ooooool0003oo`00ooooool[oooo
o`03ool00?oooooooooo01Wooooo000Nooooo`05o`000?ooooooooooo`000?oo0000oooooolYoooo
o`03ool00?oooooooooo01[ooooo000Nooooo`06o`000?ooooooooooooooool0003oo`00oooooolW
ooooo`03ool00?oooooooooo01_ooooo000Nooooo`03o`000?oooooooooo00;ooooo00?o0000ool0
0?ooool0oooooolTooooo`03ool00?oooooooooo01cooooo000Nooooo`03o`000?oooooooooo00?o
oooo00?o0000ool00?ooool0oooooolRooooo`03ool00?oooooooooo01gooooo000Nooooo`03o`00
0?oooooooooo00Cooooo00?o0000ool00?ooool0oooooolPooooo`03ool00?oooooooooo01kooooo
000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ool00?ooool0oooooolNooooo`03ool00?oo
oooooooo01oooooo000Nooooo`?o00001_ooool00ol0003oo`00ooooo`3ooooooacooooo00?oo`00
ooooooooool08?ooool001kooooo00?o0000ooooooooool01oooool00ol0003oo`00ooooo`3ooooo
oa[ooooo00?oo`00ooooooooool08Oooool001kooooo00?o0000ooooooooool02?ooool00ol0003o
o`00ooooo`3ooooooaSooooo00?oo`00ooooooooool08_ooool001kooooo00?o0000ooooooooool0
2Oooool00ol0003oo`00ooooo`3ooooooaKooooo00?oo`00ooooooooool08oooool001kooooo00?o
0000ooooooooool02_ooool00ooo003oooooooooo`3ooooooaCooooo00?oo`00ooooooooool09?oo
ool001kooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`3ooooooa;ooooo00?oo`00
ooooooooool09Oooool001kooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`3ooooo
oa3ooooo00?oo`00ooooooooool09_ooool001kooooo00?o0000ooooooooool03Oooool00ooo003o
ooooooooo`3oooooo`kooooo00?oo`00ooooooooool09oooool001kooooo00?o0000ooooooooool0
3_ooool00ooo003oooooooooo`3oooooo`cooooo00?oo`00ooooooooool0:?ooool001kooooo0ol0
000?ooooo`03ool00?oooooooooo0?oooooo2_ooool00ooo003oooooooooo`0Yooooo`007_ooool0
0ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0?oooooo2?ooool00ooo003oooooooooo`0Z
ooooo`007_ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo0?oooooo1_ooool00ooo
003oooooooooo`0[ooooo`007_ooool00ol0003oooooooooo`0Booooo`03ool00?oooooooooo0?oo
oooo1?ooool00ooo003oooooooooo`0/ooooo`007_ooool00ol0003oooooooooo`0Cooooo`03ool0
0?oooooooooo0?oooooo0_ooool00ooo003oooooooooo`0]ooooo`007_ooool00ol0003ooooooooo
o`0Dooooo`03ool00?oooooooooo0?oooooo00?oo`00ooooooooool0;_ooool001kooooo00?o0000
ooooooooool05Oooool00ooo003oooooooooo`3mooooo`03ool00?oooooooooo02oooooo000Noooo
o`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool0n_ooool2ool003;ooooo000Nooooo`03
o`000?oooooooooo01Oooooo0_oo003iooooo`03ool00?l0003ooooo03;ooooo000Nooooo`?o0000
6?ooool00ol0003oo`00ooooo`3fooooo`03ool00?l0003ooooo03?ooooo000Nooooo`03o`000?oo
oooooooo01Wooooo00?o0000ool00?ooool0m?ooool00ooo003o0000ooooo`0dooooo`007_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oo003ooooo0?;ooooo00?oo`00o`000?ooool0=Oooool0
01kooooo00?o0000ooooooooool06oooool00ol0003oo`00ooooo`3`ooooo`03ool00?l0003ooooo
03Kooooo000Nooooo`03o`000?oooooooooo01cooooo00?o0000ool00?ooool0k_ooool00ooo003o
0000ooooo`0gooooo`007_ooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo0>_ooooo
00?oo`00ooooooooool0>?ooool001kooooo00?o0000ooooooooool07oooool00ooo003ooooooooo
o`3Yooooo`03ool00?oooooooooo03Wooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo1Ol00005ooooo`03o`000?oooooooooo023ooooo00?oo`00ooooooooool0iooo
ool00ooo003oooooooooo`0jooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003oooooooooo`0Qooooo`03ool0
0?oooooooooo0>Gooooo00?oo`00ooooooooool0>oooool000Cooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool08_ooool00ooo003ooooo
ooooo`3Sooooo`03ool00?oooooooooo03cooooo0004ooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP05ooooo`?o00008oooool00ooo003oooooooooo`3Qooooo`03ool0
0?oooooooooo03gooooo0004ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIV
ooooo`04ooooo`03o`000?oooooooooo02Cooooo00?oo`00ooooooooool0goooool00ooo003ooooo
ooooo`0nooooo`001?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Uooooo`03ool00?oooooooooo0=gooooo00?oo`00ooooooooool0
?oooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41001Oooool00ol0003oooooooooo`0Vooooo`03ool00?oooooooooo0=_ooooo00?oo`00oooooooo
ool0@?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01Oooool00ol0003oooooooooo`0Wooooo`03ool00?oooooooooo0=Wooooo00?oo`00oooo
ooooool0@Oooool001kooooo00?o0000ooooooooool0:?ooool00ooo003oooooooooo`3Gooooo`03
ool00?oooooooooo04;ooooo000Nooooo`03o`000?oooooooooo02Wooooo00?oo`00ooooooooool0
eOooool00ooo003oooooooooo`13ooooo`007_ooool00ol0003oooooooooo`0Zooooo`03ool00?oo
oooooooo0=?ooooo00?oo`00ooooooooool0A?ooool001kooooo00?o0000ooooooooool0:oooool0
0ooo003o0000ooooo`3@ooooo`03o`000?oo003ooooo04Kooooo000Nooooo`?o0000;?ooool00ooo
003o0000ooooo`3>ooooo`03o`000?oo003ooooo04Oooooo000Nooooo`03o`000?oooooooooo02go
oooo00?oo`00o`000?ooool0c?ooool00ol0003oo`00ooooo`18ooooo`007_ooool00ol0003ooooo
ooooo`0^ooooo`03ool00?l0003ooooo0<[ooooo00?o0000ool00?ooool0BOooool001kooooo00?o
0000ooooooooool0;oooool00ooo003o0000ooooo`38ooooo`;oo`00Boooool001kooooo00?o0000
ooooooooool0<?ooool2ool00<Oooooo00?oo`00ooooooooool0Boooool001kooooo00?o0000oooo
ooooool0<_ooool00ooo003oooooooooo`33ooooo`03ool00?oooooooooo04cooooo000Nooooo`03
o`000?oooooooooo03?ooooo00?oo`00ooooooooool0`Oooool00ooo003oooooooooo`1=ooooo`00
7_ooool00ol0003oooooooooo`0dooooo`03ool00?oooooooooo0;oooooo00?oo`00ooooooooool0
C_ooool001kooooo00?o0000ooooooooool0=Oooool00ooo003oooooooooo`2mooooo`03ool00?oo
oooooooo04oooooo000Nooooo`?o0000=_ooool2ool00;cooooo00?oo`00ooooooooool0D?ooool0
01kooooo00?o0000ooooooooool0=oooool00ol0003oo`00ooooo`2iooooo`03ool00?oooooooooo
057ooooo000Nooooo`03o`000?oooooooooo03Sooooo00?o0000ool00?ooool0]oooool00ooo003o
ooooooooo`1Booooo`007_ooool00ol0003oooooooooo`0iooooo`03o`000?oo003ooooo0;Gooooo
00?oo`00ooooooooool0Doooool001kooooo00?o0000ooooooooool0>_ooool00ol0003oo`00oooo
o`2booooo`03o`000?oo003ooooo05Gooooo000Nooooo`03o`000?oooooooooo03cooooo00?oo`00
ooooooooool0[oooool00ol0003oo`00ooooo`1Fooooo`007_ooool00ol0003oooooooooo`0moooo
o`;oo`00[_ooool2ool005Sooooo000Nooooo`03o`000?oooooooooo03kooooo00?o0000ool00?oo
ool0Z_ooool00ol0003oo`00ooooo`1Iooooo`007_ooool00ol0003oooooooooo`10ooooo`03ool0
0?oooooooooo0:Oooooo00?o0000ool00?ooool0F_ooool001kooooo00?o0000ooooooooool0@Ooo
ool00ooo003o0000ooooo`2Tooooo`03o`000?oo003oo`0005cooooo000Nooooo`?o0000@_ooool0
0ooo003o0000ooooo`2Rooooo`03o`000?oo003ooooo05gooooo000Nooooo`03o`000?oooooooooo
04?ooooo0_oo002Qooooo`03o`000?oo003ooooo05kooooo000Nooooo`03o`000?oooooooooo04Go
oooo00?oo`00o`000?ooool0W?ooool2o`000003ool00?oooooooooo05kooooo000Nooooo`03o`00
0?oooooooooo04Kooooo00?oo`00o`000?ooool0V_ooool00ol0003oo`00ool0001Qooooo`007_oo
ool00ol0003oooooooooo`17ooooo`03ool00?l0003ooooo09Sooooo00?o0000ool00?ooool0H_oo
ool001kooooo00?o0000ooooooooool0B?ooool00ooo003o0000o`00002Eooooo`;o000000?oo`00
ooooooooool0H_ooool001kooooo00?o0000ooooooooool0BOooool2ool00003o`000?oooooooooo
097ooooo00?o0000ool00?oo0000IOooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0Boooool00ooo
003o0000ooooo`2@ooooo`03o`000?oo003ooooo06Kooooo0004ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1<oooo
o`;oo`0000?o0000ooooooooool0Roooool00ol0003oo`00ool0001Xooooo`001?ooool01Ol@413o
oooooooooooooooo410@00_ooooo1Ol00005ooooo`?o0000C_ooool00ooo003o0000ooooo`2:oooo
o`;oo`00J_ooool000Cooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgooooo
o`0000Kooooo00?o0000ooooooooool0Coooool2ool00003o`000?oooooooooo08Gooooo00?o0000
ool00?ooool0Joooool000Cooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0000Kooooo00?o0000ooooooooool0DOooool00ooo003o0000ooooo`24ooooo`;oo`00KOoo
ool000Cooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo00?o
0000ooooooooool0D_ooool00ooo003o0000ooooo`21ooooo`;oo`00Koooool000Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo00?o0000ooooooooool0Dooo
ool2ool00003o`000?oooooooooo07gooooo00?oo`00o`000?ooool0Koooool000Cooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0EOoo
ool00ooo003o0000ooooo`1kooooo`;oo`00L_ooool001kooooo00?o0000ooooooooool0E_ooool2
ool007Wooooo0_oo00000ol0003oooooooooo`1aooooo`007_ooool00ol0003oooooooooo`1Hoooo
o`;oo`00M_ooool00ooo003o0000o`00001dooooo`007_ooool00ol0003oooooooooo`1Jooooo`;o
o`00L_ooool2ool00003o`000?oooooooooo07Cooooo000Nooooo`03o`000?oooooooooo05cooooo
0_oo001^ooooo`;oo`0000?o0000ooooooooool0M_ooool001kooooo0ol0001Nooooo`03ool00?l0
003ooooo06[ooooo00?oo`00o`000?ooool0NOooool001kooooo00?o0000ooooooooool0Goooool2
ool00003o`000?oooooooooo06Gooooo0_oo001looooo`007_ooool00ol0003oooooooooo`1Qoooo
o`;oo`0000?o0000ooooooooool0HOooool2ool007kooooo000Nooooo`03o`000?oooooooooo06?o
oooo0_oo00000ol0003oooooooooo`1Mooooo`;oo`00P?ooool001kooooo00?o0000ooooooooool0
IOooool2ool000;o0000FOooool00ol0003oo`00ool00022ooooo`007_ooool00ol0003ooooooooo
o`1Wooooo`;oo`000_l0001Eooooo`03o`000?oo003oo`0008Cooooo000Nooooo`03o`000?oooooo
oooo06Wooooo0_oo0002o`00057ooooo00?o0000ool00?oo0000Q_ooool001kooooo00?o0000oooo
ooooool0Joooool2ool000;o0000COooool00ol0003oo`00ool00028ooooo`007_ooool00ol0003o
ooooooooo`1]ooooo`;oo`000_l00019ooooo`03o`000?oo003oo`0008[ooooo000Nooooo`?o0000
Koooool3ool00003o`000?oooooooooo04?ooooo0ooo002<ooooo`007_ooool00ol0003ooooooooo
o`1booooo`?oo`00@?ooool3ool008oooooo000Nooooo`03o`000?oooooooooo07Gooooo1?oo000j
ooooo`;oo`0000?o0000ooooooooool0Soooool001kooooo00?o0000ooooooooool0Moooool2o`00
00?oo`00=?ooool3ool00003o`000?oooooooooo097ooooo000Nooooo`03o`000?oooooooooo07_o
oooo00Co0000ool00?oo003oo`000_l0000Yooooo`;o00001?oo002Gooooo`007_ooool00ol0003o
ooooooooo`1oooooo`?oo`001Ol0000Mooooo`?o00001Ooo002Kooooo`007_ooool00ol0003ooooo
ooooo`22ooooo`Ooo`001?l0000Aooooo`Go00001?oo002Pooooo`007_ooool00ol0003ooooooooo
o`29oooooa[oo`00Y?ooool001kooooo00?o0000ooooooooool0Toooool5o`000:oooooo000Noooo
o`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01Oooool00ol0003oooooooooo`3ooooo
odSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMg
MoooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooooooo
o`3oooooodSooooo0004ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooo
oonHV9So8B4Q00Gooooo0ol0003oooooodSooooo0004ooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0oooooom8ooooo`00
1?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool01oooool00ol0003o
ooooooooo`3oooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo
410@oiRHV007ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go410@
oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool3o`000?oooooo
B?ooool000Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S801Oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05o`000?ooooooooooooooool0
00002oooool01Oo<c<co0000o`000?l0003oc<c<00Gooooo00?o0000ooooooooool0oooooom8oooo
o`001?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4005
ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l000001Oooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Gooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`00
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001Gooooo1?l000000ol@413oooooooooo`02ooooo`03o`00
0?oooooooooo0?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8
ooooo`005oooool00ol0003oooooooooo`04ooooo`?o0000oooooom8ooooo`005oooool00ol0003o
ooooooooo`3oooooodoooooo000Gooooo`03o`000?oooooooooo0?ooooooCoooool001Oooooo00?o
0000ooooooooool0oooooom?ooooo`005Oooool00omEEEGoIVIVo`00003ooooooe7ooooo003ooooo
ofWooooo002Aooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o
^[Zjooooo`2aooooo`00TOooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003ooooo
ooooo`03ooooo`;o<S8b/_ooool008Kooooo00Go410@o`000?l0003o0000oa0@4006ooooo`04o`00
0?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So
0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7QhOo0000okZj^P05oooo
o`05oiRHV?l0003o0000odA4A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM083ooooo0028ooooo`03o`000?oo
oooooooo00Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool0
0oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ooooooooo
o`03ooooo`03olc<c?l0003o410@00Gooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Oooooo00?oMgMgoc8b<_ooool0Ooooool008Sooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0O_ooool008Sooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo1_l0
0002ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMg
Molb<S;ooooo07oooooo0028ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oo
ool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0P?ooool008Gooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2
o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo00Wooooo00?o410@
o`000?l000000ol0000:ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo08;ooooo0025ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0P_ooool008Gooooo
1ol00005ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003ooooo
ooooo`0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00021ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.101772, -0.0802184, \
0.00411939, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.1 .0561 L
.2 .1067 L
.3 .14686 L
.4 .17265 L
.5 .18153 L
.6 .17265 L
.7 .14686 L
.8 .1067 L
.9 .0561 L
1 0 L
s
1 0 0 r
0 0 m
.04057 .02288 L
.08481 .04739 L
.12636 .06958 L
.16632 .08982 L
.20885 .1098 L
.2498 .12718 L
.29331 .14335 L
.33524 .1564 L
.37557 .1664 L
.39599 .17046 L
.41848 .17411 L
.43982 .17677 L
.44937 .17771 L
.4598 .17855 L
.46545 .17892 L
.4707 .17922 L
.47614 .17947 L
.48106 .17966 L
.48591 .1798 L
.48813 .17985 L
.49048 .1799 L
.49299 .17994 L
.4941 .17995 L
.4953 .17996 L
.49658 .17997 L
.49778 .17998 L
.49852 .17998 L
.49921 .17998 L
.50051 .17998 L
.50171 .17998 L
.503 .17997 L
.50421 .17996 L
.50533 .17995 L
.50792 .17992 L
.51065 .17988 L
.51331 .17982 L
.51579 .17976 L
.52142 .17957 L
.53077 .17914 L
.54076 .17851 L
.55151 .17763 L
.56317 .17645 L
.58433 .1737 L
.6273 .16578 L
.66867 .1553 L
.70845 .14275 L
.75081 .12694 L
.79157 .10961 L
.83491 .08921 L
Mistroke
.87666 .06801 L
.91682 .0465 L
.95955 .02281 L
1 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00D?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0<Oooool4o`000003oa0@4?oooooooooo01Gooooo001@ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00X
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B40:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<oooool00ol0003oooooooooo`0Gooooo`00D?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h0:Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Wooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002So
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<oooool0
0ol0003oooooooooo`0Gooooo`00D?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h0:?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
:?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Xoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03?ooooo00?o
0000ooooooooool05oooool0053ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002So
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0:?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00cooooo`03o`00
0?oooooooooo01Oooooo001@ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Vooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Xooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Zooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03?ooooo00?o0000ooooooooool05ooo
ool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000:?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000cooooo`03o`000?oooooooooo01Oooooo001@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<Oooool00omEEEGoIVIVo`00000Iooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Nooooo`;oo`00ool0000^o`0000;oo`002oooool01?o^k^ko8B4Qoa0@4?o^k^h:
ooooo`007_ooool01?l0003oooooool00?oo000<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo0_oo0000
0ooooooo0000ooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<P[ooooo000Nooooo`04o`000?oooooo
ooooooooo`;oo`00=oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0eooooo`03o`000?oo003ooooo00;ooooo00?o
0000ooooooooool02?ooool2o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`03
ooooo`;oo`00oooooolSooooo`;oo`007_ooool001kooooo00?o0000ooooooooool01?ooool00ol0
003oo`00ooooo`3ooooooaoooooo0_oo000Pooooo`007_ooool00ol0003oooooooooo`06ooooo`;o
o`00oooooolLooooo`03o`000?oo003ooooo027ooooo000Nooooo`03o`000?oooooooooo00Sooooo
0_oo003ooooooaSooooo00?o0000ool00?oo00008oooool001kooooo00?o0000ooooooooool02_oo
ool2ool00?oooooo5?ooool00ol0003oo`00ool0000Uooooo`007_ooool00ol0003oooooooooo`0<
ooooo`03ool00?l0003ooooo0?oooooo3oooool00ol0003oo`00ool0000Wooooo`007_ooool00ol0
003oooooooooo`0=ooooo`;oo`00ooooool>ooooo`;oo`00:Oooool001kooooo0ol0000?ooooo`;o
o`00ooooool:ooooo`;oo`00:oooool001kooooo00?o0000ooooooooool04Oooool00ooo003o0000
ooooo`3oooooo`Gooooo00?o0000ool00?ooool0;?ooool001kooooo00?o0000ooooooooool04_oo
ool2ool00003o`000?oooooooooo0?oooooo00?o0000ool00?oo0000;_ooool001kooooo00?o0000
ooooooooool05?ooool2ool00003o`000?oooooooooo0?_ooooo00?o0000ool00?oo0000<?ooool0
01kooooo00?o0000ooooooooool05_ooool00ooo003o0000ooooo`3jooooo`;oo`00<_ooool001ko
oooo00?o0000ooooooooool05oooool2ool00003o`000?oooooooooo0?Gooooo0_oo000dooooo`00
7_ooool00ol0003oooooooooo`0Iooooo`;oo`0000?o0000ooooooooool0lOooool2ool003Kooooo
000Nooooo`03o`000?oooooooooo01_ooooo0_oo00000ol0003oooooooooo`3]ooooo`;oo`00>?oo
ool001kooooo00?o0000ooooooooool07Oooool3ool00>_ooooo00?o0000ool00?ooool0>Oooool0
01kooooo0ol0000Pooooo`;oo`00ioooool00ol0003oo`00ool0000kooooo`007_ooool00ol0003o
ooooooooo`0Rooooo`;oo`00hoooool00ol0003oo`00ool0000mooooo`007_ooool00ol0003ooooo
ooooo`0Tooooo`;oo`00h?ooool2ool003oooooo000Nooooo`03o`000?oooooooooo02Gooooo00?o
0000ool00?oo0000g?ooool2ool0047ooooo000Nooooo`03o`000?oooooooooo02Oooooo00?o0000
ool00?oo0000f?ooool2ool004?ooooo000Nooooo`03o`000?oooooooooo02Wooooo00?o0000ool0
0?oo0000e?ooool2ool004Gooooo000Nooooo`03o`000?oooooooooo02_ooooo00?o0000ool00?oo
0000d?ooool2ool004Oooooo000Nooooo`03o`000?oooooooooo02gooooo00?o0000ool00?oo0000
c?ooool2ool004Wooooo000Nooooo`03o`000?oooooooooo02oooooo00?o0000ool00?oo0000b?oo
ool2ool004_ooooo000Nooooo`?o0000<Oooool00ol0003oo`00ool00034ooooo`;oo`00COooool0
01kooooo00?o0000ooooooooool0<oooool00ol0003oo`00ool00030ooooo`;oo`00Coooool001ko
oooo00?o0000ooooooooool0=?ooool2o`0000?oo`00^_ooool3ool00003o`000?oooooooooo04ko
oooo000Nooooo`03o`000?oooooooooo03Kooooo0_l000000oooooooo`00ool0002fooooo`;oo`00
0_l0001Booooo`007_ooool00ol0003oooooooooo`0hooooo`;o000000?oooooool00?oo0000/_oo
ool2ool000;o0000E?ooool001kooooo00?o0000ooooooooool0>_ooool2o`000003oooooooo003o
o`000:kooooo0_oo0002o`0005Kooooo000Nooooo`03o`000?oooooooooo03cooooo0ol00002ool0
0:[ooooo0_oo0002o`0005Sooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo1Ol00005ooooo`03o`000?oooooooooo03oooooo0_l00002ool00:Kooooo0_oo00000ol0
003oooooooooo`1Iooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003oooooooooo`11ooooo`;o00000_oo002Q
ooooo`?oo`0000?o0000ooooooooool0Foooool000Cooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0A?ooool00ol0003oo`00ool0002M
ooooo`;oo`0000?o0000ooooooooool0G_ooool000Cooooo00Go0000ooooooooooooooooo`00000=
ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0ol00016ooooo`03o`000?oo003oo`0009Wooooo0_oo0000
0ol0003oooooooooo`1Pooooo`001?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMg
ofIVI_ooool01?ooool00ol0003oooooooooo`19ooooo`;oo`00U?ooool3ool006Gooooo0004oooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo04_ooooo0ooo002>ooooo`?oo`0000?o0000ooooooooool0IOooool000Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool00ol0003ooooooooo
o`1>ooooo`?oo`00R?ooool3ool00003o`000?oooooooooo06Sooooo0004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0
D?ooool00ol0003oo`00ool00023ooooo`?oo`000_l0001/ooooo`007_ooool00ol0003ooooooooo
o`1Cooooo`?oo`00OOooool3ool000;o0000Koooool001kooooo00?o0000ooooooooool0EOooool0
1?l0003oo`00ool00?oo001gooooo`?oo`000ol0001aooooo`007_ooool00ol0003oooooooooo`1H
ooooo`04o`000?oo003oo`00ool0077ooooo0ooo0003o`0007Cooooo000Nooooo`03o`000?oooooo
oooo05_ooooo00Co0000ool00?oo003oo`00Joooool3ool000?o0000Moooool001kooooo0ol0001O
ooooo`?oo`0000?o0000ooooooooool0HOooool4ool000;o0000Noooool001kooooo00?o0000oooo
ooooool0H_ooool4ool00003o`000?oooooooooo05Wooooo1?oo0002o`0007oooooo000Nooooo`03
o`000?oooooooooo06Kooooo1?oo001Dooooo`Coo`000_l00023ooooo`007_ooool00ol0003ooooo
ooooo`1Zooooo`Coo`00C?ooool4ool000?o0000Q_ooool001kooooo00?o0000ooooooooool0K_oo
ool6ool0047ooooo1Ooo0003o`0008[ooooo000Nooooo`03o`000?oooooooooo07;ooooo0_l00006
ool003Oooooo1?oo0004o`0008kooooo000Nooooo`03o`000?oooooooooo07Kooooo1?l00007ool0
02_ooooo1Ooo0004o`0009;ooooo000Nooooo`03o`000?oooooooooo083ooooo00?o0000ool00?oo
00002Ooo0003o`0000kooooo0ol0000<ool009_ooooo000Nooooo`03o`000?oooooooooo08cooooo
5?oo002Wooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo0004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool0
00Cooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001Oooool3o`000?ooooooB?ooool0
00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o
0000ooooooooool0oooooom8ooooo`001?ooool01Ol0003ooooooooooooooooo000000_ooooo00Co
gMgMoeEEEOoooooo00001_ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo
00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo
00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01Oooool00ol0
003oooooooooo`3oooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooB?ooool0
00Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05o`000?ooooooooooooooool000002ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Gooooo0ol0003oooooodSooooo0004ooooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo00?o0000oooooooo
ool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qooo
ool01oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool00ooMgMgo410@oiRHV007ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool0
0ol0003oooooooooo`3oooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooB?oo
ool000Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000
1Oooool3o`000?ooooooB?ooool000Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b
<_nHV9SooooooiRHV?lb<S801Oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05o`00
0?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Gooooo00?o0000oooo
ooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj
^_oooooo^[Zjoa0@4005ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001Oooool00ol0003ooooooooo
o`3oooooodSooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`00
0?l@413oZJVY00Gooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Gooooo1?l000000ol@413ooooo
ooooo`02ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`?o0000oooooom8oooo
o`005oooool00ol0003oooooooooo`3oooooodoooooo000Gooooo`03o`000?oooooooooo0?oooooo
Coooool001Oooooo00?o0000ooooooooool0oooooom?ooooo`005Oooool00omEEEGoIVIVo`00003o
oooooe7ooooo003oooooofWooooo002Eooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o
00001Oooool00ol0003o^[Zjooooo`2]ooooo`00UOooool00ol0003oooooooooo`0:ooooo`;o<S8b
3_ooool00ol0003oooooooooo`03ooooo`;o<S8b[_ooool008[ooooo00Go410@o`000?l0003o0000
oa0@4006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj
^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7
QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0Q?ooool008cooooo00?o
0000ooooooooool01_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3
ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oo
oooooooo00?ooooo00?oc<c<o`000?l@41001Oooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko
00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
08?ooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo
0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`22
ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q
8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool00oooool6o`0000;ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo08?ooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool0
1?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<08Cooooo0029ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o0000
00?o00001Oooool00ol0003oooooooooo`09ooooo`03oa0@4?l0003o000000?o00002_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0Q_ooool008Wooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo08Kooooo0029ooooo`Oo00001Oooool2
o`0001;ooooo00?o0000ooooooooool01Oooool2o`0000gooooo00?o0000ooooooooool02oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00025ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.101772, -0.0802184, \
0.00411939, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.1 .0304 L
.2 .05783 L
.3 .07959 L
.4 .09357 L
.5 .09838 L
.6 .09357 L
.7 .07959 L
.8 .05783 L
.9 .0304 L
1 0 L
s
1 0 0 r
0 0 m
.04057 .01234 L
.08481 .02557 L
.12636 .03755 L
.16632 .04847 L
.20885 .05925 L
.2498 .06863 L
.29331 .07736 L
.33524 .0844 L
.37557 .0898 L
.39599 .09199 L
.41848 .09396 L
.43982 .09539 L
.44937 .0959 L
.4598 .09635 L
.46545 .09655 L
.4707 .09671 L
.47614 .09685 L
.48106 .09695 L
.48591 .09703 L
.48813 .09706 L
.49048 .09708 L
.49299 .0971 L
.4941 .09711 L
.4953 .09711 L
.49658 .09712 L
.49778 .09712 L
.49852 .09712 L
.49921 .09712 L
.50051 .09712 L
.50171 .09712 L
.503 .09712 L
.50421 .09712 L
.50533 .09711 L
.50792 .09709 L
.51065 .09707 L
.51331 .09704 L
.51579 .097 L
.52142 .0969 L
.53077 .09667 L
.54076 .09633 L
.55151 .09586 L
.56317 .09522 L
.58433 .09374 L
.6273 .08946 L
.66867 .08381 L
.70845 .07703 L
.75081 .0685 L
.79157 .05915 L
.83491 .04814 L
Mistroke
.87666 .0367 L
.91682 .02509 L
.95955 .01231 L
1 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00D?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0<Oooool4o`000003oa0@4?oooooooooo01Gooooo001@ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00X
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B40:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<oooool00ol0003oooooooooo`0Gooooo`00D?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h0:Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Wooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002So
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<oooool0
0ol0003oooooooooo`0Gooooo`00D?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h0:?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
:?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Xoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03?ooooo00?o
0000ooooooooool05oooool0053ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002So
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0:?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00cooooo`03o`00
0?oooooooooo01Oooooo001@ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Vooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Xooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Zooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03?ooooo00?o0000ooooooooool05ooo
ool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000:?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000cooooo`03o`000?oooooooooo01Oooooo001@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<Oooool00omEEEGoIVIVo`00000Iooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Nooooo`?oo`00ool0000]o`0000;oo`002oooool01?o^k^ko8B4Qoa0@4?o^k^h:
ooooo`007_ooool00ol0003oooooooooo`03ool000[ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool01_l0
003oo`00ool00?oo003oooooo`0000_ooooo00Co8B4QogMgMomgMgOo<S8b2_ooool001kooooo00?o
0000ooooooooool00oooool3ool00003o`000?oooooooooo037ooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0<Ooo
ool2o`0000?oo`001?ooool00ol0003oooooooooo`08ooooo`;o00000_ooool2o`0000Wooooo000N
ooooo`03o`000?oooooooooo00Kooooo0ooo00000ol0003oooooooooo`3ooooooaKooooo0_l00003
ool0027ooooo000Nooooo`03o`000?oooooooooo00Wooooo1?oo00000ol0003oooooooooo`3ooooo
o`kooooo0_l00004ool002Cooooo000Nooooo`03o`000?oooooooooo00gooooo0ooo00000ol0003o
ooooooooo`3oooooo`Sooooo0_l00003ool002Sooooo000Nooooo`03o`000?oooooooooo013ooooo
0ooo00000ol0003oooooooooo`3oooooo`;ooooo0_l00003ool002_ooooo000Nooooo`03o`000?oo
oooooooo01?ooooo0ooo0002o`000?_ooooo0ol00003ool002kooooo000Nooooo`03o`000?oooooo
oooo01Kooooo1?oo00000ol0003oooooooooo`3cooooo`;o00001?oo000aooooo`007_ooool00ol0
003oooooooooo`0Jooooo`?oo`000_l0003]ooooo`03o`000?oo003oo`0000?oo`00=Oooool001ko
oooo0ol0000Mooooo`?oo`000_l0003Wooooo`Coo`00>_ooool001kooooo00?o0000ooooooooool0
8?ooool3ool000;o0000hOooool3ool003kooooo000Nooooo`03o`000?oooooooooo02?ooooo1?oo
0002o`000=Wooooo00Co0000ool00?oo003oo`00@Oooool001kooooo00?o0000ooooooooool09ooo
ool4ool00003o`000?oooooooooo0=7ooooo00Co0000ool00?oo003oo`00A?ooool001kooooo00?o
0000ooooooooool0:oooool4ool00<gooooo00Co0000ool00?oo003oo`00Aoooool001kooooo00?o
0000ooooooooool0;oooool4ool00<Gooooo00?o0000ool00?oo00000_oo001:ooooo`007_ooool0
0ol0003oooooooooo`0cooooo`Goo`00_?ooool5ool004kooooo000Nooooo`03o`000?oooooooooo
03Kooooo0_l00004ool00;Cooooo1?oo00000ol0003oooooooooo`1@ooooo`007_ooool00ol0003o
ooooooooo`0iooooo`?o00001?oo002/ooooo`Coo`000_l0001Eooooo`007_ooool3o`0003kooooo
0_l00004ool00:?ooooo1Ooo0002o`0005Wooooo000Nooooo`03o`000?oooooooooo04?ooooo00?o
0000ool00?oo00000_oo002Kooooo`Coo`000_l0001Nooooo`007_ooool00ol0003oooooooooo`18
ooooo`Coo`0000?o0000ooooooooool0T?ooool4ool00003o`000?oooooooooo067ooooo000Noooo
o`03o`000?oooooooooo04cooooo1Ooo00000ol0003oooooooooo`26ooooo`Goo`00J?ooool001ko
oooo00?o0000ooooooooool0DOooool4ool000;o0000O_ooool00ol0003oo`00ool00002ool006go
oooo000Nooooo`03o`000?oooooooooo05Gooooo1Ooo0002o`0007?ooooo0_l00005ool0077ooooo
000Nooooo`03o`000?oooooooooo05[ooooo1ooo00000ol0003oooooooooo`1Uooooo`;o00001_oo
001fooooo`007_ooool00ol0003oooooooooo`1Qooooo`Woo`00F?ooool9ool007cooooo000Noooo
o`03o`000?oooooooooo06Wooooo00?o0000ool00?oo00002?oo0015ooooo`Woo`00QOooool001ko
oooo0ol0001_ooooo`Go00001_oo000hooooo`Ooo`000ol0002;ooooo`007_ooool00ol0003ooooo
ooooo`1eooooo`Go00004_oo000Doooooa;oo`001?l0002Aooooo`007_ooool00ol0003ooooooooo
o`27ooooo`Go00005?oo0004o`000:?ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom8ooooo`001?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01Oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0ol0003oooooodSo
oooo0004ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`04ooooo`03
o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo
0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l00000
0ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?ooooooB?ooool000Cooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001Oooool3
o`000?ooooooB?ooool000Cooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgo
ooooo`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol0003ooooooooooooo
oooo000000_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003oooooooooo`3oooooodSooooo
0004ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`03o`00
0?oooooooooo0?ooooooB?ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^
k_m4A4Co000000Kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`01Oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@05ooooo`03o`000?oooooo
oooo0?ooooooB?ooool000Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Gooooo0ol0003oooooodSooooo
0004ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Go
oooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooooooo410@00_o
oooo00?oEEEEohN7Qoooool01oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV007ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@
40Gooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oo
ooooooooooooool000001Oooool3o`000?ooooooB?ooool000Cooooo00Go0000oooooooooooooooo
o`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801Oooool00ol0003oooooooooo`3oooooodSo
oooo0004ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<
00Gooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4005ooooo`03o`000?oooooooooo0?ooooooB?ooool0
00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001Ooo
ool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY00Gooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Gooooo
1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool00ol0003oooooooooo`04oooo
o`?o0000oooooom8ooooo`005oooool00ol0003oooooooooo`3oooooodoooooo000Gooooo`03o`00
0?oooooooooo0?ooooooCoooool001Oooooo00?o0000ooooooooool0oooooom?ooooo`005Oooool0
0omEEEGoIVIVo`00003ooooooe7ooooo003oooooofWooooo002Aooooo`;o00002oooool00ol0003o
^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2aooooo`00TOooool00ol0003ooooo
ooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b/_ooool008Kooooo00Go
410@o`000?l0003o0000oa0@4006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?o
oooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000oooo
ooooool00oooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@20ooooo`00R?ooool00ol0003oooooooooo`06ooooo`0:o`000?oo
ooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool0
1Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool00oooool00oo<c<co0000oa0@
4005ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l00002ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`1ooooo
o`00R?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@
413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool0
0ol0003oooooooooo`1nooooo`00R?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00oooool6o`0000;ooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool0Ooooool008Sooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c020ooooo`00QOooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`00
00Gooooo00?o0000ooooooooool02Oooool00ol@413o0000o`000003o`0000[ooooo00Go410@oooo
oooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0P_ooool0
08Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S80
1?ooool00ol0003oooooooooo`22ooooo`00QOooool7o`0000Gooooo0_l0000Booooo`03o`000?oo
oooooooo00Gooooo0_l0000=ooooo`03o`000?oooooooooo00_ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`Go00001?ooool4o`00087ooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.101772, -0.0802184, \
0.00411939, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.1 .01648 L
.2 .03134 L
.3 .04314 L
.4 .05071 L
.5 .05332 L
.6 .05071 L
.7 .04314 L
.8 .03134 L
.9 .01648 L
1 0 L
s
1 0 0 r
0 0 m
.04057 .00666 L
.08481 .0138 L
.12636 .02026 L
.16632 .02616 L
.20885 .03197 L
.2498 .03704 L
.29331 .04175 L
.33524 .04555 L
.37557 .04846 L
.39599 .04964 L
.41848 .0507 L
.43982 .05148 L
.44937 .05175 L
.4598 .05199 L
.46545 .0521 L
.4707 .05219 L
.47614 .05227 L
.48106 .05232 L
.48591 .05236 L
.48813 .05238 L
.49048 .05239 L
.49299 .0524 L
.4941 .0524 L
.4953 .05241 L
.49658 .05241 L
.49778 .05241 L
.49852 .05241 L
.49921 .05241 L
.50051 .05241 L
.50171 .05241 L
.503 .05241 L
.50421 .05241 L
.50533 .05241 L
.50792 .0524 L
.51065 .05238 L
.51331 .05237 L
.51579 .05235 L
.52142 .05229 L
.53077 .05217 L
.54076 .05198 L
.55151 .05173 L
.56317 .05138 L
.58433 .05058 L
.6273 .04828 L
.66867 .04522 L
.70845 .04157 L
.75081 .03697 L
.79157 .03192 L
.83491 .02598 L
Mistroke
.87666 .0198 L
.91682 .01354 L
.95955 .00664 L
1 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00D?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0<Oooool4o`000003oa0@4?oooooooooo01Gooooo001@ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00X
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B40:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<oooool00ol0003oooooooooo`0Gooooo`00D?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h0:Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Wooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002So
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<oooool0
0ol0003oooooooooo`0Gooooo`00D?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h0:?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
:?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Xoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03?ooooo00?o
0000ooooooooool05oooool0053ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002So
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0:?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00cooooo`03o`00
0?oooooooooo01Oooooo001@ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Vooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Xooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Zooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03?ooooo00?o0000ooooooooool05ooo
ool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000:?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000cooooo`03o`000?oooooooooo01Oooooo001@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<Oooool00omEEEGoIVIVo`00000Iooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Nooooo`Coo`00ool0000Zo`0000Coo`002oooool01?o^k^ko8B4Qoa0@4?o^k^h:
ooooo`007_ooool01?l0003oooooooooooooool7ool000Gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool6
ool000?ooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oo003oo`0000Coo`00;?ooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oo003oo`0000Coo`002Oooool00ol0003oooooooooo`08ooooo`;o00000_ooool2
o`0000Wooooo000Nooooo`03o`000?oooooooooo00kooooo1ooo003oooooo`?ooooo1ooo000Yoooo
o`007_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0000Coo`00m_ooool6ool0033o
oooo000Nooooo`03o`000?oooooooooo01[ooooo00?o0000ool00?oo00001Ooo003Xooooo`Ooo`00
=_ooool001kooooo00?o0000ooooooooool08?ooool2o`0000Koo`00g?ooool6ool00003o`000?oo
oooooooo03[ooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l00006ool00=3ooooo1_oo0000
0ol0003oooooooooo`10ooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o00001_oo0034oooo
o`Koo`0000?o0000ooooooooool0A_ooool001kooooo00?o0000ooooooooool0<_ooool2o`0000Oo
o`00]_ooool7ool00003o`000?oooooooooo04cooooo000Nooooo`?o0000>?ooool3o`0000Woo`00
Y?ooool9ool000;o0000E?ooool001kooooo00?o0000ooooooooool0@?ooool4o`0000Woo`00TOoo
ool:ool000?o0000G?ooool001kooooo00?o0000ooooooooool0B_ooool3o`0000Ooo`00Poooool7
ool000?o0000I_ooool001kooooo00?o0000ooooooooool0E?ooool:ool006oooooo00?o0000ool0
0?oo00001ooo001`ooooo`007_ooool00ol0003oooooooooo`1Nooooo`coo`00F?ooool<ool007Wo
oooo000Nooooo`03o`000?oooooooooo06Wooooo00?o0000ool00?oo00003_oo000looooo`coo`00
QOooool001kooooo00?o0000ooooooooool0Loooool7o`0003coo`000_l0002?ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Go
oooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003oooooooooo`3ooooo
odSooooo0004ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP06oooo
o`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00Gooooo0ol0003oooooodSooooo0004ooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000Co
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooom8ooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go410@
oooooooooooooooooa0@400;ooooo`Go00001Oooool3o`000?ooooooB?ooool000Cooooo00Go0000
ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000ooooooooool0
oooooom8ooooo`001?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo
00001_ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00omgMgOoc<c<o`000006ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?oo
ool01Oooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01Oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEE
ogMgMoooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go410@
oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
ooooo`3oooooodSooooo0004ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RH
oooooonHV9So8B4Q00Gooooo0ol0003oooooodSooooo0004ooooo`05o`000?ooooooooooooooool0
00002oooool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0oooooom8oooo
o`001?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool01oooool00ol0
003oooooooooo`3oooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooM
gMgo410@oiRHV007ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0
003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool00ol0003ooooooooo
o`3oooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
8B4QoiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go
410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool3o`000?oo
ooooB?ooool000Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRH
V?lb<S801Oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05o`000?oooooooooooooo
ool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Gooooo00?o0000ooooooooool0oooooom8
ooooo`001?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@
4005ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooookZj^_l000001Oooool00ol0003oooooooooo`3oooooodSooooo
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Go
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3
o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001Gooooo1?l000000ol@413oooooooooo`02ooooo`03
o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom8ooooo`005oooool00ol0003oooooooooo`04ooooo`?o0000oooooom8ooooo`005oooool00ol0
003oooooooooo`3oooooodoooooo000Gooooo`03o`000?oooooooooo0?ooooooCoooool001Oooooo
00?o0000ooooooooool0oooooom?ooooo`005Oooool00omEEEGoIVIVo`00003ooooooe7ooooo003o
ooooofWooooo002Hooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001_ooool00ol0
003o^[Zjooooo`2Yooooo`00V?ooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003o
ooooooooo`04ooooo`;o<S8bZ_ooool008kooooo00Go410@o`000?l0003o0000oa0@4005ooooo`03
o`000?oooooooooo00;ooooo0_l00002ooooo`;o00000_ooool00on7QhOo0000okZj^P05ooooo`05
oiRHV?l0003o0000odA4A?nj^[X00oooool00ol0003oooooooooo`04ooooo`03ohN7Qol0003o^[Zj
00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`Co000000?o410@ooooooooool00_ooool2
ob4Q8H_ooooo002@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01_o^
k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^
k_mgMgOo410@00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@4004ooooo`05oa0@
4?nj^[[ok^k^ogMgMol@41000_ooool6o`0000Cooooo00?o0000ooooooooool01?ooool2ob4Q8H_o
oooo002@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01?oMgMgo0000
oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo097ooooo002@ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`Ko00001?ooool00ol0003o
ooooooooo`2Aooooo`00T?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2Aooooo`00SOooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000;o
oooo0_l00008ooooo`03oa0@4?l0003o000000?o00001?ooool00ol0003oooooooooo`09ooooo`03
oa0@4?l0003o000000?o00003Oooool00ol0003oooooooooo`2Aooooo`00SOooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`2Aooooo`00SOooool7o`0000Cooooo0_l0000Cooooo`03o`000?oooooooooo00Cooooo
0_l0000=ooooo`03o`000?oooooooooo00cooooo00?oEEEEofIVI_l00000Toooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.101772, -0.0802184, \
0.00411939, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.1 .00893 L
.2 .01699 L
.3 .02338 L
.4 .02748 L
.5 .0289 L
.6 .02748 L
.7 .02338 L
.8 .01699 L
.9 .00893 L
1 0 L
s
1 0 0 r
0 0 m
.04057 .00359 L
.08481 .00745 L
.12636 .01094 L
.16632 .01412 L
.20885 .01725 L
.2498 .01999 L
.29331 .02253 L
.33524 .02458 L
.37557 .02615 L
.39599 .02679 L
.41848 .02736 L
.43982 .02778 L
.44937 .02793 L
.4598 .02806 L
.46545 .02812 L
.4707 .02816 L
.47614 .0282 L
.48106 .02823 L
.48591 .02826 L
.48813 .02826 L
.49048 .02827 L
.49299 .02828 L
.4941 .02828 L
.4953 .02828 L
.49658 .02828 L
.49778 .02828 L
.49852 .02828 L
.49921 .02828 L
.50051 .02828 L
.50171 .02828 L
.503 .02828 L
.50421 .02828 L
.50533 .02828 L
.50792 .02828 L
.51065 .02827 L
.51331 .02826 L
.51579 .02825 L
.52142 .02822 L
.53077 .02815 L
.54076 .02805 L
.55151 .02791 L
.56317 .02773 L
.58433 .0273 L
.6273 .02605 L
.66867 .02441 L
.70845 .02243 L
.75081 .01995 L
.79157 .01722 L
.83491 .01402 L
Mistroke
.87666 .01069 L
.91682 .00731 L
.95955 .00358 L
1 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00D?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0<Oooool4o`000003oa0@4?oooooooooo01Gooooo001@ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00X
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B40:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<oooool00ol0003oooooooooo`0Gooooo`00D?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h0:Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Wooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002So
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<oooool0
0ol0003oooooooooo`0Gooooo`00D?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h0:?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
:?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Xoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03?ooooo00?o
0000ooooooooool05oooool0053ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002So
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0:?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00cooooo`03o`00
0?oooooooooo01Oooooo001@ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Vooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Xooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Zooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03?ooooo00?o0000ooooooooool05ooo
ool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000:?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000cooooo`03o`000?oooooooooo01Oooooo001@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<Oooool00omEEEGoIVIVo`00000Iooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Nooooo`Soo`00ool0000So`0000Ooo`002oooool01?o^k^ko8B4Qoa0@4?o^k^h:
ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o00003Ooo000:ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02_ooool<ool00003o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool00ol0003oooooooooo`0>oooo
o`Co00003Ooo000Kooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo01_ooooo3Ooo0002o`00013ooooo00?o0000oooo
ooooool02?ooool2o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`0Hooooo`Oo
00003?oo003Fooooo`goo`001Ol0000dooooo`007_ooool00ol0003oooooooooo`0Uooooo`Ko0000
3Ooo002mooooo`coo`001_l00010ooooo`007_ooool00ol0003oooooooooo`0dooooo`Co00003?oo
002Tooooo`goo`000ol0001?ooooo`007_ooool00ol0003oooooooooo`13ooooo`03o`000?oo003o
o`0000_oo`0000?o0000ooooooooool0Q_ooool00ol0003oo`00ool0000;ool00003o`000?oooooo
oooo05cooooo000Nooooo`03o`000?oooooooooo057ooooo3Ooo0003o`0006Wooooo1?l0000=ool0
06cooooo000Nooooo`03o`000?oooooooooo05kooooo8ooo000[ooooob;oo`00NOooool001kooooo
00?o0000ooooooooool0L?oooolAo`0002_oo`003ol0002<ooooo`007_ooool3o`000?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol00005ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Go
oooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05ooooo`?o0000oooooom8ooooo`00
1?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo0004ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`3ooooo
odSooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Gooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo0ol0003o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0
0006ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`001?oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003ooooo
ooooo`3oooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4
o`000006ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
00Gooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401Oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000000Gooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@05ooooo`?o0000oooooom8ooooo`001?oo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c005ooooo`03
o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go410@oooooooooooooooooa0@400;ooooo`03
oeEEEOn7QhOooooo00Oooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P01oooool00ol0003oooooooooo`3oooooodSo
oooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4105oooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Gooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401Oooool00ol0003ooooooooo
o`3oooooodSooooo0004ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000000Gooooo0ol0003oooooodSooooo0004ooooo`05o`000?ooooooooooooooool00000
2oooool01Olb<S;oV9RHoooooonHV9So<S8b00Gooooo00?o0000ooooooooool0oooooom8ooooo`00
1?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c005oooo
o`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?nj^[[ooooookZj^_l@41001Oooool00ol0003oooooooooo`3oooooodSooooo0004oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Gooooo00?o
0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@05ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Eooooo`Co0000
00?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo000Gooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool3o`00
0?ooooooB?ooool001Oooooo00?o0000ooooooooool0oooooom?ooooo`005oooool00ol0003ooooo
ooooo`3oooooodoooooo000Gooooo`03o`000?oooooooooo0?ooooooCoooool001Gooooo00?oEEEE
ofIVI_l00000oooooomAooooo`00oooooomYooooo`00TOooool2o`0000_ooooo00?o0000okZj^_oo
ool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0/Oooool0097ooooo00?o0000ooooooooool0
2_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<[;ooooo0026ooooo`05oa0@4?l0
003o0000o`000?l@41001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03
ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo
00?ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00[ooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@20ooooo`00R?ooool00ol0003oooooooooo`06ooooo`0:o`000?ooooooooooooooooo^k^ko8B4Q
ohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo
410@00Cooooo00?o0000ooooooooool00oooool00oo<c<co0000oa0@4005ooooo`06oa0@4?nj^[[o
k^k^ogMgMol@413ooooo1_l00005ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`1oooooo`00R?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0O_ooool008Sooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?o
oooo1_l00005ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo
<S8booooo`1oooooo`00R?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo
00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c020ooooo`00QOooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool0
0ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool02Oooool00ol@413o0000o`000003
o`0000gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo08;ooooo0025ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo08;ooooo0025ooooo`Oo00001Oooool2o`0001;ooooo00?o0000
ooooooooool01Oooool2o`0000gooooo00?o0000ooooooooool03?ooool00omEEEGoIVIVo`00000<
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00087ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.101772, -0.0802184, \
0.00411939, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.1 .00484 L
.2 .00921 L
.3 .01267 L
.4 .01489 L
.5 .01566 L
.6 .01489 L
.7 .01267 L
.8 .00921 L
.9 .00484 L
1 0 L
s
1 0 0 r
0 0 m
.04057 .00194 L
.08481 .00402 L
.12636 .0059 L
.16632 .00762 L
.20885 .00931 L
.2498 .01079 L
.29331 .01216 L
.33524 .01326 L
.37557 .01411 L
.39599 .01446 L
.41848 .01477 L
.43982 .01499 L
.44937 .01507 L
.4598 .01514 L
.46545 .01517 L
.4707 .0152 L
.47614 .01522 L
.48106 .01524 L
.48591 .01525 L
.48813 .01525 L
.49048 .01526 L
.49299 .01526 L
.4941 .01526 L
.4953 .01526 L
.49658 .01526 L
.49778 .01526 L
.49852 .01526 L
.49921 .01526 L
.50051 .01526 L
.50171 .01526 L
.503 .01526 L
.50421 .01526 L
.50533 .01526 L
.50792 .01526 L
.51065 .01525 L
.51331 .01525 L
.51579 .01524 L
.52142 .01523 L
.53077 .01519 L
.54076 .01514 L
.55151 .01506 L
.56317 .01496 L
.58433 .01473 L
.6273 .01406 L
.66867 .01317 L
.70845 .01211 L
.75081 .01077 L
.79157 .0093 L
.83491 .00757 L
Mistroke
.87666 .00577 L
.91682 .00394 L
.95955 .00193 L
1 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00D?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0<Oooool4o`000003oa0@4?oooooooooo01Gooooo001@ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00X
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B40:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<oooool00ol0003oooooooooo`0Gooooo`00D?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h0:Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Wooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002So
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<oooool0
0ol0003oooooooooo`0Gooooo`00D?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h0:?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
:?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Xoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03?ooooo00?o
0000ooooooooool05oooool0053ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002So
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0:?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00cooooo`03o`00
0?oooooooooo01Oooooo001@ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Vooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Xooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Zooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03?ooooo00?o0000ooooooooool05ooo
ool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000:?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000cooooo`03o`000?oooooooooo01Oooooo001@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<Oooool00omEEEGoIVIVo`00000Iooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Nooooo`Soo`00ool0000So`0000Ooo`002oooool01?o^k^ko8B4Qoa0@4?o^k^h:
ooooo`007_ooool00ol0003oooooooooo`05oooooa[oo`003?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oooolIool000Kooooo00?o0000oooo
ooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool00ol0003oooooooooo`0Eoooo
o`[o00006Ooo0002ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo00;ooooo6Ooo0008o`0001Oooooo00?o0000oooo
ooooool02?ooool2o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`0/ooooo`co
00006Ooo002:oooooa[oo`002_l00018ooooo`007_ooool00ol0003oooooooooo`1:ooooo`Oo0000
8ooo0012ooooobGoo`001_l0001Vooooo`007_ooool00ol0003oooooooooo`1Yooooo`_o0000@_oo
000=o`0008Cooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
1Oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000Cooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Ko
oooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?ooooooB?ooool000Cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`00
1?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`3oooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom8ooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@
413ooooooooooooooooo410@00_ooooo1Ol00005ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001_ooool00ol0003ooooooooo
o`3oooooodSooooo0004ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEoooo
ool00006ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03ogMgMoo<c<co000000Kooooo00?o0000ooooooooool0oooooom8ooooo`001?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001_ooool00ol0003ooooo
ooooo`3oooooodSooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000
ooooo`05ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c005ooooo`03o`000?oooooooooo
0?ooooooB?ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401Oooool3o`000?ooooooB?ooool000Cooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01Oooool00ol0003oooooooooo`3oooooodSo
oooo0004ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`07ooooo`03
o`000?oooooooooo0?ooooooB?ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03
omgMgOl@413oV9RH00Oooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1Oooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3
o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c005ooooo`03o`000?oooooo
oooo0?ooooooB?ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000005ooooo`?o0000
oooooom8ooooo`001?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oooooo
V9RHoc8b<P05ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01Oooool00ol0003oooooooooo`3ooooo
odSooooo0004ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o
410@00Gooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000005ooooo`03o`000?oooooooooo0?ooooooB?oo
ool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
1Oooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`005Oooool4o`000003oa0@4?oooooooooo00;ooooo
00?o0000ooooooooool0oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
ooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo0ol0003oooooodSooooo000Gooooo`03
o`000?oooooooooo0?ooooooCoooool001Oooooo00?o0000ooooooooool0oooooom?ooooo`005ooo
ool00ol0003oooooooooo`3oooooodoooooo000Eooooo`03oeEEEOmVIVKo00000?ooooooDOooool0
0?ooooooJOooool009Gooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00005ooooo`03
o`000?nj^[[ooooo0:gooooo002Eooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`00
0?oooooooooo00?ooooo0_lb<S:^ooooo`00R_ooool01Ol@413o0000o`000?l0003o410@00Kooooo
00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05
oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`03ooooo`03ohN7Qol0003o^[Zj
00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`Co000000?o410@ooooooooool00_ooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@24ooooo`00S?ooool00ol0003oooooooooo`06
ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`00
0?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool00oooool0
0oo<c<co0000oa0@4005ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l00005ooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo08?ooooo002<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0P_ooool008cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo1_l00005ooooo`03o`00
0?oooooooooo00kooooo00?oMgMgoc8b<_ooool0Poooool008cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<08Cooooo0029ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008oooo
o`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`09ooooo`03oa0@4?l0003o0000
00?o00003Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo08Kooooo0029ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Q_ooool008Wooooo1ol00005ooooo`;o
00004_ooool00ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003oooooooooo`0<ooooo`03
oeEEEOmVIVKo000000gooooo1?l00025ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.101772, -0.0802184, \
0.00411939, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.1 .00262 L
.2 .00499 L
.3 .00687 L
.4 .00807 L
.5 .00849 L
.6 .00807 L
.7 .00687 L
.8 .00499 L
.9 .00262 L
1 0 L
s
1 0 0 r
0 0 m
.04057 .00105 L
.08481 .00217 L
.12636 .00318 L
.16632 .00411 L
.20885 .00502 L
.2498 .00582 L
.29331 .00656 L
.33524 .00716 L
.37557 .00762 L
.39599 .0078 L
.41848 .00797 L
.43982 .00809 L
.44937 .00813 L
.4598 .00817 L
.46545 .00819 L
.4707 .0082 L
.47614 .00821 L
.48106 .00822 L
.48591 .00823 L
.48813 .00823 L
.49048 .00823 L
.49299 .00823 L
.4941 .00824 L
.4953 .00824 L
.49658 .00824 L
.49778 .00824 L
.49852 .00824 L
.49921 .00824 L
.50051 .00824 L
.50171 .00824 L
.503 .00824 L
.50421 .00824 L
.50533 .00824 L
.50792 .00823 L
.51065 .00823 L
.51331 .00823 L
.51579 .00823 L
.52142 .00822 L
.53077 .0082 L
.54076 .00817 L
.55151 .00813 L
.56317 .00807 L
.58433 .00795 L
.6273 .00759 L
.66867 .00711 L
.70845 .00653 L
.75081 .00581 L
.79157 .00502 L
.83491 .00408 L
Mistroke
.87666 .00311 L
.91682 .00213 L
.95955 .00104 L
1 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00D?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0<Oooool4o`000003oa0@4?oooooooooo01Gooooo001@ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00X
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B40:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<oooool00ol0003oooooooooo`0Gooooo`00D?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h0:Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Wooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002So
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<oooool0
0ol0003oooooooooo`0Gooooo`00D?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h0:?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
:?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Xoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03?ooooo00?o
0000ooooooooool05oooool0053ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002So
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0:?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00cooooo`03o`00
0?oooooooooo01Oooooo001@ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Vooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Xooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Zooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03?ooooo00?o0000ooooooooool05ooo
ool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000:?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000cooooo`03o`000?oooooooooo01Oooooo001@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<Oooool00omEEEGoIVIVo`00000Iooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000NoooooaGoo`00ool0000:o`0001?oo`002oooool01?o^k^ko8B4Qoa0@4?o^k^h:
ooooo`007_ooool00ol0003oooooooooo`0=ooooo`Go00009_oo0002ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00;ooooo9_oo0004o`0000kooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:
ooooo`007_ooool00ol0003oooooooooo`0/ooooo`co0000??oo0003ooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool0?ooo000:o`0002kooooo00?o0000ooooooooool02?ooool2o`00
00;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`1Yooooo`_o0000@_oo000=o`0008Co
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo
00?o0000ooooooooool0oooooom8ooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003oooooooooo`3oooooodSo
oooo0004ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP06ooooo`03
o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^00Gooooo0ol0003oooooodSooooo0004ooooo`05o`000?ooooooooooooooool0
00003_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0oooooom8ooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4005ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo0?ooooooB?ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go410@oooo
oooooooooooooa0@400;ooooo`Go00001Oooool3o`000?ooooooB?ooool000Cooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000ooooooooool0oooo
oom8ooooo`001?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo0000
1_ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00omgMgOoc<c<o`000006ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo00?o0000ooooooooool0
oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0
1Oooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01Oooool00ol0003oooooooooo`3ooooo
odSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMg
MoooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooooooo
o`3oooooodSooooo0004ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooo
oonHV9So8B4Q00Gooooo0ol0003oooooodSooooo0004ooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0oooooom8ooooo`00
1?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool01oooool00ol0003o
ooooooooo`3oooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo
410@oiRHV007ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go410@
oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool3o`000?oooooo
B?ooool000Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S801Oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05o`000?ooooooooooooooool0
00002oooool01Oo<c<co0000o`000?l0003oc<c<00Gooooo00?o0000ooooooooool0oooooom8oooo
o`001?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4005
ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l000001Oooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Gooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`00
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001Gooooo1?l000000ol@413oooooooooo`02ooooo`03o`00
0?oooooooooo0?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8
ooooo`005oooool00ol0003oooooooooo`04ooooo`?o0000oooooom8ooooo`005oooool00ol0003o
ooooooooo`3oooooodoooooo000Gooooo`03o`000?oooooooooo0?ooooooCoooool001Oooooo00?o
0000ooooooooool0oooooom?ooooo`005Oooool00omEEEGoIVIVo`00003ooooooe7ooooo003ooooo
ofWooooo002Aooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o
^[Zjooooo`2aooooo`00TOooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003ooooo
ooooo`03ooooo`;o<S8b/_ooool008Kooooo00Go410@o`000?l0003o0000oa0@4006ooooo`04o`00
0?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So
0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7QhOo0000okZj^P05oooo
o`05oiRHV?l0003o0000odA4A?nj^[X02_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@20ooooo`00R?ooool0
0ol0003oooooooooo`06ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgM
g@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000
ooooooooool00oooool00oo<c<co0000oa0@4005ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo
1_l00005ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo
00?oMgMgoc8b<_ooool0Ooooool008Sooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool00onYZJWoEEEE
ooooo`08ooooo`03o`000?oooooooooo07kooooo0028ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0003ooooo
ooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool0Ooooool008Sooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`0P?ooool008Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005oooo
o`03o`000?oooooooooo00Wooooo00?o410@o`000?l000000ol0000=ooooo`03o`000?oooooooooo
00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`22ooooo`00QOooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`22
ooooo`00QOooool7o`0000Gooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0000=oooo
o`03o`000?oooooooooo00cooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00021oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.101772, -0.0802184, \
0.00411939, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.1 .00142 L
.2 .0027 L
.3 .00372 L
.4 .00437 L
.5 .0046 L
.6 .00437 L
.7 .00372 L
.8 .0027 L
.9 .00142 L
1 0 L
s
1 0 0 r
0 0 m
.04057 .00056 L
.08481 .00117 L
.12636 .00172 L
.16632 .00222 L
.20885 .00271 L
.2498 .00314 L
.29331 .00354 L
.33524 .00386 L
.37557 .00411 L
.39599 .00421 L
.41848 .0043 L
.43982 .00437 L
.44937 .00439 L
.4598 .00441 L
.46545 .00442 L
.4707 .00443 L
.47614 .00443 L
.48106 .00444 L
.48591 .00444 L
.48813 .00444 L
.49048 .00444 L
.49299 .00444 L
.4941 .00444 L
.4953 .00444 L
.49658 .00444 L
.49778 .00444 L
.49852 .00444 L
.49921 .00444 L
.50051 .00444 L
.50171 .00444 L
.503 .00444 L
.50421 .00444 L
.50533 .00444 L
.50792 .00444 L
.51065 .00444 L
.51331 .00444 L
.51579 .00444 L
.52142 .00443 L
.53077 .00442 L
.54076 .00441 L
.55151 .00439 L
.56317 .00436 L
.58433 .00429 L
.6273 .00409 L
.66867 .00384 L
.70845 .00353 L
.75081 .00313 L
.79157 .00271 L
.83491 .0022 L
Mistroke
.87666 .00168 L
.91682 .00115 L
.95955 .00056 L
1 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00D?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0<Oooool4o`000003oa0@4?oooooooooo01Gooooo001@ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00X
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B40:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<oooool00ol0003oooooooooo`0Gooooo`00D?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h0:Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Wooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002So
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<oooool0
0ol0003oooooooooo`0Gooooo`00D?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h0:?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
:?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Xoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03?ooooo00?o
0000ooooooooool05oooool0053ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002So
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0:?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00cooooo`03o`00
0?oooooooooo01Oooooo001@ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Vooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Xooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Zooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03?ooooo00?o0000ooooooooool05ooo
ool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000:?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000cooooo`03o`000?oooooooooo01Oooooo001@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<Oooool00omEEEGoIVIVo`00000Iooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000NoooooaGoo`00ool0000:o`0001?oo`002oooool01?o^k^ko8B4Qoa0@4?o^k^h:
ooooo`007_ooool00ol0003oooooooooo`0=ooooo`Go0000Mooo000<ooooo`03o`000?oooooooooo
00_oooooN?oo0004o`0000kooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:
ooooo`007_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool03Oooool2o`0001[oo`0000?o0000ooooooooool03Oooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02?ooool2o`0000;ooooo0_l00009oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom8ooooo`001?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01Oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0ol0003oooooodSo
oooo0004ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`04ooooo`03
o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo
0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l00000
0ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?ooooooB?ooool000Cooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001Oooool3
o`000?ooooooB?ooool000Cooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgo
ooooo`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol0003ooooooooooooo
oooo000000_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003oooooooooo`3oooooodSooooo
0004ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`03o`00
0?oooooooooo0?ooooooB?ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^
k_m4A4Co000000Kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`01Oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@05ooooo`03o`000?oooooo
oooo0?ooooooB?ooool000Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Gooooo0ol0003oooooodSooooo
0004ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Go
oooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooooooo410@00_o
oooo00?oEEEEohN7Qoooool01oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV007ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@
40Gooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oo
ooooooooooooool000001Oooool3o`000?ooooooB?ooool000Cooooo00Go0000oooooooooooooooo
o`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801Oooool00ol0003oooooooooo`3oooooodSo
oooo0004ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<
00Gooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4005ooooo`03o`000?oooooooooo0?ooooooB?ooool0
00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001Ooo
ool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY00Gooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Gooooo
1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool00ol0003oooooooooo`04oooo
o`?o0000oooooom8ooooo`005oooool00ol0003oooooooooo`3oooooodoooooo000Gooooo`03o`00
0?oooooooooo0?ooooooCoooool001Oooooo00?o0000ooooooooool0oooooom?ooooo`005Oooool0
0omEEEGoIVIVo`00003ooooooe7ooooo003oooooofWooooo002Hooooo`;o00002oooool00ol0003o
^[Zjooooo`0<ooooo`;o00001_ooool00ol0003o^[Zjooooo`2Yooooo`00V?ooool00ol0003ooooo
ooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`04ooooo`;o<S8bZ_ooool008kooooo00Go
410@o`000?l0003o0000oa0@4005ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o0000
0_ooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool00ol0003o
ooooooooo`04ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P09oooo
o`Go00001Oooool2ob4Q8H_ooooo002@ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41001Oooool0
1Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@
4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool6o`000006oooooonHV9So8B4Qonk^k_oo
ooooA4A41Oooool2ob4Q8H_ooooo002@ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^09?ooooo002@ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01?o^k^ko8B4Qoa0@4?o^k^h;oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04oooo
o`Ko00000oooool00onHV9So8B4Qonk^kP2Booooo`00T?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00omgMgOoIVIVooooo`2Aoooo
o`00SOooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001?ooool00ol0
003oooooooooo`09ooooo`03oa0@4?l0003o000000?o00003_ooool00ol0003oooooooooo`2@oooo
o`00SOooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool01Ol0003o^[ZjoooooonHV9So410@09;ooooo002=ooooo`Oo00001?ooool2o`00
01?ooooo00?o0000ooooooooool01?ooool2o`0000gooooo00?o0000ooooooooool02oooool01OnH
V9So410@o`000?lQ8B7oc<c<09;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.101772, -0.0802184, \
0.00411939, 0.00666531}}]
}, Closed]]
}, Open  ]],

Cell["\<\
The method works beautifully, following the exact result precisely \
even for these rather course grids in time and space.\
\>", "Text"],

Cell["\<\
\tFinally, we note that, just as it was possible to create an \
interpolation function for grid solutions to ODEs, it is possible to do the \
same for grid solutions to PDEs:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Tsol\  = \ 
      Interpolation[
        Flatten[Table[
            Table[{j\ \[CapitalDelta]x, n\ \[CapitalDelta]t, T[j, n]}, {j, 0, 
                  M}] /. sol[n], {n, 0, 25}], 1]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.65"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.`, 1.`}, {0.`, 1.25`}}, "<>"]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["Flatten",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command used here removes an extra set of brackets that the ",
  StyleBox["Interpolation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function finds objectionable. We can plot the solution function ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"Tsol", "[", 
            RowBox[{
              StyleBox["x",
                FontSlant->"Plain"], ",", 
              StyleBox["t",
                FontSlant->"Plain"]}], "]"}],
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  "vs. both ",
  Cell[BoxData[
      FormBox[
        StyleBox["x",
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]],
    FontSlant->"Italic"],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["t",
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", and we do so in Cell ",
  ButtonBox["6.66",
    ButtonData:>"Cell 6.66",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot3D[Tsol[x, t], {x, 0, 1}, {t, 0, 1.25}, 
        AxesLabel \[Rule] {"\<x\>", "\<t\>", "\<T[x,t]\>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.66"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.1978e-17 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.29165 .07573 -9.31117 -12 ]
[.29165 .07573 .68883 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 24 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 24 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 6 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 24 3.14607 ]
[.91861 .21225 0 -8.04169 ]
[.91861 .21225 10 3.95831 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01568 .31795 -24 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00696 .37264 -18 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00208 .42927 -24 -2.88161 ]
[-0.00208 .42927 0 6.11839 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[-0.05457 .39542 -40 -3.77786 ]
[-0.05457 .39542 0 8.22214 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.25)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.5)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.75)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(1)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1.25)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70252 .02109 m
.69885 .02251 L
s
.71605 .04178 m
.71237 .04318 L
s
.72932 .06208 m
.72564 .06347 L
s
.74235 .08201 m
.73866 .08339 L
s
.7677 .12078 m
.764 .12213 L
s
.78003 .13965 m
.77633 .14098 L
s
.79214 .15817 m
.78843 .1595 L
s
.80404 .17637 m
.80033 .17768 L
s
.82721 .21182 m
.82349 .21311 L
s
.8385 .22909 m
.83478 .23037 L
s
.8496 .24606 m
.84587 .24733 L
s
.86051 .26275 m
.85677 .264 L
s
.88178 .29529 m
.87804 .29651 L
s
.89215 .31115 m
.88841 .31237 L
s
.90235 .32676 m
.89861 .32797 L
s
.91239 .34211 m
.90864 .34331 L
s
.93198 .37208 m
.92823 .37326 L
s
.94155 .38671 m
.93779 .38788 L
s
.95096 .40111 m
.9472 .40226 L
s
.96022 .41528 m
.95646 .41643 L
s
gsave
.91861 .21225 -61 -12.0417 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02795 .31328 m
.03408 .31095 L
s
[(0.25)] .01568 .31795 1 -0.38067 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0.5)] .00696 .37264 1 -0.37036 Mshowa
.01027 .42483 m
.01644 .42261 L
s
[(0.75)] -0.00208 .42927 1 -0.35964 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.03468 .27078 m
.03835 .26935 L
s
.03301 .2813 m
.03669 .27988 L
s
.03134 .29189 m
.03501 .29047 L
s
.02965 .30255 m
.03332 .30114 L
s
.02623 .32409 m
.02991 .3227 L
s
.02451 .33497 m
.02819 .33359 L
s
.02277 .34593 m
.02646 .34455 L
s
.02102 .35697 m
.02471 .35559 L
s
.01749 .37927 m
.02118 .37791 L
s
.0157 .39054 m
.0194 .38919 L
s
.0139 .40189 m
.0176 .40054 L
s
.01209 .41332 m
.01579 .41198 L
s
.00843 .43642 m
.01214 .4351 L
s
.00658 .4481 m
.01029 .44678 L
s
.00472 .45986 m
.00843 .45855 L
s
.00284 .4717 m
.00656 .4704 L
s
gsave
-0.05457 .39542 -101 -7.77786 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.637 .734 .919 r
.38313 .58323 .40512 .60371 .44184 .59468 .42013 .57442 Metetra
.638 .739 .922 r
.42013 .57442 .44184 .59468 .47911 .5854 .45771 .56534 Metetra
.64 .744 .925 r
.45771 .56534 .47911 .5854 .51694 .5758 .49588 .55588 Metetra
.643 .75 .926 r
.49588 .55588 .51694 .5758 .55533 .56576 .53463 .54591 Metetra
.648 .754 .927 r
.53463 .54591 .55533 .56576 .59429 .55522 .57397 .53534 Metetra
.653 .759 .927 r
.57397 .53534 .59429 .55522 .63381 .5441 .6139 .52409 Metetra
.658 .762 .926 r
.6139 .52409 .63381 .5441 .67389 .53238 .6544 .51211 Metetra
.664 .764 .925 r
.6544 .51211 .67389 .53238 .71454 .52001 .69548 .49937 Metetra
.67 .766 .922 r
.69548 .49937 .71454 .52001 .75573 .50702 .73711 .48588 Metetra
.675 .766 .919 r
.73711 .48588 .75573 .50702 .79747 .49343 .7793 .47167 Metetra
.679 .765 .916 r
.7793 .47167 .79747 .49343 .83976 .47928 .82203 .4568 Metetra
.682 .762 .912 r
.82203 .4568 .83976 .47928 .88261 .46464 .86533 .44136 Metetra
.684 .759 .908 r
.86533 .44136 .88261 .46464 .92603 .4496 .90918 .42546 Metetra
.685 .755 .904 r
.90918 .42546 .92603 .4496 .97003 .43424 .95362 .4092 Metetra
.63 .732 .921 r
.36056 .56222 .38313 .58323 .42013 .57442 .39785 .55375 Metetra
.631 .739 .925 r
.39785 .55375 .42013 .57442 .45771 .56534 .43574 .54498 Metetra
.633 .745 .928 r
.43574 .54498 .45771 .56534 .49588 .55588 .47424 .53576 Metetra
.638 .751 .931 r
.47424 .53576 .49588 .55588 .53463 .54591 .51336 .52594 Metetra
.643 .757 .932 r
.51336 .52594 .53463 .54591 .57397 .53534 .5531 .51541 Metetra
.65 .763 .932 r
.5531 .51541 .57397 .53534 .6139 .52409 .59344 .50406 Metetra
.657 .767 .931 r
.59344 .50406 .6139 .52409 .6544 .51211 .63437 .49183 Metetra
.664 .77 .928 r
.63437 .49183 .6544 .51211 .69548 .49937 .67589 .47868 Metetra
.671 .772 .925 r
.67589 .47868 .69548 .49937 .73711 .48588 .71798 .46463 Metetra
.678 .772 .921 r
.71798 .46463 .73711 .48588 .7793 .47167 .76063 .44972 Metetra
.683 .77 .917 r
.76063 .44972 .7793 .47167 .82203 .4568 .80382 .43403 Metetra
.687 .767 .913 r
.80382 .43403 .82203 .4568 .86533 .44136 .84757 .41766 Metetra
.689 .763 .908 r
.84757 .41766 .86533 .44136 .90918 .42546 .89187 .40075 Metetra
.691 .758 .903 r
.89187 .40075 .90918 .42546 .95362 .4092 .93675 .38345 Metetra
.621 .73 .925 r
.33741 .54067 .36056 .56222 .39785 .55375 .37497 .53268 Metetra
.622 .737 .929 r
.37497 .53268 .39785 .55375 .43574 .54498 .41316 .52436 Metetra
.625 .745 .933 r
.41316 .52436 .43574 .54498 .47424 .53576 .452 .51551 Metetra
.63 .753 .936 r
.452 .51551 .47424 .53576 .51336 .52594 .49149 .50595 Metetra
.638 .761 .937 r
.49149 .50595 .51336 .52594 .5531 .51541 .53162 .49553 Metetra
.646 .768 .937 r
.53162 .49553 .5531 .51541 .59344 .50406 .57239 .48412 Metetra
.655 .773 .936 r
.57239 .48412 .59344 .50406 .63437 .49183 .61378 .47165 Metetra
.665 .777 .933 r
.61378 .47165 .63437 .49183 .67589 .47868 .65576 .45807 Metetra
.674 .779 .929 r
.65576 .45807 .67589 .47868 .71798 .46463 .69832 .44339 Metetra
.681 .779 .924 r
.69832 .44339 .71798 .46463 .76063 .44972 .74144 .42768 Metetra
.688 .777 .919 r
.74144 .42768 .76063 .44972 .80382 .43403 .78511 .41103 Metetra
.693 .773 .913 r
.78511 .41103 .80382 .43403 .84757 .41766 .82932 .39357 Metetra
.696 .768 .907 r
.82932 .39357 .84757 .41766 .89187 .40075 .87407 .37548 Metetra
.697 .762 .902 r
.87407 .37548 .89187 .40075 .93675 .38345 .91939 .35695 Metetra
.609 .726 .928 r
.31365 .51855 .33741 .54067 .37497 .53268 .35146 .51123 Metetra
.61 .736 .934 r
.35146 .51123 .37497 .53268 .41316 .52436 .38994 .50354 Metetra
.614 .746 .939 r
.38994 .50354 .41316 .52436 .452 .51551 .42911 .49523 Metetra
.621 .756 .943 r
.42911 .49523 .452 .51551 .49149 .50595 .46896 .48606 Metetra
.63 .766 .944 r
.46896 .48606 .49149 .50595 .53162 .49553 .50951 .47585 Metetra
.641 .774 .944 r
.50951 .47585 .53162 .49553 .57239 .48412 .55072 .46445 Metetra
.653 .781 .942 r
.55072 .46445 .57239 .48412 .61378 .47165 .59258 .45175 Metetra
.665 .786 .939 r
.59258 .45175 .61378 .47165 .65576 .45807 .63505 .43769 Metetra
.676 .788 .934 r
.63505 .43769 .65576 .45807 .69832 .44339 .67811 .42231 Metetra
.686 .788 .928 r
.67811 .42231 .69832 .44339 .74144 .42768 .72172 .40566 Metetra
.694 .785 .921 r
.72172 .40566 .74144 .42768 .78511 .41103 .76587 .38788 Metetra
.7 .781 .914 r
.76587 .38788 .78511 .41103 .82932 .39357 .81055 .36914 Metetra
.704 .774 .907 r
.81055 .36914 .82932 .39357 .87407 .37548 .85576 .34966 Metetra
.705 .767 .9 r
.85576 .34966 .87407 .37548 .91939 .35695 .90152 .32967 Metetra
.593 .721 .933 r
.28926 .49583 .31365 .51855 .35146 .51123 .32729 .48943 Metetra
.594 .733 .941 r
.32729 .48943 .35146 .51123 .38994 .50354 .36604 .4826 Metetra
.599 .746 .947 r
.36604 .4826 .38994 .50354 .42911 .49523 .40552 .47503 Metetra
.608 .759 .951 r
.40552 .47503 .42911 .49523 .46896 .48606 .44575 .46643 Metetra
.62 .771 .953 r
.44575 .46643 .46896 .48606 .50951 .47585 .48671 .45657 Metetra
.634 .782 .952 r
.48671 .45657 .50951 .47585 .55072 .46445 .52839 .44524 Metetra
.649 .791 .95 r
.52839 .44524 .55072 .46445 .59258 .45175 .57073 .43233 Metetra
.665 .797 .945 r
.57073 .43233 .59258 .45175 .63505 .43769 .61372 .41776 Metetra
.679 .8 .939 r
.61372 .41776 .63505 .43769 .67811 .42231 .6573 .40156 Metetra
.692 .799 .931 r
.6573 .40156 .67811 .42231 .72172 .40566 .70143 .38383 Metetra
.702 .796 .923 r
.70143 .38383 .72172 .40566 .76587 .38788 .74609 .36472 Metetra
.709 .79 .914 r
.74609 .36472 .76587 .38788 .81055 .36914 .79126 .34445 Metetra
.713 .782 .906 r
.79126 .34445 .81055 .36914 .85576 .34966 .83693 .32331 Metetra
.715 .772 .898 r
.83693 .32331 .85576 .34966 .90152 .32967 .88312 .30158 Metetra
.573 .714 .938 r
.2642 .4725 .28926 .49583 .32729 .48943 .30242 .46732 Metetra
.573 .729 .948 r
.30242 .46732 .32729 .48943 .36604 .4826 .3414 .46163 Metetra
.579 .745 .955 r
.3414 .46163 .36604 .4826 .40552 .47503 .38119 .45507 Metetra
.59 .761 .96 r
.38119 .45507 .40552 .47503 .44575 .46643 .42179 .44727 Metetra
.605 .777 .963 r
.42179 .44727 .44575 .46643 .48671 .45657 .46318 .43792 Metetra
.624 .791 .962 r
.46318 .43792 .48671 .45657 .52839 .44524 .50533 .42678 Metetra
.644 .803 .959 r
.50533 .42678 .52839 .44524 .57073 .43233 .54819 .41368 Metetra
.664 .81 .953 r
.54819 .41368 .57073 .43233 .61372 .41776 .59172 .39854 Metetra
.683 .814 .945 r
.59172 .39854 .61372 .41776 .6573 .40156 .63585 .3814 Metetra
.699 .813 .936 r
.63585 .3814 .6573 .40156 .70143 .38383 .68054 .36239 Metetra
.712 .809 .925 r
.68054 .36239 .70143 .38383 .74609 .36472 .72573 .34169 Metetra
.721 .801 .915 r
.72573 .34169 .74609 .36472 .79126 .34445 .7714 .3196 Metetra
.725 .791 .904 r
.7714 .3196 .79126 .34445 .83693 .32331 .81754 .29646 Metetra
.726 .779 .894 r
.81754 .29646 .83693 .32331 .88312 .30158 .86416 .27265 Metetra
.544 .704 .944 r
.23846 .44853 .2642 .4725 .30242 .46732 .2768 .44494 Metetra
.544 .722 .956 r
.2768 .44494 .30242 .46732 .3414 .46163 .31599 .44078 Metetra
.55 .742 .965 r
.31599 .44078 .3414 .46163 .38119 .45507 .35606 .43556 Metetra
.564 .763 .972 r
.35606 .43556 .38119 .45507 .42179 .44727 .39701 .42885 Metetra
.584 .784 .975 r
.39701 .42885 .42179 .44727 .46318 .43792 .43883 .42022 Metetra
.609 .803 .974 r
.43883 .42022 .46318 .43792 .50533 .42678 .48147 .40939 Metetra
.636 .817 .97 r
.48147 .40939 .50533 .42678 .54819 .41368 .52489 .39615 Metetra
.663 .827 .962 r
.52489 .39615 .54819 .41368 .59172 .39854 .569 .38038 Metetra
.688 .832 .952 r
.569 .38038 .59172 .39854 .63585 .3814 .61373 .36215 Metetra
.708 .831 .94 r
.61373 .36215 .63585 .3814 .68054 .36239 .659 .3416 Metetra
.724 .825 .927 r
.659 .3416 .68054 .36239 .72573 .34169 .70476 .31899 Metetra
.734 .815 .914 r
.70476 .31899 .72573 .34169 .7714 .3196 .75096 .29469 Metetra
.74 .802 .902 r
.75096 .29469 .7714 .3196 .81754 .29646 .79757 .26915 Metetra
.74 .786 .89 r
.79757 .26915 .81754 .29646 .86416 .27265 .84462 .24283 Metetra
.505 .689 .95 r
.212 .42389 .23846 .44853 .2768 .44494 .2504 .42238 Metetra
.502 .711 .964 r
.2504 .42238 .2768 .44494 .31599 .44078 .28973 .4202 Metetra
.509 .735 .976 r
.28973 .4202 .31599 .44078 .35606 .43556 .33003 .41677 Metetra
.526 .763 .983 r
.33003 .41677 .35606 .43556 .39701 .42885 .37132 .4115 Metetra
.553 .79 .987 r
.37132 .4115 .39701 .42885 .43883 .42022 .41357 .40389 Metetra
.587 .815 .986 r
.41357 .40389 .43883 .42022 .48147 .40939 .45673 .39354 Metetra
.624 .835 .981 r
.45673 .39354 .48147 .40939 .52489 .39615 .50074 .38021 Metetra
.66 .848 .972 r
.50074 .38021 .52489 .39615 .569 .38038 .54548 .36374 Metetra
.693 .854 .96 r
.54548 .36374 .569 .38038 .61373 .36215 .59086 .34421 Metetra
.719 .852 .945 r
.59086 .34421 .61373 .36215 .659 .3416 .63678 .32182 Metetra
.739 .844 .929 r
.63678 .32182 .659 .3416 .70476 .31899 .68314 .2969 Metetra
.751 .831 .913 r
.68314 .2969 .70476 .31899 .75096 .29469 .72989 .26992 Metetra
.757 .814 .898 r
.72989 .26992 .75096 .29469 .79757 .26915 .777 .24145 Metetra
.757 .795 .884 r
.777 .24145 .79757 .26915 .84462 .24283 .82447 .21208 Metetra
.449 .666 .955 r
.18479 .39856 .212 .42389 .2504 .42238 .22314 .39973 Metetra
.441 .691 .971 r
.22314 .39973 .2504 .42238 .28973 .4202 .26253 .40014 Metetra
.447 .721 .984 r
.26253 .40014 .28973 .4202 .33003 .41677 .30301 .39904 Metetra
.469 .756 .993 r
.30301 .39904 .33003 .41677 .37132 .4115 .3446 .39569 Metetra
.505 .793 .997 r
.3446 .39569 .37132 .4115 .41357 .40389 .38729 .38945 Metetra
.552 .827 .997 r
.38729 .38945 .41357 .40389 .45673 .39354 .431 .37982 Metetra
.603 .854 .991 r
.431 .37982 .45673 .39354 .50074 .38021 .47563 .36646 Metetra
.653 .873 .981 r
.47563 .36646 .50074 .38021 .54548 .36374 .52107 .3492 Metetra
.697 .88 .966 r
.52107 .3492 .54548 .36374 .59086 .34421 .56717 .32812 Metetra
.732 .878 .948 r
.56717 .32812 .59086 .34421 .63678 .32182 .61379 .30349 Metetra
.757 .867 .929 r
.61379 .30349 .63678 .32182 .68314 .2969 .66082 .27574 Metetra
.772 .85 .91 r
.66082 .27574 .68314 .2969 .72989 .26992 .70817 .24548 Metetra
.778 .829 .892 r
.70817 .24548 .72989 .26992 .777 .24145 .7558 .21344 Metetra
.777 .806 .876 r
.7558 .21344 .777 .24145 .82447 .21208 .80369 .18035 Metetra
.367 .628 .954 r
.1568 .3725 .18479 .39856 .22314 .39973 .19497 .37712 Metetra
.35 .655 .969 r
.19497 .37712 .22314 .39973 .26253 .40014 .2343 .38087 Metetra
.352 .691 .981 r
.2343 .38087 .26253 .40014 .30301 .39904 .27487 .38281 Metetra
.378 .735 .99 r
.27487 .38281 .30301 .39904 .3446 .39569 .31673 .382 Metetra
.428 .785 .996 r
.31673 .382 .3446 .39569 .38729 .38945 .35983 .3776 Metetra
.494 .832 .998 r
.35983 .3776 .38729 .38945 .431 .37982 .40411 .36898 Metetra
.567 .872 .995 r
.40411 .36898 .431 .37982 .47563 .36646 .44944 .3557 Metetra
.639 .899 .984 r
.44944 .3557 .47563 .36646 .52107 .3492 .49564 .33753 Metetra
.7 .911 .968 r
.49564 .33753 .52107 .3492 .56717 .32812 .54255 .31458 Metetra
.747 .908 .948 r
.54255 .31458 .56717 .32812 .61379 .30349 .58997 .28721 Metetra
.778 .894 .926 r
.58997 .28721 .61379 .30349 .66082 .27574 .63774 .25598 Metetra
.796 .872 .904 r
.63774 .25598 .66082 .27574 .70817 .24548 .68575 .22168 Metetra
.802 .845 .883 r
.68575 .22168 .70817 .24548 .7558 .21344 .73392 .18524 Metetra
.799 .817 .865 r
.73392 .18524 .7558 .21344 .80369 .18035 .78223 .14761 Metetra
.245 .564 .936 r
.128 .34568 .1568 .3725 .19497 .37712 .16579 .35471 Metetra
.21 .588 .945 r
.16579 .35471 .19497 .37712 .2343 .38087 .2049 .36277 Metetra
.203 .626 .949 r
.2049 .36277 .2343 .38087 .27487 .38281 .24545 .36867 Metetra
.234 .68 .955 r
.24545 .36867 .27487 .38281 .31673 .382 .28749 .37119 Metetra
.302 .747 .962 r
.28749 .37119 .31673 .382 .35983 .3776 .331 .36926 Metetra
.396 .816 .971 r
.331 .36926 .35983 .3776 .40411 .36898 .37587 .36204 Metetra
.504 .878 .976 r
.37587 .36204 .40411 .36898 .44944 .3557 .42195 .34897 Metetra
.609 .922 .973 r
.42195 .34897 .44944 .3557 .49564 .33753 .46903 .32974 Metetra
.697 .942 .961 r
.46903 .32974 .49564 .33753 .54255 .31458 .51686 .30451 Metetra
.761 .941 .941 r
.51686 .30451 .54255 .31458 .58997 .28721 .5652 .27375 Metetra
.802 .924 .917 r
.5652 .27375 .58997 .28721 .63774 .25598 .61382 .2382 Metetra
.823 .896 .893 r
.61382 .2382 .63774 .25598 .68575 .22168 .66257 .19888 Metetra
.829 .863 .871 r
.66257 .19888 .68575 .22168 .73392 .18524 .71133 .15701 Metetra
.825 .828 .851 r
.71133 .15701 .73392 .18524 .78223 .14761 .76008 .1138 Metetra
.066 .456 .883 r
.09834 .31807 .128 .34568 .16579 .35471 .1355 .33274 Metetra
.002 .466 .867 r
.1355 .33274 .16579 .35471 .2049 .36277 .17417 .34634 Metetra
0 .498 .849 r
.17417 .34634 .2049 .36277 .24545 .36867 .21453 .35738 Metetra
.018 .559 .842 r
.21453 .35738 .24545 .36867 .28749 .37119 .25664 .36427 Metetra
.108 .646 .853 r
.25664 .36427 .28749 .37119 .331 .36926 .30051 .36562 Metetra
.239 .748 .878 r
.30051 .36562 .331 .36926 .37587 .36204 .34601 .36034 Metetra
.395 .847 .908 r
.34601 .36034 .37587 .36204 .42195 .34897 .39293 .34765 Metetra
.551 .925 .928 r
.39293 .34765 .42195 .34897 .46903 .32974 .44101 .32717 Metetra
.68 .966 .932 r
.44101 .32717 .46903 .32974 .51686 .30451 .48992 .29912 Metetra
.771 .973 .92 r
.48992 .29912 .51686 .30451 .5652 .27375 .53933 .26412 Metetra
.827 .954 .899 r
.53933 .26412 .5652 .27375 .61382 .2382 .58896 .22315 Metetra
.853 .921 .875 r
.58896 .22315 .61382 .2382 .66257 .19888 .63856 .17757 Metetra
.86 .881 .852 r
.63856 .17757 .66257 .19888 .71133 .15701 .68798 .12895 Metetra
.852 .84 .832 r
.68798 .12895 .71133 .15701 .76008 .1138 .73719 .07886 Metetra
0 .284 .759 r
.0678 .28963 .09834 .31807 .1355 .33274 .10398 .31147 Metetra
0 .27 .695 r
.10398 .31147 .1355 .33274 .17417 .34634 .1419 .33221 Metetra
.29 0 0 r
.1419 .33221 .17417 .34634 .21453 .35738 .18181 .34992 Metetra
.245 0 0 r
.18181 .34992 .21453 .35738 .25664 .36427 .22383 .36257 Metetra
.138 0 0 r
.22383 .36257 .25664 .36427 .30051 .36562 .26799 .3683 Metetra
.26799 .3683 .30051 .36562 .34601 .36034 .31413 .36566 Metetra
.229 .746 .753 r
.31413 .36566 .34601 .36034 .39293 .34765 .36201 .35362 Metetra
.447 .88 .82 r
.36201 .35362 .39293 .34765 .44101 .32717 .41126 .33165 Metetra
.636 .965 .862 r
.41126 .33165 .44101 .32717 .48992 .29912 .46146 .30005 Metetra
.77 .994 .875 r
.46146 .30005 .48992 .29912 .53933 .26412 .51218 .25968 Metetra
.848 .981 .866 r
.51218 .25968 .53933 .26412 .58896 .22315 .563 .21185 Metetra
.884 .944 .847 r
.563 .21185 .58896 .22315 .63856 .17757 .61362 .15839 Metetra
.891 .898 .827 r
.61362 .15839 .63856 .17757 .68798 .12895 .66382 .10135 Metetra
.881 .85 .808 r
.66382 .10135 .68798 .12895 .73719 .07886 .71353 .04274 Metetra
0 .056 .546 r
.03634 .26033 .0678 .28963 .10398 .31147 .07105 .2913 Metetra
.531 0 0 r
.07105 .2913 .10398 .31147 .1419 .33221 .10779 .32122 Metetra
.533 0 0 r
.10779 .32122 .1419 .33221 .18181 .34992 .1469 .34764 Metetra
.474 0 0 r
.1469 .34764 .18181 .34992 .22383 .36257 .18859 .36788 Metetra
.361 0 0 r
.18859 .36788 .22383 .36257 .26799 .3683 .23291 .37948 Metetra
.194 0 0 r
.23291 .37948 .26799 .3683 .31413 .36566 .27971 .38046 Metetra
.27971 .38046 .31413 .36566 .36201 .35362 .32868 .36942 Metetra
.32868 .36942 .36201 .35362 .41126 .33165 .37934 .34563 Metetra
.554 .916 .736 r
.37934 .34563 .41126 .33165 .46146 .30005 .43113 .30952 Metetra
.747 .99 .793 r
.43113 .30952 .46146 .30005 .51218 .25968 .48345 .26225 Metetra
.861 .996 .811 r
.48345 .26225 .51218 .25968 .563 .21185 .53576 .20565 Metetra
.911 .962 .806 r
.53576 .20565 .563 .21185 .61362 .15839 .58762 .14218 Metetra
.922 .912 .792 r
.58762 .14218 .61362 .15839 .66382 .10135 .63876 .07456 Metetra
.91 .857 .777 r
.63876 .07456 .66382 .10135 .71353 .04274 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{328.625, 266.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006J0001CB000`400?l00000o`00003ooooooonK
ooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonK
ooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonK
ooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonK
ooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonK
ooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonK
ooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonK
ooooo`00oooooonKooooo`00oooooolHooooo`Co000000?o410@ooooooooool0O?ooool00?oooooo
6_ooool00ol0003oooooooooo`1nooooo`00oooooolJooooo`03o`000?oooooooooo07kooooo003o
oooooa[ooooo00?o0000ooooooooool0O_ooool00?oooooo6_ooool00ol0003oooooooooo`1noooo
o`00oooooolJooooo`03o`000?oooooooooo07kooooo003ooooooa[ooooo00?o0000ooooooooool0
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07;ooooo003ooooooaSooooo00?oEEEEofIVI_l00000
2Oooool01OmgMgOoV9RHoooooonHV9SoMgMg07;ooooo003oooooobCooooo00Go410@oooooooooooo
oooooa0@401booooo`00oooooolTooooo`05o`000?ooooooooooooooool00000L_ooool00?oooooo
9?ooool01Ol0003ooooooooooooooooo000007;ooooo003oooooobCooooo00Go410@oooooooooooo
oooooa0@401booooo`00oooooolTooooo`05ogMgMonHV9SooooooiRHV?mgMgL0L_ooool00?oooooo
7_ooool2o`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1booooo`00oooooolKooooo`?o0000
00?oooooo`000?l00000N_ooool00?oooooo6Oooool2o`0000Cooooo0_l0001jooooo`00oooooolF
ooooo`?o00001Oooool4o`0007Wooooo003ooooooa?ooooo0ol00007ooooo`05o`000?oXflKo0000
onSKa_l00000NOooool00=[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool0
1Oo<c<co8B4Qo`000?lQ8B7oc<c<027ooooo0_l000000ooooooo0000ooooo`06ooooo`05o`000?oX
flKoj=_6o`000?oXflH00_l0001hooooo`00f_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B407_ooool3o`0000_ooooo00Co0000onSKa_oX
flKo00000_oXflH2o`0007Oooooo003Jooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0
003ooooooooooooooooo000001cooooo0_l0000=ooooo`05o`000?oXflKoj=_6onSKa_l000000ooX
flH00ol0003oooooooooo`1eooooo`00f_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go
<S8boiRHV?ooooooV9RHoc8b<P0Iooooo`?o00003_ooool00ol0003oj=_6onSKaP02onSKaP04o`00
0?oXflKoj=_6onSKaP;o0000M_ooool00=[ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
olc<c?l0003o0000o`000?o<c<`05oooool2o`00017ooooo00?o0000onSKa_oXflH00ooXflH01?l0
003oj=_6onSKa_oXflH2o`0007Gooooo003Jooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol@413o^[Zjoooooonj^[[o410@01Cooooo0ol00002ooooo`03o`000?oooooooooo00gooooo00?o
0000onSKa_oXflH01?oXflH00ol0003oj=_6onSKaP02onSKaP03o`000?oooooooooo07?ooooo003J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000001;ooooo
0_l0000Dooooo`03o`000?oXflKoj=_600Goj=_600?o0000onSKa_oXflH00_oXflH2o`0007Cooooo
003Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00oo
oooo0ol0000Eooooo`03o`000?oXflKoj=_600Koj=_600?o0000onSKa_oXflH00ooXflH2o`0007?o
oooo003kooooo`?o00006?ooool00ol0003oj=_6onSKaP06onSKaP03o`000?oXflKoj=_600Coj=_6
0_l0001booooo`00V?ooool2o`0000;ooooo0_l0001Kooooo`;o000000?oooooo`000?ooool05ooo
ool00ol0003oj=_6onSKaP07onSKaP03o`000?oXflKoj=_600Coj=_60_l0001booooo`00V?ooool0
1_o^k^ko8B4QohN7Qonj^[[o0000omgMgESooooo0ol0000Kooooo`03o`000?oXflKoj=_600Soj=_6
00?o0000onSKa_oXflH00ooXflH00ol0003ohMW>o`00001booooo`00VOooool01?oMgMgo0000oa0@
4?o<c<aGooooo`;o00007Oooool00ol0003oj=_6onSKaP09onSKaP03o`000?oXflKoj=_600;oj=_6
00?o0000on7Ic_oQfLh00_l0001aooooo`00VOooool01?o^k^ko8B4Qoa0@4?o^k^iDooooo`?o0000
7oooool00ol0003oj=_6onSKaP09onSKaP05o`000?oXflKoj=_6onSKa_l000001?oQfLh2o`00073o
oooo002Iooooo`04ob4Q8OmgMgOoMgMgoc8b<U;ooooo0ol0000Pooooo`03o`000?oXflKoj=_600[o
j=_600Co0000onSKa_oXflKo00001_oQfLh00ol0003oooooooooo`1^ooooo`00V?ooool2o`0000;o
oooo0_l0001>ooooo`?o00000oooool00ol0003oooooooooo`0Looooo`03o`000?oXflKoj=_600_o
j=_600?o0000onSKa_l000001ooQfLh3o`0006kooooo003Zooooo`;o00009Oooool00ol0003oj=_6
onSKaP0;onSKaP03o`000?oXflKo000000SohMW>0_l0001^ooooo`00ioooool3o`0002Kooooo00?o
0000onSKa_oXflH03?oXflH2o`0000WohMW>0_l0001^ooooo`00[Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`08_ooool3o`0002Sooooo
00?o0000onSKa_oXflH03OoXflH00ol0003ohMW>on7IcP09on7IcP;o0000KOooool00:gooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q023o
oooo0_l00002ooooo`03o`000?oooooooooo02Gooooo00?o0000onSKa_oXflH03OoXflH2o`0000co
hMW>0_l0001/ooooo`00[Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooo
ooooooooo`00000Mooooo`?o0000;?ooool00ol0003oj=_6onSKaP0<onSKaP04o`000?oQfLkohMW>
o`0000_ohMW>0_l0001/ooooo`00[Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000
oiRHV?ooooooV9RHob4Q8@0Kooooo`;o0000;_ooool00ol0003ok>W:o`00000<onSKaP05o`000?oQ
fLkohMW>on7Ic_l000003?oQfLh2o`0006_ooooo002]ooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oEEEEo`000?l@413oc<c<01Sooooo0ol0000_ooooo`05o`000?o/jL[ok>W:oncY
b_l000002_oXflH00ol0003ohMW>on7IcP02on7IcP03o`000?oQfLkohMW>00[ohMW>0ol00008oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o
0000oc8b<_oMgMd0A?ooool00:gooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo01Sooooo0_l000000ooooooo0000ooooo`0^ooooo`03o`000?o/jL[ok>W:00?ok>W:00?o
0000onSKa_oXflH01ooXflH00ol0003ohMW>on7IcP02on7IcP03o`000?oQfLkohMW>00WohMW>00Co
0000om[Ge?l0003o00002?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`13ooooo`00[Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P05Oooool3o`0003?ooooo00?o0000oncY
b_o/jLX01?o/jLX00ol0003oj=_6onSKaP05onSKaP03o`000?oQfLkohMW>00?ohMW>00?o0000on7I
c_oQfLh02?oQfLh01?l0003of]ODom[Ge?oJem@2o`0000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0@_ooool00:gooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@417ooooo0_l0000eooooo`03o`00
0?o/jL[ok>W:00Kok>W:00?o0000onSKa_oXflH00ooXflH00ol0003ohMW>on7IcP04on7IcP03o`00
0?oQfLkohMW>00OohMW>00?o0000om[Ge?oJem@00ooJem@2o`0000Kooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0@oooool00=3ooooo
0ol0000fooooo`03o`000?o/jL[ok>W:00Sok>W:00Go0000onSKa_oXflKoj=_6o`000007on7IcP03
o`000?oQfLkohMW>00KohMW>00?o0000om[Ge?oJem@01?oJem@2o`0000Kooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c014
ooooo`00cOooool4o`0003Sooooo00?o0000oncYb_o/jLX02Oo/jLX00ol0003oj=_6o`000008on7I
cP03o`000?oQfLkohMW>00GohMW>00?o0000om[Ge?oJem@01_oJem@2o`0000Gooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0A_ooool0
0<_ooooo0_l0000kooooo`03o`000?o/jL[ok>W:00_ok>W:00?o0000on7Ic_oQfLh01ooQfLh00ol0
003ohMW>on7IcP04on7IcP03o`000?oJemCof]OD00Sof]OD0_l00004ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0A_oo
ool00<Sooooo0ol0000looooo`03o`000?o/jL[ok>W:00cok>W:00?o0000on7Ic_oQfLh01ooQfLh0
0ol0003ohMW>on7IcP03on7IcP03o`000?oJemCof]OD00Wof]OD0_l00004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00015ooooo`00a_oo
ool2o`0003kooooo00?o0000oncYb_o/jLX03?o/jLX00ol0003oi>GCo`000008on7IcP03o`000?oQ
fLkohMW>00;ohMW>00?o0000om[Ge?oJem@02ooJem@2o`0006Gooooo0033ooooo`?o0000@?ooool0
0ol0003ok>W:oncYbP0;oncYbP05o`000?oTiM?oi>GConCUdol000001ooQfLh01Ol0003ohMW>on7I
c_oQfLko000000oof]OD0_l0001Tooooo`00`Oooool2o`0000?ooooo00?o0000ooooooooool0??oo
ool00ol0003ok>W:oncYbP0;oncYbP03o`000?oTiM?oi>GC00?oi>GC00?o0000on7Ic_oQfLh01?oQ
fLh01?l0003ohMW>on7Ic_l0000@om[Ge0;o0000I?ooool00;kooooo0ol00013ooooo`03o`000?o/
jL[ok>W:00_ok>W:00?o0000onCUdooTiM<01OoTiM<00ol0003ohMW>on7IcP03on7IcP03o`000?oQ
fLko0000013of]OD00Co0000om?CfOl0003o0000Hoooool00;cooooo0_l00015ooooo`03o`000?o/
jL[ok>W:00_ok>W:00?o0000onCUdooTiM<01ooTiM<00ol0003ohMW>on7IcP02on7IcP;o00004?oJ
em@01?l0003odm?Iom?CfOoCdmT2o`0006;ooooo0023ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`0Oooooo`?o0000Aoooool00ol0003ok>W:
oncYbP0:oncYbP03o`000?oTiM?oi>GC00Woi>GC00Go0000on7Ic_oQfLkohMW>o`00000@om[Ge003
o`000?oCdmWodm?I00?odm?I00?o0000ooooooooool0H?ooool008?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Mooooo`?o00000_ooool00ol0003o
ooooooooo`14ooooo`03o`000?o/jL[ok>W:00[ok>W:00?o0000onCUdooTiM<02ooTiM<01Ol0003o
hMW>o`000?oJemCo000000kof]OD00?o0000om?CfOoCdmT01?oCdmT2o`00067ooooo0023ooooo`05
oa0@4?ooooooooooooooool@41002oooool5o`0001cooooo0_l0001;ooooo`03o`000?o/jL[ok>W:
00[ok>W:00?o0000onCUdooTiM<03?oTiM<2o`0000;of]OD00?o0000om[Ge?oJem@02ooJem@00ol0
003odm?Iom?Cf@06om?Cf@;o0000H?ooool008?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0001[ooooo0ol0001=ooooo`03o`000?o/jL[ok>W:00[ok>W:00?o0000
onCUdooTiM<02ooTiM<00ol0003og>7Jo`000002om[Ge003o`000?oJemCof]OD00[of]OD00?o0000
om?CfOoCdmT02?oCdmT00ol0003oooooooooo`1Nooooo`00Poooool01Ol0003ooooooooooooooooo
000000_ooooo00CogMgMoeEEEOoooooo00006?ooool2o`0004oooooo00?o0000oncYb_o/jLX02_o/
jLX00ol0003oi>GConCUd`0;onCUd`07o`000?oLhM[og>7JomcQf_l0003of]ODo`00000:om[Ge0;o
00002ooCdmT2o`0005oooooo0023ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOo
c<c<o`00000Eooooo`?o00000_ooool00ol0003oooooooooo`1;ooooo`03o`000?o/jL[ok>W:00[o
k>W:00?o0000onCUdooTiM<02ooTiM<00ol0003og>7JomcQfP03omcQfP;o00002OoJem@00ol0003o
dm?Iom?Cf@0<om?Cf@;o0000G_ooool008?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
onk^k_m4A4Co000001?ooooo0_l0001Booooo`;o00002oo/jLX00ol0003oi>GConCUd`0;onCUd`03
o`000?oLhM[og>7J00Gog>7J00?o0000om[Ge?oJem@01_oJem@00ol0003odm?Iom?Cf@0=om?Cf@;o
0000G_ooool008?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00oo
oooo0ol0001Dooooo`03o`000?oYm/ko000000Wok>W:00?o0000onCUdooTiM<02ooTiM<00ol0003o
g>7JomcQfP06omcQfP;o00001_oJem@00ol0003odm?Iom?Cf@0?om?Cf@;o0000GOooool00:Gooooo
0_l0001Fooooo`04o`000?oYm/kojOK>onWfcP;o00001_o/jLX00ol0003oi>GConCUd`0;onCUd`03
o`000?oLhM[og>7J00Oog>7J0_l00005om[Ge003o`000?oCdmWodm?I013odm?I0_l0001Mooooo`00
X_ooool3o`0000;ooooo00?o0000ooooooooool0D_ooool00ol0003ojOK>onWfcP04onWfcP;o0000
0oo/jLX00ol0003oi>GConCUd`0;onCUd`03o`000?oLhM[og>7J00Sog>7J00?o0000omcQf_l00000
0ooJem@00ol0003odm?Iom?Cf@0@om?Cf@04o`000?o<dMgo0000o`0005cooooo002Oooooo`?o0000
FOooool00ol0003ojOK>onWfcP07onWfcP03o`000?o/jL[o000000goi>GC00?o0000omcQf_oLhMX0
2OoLhMX01_l0003og>7JomcQf_l0003of]ODo`0001;odm?I00Co0000olcAgOo<dMgoc=7M0_l0001K
ooooo`00WOooool2o`0005_ooooo00?o0000onWfc_oYm/h02OoYm/h2o`0000coi>GC00?o0000omcQ
f_oLhMX02_oLhMX00ol0003og>7JomcQfP02o`00017odm?I0_l00005olcAg@;o0000F_ooool009[o
oooo0ol0001Looooo`03o`000?oYm/kojOK>00[ojOK>00?o0000on;af?l000002_oTiM<00ol0003o
g>7JomcQfP0;omcQfP05o`000?oLhM[o0000omCLg_l000004?oCdmT00ol0003oc=7MolcAg@05olcA
g@;o0000F_ooool009Sooooo0_l00003ooooo`03o`000?oooooooooo05Sooooo00?o0000onWfc_oY
m/h02_oYm/h01Ol0003oh_7Hon;af?oRlMSo000000Soi>GC00?o0000omcQf_oLhMX03?oLhMX2o`00
00?oe=cN00?o0000om?CfOoCdmT03?oCdmT00ol0003oc=7MolcAg@07olcAg@;o0000FOooool009Go
oooo0ol0001Pooooo`03o`000?oYm/kojOK>00WojOK>00?o0000on;af?oRlMP00ooRlMP2o`0000Go
i>GC00?o0000omcQf_oLhMX03OoLhMX00ol0003oe=cNomCLgP03omCLgP03o`000?oCdmWodm?I00Wo
dm?I0_l0000;olcAg@03o`000?oooooooooo05Oooooo001Jooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol0000Tooooo`;o0000H_ooool00ol0003ojOK>onWfcP09onWfcP03
o`000?oRlMSoh_7H00Koh_7H00Go0000onCUdooTiM?oi>GCo`00000?omcQfP;o00001_oDg=h00ol0
003odm?Iom?Cf@07om?Cf@03o`000?o<dMgoc=7M00coc=7M00?o0000ooooooooool0E_ooool005[o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A4027ooooo0ol0001Sooooo`03o`000?oYm/kojOK>00WojOK>00?o0000on;af?oRlMP02?oRlMP0
0ol0003oi>GCo`00000?omcQfP03o`000?oDg=ko000000Ooe=cN00?o0000om?CfOoCdmT01OoCdmT0
0ol0003oc=7MolcAg@0=olcAg@;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0>Oooool005[ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^023ooooo0_l00002ooooo`03o`000?oooooooooo063ooooo
00?o0000onWfc_oYm/h02OoYm/h00ol0003oh_7Hon;af009on;af0?o00003OoLhMX2o`0000?oe=cN
00?o0000omCLg_oDg=h01?oDg=h00ol0003odm?Iom?Cf@03om?Cf@;o00004Oo<dMd2o`0000Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0hooooo`00
F_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h07?ooool3o`0006Ko
oooo00?o0000onWfc_oYm/h02OoYm/h00ol0003oh_7Hon;af009on;af005o`000?oJjmoof^_Oom[[
gol000002ooLhMX00ol0003oe=cNomCLgP03omCLgP03o`000?oDg=koe=cN00Goe=cN00Go0000om?C
fOoCdmWodm?Io`00000ColcAg@;o00001oooool01Ol@413ooooooooooooooooo410@013ooooo00?o
0000ooooooooool0=oooool005[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo01Sooooo0ol0001Xooooo`03o`000?oYm/kojOK>00WojOK>00?o0000on;af?oRlMP02OoR
lMP00ol0003of^_Oom[[g`03om[[g`03o`000?oLhM[og>7J00Oog>7J00?o0000omCLg_oDg=h01?oD
g=h00ol0003oe=cNomCLgP06omCLgP03o`000?oCdmWo000001?oc=7M00Co0000olK>h?l0003o0000
1_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0>?ooool005[ooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Gooooo0ol0001Zooooo`03
o`000?oYm/kojOK>00SojOK>00?o0000on;af?oRlMP02OoRlMP00ol0003of^_Oom[[g`05om[[g`03
o`000?oLhM[og>7J00Gog>7J00?o0000omCLg_oDg=h01OoDg=h00ol0003oe=cNomCLgP06omCLgP;o
00004_o<dMd2o`0000?oa/kP00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`00F_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Dooooo`?o00000oooool00ol0003ooooooooo
o`1Vooooo`03o`000?oYm/kojOK>00SojOK>00?o0000on;af?oRlMP02OoRlMP00ol0003of^_Oom[[
g`07om[[g`03o`000?oLhM[og>7J00?og>7J00?o0000omCLg_oDg=h01_oDg=h00ol0003oe=cNomCL
gP05omCLgP03o`000?o=f>;o0000017oc=7M00?o0000olK>h?o6c^001?o6c^000ol0003ooooooooo
o`03ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0kooooo`00F_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Booooo`;o
0000K_ooool00ol0003ojOK>onWfcP08onWfcP03o`000?oRlMSoh_7H00Woh_7H00?o0000om[[gooJ
jml02OoJjml01Ol0003og>7JomcQf_oLhM[o000000Woe=cN00?o0000omCLg_oDg=h01?oDg=h01Ol0
003ocMSRolgHh_o=f>;o000000koc=7M0_l00007olK>h0;o00001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool0>oooool007kooooo0ol0001_ooooo`03o`000?oYm/ko
jOK>00SojOK>00?o0000on;af?oRlMP02OoRlMP00ol0003of^_Oom[[g`0;om[[g`03o`000?oLhM[o
000000[oe=cN00?o0000omCLg_oDg=h00_oDg=h2o`0000GocMSR00?o0000olcAgOo<dMd02_o<dMd0
0ol0003oa/kPolK>h008olK>h003o`000?oooooooooo00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00003?ooool01OnHV9So0000o`000?m4A4Co^[Zj02Wooooo001looooo`;o000000?o
ooooo`000?ooool0K_ooool00ol0003ojOK>onWfcP08onWfcP03o`000?oRlMSoh_7H00Woh_7H00?o
0000om[[gooJjml03?oJjml2o`0000_oe=cN00Go0000omCLg_oDg=koe=cNo`000008olgHhP03o`00
0?o<dMgoc=7M00Soc=7M00?o0000olK>h?o6c^002Oo6c^02o`0002Cooooo00Go410@okZj^_o^k^ko
MgMgoa0@400Yooooo`00NOooool3o`0007;ooooo00?o0000onWfc_oYm/h02?oYm/h00ol0003oh_7H
on;af009on;af003o`000?oJjmoof^_O00cof^_O00Co0000om;Ui?oBiNCo00002_oDg=h01?l0003o
e=cNo`000?l0000:olgHhP03o`000?o<dMgoc=7M00Goc=7M0_l0000=olK>h0;o00008oooool00ol0
003oooooooooo`0[ooooo`00Moooool2o`0007Cooooo0ol00008onWfcP03o`000?oRlMSoh_7H00Wo
h_7H00?o0000om[[gooJjml03?oJjml00ol0003od^GTom;Ui002om;Ui003o`000?oDg=koe=cN00Oo
e=cN0_l0000<olgHhP03o`000?o<dMgoc=7M00Coc=7M00?o0000olK>h?o6c^003_o6c^000ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo02_ooooo001dooooo`?o0000M_ooool00ol0003og?k?
omcnc`05o`0000;ojOK>00?o0000on;af?oRlMP02OoRlMP00ol0003of^_Oom[[g`0<om[[g`03o`00
0?oBiNCod^GT00Cod^GT00?o0000omCLg_oDg=h01_oDg=h00ol0003ocMSRolgHhP0<olgHhP04o`00
0?o<dMgoc=7MolcAg@;o00004Oo6c^02o`0002;ooooo00?o0000ooooooooool0:oooool0077ooooo
0ol000000ooooooo0000ooooo`1eooooo`03o`000?oLo/oog?k?00Kog?k?0ol0000:on;af003o`00
0?oJjmoof^_O00_of^_O0_l00008om;Ui003o`000?oDg=koe=cN00?oe=cN0ol0000?olgHhP03o`00
0?o<dMgo000001?oa/kP0ol0000Oooooo`03oa0@4?l0003o000000?o0000:_ooool006oooooo0_l0
0005ooooo`03o`000?oooooooooo07;ooooo00?o0000omcncooLo/l01_oLo/l01?l0003ofO_MomWk
gOoInmd2o`0000Ooh_7H00?o0000om[[gooJjml02ooJjml00ol0003od^GTom;Ui009om;Ui005o`00
0?oDg=koe=cNomCLg_l000000_o=f>800ol0003ocMSRolgHhP0=olgHhP;o00004oo6c^001?l0003o
`L_Ro`000?l0000Qooooo`03o`000?oooooooooo02_ooooo001/ooooo`?o0000Noooool00ol0003o
g?k?omcnc`06omcnc`03o`000?oInmgofO_M00CofO_M0_l00004on;af003o`000?oJjmoof^_O00_o
f^_O00?o0000om;Ui?oBiN@02ooBiN@00ol0003oe=cNo`000003olgHhP03o`000?o=f>;ocMSR00co
cMSR00?o0000olODi?l000004Oo6c^02o`0000?o`L_R0_l0000Pooooo`03o`000?oooooooooo02_o
oooo0015ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08?ooool2o`0007gooooo00?o0000omcncooL
o/l01_oLo/l00ol0003ofO_MomWkg@07omWkg@;o000000?oh_7Ho`000?oJjml03?oJjml00ol0003o
d^GTom;Ui00<om;Ui0;o00001?o=f>800ol0003ocMSRolgHhP0:olgHhP;o00000oo7e>@00ol0003o
a/kPolK>h00=olK>h003o`000?o1bn;o`L_R00Co`L_R00?o0000ooooooooool0C?ooool004Gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`?o00000_ooool00ol0003oooooooooo`1iooooo`03
o`000?oLo/oog?k?00Kog?k?00?o0000omWkgOoInmd02OoInmd3o`0000cof^_O00?o0000om;Ui?oB
iN@03?oBiN@00ol0003obmoWo`000005olgHhP03o`000?o=f>;ocMSR00SocMSR00?o0000olODi?o7
e>@01?o7e>@00ol0003oa/kPolK>h00:olK>h0;o00001oo1bn82o`0004gooooo0015ooooo`05oa0@
4?ooooooooooooooool@41006oooool2o`00083ooooo00?o0000omcncooLo/l01_oLo/l00ol0003o
fO_MomWkg@09omWkg@05o`000?oCm>KodoCVom?di_l000002OoJjml2o`0000kod^GT00Go0000ol_O
ioo;gnOobmoWo`000004olgHhP03o`000?o=f>;ocMSR00KocMSR0_l00008olODi003o`000?o6c^3o
a/kP00Soa/kP00?o0000ol7;h_o1bn802?o1bn82o`0004cooooo0015ooooo`05o`000?oooooooooo
ooooool000006?ooool3o`00087ooooo00?o0000omcncooLo/l01_oLo/l00ol0003ofO_MomWkg@09
omWkg@03o`000?oCm>KodoCV00?odoCV0_l00006om[[g`03o`000?oBiNCod^GT00cod^GT0_l00005
ol_Oi`05o`000?o=f>;ocMSRolgHh_l000001oo=f>800ol0003oamCTolODi009olODi003o`000?o6
c^3oa/kP00Goa/kP0_l0000<ol7;hP;o0000Boooool004Gooooo00Go0000ooooooooooooooooo`00
000Fooooo`;o0000Poooool00ol0003og?k?omcnc`06omcnc`03o`000?oInmgofO_M00WofO_M00?o
0000om?di_oCm>H01_oCm>H2o`0000?of^_O00?o0000om;Ui?oBiN@03?oBiN@00ol0003obmoWol_O
i`06ol_Oi`04o`000?o=f>;ocMSRo`0000GocMSR0_l0000<olODi003o`000?o6c^3oa/kP00Coa/kP
00?o0000ol7;h_o1bn803Oo1bn800ol0003oooooooooo`19ooooo`00AOooool01Ol@413ooooooooo
oooooooo410@01?ooooo0ol00002ooooo`03o`000?oooooooooo083ooooo00?o0000omcncooLo/l0
1OoLo/l00ol0003ofO_MomWkg@08omWkg@;o00002ooCm>H00ol0003of^_Oo`00000=om;Ui0;o0000
2_o;gnL00ol0003ocMSRo`000004olgHhP03o`000?o7e>CoamCT00goamCT00Co0000olK>h?o6c^3o
a/kP0_l0000@ol7;hP;o0000B_ooool004Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`?o
0000Qoooool00ol0003og?k?omcnc`05omcnc`03o`000?oInmgofO_M00SofO_M00?o0000om?di_oC
m>H02ooCm>H3o`0000cod^GT00?o0000ol_Oioo;gnL02oo;gnL2o`0000;ocMSR0_l0000AolODi003
o`000?o6c^3o000001?o`L_R00?o0000ooooooooool0B?ooool004Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0>ooooo`;o0000ROooool00ol0003og?k?omcnc`05omcnc`03o`000?oInmgofO_M00So
fO_M00?o0000om?di_oCm>H02ooCm>H01Ol0003ocNcZolg/j_o=k>[o000000[od^GT00?o0000ol_O
ioo;gnL03Oo;gnL00ol0003ocMSRo`00000ColODi0;o00005?o1bn82o`0004Wooooo001Eooooo`?o
000000?oooooo`000?ooool0Qoooool00ol0003og?k?omcnc`05omcnc`03o`000?oInmgofO_M00So
fO_M00?o0000om?di_oCm>H02ooCm>H00ol0003ocNcZolg/jP03olg/jP;o00001_oBiN@2o`0000oo
bmoW0ol0000BolODi0;o000000?o`M3Uo`000?o1bn804Oo1bn82o`000003okg9hol0003o000004So
oooo001Cooooo`;o0000S?ooool00ol0003og?k?omcnc`05omcnc`03o`000?oInmgofO_M00SofO_M
00?o0000om?di_oCm>H02_oCm>H2o`0000SocNcZ0_l00003om;Ui003o`000?o;gnOobmoW00cobmoW
1_l0000AolODi003o`000?o1d>Go`M3U00;o`M3U00?o0000ol7;h_o1bn803Oo1bn82o`0000Co_LWS
00?o0000ooooooooool0A_ooool0053ooooo0ol0002=ooooo`03o`000?oLo/oog?k?00Gog?k?00?o
0000omWkgOoInmd01ooInmd2o`0000codoCV00?o0000olg/j_o=k>X02_o=k>X00ol0003od^GTo`00
000<ol_Oi`?o000000?obmoWo`000?o5fNP00_o5fNP2o`0000koamCT0_l00006ol7@i@03o`000?o1
bn;o`L_R00[o`L_R0_l00007okg9h`03o`000?oooooooooo04Gooooo001?ooooo`;o0000S_ooool0
0ol0003og?k?omcnc`05omcnc`03o`000?oInmgofO_M00OofO_M00?o0000om?di_oCm>H02_oCm>H2
o`0000gocNcZ0ol00009ol_Oi`?o00000_o;gnL2o`0000GoaMWX0_l0000;olODi0;o00002Oo1d>D0
0ol0003o`L_Rol7;hP08ol7;hP03o`000?nmbN?o_LWS00Oo_LWS0_l00016ooooo`00Coooool3o`00
08cooooo00Co0000omcncooLo/oog?k?1ol00007omWkg@03o`000?oCm>KodoCV00[odoCV00?o0000
olg/j_o=k>X03?o=k>X01Ol0003oanC]olOTkOo7i>go000000GobmoW0ol00003ol_Oi`;o00002?o5
fNP2o`0000WoamCT00?o0000ol7@iOo1d>D02_o1d>D00ol0003o`L_Rol7;hP05ol7;hP;o00002onm
bN<00ol0003oooooooooo`14ooooo`00C_ooool2o`0000;ooooo00?o0000ooooooooool0Qoooool6
o`0000;o_og;00?o0000olGngoo5o]l00_o5o]l4o`0000;ofO_M00?o0000om?di_oCm>H02_oCm>H0
0ol0003ocNcZolg/jP0;olg/jP;o00001Oo7i>d00ol0003obmoWo`000002o`0000GobmoW00?o0000
olGIj?o5fNP02?o5fNP00ol0003oaMWXo`000006olODi0;o00003_o1d>D00ol0003o`L_Rol7;hP02
ol7;hP;o00003_nmbN<2o`0000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd07oooool004Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`;o00000_ooool00ol0003oooooooooo`25ooooo`03o`00
0?nooL_o_og;00Go_og;00?o0000olGngoo5o]l01oo5o]l4o`0000WodoCV0_l0000=olg/jP03o`00
0?o7i>goanC]00CoanC]0ol00006ol_Oi`;o00003?o5fNP00ol0003oaMWXo`000003olODi0;o0000
4Oo1d>D01?l0003o`L_Ro`000?l0000@okg9h`;o00001oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool07_ooool004Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o000000Goooooo`000?ooooooooooo`000025
ooooo`03o`000?nooL_o_og;00Go_og;00?o0000olGngoo5o]l01oo5o]l00ol0003oaOW[olGij`02
olGij`?o00001OoCm>H00ol0003ocNcZolg/jP0;olg/jP;o00001?o7i>d3o`0000?oanC]00Co0000
ol_Oioo;gnOobmoW0_l0000?olGIj005o`000?o5fNSo0000olODi?l000004oo1d>D2o`0001?o_LWS
00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOoo
ool02?ooool00ol0003oooooooooo`0Mooooo`00A?ooool01Ol@413ooooooooooooooooo410@00Go
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo087ooooo00?o0000okom
bonooL/01?nooL/2o`0000WoaOkO00?o0000olGijoo5nN/01_o5nN/3o`000003om?di_l0003ocNcZ
00cocNcZ00?o0000olOTkOo7i>d00_o7i>d2o`0000OoanC]00?o0000ol_Oiol000004Oo5fNP01?l0
003oaMWXo`000?l0000Bol7@i@;o000000?o_LgVo`000?nmbN<04_nmbN<2o`0000Kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool07_oo
ool004Cooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo0_l0
00000ooooooo0000ooooo`20ooooo`03o`000?nooL_o_og;00Co_og;00?o0000olGngoo5o]l01oo5
o]l2o`0000_oaOW[0ol0000;olg/jP;o00000_o7i>d3o`0000WoanC]0_l0000BolGIj0;o000000?o
`=CYo`000?o1d>D04?o1d>D00ol0003o_LgVokg=iP02okg=iP03o`000?nmbN?o_LWS00ko_LWS0_l0
00000onianCo0000o`000005ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07oooool004Cooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo00?ooooo0_l000000ooooooo0000ooooo`1nooooo`03
o`000?nooL_o_og;00Co_og;00?o0000olGngoo5o]l01oo5o]l00ol0003oaOW[olGij`0:olGij`04
o`000?o2l?3o`_3`ol;`l0;o00002?o=k>X00ol0003oanC]o`000002o`0000[oanC]0_l00002ol7M
k@03o`000?o5fNSoaMWX00goaMWX0_l00002ol3Dj@03o`000?o0e>Wo000000ko`M3U0_l00006okg=
iP03o`000?nmbN?o_LWS00_o_LWS0_l00004okW7i003o`000?oooooooooo00?ooooo00Go410@oooo
oooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool08Oooool0
04Cooooo00Go410@oooooooooooooooooa0@4004ooooo`?o00001Oooool2o`000003ooooool0003o
oooo07cooooo00?o0000okombonooL/01?nooL/00ol0003oaOkOolGng`06olGng`;o00002oo5nN/2
o`0000Ko`_3`0_l00004olg/jPCo00003?o7i>d00ol0003o`Mg]ol7Mk@03ol7Mk@03o`000?o5fNSo
aMWX00[oaMWX0_l00005ol3Dj@03o`000?o0e>Wo000000_o`M3U0_l00008okg=iP03o`000?nmbN?o
_LWS00Wo_LWS0_l00007okW7i003o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Qooooo`00A?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool01Oooool2o`000003oooo
ool0003ooooo07Wooooo0_l00006okomb`03o`000?o5o]ooaOkO00KoaOkO00?o0000olGijoo5nN/0
2Oo5nN/2o`0000[o`_3`1Ol0000=olOTk@;o00001oo1gNd00ol0003oaMWXolGIj008olGIj003o`00
0?o0e>Wo`=CY00Go`=CY00Co0000ol3DjOo0e>Wo00002Oo1d>D00ol0003o_LgVokg=iP09okg=iP03
o`000?nmbN?o_LWS00Oo_LWS00?o0000okW7i?nian@01onian@2o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00023ooooo0014ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01?ooool00ol0003oooooooooo`07ooooo`;o000000?oooooo`000?ooool0Moooool00ol0
003o_og;okomb`04okomb`;o00002?o5o]l00ol0003oaOW[olGij`09olGij`03o`000?o2l?3o`_3`
00Wo`_3`1Ol0000<olOTk@;o00002_o1gNd00ol0003oaMWXolGIj005olGIj0;o00002Oo0e>T01?l0
003o`=CYol3DjOl00006ol7@i@;o00003OnmcNH00ol0003o_LWSokg9h`04okg9h`;o00002onian@0
0ol0003oooooooooo`0nooooo`00COooool2o`0000Wooooo1?l0001fooooo`03o`000?nooL_o_og;
00Co_og;00?o0000olGngoo5o]l01_o5o]l2o`0000[oaOW[0_l00009ol;`l0Go00000onoj?800ol0
003oanC]olOTk@08olOTk@03o`000?o1gNgo`Mg]00_o`Mg]00?o0000olGIj?o5fNP00_o5fNP2o`00
00co`=CY00Co0000ol3DjOo0e>Wo00000oo1d>D2o`0000oo_LgV00?o0000okg9honmbN<00_nmbN<2
o`0000go^LOT0_l0000oooooo`00COooool00ol0003oooooooooo`0:ooooo`?o0000M?ooool00ol0
003o_og;okomb`04okomb`03o`000?o5o]ooaOkO00KoaOkO00?o0000olGijoo5nN/02Oo5nN/00ol0
003o`_3`ol;`l006ol;`l0?o00000_o2l?000ol0003o_nSbokoXlP04okoXlP;o00001_o7i>d2o`00
00oo`Mg]00Co0000olGIj?l0003o00003_o0e>T01ol0003o`=CYol3DjOo0e>Wo0000ol7@iOl00000
4_nmcNH01?l0003o_LWSo`000?l0000@okW7i0;o0000?_ooool004gooooo00?o0000ooooooooool0
2oooool3o`0007;ooooo00?o0000okombonooL/01?nooL/00ol0003oaOkOolGng`06olGng`03o`00
0?o5nN_oaOW[00SoaOW[0_l00007ol;`l0;o00000oo2l?02o`0000Wo_nSb00Co0000olOTkOo7i>go
anC]0_l0000Aol7Mk@;o00004Oo0e>T00ol0003o`=CYol3Dj@02o`0001?o_LgV0_l0000CokW7i003
o`000?oooooooooo03cooooo001=ooooo`03o`000?oooooooooo00cooooo1?l0001_ooooo`03o`00
0?nooL_o_og;00;o_og;3_l00007olGij`;o00001_o2l?03o`0000?o`_3`0_l0000<okoXlP03o`00
0?o7i>go0000017o`Mg]0_l00002okgHk@03o`000?o0e>Wo`=CY00oo`=CY0_l000000onkd>Wo0000
okg=iP0@okg=iP;o000000?o^L[Wo`000?nian@04_nian@2o`0003gooooo001<ooooo`;o00003ooo
ool2o`000003ohL00?l0003ooooo06cooooo00?o0000okombonooL/01?l00007oj;gg0;o00001?n^
mnh4o`0000;oaOW[00?o0000ol;`l?o2l?000oo2l?03o`0000Co`_3`0_l0000>okoXlP?o00003oo1
gNd2o`0000Go_MS]00?o0000ol3DjOo0e>T03?o0e>T2o`000005ok_@jOl0003o^m3Yok_@jOl00000
3_nmcNH2o`0000Co^L[W00?o0000okW7i?nian@04?nian@2o`0003gooooo001=ooooo`03o`000?oo
oooooooo00kooooo1Ol0001Zooooo`Co000000?oSNZlo`000?l000001onRmm`00ol0003o[_O^ojkg
kP08ojkgkP?o00000_o2l?03o`0000Go`_3`0_l0000>okoXlP;o00000onkh?800ol0003o`Mg]ol7M
k@0:ol7Mk@;o00002?nmf>d00ol0003o`=CYol3Dj@08ol3Dj@?o00000onkd>T01Ol0003o^m3Yok_@
jOnkd>Wo000000[o_LgV0ol00007okW:i`03o`000?nianCo^LOT00go^LOT0_l000000ongaNGo0000
o`00000looooo`00C?ooool00ol0003oooooooooo`0@ooooo`05o`000?l0B<;o0000ohL00?l00000
Ioooool3o`0000;oSNZl0_l00007oj;gg0;o00002On^mnh2o`0000;o/_7f1?l00006ol;`l003o`00
0?noj?;o_nSb00co_nSb0_l00006ok_PlP03o`000?o1gNgo`Mg]00So`Mg]00?o0000okgHkOnmf>d0
2Onmf>d00ol0003o`=CYol3Dj@05ol3Dj@;o00001onkd>T01Ol0003o^m3Yok_@jOnkd>Wo000000Oo
_LgV0_l0000:okW:i`03o`000?nianCo^LOT00_o^LOT0_l00004okO5i@;o0000>oooool004cooooo
0ol0000Aooooo`04o`000?l0B<;o0000ohL000;o0000I?ooool00ol0003oSNZlohgZ_002ohgZ_003
o`000?nRmmcoX_OL00GoX_OL0_l00009ojkgkP;o000000Co/_7fo`000?l0003o00001?nblOH3o`00
0003ol;`l?l0003o000000go_nSb0_l00009ok_PlP03o`000?o1gNgo`Mg]00Go`Mg]0_l0000=okgH
k@03o`000?o0e>Wo`=CY00;o`=CY0_l0000:ok_@j@05o`000?nkd>Wo^m3Yok_@jOl000001?nmcNH2
o`0000go^L[W00?o0000okW7i?nian@01onian@3o`0000Oo]lGU0_l0000jooooo`00C?ooool00ol0
003oooooooooo`0Booooo`03o`000?l0B<;o000000;oQ`000_l0001Qooooo`04o`000?n=j[coSNZl
ohgZ_0;o00001_nRmm`2o`0000Wo[_O^1Ol00009ok;amP?o00003Onoj?800ol0003o^n3bok_PlP0:
ok_PlP03o`000?o1gNgo`Mg]00;o`Mg]0_l0000@okgHk@04o`000?o0e>Wo0000o`0000go^m3Y00Ko
0000ok_@jOnkd>Wo^m3Yo`000?nmcNH2o`00013o^L[W00?o0000okW7i?nian@01?nian@2o`0000[o
]lGU0_l0000jooooo`00:Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool04oooool3o`00
00?oQ`000_l0001Mooooo`;o00000on=j[`00ol0003oX_OLoj;gg004oj;gg0;o00002_n^mnh3o`00
00[o/_7f0_l00003ok?Ym`;o00002Onoj?82o`0000ko^n3b00Co0000ol7MkOl0003o00004_nmf>d2
o`0000oo^m3Y00Co0000ok_@jOnkd>Wo^m3Y0_l0000BokW:i`03o`000?nianCo^LOT00;o^LOT0_l0
000=okO5i@;o0000>Oooool002Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0Eooooo`Co00000_n70002o`0005[ooooo00Co0000ohgZ_?n=j[coSNZl0_l00006oj;gg003
o`000?n^mnko[_O^00So[_O^0ol0000:ok;amP;o00001oncjOL2o`0000Go_nSb0_l0000@ok_PlP?o
00004Onmf>d2o`0000;o^M?]00?o0000ok_@jOnkd>T03Onkd>T3o`000003okS=j_l0003o^L[W01;o
^L[W00Co0000okW7i?l0003o00004?ngaND00ol0003oooooooooo`0gooooo`00:Oooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`02oooo
o`;o00006?ooool00ol0003o47CRo`000006o`0005Oooooo00?o0000ohgZ_?n=j[`00_l00006oj;g
g0;o00002?n^mnh3o`0000_o/_7f0_l0000;ok?Ym`;o000000?o_nSbo`000?l000004?nkh?82o`00
00?o^=[a00?o0000okgHkOnmf>d03?nmf>d2o`0000Go^M?]00?o0000ok_@jOnkd>T02onkd>T3o`00
00?o^<gZ00?o0000okW:ionib^L04?nib^L2o`0001;o]lGU0_l0000hooooo`00:Oooool01Ol0003o
oooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`03oooo
o`03o`000?oooooooooo01Sooooo00Co0000oa1dh_l0003o00000_n80004o`0005?ooooo0_l00002
ohgZ_004o`000?nRmmcoX_OLoj;gg0[o00000_n^mnh4o`0000_o/_7f0_l0000>ok?Ym`?o00003onk
h?82o`0000Ko^=[a00?o0000okgHkOnmf>d02Onmf>d2o`0000So^M?]00?o0000ok_@jOnkd>T02?nk
d>T2o`0000;o^<gZ00?o0000okS=j_nhcNX00_nhcNX00ol0003o^L[WokW:i`0<okW:i`?o000000?o
]/SWo`000?ngaND04_ngaND2o`0003Oooooo000Yooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?l@M>;o47CR00;o00000on80003o`00053ooooo00?o0000ohgZ_?n=j[`0
2Ol00006ohg/k@Oo00002OnblOH2o`0000ko/nWg0_l00003ok;Qm`03o`000?nkh?;o^n3b00[o^n3b
0_l00009okSJl@;o00001onmf>d2o`0000_o^M?]00?o0000ok_@jOnkd>T01Onkd>T2o`0000Go^<gZ
00?o0000okS=j_nhcNX00_nhcNX00ol0003o^L[WokW:i`09okW:i`;o00001Onfb>L00ol0003o]lGU
okO5i@0@okO5i@;o0000=oooool002Wooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01_ooool2o`0001_ooooo00Go0000oa1dh_l@M>;o
47CRo`000005ohP000;o0000COooool01?l0003oSNZlo`000?l00004og;Qd@;o00001_n=k>d6o`00
00CoVnci1Ol00002ok;amP;o00003_ncjOL2o`0000Ko/^7g0_l00008ok_PlP;o00003Onhf_400ol0
003o_MS]okgHk@02okgHk@;o00003_nidnd00ol0003o^m3Yok_@j@02ok_@j@;o00002?nhcNX00ol0
003o^<gZokS=jP02okS=jP03o`000?nib^Oo^L[W00Ko^L[W0_l00008okK8i`03o`000?ngaNGo]lGU
00co]lGU0ol000000onda>Ko0000o`00000fooooo`00:Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool06oooool01?l0003o47CRoa1dh_l@M>82o`0000GoR0000_l00019ooooo`Co00000omb
hM43o`0000GoSNc]0ol000000on=k>go0000o`00000<oi_/n@?o00003OncjOL2o`0000[o/^7g0_l0
0004ok_PlP;o00004?nhf_401?l0003o_MS]o`000?l0000AokWCk@04o`000?nkd>Wo0000o`0000_o
^<gZ00?o0000okS=j_nhcNX00_nhcNX00ol0003o^L[WokW:i`02okW:i`?o00002onfb>L00ol0003o
]lGUokO5i@09okO5i@;o00001Onda>H2o`0003Gooooo000Yooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00005ooooo`03o`000?oooooooooo
01cooooo00?o0000oa1dh_l@M>800_l@M>82o`0000GoR0000ol00015ooooo`?o00000ombhM42o`00
00GoSNc]0ol000001?n=k>go0000o`000?l0000;oi_/n@?o00000onSi_/2o`0000Wo/nWg0_l0000>
ok;Qm`04o`000?nkh?;o0000o`0001;o^=[a0_l0000CokWCk@;o00003OnhcNX00ol0003o^<gZokS=
jP03okS=jP04o`000?nib^Oo0000o`0000ko]/SW00?o0000okO5iOngaND01_ngaND3o`0000So]<CV
00?o0000ooooooooool01oooool4o`000003oa0@4?oooooooooo02Gooooo001;ooooo`03o`000?oo
oooooooo01gooooo00?o0000oa1dh_l@M>800ol@M>800ol0003oR000ohP00005ohP000;o0000@Ooo
ool3o`0000;oL^7A0ol00005ohg/k@;o00000_n=k>d2o`0000coVnci0_l00008oj?Vn`;o00001Onc
jOL2o`00013o/^7g0ol0000AokSJl@;o000000?o]MC`o`000?nidnd04?nidnd2o`000003okK?k?l0
003o^<gZ00go^<gZ00?o0000okS=j_nhcNX00_nhcNX2o`00017o]/SW00?o0000okO5iOngaND00ong
aND2o`0000_o]<CV0_l0000:ooooo`03o`000?oooooooooo02Oooooo001:ooooo`03o`000?oooooo
oooo01oooooo0ol00003oa1dhPOo00000_n80002o`0003cooooo1?l000000ombhM7o0000o`000009
o`000004ohg/kOl0003o0000o`0000_oVnci0ol0000<oj?Vn`;o000000?o/nWgo`000?l000003onb
hOL3o`0000?o/M[e00?o0000okSJlOnhf_403?nhf_42o`0000Co]MC`00?o0000okWCkOnidnd03?ni
dnd2o`0000Co]/o/00?o0000okS=j_nhcNX03?nhcNX01_l0003o^<gZo`000?l0003o]L[Yo`0001;o
]/SW00?o0000okO5iOl000000_l0000>okC4iP;o00002Oooool00ol0003oooooooooo`0Wooooo`00
B_ooool00ol0003oooooooooo`0Qooooo`Go000000?o47CRo`000?l000000omi0009o`0003Gooooo
1ol00005ofGHj0Wo00002_nKk?T2o`00013oXnKk0ol0000>ok;Qm`;o00001onaf_D00ol0003o^=[a
okSJl@08okSJl@?o00001onee?000ol0003o^M?]okWCk@08okWCk@?o00001onfcn`00ol0003o^<gZ
okS=jP0;okS=jP;o00001?neb^T00ol0003o]/SWokK8i`0?okK8i`;o00004Onda>H2o`0000Wooooo
00?o0000ooooooooool09oooool004[ooooo00?o0000ooooooooool08_ooool01?l0003o?Y3_ocj@
kolnT>l5o`0000SoN@001_l0000^ooooo`Ko00001_mUf>P7o`0000GoPN3i1Ol00002oi_/n@?o0000
3onSi_/3o`0000?oYmok0_l00009ok;Qm`?o00002_naf_D00ol0003o^=[aokSJl@05okSJl@;o0000
2onee?000ol0003o^M?]okWCk@05okWCk@;o00002onfcn`00ol0003o^<gZokS=jP07okS=jP?o0000
00?o]L[Yo`000?neb^T01?neb^T00ol0003o]/SWokK8i`0;okK8i`?o000000?o]<KXo`000?nda>H0
4Onda>H2o`0000Sooooo00?o0000ooooooooool09oooool004[ooooo0_l0000Tooooo`03o`000?ln
T>oo?Y3_00Co?Y3_0ol00009ogT000Oo00009_ooool7o`0000KoIMSX1_l0000=oh7Pn@Co00003_nS
i_/3o`0000SoYmok00?o0000ok;QmonbhOL01?nbhOL2o`0000ko/M[e00?o0000okSJlOnhf_400_nh
f_42o`0000ko]MC`00?o0000okWCkOnidnd00_nidnd2o`0000go]/o/00?o0000okS=j_nhcNX01Onh
cNX2o`0000Go]L[Y00?o0000okG:jOneb^T00oneb^T00ol0003o]/SWokK8i`08okK8i`;o00001Ond
a^P00ol0003o]<CVokC4iP0?okC4iP?o00001oooool00ol0003oooooooooo`0Wooooo`00B_ooool0
0ol0003oooooooooo`0Tooooo`03o`000?lnT>oo?Y3_00Ko?Y3_00?o0000ogT00?mi00002Omi0003
o`000003och00?l0003o000000?o00007_ooool:o`0000?oIMSX1_l0000<oh7Pn@Co00001?nAgoh3
o`0000SoXnKk0ol0000<ojOOn`;o000000Co/^7go`000?l0003o00004Onaf_D01?l0003o^=[ao`00
0?l0000AokGDl004o`000?nidngo0000o`00013o]/o/00?o0000okS=j_nhcNX00_nhcNX2o`0000So
]L[Y00?o0000okG:jOneb^T00_neb^T00ol0003o]/SWokK8i`06okK8i`;o00002?nda^P00ol0003o
]<CVokC4iP0;okC4iP?o000000?o//?Vo`000?l000001oooool00ol0003oooooooooo`0Wooooo`00
B_ooool00ol0003oooooooooo`0Uooooo`03o`000?lnT>oo?Y3_00Ko?Y3_0_l0000:ogT000go0000
4_ooool;o`0000Ko?KoP1_l0000<oh7Pn@?o00002onAgoh3o`0000;oXnKk0ol0000@ojOOn`?o0000
4onaf_D3o`0001;o]MC`0_l0000CokK?k004o`000?nhcN[o0000o`0000[o]L[Y00?o0000okG:jOne
b^T00oneb^T00ol0003o]/SWokK8i`02okK8i`?o00002onda^P00ol0003o]<CVokC4iP08okC4iP;o
00001Onb`nH2o`0000Cooooo00?oEEEEofIVI_l00000:Oooool004Wooooo0ol0000Wooooo`03o`00
0?lnT>oo?Y3_00Ko?Y3_0ol00003ogT000Go00002?mL000Po`000003ocfoh?l0003o000000Go0000
1_mUd?P5o`0000?oPN3i1?l0000@oi7OoP?o00004?nWgo/3o`0000?oZ=Wh00?o0000ok7JmOnaf_D0
3Onaf_D3o`0000?o/=Cc00?o0000okGDl?nee?003?nee?03o`0000;o/]3_00?o0000okK?k?nfcn`0
4?nfcn`2o`0000go]L[Y00?o0000okG:jOneb^T00oneb^T01?l0003o]/SWo`000?l0000>okC6j003
o`000?nda>Ko]<CV00Ko]<CV0_l00008ok;3iP;o0000;oooool004Wooooo00?o0000ooooooooool0
:?ooool00ol0003o?Y3_ocj@k`07ocj@k`Co00005?mL000:o`0000Co<@003?l00002ofG@n0;o0000
3OmUd?P4o`00017oTMon0ol00003oi[Jo@03o`000?nWgo_oYmok00_oYmok0_l00007ojSIn003o`00
0?naf_Go/M[e00[o/M[e0_l00007ok3Dl`03o`000?nee?3o]MC`00Wo]MC`0_l00006ok;@k`03o`00
0?nfcnco]/o/00co]/o/0ol00002ok?;k003o`000?neb^Wo]L[Y00_o]L[Y00?o0000okG:jOneb^T0
0_neb^T2o`00017o]<KX00?o0000okC4i_nda>H00_nda>H3o`0000[o//?V0_l0000_ooooo`00;_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`0Yooooo`Co00001_lnT>l00ol0003o=IKaocFFl@05o`0000_o
G0001?l0000;oc4000So00001_m=_oH3o`0000[oIM3h1Ol00004ogkDo`;o00003?nAgoh3o`0000Oo
V][m0_l00009ojOOn`;o00002_nXfOP2o`0000So/M[e0_l0000:ok3Dl`03o`000?nee?3o]MC`00Ko
]MC`0_l00009ok;@k`03o`000?nfcnco]/o/00Wo]/o/0_l00006ok?;k003o`000?neb^Wo]L[Y00_o
]L[Y1?l000000oncanWo0000okC6j00AokC6j004o`000?nda>Ko0000o`0000ko//?V0_l0000^oooo
o`00;_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0:_ooool00ol0003oGJ3doefPm006o`000003ocj@kol0003o=IKa
00Go=IKa1Ol00003oe`000?o00003Ola0006o`0000OoCKof0ol00003odfomP?o00000_mUd?P5o`00
00_oO]Co0ol00006oi7OoP?o00003?nJf_d2o`0000CoYmok0ol0000>ojSIn003o`000?naf_Go/M[e
00;o/M[e0ol0000=ok3Dl`03o`000?nee?3o]MC`00;o]MC`0ol0000<ok;@k`03o`000?nfcnco]/o/
00Ko]/o/0_l00009ok?;k003o`000?neb^Wo]L[Y00Wo]L[Y0_l00005ok?7j@03o`000?nda^So]<KX
00oo]<KX0_l0000Aok;3iP;o0000;Oooool002kooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00;ooooo0ol0000/ooooo`03o`000?mMX?CoGJ3d00GoGJ3d2Ol00004ocFF
l@[o00001ola0005o`0000;o>jkd0ol00002odfomP?o00000om=_oH8o`0001?oO]Co0_l000001?nA
goko0000o`000?l0000Aoi[Jo@04o`000?nWgo_o0000o`0001;oZ=Wh00Co0000ok7JmOl0003o0000
4On`e?<01?l0003o]MC`o`000?l0000@ok;@k`03o`000?nfcnco]/o/00;o]/o/0ol0000<ok?;k003
o`000?neb^Wo]L[Y00Ko]L[Y0_l00002ok?7j@03o`000?ncanWo/lOY00?o/lOY00?o0000okC6j?nd
a^P02onda^P3o`000003ok;4j?l0003o//?V013o//?V0_l0000]ooooo`00;_ooool01Ol0003ooooo
oooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0/ooooo`03
o`000?mMX?CoGJ3d00SoGJ3d00?o0000oeVWn?mIYoP00_mIYoP=o`000003oc>Pl_l0003o000000Ko
00000olk[_@>o`0000SoKLSn0_l0000AogkDo`Co00004_nJf_d4o`0001?oZ=Wh0ol0000Bok3Dl`;o
00004onbd>l01?l0003o]/o/o`000?l0000@ok?;k003o`000?neb^Wo]L[Y00;o]L[Y0ol00005ok?7
j@03o`000?ncanWo/lOY00?o/lOY00?o0000okC6j?nda^P02?nda^P2o`0000Go//CX00?o0000ok;3
i_nb`nH03onb`nH2o`0002cooooo000^ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0;Oooool00ol0003oGJ3doefPm008
oefPm003o`000?mIYoSoFJOh00SoFJOh00?o0000oeZ`nomJ/?/00omJ/?/<o`0000;oH;cm0ol00004
of2lo@03o`000?m]b?koKLSn00coKLSn0ol00009ogkDo`Go00001?n=dol2o`0000goV][m0ol00004
oioEn`03o`000?nXfOSoZ=Wh00goZ=Wh0ol00003ojWCmP03o`000?n`e??o/=Cc00co/=Cc0ol00002
ojk@l@03o`000?nbd>oo/]3_013o/]3_0_l0000Cok?;k004o`000?neb^Wo0000o`0000So/lOY00?o
0000ok?7jOncanT00oncanT00ol0003o]<KXokC6j006okC6j0;o00002?nba>P00ol0003o//?Vok;3
iP0>ok;3iP?o0000:oooool002kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0;oooool00ol0003oGJ3doefPm008oefPm0;o00002OmI
YoP2o`0000[oF[3k0_l00002of2lo@?o00002?mP_?d2o`0000ooKLSn0_l00002ogkDo`Go00002on=
dol2o`0000OoV][m1?l00008oioEn`;o00002_nXfOP3o`0000OoZM?f00?o0000ok3Dlon`e?<02On`
e?<2o`0000Ko[]3a00?o0000ok;@konbd>l03?nbd>l3o`000003ok7<k_l0003o/l_/01;o/l_/0_l0
000;ok?7j@03o`000?ncanWo/lOY00?o/lOY00?o0000okC6j?nda^P00_nda^P3o`0000_o//CX00?o
0000ok;3i_nb`nH02_nb`nH3o`000003ok32iol0003o000002_ooooo000>ooooo`;o00002oooool0
0ol0003o^[Zjooooo`0<ooooo`;o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
0000ooooooooool01_ooool2o`00037ooooo00?o0000oefPm?mMX?@02OmMX?@00ol0003oFJOhoeVW
n008oeVWn003o`000?mJ/?_oF[3k00SoF[3k0ol0000=of2lo@;o00003?m]b?h5o`0001;oSM?o0_l0
0002oi[Jo@?o00003_nOeO/2o`0000GoZ=Wh0ol0000;ojWCmP03o`000?n`e??o/=Cc00Ko/=Cc0_l0
0009ojk@l@03o`000?nbd>oo/]3_00Wo/]3_0_l00005ok7<kP03o`000?ncbnco/l_/00go/l_/0ol0
00000onab>_o0000ok?7j@0;ok?7j@03o`000?ncanWo/lOY00?o/lOY00Co0000okC6j?l0003o0000
3_nba>P00ol0003o//?Vok;3iP07ok;3iP?o00001On``^L2o`0002[ooooo000>ooooo`03o`000?oo
oooooooo00[ooooo0_lb<S8>ooooo`08o`000?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h<oooo
o`Co00001Oooool00ol0003oooooooooo`0aooooo`03o`000?mMX?CoGJ3d00WoGJ3d00?o0000oeVW
n?mIYoP02?mIYoP2o`0000KoF[3k0_l00003oeZ`n`03o`000?mP_?goH;cm00coH;cm00?o0000ofg8
o_m]b?h00_m]b?h7o`0000GoPL_o0_l0000@ohgCo`Co00004onOeO/00ol0003oZ=Who`000002o`00
00ooZM?f00?o0000ok3Dlon`e?<00_n`e?<3o`0000co[]3a00?o0000ok;@konbd>l01_nbd>l2o`00
00So/Lc^00?o0000ok?;k?ncbn`02_ncbn`2o`0000Go/LS[00?o0000ok?7jOncanT02_ncanT00ol0
003o/lOYok?7j@02ok?7j@;o00004Onba>P00ol0003o//?Vok;3iP03ok;3iP?o00002On``^L00ol0
003oooooooooo`0Xooooo`000oooool01Ol@413o0000o`000?l0003o410@00Kooooo00Co0000oooo
oooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o
0000odA4A?nj^[X01?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03;ooooo00?o
0000oefPm?mMX?@02OmMX?@00ol0003oFJOhoeVWn009oeVWn003o`000?mJ/?_oF[3k00?o00001_mJ
/?/2o`0000OoH;cm2_l0000>oh7;o`;o00002On=dol5o`0000CoU]3l00?o0000oioEnonOeO/03onO
eO/4o`0001;oZM?f00Co0000ok3Dlol0003o00004?n^d?400ol0003o/]3_ok;@k`02ok;@k`?o0000
2onac>h00ol0003o/l_/ok?;k006ok?;k0?o00002?nab>/00ol0003o/lOYok?7j@09ok?7j@03o`00
0?ncanWo000000;o000000?o/LGYo`000?nba>P04Onba>P00ol0003o//?Vo`000002o`0000co/<;W
0_l0000Yooooo`001Oooool00ol0003oooooooooo`06ooooo`0:o`000?ooooooooooooooooo^k^ko
8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mg
MgOo410@00Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0cooooobco00002?mh
`Oh2o`00013oPL_o0_l00002ohgCo`Go00002_nFd?`2o`0000coWmGk0ol00004oj;An003o`000?nY
doKoZM?f00koZM?f1?l0000Bojk@l@04o`000?nbd>oo0000o`0000oo/Lc^00?o0000ok?;k?ncbn`0
0oncbn`2o`0000co/LS[00?o0000ok?7jOncanT02?ncanT2o`0000Go/LGY00?o0000ok;4j?nba>P0
3onba>P2o`00013o/<;W0_l0000Xooooo`001Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo01Wooooo0_l0000fooooo`03o`000?mbZ_CoLZ[d00[oLZ[d00?o0000og2`n?m`/?P0
0om`/?P3o`0000?oL;3h00?o0000og:hnomb^?/02_mb^?/2o`0000goN<7n0_l0000>oh7;o`Co0000
4OnFd?`2o`0000KoWmGk1?l00008oj;An0;o00002onYdoH3o`0000CoZLoc00?o0000ojk@lOn^d?40
3on^d?43o`00017o/Lc^00?o0000ok?;k?l000000_l0000>ok78j`03o`000?ncanWo/lOY00Ko/lOY
0_l00002ok75j@03o`000?naaNWo/LGY00?o/LGY00?o0000ok;4j?nba>P02onba>P3o`000003ok33
j?l0003o/<;W00oo/<;W0_l0000Xooooo`001Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0=_ooool00ol0003oLZ[dog:Zm00:og:Zm003o`00
0?m`/?So000000;o00001om`/?P2o`0000coL[Sk0_l0000=ogS1oP03o`000?n1boooPL_o00KoPL_o
1Ol00004ohg:o003o`000?nFd?coU]3l013oU]3l00?o0000oioEnonOeO/00ol0000>oj;An003o`00
0?nYdoKoZM?f00CoZM?f1?l00008ojW?l`03o`000?n^d?7o[]3a00_o[]3a0ol00003ojg<l003o`00
0?nac>ko/Lc^00ko/Lc^0_l0000Bok78j`03o`000?ncanWo/lOY00;o/lOY0ol00005ok75j@03o`00
0?naaNWo/LGY00?o/LGY00?o0000ok;4j?nba>P02?nba>P2o`0000Go/<?X00?o0000ok32ion``^L0
3_n``^L2o`0002Oooooo0005ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oo
ool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0gooooo`03o`000?mbZ_CoLZ[d00SoLZ[d1?l0000;og2`n003o`00
0?mb^?_oL[Sk00_oL[Sk00?o0000ogS1o_mh`Oh02omh`Oh2o`0000;oPL_o1?l0000:ohg:o0;o0000
3onFd?`4o`0001;oX]7h00?o0000ojWCm_nYdoH00ol0000=ojW?l`03o`000?n^d?7o[]3a00Oo[]3a
0ol00007ojg<l003o`000?nac>ko/Lc^00[o/Lc^0ol00002ojo9k@03o`000?nab>_o/LS[013o/LS[
00Co0000ok?7jOl0003o00002?naaNT00ol0003o/LGYok75j@03ok75j@03o`000?nba>So//CX00Ko
//CX0_l00008ok33j003o`000?n``^Oo/<;W00go/<;W0ol0000Vooooo`000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002oooo
o`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool06Oooool2o`00
03Wooooo00?o0000og:Zm?mbZ_@01?mbZ_@3o`0000CoLZ[d00?o0000og2`n?m`/?P02Om`/?P2o`00
00coL[Sk0_l00007ogS1oPSo00004?n=b_`2o`0000SoU]3l1Ol00004oi_=n@03o`000?nRdOSoX]7h
00ooX]7h0ol0000AojW?l`03o`000?n^d?7o[]3a00?o[]3a0ol0000;ojg<l003o`000?nac>ko/Lc^
00Ko/Lc^0ol00006ojo9k@03o`000?nab>_o/LS[00oo/LS[0_l0000;ok75j@03o`000?naaNWo/LGY
00?o/LGY00?o0000ok;4j?nba>P00_nba>P3o`0000[o/<?X00?o0000ok32ion``^L02_n``^L3o`00
0003ojo1iol0003o000000Wooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`00
00Cooooo00CoA4A4o`000?l0003o<S8b0OoMgMd000;ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03Wooooo00?o0000og:Zm?mbZ_@00ol00008
og:Zm003o`000?m`/?SoL;3h00[oL;3h00?o0000og:hnomb^?/01Omb^?/=o`0000SoQ/?k00?o0000
ohg:o?n=b_`03on=b_`00ol0003oU]3loiK@o005o`0000[oVlgi00?o0000oj;An?nRdOP02onRdOP3
o`0000?oY<ge00?o0000ojW?lonYco<03onYco<00ol0003o[]3ao`000002o`0000oo[Lc`00?o0000
ok7<k_nac>h00onac>h2o`0000[o[lW]00?o0000ok78jonab>/02onab>/3o`000003ok36jol0003o
/LGY00_o/LGY00?o0000ok75jOnaaNT00onaaNT01?l0003o//CXo`000?l0000>ok33j003o`000?n`
`^Oo/<;W00Ko/<;W0ol00005ojo1i`;o00002_ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo0OmgMgL1oc8b<P000_ooool7o`0000Gooooo0_l0
000Booooo`03o`000?oooooooooo00Gooooo0_l0000Kooooo`03o`000?oooooooooo03[ooooo0_l0
000<og:Zm003o`000?m`/?SoL;3h00CoL;3h3Ol00008oh:ln@03o`000?n6`o_oQ/?k00_oQ/?k0_l0
000>ohg:o0Co00004?nKcOT2o`0000SoX]7h0ol00007ojC=m@03o`000?nYco?oZLoc00goZLoc1?l0
000Bojg<l003o`000?nac>ko000000;o00003On_bNd00ol0003o/LS[ok78j`07ok78j`?o00001On`
a^/00ol0003o/LGYok75j@09ok75j@03o`000?naaNWo/LGY00?o/LGY0_l0000@ok33j003o`000?n`
`^Oo/<;W00?o/<;W0ol00009ojo1i`;o00002Oooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo0Ol0000004Oooooo0_l0000hooooo`?o000000?oooooo`000?mbZ_@01_mbZ_@<
o`0000SoP;Kf00?o0000oh:lnOn2_?T02on2_?T00ol0003oQ/?kohK3n`0<ohK3n`;o00001on=b_`5
o`0000CoULSi00?o0000oi_=nOnKcOT03onKcOT00ol0003oX]7hoj;An003oj;An0;o00002onTcOD0
0ol0003oZLocojW?l`09ojW?l`?o00001?nZc?400ol0003o[Lc`ojg<l00?ojg<l0;o00004On_bNd0
0ol0003o/LS[ok78j`03ok78j`?o00002On`a^/00ol0003o/LGYok75j@09ok75j@03o`000?naaNWo
000000;o000000?o[lCYo`000?n``nP04?n``nP00ol0003o/<;Wo`000002o`0000co[l7W0_l00009
ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool1ogMgM`7o<S8b0016oooo
o`03o`000?oooooooooo03Gooooo0ol00005ooooo`Oo00002?n1/?<00ol0003oP;Kfoh2fmP0:oh2f
mP03o`000?n2_?WoP[ci00_oP[ci0_l0000>ohK3n`03o`000?n=b_coSL[l00Co00002_nEb?T00ol0
003oVlgioi_=n@0?oi_=n@03o`000?nRdOSo000000;o00003_nTcOD00ol0003oZLocojW?l`04ojW?
l`Co00002?nZc?400ol0003o[Lc`ojg<l00;ojg<l0?o000000?o[LW_o`000?n_bNd04On_bNd00ol0
003o/LS[o`000002o`0000go/<K[00?o0000ok75jOnaaNT01onaaNT3o`0000Go[lCY00?o0000ok33
j?n``nP03_n``nP2o`00013o[l7W0_l00008ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIV
I_ooool00oooool01?l0003o8B4Qo`000?lb<S81olc<c0008oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo03;ooooo0ol0000:ooooo`03o`000?n1/??oPK3c00_oPK3c00?o
0000oh2fm_n0]_H02_n0]_H00ol0003oP[cioh:ln@0<oh:ln@03o`000?n6`o_oQ/?k00WoQ/?k1Ol0
000?oiG8n@;o00003_nKcOT4o`00017oY<ge00?o0000ojW?lonYco<00ol0000=oj[<l@03o`000?n]
c?3o[Lc`00Oo[Lc`0ol00005ojg9k`03o`000?n_bNgo[lW]00oo[lW]0_l0000Aok36j`03o`000?na
aNWo/LGY00?o/LGY0ol00003ojo4j@03o`000?n_a>Wo[lCY00?o[lCY00?o0000ok33j?n``nP02_n`
`nP3o`000003ojo2j?l0003o[l7W00oo[l7W0ol00007ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`008oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`0_ooooo`?o00003_ooool00ol0003oPK3coh6`l`0;oh6`l`03o`000?n0
]_KoP;Kf00[oP;Kf00?o0000oh:lnOn2_?T03?n2_?T01?l0003oQ/?kohK3non6`o/7o`0000GoT<?h
00?o0000oiG8nOnEb?T03_nEb?T00ol0003oVlgioi_=n@06oi_=n@Go00001?nOb_H00ol0003oY<ge
ojC=m@0=ojC=m@Co00004OnZc?400ol0003o[Lc`ojg<l003ojg<l0?o00002On]bNl00ol0003o[lW]
ojo9k@0;ojo9k@?o000000?o[/O/o`000?n`a^/04On`a^/00ol0003o/LGYo`000002o`0000Ko[lCY
00?o0000ojo4jOn_a>T01?n_a>T00ol0003o/<?Xok33j006ok33j0?o00001On_`^P00ol0003o[l7W
ojo1i`0>ojo1i`;o00001oooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`02ooooo`008oooool01Ol@413ooooooooooooooooo410@00go
oooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`;o0000;Oooool3o`0001;o
oooo0_l0000<oh6`l`03o`000?n0]_KoP;Kf00[oP;Kf00?o0000oh:lnOn2_?T02On2_?T6o`0000go
T<?h00?o0000oiG8nOnEb?T03_nEb?T00ol0003oVlgioi_=n@05o`0000[oWl[f0_l0000:ojC=m@?o
00001?nVb_<00ol0003oZ/caoj[<l@0?oj[<l@03o`000?n]c?3o000000;o00003On]bNl00ol0003o
[lW]ojo9k@07ojo9k@?o00001On^an`00ol0003o/<K[ok36j`0?ok36j`;o00002_n_a>T00ol0003o
[lCYojo4j@03ojo4j@03o`000?n``nSo/<?X00?o/<?X0ol00009ojo2j003o`000?n_`NOo[l7W00go
[l7W0_l00005ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00000Oooool002?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo
00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Yooooo`?o00005oooool00ol0
003oPK3coh6`l`0:oh6`l`03o`000?n0]_KoP;Kf00[oP;Kf00Co0000oh:lnOn2_?WoP[ci1ol00005
ohbmm`03o`000?n@`oSoT<?h00coT<?h0_l0000=oiG8n@Co00004OnOb_H00ol0003oY<geojC=m@04
ojC=m@?o00002?nVb_<00ol0003oZ/caoj[<l@0=oj[<l@?o00004On]bNl00ol0003o[lW]ojo9k@03
ojo9k@?o00002On^an`00ol0003o/<K[ok36j`0;ok36j`?o000000?o[/GZo`000?n_a>T02_n_a>T0
0ol0003o[lCYojo4j@03ojo4j@03o`000?n``nSo000000;o00003?n_`^P00ol0003o[l7Wojo1i`0:
ojo1i`?o000000?oooooo`000?ooool08Oooool002?ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo02Oooooo0_l0000Kooooo`03o`000?n1/??oPK3c00[oPK3c00?o0000oh2fm_n0]_H01?n0
]_H9o`0000goS;gg00?o0000oi33n?n@`oP03On@`oP00ol0003oULSioiG8n@05oiG8n@Go00001?nJ
a_H00ol0003oWl[foio:mP0?oio:mP03o`000?nTcOGoY<ge00?o00003?nVb_<00ol0003oZ/caoj[<
l@09oj[<l@?o00000onZbO000ol0003o[LW_ojg9k`0?ojg9k`03o`000?n_bNgo000000;o00003On^
an`00ol0003o/<K[ok36j`07ok36j`?o00001On^aNX00ol0003o[lCYojo4j@08ojo4j@03o`000?n_
a>Wo[lCY00?o[lCY0_l0000@ojo2j003o`000?n_`NOo[l7W00Ko[l7W0ol00004ooooo`03o`000?oo
oooooooo023ooooo000Sooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgoooo
o`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09Oooool3o`0001kooooo00?o
0000oh6`lon1/?<01?n1/?<<o`0000SoRkSd00?o0000ohbmmon<_OL03?n<_OL00ol0003oT<?hoi33
n00=oi33n003o`000?nEb?WoULSi00Co00002_nJa_H00ol0003oWl[foio:mP0=oio:mPCo00004?nV
b_<00ol0003oZ/caoj[<l@04oj[<l@Co00001onZbO000ol0003o[LW_ojg9k`0=ojg9k`?o00004On^
an`00ol0003o/<K[ok36j`03ok36j`?o00002On^aNX00ol0003o[lCYojo4j@08ojo4j@03o`000?n_
a>Wo000000;o000000?o[/?Yo`000?n_`^P03on_`^P00ol0003o[l7Wojo1i`03ojo1i`?o00002?oo
ool00ol0003oooooooooo`0Oooooo`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Kooooo0_l0000Sooooo`?o0000
8_ooool6o`0000SoRkCa00?o0000oh^hm?n;^?@02_n;^?@00ol0003oS;ggohbmm`0<ohbmm`03o`00
0?n@`oSoT<?h00_oT<?h1?l0000?oi[6mP;o00002_nOb_H3o`0000?oX/Sc00?o0000ojK:lonVb_<0
3onVb_<00ol0003oZ/caoj[<l@03o`0000coZ/W`00?o0000ojg9kon]bNl02On]bNl3o`0000;o[<O]
00?o0000ojk7k?n^an`04?n^an`00ol0003o/<K[o`000002o`0000go[/GZ00?o0000ojo4jOn_a>T0
1_n_a>T3o`0000Go[/?Y00?o0000ojo2j?n_`^P03_n_`^P00ol0003o[l7Wo`000002o`0000_ooooo
00?o0000ooooooooool07oooool002?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go0000
1?ooool4o`0000Gooooo00?o0000ooooooooool07oooool3o`0002Kooooo00?o0000oh^dlOn;]?40
2on;]?400ol0003oRkSdoh^hm00:oh^hm003o`000?n<_OOoS;gg00coS;gg00?o0000oi33n?n@`oP0
1On@`oP5o`0000CoUl;e00?o0000oi[6m_nJa_H03_nJa_H00ol0003oWl[foio:mP04oio:mP?o0000
1onRb?<00ol0003oY/[cojK:l`0>ojK:l`?o00004?nZbO000ol0003o[LW_ojg9k`04ojg9k`Co0000
1_n/and00ol0003o[/O/ojk7k00?ojk7k0;o00004?n^aNX00ol0003o[lCYojo4j@03ojo4j@?o0000
0on^`nT00ol0003o[/?Yojk3j@03ojk3j@03o`000?n_`^So[l;X00go[l;X0_l0000>ooooo`03o`00
0?oooooooooo01oooooo0015ooooo`03o`000?oooooooooo01cooooo0ol0000Zooooo`03o`000?n;
]?7oRkCa00_oRkCa00?o0000oh^hm?n;^?@02_n;^?@00ol0003oS;ggohbmm`0<ohbmm`03o`000?n@
`oSoT<?h00Co00002_nG`_D00ol0003oV/Kfoi[6mP0>oi[6mP03o`000?nOb_KoWl[f00?o00002onR
b?<00ol0003oY/[cojK:l`0:ojK:l`?o00000_nWao400ol0003oZ/W`oj[9l00?oj[9l003o`000?n]
bNoo[LW_00?o00002on/and00ol0003o[/O/ojk7k00;ojk7k0?o000000?o[LG[o`000?n^aNX04?n^
aNX00ol0003o[lCYo`000002o`0000Ko[/?Y00?o0000ojk3jOn^`nT01?n^`nT00ol0003o[l;Xojo2
j009ojo2j0?o00004?ooool00ol0003oooooooooo`0Oooooo`00AOooool00ol0003oooooooooo`0I
ooooo`?o0000;_ooool00ol0003oRkCaoh^dl@0;oh^dl@03o`000?n;^?CoRkSd00[oRkSd00?o0000
ohbmmon<_OL02On<_OL5o`0000ooUl;e0_l0000=oi[6mPCo00003onRb?<00ol0003oY/[cojK:l`06
ojK:l`?o00001_nWao400ol0003oZ/W`oj[9l00>oj[9l0?o00003on/and00ol0003o[/O/ojk7k007
ojk7k0?o00001On]aN/00ol0003o[/GZojk5jP0>ojk5jP;o00002_n^`nT00ol0003o[/?Yojk3j@03
ojk3j@03o`000?n_`^So[l;X00Ko[l;X0ol0000Cooooo`03o`000?oooooooooo01oooooo0014oooo
o`?o00005oooool3o`0003;ooooo00?o0000oh^dlOn;]?402on;]?400ol0003oRkSdoh^hm00:oh^h
m004o`000?n<_OOoS;ggohbmm`Oo00001OnD__@00ol0003oUl;eoiO2m@0>oiO2m@03o`000?nJa_Ko
V/Kf00GoV/Kf1Ol00004oik5l`03o`000?nRb??oX/Sc00goX/Sc00?o0000ojK:lonVb_<00onVb_<2
o`0000[oYlOa00?o0000oj[9l?nZbO002_nZbO03o`0000;oZ/K^00?o0000ojc7kOn/and03_n/and0
0ol0003o[/O/ojk7k003ojk7k0?o00002On]aN/00ol0003o[/GZojk5jP0:ojk5jP?o000000?o[L?Z
o`000?n^`nT02_n^`nT00ol0003o[/?Yojk3j@03ojk3j@03o`000?n_`^So[l;X00?o[l;X0_l0000F
ooooo`03o`000?oooooooooo01oooooo0015ooooo`03o`000?oooooooooo01?ooooo0ol0000foooo
o`03o`000?n;]?7oRkCa00_oRkCa00?o0000oh^hm?n;^?@01?n;^?@9o`0000goU;kd00?o0000oiO2
mOnG`_D03_nG`_D00ol0003oV/Kfoi[6mP04o`0000[oW/Gc00?o0000oj;8lonRb?<03OnRb?<00ol0
003oY/[co`000002o`0000goYlOa00?o0000oj[9l?nZbO001_nZbO03o`0000KoZ/K^00?o0000ojc7
kOn/and03_n/and00ol0003o[/O/o`000002o`0000go[LG[00?o0000ojk5j_n^aNX01_n^aNX3o`00
00Go[L?Z00?o0000ojk3jOn^`nT02On^`nT00ol0003o[/?Yojk3j@03ojk3j@03o`000?n_`^So0000
00;o00006?ooool00ol0003oooooooooo`0Oooooo`00A?ooool00ol0003oooooooooo`0Booooo`;o
0000>_ooool00ol0003oRkCaoh^dl@08oh^dl@Wo00002?nB^_800ol0003oU;kdoiBnm00<oiBnm0;o
00003OnG`_D4o`0000ooW/Gc00?o0000oj;8lonRb?<02onRb?<4o`00013oYlOa00?o0000oj[9l?nZ
bO000onZbO02o`0000[oZ/K^00?o0000ojc7kOn/and03?n/and3o`00017o[LG[00?o0000ojk5j_n^
aNX00on^aNX2o`0000Wo[L?Z00?o0000ojk3jOn^`nT02?n^`nT00ol0003o[/?Yojk3j@02ojk3j@?o
00007?ooool00ol0003oooooooooo`0Nooooo`00A?ooool2o`00013ooooo0ol0000mooooo`04o`00
0?n;]?7oRkCaoh^dl@Ko00001OnB]_000ol0003oT[[boi:jlP0:oi:jlP03o`000?nD__CoU;kd00go
U;kd00?o0000oiO2mOnG`_D01OnG`_D5o`0000CoVl;c00?o0000oik5lonNaO<03OnNaO<00ol0003o
X/Scoj;8l`05oj;8l`Go00001?nTa_400ol0003oYlOaojO7l@0>ojO7l@03o`000?nZbO3o000000;o
00003OnZa^h00ol0003o[<O]ojc7k@08ojc7k@?o00000on[aN`00ol0003o[LG[ojg5j`0?ojg5j`03
o`000?n^aN[o000000;o00003?n]`nX00ol0003o[/?Yojk3j@08ojk3j@Co00007oooool00ol0003o
ooooooooo`0Nooooo`00A?ooool00ol0003oooooooooo`0<ooooo`?o0000@Oooool3o`0000coT[K`
00?o0000oi:jl_nB^_802_nB^_82o`0000koU;kd00?o0000oiO2mOnG`_D01?l0000:oi_2l`03o`00
0?nNaO?oW/Gc00goW/Gc00?o0000oj;8lonRb?<01?l0000:ojC6l@03o`000?nWao7oYlOa00coYlOa
1?l0000@oj[6kP03o`000?n/ango[<O]00Co[<O]0ol00007oj_5k003o`000?n]aN_o[LG[00go[LG[
0ol0000@ojg3jP03o`000?n^`nWo[/?Y00Co[/?Y1Ol0000Qooooo`03o`000?oooooooooo01kooooo
0014ooooo`03o`000?oooooooooo00Wooooo0ol00016ooooo`03o`000?nB]_3oT[K`00_oT[K`00?o
0000oi:jl_nB^_802onB^_800ol0003oU;kdoiBnm009oiBnm0Go00003onK`_<00ol0003oW/Gcoik5
l`0;oik5l`Co00003onTa_400ol0003oYlOaojO7l@08ojO7l@?o00001?nWaNl00ol0003oZ/K^oj[6
kP0>oj[6kP03o`000?n/ango[<O]00?o00002on[aN`00ol0003o[LG[ojg5j`09ojg5j`?o00000_n/
a>/00ol0003o[L?Zojg3jP0?ojg3jP03o`000?n^`nWo[/?Y00?o00001?ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo01kooooo0014ooooo`03o`000?oooooooooo00Kooooo0ol0001:
ooooo`03o`000?nB]_3oT[K`00_oT[K`00?o0000oi:jl_nB^_802onB^_801?l0003oU;kdoiBnm?nD
__@7o`0000GoVKkb00?o0000oi_2lonK`_<03OnK`_<00ol0003oW/Gcoik5l`05oik5l`Go00001?nQ
a?400ol0003oY<KaojC6l@0=ojC6l@03o`000?nWao7oYlOa00CoYlOa0ol00008ojO5k`03o`000?nZ
a^koZ/K^00coZ/K^1?l0000?oj_5k003o`000?n]aN_o[LG[00Co[LG[1?l00006ojc4j`03o`000?n]
`n[o[L?Z00ko[L?Z0ol00008ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_oo
ool004Cooooo0_l00004ooooo`?o0000C_ooool00ol0003oT[K`oi:fl00;oi:fl003o`000?nB^_;o
T[[b00SoT[[b1_l0000=oiVnlP03o`000?nK`_?oVl;c00goVl;c00?o0000oik5lonNaO<01?l0000:
oj74l@03o`000?nTa_7oY<Ka00goY<Ka00?o0000ojO7lOnWao400ol0000<ojO5k`03o`000?nZa^ko
Z/K^00SoZ/K^0ol00002ojW5k@03o`000?n[aNcoZlG/00ooZlG/00?o0000ojg5jon]aN/00ol0000;
ojc4j`03o`000?n]`n[o[L?Z00[o[L?Z0ol0000<ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool07_ooool004?ooooo00Co0000oooooooooooooooo0ol0001Booooo`03o`000?nB]_3o
T[K`00_oT[K`00Co0000oi:jl_nB^_;oT[[b1_l00005oiRkl003o`000?nI__;oVKkb00coVKkb00?o
0000oi_2lonK`_<02onK`_<4o`0000ooXLCa00?o0000ojC6lOnTa_402onTa_44o`00013oYlG_00?o
0000oj[6k_nZa^h01?nZa^h3o`0000KoZLG]00?o0000oj_5k?n[aN`03_n[aN`3o`0000oo[<C[00?o
0000ojg3j_n]`nX01_n]`nX3o`00013ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Nooooo`00>Oooool4o`000003oa0@4?oooooooooo00?ooooo1?l0001Fooooo`03o`000?nB]_3o
T[K`00SoT[K`1_l0000<oiRkl003o`000?nI__;oVKkb00coVKkb00?o0000oi_2lonK`_<01OnK`_<5
o`0000?oW/7a00?o0000oj74lOnQa?403_nQa?400ol0003oY<KaojC6l@05ojC6l@Go00001?nUa>l0
0ol0003oYlG_ojO5k`0>ojO5k`03o`000?nZa^koZ/K^00?o00002_nYaNd00ol0003oZlG/oj_5k00:
oj_5k0?o000000?oZlC/o`000?n/a>/04?n/a>/00ol0003o[L?Zojg3jP03ojg3jP;o00004oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01gooooo000kooooo`03o`000?oooooooooo
00Gooooo0_l0001Iooooo`04o`000?nB]_3oT[K`oi:fl0Ko00001OnG^>h00ol0003oV;_`oiRkl00;
oiRkl003o`000?nI__;oVKkb00coVKkb00?o0000oi_2lonK`_<01?l00009oik1l@03o`000?nQa?7o
XLCa00koXLCa00?o0000ojC6lOnTa_401?l0000:ojG4k`03o`000?nWaNooYlG_00coYlG_1?l0000>
ojW5k@03o`000?n[aNcoZlG/00KoZlG/0ol00005oj_4k003o`000?n/a>_o[<C[00oo[<C[00?o0000
ojg3j_l000000_l0000Fooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool0
03_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Gooooo`?o00003?nG^>h00ol0
003oV;_`oiRkl00;oiRkl003o`000?nI__;oVKkb00[oVKkb1?l0000>oik1l@03o`000?nQa?7oXLCa
00coXLCa1?l0000?ojG4k`03o`000?nWaNooYlG_00SoYlG_0ol00002ojS4kP03o`000?nYaNgoZLG]
00koZLG]00?o0000oj_5k?n[aN`00on[aN`2o`0000WoZlC/00?o0000ojc4jon/a>/03On/a>/3o`00
01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Mooooo`00>oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo05Oooooo00?o0000oiNhk_nG^>h03?nG^>h00ol0003o
V;_`oiRkl00;oiRkl003o`000?nI__;oVKkb00GoVKkb1?l00004oifnl003o`000?nN`O7oW/7a00co
W/7a00?o0000oj74lOnQa?402?nQa?43o`0000?oXl;_00?o0000ojG4konUa>l03_nUa>l00ol0003o
YlG_ojO5k`04ojO5k`?o00001_nXa>h00ol0003oZLG]ojW5k@0>ojW5k@03o`000?n[aNco000000;o
00003?n[a>`00ol0003o[<C[ojc4j`09ojc4j`?o00007Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01gooooo000kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
Eoooool00ol0003oUkS^oiNhkP0<oiNhkP03o`000?nH^o3oV;_`00_oV;_`00?o0000oiVnl_nI__80
1?l00009oifnl003o`000?nN`O7oW/7a00coW/7a00?o0000oj74lOnQa?401?nQa?43o`0000OoXl;_
00?o0000ojG4konUa>l03_nUa>l00ol0003oYlG_ojO5k`03o`0000[oZ<C^00?o0000ojW5kOnYaNd0
3?nYaNd3o`00013oZlC/00?o0000ojc4jon/a>/01?n/a>/4o`00027ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Mooooo`00>oooool00ol0003oooooooooo`0:ooooo`;o0000F?oo
ool00ol0003oUkS^oiNhkP0<oiNhkP03o`000?nH^o3oV;_`00SoV;_`1Ol0000>oifnl003o`000?nN
`O7oW/7a00coW/7a00?o0000oj74lOnQa?400ol0000;oj?2k`03o`000?nUa>ooYLC_00coYLC_1?l0
000>ojS4kP03o`000?nYaNgoZLG]00SoZLG]0ol00003ojW3k003o`000?n[a>coZlC/00koZlC/00?o
0000ojc4jon/a>/00ol0000Vooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool07Ooo
ool003_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Fooooo`03o`000?nG^>ko
UkS^00coUkS^00Co0000oiRkl?nH^o3oV;_`1_l00004oiblk`03o`000?nM__3oWKk`00goWKk`00?o
0000oik1lOnN`O402_nN`O44o`0000ooXl;_00?o0000ojG4konUa>l02?nUa>l3o`0000?oY/?^00?o
0000ojS4k_nXa>h03OnXa>h00ol0003oZLG]ojW5k@04ojW5k@?o00001onY`n`00ol0003oZlC/oj_4
k00<oj_4k0Co0000:_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01gooooo000i
ooooo`03oeEEEOmVIVKo000000oooooo00?o0000ooooooooool0E_ooool00ol0003oUkS^oiNhkP0:
oiNhkPGo00002onL_>l00ol0003oWKk`oifnl00=oifnl003o`000?nN`O7oW/7a00GoW/7a1?l00004
oj70k`03o`000?nS`^ooXl;_00goXl;_00?o0000ojG4konUa>l01?nUa>l3o`0000OoY/?^00?o0000
ojS4k_nXa>h03OnXa>h00ol0003oZLG]ojW5k@03o`0000_oZL?/00?o0000oj_4k?n[a>`02?n[a>`3
o`0002kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Looooo`00C?ooool00ol0
003oooooooooo`1Fooooo`03o`000?nG^>koUkS^00GoUkS^1?l00003oi^ik@03o`000?nL_>ooW;c_
00_oW;c_00?o0000oifnl?nM__003OnM__000ol0003oW/7aoik1l@04o`0000WoXL3_00?o0000oj?2
konS`^l03OnS`^l00ol0003oYLC_ojG4k`03o`0000_oY/?^00?o0000ojS4k_nXa>h02onXa>h4o`00
00ooZL?/00?o0000oj_4k?n[a>`01?n[a>`3o`0003;ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Looooo`00COooool2o`0005Oooooo00?o0000oiNhk_nG^>h01?l00008oi^ik@03
o`000?nL_>ooW;c_00_oW;c_00?o0000oifnl?nM__002onM__04o`0000koXL3_00?o0000oj?2konS
`^l02onS`^l4o`0000ooY/?^00?o0000ojS4k_nXa>h01OnXa>h5o`0000?oZ<?]00?o0000ojW3k?nY
`n`03_nY`n`00ol0003oZlC/oj_4k003o`0003Kooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Looooo`00Coooool00ol0003oooooooooo`1Eooooo`;o00003OnK^Nd00ol0003oW;c_
oiblk`0;oiblk`03o`000?nM__3oWKk`00GoWKk`1Ol00004oinnkP03o`000?nQ`>ooXL3_00coXL3_
00?o0000oj?2konS`^l01OnS`^l5o`0000?oY<7^00?o0000ojK3k_nV`nh03_nV`nh00ol0003oZ<C^
ojS4kP04o`0000WoZ<?]00?o0000ojW3k?nY`n`03?nY`n`4o`0003[ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Looooo`00D?ooool00ol0003oooooooooo`1Eooooo`03o`000?nK
^NgoVkW]00coVkW]00?o0000oiblkonL_>l02onL_>l00ol0003oWKk`oifnl004o`0000[oWkk^00?o
0000oj70konQ`>l03?nQ`>l00ol0003oXl;_oj?2k`04o`0000WoY<7^00?o0000ojK3k_nV`nh03?nV
`nh4o`0000koZ<?]00?o0000ojW3k?nY`n`02?nY`n`3o`0003kooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0Looooo`00DOooool00ol0003oooooooooo`1Eooooo`03o`000?nK^Ngo
VkW]00coVkW]00?o0000oiblkonL_>l02?nL_>l5o`0000ooWkk^00?o0000oj70konQ`>l02_nQ`>l4
o`0000koY<7^00?o0000ojK3k_nV`nh02?nV`nh3o`0000?oYl;]00?o0000ojS3kOnX`nd03OnX`nd0
0ol0003oZL?/ojW3k004ojW3k0?o0000@_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01cooooo001Booooo`03o`000?oooooooooo05Gooooo00?o0000oi^ikOnK^Nd03?nK^Nd01?l0
003oW;c_oiblkonL_>l6o`0000GoWkc]00?o0000oinnk_nO_^h03OnO_^h00ol0003oXL3_oj70k`05
oj70k`Co00001?nS`>h00ol0003oY<7^ojC1kP0<ojC1kP03o`000?nV`nkoY/?^00CoY/?^0ol00007
ojO2k@03o`000?nX`ngoZ<?]00goZ<?]00?o0000ojW3k?nY`n`00ol00016ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool07?ooool005?ooooo0_l0001Fooooo`03o`000?nK^NgoVkW]
00[oVkW]1Ol0000<oinlk@03o`000?nO_^koWkk^00goWkk^00?o0000oj70konQ`>l01?l00009oj?0
kP03o`000?nT`NkoY<7^00coY<7^00?o0000ojK3k_nV`nh00ol0000;ojO2k@03o`000?nX`ngoZ<?]
00coZ<?]0ol00019ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06oooool005Go
oooo00?o0000ooooooooool0E?ooool00ol0003oVkW]oi^ik@05oi^ik@Co00000onN^^`00ol0003o
Wkc]oinlk@0<oinlk@03o`000?nO_^koWkk^00_oWkk^1?l0000>oj?0kP03o`000?nT`NkoY<7^00[o
Y<7^1?l0000?ojO2k@03o`000?nX`ngoZ<?]00SoZ<?]0ol0001=ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool06oooool005Kooooo00?o0000ooooooooool0E?ooool00ol0003oVkW]
oi^ik@04o`0000SoW[[/00?o0000oinlkOnO_>d03?nO_>d00ol0003oWkk^oinnkP05oinnkPGo0000
0onR_^d00ol0003oXl3^oj?0kP0=oj?0kP03o`000?nT`NkoY<7^00GoY<7^1?l00004ojG1k@03o`00
0?nW`^goYl;]00goYl;]00?o0000ojS3kOnX`nd01?nX`nd3o`00057ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0Kooooo`00Eoooool00ol0003oooooooooo`1Dooooo`;o00003OnN
^^`00ol0003oWkc]oinlk@0<oinlk@03o`000?nO_^koWkk^00Co00002OnR_^d00ol0003oXl3^oj?0
kP0=oj?0kP03o`000?nT`NkoY<7^00Co00002OnU`Nd00ol0003oYl;]ojO2k@0=ojO2k@03o`000?nX
`ngoZ<?]00?o0000EOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01_ooooo001H
ooooo`;o0000E_ooool00ol0003oW[[/oijjk00;oijjk003o`000?nO_>goWkc]00[oWkc]1?l0000>
oj:nk@03o`000?nS`>koXl3^00coXl3^0ol0000>ojG1k@03o`000?nW`^goYl;]00_oYl;]1?l0001H
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06oooool005[ooooo00?o0000oooo
ooooool0E?ooool00ol0003oW[[/oijjk00;oijjk003o`000?nO_>goWkc]00GoWkc]1?l00003oj6m
k003o`000?nR_^goX[k]00goX[k]00?o0000oj?0k_nS`>h02?nS`>h3o`0000;oY;o]00?o0000ojG1
kOnU`Nd03OnU`Nd00ol0003oYl;]ojO2k@05ojO2k@Go0000GOooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01_ooooo001Kooooo`03o`000?oooooooooo05Cooooo00?o0000oijjk?nN
^^`02onN^^`00ol0003oWkc]oinlk@04o`0000SoXKg/00?o0000oj:nkOnR_^d03OnR_^d00ol0003o
Xl3^oj?0kP04oj?0kP?o00001_nT_nd00ol0003oYL7]ojG1k@0=ojG1k@03o`000?nW`^goYl;]00Co
0000Hoooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01_ooooo001Looooo`03o`00
0?oooooooooo05Cooooo00?o0000oijjk?nN^^`02OnN^^`4o`0000goXKg/00?o0000oj:nkOnR_^d0
3OnR_^d00ol0003oXl3^oj?0kP03o`0000[oY;o]00?o0000ojG1kOnU`Nd03?nU`Nd3o`0006Sooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Kooooo`00GOooool2o`0005Gooooo00?o
0000oijjk?nN^^`01?nN^^`4o`0000CoXK_[00?o0000oj6mk?nQ_N`02onQ_N`00ol0003oX[k]oj:n
k@0;oj:nk@Co00003_nT_nd00ol0003oYL7]ojG1k@08ojG1k@?o0000Joooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo01[ooooo001Oooooo`03o`000?oooooooooo05?ooooo00?o0000
oijjk?nN^^`00ol00009oj6kj`03o`000?nQ_NcoXKg/00_oXKg/00?o0000oj:nkOnR_^d01OnR_^d5
o`0000?oXkk/00?o0000ojBokOnT_nd03OnT_nd00ol0003oYL7]ojG1k@04ojG1k@?o0000Koooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo001Pooooo`03o`000?oooooooooo
05?ooooo0_l0000=oj6kj`;o00003?nQ_N`00ol0003oX[k]oj:nk@04o`0000WoXkk/00?o0000ojBo
kOnT_nd03OnT_nd00ol0003oYL7]ojG1k@03o`0007?ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Jooooo`00HOooool00ol0003oooooooooo`1Dooooo`03o`000?nQ^n_oXK_[00co
XK_[00?o0000oj6mk?nQ_N`01onQ_N`5o`0000koXkk/00?o0000ojBokOnT_nd02onT_nd4o`0007Ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Jooooo`00H_ooool2o`0005Gooooo
00?o0000oj6kjonQ^n/03?nQ^n/01?l0003oXKg/oj6mk?nQ_N`5o`0000GoXkg/00?o0000oj>nk?nS
_^`03?nS_^`00ol0003oY;o]ojBok@05ojBok@Go0000Noooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo01[ooooo001Tooooo`03o`000?oooooooooo05?ooooo00?o0000oj6kjonQ^n/0
2_nQ^n/5o`0000_oXkg/00?o0000oj>nk?nS_^`03?nS_^`00ol0003oY;o]ojBok@04o`00087ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Jooooo`00IOooool00ol0003ooooooooo
o`1Cooooo`03o`000?nQ^n_oXK_[00GoXK_[1?l00002oj>kj`03o`000?nS_NcoXkg/00coXkg/00?o
0000oj>nk?nS_^`02_nS_^`4o`0008Kooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Jooooo`00I_ooool00ol0003oooooooooo`1Cooooo`03o`000?nQ^n_oXK_[00Co00001onS^n/0
0ol0003oXkg/oj>mk00<oj>mk003o`000?nS_^coXkk/00GoXkk/1?l0002:ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool06Oooool006Oooooo00?o0000ooooooooool0Doooool2o`00
00coXk_[00?o0000oj>mk?nS_N`03?nS_N`00ol0003oXkk/oj>nk004o`0008oooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Iooooo`00J?ooool2o`0005Cooooo00?o0000oj>kjonS
^n/02onS^n/00ol0003oXkg/oj>mk00:oj>mk0Co0000U?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01Wooooo001Zooooo`03o`000?oooooooooo05;ooooo00?o0000oj>kjonS^n/0
2onS^n/00ol0003oXkg/oj>mk005oj>mk0Co0000V?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo01Wooooo001[ooooo`03o`000?oooooooooo05;ooooo00?o0000oj>kjonS^n/02onS
^n/00ol0003oXkg/oj>mk004o`0009gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Iooooo`00K?ooool00ol0003oooooooooo`1Booooo`03o`000?nS^n_oXk_[00WoXk_[1?l0002R
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06Oooool006gooooo0_l0001Coooo
o`03o`000?nS^n_oXk_[00CoXk_[1?l0002Wooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool06Oooool006oooooo00?o0000ooooooooool0DOooool00ol0003oXk_[oj>kj`03o`000:_o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`00L?ooool00ol0003ooooo
ooooo`1Aooooo`;o0000[oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Sooooo
001aooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0[oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01Sooooo001booooo`;o0000D?ooool00ol0003oooooooooo`2`
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06?ooool007Cooooo00?o0000oooo
ooooool0COooool00ol0003oooooooooo`2`ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool06?ooool007Gooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`2aooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool06?ooool007Kooooo00?o0000ooooooooool0
Boooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
6?ooool007Oooooo0_l0001;ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Gooooo`00NOooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo0;?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Gooooo`00N_ooool00ol0
003oooooooooo`17ooooo`03o`000?oooooooooo0;Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Gooooo`00Noooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo0;Go
oooo00Go0000ooooooooooooooooo`00000Iooooo`00O?ooool00ol0003oooooooooo`14ooooo`03
o`000?oooooooooo0;Kooooo00Go0000ooooooooooooooooo`00000Iooooo`00OOooool2o`0004Co
oooo00?o0000ooooooooool0]oooool01?l0003oooooooooool0000Iooooo`00Ooooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo0;Sooooo00?o0000ooooool000006Oooool0083ooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`2hooooo`04o`000?ooooooooooo`0001So
oooo0021ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0^Oooool00ol0003ooooo
o`00000Hooooo`00P_ooool2o`0003oooooo00?o0000ooooooooool0^_ooool2o`0001Sooooo0024
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0^Oooool3o`0001Sooooo0025oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0]Oooool4o`0001_ooooo0026ooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool0/Oooool4o`0001oooooo0027ooooo`;o0000
>_ooool00ol0003oooooooooo`2^ooooo`?o00008oooool008Wooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`2Zooooo`Co00009_ooool008[ooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`2Vooooo`Co0000:_ooool008_ooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`2Rooooo`Co0000;_ooool008cooooo0_l0000eooooo`03o`000?oooooooooo09ko
oooo1?l0000booooo`00S_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo09[ooooo
1?l0000fooooo`00Soooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo09Oooooo0ol0
000jooooo`00T?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo09?ooooo1?l0000m
ooooo`00TOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo08oooooo1?l00011oooo
o`00T_ooool2o`0002oooooo00?o0000ooooooooool0Roooool4o`0004Gooooo002Dooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool0Qoooool4o`0004Wooooo002Eooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0Poooool4o`0004gooooo002Fooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool0Ooooool4o`00057ooooo002Gooooo`;o0000:_ooool00ol0
003oooooooooo`1looooo`?o0000EOooool009Wooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`1iooooo`Co0000F?ooool009[ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1eooooo`Co0000G?ooool009_ooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`1aooooo`Co0000H?ooool009cooooo0_l0000Tooooo`03o`000?oooooooooo06gooooo1?l0001T
ooooo`00W_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo06Wooooo1?l0001Xoooo
o`00Woooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06Kooooo0ol0001/ooooo`00
X?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo06;ooooo1?l0001_ooooo`00XOoo
ool2o`0001oooooo00?o0000ooooooooool0G_ooool4o`0007?ooooo002Sooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool0F_ooool4o`0007Oooooo002Tooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0E_ooool4o`0007_ooooo002Uooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0D_ooool4o`0007oooooo002Vooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool0Coooool3o`0008?ooooo002Wooooo`;o00006Oooool00ol0003ooooooooo
o`1;ooooo`Co0000Q_ooool00:Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`17
ooooo`Co0000R_ooool00:[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`13oooo
o`Co0000S_ooool00:_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0oooooo`Co
0000T_ooool00:cooooo0_l0000Dooooo`03o`000?oooooooooo03_ooooo1?l0002Fooooo`00[_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Sooooo0ol0002Jooooo`00[oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Cooooo1?l0002Mooooo`00/?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo033ooooo1?l0002Qooooo`00/Oooool2o`0000oo
oooo00?o0000ooooooooool0;?ooool4o`000:Gooooo002cooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0:?ooool4o`000:Wooooo002dooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool09?ooool4o`000:gooooo002eooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool08Oooool4o`000;7ooooo002fooooo`;o00002Oooool00ol0003oooooooooo`0Noooo
o`?o0000]Oooool00;Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Jooooo`Co
0000^?ooool00;Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`Co0000
_?ooool00;[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`Co0000`?oo
ool00;_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000a?ooool0
0;cooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo1?l00038ooooo`00__ooool01?l0003o
ooooooooool00009ooooo`?o0000c?ooool00;oooooo00?o0000ooooool000001Oooool4o`000<oo
oooo0030ooooo`;o000000?oooooo`000?l000000_l0003Cooooo`00`Oooool2o`000=Oooooo003o
oooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003o
oooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003o
oooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003o
oooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003o
oooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003o
oooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 409.75}, {332.188, 0}} -> {-0.2017, -0.068318, \
0.0037428, 0.0037428}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Von Neumann  and Mixed Boundary Conditions", "Section",
  CellTags->{"i:24", "c:20"}],

Cell[TextData[{
  "Grid methods can also be employed in problems involving von Neumann  or \
mixed boundary conditions. Take, for example,  a heat flow problem on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < L\)]],
  "  with  a boundary condition that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Kappa] \[PartialD]T/\[PartialD]x\)\( | \_\(x = 
                0\)\)\) = \(-\[CapitalGamma]\)\)]],
  ".  This von Neumann  condition can be met by finite-differencing the \
derivative at the boundary  ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(T\_1\%n - T\_0\%n\), 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]], 
          "=", \(\(-\[CapitalGamma]\)/\[Kappa]\)}], TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(6.2.19)"],

Cell["\<\
from which we can obtain the boundary-value for the temperature in \
terms of the interior points:\
\>", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\_0\%n\), " ", "=", 
          RowBox[{\(T\_1\%n\), "+", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], 
              " ", \(\(\[CapitalGamma]/\[Kappa]\)\(\ \)\)}]}]}], 
        TraditionalForm]]],
  ". "
}], "NE2",
  CellTags->"(6.2.20)"],

Cell[TextData[{
  " \t On the other hand, the left-hand side of Eq. ",
  ButtonBox["(6.2.19)",
    ButtonData:>"(6.2.19)",
    ButtonStyle->"Hyperlink"],
  " is a forward-difference form for the derivative at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ", and is only first-order accurate in ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ". Thus, the error in our numerical method will scale only as the first \
power of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ". This is unfortunate, because the centered-difference equations used for \
the interior points are all of second-order accuracy in ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ". It would be better to use a more accurate approximation for ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\^\[Prime]\)(x = 0, t)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\t One simple improvement is to place the boundary at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " ",
  StyleBox["halfway",
    FontSlant->"Italic"],
  " ",
  StyleBox["between",
    FontSlant->"Italic"],
  " the grid points ",
  Cell[BoxData[
      \(TraditionalForm\`0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`1\)]],
  ". Then we can use a ",
  StyleBox["centered-difference",
    FontSlant->"Italic"],
  " form for the von Neumann boundary condition, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\(T\^\[Prime]\)(x = 0, t)\), "\[Rule]", " ", 
            RowBox[{\([T\_1\%n - T\_0\%n]\), "/", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}]}], 
          "=", \(\(-\[CapitalGamma]\)/\[Kappa]\)}], TraditionalForm]]],
  ". The equation is the same as before, but now it is second-order rather \
than first-order accurate. The only change that we need make is to the \
location of the grid points. Now,  "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(x\_j\), "=", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], "(", \(j - 1/2\), ")"}]}], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0, 1, 2,  ... , M\)]],
  "."
}], "NE2",
  CellTags->"(6.2.21)"],

Cell[TextData[{
  "Considering now the  the boundary condition at ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  ", if this condition is also von Neumann , then ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  " must fall between the ",
  Cell[BoxData[
      \(TraditionalForm\`M - 1\)]],
  "st and ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  "th points in order to employ the same centered-difference scheme there. \
Therefore,  Eq. ",
  ButtonBox["(6.2.21)",
    ButtonData:>"(6.2.21)",
    ButtonStyle->"Hyperlink"],
  " implies that ",
  Cell[BoxData[
      FormBox[
        RowBox[{"L", "=", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], "(", \(M - 1/2\  - \ 1/2\), 
            ")"}]}], TraditionalForm]]],
  " and so ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "=", \(L/\((M - 1)\)\)}], 
        TraditionalForm]]],
  ". On the other hand, if the boundary condition at ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  " is Dirichlet, then we need to have the ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  "th grid point fall at ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  ", and this implies that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "=", \(L/\((M - 1/2)\)\)}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "\tFor example, consider the heat equation with insulating boundary \
conditions at both ends, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]T/\[PartialD]x\)\( | \_\(x = 
                0\)\)\) = \(\(\(\[PartialD]T/\[PartialD]x\)\( | \_\(x = 
                  L\)\)\) = 0\)\)]],
  " . For the grid we use Eq. ",
  ButtonBox["(6.2.21)",
    ButtonData:>"(6.2.21)",
    ButtonStyle->"Hyperlink"],
  " with ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "=", \(L/\((M - 1)\)\)}], 
        TraditionalForm]]],
  ". For this example, we take ",
  Cell[BoxData[
      \(TraditionalForm\`M = 10\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(L = 1\)\(,\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Chi] = 1/4\)]],
  Cell[BoxData[
      FormBox[
        RowBox[{",", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], "=", "0.05"}]}], 
        TraditionalForm]]],
  " and set source terms equal to zero:"
}], "Text"],

Cell[BoxData[{
    \(\(M = 10;\)\), "\n", 
    \(\(L = 1. ;\)\), "\n", 
    \(\(\[CapitalDelta]x = L/\((M - 1)\);\)\), "\n", 
    \(\(x[j_]\  = \ \[CapitalDelta]x \((j - 1/2)\);\)\), "\n", 
    \(\(\[Chi]\  = \ 1/4;\)\), "\n", 
    \(\(\[CapitalDelta]t\  = \ 0.05;\)\), "\n", 
    \(\(S[j_, n_]\  = \ 0;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.67"],

Cell[TextData[{
  "According to  Eq. ",
  ButtonBox["(6.2.20)",
    ButtonData:>"(6.2.20)",
    ButtonStyle->"Hyperlink"],
  " the boundary conditions are satisfied by  the equations"
}], "Text"],

Cell[BoxData[{
    \(\(T[0, n_]\  = \ T[1, n];\)\), "\n", 
    \(\(T[M, n_]\  = \ T[M - 1, n];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.68"],

Cell["\<\
For the initial condition, we again choose a single Fourier mode as \
a test, but this time we choose a cosine mode so as to satisfy the boundary \
conditions:\
\>", "Text"],

Cell[BoxData[
    \(\(T0[x_]\  = \ Cos[\ Pi\ x\ /L];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.69"],

Cell[TextData[{
  "In theory this mode should decay away exponentially at the rate ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\ \((\[Pi]/L)\)\^2\)]],
  ". We can now run any of our previously discussed methods to solve for the \
temperature evolution. We use the Crank-Nicolson module created in the \
previous section, and plot the result in Cell ",
  ButtonBox["6.71",
    ButtonData:>"Cell 6.71",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol[0]\  = \ 
      Table[T[j, 0] \[Rule] \ T0[x[j]], {j, 1, M - 1}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.70"],

Cell[BoxData[
    \({T[1, 0] \[Rule] 0.984807753012208`, 
      T[2, 0] \[Rule] 0.8660254037844387`, 
      T[3, 0] \[Rule] 0.6427876096865394`, 
      T[4, 0] \[Rule] 0.3420201433256688`, 
      T[5, 0] \[Rule] 6.123233995736766`*^-17, 
      T[6, 0] \[Rule] \(-0.3420201433256685`\), 
      T[7, 0] \[Rule] \(-0.6427876096865394`\), 
      T[8, 0] \[Rule] \(-0.8660254037844384`\), 
      T[9, 0] \[Rule] \(-0.984807753012208`\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(CrankNicolson = \ 
        Table[ListPlot[Table[{x[j], \ T[j, n]}, {j, 0, M}] /. sol[n], 
            PlotJoined \[Rule] True, PlotRange \[Rule] {{0, L}, {\(-1\), 1}}, 
            AxesLabel \[Rule] {"\<x\>", "\<\>"}, 
            PlotLabel \[Rule] "\<T[x,t],t=\>" <> 
                ToString[\[CapitalDelta]t\ n], 
            DisplayFunction \[Rule] Identity], {n, 0, 40, 5}];\)\), "\n", 
    \(\(exact\  = 
        Table[Plot[\(\[ExponentialE]\^\(\(-\[Pi]\^\(\(2\)\(\ \)\)\) \[Chi]\ t/
                      L\^2\)\) Cos[Pi\ x/L], {x, 0, L}, 
            DisplayFunction \[Rule] Identity, 
            PlotStyle \[Rule] {RGBColor[1, 0, 0], 
                Dashing[{0.05, 0.05}]}], {t, 0, 40\ \[CapitalDelta]t, 
            5\ \[CapitalDelta]t}];\)\ \), "\n", 
    \(\(Table[
        Show[CrankNicolson[\([n]\)], exact[\([n]\)], 
          DisplayFunction \[Rule] $DisplayFunction], {n, 1, 
          Length[exact]}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.71"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -32 0 ]
[.5 .63053 32 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .61334 m
.05556 .61334 L
.16667 .57663 L
.27778 .50765 L
.38889 .41471 L
.5 .30902 L
.61111 .20333 L
.72222 .11038 L
.83333 .0414 L
.94444 .00469 L
s
.94444 .00469 m
1 .00469 L
s
1 0 0 r
[ .05 .05 ] 0 setdash
0 .61803 m
.00123 .61803 L
.00236 .61803 L
.00365 .61801 L
.00488 .618 L
.00706 .61796 L
.00942 .6179 L
.01203 .61781 L
.01479 .6177 L
.01975 .61744 L
.02486 .61709 L
.02966 .61669 L
.04057 .61553 L
.0517 .61397 L
.06188 .61221 L
.08481 .60713 L
.10474 .60145 L
.1265 .59395 L
.16918 .5754 L
.21027 .55303 L
.25393 .52481 L
.296 .49378 L
.33648 .46088 L
.37953 .4232 L
.42099 .38493 L
.46086 .34692 L
.50331 .30581 L
.54416 .26628 L
.58759 .22505 L
.62943 .1868 L
.66967 .15199 L
.7125 .11771 L
.75372 .08797 L
.79336 .06286 L
.83558 .04032 L
.8762 .02308 L
.89683 .01609 L
.91939 .00985 L
.94095 .0053 L
.95057 .00372 L
.961 .00232 L
.96647 .00171 L
.97151 .00124 L
.97624 .00086 L
.98143 .00053 L
.98609 .00029 L
.99045 .00014 L
.99286 8e-05 L
.99505 4e-05 L
.99627 2e-05 L
Mistroke
.99759 1e-05 L
.99884 0 L
1 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4
o`000003oa0@4?oooooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`005_ooool6o`0000Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo9_ooool3ool001Co
oooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo4oooool5ool0017o00005?oo
ool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooo`kooooo1Ooo0003
o`0002Oooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0ooooool;oooo
o`?oo`000_ooool3o`0002[ooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooo`Wo
oooo0ooo0002ooooo`?o0000;Oooool002Wooooo00?o0000ooooooooool0ooooool:ooooo`?o0000
<?ooool002Wooooo00?o0000ooooooooool0ooooool7ooooo`?o0000<oooool002Wooooo00?o0000
ooooooooool0ooooool4ooooo`?o0000=_ooool002Wooooo0_l0003oooooo`;ooooo0ol0000ioooo
o`00:Oooool00ol0003oooooooooo`3mooooo`?o0000??ooool002Wooooo00?o0000ooooooooool0
n?ooool3ool000;o0000?oooool002Wooooo00?o0000ooooooooool0mOooool3ool000;o0000@_oo
ool002Wooooo00?o0000ooooooooool0loooool2ool000;o0000AOooool002Wooooo0_l0003boooo
o`;oo`0000?o0000ooooooooool0A_ooool002Wooooo00?o0000ooooooooool0koooool2ool000;o
0000BOooool002Wooooo00?o0000ooooooooool0kOooool2ool000;o0000Boooool002Wooooo00?o
0000ooooooooool0k?ooool00ooo003oooooo`00001=ooooo`00:Oooool00ol0003oooooooooo`3/
ooooo`;o0000C_ooool002Wooooo0_l0003[ooooo`;o0000D?ooool002Wooooo00?o0000oooooooo
ool0jOooool00ol0003oooooooooo`1@ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0>Oooooo0_l0001Cooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3Uooooo`;o0000EOooool000Co00000_ooool01Ol@413ooooooooooooooooo410@
00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000i?ooool00ol0
003oooooooooo`1Eooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0>;ooooo0_l0001Hoooo
o`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0goooool2ool00003o`000?oooooo
oooo05Sooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0g?ooool3ool00003o`000?oooooo
oooo05[ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooo
oooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3Kooooo`04ool00?oo
oooo0000o`0005gooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo
1?l00006ooooo`;o0000foooool00ooo003o0000o`00001Oooooo`00:Oooool00ol0003ooooooooo
o`3Iooooo`03ool00?l0003ooooo063ooooo000Yooooo`03o`000?oooooooooo0=Oooooo0_oo0000
0ol0003oooooooooo`1Pooooo`00:Oooool00ol0003oooooooooo`3Fooooo`03ool00?l0003ooooo
06?ooooo000Yooooo`;o0000e_ooool00ooo003oooooooooo`1Tooooo`00:Oooool00ol0003ooooo
ooooo`3Cooooo`03o`000?oo003ooooo06Kooooo000Yooooo`03o`000?oooooooooo0=;ooooo00?o
0000ool00?ooool0Ioooool002Wooooo00?o0000ooooooooool0dOooool00ol0003oooooooooo`1X
ooooo`00:Oooool00ol0003oooooooooo`3@ooooo`03o`000?oooooooooo06Wooooo000Yooooo`;o
0000d?ooool00ol0003oooooooooo`1Zooooo`00:Oooool00ol0003oooooooooo`3>ooooo`03o`00
0?oooooooooo06_ooooo000Yooooo`03o`000?oooooooooo0<cooooo0_l0001^ooooo`00:Oooool0
0ol0003oooooooooo`3;ooooo`03o`000?oooooooooo06kooooo000Yooooo`03o`000?oooooooooo
0<[ooooo00?o0000ooooooooool0Koooool002Wooooo0_l0003:ooooo`03o`000?oooooooooo073o
oooo000Yooooo`03o`000?oooooooooo0<Oooooo0_oo001cooooo`003_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`35ooooo`;oo`0000?o0000ooooooooool0L_ooool000kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0<?o
oooo0_oo00000ol0003oooooooooo`1dooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol00032ooooo`03ool00?oooooo000007Oo
oooo000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0<7ooooo00?oo`00ooooool00000N?ooool000kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`30oooo
o`03ool00?oooooo000007Wooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;oooooo00?oo`00ooooool00000N_ooool000ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0__ooool00ooo003o0000o`00001kooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l00006ooooo`;o0000__ooool00ooo003o0000ooooo`1looooo`00:Oooool00ol0003o
ooooooooo`2looooo`03ool00?l0003ooooo07gooooo000Yooooo`03o`000?oooooooooo0;cooooo
00?o0000ooooooooool0OOooool002Wooooo00?o0000ooooooooool0^oooool00ol0003ooooooooo
o`1nooooo`00:Oooool2o`000;[ooooo0_l00021ooooo`00:Oooool00ol0003oooooooooo`2hoooo
o`03o`000?oooooooooo087ooooo000Yooooo`03o`000?oooooooooo0;Oooooo00?o0000oooooooo
ool0P_ooool002Wooooo00?o0000ooooooooool0]_ooool00ol0003oooooooooo`23ooooo`00:Ooo
ool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo08Cooooo000Yooooo`;o0000]Oooool0
0ol0003oooooooooo`25ooooo`00:Oooool00ol0003oooooooooo`2booooo`;o0000R?ooool002Wo
oooo00?o0000ooooooooool0/Oooool00ooo003oooooooooo`28ooooo`00:Oooool00ol0003ooooo
ooooo`2`ooooo`03ool00?oooooooooo08Wooooo000Yooooo`03o`000?oooooooooo0:oooooo00?o
o`00ooooooooool0R_ooool002Wooooo0_l0002_ooooo`03ool00?oooooooooo08_ooooo000Yoooo
o`03o`000?oooooooooo0:gooooo00?oo`00ooooooooool0S?ooool000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo0:_ooooo0_oo002?ooooo`001_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0:[ooooo00?oo`00o`000?ooool0Soooool000Co00000_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`03ooooo`?o0000ZOooool00ooo003o0000ooooo`2@ooooo`001_ooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0:Sooooo00?oo`00o`000?ooool0TOooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0:Oooooo00?oo`00o`000?ooool0T_ooool000Kooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2Vooooo`03ool00?l0003ooooo09?ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2Vooooo`03o`000?oooooooooo09?ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000Y_ooool00ol0
003oooooooooo`2Dooooo`00:Oooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo09Go
oooo000Yooooo`03o`000?oooooooooo0:;ooooo0_l0002Hooooo`00:Oooool00ol0003ooooooooo
o`2Qooooo`03o`000?oooooooooo09Sooooo000Yooooo`;o0000XOooool00ol0003oooooooooo`2I
ooooo`00:Oooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo09[ooooo000Yooooo`03
o`000?oooooooooo02gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00
02Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooo
oooo01kooooo00?o0000ooooooooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`09oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0<?ooool4o`000003oa0@4?oooooooooo
013ooooo000Yooooo`03o`000?oooooooooo02gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A402Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03;ooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000ooooooooool0;Oooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0:?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol0000Nooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000009oooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`00000booooo`03o`000?oooooooooo01;ooooo000Yoooo
o`;o0000;_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h09oooool0
1Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00007_ooool2ool000Oooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B409oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0booooo`03o`000?oo
oooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo02Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgM
gOmEEEGoooooo`0001gooooo00?oo`00ooooooooool01oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go0000oeEEEOl0003o410@olc<c00Wooooo`05o`000?ooooooooooooooool000002ooo
ool01Oo<c<co0000o`000?l0003oc<c<03;ooooo00?o0000ooooooooool04_ooool002Wooooo00?o
0000ooooooooool0;Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
9Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000007?ooool00ooo003o
ooooooooo`08ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Yoooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03;ooooo00?o
0000ooooooooool04_ooool002Wooooo00?o0000ooooooooool0;Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Wooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00oo^k^koA4A4o`00000Kooooo`03ool00?oooooooooo00Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000<_ooool00ol0003oooooooooo`0Booooo`00:Oooool0
0ol0003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`00
0?lQ8B7oc<c<02Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo01Wo
oooo00?oo`00ooooooooool02_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4
A?l0003o410@9oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@0`ooooo`03oeEEEOmVIVKo000001Cooooo000Yooooo`;o0000Uoooool00ooo003ooooooooo
o`2Sooooo`00:Oooool00ol0003oooooooooo`2Eooooo`03ool00?oooooooooo0:Cooooo000Yoooo
o`03o`000?oooooooooo09Cooooo00?oo`00ooooooooool0Voooool2o`0000;ooooo0_l00004oooo
o`00:Oooool00ol0003oooooooooo`2Cooooo`03ool00?oooooooooo09cooooo00Kok^k^ob4Q8On7
QhOo^[Zjo`000?oMgMd4ooooo`00:OoooonEo`000003ool00?l0003o000009?o00002oooool01?oM
gMgo0000oa0@4?o<c<`5ooooo`00:Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo003o0000
00kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02Oooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`00:Oooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`09ooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Yooooo`03o`000?oooooooooo
08kooooo00?o0000ooooooooool0XOooool2o`0000;ooooo0_l00004ooooo`00:Oooool00ol0003o
ooooooooo`2=ooooo`03o`000?oooooooooo0:cooooo000Yooooo`;o0000SOooool00ol0003ooooo
ooooo`2]ooooo`00:Oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo0:kooooo000Y
ooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool0[oooool002Wooooo00?o0000oooo
ooooool0ROooool00ol0003oooooooooo`2`ooooo`00:Oooool2o`0008Wooooo00?o0000oooooooo
ool0/Oooool002Wooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`2booooo`00:Ooo
ool00ol0003oooooooooo`26ooooo`03ool00?oooooooooo0;?ooooo000Yooooo`03o`000?oooooo
oooo08Gooooo0_oo002eooooo`00:Oooool00ol0003oooooooooo`24ooooo`03ool00?oooooooooo
0;Gooooo000Yooooo`;o0000Q?ooool00ooo003oooooooooo`2fooooo`00:Oooool00ol0003ooooo
ooooo`22ooooo`03ool00?oooooooooo0;Oooooo000Yooooo`03o`000?oooooooooo087ooooo00?o
o`00ooooooooool0^?ooool002Wooooo00?o0000ooooooooool0P?ooool00ooo003oooooooooo`2i
ooooo`00:Oooool00ol0003oooooooooo`1oooooo`03ool00?oooooooooo0;[ooooo000Yooooo`;o
0000Ooooool00ooo003oooooooooo`2kooooo`00:Oooool00ol0003oooooooooo`1mooooo`03ool0
0?oooooooooo0;cooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1looooo`03
ool00?oooooooooo0;gooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0Noooool00ooo003oooooooooo`2nooooo`001_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000N_ooool00ol0
003oooooooooo`2oooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q
8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo07Wooooo00?o0000oooo
ooooool0`?ooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo07Sooooo00?o0000
ooooooooool0`Oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1gooooo`03o`000?oooooo
oooo0<;ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1fooooo`03o`000?oo
oooooooo0<?ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000M_ooool00ol0003oooooooooo`34ooooo`00:Ooo
ool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo0<Gooooo000Yooooo`03o`000?oooooo
oooo07?ooooo00?o0000ooooooooool0a_ooool002Wooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`37ooooo`00:Oooool2o`00077ooooo00?oo`00o`000?ooool0bOooool002Wooooo
00?o0000ooooooooool0Koooool00ooo003oooooooooo`3:ooooo`00:Oooool00ol0003ooooooooo
o`1]ooooo`;oo`00cOooool002Wooooo00?o0000ooooooooool0K?ooool00ooo003o0000ooooo`3=
ooooo`00:Oooool00ol0003oooooooooo`1[ooooo`03ool00?l0003ooooo0<kooooo000Yooooo`;o
0000Joooool00ooo003oooooooooo`3?ooooo`00:Oooool00ol0003oooooooooo`1Yooooo`03ool0
0?oooooooooo0=3ooooo000Yooooo`03o`000?oooooooooo06Sooooo00?oo`00ooooooooool0dOoo
ool002Wooooo00?o0000ooooooooool0I_ooool00ol0003oo`00ooooo`3Cooooo`00:Oooool00ol0
003oooooooooo`1Uooooo`03o`000?oo003ooooo0=Cooooo000Yooooo`;o0000IOooool00ol0003o
o`00ooooo`3Eooooo`00:Oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo0=Kooooo
000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo067ooooo0_l0003Iooooo`003_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0H?ooool00ol0003oooooooooo`3Iooooo`003_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00oooool3o`0005oooooo00?o0000ooooooooool0f_ooool000kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0GOooool2o`000=gooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`3Moooo
o`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1Kooooo`03o`000?oooooooooo0=kooooo000>ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05[ooooo00?o0000oooo
ooooool0goooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`00
05Wooooo00?o0000ool00?oo0000hOooool002Wooooo00?o0000ooooooooool0Eoooool00ol0003o
o`00ooooo`3Rooooo`00:Oooool00ol0003oooooooooo`1Fooooo`03o`000?oo003ooooo0>?ooooo
000Yooooo`03o`000?oooooooooo05Gooooo00?o0000ool00?ooool0i?ooool002Wooooo0_l0001D
ooooo`03o`000?oo003oo`000>Kooooo000Yooooo`03o`000?oooooooooo05;ooooo00?o0000ool0
0?ooool0ioooool002Wooooo00?o0000ooooooooool0DOooool2ool00>Wooooo000Yooooo`03o`00
0?oooooooooo053ooooo00?oo`00ooooooooool0jOooool002Wooooo00?o0000ooooooooool0C_oo
ool00ol0003oo`00ooooo`3[ooooo`00:Oooool2o`0004kooooo00?o0000ool00?ooool0k?ooool0
02Wooooo00?o0000ooooooooool0Boooool2o`000>oooooo000Yooooo`03o`000?oooooooooo04Wo
oooo0_l0003aooooo`00:Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo0?7ooooo
000Yooooo`03o`000?oooooooooo04Kooooo0_l0003dooooo`00:Oooool2o`0004Kooooo00?o0000
ooooooooool0m?ooool002Wooooo00?o0000ooooooooool0@oooool2o`000?Oooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`3g
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWo
oooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`10ooooo`;o0000n_ooool0
00Kooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000
ooooooooool00oooool3o`0003kooooo0_l000000oooooooo`00ool0003iooooo`001_ooool01Ol0
003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo03gooooo00Co0000oooooooo003oo`00noooool000Kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo03_ooooo0_l000000oooooooo`00ooooo`3looooo`001_oo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo03[ooooo00Co0000oooooooo003oo`00o_ooool000Kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo03Sooooo0_l00002ool00?oooooo0Oooool000Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0000hoooo
o`03o`000?oo003oo`000?oooooo0oooool002Wooooo00?o0000ooooooooool0=Oooool00ol0003o
o`00ool0003oooooo`Gooooo000Yooooo`03o`000?oooooooooo03?ooooo0_l000000ooo003ooooo
ooooo`3oooooo`Gooooo000Yooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0oooo
ool8ooooo`00:Oooool2o`00037ooooo0_l0003oooooo`_ooooo000Yooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool0ooooool;ooooo`00:Oooool00ol0003oooooooooo`0]ooooo`;o
0000ooooool>ooooo`00:Oooool00ol0003oooooooooo`0Zooooo`?o0000ooooool@ooooo`00:Ooo
ool00ol0003oooooooooo`0Wooooo`?o0000oooooolCooooo`00:Oooool2o`0002Gooooo0ol00002
ool00?oooooo5?ooool002Wooooo00?o0000ooooooooool08Oooool3o`0000?oo`00oooooolFoooo
o`00:Oooool00ol0003oooooooooo`0Nooooo`?o00000ooo003ooooooaWooooo000Yooooo`03o`00
0?oooooooooo01_ooooo0ol00003ool00?oooooo7?ooool002Wooooo00?o0000ooooooooool06?oo
ool3o`0000?oo`00oooooolOooooo`00:Oooool2o`0001Kooooo0ol00002ooooo`03ool00?oooooo
oooo0?oooooo8?ooool002Wooooo00?o0000ooooooooool04_ooool3o`000?oooooo:?ooool001oo
oooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00oooooo0ol0003oooooob_o
oooo000Qooooo`03o`000?oooooooooo00Gooooo3Ol00002ool000?o0000ooooool^ooooo`008Ooo
ool00ol0003oooooooooo`05ooooo`goo`00oooooolcooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmV
IVKo00000?ooooooAoooool00?ooooooJOooool00:Cooooo0_l0000;ooooo`03o`000?nj^[[ooooo
00cooooo0_l00005ooooo`03o`000?nj^[[ooooo09kooooo002Tooooo`03o`000?oooooooooo00[o
oooo0_lb<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:Oooooo`00VOooool01Ol@413o0000
o`000?l0003o410@00Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7
QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`03
ooooo`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h0Q_ooool009_ooooo00?o0000ooooooooool01_ooool02_l0003ooooooooo
ooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@
okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Ooo
ool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
08Kooooo002Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo
0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`05oa0@4?ooooooooooooooool@4100Q_ooool009_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo1_l00002
ooooo`05o`000?ooooooooooooooool00000Q_ooool009_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooooooooooo
o`000026ooooo`00V?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Go
oooo00?o0000ooooooooool02Oooool00ol@413o0000o`000003o`0000[ooooo00Go410@oooooooo
oooooooooa0@4026ooooo`00V?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Hoooo
o`Oo00001Oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0000gooooo00?o0000oooo
ooooool02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.13153, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .47414 m
.05556 .47414 L
.16667 .45423 L
.27778 .4168 L
.38889 .36636 L
.5 .30902 L
.61111 .25167 L
.72222 .20124 L
.83333 .16381 L
.94444 .14389 L
s
.94444 .14389 m
1 .14389 L
s
1 0 0 r
[ .05 .05 ] 0 setdash
0 .47578 m
.00123 .47577 L
.00236 .47577 L
.00365 .47576 L
.00488 .47576 L
.00706 .47573 L
.00942 .4757 L
.01203 .47566 L
.01479 .4756 L
.01975 .47545 L
.02486 .47527 L
.02966 .47505 L
.04057 .47442 L
.0517 .47358 L
.06188 .47263 L
.08481 .46989 L
.10474 .46683 L
.1265 .46278 L
.16918 .45277 L
.21027 .4407 L
.25393 .42547 L
.296 .40872 L
.33648 .39097 L
.37953 .37063 L
.42099 .34998 L
.46086 .32947 L
.50331 .30728 L
.54416 .28596 L
.58759 .26371 L
.62943 .24306 L
.66967 .22428 L
.7125 .20578 L
.75372 .18973 L
.79336 .17618 L
.83558 .16402 L
.8762 .15471 L
.89683 .15094 L
.91939 .14758 L
.94095 .14512 L
.95057 .14427 L
.961 .14351 L
.96647 .14318 L
.97151 .14293 L
.97624 .14272 L
.98143 .14254 L
.98609 .14242 L
.99045 .14233 L
.99286 .1423 L
.99505 .14228 L
.99627 .14227 L
Mistroke
.99759 .14226 L
.99884 .14226 L
1 .14226 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4
o`000003oa0@4?oooooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`005_ooool6o`0000Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo5?ooool;o`0000Soo`000_l0000Dooooo`003_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`3oooooo`gooooo1Ooo0002o`0002Wooooo000>ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`3oooooo`Kooooo1ooo0002o`0002kooooo0006ooooo`Ko00000_ooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo0_ooool4ool000?o0000
=?ooool000kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0oOooool6o`0003Wooooo000>ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0n?ooool5o`0003oo
oooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0?Cooooo1?l00014ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3aooooo`;oo`0000?o0000oooooooo
ool0A_ooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000>oo
oooo0ooo001;ooooo`00:Oooool00ol0003oooooooooo`3[ooooo`?oo`00C_ooool002Wooooo00?o
0000ooooooooool0ioooool4ool0057ooooo000Yooooo`03o`000?oooooooooo0>Cooooo0ooo0000
0ol0003oooooooooo`1Booooo`00:Oooool2o`000>?ooooo0ol0001Gooooo`00:Oooool00ol0003o
ooooooooo`3Oooooo`?o0000F_ooool002Wooooo00?o0000ooooooooool0g?ooool3o`0005gooooo
000Yooooo`03o`000?oooooooooo0=Wooooo0ol0001Pooooo`00:Oooool00ol0003oooooooooo`3E
ooooo`;oo`000_l0001Sooooo`00:Oooool2o`000=Cooooo0_oo00000ol0003oooooooooo`1Toooo
o`00:Oooool00ol0003oooooooooo`3Aooooo`03o`000?oo003ooooo06Sooooo000Yooooo`03o`00
0?oooooooooo0<kooooo0_l00002ool006[ooooo000Yooooo`03o`000?oooooooooo0<cooooo00Co
0000ool00?oo003oo`00K?ooool002Wooooo00?o0000ooooooooool0b_ooool3ool006oooooo000Y
ooooo`;o0000bOooool2ool007;ooooo000Yooooo`03o`000?oooooooooo0<Kooooo0_l0001doooo
o`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0`oooool3o`0007Kooooo0006oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0`Oooool2o`0007Wooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o
0000ooooooooool00oooool3o`000;oooooo0_l0001kooooo`001_ooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0;gooooo0_l0001mooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
^_ooool2ool00003o`000?oooooooooo07gooooo0006ooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
^?ooool00ol0003oo`00o`000021ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0]_ooool00ol0003oo`00ool00023ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000;Gooooo00?o0000ool0
0?oo0000QOooool002Wooooo00?o0000ooooooooool0/_ooool00ol0003oo`00ool00027ooooo`00
:Oooool00ol0003oooooooooo`2`ooooo`03o`000?oo003oo`0008Wooooo000Yooooo`03o`000?oo
oooooooo0:kooooo00?o0000ool00?oo0000Roooool002Wooooo0_l0002]ooooo`;o000000?oo`00
ooooooooool0Roooool002Wooooo00?o0000ooooooooool0Z_ooool2o`00093ooooo000Yooooo`03
o`000?oooooooooo02gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00
02Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooo
oooo02Cooooo00Cok^k^oc8b<_l0003o<S8b0_l00004ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`00
0?l@413oc<c<02Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co
8B4Qo`000?lQ8B7oc<c<033ooooo1?l000000ol@413oooooooooo`0@ooooo`00:Oooool00ol0003o
ooooooooo`0]ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A00Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o
0000ooooooooool09Oooool01OmgMgOoV9RHo`000?l0003oMgMg00Gooooo0_lQ8B44ooooo`05oeEE
EOmgMgOooooooiRHV?lQ8B409oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B40<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0
003oooooooooo`0]ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0X
ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0002Kooooo0_l00002ooooo`03oa0@4?oo
oooooooo00Wooooo00Go0000ooooooooooooooooo`00000Wooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol0003ooooooooooooooooo000003;ooooo00?o0000ooooooooool04_ooool002Wo
oooo0_l0000^ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Woooo
o`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0000Uooooo`?o00000ooo
ool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B409oooool01Ol0003ooooo
oooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0booooo`03o`000?oooooooooo
01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo02Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0002Cooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`09ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`09oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`00
0?l0003o0000olc<c00booooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo
02gooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo02Gooooo00Go410@
oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co0000027ooooo0ooo0003ooooo`05oa0@4?oo
ooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Yooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol@413o^[Zjoooooonj^[[o410@03;ooooo00?o0000ooooooooool04_ooool002Wo
oooo00?o0000ooooooooool0;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_ooooooV9RHoa0@400Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00
000Oooooo`;oo`0000?o0000ooooooooool00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00?ogMgMoa0@4?nHV9P0:Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
oooo^[Zjo`00000booooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`09oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool07Oooool00ooo003o0000oooo
o`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410Wooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY033ooooo00?oEEEE
ofIVI_l000005?ooool002Wooooo0_l0002Jooooo`;oo`00XOooool002Wooooo00?o0000oooooooo
ool0Uoooool2ool00:?ooooo000Yooooo`03o`000?oooooooooo09Gooooo00?o0000ool00?ooool0
V_ooool2o`0000;ooooo0_l00004ooooo`00:Oooool00ol0003oooooooooo`2Cooooo`03o`000?oo
003oo`0009cooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`00:OoooonFo`000003ool0
0?l0003o000009;o00002oooool01?oMgMgo0000oa0@4?o<c<`5ooooo`00:Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`09ooooo`;o000000?oooooo`000?ooool03Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`04onk^
k_lQ8B7o410@onk^kPGooooo000Yooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0Fooooo`;o00008?ooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`00
:Oooool00ol0003oooooooooo`2;ooooo`;o0000YOooool2o`0000;ooooo0_l00004ooooo`00:Ooo
ool00ol0003oooooooooo`29ooooo`;o0000/Oooool002Wooooo0_l00028ooooo`;o0000/oooool0
02Wooooo00?o0000ooooooooool0QOooool2ool00;Gooooo000Yooooo`03o`000?oooooooooo08?o
oooo0_oo002gooooo`00:Oooool00ol0003oooooooooo`21ooooo`;oo`00^Oooool002Wooooo0_l0
0020ooooo`;oo`00^oooool002Wooooo00?o0000ooooooooool0OOooool2ool00003o`000?oooooo
oooo0;[ooooo000Yooooo`03o`000?oooooooooo07_ooooo0_oo00000ol0003oooooooooo`2loooo
o`00:Oooool00ol0003oooooooooo`1jooooo`03ool00?l0003ooooo0;oooooo000Yooooo`03o`00
0?oooooooooo07Sooooo00?o0000ool00?ooool0`Oooool002Wooooo0_l0001gooooo`;o0000a?oo
ool002Wooooo00?o0000ooooooooool0M?ooool2o`000<Kooooo000Yooooo`03o`000?oooooooooo
07;ooooo0_l00038ooooo`00:Oooool00ol0003oooooooooo`1`ooooo`;o0000b_ooool002Wooooo
00?o0000ooooooooool0K_ooool2o`000<cooooo000Yooooo`;o0000K?ooool3o`000<kooooo000Y
ooooo`03o`000?oooooooooo06Wooooo00?o0000ool00?oo0000d?ooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo06Oooooo00?o0000ool00?oo0000d_ooool000Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1Uooooo`03o`000?oo003oo`000=Cooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`00
0?oooooooooo00?ooooo0ol0001Rooooo`;o00000_oo003Fooooo`001_ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo063ooooo0_l00002ool00=Sooooo0006ooooo`05o`000?ooooooooooooooool00000
3_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`1Nooooo`;o00000_oo003Jooooo`001_ooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05_o
oooo0ol00002ool00=cooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Ioooo
o`;o0000hOooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0001Hooooo`;o0000hoooool002Wooooo00?o0000oooo
ooooool0EOooool2o`000>Gooooo000Yooooo`03o`000?oooooooooo05;ooooo0ol0003Wooooo`00
:Oooool00ol0003oooooooooo`1@ooooo`;o0000j_ooool002Wooooo0_l0001?ooooo`03o`000?oo
003oo`000>_ooooo000Yooooo`03o`000?oooooooooo04_ooooo00Co0000ool00?oo003oo`00kOoo
ool002Wooooo00?o0000ooooooooool0B?ooool01?l0003oo`00ool00?oo003`ooooo`00:Oooool0
0ol0003oooooooooo`15ooooo`;o00000_oo003cooooo`00:Oooool00ol0003oooooooooo`13oooo
o`04o`000?oo003oo`00ool00?Gooooo000Yooooo`;o0000@Oooool2o`0000;oo`00n?ooool002Wo
oooo00?o0000ooooooooool0?Oooool3o`000?cooooo000Yooooo`03o`000?oooooooooo03[ooooo
0ol0003oooooo`00:Oooool00ol0003oooooooooo`0hooooo`;o0000ooooool3ooooo`00:Oooool0
0ol0003oooooooooo`0eooooo`?o0000ooooool5ooooo`00:Oooool2o`0003?ooooo0ooo003ooooo
o`Sooooo000Yooooo`03o`000?oooooooooo02gooooo1Ooo003oooooo`_ooooo000>ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo02Sooooo1Ooo0002o`000?oooooo3_ooool000kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
02Cooooo0_l00002ool000?o0000oooooolBooooo`003_ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool00oooool3o`0001gooooo1ol0003ooooooaWooooo000>ooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
01Oooooo1_l0003oooooob3ooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool04?ooool3o`0000Goo`00oooooolU
ooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool>
o`0000Soo`00oooooolZooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`08ooooo`?oo`00oooooolbooooo`003_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_oo
ool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?oo
ool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo
?Oooool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool0027ooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`007oooool0
0omEEEGoIVIVo`00003oooooodOooooo003oooooofWooooo002Hooooo`;o00002oooool00ol0003o
^[Zjooooo`0<ooooo`;o00001_ooool00ol0003o^[Zjooooo`2Yooooo`00V?ooool00ol0003ooooo
ooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`04ooooo`;o<S8bZ_ooool008kooooo00Go
410@o`000?l0003o0000oa0@4005ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o0000
0_ooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool00ol0003o
ooooooooo`04ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P09oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o
0000oc8b<_oMgMd0NOooool0093ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@4005ooooo`05oa0@
4?nj^[[ok^k^ogMgMol@41000oooool00ol0003oooooooooo`04ooooo`03olc<c?l0003o410@00Co
oooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`Ko000000KoooooogMgMonHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
N?ooool0093ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04omgMgOl0
003o410@olc<c0_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wo
oooo00?o0000ooooooooool0Moooool0093ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo1_l000000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`1hooooo`00
T?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Co8B4QogMgMomgMgOo
<S8b2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<07Wooooo002=ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000Sooooo00?o410@
o`000?l000000ol00004ooooo`03o`000?oooooooooo00Wooooo00?o410@o`000?l000000ol0000:
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo07_ooooo002=ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00?o0000ooooooooool0Noooool008gooooo1ol00004ooooo`;o0000
4oooool00ol0003oooooooooo`04ooooo`;o00003Oooool00ol0003oooooooooo`0;ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0001joooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.13153, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .39862 m
.05556 .39862 L
.16667 .38781 L
.27778 .3675 L
.38889 .34013 L
.5 .30902 L
.61111 .2779 L
.72222 .25054 L
.83333 .23023 L
.94444 .21942 L
s
.94444 .21942 m
1 .21942 L
s
1 0 0 r
[ .05 .05 ] 0 setdash
0 .39901 m
.00123 .39901 L
.00236 .399 L
.00365 .399 L
.00488 .399 L
.00706 .39898 L
.00942 .39897 L
.01203 .39894 L
.01479 .39891 L
.01975 .39883 L
.02486 .39873 L
.02966 .39862 L
.04057 .39828 L
.0517 .39782 L
.06188 .39731 L
.08481 .39583 L
.10474 .39418 L
.1265 .39199 L
.16918 .38659 L
.21027 .38008 L
.25393 .37186 L
.296 .36282 L
.33648 .35324 L
.37953 .34227 L
.42099 .33112 L
.46086 .32005 L
.50331 .30808 L
.54416 .29657 L
.58759 .28457 L
.62943 .27343 L
.66967 .26329 L
.7125 .25331 L
.75372 .24464 L
.79336 .23733 L
.83558 .23077 L
.8762 .22575 L
.89683 .22371 L
.91939 .2219 L
.94095 .22057 L
.95057 .22011 L
.961 .2197 L
.96647 .21953 L
.97151 .21939 L
.97624 .21928 L
.98143 .21918 L
.98609 .21911 L
.99045 .21907 L
.99286 .21905 L
.99505 .21904 L
.99627 .21903 L
Mistroke
.99759 .21903 L
.99884 .21903 L
1 .21903 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4
o`000003oa0@4?oooooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`005_ooool6o`0000Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo
000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo9?ooool6ool001Cooooo000Yooooo`03o`000?oooooooooo0?oo
oooo3?ooool3ool000?ooooo2ol00006ool000Ko00005?ooool000Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo0Oooool;ool000Ko0000:oooool000Kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3kooooo`?o00000_oo0006o`0003Kooooo0004o`00
00;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000
ooooooooool00oooool3o`000?;ooooo2Ol00011ooooo`001_ooool01Ol0003ooooooooooooooooo
000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0>cooooo1?oo0002o`0004[ooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`3Uooooo`Ooo`0000?o0000ooooooooool0COooool000Kooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3Qooooo`Coo`000_l0001Eooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
g?ooool6o`0005[ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000f?ooool5o`00063ooooo000Yooooo`03o`00
0?oooooooooo0=;ooooo00?oo`00o`000?l000000_l0001Uooooo`00:Oooool00ol0003ooooooooo
o`3>ooooo`04o`000?oo003oo`00ool006[ooooo000Yooooo`03o`000?oooooooooo0<[ooooo1Ooo
001]ooooo`00:Oooool2o`000<Oooooo1?oo001booooo`00:Oooool00ol0003oooooooooo`31oooo
o`?o00000_oo001fooooo`00:Oooool00ol0003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo0_l000000ol@413oooooooooo`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c004ooooo`Co00007oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0<?ooool4o`00
0003oa0@4?oooooooooo013ooooo000Yooooo`03o`000?oooooooooo02gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A402Oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Uooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@04o`0002?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03;ooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000ooooooooool0;Oooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0:?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol0000Vooooo`05oa0@4?ooooooooooooooool@41002oooool2ool000?o0000
9oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000boooo
o`03o`000?oooooooooo01;ooooo000Yooooo`;o0000;_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h09oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo00009oooool01Ol0003ooooooooooooooooo000000Sooooo0ooo00001Ol0003oV9RH
oooooonHV9So8B4Q02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9Sooooo
oiRHV?lb<S80<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003oooooooooo`0]oooo
o`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Vooooo`05o`000?oooooo
ooooooooool000002oooool01?oMgMgoEEEEooooool0000Wooooo`05o`000?ooooooooooooooool0
00001?ooool01?l0003oo`00ool00?oo0003ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00booooo`03o`00
0?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo02Gooooo00Go410@oooooooooooooooooa0@400<ooooo`03
ogMgMoo<c<co000002Oooooo00Ko410@oooooooooooooooooa0@4?ooool4ool000Kooooo00?oEEEE
ohN7Qoooool0:Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zj
oa0@400booooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41009oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009oooool00omgMgOoV9RHo`000003ool0
00[ooooo00?ogMgMoa0@4?nHV9P0:Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_oooooo^[Zjo`00000booooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooo
oooo02gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
9oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool09?ooool5o`000003
oc8b<_o^k^kooooo00_ooooo00Coc<c<odA4A?l0003o410@9oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0`ooooo`03oeEEEOmVIVKo000001Cooooo000Y
ooooo`;o0000X?ooool3o`0009[ooooo000Yooooo`03o`000?oooooooooo09_ooooo1?l0002Moooo
o`00:Oooool00ol0003oooooooooo`2Gooooo`;oo`000_l0002Gooooo`;o00000_ooool2o`0000Co
oooo000Yooooo`03o`000?oooooooooo09Cooooo0ooo002Kooooo`06onk^k_lQ8B7oQhN7okZj^_l0
003ogMgM1?ooool002WoooooU?l00003ool009Co00002oooool01?oMgMgo0000oa0@4?o<c<`5oooo
o`00:Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`06ooooo`Goo`0000?oooooo`000?ooool03Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`09ooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Yooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Cooooo`;oo`0000?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool02Oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`00:Oooool00ol0003oooooooooo`26ooooo`Co
0000Z?ooool2o`0000;ooooo0_l00004ooooo`00:Oooool00ol0003oooooooooo`23ooooo`?o0000
]_ooool002Wooooo0_l00021ooooo`?o0000^Oooool002Wooooo00?o0000ooooooooool0Noooool2
ool000?o0000_?ooool002Wooooo00?o0000ooooooooool0N?ooool3ool000;o0000_oooool002Wo
oooo00?o0000ooooooooool0M?ooool4ool00003o`000?oooooooooo0<7ooooo000Yooooo`;o0000
LOooool4ool000;o0000a_ooool002Wooooo00?o0000ooooooooool0KOooool3ool000?o0000bOoo
ool002Wooooo00?o0000ooooooooool0Joooool4o`000<gooooo000Yooooo`03o`000?oooooooooo
06Kooooo1Ol0003Aooooo`00:Oooool00ol0003oooooooooo`1Rooooo`Co0000e_ooool002Wooooo
0_l0001Nooooo`?oo`000_l0003Jooooo`00:Oooool00ol0003oooooooooo`1Hooooo`Goo`0000?o
0000ooooooooool0g?ooool002Wooooo00?o0000ooooooooool0Doooool5ool000;o0000h_ooool0
02Wooooo00?o0000ooooooooool0D?ooool3ool000;o0000ioooool002Wooooo00?o0000oooooooo
ool0C?ooool5o`000>_ooooo000Yooooo`;o0000B?ooool5o`000?3ooooo000Yooooo`03o`000?oo
oooooooo03oooooo1?oo0004o`000?Gooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`0iooooo`Koo`000_l0003kooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo03Gooooo1?oo0003o`000?oooooo0Oooool000Kooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`00037o
oooo0_l00002ool00003o`000?oooooooooo0?oooooo1Oooool000Kooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`0Yooooo`So0000ooooool<ooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool07_ooool00ol0003oo`00ool00004ool000Co0000oooooolDooooo`001_ooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01?ooooo0ol00009ool00?oooooo7_ooool000Kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07
ooooo`_oo`002ol0003oooooob[ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo
000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`003_ooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo
000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol@413ooooooooooooooooo410@00co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocgo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomYooooo`00W?oo
ool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Kooooo00?o0000okZj^_ooool0YOoo
ool009cooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool01?ooool2
oc8b<ZKooooo002Booooo`05oa0@4?l0003o0000o`000?l@41001Oooool00ol0003oooooooooo`02
ooooo`;o00000_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4
A4Co^[Zj00?ooooo00?o0000ooooooooool01?ooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0
003o0000odA4A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd0OOooool009Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@4005
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0003oooooooooo`04ooooo`03olc<c?l0
003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`Ko000000KoooooogMgMonHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`1looooo`00U?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0Noooool009Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo1_l00000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00gooooo00?oMgMgoc8b<_ooool0O?ooool0
09Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04ob4Q8OmgMgOoMgMg
oc8b<P_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
OOooool0097ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Cooooo
00?o0000ooooooooool02Oooool00ol@413o0000o`000003o`0000[ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo07oooooo002Aooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`1oooooo`00TOooool7o`0000Cooooo0_l0000Cooooo`03
o`000?oooooooooo00Cooooo0_l0000=ooooo`03o`000?oooooooooo00_ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co0000O_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.13153, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .35763 m
.05556 .35763 L
.16667 .35177 L
.27778 .34075 L
.38889 .3259 L
.5 .30902 L
.61111 .29213 L
.72222 .27728 L
.83333 .26626 L
.94444 .2604 L
s
.94444 .2604 m
1 .2604 L
s
1 0 0 r
[ .05 .05 ] 0 setdash
0 .35758 m
.00123 .35758 L
.00236 .35758 L
.00365 .35758 L
.00488 .35757 L
.00706 .35757 L
.00942 .35756 L
.01203 .35754 L
.01479 .35753 L
.01975 .35749 L
.02486 .35743 L
.02966 .35737 L
.04057 .35719 L
.0517 .35694 L
.06188 .35666 L
.08481 .35587 L
.10474 .35497 L
.1265 .35379 L
.16918 .35088 L
.21027 .34736 L
.25393 .34293 L
.296 .33805 L
.33648 .33288 L
.37953 .32696 L
.42099 .32095 L
.46086 .31497 L
.50331 .30851 L
.54416 .3023 L
.58759 .29582 L
.62943 .28981 L
.66967 .28434 L
.7125 .27895 L
.75372 .27428 L
.79336 .27033 L
.83558 .26679 L
.8762 .26408 L
.89683 .26298 L
.91939 .262 L
.94095 .26129 L
.95057 .26104 L
.961 .26082 L
.96647 .26072 L
.97151 .26065 L
.97624 .26059 L
.98143 .26054 L
.98609 .2605 L
.99045 .26048 L
.99286 .26047 L
.99505 .26046 L
.99627 .26046 L
Mistroke
.99759 .26046 L
.99884 .26046 L
1 .26045 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4
o`000003oa0@4?oooooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`005_ooool6o`0000Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo
000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Co00000_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03
ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo3_ooool:ool000ko00001?oo000Doooo
o`00:Oooool00ol0003oooooooooo`3mooooo`Wo00001_oo0002o`0002kooooo000Yooooo`03o`00
0?oooooooooo02gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo
02Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<02Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool9ool000Co0000
:?ooool4o`000003oa0@4?oooooooooo013ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A402Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Uoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q
8@0Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?l00007ool00005ob4Q8OnHV9SooooooiRHV?lQ
8B40<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003oooooooooo`0]ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Xooooo`05oa0@4?oooooooooooooo
ool@41002oooool5o`0002Kooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000007Oooool5ool000[o00002oooool01Ol0003ooooooooooooooooo000003;ooooo
00?o0000ooooooooool04_ooool002Wooooo0_l0000^ooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP0Wooooo`05o`000?ooooooooooooooool000002oooool01?m4A4Co
gMgMooooool0000Wooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonH
V9So8B4Q01Gooooo2?oo0004o`0000Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b
<_nHV9SooooooiRHV?lb<S80<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003ooooo
ooooo`0]ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Vooooo`05
o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000Wooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00oooooo0ol00003ool000;o0000
4?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00boooo
o`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo02Gooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002Oooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo00Sooooo2Ol0000Hooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zj
oooooonj^[[o410@03;ooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000ooooooooool0
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Woooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000Wooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV003o`0000?oo`000_l0000Qooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000003;ooooo00?o0000oooooooo
ool04_ooool002Wooooo00?o0000ooooooooool0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`0Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool3o`0000Ooo`009_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0`ooooo`03
oeEEEOmVIVKo000001Cooooo000Yooooo`;o0000Z_ooool5o`0000Goo`00ROooool002Wooooo00?o
0000ooooooooool0X_ooool7o`0009?ooooo000Yooooo`03o`000?oooooooooo09cooooo1?oo0002
o`00093ooooo0_l00002ooooo`;o00001?ooool002Wooooo00?o0000ooooooooool0UOooool00ol0
003oo`00ool00004ool009Kooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`00:OoooonE
o`0000Coo`00T_l0000;ooooo`04omgMgOl0003o410@olc<c0Gooooo000Yooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00;ooooo1ol000001?ooooooo`00ool00?l0000>ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00Co
k^k^ob4Q8Ol@413ok^k^1Oooool002Wooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo00[ooooo1ol0000Wooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`09ooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo
000Yooooo`03o`000?oooooooooo07_ooooo0ol00004ool00;3ooooo0_l00002ooooo`;o00001?oo
ool002Wooooo00?o0000ooooooooool0M?ooool3o`0000Ooo`00__ooool002Wooooo0_l0001_oooo
o`Go00001?oo0035ooooo`00:Oooool00ol0003oooooooooo`1Wooooo`Oo0000c_ooool002Wooooo
00?o0000ooooooooool0G_ooool7ool000;o0000eOooool002Wooooo00?o0000ooooooooool0F?oo
ool6ool000;o0000g?ooool002Wooooo0_l0001Cooooo`?o00000ooo00000ol0003oooooooooo`3Q
ooooo`00:Oooool00ol0003oooooooooo`1:ooooo`So0000j_ooool002Wooooo00?o0000oooooooo
ool0?oooool2o`0000Koo`000ol0003booooo`00:Oooool00ol0003oooooooooo`0dooooo`Co0000
2Ooo003kooooo`00:Oooool00ol0003oooooooooo`0Vooooo`Coo`002_l0003oooooo`Wooooo000Y
ooooo`;o00005_ooool5o`0000coo`00oooooolGooooo`00:Oooool?ool000Wo0000oooooolXoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool0
00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?oo
ooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo
0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooo
oooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00
00Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co
000000?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003ooooooooo
o`05ooooo`?o0000oooooolmooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAooo
ool00?ooooooJOooool009Sooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00006oooo
o`03o`000?nj^[[ooooo0:Wooooo002Hooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03
o`000?oooooooooo00Cooooo0_lb<S:Zooooo`00S_ooool01Ol@413o0000o`000?l0003o410@00Go
oooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00Go
oooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`00
0?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
NOooool0093ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`06onk^k_lQ
8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@4005ooooo`05oa0@4?nj^[[ok^k^ogMg
Mol@41000oooool00ol0003oooooooooo`04ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj
^_o^k^koMgMgoa0@4002ooooo`Ko000000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q
1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo07Sooooo002@ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`05oa0@
4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo07Oo
oooo002@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01?o^k^ko8B4Q
oa0@4?o^k^h;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`04ooooo`Ko000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03
ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool0N?ooool0093ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c01i
ooooo`00SOooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001?ooool0
0ol0003oooooooooo`09ooooo`03oa0@4?l0003o000000?o00002_ooool01Ol@413ooooooooooooo
oooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`1kooooo`00SOooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03
o`000?oooooooooo07_ooooo002=ooooo`Oo00001?ooool2o`0001?ooooo00?o0000ooooooooool0
1?ooool2o`0000gooooo00?o0000ooooooooool02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co0000N_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.13153, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .3354 m
.05556 .3354 L
.16667 .33221 L
.27778 .32624 L
.38889 .31818 L
.5 .30902 L
.61111 .29986 L
.72222 .2918 L
.83333 .28582 L
.94444 .28264 L
s
.94444 .28264 m
1 .28264 L
s
1 0 0 r
[ .05 .05 ] 0 setdash
0 .33522 m
.00123 .33522 L
.00236 .33522 L
.00365 .33522 L
.00488 .33522 L
.00706 .33522 L
.00942 .33521 L
.01203 .3352 L
.01479 .33519 L
.01975 .33517 L
.02486 .33514 L
.02966 .33511 L
.04057 .33501 L
.0517 .33488 L
.06188 .33473 L
.08481 .3343 L
.10474 .33382 L
.1265 .33318 L
.16918 .33161 L
.21027 .32971 L
.25393 .32732 L
.296 .32469 L
.33648 .3219 L
.37953 .3187 L
.42099 .31546 L
.46086 .31223 L
.50331 .30874 L
.54416 .30539 L
.58759 .3019 L
.62943 .29865 L
.66967 .2957 L
.7125 .29279 L
.75372 .29027 L
.79336 .28814 L
.83558 .28623 L
.8762 .28477 L
.89683 .28418 L
.91939 .28365 L
.94095 .28326 L
.95057 .28313 L
.961 .28301 L
.96647 .28296 L
.97151 .28292 L
.97624 .28288 L
.98143 .28286 L
.98609 .28284 L
.99045 .28282 L
.99286 .28282 L
.99505 .28281 L
.99627 .28281 L
Mistroke
.99759 .28281 L
.99884 .28281 L
1 .28281 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4
o`000003oa0@4?oooooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`005_ooool6o`0000Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo
000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Co00000_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03
ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol0000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Kooooo0_l000000ol@413oooooooooo`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c00Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00`ooooo`Co000000?o410@oooooooo
ool04?ooool002Wooooo00?o0000ooooooooool0;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02Gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03;ooooo00?o0000oooo
ooooool04_ooool002Wooooo00?o0000ooooooooool0;Oooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h0:?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000V
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Oooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<_ooool00ol0
003oooooooooo`0Booooo`00:Oooool2o`0002kooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgo
ooooo`0002Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B409oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0b
ooooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo02Kooooo00Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0002Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`09oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<
o`000?l0003o0000olc<c00Aooooob3o00000_oo000Dooooo`00:Oooool00ol0003oooooooooo`0]
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Uooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Wooooo`05oa0@4?ooooooooooooooool@
41002oooool00omEEEGoQhN7ooooo`0Yooooo`05oa0@4?ooooooooooooooool@41002?ooool4o`00
00[oo`002ol00003oooooa3oo`003_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003o
ooooooooo`0]ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02Gooooo3ol00006ool00004okZj
^_oooooo^[Zjo`0003;ooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000ooooooooool0
;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Woooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Vooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410Fooooo`koo`000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0`ooooo`03oeEEEOmVIVKo0000
01Cooooo000Yooooo`;o0000aOooool9o`0000;oo`00KOooool002Wooooo00?o0000ooooooooool0
]?ooool;ool000Go0000N?ooool002Wooooo00?o0000ooooooooool0Zoooool5o`0000Coo`001Ol0
001iooooo`;o00000_ooool2o`0000Cooooo000Yooooo`03o`000?oooooooooo09Wooooo2Ooo0009
o`0008Oooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`00:OoooonEo`0000Ooo`00Sol0
000;ooooo`04omgMgOl0003o410@olc<c0Gooooo000Yooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`Goo`002Ol00005ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02Oooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`00:Ooo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02?oo
0003o`0002gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo00Wooooo00Co8B4QogMgMomgMgOo<S8b1Oooool002Wooooo00?o0000ooooooooool0JOoo
ool;o`0000?oo`00^oooool2o`0000;ooooo0_l00004ooooo`00:Oooool00ol0003oooooooooo`1H
ooooo`Co00002_oo0003o`000=?ooooo000Yooooo`;o0000B?ooool@o`0000Goo`00h?ooool002Wo
oooo00?o0000ooooooooool0=_ooool4o`0000ooo`00loooool002Wooooo00?o0000ooooooooool0
7_ooool00ol0003oo`00ool0000:ool000_o00000oooool00ooo003oooooooooo`3oooooo`7ooooo
000Yoooooa3oo`003_l00004ool00?oooooo7_ooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP09ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo000>oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
0006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooo
oooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000
oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool0
1_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooo
oooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413o
oooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooo
ocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006oooo
o`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2
o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2
o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`007oooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Ooo
ool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`007oooool00omEEEGoIVIVo`00003oooooodOooooo003o
ooooofWooooo002Pooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0
003o^[Zjooooo`2Rooooo`00X?ooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003o
ooooooooo`03ooooo`;o<S8bXoooool009Gooooo00Go410@o`000?l0003o0000oa0@4006ooooo`04
o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnH
V9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7QhOo0000okZj^P05
ooooo`05oiRHV?l0003o0000odA4A?nj^[X02_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ
8B63ooooo`00Uoooool00ol0003oooooooooo`06ooooo`0:o`000?ooooooooooooooooo^k^ko8B4Q
ohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo
410@00Cooooo00?o0000ooooooooool00oooool00oo<c<co0000oa0@4005ooooo`06oa0@4?nj^[[o
k^k^ogMgMol@413ooooo1_l00005ooooo`03o`000?oooooooooo00Cooooo0_lQ8B63ooooo`00Uooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<
2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`29ooooo`00Uoooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool00oooool6o`0000Gooooo00?o0000ooooooooool0
ROooool009Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04ob4Q8Omg
MgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0ROooool009Cooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000So
oooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo00Wooooo00?o410@o`000?l0
00000ol0000=ooooo`03o`000?oooooooooo08Wooooo002Dooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo08Wo
oooo002Dooooo`Oo00001Oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0000gooooo
00?o0000ooooooooool03?ooool00omEEEGoIVIVo`00002;ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.13153, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .32333 m
.05556 .32333 L
.16667 .3216 L
.27778 .31836 L
.38889 .31399 L
.5 .30902 L
.61111 .30405 L
.72222 .29967 L
.83333 .29643 L
.94444 .2947 L
s
.94444 .2947 m
1 .2947 L
s
1 0 0 r
[ .05 .05 ] 0 setdash
0 .32316 m
.00123 .32316 L
.00236 .32316 L
.00365 .32316 L
.00488 .32316 L
.00706 .32316 L
.00942 .32315 L
.01203 .32315 L
.01479 .32314 L
.01975 .32313 L
.02486 .32312 L
.02966 .3231 L
.04057 .32304 L
.0517 .32297 L
.06188 .32289 L
.08481 .32266 L
.10474 .3224 L
.1265 .32206 L
.16918 .32121 L
.21027 .32018 L
.25393 .31889 L
.296 .31747 L
.33648 .31597 L
.37953 .31424 L
.42099 .31249 L
.46086 .31075 L
.50331 .30887 L
.54416 .30706 L
.58759 .30517 L
.62943 .30342 L
.66967 .30183 L
.7125 .30026 L
.75372 .2989 L
.79336 .29775 L
.83558 .29672 L
.8762 .29593 L
.89683 .29561 L
.91939 .29533 L
.94095 .29512 L
.95057 .29505 L
.961 .29498 L
.96647 .29495 L
.97151 .29493 L
.97624 .29491 L
.98143 .2949 L
.98609 .29489 L
.99045 .29488 L
.99286 .29488 L
.99505 .29488 L
.99627 .29488 L
Mistroke
.99759 .29488 L
.99884 .29488 L
1 .29488 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4
o`000003oa0@4?oooooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`005_ooool6o`0000Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo
000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Co00000_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03
ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol0000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Kooooo0_l000000ol@413oooooooooo`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c00Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00`ooooo`Co000000?o410@oooooooo
ool04?ooool002Wooooo00?o0000ooooooooool0;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02Gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03;ooooo00?o0000oooo
ooooool04_ooool002Wooooo00?o0000ooooooooool0;Oooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h0:?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000V
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Oooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<_ooool00ol0
003oooooooooo`0Booooo`00:Oooool2o`0002kooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgo
ooooo`0002Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B409oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0b
ooooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo02Kooooo00Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0002Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`09oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<
o`000?l0003o0000olc<c00booooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooo
oooo02gooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo02Gooooo00Go
410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000002Oooooo00Go410@oooooooooooo
oooooa0@400;ooooo`03oeEEEOn7QhOooooo02Wooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?nj^[[ooooookZj^_l@4100<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0
003oooooooooo`0]ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000<_ooool00ol0003oooooooooo`0B
ooooo`00:Oooool00ol0003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<02Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMg
Mol0003ooooo02Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@
42Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<?oo
ool00omEEEGoIVIVo`00000Dooooo`00:Oooool2o`000?oooooo2?ooool4o`0000ooo`003Ol00002
ool001Cooooo000Yooooo`03o`000?oooooooooo0<cooooo2ol00007ool000ko00004?oo000:o`00
03Kooooo000Yooooo`03o`000?oooooooooo0;_ooooo00?o0000ool00?oo00000_oo000<o`0000;o
oooo2Ooo001Kooooo`;o00000_ooool2o`0000Cooooo000Yooooo`03o`000?oooooooooo0:?ooooo
3Ol0000<ool007Kooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`00:OoooonEo`00013o
o`00Q_l0000;ooooo`04omgMgOl0003o410@olc<c0Gooooo000Yooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool01?l0003oooooooooooooool=ool000Go00002?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0
02Wooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Qooooo`_oo`003_l00003ool0
0003o`000?oooooooooo03Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo00Wooooo00Co8B4QogMgMomgMgOo<S8b1Oooool002Wooooo00?o0000oooo
ooooool0?oooool3o`0000Ooo`003_l00005ool000Co0000d_ooool2o`0000;ooooo0_l00004oooo
o`00:Oooool00ol0003oo`00ool0000>ool000gooooo4?oo000>o`0000Woo`00n_ooool002Wooooo
8Ol0003ooooooaoooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o
0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o
0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooolmoooo
o`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo
1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`003_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgo
oooo000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o
0000oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05o`000?ooooooooooooooool0
00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmoooo
o`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0
003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEE
ojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000
ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool001oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qoooo
o`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIV
I_l00000oooooom7ooooo`00oooooomYooooo`00V?ooool2o`0000_ooooo00?o0000okZj^_ooool0
3?ooool2o`0000Kooooo00?o0000okZj^_ooool0ZOooool009Sooooo00?o0000ooooooooool02_oo
ool2oc8b<Pkooooo00?o0000ooooooooool01?ooool2oc8b<Z[ooooo002>ooooo`05oa0@4?l0003o
0000o`000?l@41001Oooool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000;ooooo00?o
QhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?o0000ooooooooool0
1?ooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X02_ooool4o`000003
oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM
07Wooooo002@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01_o^k^ko
8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mg
MgOo410@00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj
^[[ok^k^ogMgMol@41000_ooool6o`0000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo07Sooooo002@ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`1gooooo`00
T?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Cok^k^ob4Q8Ol@413o
k^k^2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01?ooool6o`0000Cooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03
ogMgMolb<S;ooooo07Sooooo002@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<07Wooooo002=ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`00
00Sooooo00?o410@o`000?l000000ol00004ooooo`03o`000?oooooooooo00Wooooo00?o410@o`00
0?l000000ol0000=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1kooooo`00SOooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001?ooool00ol0003oooooooooo`1kooooo`00SOooool7o`0000Cooooo0_l0000Coooo
o`03o`000?oooooooooo00Cooooo0_l0000=ooooo`03o`000?oooooooooo00cooooo00?oEEEEofIV
I_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0001jooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.13153, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .31678 m
.05556 .31678 L
.16667 .31585 L
.27778 .31409 L
.38889 .31171 L
.5 .30902 L
.61111 .30632 L
.72222 .30395 L
.83333 .30219 L
.94444 .30125 L
s
.94444 .30125 m
1 .30125 L
s
1 0 0 r
[ .05 .05 ] 0 setdash
0 .31665 m
.00123 .31665 L
.00236 .31665 L
.00365 .31665 L
.00488 .31665 L
.00706 .31665 L
.00942 .31665 L
.01203 .31664 L
.01479 .31664 L
.01975 .31663 L
.02486 .31663 L
.02966 .31662 L
.04057 .31659 L
.0517 .31655 L
.06188 .3165 L
.08481 .31638 L
.10474 .31624 L
.1265 .31605 L
.16918 .3156 L
.21027 .31504 L
.25393 .31435 L
.296 .31358 L
.33648 .31277 L
.37953 .31184 L
.42099 .31089 L
.46086 .30995 L
.50331 .30894 L
.54416 .30796 L
.58759 .30694 L
.62943 .306 L
.66967 .30514 L
.7125 .30429 L
.75372 .30356 L
.79336 .30294 L
.83558 .30238 L
.8762 .30196 L
.89683 .30178 L
.91939 .30163 L
.94095 .30152 L
.95057 .30148 L
.961 .30144 L
.96647 .30143 L
.97151 .30142 L
.97624 .30141 L
.98143 .3014 L
.98609 .30139 L
.99045 .30139 L
.99286 .30139 L
.99505 .30139 L
.99627 .30139 L
Mistroke
.99759 .30139 L
.99884 .30139 L
1 .30139 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4
o`000003oa0@4?oooooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`005_ooool6o`0000Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo
000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Co00000_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03
ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol0000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Kooooo0_l000000ol@413oooooooooo`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c00Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00`ooooo`Co000000?o410@oooooooo
ool04?ooool002Wooooo00?o0000ooooooooool0;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02Gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03;ooooo00?o0000oooo
ooooool04_ooool002Wooooo00?o0000ooooooooool0;Oooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h0:?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000V
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Oooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<_ooool00ol0
003oooooooooo`0Booooo`00:Oooool2o`0002kooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgo
ooooo`0002Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B409oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0b
ooooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo02Kooooo00Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0002Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`09oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<
o`000?l0003o0000olc<c00booooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooo
oooo02gooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo02Gooooo00Go
410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000002Oooooo00Go410@oooooooooooo
oooooa0@400;ooooo`03oeEEEOn7QhOooooo02Wooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?nj^[[ooooookZj^_l@4100<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0
003oooooooooo`0]ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000<_ooool00ol0003oooooooooo`0B
ooooo`00:Oooool00ol0003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<02Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMg
Mol0003ooooo02Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@
42Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<?oo
ool00omEEEGoIVIVo`00000Dooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3Uooooo`Oo00004?oo000>o`00013o
o`003?l00002ool000[ooooo0_l00002ooooo`;o00001?ooool002Wooooo00?o0000ooooooooool0
XooooolAo`0000coo`003_l0000@ool000Oo0000COooool01_o^k^ko8B4QohN7Qonj^[[o0000omgM
g@Cooooo000YoooooiKo00004?oo000=o`0000Coo`00M?l0000;ooooo`04omgMgOl0003o410@olc<
c0Gooooo000Yooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo2ooo000>o`00013oo`003Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool002Wo
oooo00?o0000ooooooooool07?ooool?ool000ko00004?oo000>o`0000Goo`001?l0000Dooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo00Wooooo00Co8B4QogMgMomgMgOo<S8b1Oooool002Wooooo00?o0000ool00?oo
00003_oo000@o`000?oooooo5Oooool2o`0000;ooooo0_l00004ooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo
?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooooooo
ool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgo
oooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`003_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000kooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`003_oo
ool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgo
oooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onY
ZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05
o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co000000?o410@ooooooooool00oooool0
0ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`?o0000oooooolmooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?ooooooJOooool009cooooo0_l0
000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00006ooooo`03o`000?nj^[[ooooo0:Gooooo002L
ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo00Cooooo0_lb<S:V
ooooo`00T_ooool01Ol@413o0000o`000?l0003o410@00Gooooo00?o0000ooooooooool00_ooool2
o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj
^P03ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`00
0?m4A4Co^[Zj00[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM07gooooo002Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41001Oooool01Ol@
413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@4004
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool6o`0000Cooooo00?o0000ooooooooool01?oo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0O?ooool009Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1kooooo`00U?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01?ooool6o`0000Cooooo00?o0000ooooooooool03_oo
ool00omgMgOo<S8booooo`1looooo`00U?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`0OOooool0097ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00002?ooool00ol@413o0000
o`000003o`0000Cooooo00?o0000ooooooooool02Oooool00ol@413o0000o`000003o`0000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`1oooooo`00TOooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo07oooooo002Aooooo`Oo00001?ooool2o`0001?ooooo00?o
0000ooooooooool01?ooool2o`0000gooooo00?o0000ooooooooool03?ooool00omEEEGoIVIVo`00
000=ooooo`Co0000O_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.13153, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .31323 m
.05556 .31323 L
.16667 .31272 L
.27778 .31177 L
.38889 .31048 L
.5 .30902 L
.61111 .30755 L
.72222 .30627 L
.83333 .30531 L
.94444 .3048 L
s
.94444 .3048 m
1 .3048 L
s
1 0 0 r
[ .05 .05 ] 0 setdash
0 .31314 m
.00123 .31314 L
.00236 .31314 L
.00365 .31314 L
.00488 .31313 L
.00706 .31313 L
.00942 .31313 L
.01203 .31313 L
.01479 .31313 L
.01975 .31313 L
.02486 .31312 L
.02966 .31312 L
.04057 .3131 L
.0517 .31308 L
.06188 .31306 L
.08481 .31299 L
.10474 .31291 L
.1265 .31281 L
.16918 .31257 L
.21027 .31227 L
.25393 .31189 L
.296 .31148 L
.33648 .31104 L
.37953 .31054 L
.42099 .31003 L
.46086 .30952 L
.50331 .30897 L
.54416 .30845 L
.58759 .3079 L
.62943 .30739 L
.66967 .30692 L
.7125 .30647 L
.75372 .30607 L
.79336 .30574 L
.83558 .30544 L
.8762 .30521 L
.89683 .30511 L
.91939 .30503 L
.94095 .30497 L
.95057 .30495 L
.961 .30493 L
.96647 .30492 L
.97151 .30492 L
.97624 .30491 L
.98143 .30491 L
.98609 .3049 L
.99045 .3049 L
.99286 .3049 L
.99505 .3049 L
.99627 .3049 L
Mistroke
.99759 .3049 L
.99884 .3049 L
1 .3049 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4
o`000003oa0@4?oooooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`005_ooool6o`0000Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo
000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Co00000_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03
ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol0000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Kooooo0_l000000ol@413oooooooooo`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c00Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00`ooooo`Co000000?o410@oooooooo
ool04?ooool002Wooooo00?o0000ooooooooool0;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02Gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03;ooooo00?o0000oooo
ooooool04_ooool002Wooooo00?o0000ooooooooool0;Oooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h0:?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000V
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Oooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<_ooool00ol0
003oooooooooo`0Booooo`00:Oooool2o`0002kooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgo
ooooo`0002Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B409oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0b
ooooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo02Kooooo00Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0002Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`09oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<
o`000?l0003o0000olc<c00booooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooo
oooo02gooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo02Gooooo00Go
410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000002Oooooo00Go410@oooooooooooo
oooooa0@400;ooooo`03oeEEEOn7QhOooooo02Wooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?nj^[[ooooookZj^_l@4100<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0
003oooooooooo`0]ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000<_ooool00ol0003oooooooooo`0B
ooooo`00:Oooool00ol0003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<02Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMg
Mol0003ooooo02Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@
42Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<?oo
ool00omEEEGoIVIVo`00000Dooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooooc?ooooo0_l00002ooooo`;o
00001?ooool002Wooooo00?o0000ooooooooool0a?oooolCo`0000Ooo`003_l0000@ool000ko0000
4?oo000>o`0000[ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`00:Ooooon2o`0000Ko
o`003_l0000@ool000go00004?oo000>o`0000Woo`00DOl0000;ooooo`04omgMgOl0003o410@olc<
c0Gooooo000Yooooo`03o`000?oo003oo`0000koo`003Oooool00ol0003oo`00ool0000=ool000ko
00004?oo000>o`00013oo`003_l0000:ool000?o000000?oooooo`000?ooool03Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool002Wo
oooo8Ol0000Jooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02Oooool01?lQ8B7o
MgMgogMgMolb<S85ooooo`00:Oooool00ol0003oooooooooo`3ooooooc?ooooo0_l00002ooooo`;o
00001?ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0
003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo
000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413o
oooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03oooo
o`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooo
oooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0
0006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`007oooool4
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`007oooool00omEEEGoIVIVo`00003oooooodOo
oooo003oooooofWooooo002Hooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001_oo
ool00ol0003o^[Zjooooo`2Yooooo`00V?ooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool0
0ol0003oooooooooo`04ooooo`;o<S8bZ_ooool008kooooo00Go410@o`000?l0003o0000oa0@4005
ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00000_ooool00on7QhOo0000okZj^P05
ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool00ol0003oooooooooo`04ooooo`03ohN7Qol0
003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`Co000000?o410@ooooooooool0
0_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM07Wo
oooo002@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01_o^k^ko8B4Q
ohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mgMgOo
410@00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41000_ooool6o`0000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?o
EEEEojVYZOooool01oooool00omgMgOo<S8booooo`1hooooo`00T?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0Moooool0093ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo1_l0
0004ooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8boooo
o`1hooooo`00T?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Co8B4Q
ogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c01iooooo`00SOooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l00008ooooo`03oa0@
4?l0003o000000?o00001?ooool00ol0003oooooooooo`09ooooo`03oa0@4?l0003o000000?o0000
3Oooool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0
Noooool008gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Co
oooo00?o0000ooooooooool0Noooool008gooooo1ol00004ooooo`;o00004oooool00ol0003ooooo
ooooo`04ooooo`;o00003Oooool00ol0003oooooooooo`0<ooooo`03oeEEEOmVIVKo000000cooooo
1Ol00004ooooo`Co0000N_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.13153, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .3113 m
.05556 .3113 L
.16667 .31103 L
.27778 .31051 L
.38889 .30981 L
.5 .30902 L
.61111 .30822 L
.72222 .30752 L
.83333 .30701 L
.94444 .30673 L
s
.94444 .30673 m
1 .30673 L
s
1 0 0 r
[ .05 .05 ] 0 setdash
0 .31124 m
.00123 .31124 L
.00236 .31124 L
.00365 .31124 L
.00488 .31124 L
.00706 .31124 L
.00942 .31124 L
.01203 .31124 L
.01479 .31124 L
.01975 .31124 L
.02486 .31123 L
.02966 .31123 L
.04057 .31122 L
.0517 .31121 L
.06188 .3112 L
.08481 .31116 L
.10474 .31112 L
.1265 .31107 L
.16918 .31093 L
.21027 .31077 L
.25393 .31057 L
.296 .31035 L
.33648 .31011 L
.37953 .30984 L
.42099 .30956 L
.46086 .30929 L
.50331 .30899 L
.54416 .30871 L
.58759 .30841 L
.62943 .30814 L
.66967 .30789 L
.7125 .30764 L
.75372 .30743 L
.79336 .30725 L
.83558 .30708 L
.8762 .30696 L
.89683 .30691 L
.91939 .30687 L
.94095 .30683 L
.95057 .30682 L
.961 .30681 L
.96647 .30681 L
.97151 .3068 L
.97624 .3068 L
.98143 .3068 L
.98609 .3068 L
.99045 .3068 L
.99286 .3068 L
.99505 .30679 L
.99627 .30679 L
Mistroke
.99759 .30679 L
.99884 .30679 L
1 .30679 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4
o`000003oa0@4?oooooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`005_ooool6o`0000Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo
000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Co00000_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03
ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol0000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Kooooo0_l000000ol@413oooooooooo`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c00Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00`ooooo`Co000000?o410@oooooooo
ool04?ooool002Wooooo00?o0000ooooooooool0;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02Gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03;ooooo00?o0000oooo
ooooool04_ooool002Wooooo00?o0000ooooooooool0;Oooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h0:?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000V
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Oooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<_ooool00ol0
003oooooooooo`0Booooo`00:Oooool2o`0002kooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgo
ooooo`0002Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B409oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0b
ooooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo02Kooooo00Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0002Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`09oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<
o`000?l0003o0000olc<c00booooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooo
oooo02gooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo02Gooooo00Go
410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000002Oooooo00Go410@oooooooooooo
oooooa0@400;ooooo`03oeEEEOn7QhOooooo02Wooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?nj^[[ooooookZj^_l@4100<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0
003oooooooooo`0]ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000<_ooool00ol0003oooooooooo`0B
ooooo`00:Oooool00ol0003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<02Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMg
Mol0003ooooo02Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@
42Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<?oo
ool00omEEEGoIVIVo`00000Dooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooooc?ooooo0_l00002ooooo`;o
00001?ooool002Wooooo00?o0000ooooooooool0oooooolcooooo`06onk^k_lQ8B7oQhN7okZj^_l0
003ogMgM1?ooool002WoooooN?l0000@ool000ko00004?oo000=o`00013oo`003_l0000@ool000ko
00004?oo000>o`00013oo`003_l0000;ooooo`04omgMgOl0003o410@olc<c0Gooooo000Yooooo`03
o`000?oo003oo`0000koo`003_l0000?ool000ko00004?oo000>o`00013oo`003Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`09ooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Yooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`09ooooo`04ob4Q8OmgMgOoMgMgoc8b
<PGooooo000Yooooo`03o`000?oooooooooo0?oooooo<oooool2o`0000;ooooo0_l00004ooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wo
oooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooo
ocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000kooooo00Go
0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`00
3_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Ko
oooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003ooooo
ocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003o
oooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo
410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooo
oooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0
003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`?o
0000oooooolmooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?oooooo
JOooool00:3ooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00005ooooo`03o`000?nj
^[[ooooo0:;ooooo002Pooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooo
oooo00?ooooo0_lb<S:Sooooo`00UOooool01Ol@413o0000o`000?l0003o410@00Kooooo00Co0000
oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0
003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`03ooooo`03ohN7Qol0003o^[Zj00Gooooo
00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`Go00001Oooool2ob4Q8H?ooooo002Gooooo`03o`00
0?oooooooooo00Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0ooo
ool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ooooo
ooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`00
00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4QPoooool009Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?oV9RH
ob4Q8Oo^k^h0Roooool009Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02oooo
o`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00?ooooo1_l00004ooooo`03oiRHV?lQ8B7ok^k^08[ooooo002Goooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>
ooooo`03ogMgMomVIVKooooo08Wooooo002Dooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0
003o000000?o00001Oooool00ol0003oooooooooo`09ooooo`03oa0@4?l0003o000000?o00003_oo
ool00ol0003oooooooooo`28ooooo`00U?ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02oooool01Ol0003o^[ZjoooooonHV9So410@08[ooooo
002Dooooo`Oo00001Oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0000gooooo00?o
0000ooooooooool02oooool01OnHV9So410@o`000?lQ8B7oc<c<08[ooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.13153, \
0.00419705, 0.0135819}}]
}, Closed]]
}, Open  ]],

Cell["\<\
The close agreement between the numerical result (solid) and the \
exact solution (dashed) speaks for itself.\
\>", "Text"],

Cell[TextData[{
  "\tMixed boundary conditions are more of a challenge. Now both the function \
and its derivative are required on the boundary. For example, at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " the general mixed boundary condition is of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Kappa] \[PartialD]T/\[PartialD]x\)\( | \_\(x = 
                0\)\)\) = a\ [T(0, t) - \[Tau]]\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa], \ a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)]],
  " are given constants. How do we obtain second-order-accurate values for \
both ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " and its derivative at the boundary point?"
}], "Text"],

Cell[TextData[{
  "\tSince the boundary at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " falls halfway between the ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j = 1\)]],
  " grid points, one  simple approach  is to  use the average value, ",
  Cell[BoxData[
      \(TraditionalForm\`\(1\/2\) \((T\_0\%n + T\_1\%n)\)\)]],
  ", to approximate ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0. \)]],
  " We still use the centered-difference form for the first derivative for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]T/\[PartialD]x\)\( | \_\(x = 
              0\)\)\)\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ", so the mixed boundary condition becomes"
}], "Text"],

Cell[TextData[{
  "\[Kappa] ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(T\_1\%n - T\_0\%n\), 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]], 
          "=", \(a[\(1\/2\) \((T\_0\%n + T\_1\%n)\) - \[Tau]]\)}], 
        TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.22)"],

Cell[TextData[{
  "Solving for ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\_0\%n\), Cell[""]}], TraditionalForm]]],
  " yields "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\_0\%n\), "=", 
          FractionBox[
            RowBox[{
              RowBox[{"2", " ", "a", " ", "\[Tau]", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{\(2  \[Kappa]\), " ", "-", 
                    RowBox[{"a", " ", 
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]]}]}], 
                  ")"}], \(T\_1\%n\)}]}], 
            RowBox[{\(2\ \[Kappa]\), "+", 
              RowBox[{"a", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]]}]}]]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.23)"],

Cell[TextData[{
  "Similarly, for a mixed boundary condition at ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x = L\)\(,\)\)\)]],
  " namely ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Kappa] \[PartialD]T/\[PartialD]x\)\( | \_\(x = 
                L\)\)\) = \(-b\)\ \((T(L, t) - \[Tau])\)\)]],
  ", we take a grid for which ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  " falls halfway between gridpoints ",
  Cell[BoxData[
      \(TraditionalForm\`M - 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ", so that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(T\)\( | \_\(x = 
                L\)\)\) = \(1\/2\) \((T\_M\%n + \ T\_\(M - 1\)\%n)\)\)]],
  ". Then the boundary condition is "
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[Kappa]", 
          FormBox[
            RowBox[{
              FractionBox[\(T\_M\%n - T\_\(M - 1\)\%n\), 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]]], 
              "=", \(-b[\(1\/2\) \((T\_\(M - 1\)\%n + 
                          T\_M\%n)\) - \[Tau]]\)}],
            "TraditionalForm"]}], ","}], TraditionalForm]]]], "NE2",
  CellTags->"(6.2.24)"],

Cell["which leads to ", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(T\_M\%n\), "=", 
        RowBox[{
          FractionBox[
            RowBox[{
              RowBox[{"2", " ", "b", " ", "\[Tau]", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{\(2  \[Kappa]\), " ", "-", 
                    RowBox[{"b", " ", 
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]]}]}], 
                  ")"}], \(T\_\(M - 1\)\%n\)}]}], 
            RowBox[{\(2\ \[Kappa]\), "+", 
              RowBox[{"b", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]]}]}]], "."}]}], 
      TraditionalForm]]]], "NE2",
  CellTags->"(6.2.25)"],

Cell["\<\
Implementation of these boundary conditions follows the same course \
as in our previous examples, and is left to the exercises.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Multiple Spatial Dimensions", "Section",
  CellTags->"c:21"],

Cell[CellGroupData[{

Cell["Explicit Methods", "Subsubsection"],

Cell["\<\
The explicit methods discussed previously generalize easily to PDEs \
in multiple spatial dimensions. Continuing with our heat equation model, we \
now consider the problem in two dimensions:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\/\[PartialD]t\) \(T(x, y, 
            t)\) = \[Chi]\ \((\[PartialD]\^2\/\[PartialD]x\^2 + \
\[PartialD]\^2\/\[PartialD]y\^2)\) \(T(x, y, t)\) + S(x, y, t)\)]],
  "."
}], "NE2",
  CellTags->"(6.2.26)"],

Cell[TextData[{
  "For simplicity, we take the boundary to be a rectangular box of sides ",
  Cell[BoxData[
      \(TraditionalForm\`L\_x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`L\_y\)]],
  ", and create a rectangular spatial grid in ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " according to"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(x\_j\), "=", 
            RowBox[{"j", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}]}], ",", " ", \(j = 0\), ",", 
          "1", ",", "2", ",", "...", ",", \(M\_x\)}], TraditionalForm]]],
  ",\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(y\_k\), "=", 
            RowBox[{"k", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]]}]}], ",", " ", \(k = 0\), ",", 
          "1", ",", "2", ",", "...", ",", \(M\_y\)}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.27)"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"where", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}], " ", "=", " ", \(L\_x/M\_x\)}], 
        TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["y",
                FontSlant->"Italic"]}]], " ", "=", " ", \(L\_y/M\_y\)}], 
        TraditionalForm]]],
  ". (Nonrectangular boundaries are treated in Sec. ",
  ButtonBox["6.2.2",
    ButtonData:>"c:22",
    ButtonStyle->"Hyperlink"],
  ".)"
}], "Text"],

Cell["\<\
\t The FTCS method on this grid is a trivial extension of the \
method in one-dimension:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\_\(j\ k\)\%\(n + 1\)\), "=", 
          RowBox[{\(T\_\(j\ k\)\%n\), "+", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], " ", \(S\_\(j\ k\)\%n\)}], "+", 
            RowBox[{
              FractionBox[
                RowBox[{"\[Chi]", " ", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]]}], 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], 
                  "2"]], \((T\_\(j + 1\ k\)\%n - 2  T\_\(j\ k\)\%n + 
                  T\_\(j - 1\ k\)\%\(\(\ \)\(n\)\))\)}], "+", 
            RowBox[{
              FractionBox[
                RowBox[{"\[Chi]", " ", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]]}], 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["y",
                        FontSlant->"Italic"]}]], 
                  "2"]], \((T\_\(j\ k + 1\)\%n - 2  T\_\(j\ k\)\%n + 
                  T\_\(j\ k - 1\)\%\(\(\ \)\(n\)\)\ )\)}]}]}], 
        TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.28)"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(6.2.28)",
    ButtonData:>"(6.2.28)",
    ButtonStyle->"Hyperlink"],
  " is valid for the points interior to the rectangle, and must be \
supplemented by boundary conditions that determine the points on the \
boundary, as well as by initial conditions specifying ",
  Cell[BoxData[
      \(TraditionalForm\`T\_\(j\ k\)\%\(\(\ \)\(0\)\)\)]],
  ".von Neumann stability analysis for this difference equation considers the \
stability of  a Fourier mode of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[Xi]\^n\ \(\[ExponentialE]\^\(\[ImaginaryI]\ \(k\_x\
\) x\)\) \[ExponentialE]\^\(\[ImaginaryI]\ k\_y\ y\)\)]],
  ", and leads to a Courant condition that"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[Chi]", " ", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]]}], "\[LessEqual]", " ", 
        RowBox[{\(1\/2\), 
          SuperscriptBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], "2"], 
          FractionBox[
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]], "2"], 
            RowBox[{
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"], "+", 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["y",
                      FontSlant->"Italic"]}]], "2"]}]]}]}], 
      TraditionalForm]]]], "NE2",
  CellTags->"(6.2.29)"],

Cell["\<\
(see the exercises).  The other explicit methods discussed \
previously, CTCS and Lax, also can be easily extended to multiple dimensions. \
\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example: Wave Equation with Nonuniform Wave Speed", "Subsubsection",
  CellTags->"i:26"],

Cell["\<\
As an example of an explicit method in two dimensions,  we \
construct the numerical solution to a wave equation in two dimensions with \
nonuniform wave speed, \
\>", "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\^2\/\((\[PartialD]t)\)\^2\) \(z(x, y, 
            t)\) = \(\(c\^2\)(x, 
              y)\)\ [\[PartialD]\^2\/\[PartialD]x\^2 + \[PartialD]\^2\/\
\[PartialD]y\^2] \(z(x, y, t)\)\)]],
  ","
}], "Text"],

Cell[TextData[{
  "with initial conditions ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, y, 0) = \(z\_o\)(x, y), \ \(z\& . \)(x, y, 
          0) = \(v\_o\)(x, y)\)]],
  ". Here we take the simple case ",
  Cell[BoxData[
      \(TraditionalForm\`z\_o = \(v\_o = 0\)\)]],
  ". For boundary conditions",
  ",",
  " we choose a square domain with unit sides and take an oscillating \
boundary condition,"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`z(0, y, t) = \(z(1, y, t) = \(z(x, 1, t) = 0\)\); \ 
      z(x, 0, t) = \(x(1 - x)\) sin\ 2  t\)]],
  ". "
}], "Text"],

Cell["\tFor the wave speed, we choose ", "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`c(x, y)\  = 
        1\/10\ \((1\  - 
              0.7\ exp[\(-2\) \((x - 0.5)\)\^2 - 5 \((y - 0.5)\)\^2])\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "The wave speed, plotted in Cell ",
  ButtonBox["6.72",
    ButtonData:>"Cell 6.72",
    ButtonStyle->"Hyperlink"],
  ",  has a minimum at the center of the box."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear["\<Global`*\>"];\)\n\), "\[IndentingNewLine]", 
    \(\(cw[x_, y_]\  = \ 
        1/10\ \((1\  -  .7\ Exp[\(-2\) \((x - 0.5)\)\^2 - 
                    5 \((y - 0.5)\)\^2])\);\)\n\), "\[IndentingNewLine]", 
    \(\(Plot3D[cw[x, y], {x, 0, 1}, {y, 0, 1}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
        PlotLabel -> "\<wave speed\>"];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.72"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.5 .82364 -32.0625 0 ]
[.5 .82364 32.0625 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.29165 .07573 -9.31117 -12 ]
[.29165 .07573 .68883 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.91861 .21225 0 -8.04169 ]
[.91861 .21225 10 3.95831 ]
[.01831 .30146 -24 -2.77304 ]
[.01831 .30146 0 6.22696 ]
[.00629 .37681 -24 -2.83694 ]
[.00629 .37681 0 6.16306 ]
[-0.00633 .45589 -24 -2.90433 ]
[-0.00633 .45589 0 6.09567 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -93.0625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(wave) show
93.125 13.000 moveto
(speed) show
123.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
gsave
.91861 .21225 -61 -12.0417 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03056 .29676 m
.03669 .29441 L
s
[(0.04)] .01831 .30146 1 -0.38377 Mshowa
.0186 .37226 m
.02475 .36998 L
s
[(0.06)] .00629 .37681 1 -0.36957 Mshowa
.00604 .4515 m
.01223 .44931 L
s
[(0.08)] -0.00633 .45589 1 -0.35459 Mshowa
.125 Mabswid
.02763 .3153 m
.03131 .3139 L
s
.02465 .33406 m
.02834 .33267 L
s
.02164 .35304 m
.02533 .35167 L
s
.01552 .39171 m
.01921 .39035 L
s
.0124 .41139 m
.0161 .41005 L
s
.00924 .43132 m
.01295 .43 L
s
.03347 .27844 m
.03714 .27702 L
s
.03634 .26033 m
.04 .2589 L
s
.0028 .47193 m
.00652 .47063 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.696 .653 .803 r
.37539 .76904 .39806 .80578 .43711 .78916 .41473 .74956 Metetra
.691 .64 .794 r
.41473 .74956 .43711 .78916 .47659 .77263 .45444 .73029 Metetra
.683 .627 .787 r
.45444 .73029 .47659 .77263 .51651 .7565 .49454 .71163 Metetra
.675 .616 .782 r
.49454 .71163 .51651 .7565 .5569 .74104 .53506 .69397 Metetra
.665 .605 .778 r
.53506 .69397 .5569 .74104 .59781 .72653 .57605 .67767 Metetra
.655 .595 .776 r
.57605 .67767 .59781 .72653 .63928 .71318 .61759 .66303 Metetra
.645 .587 .776 r
.61759 .66303 .63928 .71318 .68139 .70112 .65977 .65024 Metetra
.634 .581 .777 r
.65977 .65024 .68139 .70112 .7242 .69042 .70267 .63938 Metetra
.624 .577 .781 r
.70267 .63938 .7242 .69042 .76779 .68105 .74638 .63042 Metetra
.615 .575 .786 r
.74638 .63042 .76779 .68105 .81222 .67289 .791 .62319 Metetra
.606 .575 .793 r
.791 .62319 .81222 .67289 .85755 .66575 .83659 .61744 Metetra
.599 .578 .801 r
.83659 .61744 .85755 .66575 .90381 .65938 .88321 .61283 Metetra
.594 .584 .811 r
.88321 .61283 .90381 .65938 .95103 .6535 .9309 .60896 Metetra
.591 .593 .822 r
.9309 .60896 .95103 .6535 .99922 .6478 .97966 .60542 Metetra
.705 .645 .787 r
.35246 .72906 .37539 .76904 .41473 .74956 .39211 .70638 Metetra
.698 .632 .779 r
.39211 .70638 .41473 .74956 .45444 .73029 .43206 .68403 Metetra
.689 .618 .772 r
.43206 .68403 .45444 .73029 .49454 .71163 .47233 .66254 Metetra
.679 .606 .767 r
.47233 .66254 .49454 .71163 .53506 .69397 .51296 .64242 Metetra
.668 .594 .763 r
.51296 .64242 .53506 .69397 .57605 .67767 .55401 .62415 Metetra
.656 .583 .762 r
.55401 .62415 .57605 .67767 .61759 .66303 .59558 .6081 Metetra
.643 .574 .762 r
.59558 .6081 .61759 .66303 .65977 .65024 .63777 .59452 Metetra
.63 .566 .764 r
.63777 .59452 .65977 .65024 .70267 .63938 .68069 .58351 Metetra
.617 .56 .768 r
.68069 .58351 .70267 .63938 .74638 .63042 .72447 .57502 Metetra
.605 .556 .773 r
.72447 .57502 .74638 .63042 .791 .62319 .76921 .56887 Metetra
.594 .555 .78 r
.76921 .56887 .791 .62319 .83659 .61744 .81501 .5647 Metetra
.585 .557 .789 r
.81501 .5647 .83659 .61744 .88321 .61283 .86195 .56209 Metetra
.578 .562 .8 r
.86195 .56209 .88321 .61283 .9309 .60896 .91006 .56053 Metetra
.574 .57 .812 r
.91006 .56053 .9309 .60896 .97966 .60542 .95936 .55948 Metetra
.715 .645 .778 r
.32924 .68736 .35246 .72906 .39211 .70638 .36922 .66134 Metetra
.707 .631 .77 r
.36922 .66134 .39211 .70638 .43206 .68403 .40944 .63579 Metetra
.698 .618 .764 r
.40944 .63579 .43206 .68403 .47233 .66254 .4499 .61137 Metetra
.686 .604 .759 r
.4499 .61137 .47233 .66254 .51296 .64242 .49066 .58872 Metetra
.673 .592 .757 r
.49066 .58872 .51296 .64242 .55401 .62415 .53177 .56842 Metetra
.658 .58 .756 r
.53177 .56842 .55401 .62415 .59558 .6081 .57335 .55091 Metetra
.643 .569 .757 r
.57335 .55091 .59558 .6081 .63777 .59452 .61553 .53652 Metetra
.627 .56 .759 r
.61553 .53652 .63777 .59452 .68069 .58351 .65845 .52535 Metetra
.611 .552 .763 r
.65845 .52535 .68069 .58351 .72447 .57502 .70225 .51736 Metetra
.596 .546 .769 r
.70225 .51736 .72447 .57502 .76921 .56887 .74708 .51229 Metetra
.582 .544 .777 r
.74708 .51229 .76921 .56887 .81501 .5647 .79305 .50976 Metetra
.571 .544 .786 r
.79305 .50976 .81501 .5647 .86195 .56209 .84026 .50921 Metetra
.561 .547 .796 r
.84026 .50921 .86195 .56209 .91006 .56053 .88876 .51003 Metetra
.555 .555 .809 r
.88876 .51003 .91006 .56053 .95936 .55948 .93857 .51156 Metetra
.728 .653 .775 r
.3056 .64602 .32924 .68736 .36922 .66134 .34597 .61681 Metetra
.72 .64 .768 r
.34597 .61681 .36922 .66134 .40944 .63579 .3865 .58823 Metetra
.709 .627 .763 r
.3865 .58823 .40944 .63579 .4499 .61137 .42721 .56104 Metetra
.696 .613 .76 r
.42721 .56104 .4499 .61137 .49066 .58872 .46812 .53599 Metetra
.681 .6 .759 r
.46812 .53599 .49066 .58872 .53177 .56842 .50933 .51376 Metetra
.664 .587 .759 r
.50933 .51376 .53177 .56842 .57335 .55091 .55096 .49487 Metetra
.646 .575 .761 r
.55096 .49487 .57335 .55091 .61553 .53652 .59316 .47968 Metetra
.626 .564 .764 r
.59316 .47968 .61553 .53652 .65845 .52535 .63609 .46833 Metetra
.607 .554 .769 r
.63609 .46833 .65845 .52535 .70225 .51736 .67992 .46076 Metetra
.588 .546 .776 r
.67992 .46076 .70225 .51736 .74708 .51229 .72483 .45668 Metetra
.57 .541 .783 r
.72483 .45668 .74708 .51229 .79305 .50976 .77096 .45562 Metetra
.555 .54 .793 r
.77096 .45562 .79305 .50976 .84026 .50921 .81841 .45696 Metetra
.542 .542 .803 r
.81841 .45696 .84026 .50921 .88876 .51003 .86727 .45997 Metetra
.534 .548 .815 r
.86727 .45997 .88876 .51003 .93857 .51156 .91755 .46387 Metetra
.744 .672 .78 r
.28134 .60739 .3056 .64602 .34597 .61681 .32215 .57548 Metetra
.736 .66 .775 r
.32215 .57548 .34597 .61681 .3865 .58823 .36307 .54431 Metetra
.725 .647 .772 r
.36307 .54431 .3865 .58823 .42721 .56104 .40408 .51476 Metetra
.711 .635 .771 r
.40408 .51476 .42721 .56104 .46812 .53599 .44524 .48767 Metetra
.694 .622 .771 r
.44524 .48767 .46812 .53599 .50933 .51376 .48663 .46379 Metetra
.674 .608 .773 r
.48663 .46379 .50933 .51376 .55096 .49487 .52838 .44369 Metetra
.652 .595 .777 r
.52838 .44369 .55096 .49487 .59316 .47968 .57067 .42778 Metetra
.629 .582 .782 r
.57067 .42778 .59316 .47968 .63609 .46833 .61368 .4162 Metetra
.604 .57 .789 r
.61368 .4162 .63609 .46833 .67992 .46076 .6576 .40889 Metetra
.579 .559 .796 r
.6576 .40889 .67992 .46076 .72483 .45668 .70263 .40552 Metetra
.556 .551 .804 r
.70263 .40552 .72483 .45668 .77096 .45562 .74893 .40559 Metetra
.536 .547 .813 r
.74893 .40559 .77096 .45562 .81841 .45696 .79663 .40839 Metetra
.52 .547 .823 r
.79663 .40839 .81841 .45696 .86727 .45997 .84583 .41312 Metetra
.509 .551 .834 r
.84583 .41312 .86727 .45997 .91755 .46387 .89657 .41891 Metetra
.762 .701 .794 r
.2562 .57368 .28134 .60739 .32215 .57548 .29751 .5398 Metetra
.755 .692 .791 r
.29751 .5398 .32215 .57548 .36307 .54431 .33888 .50676 Metetra
.745 .683 .791 r
.33888 .50676 .36307 .54431 .40408 .51476 .3803 .47549 Metetra
.731 .672 .793 r
.3803 .47549 .40408 .51476 .44524 .48767 .4218 .4469 Metetra
.712 .661 .797 r
.4218 .4469 .44524 .48767 .48663 .46379 .46348 .42177 Metetra
.69 .648 .803 r
.46348 .42177 .48663 .46379 .52838 .44369 .50548 .40073 Metetra
.664 .634 .81 r
.50548 .40073 .52838 .44369 .57067 .42778 .54798 .38419 Metetra
.634 .62 .818 r
.54798 .38419 .57067 .42778 .61368 .4162 .59118 .37232 Metetra
.602 .605 .827 r
.59118 .37232 .61368 .4162 .6576 .40889 .63529 .36504 Metetra
.57 .591 .835 r
.63529 .36504 .6576 .40889 .70263 .40552 .68052 .36201 Metetra
.539 .579 .844 r
.68052 .36201 .70263 .40552 .74893 .40559 .72706 .36268 Metetra
.512 .571 .852 r
.72706 .36268 .74893 .40559 .79663 .40839 .77507 .36632 Metetra
.491 .566 .86 r
.77507 .36632 .79663 .40839 .84583 .41312 .82463 .37205 Metetra
.477 .567 .868 r
.82463 .37205 .84583 .41312 .89657 .41891 .87581 .37895 Metetra
.783 .743 .816 r
.22988 .54647 .2562 .57368 .29751 .5398 .27174 .51157 Metetra
.778 .739 .817 r
.27174 .51157 .29751 .5398 .33888 .50676 .31364 .47754 Metetra
.769 .735 .822 r
.31364 .47754 .33888 .50676 .3803 .47549 .35555 .44534 Metetra
.755 .73 .829 r
.35555 .44534 .3803 .47549 .4218 .4469 .39752 .4159 Metetra
.736 .723 .839 r
.39752 .4159 .4218 .4469 .46348 .42177 .43963 .39003 Metetra
.711 .714 .851 r
.43963 .39003 .46348 .42177 .50548 .40073 .48202 .36837 Metetra
.679 .702 .864 r
.48202 .36837 .50548 .40073 .54798 .38419 .52489 .35133 Metetra
.64 .687 .878 r
.52489 .35133 .54798 .38419 .59118 .37232 .56843 .33909 Metetra
.597 .669 .89 r
.56843 .33909 .59118 .37232 .63529 .36504 .61288 .33155 Metetra
.552 .65 .899 r
.61288 .33155 .63529 .36504 .68052 .36201 .65844 .32839 Metetra
.51 .631 .906 r
.65844 .32839 .68052 .36201 .72706 .36268 .70534 .32904 Metetra
.474 .615 .91 r
.70534 .32904 .72706 .36268 .77507 .36632 .75372 .33273 Metetra
.447 .604 .913 r
.75372 .33273 .77507 .36632 .82463 .37205 .8037 .33859 Metetra
.432 .599 .915 r
.8037 .33859 .82463 .37205 .87581 .37895 .85534 .34564 Metetra
.802 .796 .847 r
.20211 .52644 .22988 .54647 .27174 .51157 .24455 .49153 Metetra
.799 .8 .852 r
.24455 .49153 .27174 .51157 .31364 .47754 .28702 .45746 Metetra
.792 .805 .862 r
.28702 .45746 .31364 .47754 .35555 .44534 .32952 .42518 Metetra
.779 .808 .876 r
.32952 .42518 .35555 .44534 .39752 .4159 .37207 .3956 Metetra
.758 .81 .894 r
.37207 .3956 .39752 .4159 .43963 .39003 .41475 .36953 Metetra
.727 .809 .915 r
.41475 .36953 .43963 .39003 .48202 .36837 .45771 .34758 Metetra
.686 .802 .937 r
.45771 .34758 .48202 .36837 .52489 .35133 .50111 .33017 Metetra
.633 .787 .956 r
.50111 .33017 .52489 .35133 .56843 .33909 .54518 .31747 Metetra
.571 .763 .969 r
.54518 .31747 .56843 .33909 .61288 .33155 .59013 .30939 Metetra
.507 .734 .975 r
.59013 .30939 .61288 .33155 .65844 .32839 .6362 .3056 Metetra
.449 .702 .975 r
.6362 .3056 .65844 .32839 .70534 .32904 .68358 .30553 Metetra
.404 .674 .971 r
.68358 .30553 .70534 .32904 .75372 .33273 .73245 .30845 Metetra
.376 .654 .965 r
.73245 .30845 .75372 .33273 .8037 .33859 .78293 .31347 Metetra
.366 .642 .962 r
.78293 .31347 .8037 .33859 .85534 .34564 .83509 .31965 Metetra
.812 .853 .88 r
.17268 .51318 .20211 .52644 .24455 .49153 .2157 .47923 Metetra
.81 .867 .89 r
.2157 .47923 .24455 .49153 .28702 .45746 .25879 .44603 Metetra
.802 .882 .904 r
.25879 .44603 .28702 .45746 .32952 .42518 .30195 .41448 Metetra
.785 .896 .922 r
.30195 .41448 .32952 .42518 .37207 .3956 .34518 .38544 Metetra
.756 .906 .943 r
.34518 .38544 .37207 .3956 .41475 .36953 .38857 .35967 Metetra
.71 .909 .965 r
.38857 .35967 .41475 .36953 .45771 .34758 .43223 .33776 Metetra
.647 .901 .983 r
.43223 .33776 .45771 .34758 .50111 .33017 .47635 .3201 Metetra
.567 .877 .993 r
.47635 .3201 .50111 .33017 .54518 .31747 .52112 .30685 Metetra
.479 .838 .994 r
.52112 .30685 .54518 .31747 .59013 .30939 .56676 .29794 Metetra
.396 .792 .987 r
.56676 .29794 .59013 .30939 .6362 .3056 .61349 .29303 Metetra
.329 .747 .977 r
.61349 .29303 .6362 .3056 .68358 .30553 .66152 .2916 Metetra
.288 .711 .97 r
.66152 .2916 .68358 .30553 .73245 .30845 .71101 .29295 Metetra
.272 .688 .969 r
.71101 .29295 .73245 .30845 .78293 .31347 .76209 .29622 Metetra
.28 .677 .971 r
.76209 .29622 .78293 .31347 .83509 .31965 .81484 .30054 Metetra
.806 .904 .91 r
.1415 .50531 .17268 .51318 .2157 .47923 .18507 .47312 Metetra
.8 .924 .919 r
.18507 .47312 .2157 .47923 .25879 .44603 .22879 .44155 Metetra
.783 .943 .93 r
.22879 .44155 .25879 .44603 .30195 .41448 .27264 .41141 Metetra
.751 .957 .939 r
.27264 .41141 .30195 .41448 .34518 .38544 .31663 .38348 Metetra
.699 .961 .945 r
.31663 .38348 .34518 .38544 .38857 .35967 .36082 .35844 Metetra
.624 .948 .941 r
.36082 .35844 .38857 .35967 .43223 .33776 .40533 .33684 Metetra
.529 .915 .928 r
.40533 .33684 .43223 .33776 .47635 .3201 .45031 .31903 Metetra
.423 .864 .905 r
.45031 .31903 .47635 .3201 .52112 .30685 .49594 .30516 Metetra
.323 .807 .881 r
.49594 .30516 .52112 .30685 .56676 .29794 .54244 .29515 Metetra
.243 .753 .865 r
.54244 .29515 .56676 .29794 .61349 .29303 .59 .28872 Metetra
.19 .714 .863 r
.59 .28872 .61349 .29303 .66152 .2916 .63882 .28536 Metetra
.168 .691 .876 r
.63882 .28536 .66152 .2916 .71101 .29295 .68907 .28444 Metetra
.176 .685 .901 r
.68907 .28444 .71101 .29295 .76209 .29622 .74087 .2852 Metetra
.207 .69 .931 r
.74087 .2852 .76209 .29622 .81484 .30054 .79429 .28682 Metetra
.781 .935 .931 r
.10857 .50072 .1415 .50531 .18507 .47312 .15266 .47084 Metetra
.765 .955 .935 r
.15266 .47084 .18507 .47312 .22879 .44155 .197 .44143 Metetra
.734 .969 .933 r
.197 .44143 .22879 .44155 .27264 .41141 .24155 .41317 Metetra
.683 .97 .923 r
.24155 .41317 .27264 .41141 .31663 .38348 .28633 .38674 Metetra
.607 .952 .901 r
.28633 .38674 .31663 .38348 .36082 .35844 .33139 .36274 Metetra
.512 .914 .866 r
.33139 .36274 .36082 .35844 .40533 .33684 .37683 .34164 Metetra
.406 .858 .822 r
.37683 .34164 .40533 .33684 .45031 .31903 .42277 .32374 Metetra
.303 .796 .781 r
.42277 .32374 .45031 .31903 .49594 .30516 .4694 .30919 Metetra
.217 .739 .752 r
.4694 .30919 .49594 .30516 .54244 .29515 .51688 .2979 Metetra
.156 .696 .742 r
.51688 .2979 .54244 .29515 .59 .28872 .5654 .28963 Metetra
.123 .673 .755 r
.5654 .28963 .59 .28872 .63882 .28536 .61515 .28393 Metetra
.12 .67 .789 r
.61515 .28393 .63882 .28536 .68907 .28444 .66628 .28026 Metetra
.144 .683 .837 r
.66628 .28026 .68907 .28444 .74087 .2852 .7189 .27794 Metetra
.19 .705 .889 r
.7189 .27794 .74087 .2852 .79429 .28682 .77309 .27627 Metetra
.747 .944 .947 r
.07404 .49701 .10857 .50072 .15266 .47084 .1186 .46969 Metetra
.724 .96 .944 r
.1186 .46969 .15266 .47084 .197 .44143 .16351 .44268 Metetra
.685 .966 .932 r
.16351 .44268 .197 .44143 .24155 .41317 .20875 .41652 Metetra
.625 .957 .909 r
.20875 .41652 .24155 .41317 .28633 .38674 .25433 .39179 Metetra
.545 .929 .873 r
.25433 .39179 .28633 .38674 .33139 .36274 .30027 .36896 Metetra
.453 .883 .828 r
.30027 .36896 .33139 .36274 .37683 .34164 .34667 .34844 Metetra
.358 .828 .78 r
.34667 .34844 .37683 .34164 .42277 .32374 .39365 .33048 Metetra
.274 .773 .742 r
.39365 .33048 .42277 .32374 .4694 .30919 .44133 .31519 Metetra
.208 .729 .719 r
.44133 .31519 .4694 .30919 .51688 .2979 .48988 .30251 Metetra
.165 .7 .719 r
.48988 .30251 .51688 .2979 .5654 .28963 .53947 .29222 Metetra
.148 .69 .74 r
.53947 .29222 .5654 .28963 .61515 .28393 .59024 .28397 Metetra
.156 .698 .782 r
.59024 .28397 .61515 .28393 .66628 .28026 .64233 .27727 Metetra
.188 .718 .836 r
.64233 .27727 .66628 .28026 .7189 .27794 .69586 .27159 Metetra
.239 .743 .892 r
.69586 .27159 .7189 .27794 .77309 .27627 .75091 .26633 Metetra
.716 .935 .96 r
.0381 .4919 .07404 .49701 .1186 .46969 .08308 .4671 Metetra
.693 .95 .956 r
.08308 .4671 .1186 .46969 .16351 .44268 .12852 .44243 Metetra
.656 .955 .945 r
.12852 .44243 .16351 .44268 .20875 .41652 .17441 .41835 Metetra
.603 .947 .923 r
.17441 .41835 .20875 .41652 .25433 .39179 .22074 .39528 Metetra
.537 .924 .892 r
.22074 .39528 .25433 .39179 .30027 .36896 .26756 .37361 Metetra
.463 .89 .855 r
.26756 .37361 .30027 .36896 .34667 .34844 .31492 .35365 Metetra
.389 .849 .819 r
.31492 .35365 .34667 .34844 .39365 .33048 .36293 .3356 Metetra
.325 .81 .792 r
.36293 .3356 .39365 .33048 .44133 .31519 .4117 .31955 Metetra
.277 .779 .779 r
.4117 .31955 .44133 .31519 .48988 .30251 .46135 .30544 Metetra
.249 .762 .784 r
.46135 .30544 .48988 .30251 .53947 .29222 .51204 .2931 Metetra
.242 .758 .807 r
.51204 .2931 .53947 .29222 .59024 .28397 .56389 .28225 Metetra
.256 .766 .844 r
.56389 .28225 .59024 .28397 .64233 .27727 .61701 .2725 Metetra
.288 .781 .889 r
.61701 .2725 .64233 .27727 .69586 .27159 .67152 .26343 Metetra
.333 .798 .933 r
.67152 .26343 .69586 .27159 .75091 .26633 .72747 .25457 Metetra
.694 .915 .97 r
.00095 .48363 .0381 .4919 .08308 .4671 .04631 .46103 Metetra
.676 .93 .97 r
.04631 .46103 .08308 .4671 .12852 .44243 .09224 .43843 Metetra
.649 .938 .965 r
.09224 .43843 .12852 .44243 .17441 .41835 .13873 .41617 Metetra
.612 .938 .954 r
.13873 .41617 .17441 .41835 .22074 .39528 .18578 .39455 Metetra
.566 .928 .937 r
.18578 .39455 .22074 .39528 .26756 .37361 .23342 .37387 Metetra
.515 .911 .917 r
.23342 .37387 .26756 .37361 .31492 .35365 .28171 .35435 Metetra
.465 .889 .898 r
.28171 .35435 .31492 .35365 .36293 .3356 .33072 .33615 Metetra
.422 .866 .884 r
.33072 .33615 .36293 .3356 .4117 .31955 .38055 .31932 Metetra
.39 .849 .88 r
.38055 .31932 .4117 .31955 .46135 .30544 .4313 .30382 Metetra
.373 .837 .886 r
.4313 .30382 .46135 .30544 .51204 .2931 .48308 .28952 Metetra
.371 .833 .903 r
.48308 .28952 .51204 .2931 .56389 .28225 .53601 .2762 Metetra
.384 .835 .927 r
.53601 .2762 .56389 .28225 .61701 .2725 .59019 .26358 Metetra
.407 .838 .953 r
.59019 .26358 .61701 .2725 .67152 .26343 .64571 .25133 Metetra
.438 .84 .976 r
.64571 .25133 .67152 .26343 .72747 .25457 .70262 .2391 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00moooool4o`000003oa0@4?oooooooooo06[ooooo003iooooo`03o`00
0?oooooooooo06cooooo003iooooo`03o`000?oooooooooo06cooooo003iooooo`03o`000?oooooo
oooo06cooooo003iooooo`03o`000?oooooooooo06cooooo003iooooo`03o`000?oooooooooo06co
oooo003iooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Pooooo`00
moooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0H?ooool00?oooooo
1?ooool01Ol@413ooooooooooooooooo410@063ooooo003oooooo`Cooooo00Go0000oooooooooooo
ooooo`00001Pooooo`00ooooool4ooooo`05o`000?ooooooooooooooool00000H?ooool00?oooooo
1?ooool01Ol@413ooooooooooooooooo410@063ooooo003mooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg063ooooo003jooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^063ooooo003hooooo`;o00001?ooool2o`0006Sooooo003eooooo`?o00001_oo
ool00ol0003oooooo`00001Wooooo`00l_ooool3o`0000Wooooo00?o0000ooooool00000Ioooool0
0?3ooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Kooooo002jooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000IOooool00;[ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000IOooool00;[ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Rooooo`00^_ooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006?ooooo002jooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol00002ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Qooooo`00^_ooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go410@okZj^_oooooo^[Zjoa0@400Booooo`;o00007?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo063ooooo002jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[Zjoooooonj^[[o000000oooooo0ol0000Nooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0Goooool00;[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o
0000oa0@4?nYZJT03?ooool3o`00027ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1Oooooo`00N?ooool2o`0000;ooooo0_l0001Kooooo`;o000000?oooooo`000?ooool08Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo05kooooo001hooooo`06onk^k_lQ8B7oQhN7
okZj^_l0003ogMgMF?ooool3o`0000?ooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo05kooooo001iooooo`04omgMgOl0003o410@olc<c5Oooooo0_l0
000Yooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0GOooool007Wooooo00Cok^k^
ob4Q8Ol@413ok^k^E?ooool3o`0002_ooooo00?o0000ooooooooool01_ooool2o`0005kooooo001i
ooooo`04ob4Q8OmgMgOoMgMgoc8b<U;ooooo0_l0000^ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0G?ooool007Sooooo0_l00002ooooo`;o0000C_ooool3o`0000;ooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05_ooooo003:oooo
o`;o00001_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0F_ooool00<Oooooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0F_ooool00<Cooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
FOooool008kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<01oooooo0_l00002ooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`1Hooooo`00S_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407?ooool3o`0003gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`1Hooooo`00S_ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`00000Jooooo`;o0000@?ooool00ol0003oooooooooo`0;
ooooo`;o0000FOooool008kooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9So
oooooiRHV?lQ8B405oooool3o`0004;ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000kooooo`00S_oo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Eooooo`;o
000000?oooooo`000?ooool0@_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403_ooooo002>ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0D
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0??oo
ool008kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01;ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0>oooool008kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40gooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0>_ooool00:gooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0>Oooool00:_o
oooo0_l00004ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03_ooooo002Xooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00kooooo`00Y_ooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Aooooo`00Xoooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1@ooooo`00XOooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo053o
oooo002Nooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0Coooool009cooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0C_ooool006?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Tooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0C_ooool006?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`0Mooooo`?o00000_ooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0COooool006?ooooo00Go410@oooooooooooooooooa0@
400;ooooo`Go00007?ooool2o`0006[ooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00
001>ooooo`00Hoooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
6_ooool3o`0006cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1<ooooo`00Hooo
ool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00006?ooool2o`0006oo
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1;ooooo`00Hoooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oMgMgolc<c?l000005Oooool3o`0000;ooooo00?o0000oooooooo
ool0K?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04_ooooo001Sooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000Cooooo`;o0000M?ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo04[ooooo001Sooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03Oooool00omgMgOo0000ooooo`0?ooooo`?o0000M_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo04Wooooo0025ooooo`;o0000NOooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo04Wooooo0022ooooo`?o00000_ooool00ol0003oooooooooo`1fooooo`03o`000?oo
oooooooo01Wooooo0_l0001:ooooo`00Ooooool3o`0007kooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`17ooooo`00OOooool2o`0008;ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`17ooooo`00N_ooool3o`0008Cooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`16ooooo`00N?ooool2o`0000;ooooo00?o0000ooooooooool0P_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo04Gooooo001eooooo`?o00001Oooool00ol0003ooooooooo
o`21ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0AOooool007?ooooo0_l0002<
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0A?ooool003_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00023ooooo0ol0002>ooooo`03o`000?oooooo
oooo01cooooo0ol00015ooooo`00>oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@07_ooool2o`0000?ooooo00?o0000ooooooooool0Rooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo02Kooooo000kooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Looooo`?o0000Toooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1oooool00ol0003oooooooooo`0Wooooo`00>oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h06?ooool3o`0009Kooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0002Sooooo000kooooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Eooooo`?o0000V?ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;
ooooo`04odA4A?oMgMgoooooo`0000[ooooo0ol000000ol@413oooooooooo`0Iooooo`00>oooool0
1Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool04Oooool3o`0000?ooooo00?o
0000ooooooooool0UOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000cooooo00?o410@okZj^_oo
ool06_ooool003_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRH
V?l@41004Oooool2o`0009kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000<ooooo`03oiRHV?lb<S;o
oooo01[ooooo000kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<00kooooo0ol0002Pooooo`03o`000?oooooooooo027ooooo0_l00004ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000<ooooo`03omgMgOl0003o^[Zj01[ooooo
001Looooo`?o0000X_ooool00ol0003oooooooooo`0Pooooo`04o`000?ooooooooooo`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00_ooooo00?oEEEEogMgMom4
A4@06_ooool005Wooooo0ol00003ooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0Oooooo`05omgMgOl@413oooooob4Q8OoMgMd06Oooool005Oooooo
0_l0002Xooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool01OmVIVKoQhN7
oooooonHV9SoEEEE01Wooooo001Dooooo`?o0000Z_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01gooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`0Gooooo`00DOoo
ool3o`000003ooooool0003ooooo0:[ooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Looooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05_ooool004oooooo0_l0
0005ooooo`03o`000?oooooooooo0:Sooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0kooooo`00C?ooool3o`000;?ooooo00?o0000ooooooooool09Oooool2o`0003cooooo000Uoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h08?ooool2o`000;Kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0jooooo`009Oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo0ol00002
ooooo`03o`000?oooooooooo0;?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0i
ooooo`009Oooool01Ol@413ooooooooooooooooo410@01_ooooo0_l0002kooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0>?ooool002Gooooo00Go0000ooooooooooooooooo`00000H
ooooo`?o0000_Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Sooooo000Uoooo
o`05o`000?ooooooooooooooool000005_ooool3o`000;oooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0gooooo`009Oooool01Ol@413ooooooooooooooooo410@01?ooooo0ol00003
ooooo`03o`000?oooooooooo0;cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0f
ooooo`009Oooool01OmgMgOoV9RHoooooonHV9SoMgMg013ooooo0ol00033ooooo`Co0000:_ooool2
o`0003Sooooo000Uooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool2o`000<7ooooo1Ol00002
og3Gn@03o`000?m`eoWo000002_ooooo00?o0000ooooooooool0=Oooool003Gooooo0ol000000ooo
oooo0000ooooo`2looooo`Co00001_m`eoT2o`0000;oL=Oi0_l0000Zooooo`03o`000?oooooooooo
03Cooooo000cooooo`;o0000_Oooool5o`0000OoL=Oi0ol000000om`eoWo0000og3Gn@03og3Gn@;o
0000:?ooool00ol0003oooooooooo`0dooooo`00<?ooool3o`000;_ooooo1?l00009og3Gn@?o0000
1Om`eoT00ol0003oL=Oiog3Gn@03og3Gn@03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
<oooool002oooooo0_l0002iooooo`Co00001?mXe_<2o`0000CoL=Oi0ol00009og3Gn@03o`000?m`
eoWoL=Oi00Go00009oooool00ol0003oooooooooo`0booooo`00;oooool3o`000;?ooooo1Ol0000:
ofSFl`Co00002Om`eoT6o`0000GoELc^0_l0000Uooooo`;o0000<oooool002oooooo00Co0000oooo
ool0003o0000[_ooool4o`0000goJ=Kc0ol000000omXe_?o0000o`000003og3Gn@Ko00001?mEc>h0
0ol0003oELc^oeG<kP06oeG<kP;o00008_ooool00ol0003oooooo`000008ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c00Fooooo`00;ooo
ool01Ol0003ooooooooooooooooo00000:Wooooo1?l0000>ofSFl`?o00000omXe_<6o`0000_oELc^
00?o0000oeG<k_mEc>h01omEc>h2o`0002?ooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B405_ooool002ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Rooooo`Co00001?mReNd3o`0000Wo
J=Kc2?l00006odW7h`Co00002?mEc>h00ol0003oELc^o`00000:o`00027ooooo00?o0000oooooooo
ool01Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000F
ooooo`00;_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo09cooooo1Ol0000;of;E
k@?o00000omXe_<5o`0000goBLOS3Ol0000;ocfni0?o00007oooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q01Kooooo000^
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Uoooool4o`00013oH]G]2?l00007
odW7h`Wo00001ol`]mH4o`000003ocfni?l0003o?KkT00go?KkT0_l0000Nooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
5_ooool002kooooo0_l00007ooooo`03o`000?oooooooooo09;ooooo1Ol0000=of;Ek@Wo00001?m1
a=P9o`0000co<;OF6ol0000Looooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`03oeEEEOn7QhOooooo01Sooooo000^ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0SOooool4o`0000GoG]GW1?l00004of;Ek@Go00000om1a=P:o`0000Co9k;84Ol0
000:obB^eP;o00003ol`]><2o`0001Wooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool00ooMgMgo410@oiRHV00Hooooo`00;_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo08Oooooo1Ol0000;oekEiaco00001olNZlTAo`0000?o9:kF00Co0000obB^e_l0003o0000
3ol`]><2o`0001[ooooo00Wo0000ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03?ooool0
1?o<c<coA4A4o`000?l@410Fooooo`00;_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo08;ooooo1?l0000;oekEi`Go00001?lm`/h<o`0000Co7jc13ol0000:ob^`h0?o00001?l][nHJ
o`0001Sooooo00?o0000ooooooooool0;?ooool002gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`1mooooo`So00001_mNeNL5o`0000Co?L;>5Ol0000:oc2fg0?o00003ol[/>02o`00
00Oo;JoV00Co0000obf_i_l][nKo;JoV0ol0000>ocB`kP03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0:oooool002gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1ioooo
o`?o00002?mOe^8Ho`0000Oo?/3M;?l00005obf_iP;o00003Old/>h2o`0001Oooooo00?o0000oooo
ooooool0:_ooool002gooooo0ol0000=ooooo`03o`000?oooooooooo07Cooooo1?l00008oeoFhPCo
00000olo`lP?o`0000Go?/3M1ol00006ofG:o0;o00003OmD_oX2o`0000koBKKh00?o0000odF`n?m5
/?P00om5/?P=o`0000[o=;3^00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Zooooo`00
;Oooool00ol0003oooooooooo`0>ooooo`;o0000LOooool3o`0000SoGmKR1?l00002oco3b0co0000
0_mBc^43o`0000;oD/kQ1_l0000?ofG:o003o`000?mD_o[oE;oj00coE;oj00?o0000odVfn?m9]_P0
3?m9]_P2o`0000CoAK3h00?o0000odF`n?m5/?P01_m5/?P00ol0003oAjghodN]n009o`0000;o=;3^
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Yooooo`002_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1[ooooo`?o
00001omOe^8Ao`0000CoD/kQ2?l00004og[FoP?o00003omUb_`2o`0000goE;oj0_l0000>odVfn003
o`000?m5/?SoAK3h00;oAK3h00?o0000odF`n?m5/?P01_m5/?P00ol0003oAjghodN]n008odN]n0Co
00005?ooool2o`0002_ooooo000:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1Voooooaco00001?mBc^46o`0000coN]Kn0ol00007ofG:
o1oo00001_m9]_P00ol0003oAK3hodF`n002odF`n003o`000?m5/?SoAK3h00KoAK3h00?o0000odN]
n?m7[OP02om7[OP00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Sooooo000:ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00?ooooo1Ol00006
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0H_ooool3o`0000OoHmWQ0ol00000
0om6alOo0000o`000008o`0000OoK=gW1Ol0000Bog[FoPWo00002?n1^oT00ol0003oL[?iog:cn@0;
og:cn@03o`000?mW[?SoIjch00KoIjch3?l00009odF`n003o`000?m7[OSoAjgh00_oAjgh00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Wooooo`002_ooool01Ol0003ooooooooooooooooo
000000_ooooo00Go0000ooooooooooooooooo`000003ooooo`04odA4A?oMgMgoooooo`0000Kooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Nooooo`?o00001omSfN49o`000004odg;
aol0003o0000o`0000WoK=gW1?l00003oi7PoP?o00002_mje_h5o`0000?oT/?h00?o0000oh6knOn1
^oT03?n1^oT00ol0003oL[?iog:cn@0;og:cn@03o`000?mW[?SoIjch00coIjch00?o0000of2WmomP
YoL00_mPYoL8o`0000;oAK3h00?o0000odN]n?m7[OP02om7[OP00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo02Oooooo000:ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003o
oooooooooooooooo000000?ooooo00CogMgMoeEEEOoooooo00001_ooool2o`0001Kooooo00?o0000
ooooooooool0F_ooool3o`0000OoHmWQ3Ol00008ofcMi`Go00002OnAh?h2o`0000?oN]Kn1Ol00009
oi;3n003o`000?n1^oWoPK_i00coPK_i00?o0000og:cnOmb/oT02omb/oT00ol0003oIjchofN/n00<
ofN/n003o`000?mPYoOoH:Og00;oH:Og00?o0000of2WmomPYoL01?mPYoL8o`0000WoAjgh00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Vooooo`002_ooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@oooooooooooooooooa0@4004ooooo`03ogMgMoo<c<co000000Kooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`1Fooooo`?o00001omSfN4@o`0000GoK=gW1Ol0
000<oi7PoPGo00003onB`oP00ol0003oPK_ioh6kn@0<oh6kn@03o`000?mb/oWoL[?i00_oL[?i00?o
0000ofN/n?mW[?P03?mW[?P01Ol0003oH:Ogof2WmomPYoOo000000WoH:Og00?o0000oefTm_mMY?H0
0_mMY?H8o`0000;oAjgh00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Uooooo`002_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03
onk^k_m4A4Co000000Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1AoooooaOo
00001on7j^d7o`0000coTN3n0ol00004oj;9m003o`000?nB`oSoT/?h00koT/?h00?o0000oh6knOn1
^oT03?n1^oT00ol0003oL[?iog:cn@0;og:cn@03o`000?mW[?SoIjch00coIjch00Go0000of2WmomP
YoOoH:Ogo`000009of2Wm`03o`000?mMY?KoGJCf00WoGJCf1?l0000Booooo`;o00009oooool000[o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool0
0omgMgOo0000ooooo`05ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0COooool3
o`0000SoK=gR3?l00009ohOZk@Go000000CoYNKko`000?l0003o00001onAh?h4o`0000SoX/Wd00?o
0000oi;3n?nB`oP03_nB`oP00ol0003oPK_ioh6kn@0<oh6kn@03o`000?mb/oWoL[?i00_oL[?i00?o
0000ofN/n?mW[?P03?mW[?P01Ol0003oH:Ogof2WmomPYoOo000000WoH:Og00?o0000oefTm_mMY?H0
2omMY?H00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Cooooo000/ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0BOooool3o`0000SoK=gR2_l000000omWfm;o0000o`00
0008ohOZk@Go00001onUi_/2o`0000;oTN3n0ol0000=oj;9m003o`000?nB`oSoT/?h00koT/?h00?o
0000oh6knOn1^oT01On1^oT@o`0000GoL[?i00?o0000ofN/n?mW[?P03?mW[?P01Ol0003oH:Ogof2W
momPYoOo000000WoH:Og00?o0000oefTm_mMY?H02omMY?H00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo02?ooooo000/ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0AOoo
ool3o`0000SoK=gR1ol000001?mKdlOo0000o`000?mWfm83o`0000OoQn[]1_l0000:ojGVn`?o0000
4OnRbO@00ol0003oT/?hoi;3n00<oi;3n0Wo00001on=Y^H00ol0003oPZ7Woh:Qi`06oh:Qi`oo0000
1_mW[?P01?l0003oH:Ogof2Wmol00009of2Wm`03o`000?mMY?KoGJCf00coGJCf00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Sooooo`00:oooool3o`0001cooooo00?o0000ooooooooool0
@Oooool3o`0000SoK=gR1_l00002oe_Ca`?o000000?oIm_Bo`000?l000001on7j^d6o`0000_oYNKk
0_l00003ojo=k`03o`000?nRbOCoX/Wd00ooX/Wd00?o0000oi;3n?nB`oP01_nB`oP5o`0000;oV:_S
00?o0000ohfVi_n=Y^H03?n=Y^H00ol0003oPZ7Woh:Qi`0;oh:Qi`03o`000?miWNSoNIgX00KoNIgX
3?l00008of2Wm`03o`000?mMY?KoGJCf00coGJCf00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Rooooo`00:oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03gooooo3_l0
00000omSfM7o0000o`000003oe_Ca`;o000000?oIm_Bo`000?l000003Ol0000<ojGVn`;o00001_n_
cNl00ol0003oX/Wdoj;9m00?oj;9m003o`000?nB`oSoT/?h00Go00002?nHZn<00ol0003oSJKVohfV
iP0<ohfViP03o`000?n2XNOoPZ7W00_oPZ7W00?o0000ogVMj?miWNP03?miWNP01?l0003oLY[Yog:J
jOmbV^T8o`0000;oH:Og00?o0000oefTm_mMY?H03?mMY?H00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo027ooooo000[ooooo`03o`000?oooooooooo01kooooo0_l0000jooooo`?o00001omg
hnD3o`0000;oHmWA0ol00002oe_Ca`Oo00001onOl_04o`000003okGXmol0003o000000WoYNKk0ol0
0009ojo=k`03o`000?nRbOCoX/Wd00goX/Wd1?l0000>oiR[h`03o`000?n=Y^KoSJKV00_oSJKV00?o
0000oh:Qion2XNL03?n2XNL00ol0003oNIgXogVMj00<ogVMj005o`000?mbV^WoLY[Yog:JjOl00000
1_mbV^T8o`0000[oGJCf00?o0000ooooooooool03oooool2o`0000Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo000[ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0=Oooool2o`0000OoMn?U0ol00003of?Id@;o
00000_mKdlL4o`0000;oPnWM0_l00007oiobl0?o00001_nej?L2o`0000GoYNKk0_l0000=ojo=k`03
o`000?nRbOCoX/Wd00WoX/Wd0ol00002oj>_h003o`000?nHZn?oV:_S00goV:_S00?o0000ohfVi_n=
Y^H03?n=Y^H00ol0003oPZ7Woh:Qi`0;oh:Qi`03o`000?miWNSoNIgX00goNIgX00Co0000og:JjOmb
V^Wo00002OmbV^T00ol0003oKYWZofjIjP02ofjIjPWo00000_mMY?H00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo000[ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0<Oooool3o`0000KoMn?U0ol00003of?Id@So00000on3jMd2o`0000KoWo;`0ol0000;
okGXm`;o000000?oYNKko`000?l000004?n_cNl00ol0003oX/Wdoj;9m004oj;9m0Co00001_nS[n00
0ol0003oV:_SoiR[h`0=oiR[h`03o`000?n=Y^KoSJKV00coSJKV00?o0000oh:Qion2XNL02on2XNL0
0ol0003oNIgXogVMj00<ogVMj005o`000?mbV^WoLY[Yog:JjOl000002OmbV^T00ol0003oKYWZofjI
jP0:ofjIjPCo00004_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000000Kooooo000[ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0;_ooool2o`0000KoMn?U2ol000000omch]?o0000o`000004oh?Yg@;o0000
1_nOl_03o`0000ko]NSg0ol0000Bojo=k`03o`000?nRbOCoX/Wd00?o00002onS[n000ol0003oV:_S
oiR[h`0=oiR[h`03o`000?n=Y^KoSJKV00_oSJKV00?o0000oh:Qion2XNL03?n2XNL00ol0003oNIgX
ogVMj00<ogVMj005o`000?mbV^WoLY[Yog:JjOl000002OmbV^T00ol0003oKYWZofjIjP0<ofjIjP03
o`000?oooooooooo013ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`00:_ooool3o`0002Cooooo00?o0000oooo
ooooool0:_ooool3o`000003ogOSiOl0003o000000So000000CoM^?Jo`000?l0003o00000omch]<2
o`0000CoPnWM0_l00005oiobl0Co00003Onej?L3o`0000?o^/oZ00?o0000ojo=kon_cNl03on_cNl3
o`0000koXjoP00?o0000oiR[honHZn<03OnHZn<00ol0003oSJKVohfViP0<ohfViP03o`000?n2XNOo
PZ7W00coPZ7W00?o0000ogVMj?miWNP02omiWNP01Ol0003oLY[Yog:JjOmbV^Wo000000WoLY[Y00?o
0000ofjIj_m^VNX03Om^VNX00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool002[ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Wooooo`Ko00000_n3jNX2o`0000GoM^?J
0_l00003og?Rd`?o00001?n3jMd2o`0000CoWo;`1Ol0000=okGXm`;o00001onjcnX00ol0003o[lg_
ojo=k`0;ojo=k`?o000000?o[K?Mo`000?nS[n003onS[n000ol0003oV:_SoiR[h`0=oiR[h`03o`00
0?n=Y^KoSJKV00_oSJKV00?o0000oh:Qion2XNL03?n2XNL00ol0003oNIgXogVMj00<ogVMj005o`00
0?mbV^WoLY[Yog:JjOl000002OmbV^T00ol0003oKYWZofjIjP0=ofjIjP03o`000?oooooooooo013o
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj
^_oooooo^[Zjoa0@4006ooooo`00:_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
02?ooooo0ol00006oh?YjP;o00001OmfhmX2o`0000?oLn;C0_l00002oh?Yg@oo00003?nej?L2o`00
00[o^/oZ00?o0000ojo=kon_cNl01on_cNl3o`0000Go[K?M00?o0000oj>_h?nS[n003_nS[n000ol0
003oV:_SoiR[h`0<oiR[h`03o`000?n=Y^KoSJKV00coSJKV00?o0000oh:Qion2XNL03?n2XNL00ol0
003oNIgXogVMj00<ogVMj005o`000?mbV^WoLY[Yog:JjOl000002OmbV^T00ol0003oKYWZofjIjP0<
ofjIjP03o`000?oooooooooo00kooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[Zjoooooonj^[[o000000Kooooo000Zooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool08?ooool2o`0000KoPnWZ0ol00004ogKSfP?o00000_mch]<7o`000003oi_ci_l0
003o000000;o/_Ka0ol00003ok;fl@04o`000?o1io7o`NOaol7Wl@?o00001_nej?L3o`0000go^/oZ
00?o0000ojo=kon_cNl00on_cNl3o`0000Wo[K?M00?o0000oj>_h?nS[n003_nS[n000ol0003oV:_S
oiR[h`0<oiR[h`03o`000?n=Y^KoSJKV00GoSJKV7ol00005ogVMj003o`000?mbV^WoLY[Y00;oLY[Y
00?o0000og:JjOmbV^T01ombV^T00ol0003oKYWZofjIjP0<ofjIjP03o`000?oooooooooo013ooooo
00Wo0000ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00Kooooo000Zooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool07?ooool3
o`0000KoPnWZ0_l00005ogKSfPSo00001_nKlnH00ol0003o/_Kao`000002o`0000Co/_Ka0_l00007
ol7Wl@?o000000?o]NSgo`000?l000004OnjcnX00ol0003o[lg_o`000002o`0000co[K?M00?o0000
oj>_h?nS[n003_nS[n000ol0003oV:_SoiR[h`0:oiR[h`[o00001onAUmD00ol0003oRICHohVDf00<
ohVDf003o`000?n3T][oPi;J00KoPi;J2ol00009og:Jj@03o`000?m^VN[oKYWZ00coKYWZ00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Kooooo`00:_ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo01Wooooo0_l00007oh?YjP;o00000omfhmX6o`0000;oRngO0_l00006oi_c
iPCo00001_nbm_400ol0003o`NOaol7Wl@09ol7Wl@?o00004_njcnX2o`00013o[K?M00?o0000oj>_
h?nS[n003_nS[n000ol0003oV:_SoiR[h`02oiR[h`Oo00000onJV]<00ol0003oTIOEoi6Ge@0<oi6G
e@03o`000?n9U=SoRICH00coRICH00?o0000oh>Bf_n3T]X02on3T]X00ol0003oOI3Logf@g002ogf@
g0So00000_mbV^T00ol0003oKYWZofjIjP0<ofjIjP03o`000?oooooooooo013ooooo00?o0000oooo
ooooool06oooool002Wooooo0ol0000[ooooo`03o`000?oooooooooo01Gooooo0ol00007oh?YjPWo
00001?n;kMl2o`0000KoVo?V1?l00006ok;fl@;o00002oo1io401Ol0003o`/oTol;?i?o2cnCo0000
00oo^/oZ0_l000000onf]]Wo0000ojfcg@0@ojfcg@03o`000?nS[n3oXjoP00coXjoP1_l0000;oiZJ
d`03o`000?nAUmGoTIOE00_oTIOE00?o0000ohVDf?n9U=P03?n9U=P00ol0003oPi;Joh>BfP0<oh>B
fP03o`000?mmT=coOI3L00;oOI3L00?o0000ogf@g?mmT=`01?mmT=`8o`0000[oKYWZ00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Jooooo`00:Oooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo01;ooooo3_l00003ohW/i0;o00001On;kMl00ol0003oVo?Voi_ciP04oi_ciP?o
00001onbm_42o`0000_o`NOa0_l00005ol;?i003o`000?njcn[o^/oZ00[o^/oZ0_l00004okJff@03
o`000?n]/mgo[K?M00oo[K?M00?o0000oj>_h?nS[n002?nS[n03o`0000;oXYkA00?o0000oiZJdonJ
V]<03?nJV]<00ol0003oTIOEoi6Ge@0<oi6Ge@03o`000?n9U=SoRICH00coRICH00?o0000oh>Bf_n3
T]X02on3T]X00ol0003oOI3Logf@g003ogf@g003o`000?mmT=coOI3L00KoOI3L00?o0000ogZAg_mj
TMh00_mjTMh8o`0000;oKYWZ00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Iooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0>ooooo`?o00002?n@kNl2o`0000GoRNcT0_l00005oh_]g`;o00001?nKlnH3
o`0000Wo/_Ka00?o0000ol7WlOo1io402_o1io400ol0003o`/oTol;?i006ol;?i003o`000?njcn[o
^/oZ00Oo^/oZ0_l00007okJff@03o`000?n]/mgo[K?M00ko[K?M00?o0000oj>_h?nS[n001?nS[n04
o`0000KoXYkA00?o0000oiZJdonJV]<03?nJV]<00ol0003oTIOEoi6Ge@0;oi6Ge@03o`000?n9U=So
RICH00coRICH00?o0000oh>Bf_n3T]X03?n3T]X00ol0003oOI3Logf@g002ogf@g003o`000?mmT=co
OI3L00OoOI3L00?o0000ogZAg_mjTMh02OmjTMh4o`00017ooooo0_l0000Kooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmEEEGoMgMgoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0:ooooo`?o00002On@kNl2o`0000KoRNcT00?o0000oh_]gon;kMl00on;kMl2o`0000?oVo?V
1Ol00008ok;fl@;o00002oo1io42o`0000[o`/oT00?o0000ok[?j_njcnX01OnjcnX00ol0003o][KI
okJff@08okJff@03o`000?n]/mgo[K?M00ko[K?M00?o0000oj>_h?nS[n000ol0000:oj:Nd@03o`00
0?nJV]?oVY[C00coVY[C00?o0000oi6GeOnAUmD03?nAUmD00ol0003oRICHohVDf00<ohVDf003o`00
0?n3T][oPi;J00_oPi;J00?o0000ogf@g?mmT=`00ommT=`00ol0003oOI3Logf@g006ogf@g003o`00
0?mjTMkoNY7N00coNY7N00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Hooooo`001ooo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0_ooooo`;o00002?ooool2o`00
00[oT>g_0_l00006ohW/i0;o00001?n;kMl2o`0000;oVo?V2ol00004ok;fl@03o`000?o1io7o`NOa
00[o`NOa00?o0000ol;?i?o2cn@02oo2cn@00ol0003o^/oZok[?jP02ok[?jP;o00003?nf]]T00ol0
003o[K?Mojfcg@0=ojfcg@?o00003_nRW]400ol0003oVY[CoiZJd`0<oiZJd`03o`000?nAUmGoTIOE
00_oTIOE00?o0000ohVDf?n9U=P03?n9U=P00ol0003oPi;Joh>BfP0<oh>BfP03o`000?mmT=coOI3L
00?oOI3L00?o0000ogf@g?mmT=`01_mmT=`00ol0003oNY7NogZAgP0<ogZAgP03o`000?oooooooooo
017ooooo00?o0000ooooooooool05oooool000Oooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003oV9RHoooooonHV9So8B4Q00Gooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`02ooooo`?o00002_n@kNl2o`0000KoRNcT0_l0
0003oh_]g`Oo00000on^n>`00ol0003o`?C`ol3dl005ol3dl0Ko00002_o1io400ol0003o`/oTol;?
i00=ol;?i004o`000?njcn[o0000o`0000ko][KI00?o0000ojfcgOn]/md02_n]/md3o`000003ojVR
col0003oXYkA00koXYkA00?o0000oiZJdonJV]<03?nJV]<00ol0003oTIOEoi6Ge@0<oi6Ge@03o`00
0?n9U=SoRICH00coRICH00?o0000oh>Bf_n3T]X02on3T]X00ol0003oOI3Logf@g004ogf@g003o`00
0?mmT=coOI3L00GoOI3L00?o0000ogZAg_mjTMh03?mjTMh00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01Oooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000oeEEEOl0003o410@olc<c005ooooo`;o0000<oooool4o`00
00_oT>g_0_l00006ohW/i0So000000?o[_S/o`000?l000001?n^n>`2o`0000Wo`?C`00?o0000olSU
k?o8iN`00_o8iN`3o`0000Go`NOa0_l0000@ol;?i0;o00004Onf]]T00ol0003o[K?Mojfcg@06ojfc
g@?o00001OnYX/l00ol0003oXYkAoj:Nd@0=oj:Nd@03o`000?nJV]?oVY[C00coVY[C00?o0000oi6G
eOnAUmD02onAUmD00ol0003oRICHohVDf00<ohVDf003o`000?n3T][oPi;J00coPi;J00?o0000ogf@
g?mmT=`00ommT=`00ol0003oOI3Logf@g006ogf@g003o`000?mjTMkoNY7N00coNY7N00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Fooooo`001oooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oeEEEOn7QhOooooo00Kooooo0_l0000c
ooooo`So00001_n@kNl2o`0000;oRNcT2?l00003oiodj0Co00001On^n>`00ol0003o`?C`ol3dl007
ol3dl0;o00002?o8iN`3o`000003ol7WlOl0003o`/oT013o`/oT00?o0000okbie_l000004_nf]]T0
0ol0003o[K?Mojfcg@03ojfcg@;o00002?nYX/l00ol0003oXYkAoj:Nd@0=oj:Nd@03o`000?nJV]?o
VY[C00coVY[C00?o0000oi6GeOnAUmD03?nAUmD00ol0003oRICHohVDf00<ohVDf003o`000?n3T][o
Pi;J00_oPi;J00?o0000ogf@g?mmT=`01?mmT=`00ol0003oOI3Logf@g006ogf@g003o`000?mjTMko
NY7N00_oNY7N00?o0000ooooooooool04Oooool2o`0001Oooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?ogMgMoa0@4?nHV9P01_oo
ool00ol0003oooooooooo`0`ooooo`;o00002?nLl?@:o`0000;oV_;/0_l00005oiodj0?o00001_n^
n>`2o`0000Wo`?C`00?o0000olSUk?o8iN`02_o8iN`3o`0000oo`/oT0_l00003okbieP03o`000?nf
]]Wo][KI013o][KI00?o0000ojfcgOl000000_l0000;ojVRc`03o`000?nRW]7oXYkA00goXYkA00?o
0000oiZJdonJV]<03?nJV]<00ol0003oTIOEoi6Ge@0;oi6Ge@03o`000?n9U=SoRICH00coRICH00?o
0000oh>Bf_n3T]X03?n3T]X00ol0003oOI3Logf@g004ogf@g003o`000?mmT=coOI3L00GoOI3L00?o
0000ogZAg_mjTMh03?mjTMh00ol0003oooooooooo`0?ooooo`03o`000?oooooo000001Oooooo0007
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo
00Coc<c<odA4A?l0003o410@1?ooool00ol0003oooooooooo`0^ooooo`;o00003?nLl?@2o`0000Ko
V_;/0_l00004oiodj0?o00001on^n>`2o`0000Wo`?C`0_l0000<olSUk005o`000?o7c^3oalkPolO>
h?l000003?o2cn@2o`0000Ko_;WF00?o0000okJffOnf]]T03onf]]T2o`0000ooZJ;?00?o0000oj:N
dOnRW]403?nRW]400ol0003oVY[CoiZJd`0<oiZJd`03o`000?nAUmGoTIOE00coTIOE00?o0000ohVD
f?n9U=P03?n9U=P00ol0003oPi;Joh>BfP0;oh>BfP03o`000?mmT=coOI3L00CoOI3L00?o0000ogf@
g?mmT=`01_mmT=`00ol0003oNY7NogZAgP0<ogZAgP03o`000?oooooooooo017ooooo00?o0000oooo
ooooool05?ooool002Sooooo00?o0000ooooooooool0;?ooool2o`0000coW?3d0_l00006oi[bk0;o
00000onOm>P4o`0000So[_S/00?o0000ol3dl?o0m?001oo0m?02o`0000cob>G/0_l00005olO>h003
o`000?o2cnCo`/oT00So`/oT00?o0000okbie_nl^MH01onl^MH00ol0003o][KIokJff@0<okJff@;o
000000?o/:G=o`000?nYX/l03_nYX/l00ol0003oXYkAoj:Nd@0=oj:Nd@03o`000?nJV]?oVY[C00co
VY[C00?o0000oi6GeOnAUmD02onAUmD00ol0003oRICHohVDf00<ohVDf003o`000?n3T][oPi;J00co
Pi;J00?o0000ogf@g?mmT=`01?mmT=`00ol0003oOI3Logf@g005ogf@g003o`000?mjTMkoNY7N00co
NY7N00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`00:?ooool00ol0003ooooo
ooooo`0Zooooo`;o00002onLl?@3o`0000KoV_;/0_l00002oiodj0?o000000?oWoCXo`000?n^n>`0
1on^n>`2o`0000Wo`?C`00?o0000olSUk?o8iN`02oo8iN`00ol0003oalkPolO>h006olO>h0;o0000
1_o2cn@2o`0000_o_;WF00?o0000okJffOnf]]T02Onf]]T2o`0000Co/:G=00?o0000ojVRconYX/l0
3OnYX/l00ol0003oXYkAoj:Nd@0<oj:Nd@03o`000?nJV]?oVY[C00coVY[C00?o0000oi6GeOnAUmD0
1OnAUmDOo`0000GoPi;J00?o0000ogf@g?mmT=`01OmmT=`00ol0003oOI3Logf@g005ogf@g003o`00
0?mjTMkoNY7N00coNY7N00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Cooooo`00:?oo
ool2o`0002Wooooo0_l0000;oic`m0;o00001onJl^`2o`0000;oWoCX0_l00002oiodj0;o00002?n^
n>`00ol0003o`?C`ol3dl007ol3dl0;o00003?o8iN`2o`0000_oalkP00Co0000ol;?i?o2cnCo`/oT
0_l0000=okbieP03o`000?nf]]Wo][KI00Oo][KI0_l00006ok2Uc@03o`000?nYX/ooZJ;?00goZJ;?
00?o0000oj:NdOnRW]403OnRW]400ol0003oVY[CoiZJd`09oiZJd`[o00001onDSl/00ol0003oSXg=
ohj=c@0<ohj=c@03o`000?n9S=3oRHc@00KoRHc@3ol00006ogf@g003o`000?mjTMkoNY7N00coNY7N
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`009oooool2o`0002Sooooo0_l0
000;oic`m0;o00001onJl^`2o`000003oiodj?l0003o000001Co00001?o0m?000ol0003ob>G/olSU
k00:olSUk0;o00003_o7c^000ol0003o`/oTo`00000@okbieP03o`000?nf]]Wo][KI00Go][KI00?o
0000ok2UcOn`YLd01on`YLd00ol0003oZJ;?ojVRc`0=ojVRc`03o`000?nRW]7oXYkA00coXYkA00?o
0000oiZJdonJV]<00_nJV]<7o`0000?oVY7900?o0000oiB?bonDSl/03?nDSl/00ol0003oSXg=ohj=
c@0<ohj=c@03o`000?n9S=3oRHc@00_oRHc@00?o0000ohF<d_n5S=801On5S=8=o`0000[oNY7N00?o
0000ooooooooool04?ooool2o`0000Wooooo1?l000000ol@413oooooooooo`04ooooo`00:?ooool0
0ol0003oooooooooo`0Tooooo`So00001OnLl?@2o`0000?oV_;/2_l00003ojogkP03o`000?nkn>ko
^oS^00Oo^oS^00?o0000olSak_o8lNh01Oo8lNh6o`0000[ob>G/00?o0000olO>h?o7c^003_o7c^02
o`0001;o_;WF00?o0000okJffOnf]]T00_nf]]T2o`0000[o/:G=00?o0000ojVRconYX/l03OnYX/l0
0ol0003oXYkAoj:Nd@0;oj:Nd@Ko00002onJTLT00ol0003oU8o;oiB?b`0;oiB?b`03o`000?n>SLgo
SXg=00coSXg=00?o0000ohV<d?n9S=003?n9S=000ol0003oQHcBohF<dP05ohF<dP03o`000?n5S=;o
QHcB00CoQHcB00?o0000oh:=eOn2SMD00_n2SMD8o`0000;oNY7N00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo000Wooooo`03o`000?oooooooooo
02?ooooo0_l00008ojK`m`[o00000_nWm?44o`0000Go[oO^0_l00008ok_hkP;o00002Oo8lNh00ol0
003ocN7WolgQi`02olgQi`?o00001Oo8iN`2o`00013oalkP00?o0000ol6je?l000004onl^MH01?l0
003o][KIo`000?l0000=ok2Uc@03o`000?nYX/ooZJ;?00goZJ;?00?o0000oj:NdOnRW]401onRW]43
o`0000;oXIC800?o0000oiZAbOnJTLT03?nJTLT00ol0003oU8o;oiB?b`0<oiB?b`03o`000?n>SLgo
SXg=00coSXg=00?o0000ohV<d?n9S=002on9S=000ol0003oQHcBohF<dP06ohF<dP03o`000?n5S=;o
QHcB00CoQHcB00?o0000oh:=eOn2SMD02On2SMD4o`0001Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`009oooool00ol0003oooooooooo`0Qooooo`;o00002onVl?L2o`00
00OoYoCa0ol00007ojogkP03o`000?nkn>ko^oS^00Oo^oS^00?o0000olSak_o8lNh02?o8lNh00ol0
003ocN7WolgQi`06olgQi`?o000000?ob>G/o`000?o7c^003oo7c^02o`0000?o`K[D00?o0000okbi
e_nl^MH04?nl^MH2o`0000oo/:G=00?o0000ojVRconYX/l03_nYX/l00ol0003oXYkAoj:Nd@03oj:N
d@?o00001_nQU<P00ol0003oVY79oiZAb@0<oiZAb@03o`000?nDSl_oU8o;00_oU8o;00?o0000ohj=
cOn>SLd03?n>SLd00ol0003oRHc@ohV<d00<ohV<d003o`000?n5S=;oQHcB00KoQHcB00?o0000ohF<
d_n5S=800on5S=800ol0003oPXgEoh:=e@0<oh:=e@03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`009oooool00ol0003oooooooooo`0Nooooo`?o
00002onVl?L2o`0000KoYoCa1?l00007ojogkP;o00002?nkn>h2o`0000Wob?7^0_l0000;olgQi`?o
00003oo7c^000ol0003o`K[Dol6je004ol6je003o`000?nl^MKo_;WF00go_;WF0_l000000onfZLco
0000ok2Uc@0?ok2Uc@03o`000?nYX/ooZJ;?00goZJ;?00?o0000oj:NdOnRW]400ol00009oj6Db003
o`000?nJTLWoVY7900coVY7900?o0000oiB?bonDSl/02onDSl/00ol0003oSXg=ohj=c@0<ohj=c@03
o`000?n9S=3oRHc@00coRHc@00?o0000ohF<d_n5S=801_n5S=800ol0003oQHcBohF<dP04ohF<dP03
o`000?n2SMGoPXgE00coPXgE00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo000Wooooo`03o`000?oooooooooo01cooooo0_l0000<ojK`m`;o0000
1OnWm?45o`0000Oo[oO^0_l00008ok_hkP;o00002_o8lNh00ol0003ocN7WolgQi`0:olgQi`05o`00
0?o:c]cob/kLol[>g?l000003Oo7c^000ol0003o`K[Dol6je005ol6je003o`000?nl^MKo_;WF00co
_;WF00?o0000okJYc?nfZL`00_nfZL`00ol0003o/:G=ok2Uc@0=ok2Uc@03o`000?nYX/ooZJ;?00go
ZJ;?0ol0000<oj6Db003o`000?nJTLWoVY7900coVY7900?o0000oiB?bonDSl/03?nDSl/00ol0003o
SXg=ohj=c@0<ohj=c@03o`000?n9S=3oRHc@00coRHc@00?o0000ohF<d_n5S=801_n5S=800ol0003o
QHcBohF<dP03ohF<dP03o`000?n2SMGoPXgE00coPXgE00?o0000ooooooooool04Oooool3o`0000Oo
oooo00?o0000ooooooooool01_ooool002Kooooo0ol0000Kooooo`;o00003OnVl?L00ol0003oYoCa
ojOdl@03ojOdl@;o00000_nWm?400ol0003o[oO^ojogkP06ojogkP03o`000?nkn>ko^oS^00Oo^oS^
00?o0000olSak_o8lNh02Oo8lNh00ol0003ocN7WolgQi`0:olgQi`03o`000?o:c]cob/kL00?ob/kL
00?o0000olO>h?o7c^002?o7c^02o`0000Wo`K[D00?o0000okbie_nl^MH02Onl^MH2o`0000Go]ZW<
00?o0000ok2UcOn`YLd03_n`YLd00ol0003oZJ;?ojVRc`09ojVRc`?o000000?oYYS6o`000?nQU<P0
3OnQU<P00ol0003oVY79oiZAb@0<oiZAb@03o`000?nDSl_oU8o;00_oU8o;00?o0000ohj=cOn>SLd0
3?n>SLd00ol0003oRHc@ohV<d00<ohV<d003o`000?n5S=;oQHcB00OoQHcB00?o0000ohF<d_n5S=80
0on5S=800ol0003oPXgEoh:=e@0<oh:=e@03o`000?oooooooooo00gooooo1?l000000ooooooo0000
ooooo`06ooooo`03o`000?oooooooooo00Kooooo000Wooooo`03o`000?oooooooooo01Sooooo0_l0
000=ojK`m`;o00000onWm?43o`0000;oYoCa0_l00007ojogkP;o00002?nkn>h2o`0000_ob?7^00?o
0000olgQioo=hNL02Oo=hNL2o`0000Oob/kL00?o0000olO>h?o7c^001_o7c^000ol0003o`K[Dol6j
e00:ol6je003o`000?nl^MKo_;WF00Ko_;WF0_l00008okJYc003o`000?n`YLgo/:G=00go/:G=00?o
0000ojVRconYX/l01_nYX/l3o`0000GoYYS600?o0000oj6Db?nQU<P02onQU<P00ol0003oVY79oiZA
b@0<oiZAb@03o`000?nDSl_oU8o;00coU8o;00?o0000ohj=cOn>SLd03?n>SLd00ol0003oRHc@ohV<
d00<ohV<d003o`000?n5S=;oQHcB00KoQHcB00?o0000ohF<d_n5S=800on5S=800ol0003oPXgEoh:=
e@0<oh:=e@03o`000?oooooooooo00[ooooo0ol00005ooooo`03o`000?oooooooooo00?ooooo00?o
EEEEofIVI_l000002?ooool002Oooooo00?o0000ooooooooool05_ooool5o`0000[oY_3g0_l00002
ojOdl@?o00000onWm?42o`0000So[oO^00?o0000ok_hk_nkn>h01onkn>h00ol0003ob?7^olSakP09
olSakP;o00002oo=hNL00ol0003ob/kLol[>g008ol[>g003o`000?o7c^3oalkP00?oalkP0_l0000>
ol6je003o`000?nl^MKo_;WF00?o_;WF0_l0000:okJYc003o`000?n`YLgo/:G=00ko/:G=00?o0000
ojVRconYX/l00_nYX/l3o`0000SoYYS600?o0000oj6Db?nQU<P03?nQU<P00ol0003oVY79oiZAb@0<
oiZAb@03o`000?nDSl_oU8o;00_oU8o;00?o0000ohj=cOn>SLd03?n>SLd00ol0003oRHc@ohV<d00<
ohV<d003o`000?n5S=;oQHcB00OoQHcB00?o0000ohF<d_n5S=800on5S=800ol0003oPXgEoh:=e@0<
oh:=e@03o`000?oooooooooo00Gooooo1?l00008ooooo`03o`000?oooooooooo00kooooo000Voooo
o`03o`000?oooooooooo01Gooooo0_l00005ojg^n0Go00000onVl?L2o`000004ojOdlOl0003o0000
o`0000GoYoCa00?o0000ojogk_n_mnh00_n_mnhCo`0000Sob?7^00?o0000olgQioo=hNL02_o=hNL0
0ol0003ob/kLol[>g00:ol[>g005o`000?o7c^3oalkPolO>h?l000004?o1^]@00ol0003o_;WFokbi
eP02okbieP03o`000?nfZLco]ZW<00_o]ZW<00?o0000ok2UcOn`YLd03On`YLd00ol0003oZJ;?o`00
0002o`0000coYYS600?o0000oj6Db?nQU<P02onQU<P00ol0003oVY79oiZAb@0<oiZAb@03o`000?nD
Sl_oU8o;00coU8o;00?o0000ohj=cOn>SLd03?n>SLd00ol0003oRHc@ohV<d00;ohV<d003o`000?n5
S=;oQHcB00SoQHcB00?o0000ohF<d_n5S=800_n5S=800ol0003oPXgEoh:=e@0<oh:=e@03o`000?oo
oooooooo00;ooooo0ol0000<ooooo`03o`000?oooooooooo00kooooo000Vooooo`03o`000?oooooo
oooo01?ooooo0_l0000<ojg^n1?o00000onimO400ol0003o`oC_ol?dk`07ol?dk`03o`000?o<k>_o
c>c[00?oc>c[1Ol00002olSakP03o`000?o=hNOocN7W00[ocN7W00?o0000ol[>g?o:c]`03?o:c]`0
0ol0003oalkPo`00000Bol6je004o`000?nl^MKo0000o`0000oo]ZW<00?o0000ok2UcOn`YLd03?n`
YLd2o`0000ooYYS600?o0000oj6Db?nQU<P03?nQU<P00ol0003oVY79oiZAb@0<oiZAb@03o`000?nD
Sl_oU8o;00_oU8o;00?o0000ohj=cOn>SLd03?n>SLd00ol0003oRHc@ohV<d00<ohV<d003o`000?n5
S=;oQHcB00SoQHcB00Go0000ohF<d_n5S=;oQHcBo`00000?oh:=e@Co00004?ooool00ol0003ooooo
ooooo`0=ooooo`009_ooool00ol0003oooooooooo`0Aooooo`;o00003On]k_P4o`0000Oo/O?d0_l0
0008okWel@;o00002?o3m>l2o`0000_oc>c[1?l00009olgQi`;o00003oo:c]`2o`0001?o`K[D0_l0
000AokJYc003o`000?n`YLgo/:G=00[o/:G=0_l000000on/VlGo0000ojJHaP0>ojJHaP03o`000?nQ
U<SoXIC800coXIC800?o0000oiZAbOnJTLT03?nJTLT00ol0003oU8o;oiB?b`0;oiB?b`03o`000?n>
SLgoSXg=00coSXg=00?o0000ohV<d?n9S=003?n9S=000ol0003oQHcBohF<dP08ohF<dP03o`000?n5
S=;oQHcB00;oQHcB00?o0000oh:=eOn2SMD03?n2SMD00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00gooooo000Uooooo`?o00004Oooool00ol0003o[Nkhojg^n00;ojg^n0?o00002Onalo@0
0ol0003o^OGaokWel@07okWel@03o`000?o3m>oo`oC_00Oo`oC_00?o0000olc/joo<k>/02_o<k>/0
0ol0003ocmgSoloMh`02oloMh`?o00001Oo=hNL00ol0003ob/kLol[>g00>ol[>g003o`000?o4_=;o
000001;o`K[D00?o0000ok^/bol000004_nfZL`00ol0003o/:G=ok2Uc@07ok2Uc@;o00001?n/VlD0
0ol0003oYYS6ojJHaP0=ojJHaP03o`000?nQU<SoXIC800_oXIC800?o0000oiZAbOnJTLT03?nJTLT0
0ol0003oU8o;oiB?b`0<oiB?b`03o`000?n>SLgoSXg=00coSXg=00?o0000ohV<d?n9S=003?n9S=00
0ol0003oQHcBohF<dP08ohF<dP05o`000?n5S=;oQHcBohF<d_l000003on2SMD00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00gooooo000Vooooo`03o`000?oooooooooo00kooooo0_l0000<
ojg^n0?o00002Onalo@2o`0000Wo^OGa00?o0000ol?dkoo3m>l01oo3m>l00ol0003oc>c[olc/j`09
olc/j`;o00002?o?gN<3o`000003olgQiol0003ob/kL00oob/kL00Go0000olBld_o4_=;oa;cBo`00
000?ol6je0;o00000onk[</00ol0003o]ZW<okJYc00?okJYc003o`000?n`YLgo/:G=00Co/:G=0ol0
0006ojbKa@03o`000?nVV<KoYYS600goYYS600?o0000oj6Db?nQU<P03?nQU<P00ol0003oVY79oiZA
b@0<oiZAb@03o`000?nDSl_oU8o;00_oU8o;00?o0000ohj=cOn>SLd03?n>SLd00ol0003oRHc@ohV<
d00<ohV<d003o`000?n5S=;oQHcB00WoQHcB00Go0000ohF<d_n5S=;oQHcBo`00000>oh:=e@03o`00
0?oooooooooo013ooooo00?o0000ooooooooool03Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Goc<c<ob4Q8Ol0
003o8B4Qolc<c006ooooo`03o`000?oooooooooo00cooooo0_l0000;ojg^n0?o00002_nalo@2o`00
00Wo^OGa0_l00008ol?dk`;o00002oo<k>/00ol0003ocmgSoloMh`0:oloMh`?o00003_o:c]`2o`00
00Goa;cB00?o0000ol6je?o1^]@02oo1^]@00ol0003o^jc;ok^/b`04ok^/b`03o`000?nfZLco]ZW<
00oo]ZW<00Co0000ok2UcOn`YLgo/:G=0_l0000:ojbKa@03o`000?nVV<KoYYS600goYYS600?o0000
oj6Db?nQU<P02onQU<P00ol0003oVY79oiZAb@0<oiZAb@03o`000?nDSl_oU8o;00GoU8o;;_l00003
ohF<dP04o`000?n5S=;oQHcBo`0000ooPXgE00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0=ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool02_ooool2o`0000[o[Nkh1?l0000:ok7cm0;o00002_nimO400ol0003o`oC_ol?dk`07ol?dk`03
o`000?o<k>_oc>c[00[oc>c[00?o0000oloMhoo?gN<02_o?gN<01Ol0003oc<cJolc<f_o<c=[o0000
00cob/kL00?o0000olBld_o4_=801_o4_=800ol0003o`K[Dol6je008ol6je0;o00001onk[</00ol0
003o]ZW<okJYc00?okJYc004o`000?n`YLgo0000o`0000co[9_500?o0000ojJHa_nVV<H03OnVV<H0
0ol0003oXIC8oj6Db00<oj6Db003o`000?nJTLWoVY7900[oVY792Ol00007oiJ;aP03o`000?nAR/So
TH[800coTH[800?o0000ohj:bon>R//03?n>R//00ol0003oRX[=ohZ:c@06ohZ:cA3o00001_n2SMD0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go0000oooooooooooooooo
o`000005ooooo`03o`000?oooooooooo00Wooooo2?l00003ojg^n0Go00002onalo@00ol0003o^OGa
okWel@08okWel@;o00002?o3m>l2o`0000_oc>c[0_l0000<oloMh`03o`000?o<c=[oc<cJ00?oc<cJ
00?o0000ol[>g?o:c]`02?o:c]`00ol0003oa;cBolBldP08olBldP03o`000?o1^]Co`K[D00Ko`K[D
00?o0000ok^/bonk[</02?nk[</00ol0003o]ZW<okJYc00>okJYc0;o00003_n/VlD00ol0003oYYS6
ojJHaP0>ojJHaP03o`000?nQU<SoXIC800_oXIC800?o0000oiZAbOnJTLT01OnJTLT5o`0000;oVhg4
00?o0000oiJ;a_nFRlH03?nFRlH00ol0003oTH[8oi6:b00<oi6:b003o`000?n>R/_oSX[;00coSX[;
00?o0000ohZ:cOn:R/d02On:R/d01?l0003oRX[=ohZ:cOl00008ohR<d0So00004?ooool00ol0003o
ooooooooo`0=ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801Oooool00ol0003oooooooooo`07
ooooo`;o00002?naj_P<o`0000Go/O?d0_l0000:okWel@03o`000?o3m>oo`oC_00Oo`oC_00?o0000
olc/joo<k>/02_o<k>/00ol0003ocmgSoloMh`0;oloMh`03o`000?o<c=[oc<cJ00Goc<cJ00?o0000
ol[>g?o:c]`01_o:c]`00ol0003oa;cBolBldP0:olBldP03o`000?o1^]Co`K[D00Co`K[D00?o0000
ok^/bonk[</02Onk[</00ol0003o]ZW<okJYc00=okJYc003o`000?naWlGo000000oo[9_500?o0000
ojJHa_nVV<H03OnVV<H00ol0003oXIC8oj6Db00;oj6Db003o`000?nJTLWoVY7900Go00002?nKSL@0
0ol0003oUX_6oiJ;aP0;oiJ;aP03o`000?nAR/SoTH[800coTH[800?o0000ohj:bon>R//03?n>R//0
0ol0003oRX[=ohZ:c@0:ohZ:c@04o`000?n:R/goRX[=o`0000koR8c@00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0<ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000ooooooooooooooooo`000003ooooo`05olc<c?l0003o0000o`000?o<c<`01Oooool00ol0003o
ooooooooo`05ooooo`;o00001onaj_P3o`0000;o/N[h0_l00008okO_m@_o00001OnimO400ol0003o
`oC_ol?dk`07ol?dk`03o`000?o<k>_oc>c[00Woc>c[0_l0000<oloMh`;o00002Oo<c=X00ol0003o
b/kLol[>g003ol[>g0;o00003_o4_=801?l0003o`K[Dol6je?o1^]@2o`0000go^jc;00?o0000okJY
c?nfZL`02_nfZL`2o`0000?o/Io500?o0000ojbKaOn/VlD03?n/VlD00ol0003oYYS6ojJHaP0=ojJH
aP03o`000?nQU<SoXIC800[oXIC81?l0000=oi^=a003o`000?nFRlKoUX_600_oUX_600?o0000oi6:
b?nAR/P03?nAR/P00ol0003oSX[;ohj:b`0<ohj:b`03o`000?n:R/goRX[=00_oRX[=00?o0000ohZ:
cOl000003on8S=000ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo0003ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
okZj^_oooooo^[Zjoa0@4004ooooo`?o00001?ooool2o`0000Oo/N[h0_l00004ok7Zn003o`000?ng
koGo]noe00[o]noe00?o0000okoal_nolO801_nolO8Bo`0000Soc>c[00?o0000oloMhoo?gN<02oo?
gN<00ol0003oc<cJolc<fP0:olc<fP05o`000?o:c]cob/kLol[>g?l000004Oo4_=800ol0003o`K[D
o`00000@ok^/b`03o`000?nfZLco]ZW<00Oo]ZW<0_l00005ok6Oa@03o`000?n/VlGo[9_500go[9_5
00?o0000ojJHa_nVV<H03OnVV<H00ol0003oXIC8oj6Db004oj6Db0Go00000_nPT<<00ol0003oVhg4
oi^=a00<oi^=a003o`000?nFRlKoUX_600coUX_600?o0000oi6:b?nAR/P03?nAR/P00ol0003oSX[;
ohj:b`0<ohj:b`03o`000?n:R/goRX[=00[oRX[=00?o0000ohZ:cOl000003on8S=000ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00cooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go0000okZj^_oooooo^[Zjo`000005oooo
o`04o`000?ooooooooooooooo`;o00001_naj_P3o`0000Co/N[h0_l0000;okO_m@;o00002onolO80
0ol0003oano^olO_kP07olO_kP03o`000?o>inSoc^OX00?oc^OX1Ol00002olc/j`03o`000?o?gN?o
cmgS00_ocmgS00?o0000olc<f_o<c=X03?o<c=X00ol0003ob/kLo`00000BolBldP;o00004Onk[</0
0ol0003o]ZW<okJYc006okJYc003o`000?naWlGo/Io500Ko/Io500?o0000ojbKaOn/VlD03?n/VlD0
0ol0003oYYS6ojJHaP0=ojJHaP03o`000?nQU<SoXIC800Co00002?nPT<<00ol0003oVhg4oi^=a00<
oi^=a003o`000?nFRlKoUX_600_oUX_600?o0000oi6:b?nAR/P03?nAR/P00ol0003oSX[;ohj:b`0<
ohj:b`03o`000?n:R/goRX[=00_oRX[=00?o0000ohZ:cOl000003_n8S=000ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@05ooooo`04o`00
0?oooooo0000o`0000Go/N[h0ol00005ok7Zn0;o00003?ngkoD00ol0003o_o7bokoalP09okoalP;o
00002Oo7knh00ol0003oc^OXolkWj009olkWj0?o00002oo?gN<2o`0000ooc<cJ0_l0000BolBldP03
o`000?nn[/[o000001;o^jc;00?o0000okJYc?nfZL`00onfZL`2o`0000Wo/Io500?o0000ojbKaOn/
VlD03On/VlD00ol0003oYYS6ojJHaP0<ojJHaP?o00003?nPT<<00ol0003oVhg4oi^=a00<oi^=a003
o`000?nFRlKoUX_600coUX_600?o0000oi6:b?nAR/P03?nAR/P00ol0003oSX[;ohj:b`0<ohj:b`03
o`000?n:R/goRX[=00_oRX[=0_l0000?ohR<d003o`000?oooooooooo00gooooo00?o0000oooooooo
ool03?ooool002Gooooo0_l00004ok7Zn0?o00001_naj_P2o`0000co]noe0_l0000;okoalP03o`00
0?o7knkoano^00Soano^00?o0000olkWj?o>inP02Oo>inP01?l0003ocm[QoloJhOo?f^42o`0000So
cmgS00?o0000olc<f_o<c=X03_o<c=X00ol0003oakgAo`00000AolBldP05o`000?nn[/[o_Zk:okj^
b_l000004Onk[</01?l0003o]ZW<okJYc?nfZL`2o`0000_o/Io500?o0000ojbKaOn/VlD03On/VlD0
0ol0003oYYS6ojJHaP09ojJHaP?o000000?oYI?2o`000?nPT<<03?nPT<<00ol0003oVhg4oi^=a00=
oi^=a003o`000?nFRlKoUX_600_oUX_600?o0000oi6:b?nAR/P03?nAR/P00ol0003oSX[;ohj:b`0<
ohj:b`03o`000?n:R/goRX[=00_oRX[=0_l0000?ohR<d003o`000?oooooooooo00gooooo00?o0000
ooooooooool03?ooool002Cooooo1ol00008ok7Zn003o`000?ngkoGo]noe00[o]noe0_l0000;okoa
lP;o00002Oo7knh2o`0000_oc^OX00?o0000oloJhOo?f^401?o?f^43o`0000CocmgS00?o0000olc<
f_o<c=X03_o<c=X01Ol0003oakgAolNmdOo7_M7o000000koa;cB0_l00005okj^bP03o`000?nk[<_o
^jc;00oo^jc;00?o0000okJYc?l000003_naWlD00ol0003o[9_5ojbKa@0<ojbKa@03o`000?nVV<Ko
YYS600KoYYS60ol00005ojFC`P03o`000?nPT<?oX93300_oX93300?o0000oi^=a?nKSL@03?nKSL@0
0ol0003oUX_6oiJ;aP0;oiJ;aP03o`000?nAR/SoTH[800goTH[800?o0000ohj:bon>R//03?n>R//0
0ol0003oRX[=ohZ:c@0;ohZ:c@;o00003_n8S=000ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00cooooo000Tooooo`[o00000onaj_P2o`0000co]noe00?o0000okoal_nolO802OnolO82o`00
00[oano^00?o0000olkWj?o>inP02_o>inP00ol0003ocm[QoloJh@08oloJh@;o000000?ocmgSo`00
0?o<c=X03oo<c=X00ol0003oakgAolNmd@03olNmd@03o`000?o4_=;oa;cB00[oa;cB00?o0000okj^
b_nn[/X01Onn[/X00ol0003o^jc;ok^/b`0?ok^/b`;o00003onaWlD00ol0003o[9_5ojbKa@0=ojbK
a@03o`000?nVV<KoYYS600;oYYS60ol00008ojFC`P03o`000?nPT<?oX93300_oX93300?o0000oi^=
a?nKSL@03?nKSL@00ol0003oUX_6oiJ;aP0<oiJ;aP03o`000?nAR/SoTH[800coTH[800?o0000ohj:
bon>R//03?n>R//00ol0003oRX[=ohZ:c@0<ohZ:c@03o`000?n8S=3oR8c@00goR8c@00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0;ooooo`009?ooool2o`0000Sooooo1_l00009okO_m@;o
00002onolO800ol0003oano^olO_kP09olO_kP03o`000?o>inSoc^OX00Woc^OX0_l0000<oloJh@?o
00003oo<c=X00ol0003oakgAolNmd@05olNmd@03o`000?o4_=;oa;cB00Soa;cB00?o0000okj^b_nn
[/X01onn[/X00ol0003o^jc;ok^/b`0=ok^/b`03o`000?nfX/Go0000013o/Io500?o0000ojbKaOn/
VlD03?n/VlD00ol0003oYYS6o`000002o`0000_oYI?200?o0000oj2@`onPT<<03?nPT<<00ol0003o
Vhg4oi^=a00<oi^=a003o`000?nFRlKoUX_600_oUX_600?o0000oi6:b?nAR/P03?nAR/P00ol0003o
SX[;ohj:b`0<ohj:b`03o`000?n:R/goRX[=00goRX[=00?o0000ohR<d?n8S=003?n8S=000ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo00_ooooo
1Ol00003okO_m@03o`000?nolO;o_o7b00Wo_o7b0_l0000:olO_kP;o00002oo>inP00ol0003ocm[Q
oloJh@0;oloJh@05o`000?o=bmSocL_Holg;f?l000003?o<c=X2o`0000WoakgA00?o0000olBld_o4
_=801_o4_=800ol0003o_Zk:okj^bP08okj^bP03o`000?nk[<_o^jc;00_o^jc;0_l00003okJRa@03
o`000?naWlGo/Io500go/Io500?o0000ojbKaOn/VlD03?n/VlD2o`0000ooYI?200?o0000oj2@`onP
T<<02onPT<<00ol0003oVhg4oi^=a00<oi^=a003o`000?nFRlKoUX_600_oUX_600?o0000oi6:b?nA
R/P03OnAR/P00ol0003oSX[;ohj:b`0<ohj:b`03o`000?n:R/goRX[=00coRX[=00?o0000ohR<d?n8
S=003On8S=000ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo000Wooooo`03o`00
0?oooooooooo00oooooo2Ol00005okoalP03o`000?o7knkoano^00Woano^00?o0000olkWj?o>inP0
2_o>inP00ol0003ocm[QoloJh@0;oloJh@03o`000?o=bmSocL_H00?ocL_H00?o0000olc<f_o<c=X0
2?o<c=X00ol0003oakgAolNmd@0:olNmd@03o`000?o4_=;oa;cB00?oa;cB0_l0000<okj^bP03o`00
0?nk[<_o^jc;00Wo^jc;00?o0000okJRaOnfX/D00onfX/D00ol0003o/Io5ok6Oa@0>ok6Oa@03o`00
0?n/VlGo[9_500Wo[9_50_l000000onYU/;o0000ojFC`P0>ojFC`P03o`000?nPT<?oX93300_oX933
00?o0000oi^=a?nKSL@03?nKSL@00ol0003oUX_6oiJ;aP0<oiJ;aP03o`000?nAR/SoTH[800coTH[8
00?o0000ohj:bon>R//03?n>R//00ol0003oRX[=ohZ:c@0<ohZ:c@;o00003_n8S=000ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00_ooooo000Xooooo`03o`000?oooooooooo01Oooooo2?l0
0008olO_kP03o`000?o>inSoc^OX00Woc^OX0_l0000=oloJh@03o`000?o=bmSocL_H00GocL_H0_l0
0007olc<fP03o`000?o7_M7oakgA00coakgA00Go0000olBld_o4_=;oa;cBo`00000?okj^bP03o`00
0?nk[<_o^jc;00Ko^jc;0_l00007okJRa@03o`000?naWlGo/Io500go/Io500?o0000ojbKaOn/VlD0
1on/VlD2o`0000CoZIK200?o0000ojFC`_nUTl803OnUTl800ol0003oX933oj2@``0;oj2@``03o`00
0?nKSLCoVhg400coVhg400?o0000oiJ;a_nFRlH02onFRlH00ol0003oTH[8oi6:b00=oi6:b003o`00
0?n>R/_oSX[;00coSX[;00?o0000ohZ:cOn:R/d03?n:R/d2o`0000goR8c@00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`00:Oooool2o`0001oooooo1Ol00002olO_kP03o`000?o>
inSoc^OX00Woc^OX00?o0000oloJhOo?f^403?o?f^400ol0003ocL_Holg;f008olg;f003o`000?o<
c=[oc<cJ00?oc<cJ00?o0000olNmdOo7_M403_o7_M400ol0003oa;cBo`00000@okj^bP03o`000?nk
[<_o^jc;00Go^jc;00?o0000okJRaOnfX/D01onfX/D00ol0003o/Io5ok6Oa@0=ok6Oa@03o`000?n/
VlGo[9_500Co[9_50ol00006ojVF`P03o`000?nUTl;oYI?200goYI?200?o0000oj2@`onPT<<02onP
T<<00ol0003oVhg4oi^=a00<oi^=a003o`000?nFRlKoUX_600coUX_600?o0000oi6:b?nAR/P03?nA
R/P00ol0003oSX[;ohj:b`0<ohj:b`03o`000?n:R/goRX[=00coRX[=00?o0000ohR<d?l000003On8
S=000ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo000[ooooo`03o`000?oooooo
oooo027ooooo1Ol00008olkWj003o`000?o?f^7ocm[Q00_ocm[Q0_l0000<olg;f005o`000?o<c=[o
c<cJolc<f_l000004Oo7_M42o`0001;o_Zk:00?o0000ok^/bonk[</00onk[</00ol0003o]Z;5okJR
a@09okJRa@03o`000?naWlGo/Io500go/Io500Co0000ojbKaOn/VlGo[9_50_l00009ojVF`P03o`00
0?nUTl;oYI?200goYI?200?o0000oj2@`onPT<<02onPT<<00ol0003oVhg4oi^=a00=oi^=a003o`00
0?nFRlKoUX_600_oUX_600?o0000oi6:b?nAR/P03?nAR/P00ol0003oSX[;ohj:b`0<ohj:b`03o`00
0?n:R/goRX[=00coRX[=00?o0000ohR<d?l000003On8S=000ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo000/ooooo`03o`000?oooooooooo02Gooooo1Ol00002olkWj003o`000?o?
f^7ocm[Q00_ocm[Q00?o0000olg;f?o=bmP03Oo=bmP00ol0003oc<cJo`00000AolNmd@03o`000?o1
/L[o000001;o_Zk:00Co0000ok^/bonk[<_o^jc;0_l0000<okJRa@03o`000?naWlGo/Io500go/Io5
00Co0000ojbKaOl0003o00003?nYU/800ol0003oYI?2ojFC`P0=ojFC`P03o`000?nPT<?oX93300_o
X93300?o0000oi^=a?nKSL@03?nKSL@00ol0003oUX_6oiJ;aP0;oiJ;aP03o`000?nAR/SoTH[800Ko
TH[8;_l00006ohR<d003o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool002gooooo
00?o0000ooooooooool0:Oooool3o`0000cocm[Q00?o0000olg;f?o=bmP03_o=bmP2o`00017oakgA
00Go0000ol6ab_o1/L[o`K7:o`00000Bokj^bP03o`000?nk[<_o000000oo]Z;500?o0000ok6OaOna
WlD03?naWlD2o`0000koZIK200?o0000ojFC`_nUTl803OnUTl800ol0003oX933oj2@``0;oj2@``03
o`000?nKSLCoVhg400coVhg400?o0000oiJ;a_nFRlH01OnFRlH?o`0000OoU8_600?o0000oi:;bOnB
RlT03?nBRlT00ol0003oShc;ohn<b`0<ohn<b`04o`000?n>S/ooSXk?o`0000GoSXk?2?l0000=oooo
o`03o`000?oooooooooo00[ooooo000^ooooo`;o0000;?ooool3o`0000Socm[Q00?o0000olg;f?o=
bmP03_o=bmP01?l0003ob;k@olRnd?l0000>olNmd@;o00001Oo1/LX00ol0003o_Zk:okj^bP0?okj^
bP;o00004?nfX/D00ol0003o/Io5ok6Oa@0:ok6Oa@;o000000?o[YW2o`000?nYU/803_nYU/800ol0
003oYI?2ojFC`P0<ojFC`P03o`000?nPT<?oX93300coX93300?o0000oi^=a?nKSL@02_nKSL@9o`00
00OoV8_400?o0000oiB;a_nDRlH03OnDRlH00ol0003oTX_9oi:;b@0<oi:;b@03o`000?n?S<_oShc;
00coShc;00?o0000ohj>col000003?n>S/l00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00[ooooo000`ooooo`03o`000?oooooooooo02cooooo0_l00005oloJh@03o`000?o=bmSocL_H00ko
cL_H00?o0000olRnd?o8_]000_o8_]000ol0003oakgAolNmd@0:olNmd@03o`000?o1/L[o`K7:00Go
`K7:00?o0000okj^b_nn[/X03_nn[/X00ol0003o^JG5o`00000@okJRa@03o`000?naWlGo/Io500So
/Io50_l00004ojjI`P03o`000?nYU/;oZIK200coZIK200?o0000ojFC`_nUTl803OnUTl800ol0003o
X933oj2@``0;oj2@``03o`000?nKSLCoVhg400GoVhg41Ol00002oib=``03o`000?nHRlCoV8_400co
V8_400?o0000oiB;a_nDRlH03?nDRlH00ol0003oTX_9oi:;b@0<oi:;b@03o`000?n?S<_oShc;00co
Shc;00Co0000ohj>con>S/oo00003?n>S/l00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo000aooooo`03o`000?oooooooooo02gooooo0ol000000oo?f^7o0000olg;f00?olg;f003
o`000?o8_]3ob;k@00Cob;k@00?o0000olNmdOo7_M402?o7_M400ol0003o`K7:ol6abP07ol6abP03
o`000?nn[/[o_Zk:00_o_Zk:0_l00003okVUa@03o`000?nfX/Go]Z;500ko]Z;500?o0000ok6OaOna
WlD01OnaWlD2o`0000Ko[YW200?o0000ojVF`_nYU/803?nYU/800ol0003oYI?2ojFC`P0=ojFC`P03
o`000?nPT<?oX93300_oX93300?o0000oi^=a?nKSL@01Ol00008oib=``03o`000?nHRlCoV8_400_o
V8_400?o0000oiB;a_nDRlH03?nDRlH00ol0003oTX_9oi:;b@0<oi:;b@03o`000?n?S<_oShc;00go
Shc;00Co0000ohj>con>S/oo00002on>S/l00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo000booooo`03o`000?oooooooooo02oooooo0_l0000>olg;f0;o00002?o8_]000ol0003o
akgAolNmd@06olNmd@03o`000?o1/L[o`K7:00Wo`K7:00?o0000okj^b_nn[/X02Onn[/X00ol0003o
^JG5okVUa@03okVUa@03o`000?nfX/Go]Z;500ko]Z;500?o0000ok6OaOnaWlD01?naWlD00ol0003o
[YW2ojjI`P06ojjI`P03o`000?nYU/;oZIK200goZIK200?o0000ojFC`_nUTl803OnUTl800ol0003o
X933oj2@``09oj2@``Co00003OnLSL<00ol0003oV8_4oiR;a00;oiR;a003o`000?nDRlKoU8_600go
U8_600?o0000oi:;bOnBRlT03?nBRlT00ol0003oShc;ohn<b`0<ohn<b`05o`000?n>S/ooSXk?ohj>
col000002on>S/l00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000cooooo`03
o`000?oooooooooo033ooooo00?o0000olg;f?o=bmP02_o=bmP00ol0003ob;k@olRnd009olRnd003
o`000?o7_M7oakgA00?oakgA0_l0000<ol6abP03o`000?nn[/[o_Zk:00Oo_Zk:0_l00007okVUa@03
o`000?nfX/Go]Z;500ko]Z;500Co0000ok6OaOnaWlGo/Io50_l0000:ojjI`P03o`000?nYU/;oZIK2
00coZIK200?o0000ojFC`_nUTl803OnUTl800ol0003oX933oj2@``04oj2@``Go00000_nPSl800ol0
003oW8g3oib=``0<oib=``03o`000?nHRlCoV8_400coV8_400?o0000oiB;a_nDRlH03?nDRlH00ol0
003oTX_9oi:;b@0<oi:;b@03o`000?n?S<_oShc;00coShc;00Go0000ohj>con>S/ooSXk?o`00000;
ohj>c`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool003Cooooo0_l0000aoooo
o`03o`000?o=bmSocL_H00SocL_H00?o0000olRnd?o8_]002oo8_]001Ol0003oakgAolNmdOo7_M7o
000000oo`K7:00?o0000okj^b_nn[/X01Onn[/X00ol0003o^JG5okVUa@07okVUa@03o`000?nfX/Go
]Z;500ko]Z;500Co0000ok6OaOl0003o00003?n^VL800ol0003oZIK2ojVF`P0<ojVF`P03o`000?nU
Tl;oYI?200goYI?200?o0000oj2@`onPT<<01?l00008oj2?`P03o`000?nLSL?oW8g300coW8g300?o
0000oiR;a?nHRl@02onHRl@00ol0003oU8_6oiB;aP0=oiB;aP03o`000?nBRlWoTX_900coTX_900?o
0000ohn<bon?S</03?n?S</01Ol0003oSXk?ohj>con>S/oo000000_oSXk?00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`00=_ooool00ol0003oooooooooo`0_ooooo`03o`000?o=
bmSocL_H00GocL_H0_l0000?olRnd003o`000?o7_M7o0000017o`K7:00?o0000okj^b_nn[/X00onn
[/X00ol0003o^JG5okVUa@09okVUa@03o`000?nfX/Go]Z;500go]Z;50_l0000?ojjI`P03o`000?nY
U/;oZIK200coZIK200?o0000ojFC`_nUTl803?nUTl83o`0000coX8o200?o0000oib=`onLSL<03?nL
SL<00ol0003oV8_4oiR;a00<oiR;a003o`000?nDRlKoU8_600coU8_600?o0000oi:;bOnBRlT03?nB
RlT00ol0003oShc;ohn<b`0<ohn<b`03o`000?n>S/ooSXk?00;oSXk?00?o0000ohj>con>S/l02?n>
S/l00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo000gooooo`03o`000?oooooo
oooo02oooooo00?o0000olg;f?o=bmP00oo=bmP00ol0003ob;k@olRnd00?olRnd0;o00004_o1/LX0
1?l0003o_Zk:okj^b_nn[/X2o`0000co^JG500?o0000okJRaOnfX/D03?nfX/D00ol0003o/Yc2o`00
000?ojjI`P03o`000?nYU/;oZIK200coZIK200?o0000ojFC`_nUTl802OnUTl83o`000003ojBA`Ol0
003oX8o200coX8o200?o0000oib=`onLSL<03?nLSL<00ol0003oV8_4oiR;a00<oiR;a003o`000?nD
RlKoU8_600goU8_600?o0000oi:;bOnBRlT03?nBRlT00ol0003oShc;ohn<b`0<ohn<b`03o`000?n>
S/ooSXk?00;oSXk?00?o0000ohj>con>S/l02?n>S/l00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Wooooo000hooooo`03o`000?oooooooooo02oooooo00Go0000olg;f?o=bmSocL_Ho`00
000AolRnd003o`000?o3/l_o000001?o`K7:00?o0000okj^b_l000003oniYLD00ol0003o]Z;5okJR
a@09okJRa@;o00000onbW<800ol0003o[YW2ojjI`P0<ojjI`P03o`000?nYU/;oZIK200goZIK200?o
0000ojFC`_nUTl801OnUTl83o`0000GoY97100?o0000oj2?`_nPSl802onPSl800ol0003oW8g3oib=
``0<oib=``03o`000?nHRlCoV8_400_oV8_400?o0000oiB;a_nDRlH03OnDRlH00ol0003oTX_9oi:;
b@0<oi:;b@03o`000?n?S<_oShc;00coShc;00?o0000ohj>con>S/l00_n>S/l00ol0003oSXk?ohj>
c`08ohj>c`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool003Wooooo0_l0000`
ooooo`03o`000?o=bmSo0000017ob;k@00Go0000ol>cboo3/l_o`k?;o`00000Bol6abP;o00004?ni
YLD00ol0003o]Z;5okJRa@07okJRa@;o00001OnbW<800ol0003o[YW2ojjI`P0=ojjI`P03o`000?nY
U/;oZIK200coZIK200?o0000ojFC`_nUTl800_nUTl83o`0000SoY97100?o0000oj2?`_nPSl802onP
Sl800ol0003oW8g3oib=``0<oib=``03o`000?nHRlCoV8_400coV8_400?o0000oiB;a_nDRlH03?nD
RlH00ol0003oTX_9oi:;b@0<oi:;b@03o`000?n?S<_oShc;00goShc;00?o0000ohj>con>S/l00_n>
S/l00ol0003oSXk?ohj>c`07ohj>c`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Ooo
ool003_ooooo00?o0000ooooooooool0;_ooool2o`00013ob;k@00?o0000ol>cboo3/l/00oo3/l/0
0ol0003o`K7:ol6abP0>ol6abP03o`000?nlZ<Ko0000017o^JG500?o0000okJRaOnfX/D01OnfX/D0
0ol0003o/Yc2ok:L`P05ok:L`P03o`000?n^VL;o[YW200go[YW200?o0000ojVF`_nYU/803?nYU/80
0ol0003oYI?2o`000002o`0000_oY97100?o0000oj2?`_nPSl803?nPSl800ol0003oW8g3oib=``0<
oib=``03o`000?nHRlCoV8_400_oV8_400?o0000oiB;a_nDRlH03OnDRlH00ol0003oTX_9oi:;b@0<
oi:;b@03o`000?n?S<_oShc;00coShc;00?o0000ohj>con>S/l00on>S/l00ol0003oSXk?ohj>c`07
ohj>c`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool003cooooo00?o0000oooo
ooooool0;oooool00ol0003ob;k@olRnd00<olRnd003o`000?o3/l_o`k?;00Co`k?;00?o0000ol6a
b_o1/LX03Oo1/LX01Ol0003o_:S6okbXa_nlZ<Ko0000013o^JG500?o0000okJRaOnfX/D00onfX/D2
o`0000Wo/Yc200?o0000ojjI`_n^VL803?n^VL800ol0003oZIK2ojVF`P0<ojVF`P;o00003onTTL40
0ol0003oX8o2oj2?`P0;oj2?`P03o`000?nLSL?oW8g300coW8g300?o0000oiR;a?nHRl@02onHRl@0
0ol0003oU8_6oiB;aP0=oiB;aP03o`000?nBRlWoTX_900coTX_900?o0000ohn<bon?S</03?n?S</0
0ol0003oSXk?ohj>c`04ohj>c`03o`000?n>S/ooSXk?00KoSXk?00?o0000ooooooooool01oooool0
0ol0003oooooooooo`09ooooo`00?Oooool00ol0003oooooooooo`0_ooooo`03o`000?o8_]3ob;k@
00Wob;k@0_l00008ol>cb`03o`000?o1/L[o`K7:00[o`K7:0_l00004okbXaP03o`000?niYLGo^JG5
00oo^JG500?o0000okJRaOnfX/D00_l0000;ok:L`P03o`000?n^VL;o[YW200go[YW200?o0000ojVF
`_nYU/802OnYU/82o`000003ojRD`Ol0003oY97100koY97100?o0000oj2?`_nPSl802onPSl800ol0
003oW8g3oib=``0<oib=``03o`000?nHRlCoV8_400coV8_400?o0000oiB;a_nDRlH03OnDRlH00ol0
003oTX_9oi:;b@0<oi:;b@03o`000?n?S<_oShc;00coShc;00?o0000ohj>con>S/l00on>S/l00ol0
003oSXk?ohj>c`07ohj>c`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool003ko
oooo0_l0000`ooooo`03o`000?o8_]3ob;k@00Oob;k@00?o0000ol>cboo3/l/02Oo3/l/00ol0003o
`K7:ol6abP08ol6abP03o`000?nlZ<Ko_:S600Go_:S600?o0000okVUaOniYLD03_niYLD00ol0003o
]Z;5o`00000>ok:L`P03o`000?n^VL;o[YW200co[YW200?o0000ojVF`_nYU/801onYU/82o`0000Co
Z9C100?o0000ojBA`OnTTL403?nTTL400ol0003oX8o2oj2?`P0<oj2?`P03o`000?nLSL?oW8g300co
W8g300?o0000oiR;a?nHRl@02onHRl@00ol0003oU8_6oiB;aP0=oiB;aP03o`000?nBRlWoTX_900co
TX_900?o0000ohn<bon?S</03?n?S</00ol0003oSXk?ohj>c`04ohj>c`03o`000?n>S/ooSXk?00Ko
SXk?00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`00@?ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?o8_]3ob;k@00Gob;k@00?o0000ol>cboo3/l/02_o3/l/00ol0003o`K7:
ol6abP07ol6abP03o`000?nlZ<Ko_:S600Ko_:S600?o0000okVUaOniYLD03_niYLD2o`0000oo/Yc2
00?o0000ojjI`_n^VL803On^VL800ol0003oZIK2ojVF`P03ojVF`P?o00001_nXU<400ol0003oY971
ojBA`@0=ojBA`@03o`000?nPSl;oX8o200_oX8o200?o0000oib=`onLSL<03?nLSL<00ol0003oV8_4
oiR;a00<oiR;a003o`000?nDRlKoU8_600coU8_600?o0000oi:;bOnBRlT03?nBRlT00ol0003oShc;
ohn<b`06ohn<baSo00002?ooool00ol0003oooooooooo`08ooooo`00@Oooool00ol0003ooooooooo
o`0^ooooo`03o`000?o8_]3ob;k@00?ob;k@00?o0000ol>cboo3/l/03?o3/l/00ol0003o`K7:ol6a
bP05ol6abP03o`000?nlZ<Ko_:S600So_:S600?o0000okVUaOniYLD03?niYLD00ol0003o]J33o`00
000@ok:L`P03o`000?n^VL;o[YW200co[YW200Co0000ojVF`_nYU/;oZIK20_l00009ojRD`@03o`00
0?nTTL7oY97100goY97100?o0000oj2?`_nPSl802onPSl800ol0003oW8g3oib=``0<oib=``03o`00
0?nHRlCoV8_400coV8_400?o0000oiB;a_nDRlH02OnDRlHKo`0000OoTho<00?o0000oi:AconBTLl0
1?nBTLl00ol0003oTY7?oi:Ac`06oi:Ac`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2?ooool004;ooooo00?o0000ooooooooool0;_ooool01Ol0003ob;k@olRnd?o8_]3o0000013o`k?;
00?o0000ol6ab_o1/LX00_o1/LX2o`0000_o_:S600?o0000okVUaOniYLD02_niYLD2o`0000?o]J33
00?o0000ok:L`_nbW<803OnbW<800ol0003o[YW2ojjI`P0<ojjI`P04o`000?nYU/;o0000o`0000co
Z9C100?o0000ojBA`OnTTL403OnTTL400ol0003oX8o2oj2?`P0;oj2?`P03o`000?nLSL?oW8g300co
W8g300?o0000oiR;a?nHRl@02onHRl@00ol0003oU8_6oiB;aP02oiB;aPOo00001?nHS/L00ol0003o
UHk9oiF>b@0<oiF>b@03o`000?nCSlcoTho<00goTho<00?o0000oi:AconBTLl01?nBTLl00ol0003o
TY7?oi:Ac`06oi:Ac`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool004?ooooo
0_l0000_ooooo`03o`000?o8_]3o0000017o`k?;00Go0000ol6ab_o1/L[o`K7:o`00000>okbXaP03
o`000?niYLGo^JG500So^JG500?o0000okFP`oneX<<00oneX<<00ol0003o/Yc2ok:L`P0=ok:L`P03
o`000?n^VL;o[YW200co[YW20_l0000>ojRD`@03o`000?nTTL7oY97100goY97100?o0000oj2?`_nP
Sl802onPSl800ol0003oW8g3oib=``0<oib=``03o`000?nHRlCoV8_400WoV8_41ol0000<oiR>a`03
o`000?nES/WoUHk900coUHk900?o0000oi>?c?nCSl`03?nCSl`00ol0003oTY7?oi:Ac`05oi:Ac`03
o`000?nBTLooTY7?00GoTY7?00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`00
AOooool00ol0003oooooooooo`0]ooooo`03o`000?o3/l_o`k?;017o`k?;00?o0000ol6ab_l00000
3onlZ<H00ol0003o^JG5okVUa@06okVUa@;o00001oneX<<00ol0003o/Yc2ok:L`P0=ok:L`P03o`00
0?n^VL;o[YW200Wo[YW20_l000000on/Ul7o0000ojRD`@0>ojRD`@03o`000?nTTL7oY97100coY971
00?o0000oj2?`_nPSl803?nPSl800ol0003oW8g3oib=``0;oib=``03o`000?nHRlCoV8_400;oV8_4
1ol00003oiZ>a@03o`000?nHS/OoV8k700goV8k700?o0000oiF>bOnES/T03?nES/T00ol0003oTho<
oi>?c00=oi>?c003o`000?nBTLooTY7?00GoTY7?00?o0000oi:AconBTLl01OnBTLl00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Sooooo0016ooooo`03o`000?oooooooooo02cooooo00?o
0000ol>cboo3/l/04Oo3/l/2o`00017o_:S600?o0000okVUaOniYLD01?niYLD00ol0003o]J33okFP
``07okFP``03o`000?nbW<;o/Yc200go/Yc200?o0000ojjI`_n^VL801on^VL82o`0000Co[9O100?o
0000ojRD`OnXU<403?nXU<400ol0003oY971ojBA`@0=ojBA`@03o`000?nPSl;oX8o200_oX8o200?o
0000oib=`onLSL<02OnLSL<7o`0000_oVXk500?o0000oiR>aonHS/L03?nHS/L00ol0003oUHk9oiF>
b@0=oiF>b@03o`000?nCSlcoTho<00coTho<00?o0000oi:AconBTLl01OnBTLl00ol0003oTY7?oi:A
c`05oi:Ac`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool004Oooooo00?o0000
ooooooooool0;?ooool00ol0003o`k?;ol>cb`0?ol>cb`03o`000?nn[<Oo0000017o_:S600?o0000
okVUaOniYLD00oniYLD00ol0003o]J33okFP``08okFP``03o`000?nbW<;o/Yc200ko/Yc200?o0000
ojjI`_n^VL800on^VL83o`0000Ko[9O100?o0000ojRD`OnXU<403?nXU<400ol0003oY971ojBA`@0=
ojBA`@03o`000?nPSl;oX8o200_oX8o200?o0000oib=`onLSL<00_nLSL<7o`0000?oWHo400?o0000
oiZ>aOnJS/D03?nJS/D00ol0003oV8k7oiR>a`0=oiR>a`03o`000?nES/WoUHk900coUHk900?o0000
oi>?c?nCSl`03OnCSl`00ol0003oTY7?oi:Ac`05oi:Ac`03o`000?nBTLooTY7?00CoTY7?00?o0000
ooooooooool01Oooool00ol0003oooooooooo`07ooooo`00B?ooool00ol0003oooooooooo`0/oooo
o`03o`000?o3/l_o`k?;00go`k?;00Go0000okj/aonn[<Oo_Zc7o`00000AokbXaP03o`000?niYLGo
^JG500;o00003?neX<<00ol0003o/Yc2ok:L`P0=ok:L`P04o`000?n^VL;o[YW2ojjI`P;o00002On/
Ul400ol0003oZ9C1ojRD`@0=ojRD`@03o`000?nTTL7oY97100coY97100?o0000oj2?`_nPSl802_nP
Sl86o`0000_oWHo400?o0000oiZ>aOnJS/D02onJS/D00ol0003oV8k7oiR>a`0=oiR>a`03o`000?nE
S/WoUHk900coUHk900?o0000oi>?c?nCSl`03OnCSl`00ol0003oTY7?oi:Ac`06oi:Ac`03o`000?nB
TLooTY7?00CoTY7?00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`00BOooool2
o`0002gooooo00?o0000ol>cboo3/l/02_o3/l/2o`0000Co_Zc700?o0000okbXa_nlZ<H03onlZ<H0
0ol0003o^JG5o`00000>okFP``03o`000?nbW<;o/Yc200go/Yc200Co0000ojjI`_l0003o00003?n/
Ul400ol0003oZ9C1ojRD`@0<ojRD`@03o`000?nTTL7oY97100goY97100?o0000oj2?`_nPSl801_nP
Sl83o`0000;oXI3300?o0000oif?a?nMSl@03?nMSl@00ol0003oVXk5oiZ>a@0<oiZ>a@03o`000?nH
S/OoV8k700goV8k700?o0000oiF>bOnES/T03?nES/T00ol0003oTho<oi>?c00=oi>?c003o`000?nB
TLooTY7?00KoTY7?00?o0000oi:AconBTLl00onBTLl00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Oooooo001;ooooo`03o`000?oooooooooo02[ooooo00?o0000ol>cboo3/l/02Oo3/l/0
0ol0003o_Zc7okj/a`05okj/a`03o`000?nlZ<Ko_:S600ko_:S60_l0000@okFP``03o`000?nbW<;o
/Yc200co/Yc20_l0000>ojbG`@03o`000?nXU<7oZ9C100coZ9C100?o0000ojBA`OnTTL403OnTTL40
0ol0003oX8o2oj2?`P03oj2?`P?o00001_nQT<<00ol0003oWHo4oif?a00;oif?a003o`000?nJS/Go
VXk500coVXk500?o0000oiR>aonHS/L03OnHS/L00ol0003oUHk9oiF>b@0<oiF>b@03o`000?nCSlco
Tho<00goTho<00?o0000oi:AconBTLl01_nBTLl00ol0003oTY7?oi:Ac`04oi:Ac`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01oooool004cooooo00?o0000ooooooooool0:_ooool00ol0
003o`k?;ol>cb`07ol>cb`03o`000?nn[<Oo_Zc700Ko_Zc700?o0000okbXa_nlZ<H03OnlZ<H00ol0
003o^:?4o`00000@okFP``03o`000?nbW<;o/Yc200[o/Yc20_l000000on_V/;o0000ojbG`@0>ojbG
`@03o`000?nXU<7oZ9C100coZ9C100?o0000ojBA`OnTTL403?nTTL400ol0003oX8o2oj2?`P03o`00
00WoXI3300?o0000oif?a?nMSl@03?nMSl@00ol0003oVXk5oiZ>a@0<oiZ>a@03o`000?nHS/OoV8k7
00goV8k700?o0000oiF>bOnES/T03?nES/T00ol0003oTho<oi>?c00<oi>?c003o`000?nBTLooTY7?
00OoTY7?00?o0000oi:AconBTLl00onBTLl00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Oooooo001=ooooo`03o`000?oooooooooo02[ooooo00?o0000ol>cboo3/l/01Oo3/l/00ol0003o
_Zc7okj/a`08okj/a`03o`000?nlZ<Ko_:S600[o_:S60_l00003okRSa003o`000?neX<?o]J3300ko
]J3300?o0000ok:L`_nbW<801onbW<82o`0000Co[i[200?o0000ojbG`On/Ul403?n/Ul400ol0003o
Z9C1ojRD`@0<ojRD`@03o`000?nTTL7oY97100_oY9711?l0000<oj6@``03o`000?nMSlCoWHo400co
WHo400?o0000oiZ>aOnJS/D03?nJS/D00ol0003oV8k7oiR>a`0=oiR>a`03o`000?nES/WoUHk900co
UHk900?o0000oi>?c?nCSl`03OnCSl`00ol0003oTY7?oi:Ac`07oi:Ac`03o`000?nBTLooTY7?00?o
TY7?00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`00C_ooool2o`0002[ooooo
00?o0000ol>cboo3/l/00oo3/l/2o`0000co_Zc700?o0000okbXa_nlZ<H02?nlZ<H00ol0003o^:?4
okRSa003okRSa003o`000?neX<?o]J3300ko]J3300?o0000ok:L`_nbW<801OnbW<82o`0000Ko[i[2
00?o0000ojbG`On/Ul403On/Ul400ol0003oZ9C1ojRD`@0<ojRD`@03o`000?nTTL7oY97100OoY971
0ol00002ojBB``03o`000?nQT<?oXI3300coXI3300?o0000oif?a?nMSl@03?nMSl@00ol0003oVXk5
oiZ>a@0<oiZ>a@03o`000?nHS/OoV8k700coV8k700?o0000oiF>bOnES/T03OnES/T00ol0003oTho<
oi>?c00<oi>?c003o`000?nBTLooTY7?00OoTY7?00?o0000oi:AconBTLl00onBTLl00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo001@ooooo`03o`000?oooooooooo02Sooooo00Go
0000ol>cboo3/l_o`k?;o`00000>okj/a`03o`000?nlZ<Ko_:S600Ko_:S60_l00007okRSa003o`00
0?neX<?o]J3300go]J3300?o0000ok:L`_nbW<801?nbW<800ol0003o[i[2ojnJ`P06ojnJ`P03o`00
0?n/Ul7o[9O100go[9O100?o0000ojRD`OnXU<403?nXU<400ol0003oY971ojBA`@03ojBA`@Co0000
1_nTT/<00ol0003oXI33oj6@``0;oj6@``03o`000?nMSlCoWHo400coWHo400?o0000oiZ>aOnJS/D0
3?nJS/D00ol0003oV8k7oiR>a`0=oiR>a`03o`000?nES/WoUHk900coUHk900?o0000oi>?c?nCSl`0
3OnCSl`00ol0003oTY7?oi:Ac`07oi:Ac`03o`000?nBTLooTY7?00;oTY7?00?o0000ooooooooool0
0oooool00ol0003oooooooooo`06ooooo`00DOooool00ol0003oooooooooo`0Xooooo`03o`000?o3
/l_o0000013o_Zc700?o0000okbXa_nlZ<H01?nlZ<H00ol0003o^:?4okRSa007okRSa003o`000?ne
X<?o]J3300ko]J3300Co0000ok:L`_nbW<;o/Yc20_l0000:ojnJ`P03o`000?n/Ul7o[9O100co[9O1
00?o0000ojRD`OnXU<403?nXU<400ol0003oY971ojBA`@03o`0000[oY9;300?o0000oj6@`onQT<<0
3?nQT<<00ol0003oWHo4oif?a00<oif?a003o`000?nJS/GoVXk500_oVXk500?o0000oiR>aonHS/L0
3OnHS/L00ol0003oUHk9oiF>b@0<oiF>b@03o`000?nCSlcoTho<00goTho<00?o0000oi:AconBTLl0
1_nBTLl8o`0000Cooooo00?o0000ooooooooool01_ooool005;ooooo00?o0000ooooooooool0:?oo
ool00ol0003o_Zc7okj/a`0?okj/a`03o`000?nlZ<Ko_:S600?o_:S600?o0000okRSa?nhXl@02Onh
Xl@00ol0003o]J33okFP``0=okFP``04o`000?nbW<;o0000o`0000co[i[200?o0000ojbG`On/Ul40
3On/Ul400ol0003oZ9C1ojRD`@0;ojRD`@?o00003OnTT/<00ol0003oXI33oj6@``0<oj6@``03o`00
0?nMSlCoWHo400coWHo400?o0000oiZ>aOnJS/D03?nJS/D00ol0003oV8k7oiR>a`0=oiR>a`03o`00
0?nES/WoUHk900coUHk900?o0000oi>?c?nCSl`02OnCSl`<o`0000?oUiOB00Go0000oiNGd_nGUm;o
UiOBo`000004ooooo`03o`000?oooooooooo00Kooooo001Cooooo`;o0000:?ooool00ol0003o_Zc7
okj/a`0@okj/a`03o`000?nlZ<Ko_:S600;o00003?nhXl@00ol0003o]J33okFP``0=okFP``;o0000
3on_V/800ol0003o[9O1ojbG`@0<ojbG`@03o`000?nXU<7oZ9C100SoZ9C10ol000000onWUL?o0000
ojBB``0>ojBB``03o`000?nQT<?oXI3300_oXI3300?o0000oif?a?nMSl@03?nMSl@00ol0003oVXk5
oiZ>a@0<oiZ>a@03o`000?nHS/OoV8k700goV8k700?o0000oiF>bOnES/T03?nES/T00ol0003oTho<
oi>?c002oi>?c0Oo00001?nHULl00ol0003oUiOBoiNGdP08oiNGdP03o`000?nGUm;oUiOB00;oUiOB
00Go0000ooooooooooooooooo`000008ooooo`00EOooool00ol0003oooooooooo`0Vooooo`03o`00
0?nn[<Oo_Zc700oo_Zc700?o0000okbXa_l000003onhXl@00ol0003o]J33okFP``0;okFP``03o`00
0?nbW/?o000000oo[i[200?o0000ojbG`On/Ul403On/Ul400ol0003oZ9C1ojRD`@04ojRD`@?o0000
1OnWUL<00ol0003oY9;3ojBB``0<ojBB``03o`000?nQT<?oXI3300coXI3300?o0000oif?a?nMSl@0
3?nMSl@00ol0003oVXk5oiZ>a@0<oiZ>a@03o`000?nHS/OoV8k700coV8k700?o0000oiF>bOnES/T0
1_nES/T;o`0000coV9G?00?o0000oiNGd_nGUm802?nGUm801Ol0003oUiOBoiNGd_nGUm;o000000?o
oooo00?o0000ooooooooool01_ooool005Kooooo00?o0000ooooooooool09Oooool00ol0003o_Zc7
okj/a`0?okj/a`;o00004?nhXl@00ol0003o]J33okFP``09okFP``;o00000onbW/<00ol0003o[i[2
ojnJ`P0=ojnJ`P03o`000?n/Ul7o[9O100co[9O100?o0000ojRD`OnXU<400_nXU<42o`0000SoYiG3
00?o0000ojBB`onTT/<03OnTT/<00ol0003oXI33oj6@``0;oj6@``03o`000?nMSlCoWHo400coWHo4
00?o0000oiZ>aOnJS/D03?nJS/D00ol0003oV8k7oiR>a`09oiR>a`co00001onITld00ol0003oV9G?
oiREc`0=oiREc`03o`000?nGUm;oUiOB00WoUiOB00Go0000oiNGd_nGUm;oUiOBo`000002ooooo`03
o`000?oooooooooo00Kooooo001Gooooo`03o`000?oooooooooo02Gooooo00?o0000okj/aonn[<L0
3Onn[<L00ol0003o^ZO6o`00000@okRSa003o`000?neX<?o]J3300Oo]J330_l00005ok:N``03o`00
0?n_V/;o[i[200go[i[200?o0000ojbG`On/Ul403?n/Ul400ol0003oZ9C1o`000002o`0000[oYiG3
00?o0000ojBB`onTT/<03OnTT/<00ol0003oXI33oj6@``0;oj6@``03o`000?nMSlCoWHo400goWHo4
00?o0000oiZ>aOnJS/D02onJS/D00ol0003oV8k7oiR>a`02oiR>a`Oo00001?nKTl/00ol0003oVI?=
oiVCc@0=oiVCc@03o`000?nHULooV9G?00coV9G?00?o0000oiNGd_nGUm802_nGUm801?l0003oUiOB
oiNGd_l00002ooooo`03o`000?oooooooooo00Kooooo001Hooooo`;o00009_ooool00ol0003o_Zc7
okj/a`0:okj/a`;o00000onjYlH00ol0003o^:?4okRSa00>okRSa003o`000?neX<?o]J3300Go]J33
00?o0000ok:N`onbW/<01_nbW/<00ol0003o[i[2ojnJ`P0<ojnJ`P03o`000?n/Ul7o[9O100co[9O1
0_l0000>ojNE``03o`000?nTT/?oY9;300coY9;300?o0000oj6@`onQT<<03?nQT<<00ol0003oWHo4
oif?a00<oif?a003o`000?nJS/GoVXk500WoVXk51ol0000<oi^Cb`03o`000?nITlgoVI?=00coVI?=
00?o0000oiREconHULl03OnHULl00ol0003oUiOBoiNGdP09oiNGdP04o`000?nGUm;oUiOBo`0000?o
oooo00?o0000ooooooooool01Oooool005[ooooo00?o0000ooooooooool08oooool00ol0003o_Zc7
okj/a`09okj/a`03o`000?njYlKo^ZO600?o^ZO600?o0000okRSa?nhXl@03_nhXl@00ol0003o]J33
okFP``03okFP``;o00002OnbW/<00ol0003o[i[2ojnJ`P0=ojnJ`P03o`000?n/Ul7o[9O100Wo[9O1
0_l000000on[V<?o0000ojNE``0=ojNE``03o`000?nTT/?oY9;300goY9;300?o0000oj6@`onQT<<0
2onQT<<00ol0003oWHo4oif?a00<oif?a003o`000?nJS/GoVXk500;oVXk51ol00003oifCb@03o`00
0?nKTl_oVi?;00goVi?;00?o0000oiVCcOnITld03OnITld00ol0003oV9G?oiREc`0<oiREc`03o`00
0?nGUm;oUiOB00[oUiOB00Co0000oiNGd_nGUm;o00000_ooool00ol0003oooooooooo`05ooooo`00
Foooool00ol0003oooooooooo`0Sooooo`03o`000?nn[<Oo_Zc700Ko_Zc70_l00007okZWaP03o`00
0?nhXlCo^:?400ko^:?400?o0000okFP`oneX<<00_l0000;ok:N``03o`000?n_V/;o[i[200go[i[2
00?o0000ojbG`On/Ul401on/Ul42o`0000CoZiS300?o0000ojNE`onWUL<03?nWUL<00ol0003oY9;3
ojBB``0<ojBB``03o`000?nQT<?oXI3300coXI3300?o0000oif?a?nMSl@02_nMSl@6o`0000_oWI?9
00?o0000oi^CbonKTl/03?nKTl/00ol0003oVI?=oiVCc@0=oiVCc@03o`000?nHULooV9G?00goV9G?
00?o0000oiNGd_nGUm802_nGUm800ol0003oUiOBo`000002ooooo`03o`000?oooooooooo00Gooooo
001Looooo`03o`000?oooooooooo02;ooooo00?o0000okj/aonn[<L01Onn[<L00ol0003o^ZO6okZW
aP08okZWaP03o`000?nhXlCo^:?400go^:?400?o0000okFP`ol000003_nbW/<00ol0003o[i[2ojnJ
`P0=ojnJ`P03o`000?n/Ul7o[9O100?o[9O10ol00006oj^H``03o`000?nWUL?oYiG300coYiG300?o
0000ojBB`onTT/<03?nTT/<00ol0003oXI33oj6@``0<oj6@``03o`000?nMSlCoWHo400GoWHo41Ol0
0002oinCa`03o`000?nMTlWoWI?900coWI?900?o0000oi^CbonKTl/03OnKTl/00ol0003oVI?=oiVC
c@0<oiVCc@03o`000?nHULooV9G?00goV9G?00?o0000oiNGd_nGUm802onGUm801Ol0003oUiOBo`00
0?oooooo000000Oooooo001Mooooo`03o`000?oooooooooo02;ooooo00?o0000okj/aonn[<L00onn
[<L00ol0003o^ZO6okZWaP09okZWaP03o`000?nhXlCo^:?400go^:?40_l0000?ok:N``03o`000?n_
V/;o[i[200go[i[200Co0000ojbG`On/Ul7o[9O10_l00009oj^H``03o`000?nWUL?oYiG300coYiG3
00?o0000ojBB`onTT/<03OnTT/<00ol0003oXI33oj6@``0;oj6@``03o`000?nMSlCoWHo400Go0000
2?nOTlL00ol0003oWI?9oifCb@0<oifCb@03o`000?nKTl_oVi?;00coVi?;00?o0000oiVCcOnITld0
3OnITld00ol0003oV9G?oiREc`0<oiREc`03o`000?nGUm;oUiOB00_oUiOB00Go0000oiNGd_l0003o
ooooo`000007ooooo`00G_ooool2o`0002?ooooo00?o0000okj/aonn[<L00_l0000=okZWaP03o`00
0?nhXlCo^:?400_o^:?400?o0000okBQaOl000004?nbW/<00ol0003o[i[2ojnJ`P0<ojnJ`P04o`00
0?n/Ul7o0000o`0000coZiS300?o0000ojNE`onWUL<03?nWUL<00ol0003oY9;3ojBB``0<ojBB``03
o`000?nQT<?oXI3300[oXI331?l0000=oinCa`03o`000?nMTlWoWI?900coWI?900?o0000oi^CbonK
Tl/03OnKTl/00ol0003oVI?=oiVCc@0<oiVCc@03o`000?nHULooV9G?00goV9G?00?o0000oiNGd_nG
Um802onGUm801?l0003oUiOBo`000?l00007ooooo`00H?ooool00ol0003oooooooooo`0Pooooo`03
o`000?nn[<Oo000000oo^ZO600?o0000okRSa?nhXl@02OnhXl@2o`0000?o]:7500?o0000ok:N`onb
W/<03OnbW/<00ol0003o[i[2ojnJ`P0<ojnJ`P;o00003_n[V<<00ol0003oYiG3ojNE``0<ojNE``03
o`000?nTT/?oY9;300goY9;300?o0000oj6@`onQT<<01_nQT<<3o`0000;oXYC600?o0000oinCaonO
TlL03OnOTlL00ol0003oWI?9oifCb@0;oifCb@03o`000?nKTl_oVi?;00goVi?;00?o0000oiVCcOnI
Tld03OnITld00ol0003oV9G?oiREc`0<oiREc`03o`000?nGUm;oUiOB00coUiOB0ol00007ooooo`00
HOooool00ol0003oooooooooo`0Pooooo`03o`000?njYlKo^ZO600oo^ZO600?o0000okRSa?nhXl@0
1onhXl@00ol0003o]:75okBQa@03okBQa@03o`000?nbW/?o/Yk300ko/Yk300?o0000ojnJ`_n_V/80
2On_V/82o`000003ojfKa?l0003oZiS300koZiS300?o0000ojNE`onWUL<02onWUL<00ol0003oY9;3
ojBB``0=ojBB``03o`000?nQT<?oXI3300?oXI330ol00006oj:DaP03o`000?nOTlOoWi?700coWi?7
00?o0000oifCbOnMTlT03?nMTlT00ol0003oVi?;oi^Cb`0<oi^Cb`03o`000?nITlgoVI?=00goVI?=
00?o0000oiREconHULl03OnHULl00ol0003oUiOBoiNGdP0;oiNGdP;o000000?oooooo`000?ooool0
1Oooool006;ooooo00?o0000ooooooooool07oooool00ol0003o^ZO6okZWaP0?okZWaP03o`000?nh
XlCo^:?400Go^:?40_l00007okBQa@03o`000?nbW/?o/Yk300go/Yk300?o0000ojnJ`_n_V/801on_
V/82o`0000Co[I_400?o0000oj^H`on[V<<03?n[V<<00ol0003oYiG3ojNE``0<ojNE``03o`000?nT
T/?oY9;300coY9;300?o0000oj6@`onQT<<00ol00009oj:DaP03o`000?nOTlOoWi?700coWi?700?o
0000oifCbOnMTlT03?nMTlT00ol0003oVi?;oi^Cb`0=oi^Cb`03o`000?nITlgoVI?=00goVI?=00?o
0000oiREconHULl03?nHULl00ol0003oUiOBoiNGdP09oiNGdPKo00001_ooool006?ooooo0_l0000P
ooooo`03o`000?njYlKo^ZO600oo^ZO600?o0000okRSa?nhXl@00onhXl@00ol0003o]:75okBQa@07
okBQa@03o`000?nbW/?o/Yk300go/Yk300?o0000ojnJ`_n_V/801?n_V/83o`0000Ko[I_400?o0000
oj^H`on[V<<03On[V<<00ol0003oYiG3ojNE``0;ojNE``03o`000?nTT/?oY9;300_oY9;31?l0000=
oj:DaP03o`000?nOTlOoWi?700coWi?700?o0000oifCbOnMTlT03?nMTlT00ol0003oVi?;oi^Cb`0<
oi^Cb`03o`000?nITlgoVI?=00goVI?=00?o0000oiREconHULl03?nHULl00ol0003oUiOBoiNGdP02
oiNGdPOo00001?ooool2o`0000Kooooo001Uooooo`03o`000?oooooooooo01kooooo00?o0000okZW
a_njYlH03onjYlH00ol0003o^:?4okRSa002o`0000_o]:7500?o0000ok:N`onbW/<03OnbW/<01?l0
003o[i[2ojnJ`_n_V/82o`0000[o[I_400?o0000oj^H`on[V<<03?n[V<<00ol0003oYiG3ojNE``0<
ojNE``03o`000?nTT/?oY9;300OoY9;30ol00002ojFFaP03o`000?nRU<KoXYC600coXYC600?o0000
oinCaonOTlL03?nOTlL00ol0003oWI?9oifCb@0<oifCb@03o`000?nKTl_oVi?;00goVi?;00?o0000
oiVCcOnITld03?nITld00ol0003oV9G?oiREc`06oiREc`_o00002_ooool3o`0000Kooooo001Voooo
o`03o`000?oooooooooo01gooooo00?o0000okZWa_njYlH03onjYlH00ol0003o^:?4o`00000=okBQ
a@03o`000?nbW/?o/Yk300go/Yk300Co0000ojnJ`_l0003o00003?n]Vl@00ol0003oZiS3oj^H``0<
oj^H``03o`000?nWUL?oYiG300coYiG300?o0000ojBB`onTT/<00onTT/<4o`0000KoYIK600?o0000
oj:Da_nRU<H02onRU<H00ol0003oWi?7oinCa`0=oinCa`03o`000?nMTlWoWI?900coWI?900?o0000
oi^CbonKTl/03?nKTl/00ol0003oVI?=oiVCc@09oiVCc@co00004Oooool4o`0000Wooooo001Woooo
o`03o`000?oooooooooo01gooooo00?o0000okZWa_njYlH03_njYlH2o`0000oo]:7500?o0000ok:N
`onbW/<03?nbW/<2o`0000ko[I_400?o0000oj^H`on[V<<03On[V<<00ol0003oYiG3ojNE``0;ojNE
``03o`000?nTT/?oY9;300?o00002_nUU/H00ol0003oXYC6oj:DaP0<oj:DaP03o`000?nOTlOoWi?7
00coWi?700?o0000oifCbOnMTlT03?nMTlT00ol0003oVi?;oi^Cb`0<oi^Cb`03o`000?nITlgoVI?=
00;oVI?=1ol0000Iooooo`Co00003Oooool006Sooooo0_l0000Mooooo`03o`000?njYlKo^ZO600go
^ZO600?o0000okNUaol000004?ndXLD00ol0003o/Yk3ok:N``09ok:N``;o000000?o/9k5o`000?n]
Vl@03_n]Vl@00ol0003oZiS3oj^H``0<oj^H``03o`000?nWUL?oYiG300[oYiG31?l0000>ojFFaP03
o`000?nRU<KoXYC600_oXYC600?o0000oinCaonOTlL03OnOTlL00ol0003oWI?9oifCb@0;oifCb@03
o`000?nKTl_oVi?;00_oVi?;1_l0000Mooooo`?o00004Oooool006[ooooo00?o0000ooooooooool0
6oooool00ol0003o^ZO6okZWaP0:okZWaP;o00000ongYLL00ol0003o]:75okBQa@0=okBQa@03o`00
0?nbW/?o/Yk300So/Yk300?o0000ok2NaOn`W/D00_n`W/D00ol0003o[I_4ojfKa00<ojfKa003o`00
0?n[V<?oZiS300goZiS300?o0000ojNE`onWUL<01_nWUL<3o`0000;oYiS600?o0000ojFFa_nUU/H0
3OnUU/H00ol0003oXYC6oj:DaP0<oj:DaP03o`000?nOTlOoWi?700coWi?700?o0000oifCbOnMTlT0
3?nMTlT00ol0003oVi?;oi^Cb`05oi^Cb`Go00007oooool4o`0001Cooooo001[ooooo`03o`000?oo
oooooooo01_ooooo00?o0000okZWa_njYlH01onjYlH2o`0000Go]jG700?o0000okBQaOndXLD03_nd
XLD00ol0003o/Yk3ok:N``05ok:N``;o00001On`W/D00ol0003o[I_4ojfKa00=ojfKa003o`000?n[
V<?oZiS300coZiS300?o0000ojNE`onWUL<00onWUL<3o`0000KoYiS600?o0000ojFFa_nUU/H03?nU
U/H00ol0003oXYC6oj:DaP0<oj:DaP03o`000?nOTlOoWi?700coWi?700?o0000oifCbOnMTlT03?nM
TlT00ol0003oVi?;oi^Cb`05o`00023ooooo1?l0000Hooooo`00K?ooool00ol0003oooooooooo`0J
ooooo`03o`000?njYlKo^ZO600Ko^ZO600?o0000okNUaongYLL01_ngYLL00ol0003o]:75okBQa@0=
okBQa@03o`000?nbW/?o/Yk300?o/Yk30_l00008ok2Na@03o`000?n]VlCo[I_400co[I_400?o0000
oj^H`on[V<<03?n[V<<00ol0003oYiG3ojNE``03o`0000WoYiS600?o0000ojFFa_nUU/H03OnUU/H0
0ol0003oXYC6oj:DaP0<oj:DaP03o`000?nOTlOoWi?700coWi?700?o0000oifCbOnMTlT02OnMTlT5
o`00027ooooo1?l0000Looooo`00KOooool2o`0001_ooooo00?o0000okZWa_njYlH00onjYlH2o`00
00Wo]jG700?o0000okBQaOndXLD03_ndXLD01Ol0003o/Yk3ok:N`onbW/?o000000[o/9k500?o0000
ojfKa?n]Vl@03On]Vl@00ol0003oZiS3oj^H``0;oj^H``?o00003OnWV<H00ol0003oYIK6ojFFaP0<
ojFFaP03o`000?nRU<KoXYC600coXYC600?o0000oinCaonOTlL03?nOTlL00ol0003oWI?9oifCb@02
oifCb@Oo00008_ooool4o`00023ooooo001_ooooo`03o`000?oooooooooo01Sooooo00Co0000okZW
a_njYlKo^ZO60_l0000<okNUa`03o`000?ndXLGo]:7500go]:7500Co0000ok:N`ol0003o00002on`
W/D00ol0003o[I_4ojfKa00=ojfKa003o`000?n[V<?oZiS300SoZiS30ol000000onZV/Oo0000ojNH
aP0=ojNHaP03o`000?nUU/KoYIK600goYIK600?o0000oj:Da_nRU<H02onRU<H00ol0003oWi?7oinC
a`0;oinCa`Ko00009_ooool3o`0002Cooooo001`ooooo`03o`000?oooooooooo01Sooooo00?o0000
okZWa_l000003_ngYLL00ol0003o]:75okBQa@0=okBQa@;o00003_n`W/D00ol0003o[I_4ojfKa00<
ojfKa003o`000?n[V<?oZiS300GoZiS30ol00005ojZJa`03o`000?nWV<KoYiS600coYiS600?o0000
ojFFa_nUU/H03?nUU/H00ol0003oXYC6oj:DaP0<oj:DaP03o`000?nOTlOoWi?700GoWi?71Ol0000X
ooooo`Co00009oooool0077ooooo00?o0000ooooooooool06?ooool00ol0003o]jG7okNUa`0>okNU
a`03o`000?ndXLGo]:7500[o]:750_l000000onbXLOo0000ok2Na@0=ok2Na@03o`000?n]VlCo[I_4
00go[I_400?o0000oj^H`on[V<<00_n[V<<2o`0000SoZY[700?o0000ojNHa_nWV<H03?nWV<H00ol0
003oYIK6ojFFaP0=ojFFaP03o`000?nRU<KoXYC600_oXYC600?o0000oinCaonOTlL01Ol0000Yoooo
o`Co0000:oooool007;ooooo00?o0000ooooooooool05oooool00ol0003o]jG7okNUa`0>okNUa`03
o`000?ndXLGo]:7500So]:750_l00004ok:Qa`03o`000?n`W/Go/9k500co/9k500?o0000ojfKa?n]
Vl@03?n]Vl@00ol0003oZiS3o`000002o`0000_oZY[700?o0000ojNHa_nWV<H03?nWV<H00ol0003o
YIK6ojFFaP0<ojFFaP03o`000?nRU<KoXYC600[oXYC61?l0000Zooooo`Co0000;oooool007?ooooo
0_l0000Hooooo`03o`000?ngYLOo]jG700ko]jG700?o0000okBQaOndXLD01OndXLD2o`0000Ko/Z77
00?o0000ok2NaOn`W/D03?n`W/D00ol0003o[I_4ojfKa00<ojfKa0;o00003_nZV/L00ol0003oYiS6
ojNHaP0<ojNHaP03o`000?nUU/KoYIK600coYIK600?o0000oj:Da_nRU<H01onRU<H3o`0002[ooooo
1?l0000cooooo`00MOooool00ol0003oooooooooo`0Eooooo`03o`000?ngYLOo]jG700ko]jG700?o
0000okBQaOndXLD01?ndXLD00ol0003o/Z77ok:Qa`07ok:Qa`03o`000?n`W/Go/9k500co/9k500?o
0000ojfKa?n]Vl@02On]Vl@2o`000003ojbMb?l0003oZY[700goZY[700?o0000ojNHa_nWV<H03?nW
V<H00ol0003oYIK6ojFFaP0=ojFFaP03o`000?nRU<KoXYC600?oXYC60ol0000Yooooo`Co0000=ooo
ool007Kooooo00?o0000ooooooooool05Oooool00ol0003o]jG7okNUa`0>okNUa`04o`000?ndXLGo
]:75okBQa@;o00002_nbXLL00ol0003o/9k5ok2Na@0<ok2Na@03o`000?n]VlCo[I_400Oo[I_40_l0
0004ojbMb003o`000?nZV/OoZY[700coZY[700?o0000ojNHa_nWV<H03?nWV<H00ol0003oYIK6ojFF
aP0<ojFFaP03o`000?nRU<KoXYC600?o0000:Oooool3o`0003_ooooo001gooooo`03o`000?oooooo
oooo01Cooooo00?o0000okNUaongYLL03_ngYLL01?l0003o]:75o`000?l0000=ok:Qa`03o`000?n`
W/Go/9k500_o/9k500?o0000ojfKa?n]Vl@01?n]Vl@3o`0000Ko[9g800?o0000ojZJaonZV/L03?nZ
V/L00ol0003oYiS6ojNHaP0<ojNHaP03o`000?nUU/KoYIK600_oYIK61?l0000Xooooo`Co0000?_oo
ool007Sooooo0_l0000Eooooo`03o`000?ngYLOo]jG700go]jG70_l0000?ok:Qa`03o`000?n`W/Go
/9k500co/9k500Co0000ojfKa?n]VlCo[I_40_l0000:ojbMb003o`000?nZV/OoZY[700coZY[700?o
0000ojNHa_nWV<H03?nWV<H00ol0003oYIK6ojFFaP05ojFFaPGo0000:?ooool4o`0004;ooooo001j
ooooo`03o`000?oooooooooo01;ooooo00?o0000okNUaongYLL03?ngYLL00ol0003o]:G9o`00000@
ok:Qa`03o`000?n`W/Go/9k500_o/9k500Co0000ojfKa?l0003o00003?n/WLP00ol0003oZY[7ojZJ
a`0<ojZJa`03o`000?nWV<KoYiS600coYiS600?o0000ojFFa_nUU/H01Ol0000Yooooo`Co0000A_oo
ool007_ooooo00?o0000ooooooooool04_ooool00ol0003o]jG7okNUa`09okNUa`;o00000ondYLT0
0ol0003o/Z77ok:Qa`0=ok:Qa`03o`000?n`W/Go/9k500_o/9k50_l0000?ojbMb003o`000?nZV/Oo
ZY[700coZY[700?o0000ojNHa_nWV<H02onWV<H3o`0002[ooooo1?l0001:ooooo`00O?ooool00ol0
003oooooooooo`0Aooooo`03o`000?ngYLOo]jG700Oo]jG70_l00005okBUb@03o`000?nbXLOo/Z77
00go/Z7700?o0000ok2NaOn`W/D02On`W/D2o`000003ojjPbOl0003o[9g800ko[9g800?o0000ojZJ
aonZV/L03?nZV/L00ol0003oYiS6ojNHaP08ojNHaP?o0000:_ooool3o`0004kooooo001mooooo`;o
00004_ooool00ol0003o]jG7okNUa`05okNUa`03o`000?ndYLWo]:G900Ko]:G900?o0000ok:Qaonb
XLL03OnbXLL00ol0003o/9k5ok2Na@06ok2Na@;o00001?n^X<T00ol0003o[9g8ojbMb00=ojbMb003
o`000?nZV/OoZY[700_oZY[700?o0000ojNHa_nWV<H01OnWV<H3o`0002Wooooo1?l0001Aooooo`00
Ooooool00ol0003oooooooooo`0?ooooo`03o`000?ngYLOo]jG700?o]jG70_l00009okBUb@03o`00
0?nbXLOo/Z7700go/Z7700?o0000ok2NaOn`W/D01?n`W/D2o`0000Ko[Z3900?o0000ojbMb?n/WLP0
3On/WLP00ol0003oZY[7ojZJa`0<ojZJa`03o`000?nWV<KoYiS600;oYiS60_l0000Xooooo`Co0000
EOooool0083ooooo00?o0000ooooooooool03oooool00ol0003o]jG7okNUa`02o`0000co]:G900?o
0000ok:QaonbXLL03OnbXLL01?l0003o/9k5ok2NaOn`W/D2o`0000Wo[Z3900?o0000ojbMb?n/WLP0
3?n/WLP00ol0003oZY[7ojZJa`0<ojZJa`03o`000?nWV<Ko000000;o00009_ooool4o`0005Wooooo
0021ooooo`03o`000?oooooooooo00kooooo00?o0000okNUaol000003_ndYLT00ol0003o/Z77ok:Q
a`0=ok:Qa`04o`000?n`W/Go0000o`0000_o[Z3900?o0000ojbMb?n/WLP03On/WLP00ol0003oZY[7
ojZJa`0:ojZJa`?o00009Oooool4o`0005gooooo0022ooooo`;o00003oooool00ol0003o]:G9okBU
b@0>okBUb@03o`000?nbXLOo/Z7700co/Z770_l0000>ojjPb@03o`000?n/WLSo[9g800co[9g800?o
0000ojZJaonZV/L01onZV/L3o`0002Cooooo1?l0001Qooooo`00Q?ooool00ol0003oooooooooo`0<
ooooo`03o`000?ndYLWo]:G900ko]:G900?o0000ok:QaonbXLL02_nbXLL2o`000003ok2Sbol0003o
[Z3900go[Z3900?o0000ojbMb?n/WLP03On/WLP00ol0003oZY[7ojZJa`03ojZJa`?o00009?ooool3
o`0006Gooooo0025ooooo`03o`000?oooooooooo00cooooo00?o0000okBUbOndYLT03_ndYLT00ol0
003o/Z77ok:Qa`07ok:Qa`;o00001?n`Xl/00ol0003o[Z39ojjPb@0<ojjPb@03o`000?n/WLSo[9g8
00co[9g800?o0000ojZJaonZV/L00ol0000Sooooo`Co0000J?ooool008Kooooo00?o0000oooooooo
ool03?ooool00ol0003o]:G9okBUb@0=okBUb@03o`000?nbXLOo/Z7700Co/Z770ol00006ok2Sb`03
o`000?n^X<Wo[Z3900co[Z3900?o0000ojbMb?n/WLP03?n/WLP3o`0002;ooooo1?l0001/ooooo`00
Qoooool00ol0003oooooooooo`0;ooooo`03o`000?ndYLWo]:G900ko]:G900Co0000ok:QaonbXLOo
/Z770_l0000:ok2Sb`03o`000?n^X<Wo[Z3900co[Z3900?o0000ojbMb?n/WLP02?n/WLP3o`00027o
oooo1?l0001`ooooo`00R?ooool2o`0000cooooo00?o0000okBUbOndYLT03OndYLT01?l0003o/Z77
o`000?l0000<ok2Sb`03o`000?n^X<Wo[Z3900co[Z3900?o0000ojbMb?n/WLP01On/WLP3o`00023o
oooo1?l0001dooooo`00R_ooool00ol0003oooooooooo`0:ooooo`03o`000?ndYLWo]:G900co]:G9
0_l0000?ok2Sb`03o`000?n^X<Wo[Z3900co[Z3900?o0000ojbMb?n/WLP00_n/WLP2o`0001oooooo
1?l0001hooooo`00Roooool00ol0003oooooooooo`09ooooo`03o`000?ndYLWo]:G900[o]:G90_l0
00000onbYlgo0000ok2Sb`0?ok2Sb`03o`000?n^X<Wo[Z3900_o[Z3900?o0000ojbMb?l000000_l0
000Nooooo`?o0000O?ooool008cooooo00?o0000ooooooooool02Oooool00ol0003o]:G9okBUb@07
okBUb@;o00001?nbYld00ol0003o/:?;ok2Sb`0=ok2Sb`03o`000?n^X<Wo[Z3900_o[Z390_l0000M
ooooo`Co0000Ooooool008gooooo0_l0000:ooooo`03o`000?ndYLWo]:G900Co]:G90_l00006ok:W
c@03o`000?n`Xl_o/:?;00ko/:?;00?o0000ojjPbOn^X<T01on^X<T3o`0001_ooooo1?l00023oooo
o`00Soooool00ol0003oooooooooo`07ooooo`03o`000?ndYLWo]:G900;o]:G90_l00009ok:Wc@03
o`000?n`Xl_o/:?;00go/:?;00?o0000ojjPbOn^X<T01On^X<T2o`0001[ooooo1?l00027ooooo`00
T?ooool00ol0003oooooooooo`07ooooo`04o`000?ndYLWo0000o`0000_o/ZO=00?o0000ok2Sbon`
Xl/03_n`Xl/00ol0003o[Z39ojjPb@02ojjPb@;o00006?ooool4o`0008_ooooo002Aooooo`03o`00
0?oooooooooo00Oooooo00?o0000ok:WcOnbYld03?nbYld00ol0003o/:?;ok2Sb`0=ok2Sb`03o`00
0?n^X<Wo000000;o00005oooool3o`0008oooooo002Booooo`;o00001oooool00ol0003o/ZO=ok:W
c@0=ok:Wc@03o`000?n`Xl_o/:?;00co/:?;0_l0000Fooooo`Co0000T_ooool009Cooooo00?o0000
ooooooooool01Oooool00ol0003o/ZO=ok:Wc@0<ok:Wc@03o`000?n`Xl_o/:?;00[o/:?;0_l0000D
ooooo`Co0000U_ooool009Gooooo00?o0000ooooooooool01?ooool00ol0003o/ZO=ok:Wc@0=ok:W
c@03o`000?n`Xl_o/:?;00Oo/:?;0_l0000Booooo`Co0000V_ooool009Kooooo00?o0000oooooooo
ool01?ooool00ol0003o/ZO=ok:Wc@0<ok:Wc@03o`000?n`Xl_o/:?;00Co/:?;0ol0000@ooooo`Co
0000W_ooool009Oooooo0_l00005ooooo`03o`000?nbYlgo/ZO=00co/ZO=00Co0000ok2Sbon`Xl_o
/:?;0_l0000?ooooo`Co0000X_ooool009Wooooo00?o0000ooooooooool00_ooool00ol0003o/ZO=
ok:Wc@0<ok:Wc@04o`000?n`Xl_o0000o`0000kooooo0ol0002Vooooo`00V_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?nbYlgo/ZO=00_o/ZO=0_l0000<ooooo`Co0000ZOooool009_ooooo00Go
0000ooooooooooooooooo`00000:ok:Wc@?o00002_ooool4o`000:gooooo002Looooo`05o`000?oo
ooooooooooooool000001onbYld2o`0000Wooooo1?l0002aooooo`00WOooool2o`0000;ooooo00?o
0000ok:WcOnbYld00_nbYld2o`0000Oooooo1?l0002eooooo`00Woooool01?l0003oooooo`000?nb
Yld3o`0000Kooooo0ol0002iooooo`00X?ooool00ol0003oooooo`000005ooooo`Co0000_?ooool0
0:7ooooo0_l000000ooooooo0000o`000002o`000<3ooooo002Rooooo`;o0000a?ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00<_ooooo00Co410@o`000?l0
003o0000VOooool00<cooooo00?o0000ooooooooool0VOooool00<cooooo00?o0000ooooooooool0
VOooool009oooooo00Go0000olc<c?oMgMgo0000onk^kP02ooooo`06oiRHV?l0003o0000ogMgMol@
413o00001?ooool00olQ8B7o<S8booooo`03ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj1ooo
ool01_l@413o<S8bo`000?l0003o410@ojVYZ@?ooooo00Wo0000ogMgMol0003o0000oeEEEOo^k^ko
ooooonk^k_mEEED00_l000001_m4A4Co^[Zjooooooooooook^k^oeEEE@;o000000KoA4A4okZj^_oo
ooooooooonk^k_mEEED2o`000003oiRHV?l0003o410@07kooooo002Nooooo`06ojVYZOl0003oQhN7
oiRHV?l0003oV9RH0_ooool01Ol0003oc<c<onk^k_n7QhOo000000Cooooo00CoV9RHoc8b<_l@413o
^[Zj0oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40Oooooo00Ko0000ojVYZOoooooooooookZj
^_l00003ooooo`0=o`000?mEEEGok^k^oooooomgMgOoEEEEoooooomEEEGoMgMgooooooo^k^koMgMg
oa0@4002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool01_mEEEGoMgMgooooooo^k^ko
EEEEo`0007oooooo002Nooooo`06oeEEEOn7QhOoA4A4oeEEEOmgMgOoEEEE0_ooool01Ol@413oQhN7
ooooooo^k^ko000000Cooooo00Co410@okZj^_nHV9So<S8b0oooool00ol0003oooooooooo`0;oooo
o`05okZj^_n7QhOoIVIVofIVI_l@41000oooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooo
000000Oooooo00?o0000ooooooooool01Oooool01_l0003oooooooooooooooook^k^o`0007oooooo
002Nooooo`06o`000?oMgMgoA4A4ob4Q8Oo^k^ko00000_ooool00onj^[[o410@o`000002o`0000?o
oooo00KoV9RHoc8b<_oooooooooooa0@4?nj^[X2ooooo`Ko00001oooool01_lb<S;o8B4QogMgMomg
MgOoQhN7onk^kP?ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooo`000005o`0000;ooooo
1_l00002ooooo`06o`000?ooooooooooooooooo^k^ko0000Ooooool009gooooo00SoZJVYob4Q8Ooo
ooooQhN7oeEEEOoooooo<S8bojVYZ@Cooooo00Ooc<c<o`000?ooooooooooonk^k_l0003ogMgM00;o
oooo00[oV9RHoc8b<_oooooooooooeEEEOn7QhOok^k^oooooon7QhOo<S8b1oooool01_l0003o^[Zj
ooooooo^k^koMgMgo`0000?ooooo00go0000oeEEEOo^k^koooooogMgMomVIVKooooooeEEEOn7QhOo
k^k^oooooon7QhOo<S8b00;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S82ooooo`06ofIVI_mg
MgOoooooonk^k_mEEEGo0000Ooooool009gooooo0ol00002ooooo`?o00000_ooool01?lb<S;o0000
o`000?nHV9P2ooooo`03oa0@4?l0003o000000;ooooo0ol000000oooooook^k^oeEEE@02o`000003
odA4A?o^k^kooooo00Kooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`03oa0@4?l0003o
MgMg00;o000000GoIVIVonk^k_ooooook^k^oeEEE@02o`000006odA4A?o^k^koooooooooooo^k^ko
EEEE0_l000002_m4A4Cok^k^ooooooooooook^k^oeEEEOl0003o410@olc<c?l0001oooooo`00j?oo
ool00ol0003oooooooooo`1mooooo`00j?ooool00ol0003oooooooooo`1mooooo`00ioooool2o`00
07oooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.108223, 0.020481, \
0.0037547, 0.0037547}}]
}, Open  ]],

Cell[TextData[{
  "\tFor the numerical method, we choose CTCS. This explicit method works \
well for the wave equation, being second-order in both the  space and time \
step sizes, and allowing relatively large steps according to the von Neumann \
stability criterion: for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], "=", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]], "=", "\[CapitalDelta]"}]}], 
          ","}], TraditionalForm]]],
  "  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(c\^2\), 
            RowBox[{
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]], "2"], 
              "/", \(\[CapitalDelta]\^\(\(2\)\(\ \)\)\)}]}], "\[LessEqual]", 
          " ", \(1/2\)}], TraditionalForm]]],
  " for stability (see the exercises). Therefore, if  ",
  Cell[BoxData[
      \(TraditionalForm\`c \[LessEqual] \ 1/10\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta] = \ 1/30\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], " ", "\[LessEqual]", 
            " ", \(1/3\ \@2\)}], "=", "0.24"}], TraditionalForm]]],
  ". Below, we choose ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], " ", "=", " ", "0.2"}], 
        TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox[\( (*\ define\ the\ grid\ *) \),
        FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
      RowBox[{\(M\_x = 30; \ M\_y = \ 30;\), 
        "\n", \(L\_\(\(x\)\(\ \)\) = \ \(L\_y = 1\);\), 
        "\n", \(\[CapitalDelta]x\  = \ L\_x/M\_x; \ \[CapitalDelta]y\  = \ 
          L\_y/M\_y;\), "\n", \(\[CapitalDelta]t\  = \ 0.2;\), 
        "\n", \(x[j_]\  := \ j\ \[CapitalDelta]x;\), 
        "\n", \(y[k_]\  := \ k\ \[CapitalDelta]y;\), "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        StyleBox[\( (*\ initial\ conditions\ *) \),
          FontColor->RGBColor[1, 0, 0]], "\n", \(z0[j_, k_]\  := \ 0;\), 
        "\[IndentingNewLine]", \(v0[j_, k_]\  := \ 0;\), "\n", 
        "\[IndentingNewLine]", 
        StyleBox[\( (*\ zeroth\ \(\(step\)\(:\)\)\ *) \),
          FontColor->RGBColor[1, 0, 0]], 
        "\[IndentingNewLine]", \(z[j_, k_, 0]\  := \ z0[j, k];\), "\n", 
        "\[IndentingNewLine]", 
        StyleBox[\( (*\ define\ the\ wave\ speed\ on\ the\ grid\ *) \),
          FontColor->RGBColor[1, 0, 0]], 
        "\[IndentingNewLine]", \(c[j_, k_]\  := \ cw[x[j], y[k]];\), 
        "\[IndentingNewLine]", "\n", 
        StyleBox[\( (*\ boundary\ conditions\ *) \),
          FontColor->RGBColor[1, 0, 0]], 
        "\[IndentingNewLine]", \(z[0, k_, n_]\  := \ 0;\), 
        "\[IndentingNewLine]", \(z[M\_x, k_, n_]\  := \ 0;\), 
        "\[IndentingNewLine]", \(z[j_, 0, n_]\  := \ 
            x[j] \((1 - x[j])\) Sin[2  n\ \[CapitalDelta]t];\), 
        "\[IndentingNewLine]", \(z[j_, M\_y, n_]\  := \ 0;\)}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.73"],

Cell["The CTCS method for the wave equation is", "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(z\_\(j\ k\)\%\(n + 1\)\), "=", 
          
          RowBox[{\(2  z\_\(j\ k\)\%n\), "-", \(z\_\(j\ k\)\%\(n - 1\)\), "+",
             
            RowBox[{
              FractionBox[
                RowBox[{\(c\_\(j\ k\)\%\(\(\ \)\(2\)\)\), " ", 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["t",
                          FontSlant->"Italic"]}]], "2"]}], 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], 
                  "2"]], \((z\_\(j + 1\ k\)\%n - 2  z\_\(j\ k\)\%n + 
                  z\_\(j - 1\ k\)\%\(\(\ \)\(n\)\))\)}], "+", 
            RowBox[{
              FractionBox[
                RowBox[{\(c\_\(j\ k\)\%\(\(\ \)\(2\)\)\), " ", 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["t",
                          FontSlant->"Italic"]}]], "2"]}], 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["y",
                        FontSlant->"Italic"]}]], 
                  "2"]], \((z\_\(j\ k + 1\)\%n - 2  z\_\(j\ k\)\%n + 
                  z\_\(j\ k - 1\)\%\(\(\ \)\(n\)\)\ )\)}]}]}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell["We construct the recursion relation for this method below:", "Text"],

Cell[BoxData[
    \(z[j_, k_, 
        n_]\  := \ \((z[j, k, n]\  = \ 
            2\ z[j, k, n - 1]\  - 
              z[j, k, n - 
                  2]\  + \ \ \(\(\(\[CapitalDelta]t\^2\) 
                      c[j, k]^2\)\/\[CapitalDelta]x\^2\) \((\((z[j + 1, k, 
                          n - 1]\  - \ 2\ z[j, k, n - 1]\  + \ 
                        z[j - 1, k, n - 1])\)\  + \ \((z[j, k + 1, 
                          n - 1]\  - \ 2\ z[j, k, n - 1]\  + \ 
                        z[j, k - 1, n - 1])\))\))\)\  /; \ 
        n \[GreaterEqual] \ 2\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.74"],

Cell[TextData[{
  "The method can only be used for ",
  Cell[BoxData[
      \(TraditionalForm\`n \[GreaterEqual] \ 2\)]],
  " because evaluation of the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "th time step  refers back to the ",
  Cell[BoxData[
      \(TraditionalForm\`n - 2\)]],
  "nd step. Therefore, for the first step, we use the trick employed in \
Chapter ",
  ButtonBox["1",
    ButtonData:>{"Chapter1.nb", None},
    ButtonStyle->"Hyperlink"],
  " for second-order ODEs [see Eq. ",
  ButtonBox["(1.4.28)",
    ButtonData:>{"Chapter1.nb", "(1.4.28)"},
    ButtonStyle->"Hyperlink"],
  " and the surrounding discussion]:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(z\_\(j\ k\)\%1\), "=", 
          RowBox[{\(z\_\(j\ k\)\%0\), "+", 
            RowBox[{\(\(v\_o\)\_\(j\ k\)\), 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}], "+", 
            RowBox[{
              FractionBox[
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]], "2"], 
                "2"], \(a\_\(j\ \ k\)\)}]}]}], TraditionalForm]]],
  ",\nwhere ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_o\)\_\(j\ k\)\)]],
  " is the initial velocity (equal to zero for our choice of initial \
conditions), and ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(j\ k\)\)]],
  " is the initial acceleration, given by"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(a\_\(j\ k\)\), "=", 
          RowBox[{
            RowBox[{
              FractionBox[\(\(c\_\(j\ k\)\%\(\(\ \)\(2\)\)\)\(\ \)\), 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], 
                  "2"]], \((z\_\(j + 1\ k\)\%0 - 2  z\_\(j\ k\)\%0 + 
                  z\_\(j - 1\ k\)\%\(\(\ \)\(0\)\))\)}], "+", 
            RowBox[{
              FractionBox[
                RowBox[{\(c\_\(j\ k\)\%\(\(\ \)\(2\)\)\), " ", 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["t",
                          FontSlant->"Italic"]}]], "2"]}], 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["y",
                        FontSlant->"Italic"]}]], 
                  "2"]], \((z\_\(j\ k + 1\)\%0 - 2  z\_\(j\ k\)\%0 + 
                  z\_\(j\ k - 1\)\%\(\(\ \)\(0\)\)\ )\)}]}]}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "(this is also equal to zero for our initial conditions). Therefore, we \
simply have ",
  Cell[BoxData[
      \(TraditionalForm\`z\_\(j\ k\)\%1 = z\_\(j\ k\)\%0\)]],
  "=0:"
}], "Text"],

Cell[BoxData[
    \(\(z[j_, k_, 1]\  := \ 0;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.75"],

Cell[TextData[{
  "(Of course, this cell must be modified if other initial conditions are \
used.) At each time step, we construct an interpolation function of the \
solution in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(zsol[n_]\  := \ \(zsol[n]\  = \ 
        Interpolation[
          Flatten[Table[{j\ \[CapitalDelta]x, k\ \[CapitalDelta]y, 
                z[j, k, n]}, {j, 0, M\_x}, {k, 0, M\_y}], 1]]\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.76"],

Cell[TextData[{
  "In Cell ",
  ButtonBox["6.77",
    ButtonData:>"Cell 6.77",
    ButtonStyle->"Hyperlink"],
  " we plot the solution."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        Plot3D[Evaluate[\(zsol[n]\)[x, y]], {x, 0, 1}, {y, 0, 1}, 
          PlotPoints \[Rule] 60, PlotRange \[Rule] {\(- .5\),  .5}, 
          Mesh \[Rule] False, 
          PlotLabel -> "\<t=\>"\  <> ToString[n\ \[CapitalDelta]t]], {n, 0, 
          140, 4}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.77"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -11 0 ]
[.5 .82364 11 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69467 Mtetra
.4053 .69467 .41061 .69934 .41957 .69681 .41427 .69213 Mtetra
.41427 .69213 .41957 .69681 .42855 .69428 .42327 .68958 Mtetra
.42327 .68958 .42855 .69428 .43756 .69174 .43231 .68703 Mtetra
.43231 .68703 .43756 .69174 .4466 .68919 .44137 .68446 Mtetra
.44137 .68446 .4466 .68919 .45567 .68663 .45046 .68189 Mtetra
.45046 .68189 .45567 .68663 .46478 .68407 .45958 .67931 Mtetra
.45958 .67931 .46478 .68407 .47391 .68149 .46873 .67671 Mtetra
.46873 .67671 .47391 .68149 .48307 .67891 .47792 .67412 Mtetra
.47792 .67412 .48307 .67891 .49227 .67632 .48713 .67151 Mtetra
.48713 .67151 .49227 .67632 .50149 .67371 .49638 .66889 Mtetra
.49638 .66889 .50149 .67371 .51075 .6711 .50565 .66626 Mtetra
.50565 .66626 .51075 .6711 .52004 .66849 .51496 .66363 Mtetra
.51496 .66363 .52004 .66849 .52936 .66586 .5243 .66098 Mtetra
.5243 .66098 .52936 .66586 .53871 .66322 .53367 .65833 Mtetra
.53367 .65833 .53871 .66322 .54809 .66058 .54308 .65567 Mtetra
.54308 .65567 .54809 .66058 .55751 .65792 .55251 .653 Mtetra
.55251 .653 .55751 .65792 .56695 .65526 .56198 .65032 Mtetra
.56198 .65032 .56695 .65526 .57643 .65259 .57148 .64763 Mtetra
.57148 .64763 .57643 .65259 .58595 .6499 .58102 .64493 Mtetra
.58102 .64493 .58595 .6499 .59549 .64721 .59058 .64222 Mtetra
.59058 .64222 .59549 .64721 .60507 .64451 .60018 .6395 Mtetra
.60018 .6395 .60507 .64451 .61468 .6418 .60982 .63678 Mtetra
.60982 .63678 .61468 .6418 .62432 .63908 .61948 .63404 Mtetra
.61948 .63404 .62432 .63908 .634 .63636 .62918 .63129 Mtetra
.62918 .63129 .634 .63636 .64371 .63362 .63892 .62854 Mtetra
.63892 .62854 .64371 .63362 .65345 .63087 .64868 .62577 Mtetra
.64868 .62577 .65345 .63087 .66323 .62811 .65848 .623 Mtetra
.65848 .623 .66323 .62811 .67304 .62535 .66832 .62021 Mtetra
.66832 .62021 .67304 .62535 .68289 .62257 .67819 .61742 Mtetra
.67819 .61742 .68289 .62257 .69277 .61979 .68809 .61462 Mtetra
.68809 .61462 .69277 .61979 .70269 .61699 .69803 .6118 Mtetra
.69803 .6118 .70269 .61699 .71264 .61418 .70801 .60898 Mtetra
.70801 .60898 .71264 .61418 .72262 .61137 .71802 .60615 Mtetra
.71802 .60615 .72262 .61137 .73264 .60854 .72806 .6033 Mtetra
.72806 .6033 .73264 .60854 .7427 .60571 .73814 .60045 Mtetra
.73814 .60045 .7427 .60571 .75279 .60286 .74826 .59759 Mtetra
.74826 .59759 .75279 .60286 .76291 .60001 .75841 .59471 Mtetra
.75841 .59471 .76291 .60001 .77308 .59714 .7686 .59183 Mtetra
.7686 .59183 .77308 .59714 .78328 .59427 .77882 .58893 Mtetra
.77882 .58893 .78328 .59427 .79351 .59138 .78908 .58603 Mtetra
.78908 .58603 .79351 .59138 .80378 .58849 .79938 .58311 Mtetra
.79938 .58311 .80378 .58849 .81409 .58558 .80971 .58019 Mtetra
.80971 .58019 .81409 .58558 .82443 .58267 .82008 .57725 Mtetra
.82008 .57725 .82443 .58267 .83482 .57974 .83049 .57431 Mtetra
.83049 .57431 .83482 .57974 .84523 .5768 .84094 .57135 Mtetra
.84094 .57135 .84523 .5768 .85569 .57385 .85142 .56838 Mtetra
.85142 .56838 .85569 .57385 .86618 .57089 .86194 .5654 Mtetra
.86194 .5654 .86618 .57089 .87672 .56792 .8725 .56241 Mtetra
.8725 .56241 .87672 .56792 .88729 .56494 .8831 .55941 Mtetra
.8831 .55941 .88729 .56494 .89789 .56195 .89374 .5564 Mtetra
.89374 .5564 .89789 .56195 .90854 .55895 .90441 .55338 Mtetra
.90441 .55338 .90854 .55895 .91923 .55594 .91512 .55035 Mtetra
.91512 .55035 .91923 .55594 .92995 .55292 .92588 .5473 Mtetra
.92588 .5473 .92995 .55292 .94071 .54988 .93667 .54425 Mtetra
.93667 .54425 .94071 .54988 .95152 .54684 .9475 .54118 Mtetra
.9475 .54118 .95152 .54684 .96236 .54378 .95837 .53811 Mtetra
.95837 .53811 .96236 .54378 .97324 .54071 .96928 .53502 Mtetra
.96928 .53502 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.391 .69252 .39636 .6972 .4053 .69467 .39996 .68998 Mtetra
.39996 .68998 .4053 .69467 .41427 .69213 .40895 .68742 Mtetra
.40895 .68742 .41427 .69213 .42327 .68958 .41797 .68486 Mtetra
.41797 .68486 .42327 .68958 .43231 .68703 .42702 .68228 Mtetra
.42702 .68228 .43231 .68703 .44137 .68446 .4361 .6797 Mtetra
.4361 .6797 .44137 .68446 .45046 .68189 .44521 .67711 Mtetra
.44521 .67711 .45046 .68189 .45958 .67931 .45435 .67452 Mtetra
.45435 .67452 .45958 .67931 .46873 .67671 .46352 .67191 Mtetra
.46352 .67191 .46873 .67671 .47792 .67412 .47273 .66929 Mtetra
.47273 .66929 .47792 .67412 .48713 .67151 .48196 .66667 Mtetra
.48196 .66667 .48713 .67151 .49638 .66889 .49123 .66403 Mtetra
.49123 .66403 .49638 .66889 .50565 .66626 .50053 .66139 Mtetra
.50053 .66139 .50565 .66626 .51496 .66363 .50985 .65874 Mtetra
.50985 .65874 .51496 .66363 .5243 .66098 .51922 .65608 Mtetra
.51922 .65608 .5243 .66098 .53367 .65833 .52861 .65341 Mtetra
.52861 .65341 .53367 .65833 .54308 .65567 .53803 .65073 Mtetra
.53803 .65073 .54308 .65567 .55251 .653 .54749 .64804 Mtetra
.54749 .64804 .55251 .653 .56198 .65032 .55698 .64534 Mtetra
.55698 .64534 .56198 .65032 .57148 .64763 .5665 .64264 Mtetra
.5665 .64264 .57148 .64763 .58102 .64493 .57606 .63992 Mtetra
.57606 .63992 .58102 .64493 .59058 .64222 .58565 .6372 Mtetra
.58565 .6372 .59058 .64222 .60018 .6395 .59527 .63446 Mtetra
.59527 .63446 .60018 .6395 .60982 .63678 .60493 .63172 Mtetra
.60493 .63172 .60982 .63678 .61948 .63404 .61461 .62896 Mtetra
.61461 .62896 .61948 .63404 .62918 .63129 .62434 .6262 Mtetra
.62434 .6262 .62918 .63129 .63892 .62854 .63409 .62343 Mtetra
.63409 .62343 .63892 .62854 .64868 .62577 .64388 .62064 Mtetra
.64388 .62064 .64868 .62577 .65848 .623 .65371 .61785 Mtetra
.65371 .61785 .65848 .623 .66832 .62021 .66357 .61505 Mtetra
.66357 .61505 .66832 .62021 .67819 .61742 .67346 .61224 Mtetra
.67346 .61224 .67819 .61742 .68809 .61462 .68339 .60942 Mtetra
.68339 .60942 .68809 .61462 .69803 .6118 .69335 .60658 Mtetra
.69335 .60658 .69803 .6118 .70801 .60898 .70335 .60374 Mtetra
.70335 .60374 .70801 .60898 .71802 .60615 .71338 .60089 Mtetra
.71338 .60089 .71802 .60615 .72806 .6033 .72345 .59803 Mtetra
.72345 .59803 .72806 .6033 .73814 .60045 .73356 .59516 Mtetra
.73356 .59516 .73814 .60045 .74826 .59759 .7437 .59227 Mtetra
.7437 .59227 .74826 .59759 .75841 .59471 .75387 .58938 Mtetra
.75387 .58938 .75841 .59471 .7686 .59183 .76409 .58648 Mtetra
.76409 .58648 .7686 .59183 .77882 .58893 .77434 .58356 Mtetra
.77434 .58356 .77882 .58893 .78908 .58603 .78462 .58064 Mtetra
.78462 .58064 .78908 .58603 .79938 .58311 .79495 .57771 Mtetra
.79495 .57771 .79938 .58311 .80971 .58019 .80531 .57476 Mtetra
.80531 .57476 .80971 .58019 .82008 .57725 .81571 .57181 Mtetra
.81571 .57181 .82008 .57725 .83049 .57431 .82614 .56884 Mtetra
.82614 .56884 .83049 .57431 .84094 .57135 .83661 .56586 Mtetra
.83661 .56586 .84094 .57135 .85142 .56838 .84712 .56288 Mtetra
.84712 .56288 .85142 .56838 .86194 .5654 .85767 .55988 Mtetra
.85767 .55988 .86194 .5654 .8725 .56241 .86826 .55687 Mtetra
.86826 .55687 .8725 .56241 .8831 .55941 .87889 .55385 Mtetra
.87889 .55385 .8831 .55941 .89374 .5564 .88955 .55082 Mtetra
.88955 .55082 .89374 .5564 .90441 .55338 .90025 .54777 Mtetra
.90025 .54777 .90441 .55338 .91512 .55035 .911 .54472 Mtetra
.911 .54472 .91512 .55035 .92588 .5473 .92178 .54166 Mtetra
.92178 .54166 .92588 .5473 .93667 .54425 .9326 .53858 Mtetra
.9326 .53858 .93667 .54425 .9475 .54118 .94346 .53549 Mtetra
.94346 .53549 .9475 .54118 .95837 .53811 .95436 .53239 Mtetra
.95436 .53239 .95837 .53811 .96928 .53502 .9653 .52928 Mtetra
.9653 .52928 .96928 .53502 .98024 .53192 .97628 .52616 Mtetra
.38561 .68781 .391 .69252 .39996 .68998 .39459 .68525 Mtetra
.39459 .68525 .39996 .68998 .40895 .68742 .40359 .68268 Mtetra
.40359 .68268 .40895 .68742 .41797 .68486 .41263 .6801 Mtetra
.41263 .6801 .41797 .68486 .42702 .68228 .4217 .67751 Mtetra
.4217 .67751 .42702 .68228 .4361 .6797 .4308 .67492 Mtetra
.4308 .67492 .4361 .6797 .44521 .67711 .43993 .67231 Mtetra
.43993 .67231 .44521 .67711 .45435 .67452 .44909 .6697 Mtetra
.44909 .6697 .45435 .67452 .46352 .67191 .45828 .66707 Mtetra
.45828 .66707 .46352 .67191 .47273 .66929 .46751 .66444 Mtetra
.46751 .66444 .47273 .66929 .48196 .66667 .47676 .6618 Mtetra
.47676 .6618 .48196 .66667 .49123 .66403 .48605 .65915 Mtetra
.48605 .65915 .49123 .66403 .50053 .66139 .49537 .65649 Mtetra
.49537 .65649 .50053 .66139 .50985 .65874 .50472 .65382 Mtetra
.50472 .65382 .50985 .65874 .51922 .65608 .5141 .65114 Mtetra
.5141 .65114 .51922 .65608 .52861 .65341 .52351 .64846 Mtetra
.52351 .64846 .52861 .65341 .53803 .65073 .53296 .64576 Mtetra
.53296 .64576 .53803 .65073 .54749 .64804 .54244 .64305 Mtetra
.54244 .64305 .54749 .64804 .55698 .64534 .55195 .64034 Mtetra
.55195 .64034 .55698 .64534 .5665 .64264 .56149 .63762 Mtetra
.56149 .63762 .5665 .64264 .57606 .63992 .57107 .63488 Mtetra
.57107 .63488 .57606 .63992 .58565 .6372 .58068 .63214 Mtetra
.58068 .63214 .58565 .6372 .59527 .63446 .59032 .62939 Mtetra
.59032 .62939 .59527 .63446 .60493 .63172 .6 .62663 Mtetra
.6 .62663 .60493 .63172 .61461 .62896 .60971 .62385 Mtetra
.60971 .62385 .61461 .62896 .62434 .6262 .61946 .62107 Mtetra
.61946 .62107 .62434 .6262 .63409 .62343 .62924 .61828 Mtetra
.62924 .61828 .63409 .62343 .64388 .62064 .63905 .61548 Mtetra
.63905 .61548 .64388 .62064 .65371 .61785 .6489 .61267 Mtetra
.6489 .61267 .65371 .61785 .66357 .61505 .65878 .60985 Mtetra
.65878 .60985 .66357 .61505 .67346 .61224 .6687 .60702 Mtetra
.6687 .60702 .67346 .61224 .68339 .60942 .67865 .60418 Mtetra
.67865 .60418 .68339 .60942 .69335 .60658 .68864 .60133 Mtetra
.68864 .60133 .69335 .60658 .70335 .60374 .69866 .59847 Mtetra
.69866 .59847 .70335 .60374 .71338 .60089 .70872 .5956 Mtetra
.70872 .5956 .71338 .60089 .72345 .59803 .71881 .59272 Mtetra
.71881 .59272 .72345 .59803 .73356 .59516 .72894 .58983 Mtetra
.72894 .58983 .73356 .59516 .7437 .59227 .73911 .58692 Mtetra
.73911 .58692 .7437 .59227 .75387 .58938 .74931 .58401 Mtetra
.74931 .58401 .75387 .58938 .76409 .58648 .75955 .58109 Mtetra
.75955 .58109 .76409 .58648 .77434 .58356 .76982 .57816 Mtetra
.76982 .57816 .77434 .58356 .78462 .58064 .78014 .57521 Mtetra
.78014 .57521 .78462 .58064 .79495 .57771 .79049 .57226 Mtetra
.79049 .57226 .79495 .57771 .80531 .57476 .80087 .5693 Mtetra
.80087 .5693 .80531 .57476 .81571 .57181 .8113 .56632 Mtetra
.8113 .56632 .81571 .57181 .82614 .56884 .82176 .56334 Mtetra
.82176 .56334 .82614 .56884 .83661 .56586 .83226 .56034 Mtetra
.83226 .56034 .83661 .56586 .84712 .56288 .8428 .55733 Mtetra
.8428 .55733 .84712 .56288 .85767 .55988 .85337 .55431 Mtetra
.85337 .55431 .85767 .55988 .86826 .55687 .86399 .55128 Mtetra
.86399 .55128 .86826 .55687 .87889 .55385 .87464 .54824 Mtetra
.87464 .54824 .87889 .55385 .88955 .55082 .88533 .54519 Mtetra
.88533 .54519 .88955 .55082 .90025 .54777 .89607 .54213 Mtetra
.89607 .54213 .90025 .54777 .911 .54472 .90684 .53905 Mtetra
.90684 .53905 .911 .54472 .92178 .54166 .91765 .53597 Mtetra
.91765 .53597 .92178 .54166 .9326 .53858 .9285 .53287 Mtetra
.9285 .53287 .9326 .53858 .94346 .53549 .93939 .52976 Mtetra
.93939 .52976 .94346 .53549 .95436 .53239 .95032 .52664 Mtetra
.95032 .52664 .95436 .53239 .9653 .52928 .96129 .52351 Mtetra
.96129 .52351 .9653 .52928 .97628 .52616 .9723 .52037 Mtetra
.38018 .68308 .38561 .68781 .39459 .68525 .38918 .6805 Mtetra
.38918 .6805 .39459 .68525 .40359 .68268 .3982 .67791 Mtetra
.3982 .67791 .40359 .68268 .41263 .6801 .40726 .67532 Mtetra
.40726 .67532 .41263 .6801 .4217 .67751 .41635 .67271 Mtetra
.41635 .67271 .4217 .67751 .4308 .67492 .42547 .6701 Mtetra
.42547 .6701 .4308 .67492 .43993 .67231 .43462 .66748 Mtetra
.43462 .66748 .43993 .67231 .44909 .6697 .4438 .66485 Mtetra
.4438 .66485 .44909 .6697 .45828 .66707 .45301 .66221 Mtetra
.45301 .66221 .45828 .66707 .46751 .66444 .46225 .65956 Mtetra
.46225 .65956 .46751 .66444 .47676 .6618 .47153 .6569 Mtetra
.47153 .6569 .47676 .6618 .48605 .65915 .48083 .65423 Mtetra
.48083 .65423 .48605 .65915 .49537 .65649 .49017 .65156 Mtetra
.49017 .65156 .49537 .65649 .50472 .65382 .49954 .64887 Mtetra
.49954 .64887 .50472 .65382 .5141 .65114 .50895 .64618 Mtetra
.50895 .64618 .5141 .65114 .52351 .64846 .51838 .64347 Mtetra
.51838 .64347 .52351 .64846 .53296 .64576 .52785 .64076 Mtetra
.52785 .64076 .53296 .64576 .54244 .64305 .53735 .63804 Mtetra
.53735 .63804 .54244 .64305 .55195 .64034 .54688 .6353 Mtetra
.54688 .6353 .55195 .64034 .56149 .63762 .55645 .63256 Mtetra
.55645 .63256 .56149 .63762 .57107 .63488 .56605 .62981 Mtetra
.56605 .62981 .57107 .63488 .58068 .63214 .57568 .62705 Mtetra
.57568 .62705 .58068 .63214 .59032 .62939 .58535 .62428 Mtetra
.58535 .62428 .59032 .62939 .6 .62663 .59505 .6215 Mtetra
.59505 .6215 .6 .62663 .60971 .62385 .60478 .61871 Mtetra
.60478 .61871 .60971 .62385 .61946 .62107 .61455 .61591 Mtetra
.61455 .61591 .61946 .62107 .62924 .61828 .62435 .6131 Mtetra
.62435 .6131 .62924 .61828 .63905 .61548 .63419 .61028 Mtetra
.63419 .61028 .63905 .61548 .6489 .61267 .64406 .60746 Mtetra
.64406 .60746 .6489 .61267 .65878 .60985 .65396 .60462 Mtetra
.65396 .60462 .65878 .60985 .6687 .60702 .66391 .60177 Mtetra
.66391 .60177 .6687 .60702 .67865 .60418 .67388 .59891 Mtetra
.67388 .59891 .67865 .60418 .68864 .60133 .68389 .59604 Mtetra
.68389 .59604 .68864 .60133 .69866 .59847 .69394 .59316 Mtetra
.69394 .59316 .69866 .59847 .70872 .5956 .70402 .59027 Mtetra
.70402 .59027 .70872 .5956 .71881 .59272 .71414 .58737 Mtetra
.71414 .58737 .71881 .59272 .72894 .58983 .7243 .58446 Mtetra
.7243 .58446 .72894 .58983 .73911 .58692 .73449 .58154 Mtetra
.73449 .58154 .73911 .58692 .74931 .58401 .74472 .57861 Mtetra
.74472 .57861 .74931 .58401 .75955 .58109 .75498 .57567 Mtetra
.75498 .57567 .75955 .58109 .76982 .57816 .76528 .57272 Mtetra
.76528 .57272 .76982 .57816 .78014 .57521 .77562 .56975 Mtetra
.77562 .56975 .78014 .57521 .79049 .57226 .786 .56678 Mtetra
.786 .56678 .79049 .57226 .80087 .5693 .79641 .5638 Mtetra
.79641 .5638 .80087 .5693 .8113 .56632 .80686 .5608 Mtetra
.80686 .5608 .8113 .56632 .82176 .56334 .81735 .55779 Mtetra
.81735 .55779 .82176 .56334 .83226 .56034 .82788 .55478 Mtetra
.82788 .55478 .83226 .56034 .8428 .55733 .83844 .55175 Mtetra
.83844 .55175 .8428 .55733 .85337 .55431 .84905 .54871 Mtetra
.84905 .54871 .85337 .55431 .86399 .55128 .85969 .54566 Mtetra
.85969 .54566 .86399 .55128 .87464 .54824 .87037 .5426 Mtetra
.87037 .5426 .87464 .54824 .88533 .54519 .88109 .53953 Mtetra
.88109 .53953 .88533 .54519 .89607 .54213 .89185 .53644 Mtetra
.89185 .53644 .89607 .54213 .90684 .53905 .90265 .53335 Mtetra
.90265 .53335 .90684 .53905 .91765 .53597 .91349 .53024 Mtetra
.91349 .53024 .91765 .53597 .9285 .53287 .92437 .52712 Mtetra
.92437 .52712 .9285 .53287 .93939 .52976 .93529 .524 Mtetra
.93529 .524 .93939 .52976 .95032 .52664 .94625 .52085 Mtetra
.94625 .52085 .95032 .52664 .96129 .52351 .95725 .5177 Mtetra
.95725 .5177 .96129 .52351 .9723 .52037 .96829 .51454 Mtetra
.37472 .67831 .38018 .68308 .38918 .6805 .38373 .67572 Mtetra
.38373 .67572 .38918 .6805 .3982 .67791 .39278 .67311 Mtetra
.39278 .67311 .3982 .67791 .40726 .67532 .40186 .6705 Mtetra
.40186 .6705 .40726 .67532 .41635 .67271 .41096 .66788 Mtetra
.41096 .66788 .41635 .67271 .42547 .6701 .4201 .66525 Mtetra
.4201 .66525 .42547 .6701 .43462 .66748 .42927 .66261 Mtetra
.42927 .66261 .43462 .66748 .4438 .66485 .43847 .65996 Mtetra
.43847 .65996 .4438 .66485 .45301 .66221 .4477 .65731 Mtetra
.4477 .65731 .45301 .66221 .46225 .65956 .45697 .65464 Mtetra
.45697 .65464 .46225 .65956 .47153 .6569 .46626 .65197 Mtetra
.46626 .65197 .47153 .6569 .48083 .65423 .47559 .64928 Mtetra
.47559 .64928 .48083 .65423 .49017 .65156 .48495 .64659 Mtetra
.48495 .64659 .49017 .65156 .49954 .64887 .49434 .64389 Mtetra
.49434 .64389 .49954 .64887 .50895 .64618 .50376 .64118 Mtetra
.50376 .64118 .50895 .64618 .51838 .64347 .51322 .63846 Mtetra
.51322 .63846 .51838 .64347 .52785 .64076 .52271 .63572 Mtetra
.52271 .63572 .52785 .64076 .53735 .63804 .53223 .63298 Mtetra
.53223 .63298 .53735 .63804 .54688 .6353 .54178 .63024 Mtetra
.54178 .63024 .54688 .6353 .55645 .63256 .55137 .62748 Mtetra
.55137 .62748 .55645 .63256 .56605 .62981 .56099 .62471 Mtetra
.56099 .62471 .56605 .62981 .57568 .62705 .57065 .62193 Mtetra
.57065 .62193 .57568 .62705 .58535 .62428 .58034 .61914 Mtetra
.58034 .61914 .58535 .62428 .59505 .6215 .59006 .61634 Mtetra
.59006 .61634 .59505 .6215 .60478 .61871 .59982 .61354 Mtetra
.59982 .61354 .60478 .61871 .61455 .61591 .60961 .61072 Mtetra
.60961 .61072 .61455 .61591 .62435 .6131 .61943 .60789 Mtetra
.61943 .60789 .62435 .6131 .63419 .61028 .62929 .60505 Mtetra
.62929 .60505 .63419 .61028 .64406 .60746 .63919 .60221 Mtetra
.63919 .60221 .64406 .60746 .65396 .60462 .64912 .59935 Mtetra
.64912 .59935 .65396 .60462 .66391 .60177 .65908 .59648 Mtetra
.65908 .59648 .66391 .60177 .67388 .59891 .66908 .5936 Mtetra
.66908 .5936 .67388 .59891 .68389 .59604 .67912 .59072 Mtetra
.67912 .59072 .68389 .59604 .69394 .59316 .68919 .58782 Mtetra
.68919 .58782 .69394 .59316 .70402 .59027 .6993 .58491 Mtetra
.6993 .58491 .70402 .59027 .71414 .58737 .70944 .58199 Mtetra
.70944 .58199 .71414 .58737 .7243 .58446 .71962 .57906 Mtetra
.71962 .57906 .7243 .58446 .73449 .58154 .72984 .57612 Mtetra
.72984 .57612 .73449 .58154 .74472 .57861 .74009 .57317 Mtetra
.74009 .57317 .74472 .57861 .75498 .57567 .75038 .57021 Mtetra
.75038 .57021 .75498 .57567 .76528 .57272 .76071 .56724 Mtetra
.76071 .56724 .76528 .57272 .77562 .56975 .77107 .56426 Mtetra
.77107 .56426 .77562 .56975 .786 .56678 .78148 .56126 Mtetra
.78148 .56126 .786 .56678 .79641 .5638 .79192 .55826 Mtetra
.79192 .55826 .79641 .5638 .80686 .5608 .80239 .55524 Mtetra
.80239 .55524 .80686 .5608 .81735 .55779 .81291 .55222 Mtetra
.81291 .55222 .81735 .55779 .82788 .55478 .82346 .54918 Mtetra
.82346 .54918 .82788 .55478 .83844 .55175 .83406 .54613 Mtetra
.83406 .54613 .83844 .55175 .84905 .54871 .84469 .54307 Mtetra
.84469 .54307 .84905 .54871 .85969 .54566 .85536 .54 Mtetra
.85536 .54 .85969 .54566 .87037 .5426 .86607 .53692 Mtetra
.86607 .53692 .87037 .5426 .88109 .53953 .87682 .53383 Mtetra
.87682 .53383 .88109 .53953 .89185 .53644 .88761 .53072 Mtetra
.88761 .53072 .89185 .53644 .90265 .53335 .89844 .52761 Mtetra
.89844 .52761 .90265 .53335 .91349 .53024 .90931 .52448 Mtetra
.90931 .52448 .91349 .53024 .92437 .52712 .92022 .52134 Mtetra
.92022 .52134 .92437 .52712 .93529 .524 .93116 .51819 Mtetra
.93116 .51819 .93529 .524 .94625 .52085 .94216 .51503 Mtetra
.94216 .51503 .94625 .52085 .95725 .5177 .95319 .51185 Mtetra
.95319 .51185 .95725 .5177 .96829 .51454 .96426 .50866 Mtetra
.36922 .67351 .37472 .67831 .38373 .67572 .37826 .6709 Mtetra
.37826 .6709 .38373 .67572 .39278 .67311 .38732 .66828 Mtetra
.38732 .66828 .39278 .67311 .40186 .6705 .39642 .66566 Mtetra
.39642 .66566 .40186 .6705 .41096 .66788 .40554 .66302 Mtetra
.40554 .66302 .41096 .66788 .4201 .66525 .4147 .66037 Mtetra
.4147 .66037 .4201 .66525 .42927 .66261 .42389 .65772 Mtetra
.42389 .65772 .42927 .66261 .43847 .65996 .43311 .65505 Mtetra
.43311 .65505 .43847 .65996 .4477 .65731 .44236 .65238 Mtetra
.44236 .65238 .4477 .65731 .45697 .65464 .45165 .6497 Mtetra
.45165 .6497 .45697 .65464 .46626 .65197 .46096 .64701 Mtetra
.46096 .64701 .46626 .65197 .47559 .64928 .47031 .6443 Mtetra
.47031 .6443 .47559 .64928 .48495 .64659 .47969 .64159 Mtetra
.47969 .64159 .48495 .64659 .49434 .64389 .4891 .63887 Mtetra
.4891 .63887 .49434 .64389 .50376 .64118 .49855 .63615 Mtetra
.49855 .63615 .50376 .64118 .51322 .63846 .50802 .63341 Mtetra
.50802 .63341 .51322 .63846 .52271 .63572 .51753 .63066 Mtetra
.51753 .63066 .52271 .63572 .53223 .63298 .52708 .6279 Mtetra
.52708 .6279 .53223 .63298 .54178 .63024 .53665 .62513 Mtetra
.53665 .62513 .54178 .63024 .55137 .62748 .54626 .62236 Mtetra
.54626 .62236 .55137 .62748 .56099 .62471 .55591 .61957 Mtetra
.55591 .61957 .56099 .62471 .57065 .62193 .56558 .61677 Mtetra
.56558 .61677 .57065 .62193 .58034 .61914 .57529 .61397 Mtetra
.57529 .61397 .58034 .61914 .59006 .61634 .58504 .61115 Mtetra
.58504 .61115 .59006 .61634 .59982 .61354 .59482 .60833 Mtetra
.59482 .60833 .59982 .61354 .60961 .61072 .60463 .60549 Mtetra
.60463 .60549 .60961 .61072 .61943 .60789 .61448 .60265 Mtetra
.61448 .60265 .61943 .60789 .62929 .60505 .62437 .59979 Mtetra
.62437 .59979 .62929 .60505 .63919 .60221 .63428 .59692 Mtetra
.63428 .59692 .63919 .60221 .64912 .59935 .64424 .59405 Mtetra
.64424 .59405 .64912 .59935 .65908 .59648 .65423 .59116 Mtetra
.65423 .59116 .65908 .59648 .66908 .5936 .66425 .58826 Mtetra
.66425 .58826 .66908 .5936 .67912 .59072 .67431 .58536 Mtetra
.67431 .58536 .67912 .59072 .68919 .58782 .68441 .58244 Mtetra
.68441 .58244 .68919 .58782 .6993 .58491 .69454 .57951 Mtetra
.69454 .57951 .6993 .58491 .70944 .58199 .70471 .57657 Mtetra
.70471 .57657 .70944 .58199 .71962 .57906 .71491 .57363 Mtetra
.71491 .57363 .71962 .57906 .72984 .57612 .72516 .57067 Mtetra
.72516 .57067 .72984 .57612 .74009 .57317 .73544 .5677 Mtetra
.73544 .5677 .74009 .57317 .75038 .57021 .74575 .56471 Mtetra
.74575 .56471 .75038 .57021 .76071 .56724 .75611 .56172 Mtetra
.75611 .56172 .76071 .56724 .77107 .56426 .7665 .55872 Mtetra
.7665 .55872 .77107 .56426 .78148 .56126 .77693 .55571 Mtetra
.77693 .55571 .78148 .56126 .79192 .55826 .78739 .55268 Mtetra
.78739 .55268 .79192 .55826 .80239 .55524 .7979 .54965 Mtetra
.7979 .54965 .80239 .55524 .81291 .55222 .80844 .5466 Mtetra
.80844 .5466 .81291 .55222 .82346 .54918 .81902 .54354 Mtetra
.81902 .54354 .82346 .54918 .83406 .54613 .82964 .54047 Mtetra
.82964 .54047 .83406 .54613 .84469 .54307 .8403 .53739 Mtetra
.8403 .53739 .84469 .54307 .85536 .54 .851 .5343 Mtetra
.851 .5343 .85536 .54 .86607 .53692 .86174 .5312 Mtetra
.86174 .5312 .86607 .53692 .87682 .53383 .87252 .52809 Mtetra
.87252 .52809 .87682 .53383 .88761 .53072 .88334 .52496 Mtetra
.88334 .52496 .88761 .53072 .89844 .52761 .89419 .52182 Mtetra
.89419 .52182 .89844 .52761 .90931 .52448 .90509 .51867 Mtetra
.90509 .51867 .90931 .52448 .92022 .52134 .91603 .51551 Mtetra
.91603 .51551 .92022 .52134 .93116 .51819 .92701 .51234 Mtetra
.92701 .51234 .93116 .51819 .94216 .51503 .93803 .50916 Mtetra
.93803 .50916 .94216 .51503 .95319 .51185 .94909 .50596 Mtetra
.94909 .50596 .95319 .51185 .96426 .50866 .9602 .50275 Mtetra
.36369 .66869 .36922 .67351 .37826 .6709 .37275 .66606 Mtetra
.37275 .66606 .37826 .6709 .38732 .66828 .38183 .66342 Mtetra
.38183 .66342 .38732 .66828 .39642 .66566 .39094 .66078 Mtetra
.39094 .66078 .39642 .66566 .40554 .66302 .40009 .65813 Mtetra
.40009 .65813 .40554 .66302 .4147 .66037 .40927 .65546 Mtetra
.40927 .65546 .4147 .66037 .42389 .65772 .41848 .65279 Mtetra
.41848 .65279 .42389 .65772 .43311 .65505 .42772 .65011 Mtetra
.42772 .65011 .43311 .65505 .44236 .65238 .43699 .64742 Mtetra
.43699 .64742 .44236 .65238 .45165 .6497 .44629 .64472 Mtetra
.44629 .64472 .45165 .6497 .46096 .64701 .45563 .64201 Mtetra
.45563 .64201 .46096 .64701 .47031 .6443 .465 .63929 Mtetra
.465 .63929 .47031 .6443 .47969 .64159 .4744 .63657 Mtetra
.4744 .63657 .47969 .64159 .4891 .63887 .48383 .63383 Mtetra
.48383 .63383 .4891 .63887 .49855 .63615 .4933 .63108 Mtetra
.4933 .63108 .49855 .63615 .50802 .63341 .50279 .62833 Mtetra
.50279 .62833 .50802 .63341 .51753 .63066 .51233 .62556 Mtetra
.51233 .62556 .51753 .63066 .52708 .6279 .52189 .62279 Mtetra
.52189 .62279 .52708 .6279 .53665 .62513 .53149 .62 Mtetra
.53149 .62 .53665 .62513 .54626 .62236 .54112 .61721 Mtetra
.54112 .61721 .54626 .62236 .55591 .61957 .55079 .6144 Mtetra
.55079 .6144 .55591 .61957 .56558 .61677 .56049 .61159 Mtetra
.56049 .61159 .56558 .61677 .57529 .61397 .57022 .60876 Mtetra
.57022 .60876 .57529 .61397 .58504 .61115 .57999 .60593 Mtetra
.57999 .60593 .58504 .61115 .59482 .60833 .58979 .60308 Mtetra
.58979 .60308 .59482 .60833 .60463 .60549 .59963 .60023 Mtetra
.59963 .60023 .60463 .60549 .61448 .60265 .6095 .59737 Mtetra
.6095 .59737 .61448 .60265 .62437 .59979 .61941 .59449 Mtetra
.61941 .59449 .62437 .59979 .63428 .59692 .62935 .59161 Mtetra
.62935 .59161 .63428 .59692 .64424 .59405 .63933 .58871 Mtetra
.63933 .58871 .64424 .59405 .65423 .59116 .64934 .58581 Mtetra
.64934 .58581 .65423 .59116 .66425 .58826 .65939 .58289 Mtetra
.65939 .58289 .66425 .58826 .67431 .58536 .66947 .57996 Mtetra
.66947 .57996 .67431 .58536 .68441 .58244 .67959 .57703 Mtetra
.67959 .57703 .68441 .58244 .69454 .57951 .68975 .57408 Mtetra
.68975 .57408 .69454 .57951 .70471 .57657 .69995 .57112 Mtetra
.69995 .57112 .70471 .57657 .71491 .57363 .71018 .56815 Mtetra
.71018 .56815 .71491 .57363 .72516 .57067 .72044 .56517 Mtetra
.72044 .56517 .72516 .57067 .73544 .5677 .73075 .56218 Mtetra
.73075 .56218 .73544 .5677 .74575 .56471 .74109 .55918 Mtetra
.74109 .55918 .74575 .56471 .75611 .56172 .75147 .55617 Mtetra
.75147 .55617 .75611 .56172 .7665 .55872 .76189 .55315 Mtetra
.76189 .55315 .7665 .55872 .77693 .55571 .77234 .55012 Mtetra
.77234 .55012 .77693 .55571 .78739 .55268 .78284 .54707 Mtetra
.78284 .54707 .78739 .55268 .7979 .54965 .79337 .54401 Mtetra
.79337 .54401 .7979 .54965 .80844 .5466 .80394 .54095 Mtetra
.80394 .54095 .80844 .5466 .81902 .54354 .81455 .53787 Mtetra
.81455 .53787 .81902 .54354 .82964 .54047 .8252 .53478 Mtetra
.8252 .53478 .82964 .54047 .8403 .53739 .83589 .53168 Mtetra
.83589 .53168 .8403 .53739 .851 .5343 .84661 .52857 Mtetra
.84661 .52857 .851 .5343 .86174 .5312 .85738 .52544 Mtetra
.85738 .52544 .86174 .5312 .87252 .52809 .86819 .52231 Mtetra
.86819 .52231 .87252 .52809 .88334 .52496 .87903 .51916 Mtetra
.87903 .51916 .88334 .52496 .89419 .52182 .88992 .516 Mtetra
.88992 .516 .89419 .52182 .90509 .51867 .90085 .51283 Mtetra
.90085 .51283 .90509 .51867 .91603 .51551 .91182 .50965 Mtetra
.91182 .50965 .91603 .51551 .92701 .51234 .92283 .50645 Mtetra
.92283 .50645 .92701 .51234 .93803 .50916 .93388 .50324 Mtetra
.93388 .50324 .93803 .50916 .94909 .50596 .94497 .50003 Mtetra
.94497 .50003 .94909 .50596 .9602 .50275 .9561 .4968 Mtetra
.35813 .66383 .36369 .66869 .37275 .66606 .3672 .66119 Mtetra
.3672 .66119 .37275 .66606 .38183 .66342 .3763 .65854 Mtetra
.3763 .65854 .38183 .66342 .39094 .66078 .38544 .65587 Mtetra
.38544 .65587 .39094 .66078 .40009 .65813 .3946 .6532 Mtetra
.3946 .6532 .40009 .65813 .40927 .65546 .4038 .65052 Mtetra
.4038 .65052 .40927 .65546 .41848 .65279 .41303 .64783 Mtetra
.41303 .64783 .41848 .65279 .42772 .65011 .42229 .64514 Mtetra
.42229 .64514 .42772 .65011 .43699 .64742 .43158 .64243 Mtetra
.43158 .64243 .43699 .64742 .44629 .64472 .4409 .63971 Mtetra
.4409 .63971 .44629 .64472 .45563 .64201 .45026 .63699 Mtetra
.45026 .63699 .45563 .64201 .465 .63929 .45965 .63425 Mtetra
.45965 .63425 .465 .63929 .4744 .63657 .46907 .63151 Mtetra
.46907 .63151 .4744 .63657 .48383 .63383 .47853 .62875 Mtetra
.47853 .62875 .48383 .63383 .4933 .63108 .48801 .62599 Mtetra
.48801 .62599 .4933 .63108 .50279 .62833 .49753 .62321 Mtetra
.49753 .62321 .50279 .62833 .51233 .62556 .50709 .62043 Mtetra
.50709 .62043 .51233 .62556 .52189 .62279 .51667 .61764 Mtetra
.51667 .61764 .52189 .62279 .53149 .62 .52629 .61483 Mtetra
.52629 .61483 .53149 .62 .54112 .61721 .53595 .61202 Mtetra
.53595 .61202 .54112 .61721 .55079 .6144 .54563 .6092 Mtetra
.54563 .6092 .55079 .6144 .56049 .61159 .55536 .60636 Mtetra
.55536 .60636 .56049 .61159 .57022 .60876 .56511 .60352 Mtetra
.56511 .60352 .57022 .60876 .57999 .60593 .5749 .60067 Mtetra
.5749 .60067 .57999 .60593 .58979 .60308 .58473 .59781 Mtetra
.58473 .59781 .58979 .60308 .59963 .60023 .59459 .59493 Mtetra
.59459 .59493 .59963 .60023 .6095 .59737 .60448 .59205 Mtetra
.60448 .59205 .6095 .59737 .61941 .59449 .61441 .58916 Mtetra
.61441 .58916 .61941 .59449 .62935 .59161 .62438 .58625 Mtetra
.62438 .58625 .62935 .59161 .63933 .58871 .63438 .58334 Mtetra
.63438 .58334 .63933 .58871 .64934 .58581 .64442 .58041 Mtetra
.64442 .58041 .64934 .58581 .65939 .58289 .65449 .57748 Mtetra
.65449 .57748 .65939 .58289 .66947 .57996 .6646 .57453 Mtetra
.6646 .57453 .66947 .57996 .67959 .57703 .67475 .57158 Mtetra
.67475 .57158 .67959 .57703 .68975 .57408 .68493 .56861 Mtetra
.68493 .56861 .68975 .57408 .69995 .57112 .69515 .56563 Mtetra
.69515 .56563 .69995 .57112 .71018 .56815 .70541 .56264 Mtetra
.70541 .56264 .71018 .56815 .72044 .56517 .7157 .55965 Mtetra
.7157 .55965 .72044 .56517 .73075 .56218 .72603 .55664 Mtetra
.72603 .55664 .73075 .56218 .74109 .55918 .7364 .55361 Mtetra
.7364 .55361 .74109 .55918 .75147 .55617 .7468 .55058 Mtetra
.7468 .55058 .75147 .55617 .76189 .55315 .75725 .54754 Mtetra
.75725 .54754 .76189 .55315 .77234 .55012 .76773 .54449 Mtetra
.76773 .54449 .77234 .55012 .78284 .54707 .77825 .54142 Mtetra
.77825 .54142 .78284 .54707 .79337 .54401 .78881 .53834 Mtetra
.78881 .53834 .79337 .54401 .80394 .54095 .79941 .53526 Mtetra
.79941 .53526 .80394 .54095 .81455 .53787 .81005 .53216 Mtetra
.81005 .53216 .81455 .53787 .8252 .53478 .82072 .52905 Mtetra
.82072 .52905 .8252 .53478 .83589 .53168 .83144 .52592 Mtetra
.83144 .52592 .83589 .53168 .84661 .52857 .84219 .52279 Mtetra
.84219 .52279 .84661 .52857 .85738 .52544 .85299 .51964 Mtetra
.85299 .51964 .85738 .52544 .86819 .52231 .86383 .51649 Mtetra
.86383 .51649 .86819 .52231 .87903 .51916 .8747 .51332 Mtetra
.8747 .51332 .87903 .51916 .88992 .516 .88562 .51014 Mtetra
.88562 .51014 .88992 .516 .90085 .51283 .89658 .50694 Mtetra
.89658 .50694 .90085 .51283 .91182 .50965 .90758 .50374 Mtetra
.90758 .50374 .91182 .50965 .92283 .50645 .91862 .50052 Mtetra
.91862 .50052 .92283 .50645 .93388 .50324 .9297 .49729 Mtetra
.9297 .49729 .93388 .50324 .94497 .50003 .94082 .49405 Mtetra
.94082 .49405 .94497 .50003 .9561 .4968 .95198 .4908 Mtetra
.35253 .65894 .35813 .66383 .3672 .66119 .36162 .65628 Mtetra
.36162 .65628 .3672 .66119 .3763 .65854 .37074 .65361 Mtetra
.37074 .65361 .3763 .65854 .38544 .65587 .3799 .65094 Mtetra
.3799 .65094 .38544 .65587 .3946 .6532 .38908 .64825 Mtetra
.38908 .64825 .3946 .6532 .4038 .65052 .3983 .64555 Mtetra
.3983 .64555 .4038 .65052 .41303 .64783 .40755 .64285 Mtetra
.40755 .64285 .41303 .64783 .42229 .64514 .41683 .64013 Mtetra
.41683 .64013 .42229 .64514 .43158 .64243 .42614 .63741 Mtetra
.42614 .63741 .43158 .64243 .4409 .63971 .43548 .63467 Mtetra
.43548 .63467 .4409 .63971 .45026 .63699 .44486 .63193 Mtetra
.44486 .63193 .45026 .63699 .45965 .63425 .45427 .62918 Mtetra
.45427 .62918 .45965 .63425 .46907 .63151 .46371 .62641 Mtetra
.46371 .62641 .46907 .63151 .47853 .62875 .47319 .62364 Mtetra
.47319 .62364 .47853 .62875 .48801 .62599 .48269 .62086 Mtetra
.48269 .62086 .48801 .62599 .49753 .62321 .49224 .61807 Mtetra
.49224 .61807 .49753 .62321 .50709 .62043 .50181 .61527 Mtetra
.50181 .61527 .50709 .62043 .51667 .61764 .51142 .61245 Mtetra
.51142 .61245 .51667 .61764 .52629 .61483 .52106 .60963 Mtetra
.52106 .60963 .52629 .61483 .53595 .61202 .53074 .6068 Mtetra
.53074 .6068 .53595 .61202 .54563 .6092 .54045 .60396 Mtetra
.54045 .60396 .54563 .6092 .55536 .60636 .55019 .60111 Mtetra
.55019 .60111 .55536 .60636 .56511 .60352 .55997 .59825 Mtetra
.55997 .59825 .56511 .60352 .5749 .60067 .56978 .59538 Mtetra
.56978 .59538 .5749 .60067 .58473 .59781 .57963 .59249 Mtetra
.57963 .59249 .58473 .59781 .59459 .59493 .58952 .5896 Mtetra
.58952 .5896 .59459 .59493 .60448 .59205 .59944 .5867 Mtetra
.59944 .5867 .60448 .59205 .61441 .58916 .60939 .58379 Mtetra
.60939 .58379 .61441 .58916 .62438 .58625 .61938 .58087 Mtetra
.61938 .58087 .62438 .58625 .63438 .58334 .62941 .57793 Mtetra
.62941 .57793 .63438 .58334 .64442 .58041 .63947 .57499 Mtetra
.63947 .57499 .64442 .58041 .65449 .57748 .64957 .57203 Mtetra
.64957 .57203 .65449 .57748 .6646 .57453 .6597 .56907 Mtetra
.6597 .56907 .6646 .57453 .67475 .57158 .66987 .56609 Mtetra
.66987 .56609 .67475 .57158 .68493 .56861 .68008 .56311 Mtetra
.68008 .56311 .68493 .56861 .69515 .56563 .69032 .56011 Mtetra
.69032 .56011 .69515 .56563 .70541 .56264 .7006 .5571 Mtetra
.7006 .5571 .70541 .56264 .7157 .55965 .71092 .55408 Mtetra
.71092 .55408 .7157 .55965 .72603 .55664 .72128 .55105 Mtetra
.72128 .55105 .72603 .55664 .7364 .55361 .73168 .54801 Mtetra
.73168 .54801 .7364 .55361 .7468 .55058 .74211 .54496 Mtetra
.74211 .54496 .7468 .55058 .75725 .54754 .75258 .54189 Mtetra
.75258 .54189 .75725 .54754 .76773 .54449 .76309 .53882 Mtetra
.76309 .53882 .76773 .54449 .77825 .54142 .77364 .53573 Mtetra
.77364 .53573 .77825 .54142 .78881 .53834 .78422 .53263 Mtetra
.78422 .53263 .78881 .53834 .79941 .53526 .79485 .52952 Mtetra
.79485 .52952 .79941 .53526 .81005 .53216 .80551 .5264 Mtetra
.80551 .5264 .81005 .53216 .82072 .52905 .81622 .52327 Mtetra
.81622 .52327 .82072 .52905 .83144 .52592 .82696 .52013 Mtetra
.82696 .52013 .83144 .52592 .84219 .52279 .83775 .51697 Mtetra
.83775 .51697 .84219 .52279 .85299 .51964 .84857 .51381 Mtetra
.84857 .51381 .85299 .51964 .86383 .51649 .85944 .51063 Mtetra
.85944 .51063 .86383 .51649 .8747 .51332 .87034 .50744 Mtetra
.87034 .50744 .8747 .51332 .88562 .51014 .88129 .50423 Mtetra
.88129 .50423 .88562 .51014 .89658 .50694 .89227 .50102 Mtetra
.89227 .50102 .89658 .50694 .90758 .50374 .9033 .49779 Mtetra
.9033 .49779 .90758 .50374 .91862 .50052 .91437 .49455 Mtetra
.91437 .49455 .91862 .50052 .9297 .49729 .92549 .4913 Mtetra
.92549 .4913 .9297 .49729 .94082 .49405 .93664 .48804 Mtetra
.93664 .48804 .94082 .49405 .95198 .4908 .94784 .48476 Mtetra
.34689 .65403 .35253 .65894 .36162 .65628 .356 .65135 Mtetra
.356 .65135 .36162 .65628 .37074 .65361 .36515 .64866 Mtetra
.36515 .64866 .37074 .65361 .3799 .65094 .37432 .64597 Mtetra
.37432 .64597 .3799 .65094 .38908 .64825 .38352 .64326 Mtetra
.38352 .64326 .38908 .64825 .3983 .64555 .39276 .64055 Mtetra
.39276 .64055 .3983 .64555 .40755 .64285 .40203 .63783 Mtetra
.40203 .63783 .40755 .64285 .41683 .64013 .41133 .63509 Mtetra
.41133 .63509 .41683 .64013 .42614 .63741 .42066 .63235 Mtetra
.42066 .63235 .42614 .63741 .43548 .63467 .43003 .6296 Mtetra
.43003 .6296 .43548 .63467 .44486 .63193 .43942 .62684 Mtetra
.43942 .62684 .44486 .63193 .45427 .62918 .44885 .62407 Mtetra
.44885 .62407 .45427 .62918 .46371 .62641 .45832 .62129 Mtetra
.45832 .62129 .46371 .62641 .47319 .62364 .46781 .6185 Mtetra
.46781 .6185 .47319 .62364 .48269 .62086 .47734 .6157 Mtetra
.47734 .6157 .48269 .62086 .49224 .61807 .4869 .61289 Mtetra
.4869 .61289 .49224 .61807 .50181 .61527 .4965 .61007 Mtetra
.4965 .61007 .50181 .61527 .51142 .61245 .50613 .60724 Mtetra
.50613 .60724 .51142 .61245 .52106 .60963 .5158 .6044 Mtetra
.5158 .6044 .52106 .60963 .53074 .6068 .52549 .60155 Mtetra
.52549 .60155 .53074 .6068 .54045 .60396 .53523 .59869 Mtetra
.53523 .59869 .54045 .60396 .55019 .60111 .54499 .59582 Mtetra
.54499 .59582 .55019 .60111 .55997 .59825 .5548 .59294 Mtetra
.5548 .59294 .55997 .59825 .56978 .59538 .56463 .59005 Mtetra
.56463 .59005 .56978 .59538 .57963 .59249 .5745 .58715 Mtetra
.5745 .58715 .57963 .59249 .58952 .5896 .58441 .58424 Mtetra
.58441 .58424 .58952 .5896 .59944 .5867 .59435 .58132 Mtetra
.59435 .58132 .59944 .5867 .60939 .58379 .60433 .57838 Mtetra
.60433 .57838 .60939 .58379 .61938 .58087 .61435 .57544 Mtetra
.61435 .57544 .61938 .58087 .62941 .57793 .6244 .57249 Mtetra
.6244 .57249 .62941 .57793 .63947 .57499 .63448 .56952 Mtetra
.63448 .56952 .63947 .57499 .64957 .57203 .6446 .56655 Mtetra
.6446 .56655 .64957 .57203 .6597 .56907 .65476 .56357 Mtetra
.65476 .56357 .6597 .56907 .66987 .56609 .66496 .56057 Mtetra
.66496 .56057 .66987 .56609 .68008 .56311 .67519 .55756 Mtetra
.67519 .55756 .68008 .56311 .69032 .56011 .68546 .55455 Mtetra
.68546 .55455 .69032 .56011 .7006 .5571 .69577 .55152 Mtetra
.69577 .55152 .7006 .5571 .71092 .55408 .70612 .54848 Mtetra
.70612 .54848 .71092 .55408 .72128 .55105 .7165 .54543 Mtetra
.7165 .54543 .72128 .55105 .73168 .54801 .72692 .54236 Mtetra
.72692 .54236 .73168 .54801 .74211 .54496 .73738 .53929 Mtetra
.73738 .53929 .74211 .54496 .75258 .54189 .74788 .53621 Mtetra
.74788 .53621 .75258 .54189 .76309 .53882 .75841 .53311 Mtetra
.75841 .53311 .76309 .53882 .77364 .53573 .76899 .53 Mtetra
.76899 .53 .77364 .53573 .78422 .53263 .7796 .52688 Mtetra
.7796 .52688 .78422 .53263 .79485 .52952 .79026 .52375 Mtetra
.79026 .52375 .79485 .52952 .80551 .5264 .80095 .52061 Mtetra
.80095 .52061 .80551 .5264 .81622 .52327 .81168 .51746 Mtetra
.81168 .51746 .81622 .52327 .82696 .52013 .82245 .51429 Mtetra
.82245 .51429 .82696 .52013 .83775 .51697 .83327 .51112 Mtetra
.83327 .51112 .83775 .51697 .84857 .51381 .84412 .50793 Mtetra
.84412 .50793 .84857 .51381 .85944 .51063 .85501 .50473 Mtetra
.85501 .50473 .85944 .51063 .87034 .50744 .86595 .50151 Mtetra
.86595 .50151 .87034 .50744 .88129 .50423 .87693 .49829 Mtetra
.87693 .49829 .88129 .50423 .89227 .50102 .88794 .49505 Mtetra
.88794 .49505 .89227 .50102 .9033 .49779 .899 .4918 Mtetra
.899 .4918 .9033 .49779 .91437 .49455 .9101 .48854 Mtetra
.9101 .48854 .91437 .49455 .92549 .4913 .92125 .48527 Mtetra
.92125 .48527 .92549 .4913 .93664 .48804 .93243 .48198 Mtetra
.93243 .48198 .93664 .48804 .94784 .48476 .94366 .47868 Mtetra
.34122 .64908 .34689 .65403 .356 .65135 .35035 .64638 Mtetra
.35035 .64638 .356 .65135 .36515 .64866 .35951 .64368 Mtetra
.35951 .64368 .36515 .64866 .37432 .64597 .36871 .64097 Mtetra
.36871 .64097 .37432 .64597 .38352 .64326 .37793 .63825 Mtetra
.37793 .63825 .38352 .64326 .39276 .64055 .38719 .63551 Mtetra
.38719 .63551 .39276 .64055 .40203 .63783 .39647 .63277 Mtetra
.39647 .63277 .40203 .63783 .41133 .63509 .40579 .63002 Mtetra
.40579 .63002 .41133 .63509 .42066 .63235 .41515 .62726 Mtetra
.41515 .62726 .42066 .63235 .43003 .6296 .42453 .62449 Mtetra
.42453 .62449 .43003 .6296 .43942 .62684 .43395 .62172 Mtetra
.43395 .62172 .43942 .62684 .44885 .62407 .4434 .61893 Mtetra
.4434 .61893 .44885 .62407 .45832 .62129 .45289 .61613 Mtetra
.45289 .61613 .45832 .62129 .46781 .6185 .4624 .61332 Mtetra
.4624 .61332 .46781 .6185 .47734 .6157 .47195 .6105 Mtetra
.47195 .6105 .47734 .6157 .4869 .61289 .48154 .60767 Mtetra
.48154 .60767 .4869 .61289 .4965 .61007 .49116 .60484 Mtetra
.49116 .60484 .4965 .61007 .50613 .60724 .50081 .60199 Mtetra
.50081 .60199 .50613 .60724 .5158 .6044 .5105 .59913 Mtetra
.5105 .59913 .5158 .6044 .52549 .60155 .52022 .59626 Mtetra
.52022 .59626 .52549 .60155 .53523 .59869 .52997 .59338 Mtetra
.52997 .59338 .53523 .59869 .54499 .59582 .53976 .59049 Mtetra
.53976 .59049 .54499 .59582 .5548 .59294 .54959 .58759 Mtetra
.54959 .58759 .5548 .59294 .56463 .59005 .55945 .58469 Mtetra
.55945 .58469 .56463 .59005 .5745 .58715 .56934 .58177 Mtetra
.56934 .58177 .5745 .58715 .58441 .58424 .57927 .57884 Mtetra
.57927 .57884 .58441 .58424 .59435 .58132 .58924 .57589 Mtetra
.58924 .57589 .59435 .58132 .60433 .57838 .59924 .57294 Mtetra
.59924 .57294 .60433 .57838 .61435 .57544 .60928 .56998 Mtetra
.60928 .56998 .61435 .57544 .6244 .57249 .61935 .56701 Mtetra
.61935 .56701 .6244 .57249 .63448 .56952 .62946 .56403 Mtetra
.62946 .56403 .63448 .56952 .6446 .56655 .63961 .56103 Mtetra
.63961 .56103 .6446 .56655 .65476 .56357 .64979 .55803 Mtetra
.64979 .55803 .65476 .56357 .66496 .56057 .66002 .55501 Mtetra
.66002 .55501 .66496 .56057 .67519 .55756 .67027 .55198 Mtetra
.67027 .55198 .67519 .55756 .68546 .55455 .68057 .54895 Mtetra
.68057 .54895 .68546 .55455 .69577 .55152 .6909 .5459 Mtetra
.6909 .5459 .69577 .55152 .70612 .54848 .70127 .54284 Mtetra
.70127 .54284 .70612 .54848 .7165 .54543 .71168 .53976 Mtetra
.71168 .53976 .7165 .54543 .72692 .54236 .72213 .53668 Mtetra
.72213 .53668 .72692 .54236 .73738 .53929 .73262 .53359 Mtetra
.73262 .53359 .73738 .53929 .74788 .53621 .74314 .53048 Mtetra
.74314 .53048 .74788 .53621 .75841 .53311 .75371 .52737 Mtetra
.75371 .52737 .75841 .53311 .76899 .53 .76431 .52424 Mtetra
.76431 .52424 .76899 .53 .7796 .52688 .77495 .5211 Mtetra
.77495 .5211 .7796 .52688 .79026 .52375 .78563 .51794 Mtetra
.78563 .51794 .79026 .52375 .80095 .52061 .79635 .51478 Mtetra
.79635 .51478 .80095 .52061 .81168 .51746 .80711 .51161 Mtetra
.80711 .51161 .81168 .51746 .82245 .51429 .81792 .50842 Mtetra
.81792 .50842 .82245 .51429 .83327 .51112 .82876 .50522 Mtetra
.82876 .50522 .83327 .51112 .84412 .50793 .83964 .50201 Mtetra
.83964 .50201 .84412 .50793 .85501 .50473 .85056 .49879 Mtetra
.85056 .49879 .85501 .50473 .86595 .50151 .86153 .49555 Mtetra
.86153 .49555 .86595 .50151 .87693 .49829 .87253 .4923 Mtetra
.87253 .4923 .87693 .49829 .88794 .49505 .88358 .48904 Mtetra
.88358 .48904 .88794 .49505 .899 .4918 .89467 .48577 Mtetra
.89467 .48577 .899 .4918 .9101 .48854 .9058 .48249 Mtetra
.9058 .48249 .9101 .48854 .92125 .48527 .91698 .47919 Mtetra
.91698 .47919 .92125 .48527 .93243 .48198 .92819 .47588 Mtetra
.92819 .47588 .93243 .48198 .94366 .47868 .93945 .47256 Mtetra
.33552 .6441 .34122 .64908 .35035 .64638 .34467 .64139 Mtetra
.34467 .64139 .35035 .64638 .35951 .64368 .35385 .63866 Mtetra
.35385 .63866 .35951 .64368 .36871 .64097 .36306 .63594 Mtetra
.36306 .63594 .36871 .64097 .37793 .63825 .3723 .6332 Mtetra
.3723 .6332 .37793 .63825 .38719 .63551 .38158 .63045 Mtetra
.38158 .63045 .38719 .63551 .39647 .63277 .39089 .62769 Mtetra
.39089 .62769 .39647 .63277 .40579 .63002 .40023 .62492 Mtetra
.40023 .62492 .40579 .63002 .41515 .62726 .4096 .62214 Mtetra
.4096 .62214 .41515 .62726 .42453 .62449 .41901 .61936 Mtetra
.41901 .61936 .42453 .62449 .43395 .62172 .42844 .61656 Mtetra
.42844 .61656 .43395 .62172 .4434 .61893 .43792 .61375 Mtetra
.43792 .61375 .4434 .61893 .45289 .61613 .44742 .61094 Mtetra
.44742 .61094 .45289 .61613 .4624 .61332 .45696 .60811 Mtetra
.45696 .60811 .4624 .61332 .47195 .6105 .46653 .60527 Mtetra
.46653 .60527 .47195 .6105 .48154 .60767 .47614 .60243 Mtetra
.47614 .60243 .48154 .60767 .49116 .60484 .48578 .59957 Mtetra
.48578 .59957 .49116 .60484 .50081 .60199 .49545 .5967 Mtetra
.49545 .5967 .50081 .60199 .5105 .59913 .50516 .59383 Mtetra
.50516 .59383 .5105 .59913 .52022 .59626 .5149 .59094 Mtetra
.5149 .59094 .52022 .59626 .52997 .59338 .52468 .58804 Mtetra
.52468 .58804 .52997 .59338 .53976 .59049 .5345 .58513 Mtetra
.5345 .58513 .53976 .59049 .54959 .58759 .54434 .58222 Mtetra
.54434 .58222 .54959 .58759 .55945 .58469 .55423 .57929 Mtetra
.55423 .57929 .55945 .58469 .56934 .58177 .56414 .57635 Mtetra
.56414 .57635 .56934 .58177 .57927 .57884 .5741 .5734 Mtetra
.5741 .5734 .57927 .57884 .58924 .57589 .58409 .57044 Mtetra
.58409 .57044 .58924 .57589 .59924 .57294 .59412 .56747 Mtetra
.59412 .56747 .59924 .57294 .60928 .56998 .60418 .56449 Mtetra
.60418 .56449 .60928 .56998 .61935 .56701 .61428 .56149 Mtetra
.61428 .56149 .61935 .56701 .62946 .56403 .62441 .55849 Mtetra
.62441 .55849 .62946 .56403 .63961 .56103 .63458 .55547 Mtetra
.63458 .55547 .63961 .56103 .64979 .55803 .64479 .55245 Mtetra
.64479 .55245 .64979 .55803 .66002 .55501 .65504 .54941 Mtetra
.65504 .54941 .66002 .55501 .67027 .55198 .66532 .54637 Mtetra
.66532 .54637 .67027 .55198 .68057 .54895 .67564 .54331 Mtetra
.67564 .54331 .68057 .54895 .6909 .5459 .686 .54024 Mtetra
.686 .54024 .6909 .5459 .70127 .54284 .6964 .53716 Mtetra
.6964 .53716 .70127 .54284 .71168 .53976 .70684 .53406 Mtetra
.70684 .53406 .71168 .53976 .72213 .53668 .71731 .53096 Mtetra
.71731 .53096 .72213 .53668 .73262 .53359 .72782 .52785 Mtetra
.72782 .52785 .73262 .53359 .74314 .53048 .73838 .52472 Mtetra
.73838 .52472 .74314 .53048 .75371 .52737 .74897 .52158 Mtetra
.74897 .52158 .75371 .52737 .76431 .52424 .7596 .51843 Mtetra
.7596 .51843 .76431 .52424 .77495 .5211 .77027 .51527 Mtetra
.77027 .51527 .77495 .5211 .78563 .51794 .78098 .5121 Mtetra
.78098 .5121 .78563 .51794 .79635 .51478 .79173 .50891 Mtetra
.79173 .50891 .79635 .51478 .80711 .51161 .80251 .50571 Mtetra
.80251 .50571 .80711 .51161 .81792 .50842 .81335 .5025 Mtetra
.81335 .5025 .81792 .50842 .82876 .50522 .82422 .49928 Mtetra
.82422 .49928 .82876 .50522 .83964 .50201 .83513 .49605 Mtetra
.83513 .49605 .83964 .50201 .85056 .49879 .84608 .4928 Mtetra
.84608 .4928 .85056 .49879 .86153 .49555 .85707 .48955 Mtetra
.85707 .48955 .86153 .49555 .87253 .4923 .86811 .48627 Mtetra
.86811 .48627 .87253 .4923 .88358 .48904 .87919 .48299 Mtetra
.87919 .48299 .88358 .48904 .89467 .48577 .89031 .4797 Mtetra
.89031 .4797 .89467 .48577 .9058 .48249 .90147 .47639 Mtetra
.90147 .47639 .9058 .48249 .91698 .47919 .91268 .47307 Mtetra
.91268 .47307 .91698 .47919 .92819 .47588 .92392 .46974 Mtetra
.92392 .46974 .92819 .47588 .93945 .47256 .93521 .46639 Mtetra
.32977 .63908 .33552 .6441 .34467 .64139 .33894 .63636 Mtetra
.33894 .63636 .34467 .64139 .35385 .63866 .34814 .63362 Mtetra
.34814 .63362 .35385 .63866 .36306 .63594 .35737 .63087 Mtetra
.35737 .63087 .36306 .63594 .3723 .6332 .36664 .62811 Mtetra
.36664 .62811 .3723 .6332 .38158 .63045 .37593 .62535 Mtetra
.37593 .62535 .38158 .63045 .39089 .62769 .38526 .62257 Mtetra
.38526 .62257 .39089 .62769 .40023 .62492 .39462 .61979 Mtetra
.39462 .61979 .40023 .62492 .4096 .62214 .40402 .61699 Mtetra
.40402 .61699 .4096 .62214 .41901 .61936 .41344 .61418 Mtetra
.41344 .61418 .41901 .61936 .42844 .61656 .4229 .61137 Mtetra
.4229 .61137 .42844 .61656 .43792 .61375 .43239 .60854 Mtetra
.43239 .60854 .43792 .61375 .44742 .61094 .44192 .60571 Mtetra
.44192 .60571 .44742 .61094 .45696 .60811 .45148 .60286 Mtetra
.45148 .60286 .45696 .60811 .46653 .60527 .46108 .60001 Mtetra
.46108 .60001 .46653 .60527 .47614 .60243 .4707 .59714 Mtetra
.4707 .59714 .47614 .60243 .48578 .59957 .48037 .59427 Mtetra
.48037 .59427 .48578 .59957 .49545 .5967 .49006 .59138 Mtetra
.49006 .59138 .49545 .5967 .50516 .59383 .49979 .58849 Mtetra
.49979 .58849 .50516 .59383 .5149 .59094 .50956 .58558 Mtetra
.50956 .58558 .5149 .59094 .52468 .58804 .51936 .58267 Mtetra
.51936 .58267 .52468 .58804 .5345 .58513 .52919 .57974 Mtetra
.52919 .57974 .5345 .58513 .54434 .58222 .53907 .5768 Mtetra
.53907 .5768 .54434 .58222 .55423 .57929 .54897 .57385 Mtetra
.54897 .57385 .55423 .57929 .56414 .57635 .55891 .57089 Mtetra
.55891 .57089 .56414 .57635 .5741 .5734 .56889 .56792 Mtetra
.56889 .56792 .5741 .5734 .58409 .57044 .57891 .56494 Mtetra
.57891 .56494 .58409 .57044 .59412 .56747 .58896 .56195 Mtetra
.58896 .56195 .59412 .56747 .60418 .56449 .59904 .55895 Mtetra
.59904 .55895 .60418 .56449 .61428 .56149 .60917 .55594 Mtetra
.60917 .55594 .61428 .56149 .62441 .55849 .61933 .55292 Mtetra
.61933 .55292 .62441 .55849 .63458 .55547 .62952 .54988 Mtetra
.62952 .54988 .63458 .55547 .64479 .55245 .63976 .54684 Mtetra
.63976 .54684 .64479 .55245 .65504 .54941 .65003 .54378 Mtetra
.65003 .54378 .65504 .54941 .66532 .54637 .66034 .54071 Mtetra
.66034 .54071 .66532 .54637 .67564 .54331 .67069 .53763 Mtetra
.67069 .53763 .67564 .54331 .686 .54024 .68107 .53454 Mtetra
.68107 .53454 .686 .54024 .6964 .53716 .69149 .53144 Mtetra
.69149 .53144 .6964 .53716 .70684 .53406 .70196 .52833 Mtetra
.70196 .52833 .70684 .53406 .71731 .53096 .71246 .5252 Mtetra
.71246 .5252 .71731 .53096 .72782 .52785 .723 .52206 Mtetra
.723 .52206 .72782 .52785 .73838 .52472 .73358 .51892 Mtetra
.73358 .51892 .73838 .52472 .74897 .52158 .74419 .51576 Mtetra
.74419 .51576 .74897 .52158 .7596 .51843 .75485 .51258 Mtetra
.75485 .51258 .7596 .51843 .77027 .51527 .76555 .5094 Mtetra
.76555 .5094 .77027 .51527 .78098 .5121 .77629 .50621 Mtetra
.77629 .50621 .78098 .5121 .79173 .50891 .78707 .503 Mtetra
.78707 .503 .79173 .50891 .80251 .50571 .79788 .49978 Mtetra
.79788 .49978 .80251 .50571 .81335 .5025 .80874 .49655 Mtetra
.80874 .49655 .81335 .5025 .82422 .49928 .81964 .4933 Mtetra
.81964 .4933 .82422 .49928 .83513 .49605 .83058 .49005 Mtetra
.83058 .49005 .83513 .49605 .84608 .4928 .84157 .48678 Mtetra
.84157 .48678 .84608 .4928 .85707 .48955 .85259 .4835 Mtetra
.85259 .4835 .85707 .48955 .86811 .48627 .86366 .4802 Mtetra
.86366 .4802 .86811 .48627 .87919 .48299 .87477 .4769 Mtetra
.87477 .4769 .87919 .48299 .89031 .4797 .88592 .47358 Mtetra
.88592 .47358 .89031 .4797 .90147 .47639 .89711 .47025 Mtetra
.89711 .47025 .90147 .47639 .91268 .47307 .90834 .46691 Mtetra
.90834 .46691 .91268 .47307 .92392 .46974 .91962 .46355 Mtetra
.91962 .46355 .92392 .46974 .93521 .46639 .93095 .46018 Mtetra
.32399 .63404 .32977 .63908 .33894 .63636 .33318 .63129 Mtetra
.33318 .63129 .33894 .63636 .34814 .63362 .3424 .62854 Mtetra
.3424 .62854 .34814 .63362 .35737 .63087 .35165 .62577 Mtetra
.35165 .62577 .35737 .63087 .36664 .62811 .36094 .623 Mtetra
.36094 .623 .36664 .62811 .37593 .62535 .37025 .62021 Mtetra
.37025 .62021 .37593 .62535 .38526 .62257 .3796 .61742 Mtetra
.3796 .61742 .38526 .62257 .39462 .61979 .38898 .61462 Mtetra
.38898 .61462 .39462 .61979 .40402 .61699 .3984 .6118 Mtetra
.3984 .6118 .40402 .61699 .41344 .61418 .40784 .60898 Mtetra
.40784 .60898 .41344 .61418 .4229 .61137 .41732 .60615 Mtetra
.41732 .60615 .4229 .61137 .43239 .60854 .42684 .6033 Mtetra
.42684 .6033 .43239 .60854 .44192 .60571 .43639 .60045 Mtetra
.43639 .60045 .44192 .60571 .45148 .60286 .44597 .59759 Mtetra
.44597 .59759 .45148 .60286 .46108 .60001 .45558 .59471 Mtetra
.45558 .59471 .46108 .60001 .4707 .59714 .46523 .59183 Mtetra
.46523 .59183 .4707 .59714 .48037 .59427 .47492 .58893 Mtetra
.47492 .58893 .48037 .59427 .49006 .59138 .48463 .58603 Mtetra
.48463 .58603 .49006 .59138 .49979 .58849 .49439 .58311 Mtetra
.49439 .58311 .49979 .58849 .50956 .58558 .50418 .58019 Mtetra
.50418 .58019 .50956 .58558 .51936 .58267 .514 .57725 Mtetra
.514 .57725 .51936 .58267 .52919 .57974 .52386 .57431 Mtetra
.52386 .57431 .52919 .57974 .53907 .5768 .53375 .57135 Mtetra
.53375 .57135 .53907 .5768 .54897 .57385 .54368 .56838 Mtetra
.54368 .56838 .54897 .57385 .55891 .57089 .55365 .5654 Mtetra
.55365 .5654 .55891 .57089 .56889 .56792 .56365 .56241 Mtetra
.56365 .56241 .56889 .56792 .57891 .56494 .57369 .55941 Mtetra
.57369 .55941 .57891 .56494 .58896 .56195 .58376 .5564 Mtetra
.58376 .5564 .58896 .56195 .59904 .55895 .59387 .55338 Mtetra
.59387 .55338 .59904 .55895 .60917 .55594 .60402 .55035 Mtetra
.60402 .55035 .60917 .55594 .61933 .55292 .61421 .5473 Mtetra
.61421 .5473 .61933 .55292 .62952 .54988 .62443 .54425 Mtetra
.62443 .54425 .62952 .54988 .63976 .54684 .63469 .54118 Mtetra
.63469 .54118 .63976 .54684 .65003 .54378 .64498 .53811 Mtetra
.64498 .53811 .65003 .54378 .66034 .54071 .65532 .53502 Mtetra
.65532 .53502 .66034 .54071 .67069 .53763 .66569 .53192 Mtetra
.66569 .53192 .67069 .53763 .68107 .53454 .6761 .52881 Mtetra
.6761 .52881 .68107 .53454 .69149 .53144 .68655 .52568 Mtetra
.68655 .52568 .69149 .53144 .70196 .52833 .69704 .52255 Mtetra
.69704 .52255 .70196 .52833 .71246 .5252 .70757 .5194 Mtetra
.70757 .5194 .71246 .5252 .723 .52206 .71814 .51624 Mtetra
.71814 .51624 .723 .52206 .73358 .51892 .72874 .51307 Mtetra
.72874 .51307 .73358 .51892 .74419 .51576 .73939 .50989 Mtetra
.73939 .50989 .74419 .51576 .75485 .51258 .75008 .5067 Mtetra
.75008 .5067 .75485 .51258 .76555 .5094 .7608 .50349 Mtetra
.7608 .50349 .76555 .5094 .77629 .50621 .77157 .50027 Mtetra
.77157 .50027 .77629 .50621 .78707 .503 .78237 .49704 Mtetra
.78237 .49704 .78707 .503 .79788 .49978 .79322 .4938 Mtetra
.79322 .4938 .79788 .49978 .80874 .49655 .80411 .49055 Mtetra
.80411 .49055 .80874 .49655 .81964 .4933 .81504 .48728 Mtetra
.81504 .48728 .81964 .4933 .83058 .49005 .82601 .484 Mtetra
.82601 .484 .83058 .49005 .84157 .48678 .83702 .48071 Mtetra
.83702 .48071 .84157 .48678 .85259 .4835 .84808 .47741 Mtetra
.84808 .47741 .85259 .4835 .86366 .4802 .85917 .47409 Mtetra
.85917 .47409 .86366 .4802 .87477 .4769 .87031 .47076 Mtetra
.87031 .47076 .87477 .4769 .88592 .47358 .88149 .46742 Mtetra
.88149 .46742 .88592 .47358 .89711 .47025 .89272 .46407 Mtetra
.89272 .46407 .89711 .47025 .90834 .46691 .90398 .4607 Mtetra
.90398 .4607 .90834 .46691 .91962 .46355 .91529 .45732 Mtetra
.91529 .45732 .91962 .46355 .93095 .46018 .92665 .45393 Mtetra
.31818 .62896 .32399 .63404 .33318 .63129 .32738 .6262 Mtetra
.32738 .6262 .33318 .63129 .3424 .62854 .33662 .62343 Mtetra
.33662 .62343 .3424 .62854 .35165 .62577 .34589 .62064 Mtetra
.34589 .62064 .35165 .62577 .36094 .623 .3552 .61785 Mtetra
.3552 .61785 .36094 .623 .37025 .62021 .36453 .61505 Mtetra
.36453 .61505 .37025 .62021 .3796 .61742 .3739 .61224 Mtetra
.3739 .61224 .3796 .61742 .38898 .61462 .3833 .60942 Mtetra
.3833 .60942 .38898 .61462 .3984 .6118 .39274 .60658 Mtetra
.39274 .60658 .3984 .6118 .40784 .60898 .40221 .60374 Mtetra
.40221 .60374 .40784 .60898 .41732 .60615 .41171 .60089 Mtetra
.41171 .60089 .41732 .60615 .42684 .6033 .42124 .59803 Mtetra
.42124 .59803 .42684 .6033 .43639 .60045 .43081 .59516 Mtetra
.43081 .59516 .43639 .60045 .44597 .59759 .44042 .59227 Mtetra
.44042 .59227 .44597 .59759 .45558 .59471 .45005 .58938 Mtetra
.45005 .58938 .45558 .59471 .46523 .59183 .45972 .58648 Mtetra
.45972 .58648 .46523 .59183 .47492 .58893 .46943 .58356 Mtetra
.46943 .58356 .47492 .58893 .48463 .58603 .47917 .58064 Mtetra
.47917 .58064 .48463 .58603 .49439 .58311 .48895 .57771 Mtetra
.48895 .57771 .49439 .58311 .50418 .58019 .49876 .57476 Mtetra
.49876 .57476 .50418 .58019 .514 .57725 .5086 .57181 Mtetra
.5086 .57181 .514 .57725 .52386 .57431 .51849 .56884 Mtetra
.51849 .56884 .52386 .57431 .53375 .57135 .5284 .56586 Mtetra
.5284 .56586 .53375 .57135 .54368 .56838 .53836 .56288 Mtetra
.53836 .56288 .54368 .56838 .55365 .5654 .54835 .55988 Mtetra
.54835 .55988 .55365 .5654 .56365 .56241 .55837 .55687 Mtetra
.55837 .55687 .56365 .56241 .57369 .55941 .56843 .55385 Mtetra
.56843 .55385 .57369 .55941 .58376 .5564 .57853 .55082 Mtetra
.57853 .55082 .58376 .5564 .59387 .55338 .58867 .54777 Mtetra
.58867 .54777 .59387 .55338 .60402 .55035 .59884 .54472 Mtetra
.59884 .54472 .60402 .55035 .61421 .5473 .60905 .54166 Mtetra
.60905 .54166 .61421 .5473 .62443 .54425 .6193 .53858 Mtetra
.6193 .53858 .62443 .54425 .63469 .54118 .62958 .53549 Mtetra
.62958 .53549 .63469 .54118 .64498 .53811 .63991 .53239 Mtetra
.63991 .53239 .64498 .53811 .65532 .53502 .65027 .52928 Mtetra
.65027 .52928 .65532 .53502 .66569 .53192 .66067 .52616 Mtetra
.66067 .52616 .66569 .53192 .6761 .52881 .6711 .52303 Mtetra
.6711 .52303 .6761 .52881 .68655 .52568 .68158 .51989 Mtetra
.68158 .51989 .68655 .52568 .69704 .52255 .6921 .51673 Mtetra
.6921 .51673 .69704 .52255 .70757 .5194 .70265 .51356 Mtetra
.70265 .51356 .70757 .5194 .71814 .51624 .71324 .51038 Mtetra
.71324 .51038 .71814 .51624 .72874 .51307 .72388 .50719 Mtetra
.72388 .50719 .72874 .51307 .73939 .50989 .73455 .50399 Mtetra
.73455 .50399 .73939 .50989 .75008 .5067 .74527 .50077 Mtetra
.74527 .50077 .75008 .5067 .7608 .50349 .75602 .49754 Mtetra
.75602 .49754 .7608 .50349 .77157 .50027 .76681 .4943 Mtetra
.76681 .4943 .77157 .50027 .78237 .49704 .77765 .49105 Mtetra
.77765 .49105 .78237 .49704 .79322 .4938 .78852 .48779 Mtetra
.78852 .48779 .79322 .4938 .80411 .49055 .79944 .48451 Mtetra
.79944 .48451 .80411 .49055 .81504 .48728 .8104 .48122 Mtetra
.8104 .48122 .81504 .48728 .82601 .484 .8214 .47792 Mtetra
.8214 .47792 .82601 .484 .83702 .48071 .83244 .4746 Mtetra
.83244 .4746 .83702 .48071 .84808 .47741 .84353 .47128 Mtetra
.84353 .47128 .84808 .47741 .85917 .47409 .85465 .46794 Mtetra
.85465 .46794 .85917 .47409 .87031 .47076 .86582 .46458 Mtetra
.86582 .46458 .87031 .47076 .88149 .46742 .87704 .46122 Mtetra
.87704 .46122 .88149 .46742 .89272 .46407 .88829 .45784 Mtetra
.88829 .45784 .89272 .46407 .90398 .4607 .89959 .45445 Mtetra
.89959 .45445 .90398 .4607 .91529 .45732 .91093 .45104 Mtetra
.91093 .45104 .91529 .45732 .92665 .45393 .92232 .44763 Mtetra
.31232 .62385 .31818 .62896 .32738 .6262 .32155 .62107 Mtetra
.32155 .62107 .32738 .6262 .33662 .62343 .33081 .61828 Mtetra
.33081 .61828 .33662 .62343 .34589 .62064 .3401 .61548 Mtetra
.3401 .61548 .34589 .62064 .3552 .61785 .34942 .61267 Mtetra
.34942 .61267 .3552 .61785 .36453 .61505 .35878 .60985 Mtetra
.35878 .60985 .36453 .61505 .3739 .61224 .36817 .60702 Mtetra
.36817 .60702 .3739 .61224 .3833 .60942 .37759 .60418 Mtetra
.37759 .60418 .3833 .60942 .39274 .60658 .38704 .60133 Mtetra
.38704 .60133 .39274 .60658 .40221 .60374 .39653 .59847 Mtetra
.39653 .59847 .40221 .60374 .41171 .60089 .40606 .5956 Mtetra
.40606 .5956 .41171 .60089 .42124 .59803 .41561 .59272 Mtetra
.41561 .59272 .42124 .59803 .43081 .59516 .4252 .58983 Mtetra
.4252 .58983 .43081 .59516 .44042 .59227 .43483 .58692 Mtetra
.43483 .58692 .44042 .59227 .45005 .58938 .44449 .58401 Mtetra
.44449 .58401 .45005 .58938 .45972 .58648 .45418 .58109 Mtetra
.45418 .58109 .45972 .58648 .46943 .58356 .46391 .57816 Mtetra
.46391 .57816 .46943 .58356 .47917 .58064 .47367 .57521 Mtetra
.47367 .57521 .47917 .58064 .48895 .57771 .48347 .57226 Mtetra
.48347 .57226 .48895 .57771 .49876 .57476 .4933 .5693 Mtetra
.4933 .5693 .49876 .57476 .5086 .57181 .50317 .56632 Mtetra
.50317 .56632 .5086 .57181 .51849 .56884 .51308 .56334 Mtetra
.51308 .56334 .51849 .56884 .5284 .56586 .52302 .56034 Mtetra
.52302 .56034 .5284 .56586 .53836 .56288 .533 .55733 Mtetra
.533 .55733 .53836 .56288 .54835 .55988 .54301 .55431 Mtetra
.54301 .55431 .54835 .55988 .55837 .55687 .55306 .55128 Mtetra
.55306 .55128 .55837 .55687 .56843 .55385 .56314 .54824 Mtetra
.56314 .54824 .56843 .55385 .57853 .55082 .57327 .54519 Mtetra
.57327 .54519 .57853 .55082 .58867 .54777 .58343 .54213 Mtetra
.58343 .54213 .58867 .54777 .59884 .54472 .59363 .53905 Mtetra
.59363 .53905 .59884 .54472 .60905 .54166 .60386 .53597 Mtetra
.60386 .53597 .60905 .54166 .6193 .53858 .61413 .53287 Mtetra
.61413 .53287 .6193 .53858 .62958 .53549 .62444 .52976 Mtetra
.62444 .52976 .62958 .53549 .63991 .53239 .63479 .52664 Mtetra
.63479 .52664 .63991 .53239 .65027 .52928 .64518 .52351 Mtetra
.64518 .52351 .65027 .52928 .66067 .52616 .6556 .52037 Mtetra
.6556 .52037 .66067 .52616 .6711 .52303 .66607 .51722 Mtetra
.66607 .51722 .6711 .52303 .68158 .51989 .67657 .51405 Mtetra
.67657 .51405 .68158 .51989 .6921 .51673 .68711 .51087 Mtetra
.68711 .51087 .6921 .51673 .70265 .51356 .6977 .50768 Mtetra
.6977 .50768 .70265 .51356 .71324 .51038 .70832 .50448 Mtetra
.70832 .50448 .71324 .51038 .72388 .50719 .71898 .50127 Mtetra
.71898 .50127 .72388 .50719 .73455 .50399 .72968 .49804 Mtetra
.72968 .49804 .73455 .50399 .74527 .50077 .74042 .4948 Mtetra
.74042 .4948 .74527 .50077 .75602 .49754 .7512 .49155 Mtetra
.7512 .49155 .75602 .49754 .76681 .4943 .76203 .48829 Mtetra
.76203 .48829 .76681 .4943 .77765 .49105 .77289 .48501 Mtetra
.77289 .48501 .77765 .49105 .78852 .48779 .7838 .48173 Mtetra
.7838 .48173 .78852 .48779 .79944 .48451 .79474 .47843 Mtetra
.79474 .47843 .79944 .48451 .8104 .48122 .80573 .47511 Mtetra
.80573 .47511 .8104 .48122 .8214 .47792 .81676 .47179 Mtetra
.81676 .47179 .8214 .47792 .83244 .4746 .82783 .46845 Mtetra
.82783 .46845 .83244 .4746 .84353 .47128 .83895 .4651 Mtetra
.83895 .4651 .84353 .47128 .85465 .46794 .85011 .46174 Mtetra
.85011 .46174 .85465 .46794 .86582 .46458 .86131 .45836 Mtetra
.86131 .45836 .86582 .46458 .87704 .46122 .87255 .45497 Mtetra
.87255 .45497 .87704 .46122 .88829 .45784 .88384 .45157 Mtetra
.88384 .45157 .88829 .45784 .89959 .45445 .89517 .44815 Mtetra
.89517 .44815 .89959 .45445 .91093 .45104 .90654 .44472 Mtetra
.90654 .44472 .91093 .45104 .92232 .44763 .91796 .44128 Mtetra
.30643 .61871 .31232 .62385 .32155 .62107 .31568 .61591 Mtetra
.31568 .61591 .32155 .62107 .33081 .61828 .32495 .6131 Mtetra
.32495 .6131 .33081 .61828 .3401 .61548 .33427 .61028 Mtetra
.33427 .61028 .3401 .61548 .34942 .61267 .34361 .60746 Mtetra
.34361 .60746 .34942 .61267 .35878 .60985 .35299 .60462 Mtetra
.35299 .60462 .35878 .60985 .36817 .60702 .36239 .60177 Mtetra
.36239 .60177 .36817 .60702 .37759 .60418 .37184 .59891 Mtetra
.37184 .59891 .37759 .60418 .38704 .60133 .38131 .59604 Mtetra
.38131 .59604 .38704 .60133 .39653 .59847 .39082 .59316 Mtetra
.39082 .59316 .39653 .59847 .40606 .5956 .40037 .59027 Mtetra
.40037 .59027 .40606 .5956 .41561 .59272 .40995 .58737 Mtetra
.40995 .58737 .41561 .59272 .4252 .58983 .41956 .58446 Mtetra
.41956 .58446 .4252 .58983 .43483 .58692 .4292 .58154 Mtetra
.4292 .58154 .43483 .58692 .44449 .58401 .43888 .57861 Mtetra
.43888 .57861 .44449 .58401 .45418 .58109 .4486 .57567 Mtetra
.4486 .57567 .45418 .58109 .46391 .57816 .45835 .57272 Mtetra
.45835 .57272 .46391 .57816 .47367 .57521 .46814 .56975 Mtetra
.46814 .56975 .47367 .57521 .48347 .57226 .47796 .56678 Mtetra
.47796 .56678 .48347 .57226 .4933 .5693 .48781 .5638 Mtetra
.48781 .5638 .4933 .5693 .50317 .56632 .49771 .5608 Mtetra
.49771 .5608 .50317 .56632 .51308 .56334 .50763 .55779 Mtetra
.50763 .55779 .51308 .56334 .52302 .56034 .5176 .55478 Mtetra
.5176 .55478 .52302 .56034 .533 .55733 .5276 .55175 Mtetra
.5276 .55175 .533 .55733 .54301 .55431 .53764 .54871 Mtetra
.53764 .54871 .54301 .55431 .55306 .55128 .54771 .54566 Mtetra
.54771 .54566 .55306 .55128 .56314 .54824 .55782 .5426 Mtetra
.55782 .5426 .56314 .54824 .57327 .54519 .56797 .53953 Mtetra
.56797 .53953 .57327 .54519 .58343 .54213 .57815 .53644 Mtetra
.57815 .53644 .58343 .54213 .59363 .53905 .58837 .53335 Mtetra
.58837 .53335 .59363 .53905 .60386 .53597 .59864 .53024 Mtetra
.59864 .53024 .60386 .53597 .61413 .53287 .60893 .52712 Mtetra
.60893 .52712 .61413 .53287 .62444 .52976 .61927 .524 Mtetra
.61927 .524 .62444 .52976 .63479 .52664 .62964 .52085 Mtetra
.62964 .52085 .63479 .52664 .64518 .52351 .64006 .5177 Mtetra
.64006 .5177 .64518 .52351 .6556 .52037 .65051 .51454 Mtetra
.65051 .51454 .6556 .52037 .66607 .51722 .661 .51136 Mtetra
.661 .51136 .66607 .51722 .67657 .51405 .67153 .50817 Mtetra
.67153 .50817 .67657 .51405 .68711 .51087 .6821 .50497 Mtetra
.6821 .50497 .68711 .51087 .6977 .50768 .69271 .50176 Mtetra
.69271 .50176 .6977 .50768 .70832 .50448 .70336 .49854 Mtetra
.70336 .49854 .70832 .50448 .71898 .50127 .71405 .4953 Mtetra
.71405 .4953 .71898 .50127 .72968 .49804 .72477 .49205 Mtetra
.72477 .49205 .72968 .49804 .74042 .4948 .73554 .48879 Mtetra
.73554 .48879 .74042 .4948 .7512 .49155 .74636 .48552 Mtetra
.74636 .48552 .7512 .49155 .76203 .48829 .75721 .48223 Mtetra
.75721 .48223 .76203 .48829 .77289 .48501 .7681 .47893 Mtetra
.7681 .47893 .77289 .48501 .7838 .48173 .77903 .47562 Mtetra
.77903 .47562 .7838 .48173 .79474 .47843 .79001 .4723 Mtetra
.79001 .4723 .79474 .47843 .80573 .47511 .80103 .46897 Mtetra
.80103 .46897 .80573 .47511 .81676 .47179 .81209 .46562 Mtetra
.81209 .46562 .81676 .47179 .82783 .46845 .82319 .46226 Mtetra
.82319 .46226 .82783 .46845 .83895 .4651 .83434 .45888 Mtetra
.83434 .45888 .83895 .4651 .85011 .46174 .84552 .45549 Mtetra
.84552 .45549 .85011 .46174 .86131 .45836 .85676 .45209 Mtetra
.85676 .45209 .86131 .45836 .87255 .45497 .86803 .44868 Mtetra
.86803 .44868 .87255 .45497 .88384 .45157 .87935 .44525 Mtetra
.87935 .44525 .88384 .45157 .89517 .44815 .89071 .44181 Mtetra
.89071 .44181 .89517 .44815 .90654 .44472 .90212 .43836 Mtetra
.90212 .43836 .90654 .44472 .91796 .44128 .91357 .43489 Mtetra
.3005 .61354 .30643 .61871 .31568 .61591 .30977 .61072 Mtetra
.30977 .61072 .31568 .61591 .32495 .6131 .31906 .60789 Mtetra
.31906 .60789 .32495 .6131 .33427 .61028 .32839 .60505 Mtetra
.32839 .60505 .33427 .61028 .34361 .60746 .33776 .60221 Mtetra
.33776 .60221 .34361 .60746 .35299 .60462 .34715 .59935 Mtetra
.34715 .59935 .35299 .60462 .36239 .60177 .35658 .59648 Mtetra
.35658 .59648 .36239 .60177 .37184 .59891 .36605 .5936 Mtetra
.36605 .5936 .37184 .59891 .38131 .59604 .37555 .59072 Mtetra
.37555 .59072 .38131 .59604 .39082 .59316 .38508 .58782 Mtetra
.38508 .58782 .39082 .59316 .40037 .59027 .39464 .58491 Mtetra
.39464 .58491 .40037 .59027 .40995 .58737 .40424 .58199 Mtetra
.40424 .58199 .40995 .58737 .41956 .58446 .41387 .57906 Mtetra
.41387 .57906 .41956 .58446 .4292 .58154 .42354 .57612 Mtetra
.42354 .57612 .4292 .58154 .43888 .57861 .43324 .57317 Mtetra
.43324 .57317 .43888 .57861 .4486 .57567 .44298 .57021 Mtetra
.44298 .57021 .4486 .57567 .45835 .57272 .45276 .56724 Mtetra
.45276 .56724 .45835 .57272 .46814 .56975 .46256 .56426 Mtetra
.46256 .56426 .46814 .56975 .47796 .56678 .47241 .56126 Mtetra
.47241 .56126 .47796 .56678 .48781 .5638 .48229 .55826 Mtetra
.48229 .55826 .48781 .5638 .49771 .5608 .4922 .55524 Mtetra
.4922 .55524 .49771 .5608 .50763 .55779 .50215 .55222 Mtetra
.50215 .55222 .50763 .55779 .5176 .55478 .51214 .54918 Mtetra
.51214 .54918 .5176 .55478 .5276 .55175 .52217 .54613 Mtetra
.52217 .54613 .5276 .55175 .53764 .54871 .53223 .54307 Mtetra
.53223 .54307 .53764 .54871 .54771 .54566 .54232 .54 Mtetra
.54232 .54 .54771 .54566 .55782 .5426 .55246 .53692 Mtetra
.55246 .53692 .55782 .5426 .56797 .53953 .56263 .53383 Mtetra
.56263 .53383 .56797 .53953 .57815 .53644 .57284 .53072 Mtetra
.57284 .53072 .57815 .53644 .58837 .53335 .58309 .52761 Mtetra
.58309 .52761 .58837 .53335 .59864 .53024 .59337 .52448 Mtetra
.59337 .52448 .59864 .53024 .60893 .52712 .6037 .52134 Mtetra
.6037 .52134 .60893 .52712 .61927 .524 .61406 .51819 Mtetra
.61406 .51819 .61927 .524 .62964 .52085 .62446 .51503 Mtetra
.62446 .51503 .62964 .52085 .64006 .5177 .6349 .51185 Mtetra
.6349 .51185 .64006 .5177 .65051 .51454 .64538 .50866 Mtetra
.64538 .50866 .65051 .51454 .661 .51136 .65589 .50547 Mtetra
.65589 .50547 .661 .51136 .67153 .50817 .66645 .50226 Mtetra
.66645 .50226 .67153 .50817 .6821 .50497 .67705 .49903 Mtetra
.67705 .49903 .6821 .50497 .69271 .50176 .68768 .4958 Mtetra
.68768 .4958 .69271 .50176 .70336 .49854 .69836 .49255 Mtetra
.69836 .49255 .70336 .49854 .71405 .4953 .70908 .48929 Mtetra
.70908 .48929 .71405 .4953 .72477 .49205 .71984 .48602 Mtetra
.71984 .48602 .72477 .49205 .73554 .48879 .73063 .48274 Mtetra
.73063 .48274 .73554 .48879 .74636 .48552 .74147 .47944 Mtetra
.74147 .47944 .74636 .48552 .75721 .48223 .75235 .47613 Mtetra
.75235 .47613 .75721 .48223 .7681 .47893 .76328 .47281 Mtetra
.76328 .47281 .7681 .47893 .77903 .47562 .77424 .46948 Mtetra
.77424 .46948 .77903 .47562 .79001 .4723 .78524 .46613 Mtetra
.78524 .46613 .79001 .4723 .80103 .46897 .79629 .46277 Mtetra
.79629 .46277 .80103 .46897 .81209 .46562 .80738 .4594 Mtetra
.80738 .4594 .81209 .46562 .82319 .46226 .81852 .45602 Mtetra
.81852 .45602 .82319 .46226 .83434 .45888 .82969 .45262 Mtetra
.82969 .45262 .83434 .45888 .84552 .45549 .84091 .44921 Mtetra
.84091 .44921 .84552 .45549 .85676 .45209 .85217 .44578 Mtetra
.85217 .44578 .85676 .45209 .86803 .44868 .86348 .44234 Mtetra
.86348 .44234 .86803 .44868 .87935 .44525 .87483 .43889 Mtetra
.87483 .43889 .87935 .44525 .89071 .44181 .88623 .43543 Mtetra
.88623 .43543 .89071 .44181 .90212 .43836 .89766 .43195 Mtetra
.89766 .43195 .90212 .43836 .91357 .43489 .90915 .42846 Mtetra
.29453 .60833 .3005 .61354 .30977 .61072 .30382 .60549 Mtetra
.30382 .60549 .30977 .61072 .31906 .60789 .31314 .60265 Mtetra
.31314 .60265 .31906 .60789 .32839 .60505 .32249 .59979 Mtetra
.32249 .59979 .32839 .60505 .33776 .60221 .33187 .59692 Mtetra
.33187 .59692 .33776 .60221 .34715 .59935 .34129 .59405 Mtetra
.34129 .59405 .34715 .59935 .35658 .59648 .35074 .59116 Mtetra
.35074 .59116 .35658 .59648 .36605 .5936 .36022 .58826 Mtetra
.36022 .58826 .36605 .5936 .37555 .59072 .36974 .58536 Mtetra
.36974 .58536 .37555 .59072 .38508 .58782 .37929 .58244 Mtetra
.37929 .58244 .38508 .58782 .39464 .58491 .38888 .57951 Mtetra
.38888 .57951 .39464 .58491 .40424 .58199 .3985 .57657 Mtetra
.3985 .57657 .40424 .58199 .41387 .57906 .40815 .57363 Mtetra
.40815 .57363 .41387 .57906 .42354 .57612 .41784 .57067 Mtetra
.41784 .57067 .42354 .57612 .43324 .57317 .42757 .5677 Mtetra
.42757 .5677 .43324 .57317 .44298 .57021 .43733 .56471 Mtetra
.43733 .56471 .44298 .57021 .45276 .56724 .44712 .56172 Mtetra
.44712 .56172 .45276 .56724 .46256 .56426 .45695 .55872 Mtetra
.45695 .55872 .46256 .56426 .47241 .56126 .46682 .55571 Mtetra
.46682 .55571 .47241 .56126 .48229 .55826 .47672 .55268 Mtetra
.47672 .55268 .48229 .55826 .4922 .55524 .48666 .54965 Mtetra
.48666 .54965 .4922 .55524 .50215 .55222 .49664 .5466 Mtetra
.49664 .5466 .50215 .55222 .51214 .54918 .50665 .54354 Mtetra
.50665 .54354 .51214 .54918 .52217 .54613 .5167 .54047 Mtetra
.5167 .54047 .52217 .54613 .53223 .54307 .52678 .53739 Mtetra
.52678 .53739 .53223 .54307 .54232 .54 .5369 .5343 Mtetra
.5369 .5343 .54232 .54 .55246 .53692 .54706 .5312 Mtetra
.54706 .5312 .55246 .53692 .56263 .53383 .55726 .52809 Mtetra
.55726 .52809 .56263 .53383 .57284 .53072 .56749 .52496 Mtetra
.56749 .52496 .57284 .53072 .58309 .52761 .57777 .52182 Mtetra
.57777 .52182 .58309 .52761 .59337 .52448 .58808 .51867 Mtetra
.58808 .51867 .59337 .52448 .6037 .52134 .59843 .51551 Mtetra
.59843 .51551 .6037 .52134 .61406 .51819 .60881 .51234 Mtetra
.60881 .51234 .61406 .51819 .62446 .51503 .61924 .50916 Mtetra
.61924 .50916 .62446 .51503 .6349 .51185 .62971 .50596 Mtetra
.62971 .50596 .6349 .51185 .64538 .50866 .64021 .50275 Mtetra
.64021 .50275 .64538 .50866 .65589 .50547 .65075 .49953 Mtetra
.65075 .49953 .65589 .50547 .66645 .50226 .66134 .4963 Mtetra
.66134 .4963 .66645 .50226 .67705 .49903 .67196 .49305 Mtetra
.67196 .49305 .67705 .49903 .68768 .4958 .68263 .4898 Mtetra
.68263 .4898 .68768 .4958 .69836 .49255 .69333 .48653 Mtetra
.69333 .48653 .69836 .49255 .70908 .48929 .70408 .48325 Mtetra
.70408 .48325 .70908 .48929 .71984 .48602 .71486 .47995 Mtetra
.71486 .47995 .71984 .48602 .73063 .48274 .72569 .47664 Mtetra
.72569 .47664 .73063 .48274 .74147 .47944 .73656 .47333 Mtetra
.73656 .47333 .74147 .47944 .75235 .47613 .74746 .46999 Mtetra
.74746 .46999 .75235 .47613 .76328 .47281 .75842 .46665 Mtetra
.75842 .46665 .76328 .47281 .77424 .46948 .76941 .46329 Mtetra
.76941 .46329 .77424 .46948 .78524 .46613 .78044 .45992 Mtetra
.78044 .45992 .78524 .46613 .79629 .46277 .79152 .45654 Mtetra
.79152 .45654 .79629 .46277 .80738 .4594 .80264 .45314 Mtetra
.80264 .45314 .80738 .4594 .81852 .45602 .81381 .44973 Mtetra
.81381 .44973 .81852 .45602 .82969 .45262 .82501 .44631 Mtetra
.82501 .44631 .82969 .45262 .84091 .44921 .83626 .44287 Mtetra
.83626 .44287 .84091 .44921 .85217 .44578 .84756 .43942 Mtetra
.84756 .43942 .85217 .44578 .86348 .44234 .8589 .43596 Mtetra
.8589 .43596 .86348 .44234 .87483 .43889 .87028 .43248 Mtetra
.87028 .43248 .87483 .43889 .88623 .43543 .88171 .42899 Mtetra
.88171 .42899 .88623 .43543 .89766 .43195 .89318 .42549 Mtetra
.89318 .42549 .89766 .43195 .90915 .42846 .90469 .42197 Mtetra
.28853 .60308 .29453 .60833 .30382 .60549 .29783 .60023 Mtetra
.29783 .60023 .30382 .60549 .31314 .60265 .30717 .59737 Mtetra
.30717 .59737 .31314 .60265 .32249 .59979 .31654 .59449 Mtetra
.31654 .59449 .32249 .59979 .33187 .59692 .32594 .59161 Mtetra
.32594 .59161 .33187 .59692 .34129 .59405 .33538 .58871 Mtetra
.33538 .58871 .34129 .59405 .35074 .59116 .34485 .58581 Mtetra
.34485 .58581 .35074 .59116 .36022 .58826 .35435 .58289 Mtetra
.35435 .58289 .36022 .58826 .36974 .58536 .36389 .57996 Mtetra
.36389 .57996 .36974 .58536 .37929 .58244 .37347 .57703 Mtetra
.37347 .57703 .37929 .58244 .38888 .57951 .38307 .57408 Mtetra
.38307 .57408 .38888 .57951 .3985 .57657 .39272 .57112 Mtetra
.39272 .57112 .3985 .57657 .40815 .57363 .40239 .56815 Mtetra
.40239 .56815 .40815 .57363 .41784 .57067 .41211 .56517 Mtetra
.41211 .56517 .41784 .57067 .42757 .5677 .42185 .56218 Mtetra
.42185 .56218 .42757 .5677 .43733 .56471 .43163 .55918 Mtetra
.43163 .55918 .43733 .56471 .44712 .56172 .44145 .55617 Mtetra
.44145 .55617 .44712 .56172 .45695 .55872 .45131 .55315 Mtetra
.45131 .55315 .45695 .55872 .46682 .55571 .4612 .55012 Mtetra
.4612 .55012 .46682 .55571 .47672 .55268 .47112 .54707 Mtetra
.47112 .54707 .47672 .55268 .48666 .54965 .48108 .54401 Mtetra
.48108 .54401 .48666 .54965 .49664 .5466 .49108 .54095 Mtetra
.49108 .54095 .49664 .5466 .50665 .54354 .50112 .53787 Mtetra
.50112 .53787 .50665 .54354 .5167 .54047 .51119 .53478 Mtetra
.51119 .53478 .5167 .54047 .52678 .53739 .5213 .53168 Mtetra
.5213 .53168 .52678 .53739 .5369 .5343 .53144 .52857 Mtetra
.53144 .52857 .5369 .5343 .54706 .5312 .54163 .52544 Mtetra
.54163 .52544 .54706 .5312 .55726 .52809 .55185 .52231 Mtetra
.55185 .52231 .55726 .52809 .56749 .52496 .56211 .51916 Mtetra
.56211 .51916 .56749 .52496 .57777 .52182 .57241 .516 Mtetra
.57241 .516 .57777 .52182 .58808 .51867 .58274 .51283 Mtetra
.58274 .51283 .58808 .51867 .59843 .51551 .59312 .50965 Mtetra
.59312 .50965 .59843 .51551 .60881 .51234 .60353 .50645 Mtetra
.60353 .50645 .60881 .51234 .61924 .50916 .61398 .50324 Mtetra
.61398 .50324 .61924 .50916 .62971 .50596 .62448 .50003 Mtetra
.62448 .50003 .62971 .50596 .64021 .50275 .63501 .4968 Mtetra
.63501 .4968 .64021 .50275 .65075 .49953 .64558 .49355 Mtetra
.64558 .49355 .65075 .49953 .66134 .4963 .65619 .4903 Mtetra
.65619 .4903 .66134 .4963 .67196 .49305 .66684 .48703 Mtetra
.66684 .48703 .67196 .49305 .68263 .4898 .67753 .48375 Mtetra
.67753 .48375 .68263 .4898 .69333 .48653 .68826 .48046 Mtetra
.68826 .48046 .69333 .48653 .70408 .48325 .69904 .47715 Mtetra
.69904 .47715 .70408 .48325 .71486 .47995 .70985 .47384 Mtetra
.70985 .47384 .71486 .47995 .72569 .47664 .72071 .47051 Mtetra
.72071 .47051 .72569 .47664 .73656 .47333 .7316 .46716 Mtetra
.7316 .46716 .73656 .47333 .74746 .46999 .74254 .46381 Mtetra
.74254 .46381 .74746 .46999 .75842 .46665 .75352 .46044 Mtetra
.75352 .46044 .75842 .46665 .76941 .46329 .76455 .45706 Mtetra
.76455 .45706 .76941 .46329 .78044 .45992 .77561 .45366 Mtetra
.77561 .45366 .78044 .45992 .79152 .45654 .78672 .45026 Mtetra
.78672 .45026 .79152 .45654 .80264 .45314 .79787 .44684 Mtetra
.79787 .44684 .80264 .45314 .81381 .44973 .80906 .4434 Mtetra
.80906 .4434 .81381 .44973 .82501 .44631 .8203 .43995 Mtetra
.8203 .43995 .82501 .44631 .83626 .44287 .83158 .43649 Mtetra
.83158 .43649 .83626 .44287 .84756 .43942 .84291 .43302 Mtetra
.84291 .43302 .84756 .43942 .8589 .43596 .85428 .42953 Mtetra
.85428 .42953 .8589 .43596 .87028 .43248 .86569 .42603 Mtetra
.86569 .42603 .87028 .43248 .88171 .42899 .87715 .42251 Mtetra
.87715 .42251 .88171 .42899 .89318 .42549 .88866 .41899 Mtetra
.88866 .41899 .89318 .42549 .90469 .42197 .90021 .41544 Mtetra
.28248 .59781 .28853 .60308 .29783 .60023 .2918 .59493 Mtetra
.2918 .59493 .29783 .60023 .30717 .59737 .30116 .59205 Mtetra
.30116 .59205 .30717 .59737 .31654 .59449 .31055 .58916 Mtetra
.31055 .58916 .31654 .59449 .32594 .59161 .31998 .58625 Mtetra
.31998 .58625 .32594 .59161 .33538 .58871 .32943 .58334 Mtetra
.32943 .58334 .33538 .58871 .34485 .58581 .33892 .58041 Mtetra
.33892 .58041 .34485 .58581 .35435 .58289 .34845 .57748 Mtetra
.34845 .57748 .35435 .58289 .36389 .57996 .35801 .57453 Mtetra
.35801 .57453 .36389 .57996 .37347 .57703 .3676 .57158 Mtetra
.3676 .57158 .37347 .57703 .38307 .57408 .37723 .56861 Mtetra
.37723 .56861 .38307 .57408 .39272 .57112 .3869 .56563 Mtetra
.3869 .56563 .39272 .57112 .40239 .56815 .3966 .56264 Mtetra
.3966 .56264 .40239 .56815 .41211 .56517 .40633 .55965 Mtetra
.40633 .55965 .41211 .56517 .42185 .56218 .4161 .55664 Mtetra
.4161 .55664 .42185 .56218 .43163 .55918 .4259 .55361 Mtetra
.4259 .55361 .43163 .55918 .44145 .55617 .43574 .55058 Mtetra
.43574 .55058 .44145 .55617 .45131 .55315 .44562 .54754 Mtetra
.44562 .54754 .45131 .55315 .4612 .55012 .45553 .54449 Mtetra
.45553 .54449 .4612 .55012 .47112 .54707 .46548 .54142 Mtetra
.46548 .54142 .47112 .54707 .48108 .54401 .47547 .53834 Mtetra
.47547 .53834 .48108 .54401 .49108 .54095 .48549 .53526 Mtetra
.48549 .53526 .49108 .54095 .50112 .53787 .49555 .53216 Mtetra
.49555 .53216 .50112 .53787 .51119 .53478 .50564 .52905 Mtetra
.50564 .52905 .51119 .53478 .5213 .53168 .51578 .52592 Mtetra
.51578 .52592 .5213 .53168 .53144 .52857 .52595 .52279 Mtetra
.52595 .52279 .53144 .52857 .54163 .52544 .53616 .51964 Mtetra
.53616 .51964 .54163 .52544 .55185 .52231 .5464 .51649 Mtetra
.5464 .51649 .55185 .52231 .56211 .51916 .55669 .51332 Mtetra
.55669 .51332 .56211 .51916 .57241 .516 .56701 .51014 Mtetra
.56701 .51014 .57241 .516 .58274 .51283 .57737 .50694 Mtetra
.57737 .50694 .58274 .51283 .59312 .50965 .58777 .50374 Mtetra
.58777 .50374 .59312 .50965 .60353 .50645 .59821 .50052 Mtetra
.59821 .50052 .60353 .50645 .61398 .50324 .60869 .49729 Mtetra
.60869 .49729 .61398 .50324 .62448 .50003 .61921 .49405 Mtetra
.61921 .49405 .62448 .50003 .63501 .4968 .62977 .4908 Mtetra
.62977 .4908 .63501 .4968 .64558 .49355 .64037 .48753 Mtetra
.64037 .48753 .64558 .49355 .65619 .4903 .65101 .48426 Mtetra
.65101 .48426 .65619 .4903 .66684 .48703 .66168 .48097 Mtetra
.66168 .48097 .66684 .48703 .67753 .48375 .6724 .47766 Mtetra
.6724 .47766 .67753 .48375 .68826 .48046 .68316 .47435 Mtetra
.68316 .47435 .68826 .48046 .69904 .47715 .69396 .47102 Mtetra
.69396 .47102 .69904 .47715 .70985 .47384 .70481 .46768 Mtetra
.70481 .46768 .70985 .47384 .72071 .47051 .71569 .46433 Mtetra
.71569 .46433 .72071 .47051 .7316 .46716 .72662 .46096 Mtetra
.72662 .46096 .7316 .46716 .74254 .46381 .73758 .45758 Mtetra
.73758 .45758 .74254 .46381 .75352 .46044 .74859 .45419 Mtetra
.74859 .45419 .75352 .46044 .76455 .45706 .75965 .45078 Mtetra
.75965 .45078 .76455 .45706 .77561 .45366 .77074 .44736 Mtetra
.77074 .44736 .77561 .45366 .78672 .45026 .78188 .44393 Mtetra
.78188 .44393 .78672 .45026 .79787 .44684 .79306 .44049 Mtetra
.79306 .44049 .79787 .44684 .80906 .4434 .80429 .43703 Mtetra
.80429 .43703 .80906 .4434 .8203 .43995 .81556 .43355 Mtetra
.81556 .43355 .8203 .43995 .83158 .43649 .82687 .43007 Mtetra
.82687 .43007 .83158 .43649 .84291 .43302 .83823 .42657 Mtetra
.83823 .42657 .84291 .43302 .85428 .42953 .84963 .42306 Mtetra
.84963 .42306 .85428 .42953 .86569 .42603 .86108 .41953 Mtetra
.86108 .41953 .86569 .42603 .87715 .42251 .87257 .41599 Mtetra
.87257 .41599 .87715 .42251 .88866 .41899 .8841 .41243 Mtetra
.8841 .41243 .88866 .41899 .90021 .41544 .89569 .40886 Mtetra
.27639 .59249 .28248 .59781 .2918 .59493 .28574 .5896 Mtetra
.28574 .5896 .2918 .59493 .30116 .59205 .29511 .5867 Mtetra
.29511 .5867 .30116 .59205 .31055 .58916 .30452 .58379 Mtetra
.30452 .58379 .31055 .58916 .31998 .58625 .31397 .58087 Mtetra
.31397 .58087 .31998 .58625 .32943 .58334 .32345 .57793 Mtetra
.32345 .57793 .32943 .58334 .33892 .58041 .33296 .57499 Mtetra
.33296 .57499 .33892 .58041 .34845 .57748 .34251 .57203 Mtetra
.34251 .57203 .34845 .57748 .35801 .57453 .35209 .56907 Mtetra
.35209 .56907 .35801 .57453 .3676 .57158 .3617 .56609 Mtetra
.3617 .56609 .3676 .57158 .37723 .56861 .37135 .56311 Mtetra
.37135 .56311 .37723 .56861 .3869 .56563 .38104 .56011 Mtetra
.38104 .56011 .3869 .56563 .3966 .56264 .39076 .5571 Mtetra
.39076 .5571 .3966 .56264 .40633 .55965 .40052 .55408 Mtetra
.40052 .55408 .40633 .55965 .4161 .55664 .41031 .55105 Mtetra
.41031 .55105 .4161 .55664 .4259 .55361 .42013 .54801 Mtetra
.42013 .54801 .4259 .55361 .43574 .55058 .43 .54496 Mtetra
.43 .54496 .43574 .55058 .44562 .54754 .4399 .54189 Mtetra
.4399 .54189 .44562 .54754 .45553 .54449 .44983 .53882 Mtetra
.44983 .53882 .45553 .54449 .46548 .54142 .4598 .53573 Mtetra
.4598 .53573 .46548 .54142 .47547 .53834 .46981 .53263 Mtetra
.46981 .53263 .47547 .53834 .48549 .53526 .47986 .52952 Mtetra
.47986 .52952 .48549 .53526 .49555 .53216 .48994 .5264 Mtetra
.48994 .5264 .49555 .53216 .50564 .52905 .50006 .52327 Mtetra
.50006 .52327 .50564 .52905 .51578 .52592 .51022 .52013 Mtetra
.51022 .52013 .51578 .52592 .52595 .52279 .52041 .51697 Mtetra
.52041 .51697 .52595 .52279 .53616 .51964 .53065 .51381 Mtetra
.53065 .51381 .53616 .51964 .5464 .51649 .54092 .51063 Mtetra
.54092 .51063 .5464 .51649 .55669 .51332 .55123 .50744 Mtetra
.55123 .50744 .55669 .51332 .56701 .51014 .56158 .50423 Mtetra
.56158 .50423 .56701 .51014 .57737 .50694 .57197 .50102 Mtetra
.57197 .50102 .57737 .50694 .58777 .50374 .58239 .49779 Mtetra
.58239 .49779 .58777 .50374 .59821 .50052 .59286 .49455 Mtetra
.59286 .49455 .59821 .50052 .60869 .49729 .60336 .4913 Mtetra
.60336 .4913 .60869 .49729 .61921 .49405 .61391 .48804 Mtetra
.61391 .48804 .61921 .49405 .62977 .4908 .62449 .48476 Mtetra
.62449 .48476 .62977 .4908 .64037 .48753 .63512 .48147 Mtetra
.63512 .48147 .64037 .48753 .65101 .48426 .64578 .47817 Mtetra
.64578 .47817 .65101 .48426 .66168 .48097 .65649 .47486 Mtetra
.65649 .47486 .66168 .48097 .6724 .47766 .66724 .47153 Mtetra
.66724 .47153 .6724 .47766 .68316 .47435 .67803 .46819 Mtetra
.67803 .46819 .68316 .47435 .69396 .47102 .68886 .46484 Mtetra
.68886 .46484 .69396 .47102 .70481 .46768 .69973 .46148 Mtetra
.69973 .46148 .70481 .46768 .71569 .46433 .71064 .4581 Mtetra
.71064 .4581 .71569 .46433 .72662 .46096 .72159 .45471 Mtetra
.72159 .45471 .72662 .46096 .73758 .45758 .73259 .45131 Mtetra
.73259 .45131 .73758 .45758 .74859 .45419 .74363 .44789 Mtetra
.74363 .44789 .74859 .45419 .75965 .45078 .75471 .44446 Mtetra
.75471 .44446 .75965 .45078 .77074 .44736 .76584 .44102 Mtetra
.76584 .44102 .77074 .44736 .78188 .44393 .77701 .43756 Mtetra
.77701 .43756 .78188 .44393 .79306 .44049 .78822 .43409 Mtetra
.78822 .43409 .79306 .44049 .80429 .43703 .79948 .43061 Mtetra
.79948 .43061 .80429 .43703 .81556 .43355 .81078 .42711 Mtetra
.81078 .42711 .81556 .43355 .82687 .43007 .82212 .4236 Mtetra
.82212 .4236 .82687 .43007 .83823 .42657 .83351 .42007 Mtetra
.83351 .42007 .83823 .42657 .84963 .42306 .84494 .41653 Mtetra
.84494 .41653 .84963 .42306 .86108 .41953 .85642 .41298 Mtetra
.85642 .41298 .86108 .41953 .87257 .41599 .86795 .40941 Mtetra
.86795 .40941 .87257 .41599 .8841 .41243 .87952 .40583 Mtetra
.87952 .40583 .8841 .41243 .89569 .40886 .89113 .40224 Mtetra
.27027 .58715 .27639 .59249 .28574 .5896 .27963 .58424 Mtetra
.27963 .58424 .28574 .5896 .29511 .5867 .28903 .58132 Mtetra
.28903 .58132 .29511 .5867 .30452 .58379 .29846 .57838 Mtetra
.29846 .57838 .30452 .58379 .31397 .58087 .30792 .57544 Mtetra
.30792 .57544 .31397 .58087 .32345 .57793 .31742 .57249 Mtetra
.31742 .57249 .32345 .57793 .33296 .57499 .32696 .56952 Mtetra
.32696 .56952 .33296 .57499 .34251 .57203 .33652 .56655 Mtetra
.33652 .56655 .34251 .57203 .35209 .56907 .34613 .56357 Mtetra
.34613 .56357 .35209 .56907 .3617 .56609 .35576 .56057 Mtetra
.35576 .56057 .3617 .56609 .37135 .56311 .36543 .55756 Mtetra
.36543 .55756 .37135 .56311 .38104 .56011 .37514 .55455 Mtetra
.37514 .55455 .38104 .56011 .39076 .5571 .38488 .55152 Mtetra
.38488 .55152 .39076 .5571 .40052 .55408 .39466 .54848 Mtetra
.39466 .54848 .40052 .55408 .41031 .55105 .40448 .54543 Mtetra
.40448 .54543 .41031 .55105 .42013 .54801 .41432 .54236 Mtetra
.41432 .54236 .42013 .54801 .43 .54496 .42421 .53929 Mtetra
.42421 .53929 .43 .54496 .4399 .54189 .43413 .53621 Mtetra
.43413 .53621 .4399 .54189 .44983 .53882 .44409 .53311 Mtetra
.44409 .53311 .44983 .53882 .4598 .53573 .45409 .53 Mtetra
.45409 .53 .4598 .53573 .46981 .53263 .46412 .52688 Mtetra
.46412 .52688 .46981 .53263 .47986 .52952 .47419 .52375 Mtetra
.47419 .52375 .47986 .52952 .48994 .5264 .4843 .52061 Mtetra
.4843 .52061 .48994 .5264 .50006 .52327 .49444 .51746 Mtetra
.49444 .51746 .50006 .52327 .51022 .52013 .50462 .51429 Mtetra
.50462 .51429 .51022 .52013 .52041 .51697 .51484 .51112 Mtetra
.51484 .51112 .52041 .51697 .53065 .51381 .5251 .50793 Mtetra
.5251 .50793 .53065 .51381 .54092 .51063 .5354 .50473 Mtetra
.5354 .50473 .54092 .51063 .55123 .50744 .54573 .50151 Mtetra
.54573 .50151 .55123 .50744 .56158 .50423 .55611 .49829 Mtetra
.55611 .49829 .56158 .50423 .57197 .50102 .56652 .49505 Mtetra
.56652 .49505 .57197 .50102 .58239 .49779 .57697 .4918 Mtetra
.57697 .4918 .58239 .49779 .59286 .49455 .58747 .48854 Mtetra
.58747 .48854 .59286 .49455 .60336 .4913 .598 .48527 Mtetra
.598 .48527 .60336 .4913 .61391 .48804 .60857 .48198 Mtetra
.60857 .48198 .61391 .48804 .62449 .48476 .61918 .47868 Mtetra
.61918 .47868 .62449 .48476 .63512 .48147 .62983 .47537 Mtetra
.62983 .47537 .63512 .48147 .64578 .47817 .64053 .47205 Mtetra
.64053 .47205 .64578 .47817 .65649 .47486 .65126 .46871 Mtetra
.65126 .46871 .65649 .47486 .66724 .47153 .66204 .46536 Mtetra
.66204 .46536 .66724 .47153 .67803 .46819 .67285 .462 Mtetra
.67285 .462 .67803 .46819 .68886 .46484 .68371 .45862 Mtetra
.68371 .45862 .68886 .46484 .69973 .46148 .69461 .45523 Mtetra
.69461 .45523 .69973 .46148 .71064 .4581 .70555 .45183 Mtetra
.70555 .45183 .71064 .4581 .72159 .45471 .71654 .44842 Mtetra
.71654 .44842 .72159 .45471 .73259 .45131 .72756 .44499 Mtetra
.72756 .44499 .73259 .45131 .74363 .44789 .73863 .44155 Mtetra
.73863 .44155 .74363 .44789 .75471 .44446 .74974 .43809 Mtetra
.74974 .43809 .75471 .44446 .76584 .44102 .7609 .43462 Mtetra
.7609 .43462 .76584 .44102 .77701 .43756 .7721 .43114 Mtetra
.7721 .43114 .77701 .43756 .78822 .43409 .78334 .42765 Mtetra
.78334 .42765 .78822 .43409 .79948 .43061 .79463 .42414 Mtetra
.79463 .42414 .79948 .43061 .81078 .42711 .80596 .42062 Mtetra
.80596 .42062 .81078 .42711 .82212 .4236 .81734 .41708 Mtetra
.81734 .41708 .82212 .4236 .83351 .42007 .82876 .41353 Mtetra
.82876 .41353 .83351 .42007 .84494 .41653 .84023 .40996 Mtetra
.84023 .40996 .84494 .41653 .85642 .41298 .85174 .40639 Mtetra
.85174 .40639 .85642 .41298 .86795 .40941 .8633 .40279 Mtetra
.8633 .40279 .86795 .40941 .87952 .40583 .8749 .39919 Mtetra
.8749 .39919 .87952 .40583 .89113 .40224 .88655 .39556 Mtetra
.2641 .58177 .27027 .58715 .27963 .58424 .27348 .57884 Mtetra
.27348 .57884 .27963 .58424 .28903 .58132 .2829 .57589 Mtetra
.2829 .57589 .28903 .58132 .29846 .57838 .29235 .57294 Mtetra
.29235 .57294 .29846 .57838 .30792 .57544 .30184 .56998 Mtetra
.30184 .56998 .30792 .57544 .31742 .57249 .31136 .56701 Mtetra
.31136 .56701 .31742 .57249 .32696 .56952 .32091 .56403 Mtetra
.32091 .56403 .32696 .56952 .33652 .56655 .3305 .56103 Mtetra
.3305 .56103 .33652 .56655 .34613 .56357 .34012 .55803 Mtetra
.34012 .55803 .34613 .56357 .35576 .56057 .34978 .55501 Mtetra
.34978 .55501 .35576 .56057 .36543 .55756 .35947 .55198 Mtetra
.35947 .55198 .36543 .55756 .37514 .55455 .3692 .54895 Mtetra
.3692 .54895 .37514 .55455 .38488 .55152 .37897 .5459 Mtetra
.37897 .5459 .38488 .55152 .39466 .54848 .38877 .54284 Mtetra
.38877 .54284 .39466 .54848 .40448 .54543 .3986 .53976 Mtetra
.3986 .53976 .40448 .54543 .41432 .54236 .40848 .53668 Mtetra
.40848 .53668 .41432 .54236 .42421 .53929 .41839 .53359 Mtetra
.41839 .53359 .42421 .53929 .43413 .53621 .42833 .53048 Mtetra
.42833 .53048 .43413 .53621 .44409 .53311 .43831 .52737 Mtetra
.43831 .52737 .44409 .53311 .45409 .53 .44833 .52424 Mtetra
.44833 .52424 .45409 .53 .46412 .52688 .45839 .5211 Mtetra
.45839 .5211 .46412 .52688 .47419 .52375 .46848 .51794 Mtetra
.46848 .51794 .47419 .52375 .4843 .52061 .47861 .51478 Mtetra
.47861 .51478 .4843 .52061 .49444 .51746 .48878 .51161 Mtetra
.48878 .51161 .49444 .51746 .50462 .51429 .49899 .50842 Mtetra
.49899 .50842 .50462 .51429 .51484 .51112 .50923 .50522 Mtetra
.50923 .50522 .51484 .51112 .5251 .50793 .51952 .50201 Mtetra
.51952 .50201 .5251 .50793 .5354 .50473 .52984 .49879 Mtetra
.52984 .49879 .5354 .50473 .54573 .50151 .5402 .49555 Mtetra
.5402 .49555 .54573 .50151 .55611 .49829 .5506 .4923 Mtetra
.5506 .4923 .55611 .49829 .56652 .49505 .56104 .48904 Mtetra
.56104 .48904 .56652 .49505 .57697 .4918 .57152 .48577 Mtetra
.57152 .48577 .57697 .4918 .58747 .48854 .58203 .48249 Mtetra
.58203 .48249 .58747 .48854 .598 .48527 .59259 .47919 Mtetra
.59259 .47919 .598 .48527 .60857 .48198 .60319 .47588 Mtetra
.60319 .47588 .60857 .48198 .61918 .47868 .61383 .47256 Mtetra
.61383 .47256 .61918 .47868 .62983 .47537 .62451 .46922 Mtetra
.62451 .46922 .62983 .47537 .64053 .47205 .63523 .46587 Mtetra
.63523 .46587 .64053 .47205 .65126 .46871 .64599 .46251 Mtetra
.64599 .46251 .65126 .46871 .66204 .46536 .6568 .45914 Mtetra
.6568 .45914 .66204 .46536 .67285 .462 .66764 .45575 Mtetra
.66764 .45575 .67285 .462 .68371 .45862 .67853 .45235 Mtetra
.67853 .45235 .68371 .45862 .69461 .45523 .68946 .44894 Mtetra
.68946 .44894 .69461 .45523 .70555 .45183 .70043 .44552 Mtetra
.70043 .44552 .70555 .45183 .71654 .44842 .71144 .44208 Mtetra
.71144 .44208 .71654 .44842 .72756 .44499 .7225 .43862 Mtetra
.7225 .43862 .72756 .44499 .73863 .44155 .7336 .43516 Mtetra
.7336 .43516 .73863 .44155 .74974 .43809 .74474 .43168 Mtetra
.74474 .43168 .74974 .43809 .7609 .43462 .75593 .42819 Mtetra
.75593 .42819 .7609 .43462 .7721 .43114 .76716 .42468 Mtetra
.76716 .42468 .7721 .43114 .78334 .42765 .77843 .42116 Mtetra
.77843 .42116 .78334 .42765 .79463 .42414 .78975 .41762 Mtetra
.78975 .41762 .79463 .42414 .80596 .42062 .80111 .41408 Mtetra
.80111 .41408 .80596 .42062 .81734 .41708 .81252 .41051 Mtetra
.81252 .41051 .81734 .41708 .82876 .41353 .82397 .40694 Mtetra
.82397 .40694 .82876 .41353 .84023 .40996 .83547 .40335 Mtetra
.83547 .40335 .84023 .40996 .85174 .40639 .84702 .39974 Mtetra
.84702 .39974 .85174 .40639 .8633 .40279 .85861 .39612 Mtetra
.85861 .39612 .8633 .40279 .8749 .39919 .87025 .39249 Mtetra
.87025 .39249 .8749 .39919 .88655 .39556 .88193 .38884 Mtetra
.25789 .57635 .2641 .58177 .27348 .57884 .2673 .5734 Mtetra
.2673 .5734 .27348 .57884 .2829 .57589 .27673 .57044 Mtetra
.27673 .57044 .2829 .57589 .29235 .57294 .2862 .56747 Mtetra
.2862 .56747 .29235 .57294 .30184 .56998 .29571 .56449 Mtetra
.29571 .56449 .30184 .56998 .31136 .56701 .30525 .56149 Mtetra
.30525 .56149 .31136 .56701 .32091 .56403 .31483 .55849 Mtetra
.31483 .55849 .32091 .56403 .3305 .56103 .32444 .55547 Mtetra
.32444 .55547 .3305 .56103 .34012 .55803 .33408 .55245 Mtetra
.33408 .55245 .34012 .55803 .34978 .55501 .34376 .54941 Mtetra
.34376 .54941 .34978 .55501 .35947 .55198 .35348 .54637 Mtetra
.35348 .54637 .35947 .55198 .3692 .54895 .36323 .54331 Mtetra
.36323 .54331 .3692 .54895 .37897 .5459 .37301 .54024 Mtetra
.37301 .54024 .37897 .5459 .38877 .54284 .38284 .53716 Mtetra
.38284 .53716 .38877 .54284 .3986 .53976 .39269 .53406 Mtetra
.39269 .53406 .3986 .53976 .40848 .53668 .40259 .53096 Mtetra
.40259 .53096 .40848 .53668 .41839 .53359 .41252 .52785 Mtetra
.41252 .52785 .41839 .53359 .42833 .53048 .42249 .52472 Mtetra
.42249 .52472 .42833 .53048 .43831 .52737 .43249 .52158 Mtetra
.43249 .52158 .43831 .52737 .44833 .52424 .44254 .51843 Mtetra
.44254 .51843 .44833 .52424 .45839 .5211 .45262 .51527 Mtetra
.45262 .51527 .45839 .5211 .46848 .51794 .46273 .5121 Mtetra
.46273 .5121 .46848 .51794 .47861 .51478 .47289 .50891 Mtetra
.47289 .50891 .47861 .51478 .48878 .51161 .48308 .50571 Mtetra
.48308 .50571 .48878 .51161 .49899 .50842 .49331 .5025 Mtetra
.49331 .5025 .49899 .50842 .50923 .50522 .50358 .49928 Mtetra
.50358 .49928 .50923 .50522 .51952 .50201 .51389 .49605 Mtetra
.51389 .49605 .51952 .50201 .52984 .49879 .52424 .4928 Mtetra
.52424 .4928 .52984 .49879 .5402 .49555 .53463 .48955 Mtetra
.53463 .48955 .5402 .49555 .5506 .4923 .54505 .48627 Mtetra
.54505 .48627 .5506 .4923 .56104 .48904 .55552 .48299 Mtetra
.55552 .48299 .56104 .48904 .57152 .48577 .56602 .4797 Mtetra
.56602 .4797 .57152 .48577 .58203 .48249 .57657 .47639 Mtetra
.57657 .47639 .58203 .48249 .59259 .47919 .58715 .47307 Mtetra
.58715 .47307 .59259 .47919 .60319 .47588 .59778 .46974 Mtetra
.59778 .46974 .60319 .47588 .61383 .47256 .60844 .46639 Mtetra
.60844 .46639 .61383 .47256 .62451 .46922 .61915 .46303 Mtetra
.61915 .46303 .62451 .46922 .63523 .46587 .6299 .45966 Mtetra
.6299 .45966 .63523 .46587 .64599 .46251 .64069 .45628 Mtetra
.64069 .45628 .64599 .46251 .6568 .45914 .65152 .45288 Mtetra
.65152 .45288 .6568 .45914 .66764 .45575 .66239 .44947 Mtetra
.66239 .44947 .66764 .45575 .67853 .45235 .67331 .44604 Mtetra
.67331 .44604 .67853 .45235 .68946 .44894 .68427 .44261 Mtetra
.68427 .44261 .68946 .44894 .70043 .44552 .69527 .43916 Mtetra
.69527 .43916 .70043 .44552 .71144 .44208 .70631 .43569 Mtetra
.70631 .43569 .71144 .44208 .7225 .43862 .7174 .43222 Mtetra
.7174 .43222 .7225 .43862 .7336 .43516 .72853 .42872 Mtetra
.72853 .42872 .7336 .43516 .74474 .43168 .7397 .42522 Mtetra
.7397 .42522 .74474 .43168 .75593 .42819 .75092 .4217 Mtetra
.75092 .4217 .75593 .42819 .76716 .42468 .76218 .41817 Mtetra
.76218 .41817 .76716 .42468 .77843 .42116 .77348 .41462 Mtetra
.77348 .41462 .77843 .42116 .78975 .41762 .78483 .41106 Mtetra
.78483 .41106 .78975 .41762 .80111 .41408 .79623 .40749 Mtetra
.79623 .40749 .80111 .41408 .81252 .41051 .80767 .4039 Mtetra
.80767 .4039 .81252 .41051 .82397 .40694 .81915 .4003 Mtetra
.81915 .4003 .82397 .40694 .83547 .40335 .83069 .39668 Mtetra
.83069 .39668 .83547 .40335 .84702 .39974 .84226 .39305 Mtetra
.84226 .39305 .84702 .39974 .85861 .39612 .85389 .3894 Mtetra
.85389 .3894 .85861 .39612 .87025 .39249 .86556 .38574 Mtetra
.86556 .38574 .87025 .39249 .88193 .38884 .87727 .38207 Mtetra
.25164 .57089 .25789 .57635 .2673 .5734 .26107 .56792 Mtetra
.26107 .56792 .2673 .5734 .27673 .57044 .27052 .56494 Mtetra
.27052 .56494 .27673 .57044 .2862 .56747 .28002 .56195 Mtetra
.28002 .56195 .2862 .56747 .29571 .56449 .28954 .55895 Mtetra
.28954 .55895 .29571 .56449 .30525 .56149 .2991 .55594 Mtetra
.2991 .55594 .30525 .56149 .31483 .55849 .3087 .55292 Mtetra
.3087 .55292 .31483 .55849 .32444 .55547 .31833 .54988 Mtetra
.31833 .54988 .32444 .55547 .33408 .55245 .328 .54684 Mtetra
.328 .54684 .33408 .55245 .34376 .54941 .3377 .54378 Mtetra
.3377 .54378 .34376 .54941 .35348 .54637 .34744 .54071 Mtetra
.34744 .54071 .35348 .54637 .36323 .54331 .35721 .53763 Mtetra
.35721 .53763 .36323 .54331 .37301 .54024 .36702 .53454 Mtetra
.36702 .53454 .37301 .54024 .38284 .53716 .37686 .53144 Mtetra
.37686 .53144 .38284 .53716 .39269 .53406 .38674 .52833 Mtetra
.38674 .52833 .39269 .53406 .40259 .53096 .39666 .5252 Mtetra
.39666 .5252 .40259 .53096 .41252 .52785 .40662 .52206 Mtetra
.40662 .52206 .41252 .52785 .42249 .52472 .41661 .51892 Mtetra
.41661 .51892 .42249 .52472 .43249 .52158 .42664 .51576 Mtetra
.42664 .51576 .43249 .52158 .44254 .51843 .4367 .51258 Mtetra
.4367 .51258 .44254 .51843 .45262 .51527 .44681 .5094 Mtetra
.44681 .5094 .45262 .51527 .46273 .5121 .45695 .50621 Mtetra
.45695 .50621 .46273 .5121 .47289 .50891 .46713 .503 Mtetra
.46713 .503 .47289 .50891 .48308 .50571 .47734 .49978 Mtetra
.47734 .49978 .48308 .50571 .49331 .5025 .4876 .49655 Mtetra
.4876 .49655 .49331 .5025 .50358 .49928 .49789 .4933 Mtetra
.49789 .4933 .50358 .49928 .51389 .49605 .50823 .49005 Mtetra
.50823 .49005 .51389 .49605 .52424 .4928 .5186 .48678 Mtetra
.5186 .48678 .52424 .4928 .53463 .48955 .52901 .4835 Mtetra
.52901 .4835 .53463 .48955 .54505 .48627 .53946 .4802 Mtetra
.53946 .4802 .54505 .48627 .55552 .48299 .54996 .4769 Mtetra
.54996 .4769 .55552 .48299 .56602 .4797 .56049 .47358 Mtetra
.56049 .47358 .56602 .4797 .57657 .47639 .57106 .47025 Mtetra
.57106 .47025 .57657 .47639 .58715 .47307 .58167 .46691 Mtetra
.58167 .46691 .58715 .47307 .59778 .46974 .59232 .46355 Mtetra
.59232 .46355 .59778 .46974 .60844 .46639 .60302 .46018 Mtetra
.60302 .46018 .60844 .46639 .61915 .46303 .61375 .4568 Mtetra
.61375 .4568 .61915 .46303 .6299 .45966 .62453 .4534 Mtetra
.62453 .4534 .6299 .45966 .64069 .45628 .63535 .44999 Mtetra
.63535 .44999 .64069 .45628 .65152 .45288 .64621 .44657 Mtetra
.64621 .44657 .65152 .45288 .66239 .44947 .65711 .44314 Mtetra
.65711 .44314 .66239 .44947 .67331 .44604 .66805 .43969 Mtetra
.66805 .43969 .67331 .44604 .68427 .44261 .67904 .43623 Mtetra
.67904 .43623 .68427 .44261 .69527 .43916 .69007 .43275 Mtetra
.69007 .43275 .69527 .43916 .70631 .43569 .70114 .42926 Mtetra
.70114 .42926 .70631 .43569 .7174 .43222 .71226 .42576 Mtetra
.71226 .42576 .7174 .43222 .72853 .42872 .72342 .42224 Mtetra
.72342 .42224 .72853 .42872 .7397 .42522 .73462 .41871 Mtetra
.73462 .41871 .7397 .42522 .75092 .4217 .74587 .41517 Mtetra
.74587 .41517 .75092 .4217 .76218 .41817 .75716 .41161 Mtetra
.75716 .41161 .76218 .41817 .77348 .41462 .7685 .40804 Mtetra
.7685 .40804 .77348 .41462 .78483 .41106 .77988 .40445 Mtetra
.77988 .40445 .78483 .41106 .79623 .40749 .79131 .40085 Mtetra
.79131 .40085 .79623 .40749 .80767 .4039 .80278 .39724 Mtetra
.80278 .39724 .80767 .4039 .81915 .4003 .8143 .39361 Mtetra
.8143 .39361 .81915 .4003 .83069 .39668 .82586 .38996 Mtetra
.82586 .38996 .83069 .39668 .84226 .39305 .83747 .38631 Mtetra
.83747 .38631 .84226 .39305 .85389 .3894 .84913 .38263 Mtetra
.84913 .38263 .85389 .3894 .86556 .38574 .86083 .37895 Mtetra
.86083 .37895 .86556 .38574 .87727 .38207 .87259 .37524 Mtetra
.24535 .5654 .25164 .57089 .26107 .56792 .2548 .56241 Mtetra
.2548 .56241 .26107 .56792 .27052 .56494 .26427 .55941 Mtetra
.26427 .55941 .27052 .56494 .28002 .56195 .27379 .5564 Mtetra
.27379 .5564 .28002 .56195 .28954 .55895 .28333 .55338 Mtetra
.28333 .55338 .28954 .55895 .2991 .55594 .29292 .55035 Mtetra
.29292 .55035 .2991 .55594 .3087 .55292 .30253 .5473 Mtetra
.30253 .5473 .3087 .55292 .31833 .54988 .31218 .54425 Mtetra
.31218 .54425 .31833 .54988 .328 .54684 .32187 .54118 Mtetra
.32187 .54118 .328 .54684 .3377 .54378 .3316 .53811 Mtetra
.3316 .53811 .3377 .54378 .34744 .54071 .34135 .53502 Mtetra
.34135 .53502 .34744 .54071 .35721 .53763 .35115 .53192 Mtetra
.35115 .53192 .35721 .53763 .36702 .53454 .36098 .52881 Mtetra
.36098 .52881 .36702 .53454 .37686 .53144 .37085 .52568 Mtetra
.37085 .52568 .37686 .53144 .38674 .52833 .38075 .52255 Mtetra
.38075 .52255 .38674 .52833 .39666 .5252 .39069 .5194 Mtetra
.39069 .5194 .39666 .5252 .40662 .52206 .40067 .51624 Mtetra
.40067 .51624 .40662 .52206 .41661 .51892 .41068 .51307 Mtetra
.41068 .51307 .41661 .51892 .42664 .51576 .42074 .50989 Mtetra
.42074 .50989 .42664 .51576 .4367 .51258 .43083 .5067 Mtetra
.43083 .5067 .4367 .51258 .44681 .5094 .44095 .50349 Mtetra
.44095 .50349 .44681 .5094 .45695 .50621 .45112 .50027 Mtetra
.45112 .50027 .45695 .50621 .46713 .503 .46132 .49704 Mtetra
.46132 .49704 .46713 .503 .47734 .49978 .47157 .4938 Mtetra
.47157 .4938 .47734 .49978 .4876 .49655 .48185 .49055 Mtetra
.48185 .49055 .4876 .49655 .49789 .4933 .49217 .48728 Mtetra
.49217 .48728 .49789 .4933 .50823 .49005 .50253 .484 Mtetra
.50253 .484 .50823 .49005 .5186 .48678 .51292 .48071 Mtetra
.51292 .48071 .5186 .48678 .52901 .4835 .52336 .47741 Mtetra
.52336 .47741 .52901 .4835 .53946 .4802 .53384 .47409 Mtetra
.53384 .47409 .53946 .4802 .54996 .4769 .54436 .47076 Mtetra
.54436 .47076 .54996 .4769 .56049 .47358 .55491 .46742 Mtetra
.55491 .46742 .56049 .47358 .57106 .47025 .56551 .46407 Mtetra
.56551 .46407 .57106 .47025 .58167 .46691 .57615 .4607 Mtetra
.57615 .4607 .58167 .46691 .59232 .46355 .58683 .45732 Mtetra
.58683 .45732 .59232 .46355 .60302 .46018 .59755 .45393 Mtetra
.59755 .45393 .60302 .46018 .61375 .4568 .60832 .45052 Mtetra
.60832 .45052 .61375 .4568 .62453 .4534 .61912 .4471 Mtetra
.61912 .4471 .62453 .4534 .63535 .44999 .62997 .44367 Mtetra
.62997 .44367 .63535 .44999 .64621 .44657 .64085 .44022 Mtetra
.64085 .44022 .64621 .44657 .65711 .44314 .65178 .43676 Mtetra
.65178 .43676 .65711 .44314 .66805 .43969 .66276 .43329 Mtetra
.66276 .43329 .66805 .43969 .67904 .43623 .67377 .4298 Mtetra
.67377 .4298 .67904 .43623 .69007 .43275 .68483 .4263 Mtetra
.68483 .4263 .69007 .43275 .70114 .42926 .69594 .42279 Mtetra
.69594 .42279 .70114 .42926 .71226 .42576 .70708 .41926 Mtetra
.70708 .41926 .71226 .42576 .72342 .42224 .71827 .41572 Mtetra
.71827 .41572 .72342 .42224 .73462 .41871 .72951 .41216 Mtetra
.72951 .41216 .73462 .41871 .74587 .41517 .74079 .40859 Mtetra
.74079 .40859 .74587 .41517 .75716 .41161 .75211 .40501 Mtetra
.75211 .40501 .75716 .41161 .7685 .40804 .76348 .40141 Mtetra
.76348 .40141 .7685 .40804 .77988 .40445 .77489 .39779 Mtetra
.77489 .39779 .77988 .40445 .79131 .40085 .78635 .39417 Mtetra
.78635 .39417 .79131 .40085 .80278 .39724 .79786 .39053 Mtetra
.79786 .39053 .80278 .39724 .8143 .39361 .80941 .38687 Mtetra
.80941 .38687 .8143 .39361 .82586 .38996 .821 .3832 Mtetra
.821 .3832 .82586 .38996 .83747 .38631 .83265 .37951 Mtetra
.83265 .37951 .83747 .38631 .84913 .38263 .84434 .37581 Mtetra
.84434 .37581 .84913 .38263 .86083 .37895 .85608 .3721 Mtetra
.85608 .3721 .86083 .37895 .87259 .37524 .86786 .36837 Mtetra
.23902 .55988 .24535 .5654 .2548 .56241 .24848 .55687 Mtetra
.24848 .55687 .2548 .56241 .26427 .55941 .25798 .55385 Mtetra
.25798 .55385 .26427 .55941 .27379 .5564 .26751 .55082 Mtetra
.26751 .55082 .27379 .5564 .28333 .55338 .27708 .54777 Mtetra
.27708 .54777 .28333 .55338 .29292 .55035 .28669 .54472 Mtetra
.28669 .54472 .29292 .55035 .30253 .5473 .29632 .54166 Mtetra
.29632 .54166 .30253 .5473 .31218 .54425 .306 .53858 Mtetra
.306 .53858 .31218 .54425 .32187 .54118 .31571 .53549 Mtetra
.31571 .53549 .32187 .54118 .3316 .53811 .32545 .53239 Mtetra
.32545 .53239 .3316 .53811 .34135 .53502 .33523 .52928 Mtetra
.33523 .52928 .34135 .53502 .35115 .53192 .34505 .52616 Mtetra
.34505 .52616 .35115 .53192 .36098 .52881 .3549 .52303 Mtetra
.3549 .52303 .36098 .52881 .37085 .52568 .36479 .51989 Mtetra
.36479 .51989 .37085 .52568 .38075 .52255 .37472 .51673 Mtetra
.37472 .51673 .38075 .52255 .39069 .5194 .38468 .51356 Mtetra
.38468 .51356 .39069 .5194 .40067 .51624 .39468 .51038 Mtetra
.39468 .51038 .40067 .51624 .41068 .51307 .40472 .50719 Mtetra
.40472 .50719 .41068 .51307 .42074 .50989 .4148 .50399 Mtetra
.4148 .50399 .42074 .50989 .43083 .5067 .42491 .50077 Mtetra
.42491 .50077 .43083 .5067 .44095 .50349 .43506 .49754 Mtetra
.43506 .49754 .44095 .50349 .45112 .50027 .44525 .4943 Mtetra
.44525 .4943 .45112 .50027 .46132 .49704 .45548 .49105 Mtetra
.45548 .49105 .46132 .49704 .47157 .4938 .46575 .48779 Mtetra
.46575 .48779 .47157 .4938 .48185 .49055 .47605 .48451 Mtetra
.47605 .48451 .48185 .49055 .49217 .48728 .4864 .48122 Mtetra
.4864 .48122 .49217 .48728 .50253 .484 .49678 .47792 Mtetra
.49678 .47792 .50253 .484 .51292 .48071 .50721 .4746 Mtetra
.50721 .4746 .51292 .48071 .52336 .47741 .51767 .47128 Mtetra
.51767 .47128 .52336 .47741 .53384 .47409 .52817 .46794 Mtetra
.52817 .46794 .53384 .47409 .54436 .47076 .53872 .46458 Mtetra
.53872 .46458 .54436 .47076 .55491 .46742 .5493 .46122 Mtetra
.5493 .46122 .55491 .46742 .56551 .46407 .55993 .45784 Mtetra
.55993 .45784 .56551 .46407 .57615 .4607 .57059 .45445 Mtetra
.57059 .45445 .57615 .4607 .58683 .45732 .5813 .45104 Mtetra
.5813 .45104 .58683 .45732 .59755 .45393 .59205 .44763 Mtetra
.59205 .44763 .59755 .45393 .60832 .45052 .60284 .4442 Mtetra
.60284 .4442 .60832 .45052 .61912 .4471 .61367 .44075 Mtetra
.61367 .44075 .61912 .4471 .62997 .44367 .62455 .43729 Mtetra
.62455 .43729 .62997 .44367 .64085 .44022 .63546 .43382 Mtetra
.63546 .43382 .64085 .44022 .65178 .43676 .64642 .43034 Mtetra
.64642 .43034 .65178 .43676 .66276 .43329 .65743 .42684 Mtetra
.65743 .42684 .66276 .43329 .67377 .4298 .66847 .42333 Mtetra
.66847 .42333 .67377 .4298 .68483 .4263 .67956 .4198 Mtetra
.67956 .4198 .68483 .4263 .69594 .42279 .69069 .41626 Mtetra
.69069 .41626 .69594 .42279 .70708 .41926 .70187 .41271 Mtetra
.70187 .41271 .70708 .41926 .71827 .41572 .71309 .40914 Mtetra
.71309 .40914 .71827 .41572 .72951 .41216 .72436 .40556 Mtetra
.72436 .40556 .72951 .41216 .74079 .40859 .73566 .40196 Mtetra
.73566 .40196 .74079 .40859 .75211 .40501 .74702 .39835 Mtetra
.74702 .39835 .75211 .40501 .76348 .40141 .75842 .39473 Mtetra
.75842 .39473 .76348 .40141 .77489 .39779 .76987 .39109 Mtetra
.76987 .39109 .77489 .39779 .78635 .39417 .78136 .38743 Mtetra
.78136 .38743 .78635 .39417 .79786 .39053 .79289 .38376 Mtetra
.79289 .38376 .79786 .39053 .80941 .38687 .80448 .38008 Mtetra
.80448 .38008 .80941 .38687 .821 .3832 .81611 .37638 Mtetra
.81611 .37638 .821 .3832 .83265 .37951 .82779 .37267 Mtetra
.82779 .37267 .83265 .37951 .84434 .37581 .83951 .36894 Mtetra
.83951 .36894 .84434 .37581 .85608 .3721 .85128 .3652 Mtetra
.85128 .3652 .85608 .3721 .86786 .36837 .8631 .36144 Mtetra
.23264 .55431 .23902 .55988 .24848 .55687 .24213 .55128 Mtetra
.24213 .55128 .24848 .55687 .25798 .55385 .25165 .54824 Mtetra
.25165 .54824 .25798 .55385 .26751 .55082 .2612 .54519 Mtetra
.2612 .54519 .26751 .55082 .27708 .54777 .27079 .54213 Mtetra
.27079 .54213 .27708 .54777 .28669 .54472 .28041 .53905 Mtetra
.28041 .53905 .28669 .54472 .29632 .54166 .29007 .53597 Mtetra
.29007 .53597 .29632 .54166 .306 .53858 .29977 .53287 Mtetra
.29977 .53287 .306 .53858 .31571 .53549 .3095 .52976 Mtetra
.3095 .52976 .31571 .53549 .32545 .53239 .31926 .52664 Mtetra
.31926 .52664 .32545 .53239 .33523 .52928 .32907 .52351 Mtetra
.32907 .52351 .33523 .52928 .34505 .52616 .33891 .52037 Mtetra
.33891 .52037 .34505 .52616 .3549 .52303 .34878 .51722 Mtetra
.34878 .51722 .3549 .52303 .36479 .51989 .35869 .51405 Mtetra
.35869 .51405 .36479 .51989 .37472 .51673 .36864 .51087 Mtetra
.36864 .51087 .37472 .51673 .38468 .51356 .37863 .50768 Mtetra
.37863 .50768 .38468 .51356 .39468 .51038 .38865 .50448 Mtetra
.38865 .50448 .39468 .51038 .40472 .50719 .39872 .50127 Mtetra
.39872 .50127 .40472 .50719 .4148 .50399 .40882 .49804 Mtetra
.40882 .49804 .4148 .50399 .42491 .50077 .41895 .4948 Mtetra
.41895 .4948 .42491 .50077 .43506 .49754 .42913 .49155 Mtetra
.42913 .49155 .43506 .49754 .44525 .4943 .43934 .48829 Mtetra
.43934 .48829 .44525 .4943 .45548 .49105 .4496 .48501 Mtetra
.4496 .48501 .45548 .49105 .46575 .48779 .45989 .48173 Mtetra
.45989 .48173 .46575 .48779 .47605 .48451 .47022 .47843 Mtetra
.47022 .47843 .47605 .48451 .4864 .48122 .48059 .47511 Mtetra
.48059 .47511 .4864 .48122 .49678 .47792 .491 .47179 Mtetra
.491 .47179 .49678 .47792 .50721 .4746 .50145 .46845 Mtetra
.50145 .46845 .50721 .4746 .51767 .47128 .51194 .4651 Mtetra
.51194 .4651 .51767 .47128 .52817 .46794 .52247 .46174 Mtetra
.52247 .46174 .52817 .46794 .53872 .46458 .53304 .45836 Mtetra
.53304 .45836 .53872 .46458 .5493 .46122 .54365 .45497 Mtetra
.54365 .45497 .5493 .46122 .55993 .45784 .5543 .45157 Mtetra
.5543 .45157 .55993 .45784 .57059 .45445 .565 .44815 Mtetra
.565 .44815 .57059 .45445 .5813 .45104 .57573 .44472 Mtetra
.57573 .44472 .5813 .45104 .59205 .44763 .58651 .44128 Mtetra
.58651 .44128 .59205 .44763 .60284 .4442 .59732 .43783 Mtetra
.59732 .43783 .60284 .4442 .61367 .44075 .60819 .43436 Mtetra
.60819 .43436 .61367 .44075 .62455 .43729 .61909 .43087 Mtetra
.61909 .43087 .62455 .43729 .63546 .43382 .63003 .42738 Mtetra
.63003 .42738 .63546 .43382 .64642 .43034 .64102 .42387 Mtetra
.64102 .42387 .64642 .43034 .65743 .42684 .65205 .42034 Mtetra
.65205 .42034 .65743 .42684 .66847 .42333 .66313 .41681 Mtetra
.66313 .41681 .66847 .42333 .67956 .4198 .67425 .41326 Mtetra
.67425 .41326 .67956 .4198 .69069 .41626 .68541 .40969 Mtetra
.68541 .40969 .69069 .41626 .70187 .41271 .69662 .40611 Mtetra
.69662 .40611 .70187 .41271 .71309 .40914 .70787 .40252 Mtetra
.70787 .40252 .71309 .40914 .72436 .40556 .71917 .39891 Mtetra
.71917 .39891 .72436 .40556 .73566 .40196 .73051 .39529 Mtetra
.73051 .39529 .73566 .40196 .74702 .39835 .74189 .39165 Mtetra
.74189 .39165 .74702 .39835 .75842 .39473 .75332 .388 Mtetra
.75332 .388 .75842 .39473 .76987 .39109 .7648 .38433 Mtetra
.7648 .38433 .76987 .39109 .78136 .38743 .77633 .38065 Mtetra
.77633 .38065 .78136 .38743 .79289 .38376 .7879 .37695 Mtetra
.7879 .37695 .79289 .38376 .80448 .38008 .79951 .37324 Mtetra
.79951 .37324 .80448 .38008 .81611 .37638 .81118 .36952 Mtetra
.81118 .36952 .81611 .37638 .82779 .37267 .82289 .36578 Mtetra
.82289 .36578 .82779 .37267 .83951 .36894 .83465 .36202 Mtetra
.83465 .36202 .83951 .36894 .85128 .3652 .84645 .35825 Mtetra
.84645 .35825 .85128 .3652 .8631 .36144 .85831 .35446 Mtetra
.22623 .54871 .23264 .55431 .24213 .55128 .23573 .54566 Mtetra
.23573 .54566 .24213 .55128 .25165 .54824 .24527 .5426 Mtetra
.24527 .5426 .25165 .54824 .2612 .54519 .25484 .53953 Mtetra
.25484 .53953 .2612 .54519 .27079 .54213 .26445 .53644 Mtetra
.26445 .53644 .27079 .54213 .28041 .53905 .2741 .53335 Mtetra
.2741 .53335 .28041 .53905 .29007 .53597 .28378 .53024 Mtetra
.28378 .53024 .29007 .53597 .29977 .53287 .2935 .52712 Mtetra
.2935 .52712 .29977 .53287 .3095 .52976 .30325 .524 Mtetra
.30325 .524 .3095 .52976 .31926 .52664 .31304 .52085 Mtetra
.31304 .52085 .31926 .52664 .32907 .52351 .32286 .5177 Mtetra
.32286 .5177 .32907 .52351 .33891 .52037 .33272 .51454 Mtetra
.33272 .51454 .33891 .52037 .34878 .51722 .34262 .51136 Mtetra
.34262 .51136 .34878 .51722 .35869 .51405 .35256 .50817 Mtetra
.35256 .50817 .35869 .51405 .36864 .51087 .36253 .50497 Mtetra
.36253 .50497 .36864 .51087 .37863 .50768 .37254 .50176 Mtetra
.37254 .50176 .37863 .50768 .38865 .50448 .38258 .49854 Mtetra
.38258 .49854 .38865 .50448 .39872 .50127 .39267 .4953 Mtetra
.39267 .4953 .39872 .50127 .40882 .49804 .40279 .49205 Mtetra
.40279 .49205 .40882 .49804 .41895 .4948 .41295 .48879 Mtetra
.41295 .48879 .41895 .4948 .42913 .49155 .42315 .48552 Mtetra
.42315 .48552 .42913 .49155 .43934 .48829 .43339 .48223 Mtetra
.43339 .48223 .43934 .48829 .4496 .48501 .44367 .47893 Mtetra
.44367 .47893 .4496 .48501 .45989 .48173 .45399 .47562 Mtetra
.45399 .47562 .45989 .48173 .47022 .47843 .46434 .4723 Mtetra
.46434 .4723 .47022 .47843 .48059 .47511 .47474 .46897 Mtetra
.47474 .46897 .48059 .47511 .491 .47179 .48517 .46562 Mtetra
.48517 .46562 .491 .47179 .50145 .46845 .49565 .46226 Mtetra
.49565 .46226 .50145 .46845 .51194 .4651 .50617 .45888 Mtetra
.50617 .45888 .51194 .4651 .52247 .46174 .51672 .45549 Mtetra
.51672 .45549 .52247 .46174 .53304 .45836 .52732 .45209 Mtetra
.52732 .45209 .53304 .45836 .54365 .45497 .53796 .44868 Mtetra
.53796 .44868 .54365 .45497 .5543 .45157 .54864 .44525 Mtetra
.54864 .44525 .5543 .45157 .565 .44815 .55936 .44181 Mtetra
.55936 .44181 .565 .44815 .57573 .44472 .57012 .43836 Mtetra
.57012 .43836 .57573 .44472 .58651 .44128 .58092 .43489 Mtetra
.58092 .43489 .58651 .44128 .59732 .43783 .59177 .43141 Mtetra
.59177 .43141 .59732 .43783 .60819 .43436 .60266 .42792 Mtetra
.60266 .42792 .60819 .43436 .61909 .43087 .61359 .42441 Mtetra
.61359 .42441 .61909 .43087 .63003 .42738 .62456 .42089 Mtetra
.62456 .42089 .63003 .42738 .64102 .42387 .63558 .41735 Mtetra
.63558 .41735 .64102 .42387 .65205 .42034 .64664 .4138 Mtetra
.64664 .4138 .65205 .42034 .66313 .41681 .65775 .41024 Mtetra
.65775 .41024 .66313 .41681 .67425 .41326 .6689 .40666 Mtetra
.6689 .40666 .67425 .41326 .68541 .40969 .68009 .40307 Mtetra
.68009 .40307 .68541 .40969 .69662 .40611 .69133 .39946 Mtetra
.69133 .39946 .69662 .40611 .70787 .40252 .70261 .39584 Mtetra
.70261 .39584 .70787 .40252 .71917 .39891 .71394 .39221 Mtetra
.71394 .39221 .71917 .39891 .73051 .39529 .72531 .38856 Mtetra
.72531 .38856 .73051 .39529 .74189 .39165 .73673 .3849 Mtetra
.73673 .3849 .74189 .39165 .75332 .388 .74819 .38122 Mtetra
.74819 .38122 .75332 .388 .7648 .38433 .7597 .37752 Mtetra
.7597 .37752 .7648 .38433 .77633 .38065 .77126 .37381 Mtetra
.77126 .37381 .77633 .38065 .7879 .37695 .78286 .37009 Mtetra
.78286 .37009 .7879 .37695 .79951 .37324 .79451 .36635 Mtetra
.79451 .36635 .79951 .37324 .81118 .36952 .80621 .3626 Mtetra
.80621 .3626 .81118 .36952 .82289 .36578 .81795 .35883 Mtetra
.81795 .35883 .82289 .36578 .83465 .36202 .82975 .35505 Mtetra
.82975 .35505 .83465 .36202 .84645 .35825 .84159 .35125 Mtetra
.84159 .35125 .84645 .35825 .85831 .35446 .85348 .34743 Mtetra
.21976 .54307 .22623 .54871 .23573 .54566 .22929 .54 Mtetra
.22929 .54 .23573 .54566 .24527 .5426 .23885 .53692 Mtetra
.23885 .53692 .24527 .5426 .25484 .53953 .24844 .53383 Mtetra
.24844 .53383 .25484 .53953 .26445 .53644 .25807 .53072 Mtetra
.25807 .53072 .26445 .53644 .2741 .53335 .26774 .52761 Mtetra
.26774 .52761 .2741 .53335 .28378 .53024 .27744 .52448 Mtetra
.27744 .52448 .28378 .53024 .2935 .52712 .28718 .52134 Mtetra
.28718 .52134 .2935 .52712 .30325 .524 .29695 .51819 Mtetra
.29695 .51819 .30325 .524 .31304 .52085 .30676 .51503 Mtetra
.30676 .51503 .31304 .52085 .32286 .5177 .31661 .51185 Mtetra
.31661 .51185 .32286 .5177 .33272 .51454 .3265 .50866 Mtetra
.3265 .50866 .33272 .51454 .34262 .51136 .33642 .50547 Mtetra
.33642 .50547 .34262 .51136 .35256 .50817 .34637 .50226 Mtetra
.34637 .50226 .35256 .50817 .36253 .50497 .35637 .49903 Mtetra
.35637 .49903 .36253 .50497 .37254 .50176 .3664 .4958 Mtetra
.3664 .4958 .37254 .50176 .38258 .49854 .37647 .49255 Mtetra
.37647 .49255 .38258 .49854 .39267 .4953 .38658 .48929 Mtetra
.38658 .48929 .39267 .4953 .40279 .49205 .39673 .48602 Mtetra
.39673 .48602 .40279 .49205 .41295 .48879 .40691 .48274 Mtetra
.40691 .48274 .41295 .48879 .42315 .48552 .41714 .47944 Mtetra
.41714 .47944 .42315 .48552 .43339 .48223 .4274 .47613 Mtetra
.4274 .47613 .43339 .48223 .44367 .47893 .4377 .47281 Mtetra
.4377 .47281 .44367 .47893 .45399 .47562 .44805 .46948 Mtetra
.44805 .46948 .45399 .47562 .46434 .4723 .45843 .46613 Mtetra
.45843 .46613 .46434 .4723 .47474 .46897 .46885 .46277 Mtetra
.46885 .46277 .47474 .46897 .48517 .46562 .47931 .4594 Mtetra
.47931 .4594 .48517 .46562 .49565 .46226 .48981 .45602 Mtetra
.48981 .45602 .49565 .46226 .50617 .45888 .50035 .45262 Mtetra
.50035 .45262 .50617 .45888 .51672 .45549 .51093 .44921 Mtetra
.51093 .44921 .51672 .45549 .52732 .45209 .52156 .44578 Mtetra
.52156 .44578 .52732 .45209 .53796 .44868 .53222 .44234 Mtetra
.53222 .44234 .53796 .44868 .54864 .44525 .54293 .43889 Mtetra
.54293 .43889 .54864 .44525 .55936 .44181 .55368 .43543 Mtetra
.55368 .43543 .55936 .44181 .57012 .43836 .56447 .43195 Mtetra
.56447 .43195 .57012 .43836 .58092 .43489 .5753 .42846 Mtetra
.5753 .42846 .58092 .43489 .59177 .43141 .58617 .42495 Mtetra
.58617 .42495 .59177 .43141 .60266 .42792 .59709 .42143 Mtetra
.59709 .42143 .60266 .42792 .61359 .42441 .60805 .4179 Mtetra
.60805 .4179 .61359 .42441 .62456 .42089 .61906 .41435 Mtetra
.61906 .41435 .62456 .42089 .63558 .41735 .6301 .41079 Mtetra
.6301 .41079 .63558 .41735 .64664 .4138 .64119 .40721 Mtetra
.64119 .40721 .64664 .4138 .65775 .41024 .65233 .40362 Mtetra
.65233 .40362 .65775 .41024 .6689 .40666 .66351 .40002 Mtetra
.66351 .40002 .6689 .40666 .68009 .40307 .67473 .3964 Mtetra
.67473 .3964 .68009 .40307 .69133 .39946 .686 .39277 Mtetra
.686 .39277 .69133 .39946 .70261 .39584 .69731 .38912 Mtetra
.69731 .38912 .70261 .39584 .71394 .39221 .70867 .38546 Mtetra
.70867 .38546 .71394 .39221 .72531 .38856 .72007 .38178 Mtetra
.72007 .38178 .72531 .38856 .73673 .3849 .73152 .37809 Mtetra
.73152 .37809 .73673 .3849 .74819 .38122 .74302 .37439 Mtetra
.74302 .37439 .74819 .38122 .7597 .37752 .75456 .37067 Mtetra
.75456 .37067 .7597 .37752 .77126 .37381 .76615 .36693 Mtetra
.76615 .36693 .77126 .37381 .78286 .37009 .77779 .36318 Mtetra
.77779 .36318 .78286 .37009 .79451 .36635 .78947 .35941 Mtetra
.78947 .35941 .79451 .36635 .80621 .3626 .8012 .35563 Mtetra
.8012 .35563 .80621 .3626 .81795 .35883 .81298 .35183 Mtetra
.81298 .35183 .81795 .35883 .82975 .35505 .82481 .34802 Mtetra
.82481 .34802 .82975 .35505 .84159 .35125 .83668 .34419 Mtetra
.83668 .34419 .84159 .35125 .85348 .34743 .84861 .34035 Mtetra
.21326 .53739 .21976 .54307 .22929 .54 .2228 .5343 Mtetra
.2228 .5343 .22929 .54 .23885 .53692 .23238 .5312 Mtetra
.23238 .5312 .23885 .53692 .24844 .53383 .242 .52809 Mtetra
.242 .52809 .24844 .53383 .25807 .53072 .25165 .52496 Mtetra
.25165 .52496 .25807 .53072 .26774 .52761 .26134 .52182 Mtetra
.26134 .52182 .26774 .52761 .27744 .52448 .27106 .51867 Mtetra
.27106 .51867 .27744 .52448 .28718 .52134 .28082 .51551 Mtetra
.28082 .51551 .28718 .52134 .29695 .51819 .29062 .51234 Mtetra
.29062 .51234 .29695 .51819 .30676 .51503 .30045 .50916 Mtetra
.30045 .50916 .30676 .51503 .31661 .51185 .31032 .50596 Mtetra
.31032 .50596 .31661 .51185 .3265 .50866 .32022 .50275 Mtetra
.32022 .50275 .3265 .50866 .33642 .50547 .33017 .49953 Mtetra
.33017 .49953 .33642 .50547 .34637 .50226 .34015 .4963 Mtetra
.34015 .4963 .34637 .50226 .35637 .49903 .35017 .49305 Mtetra
.35017 .49305 .35637 .49903 .3664 .4958 .36022 .4898 Mtetra
.36022 .4898 .3664 .4958 .37647 .49255 .37032 .48653 Mtetra
.37032 .48653 .37647 .49255 .38658 .48929 .38045 .48325 Mtetra
.38045 .48325 .38658 .48929 .39673 .48602 .39062 .47995 Mtetra
.39062 .47995 .39673 .48602 .40691 .48274 .40083 .47664 Mtetra
.40083 .47664 .40691 .48274 .41714 .47944 .41108 .47333 Mtetra
.41108 .47333 .41714 .47944 .4274 .47613 .42137 .46999 Mtetra
.42137 .46999 .4274 .47613 .4377 .47281 .43169 .46665 Mtetra
.43169 .46665 .4377 .47281 .44805 .46948 .44206 .46329 Mtetra
.44206 .46329 .44805 .46948 .45843 .46613 .45247 .45992 Mtetra
.45247 .45992 .45843 .46613 .46885 .46277 .46291 .45654 Mtetra
.46291 .45654 .46885 .46277 .47931 .4594 .4734 .45314 Mtetra
.4734 .45314 .47931 .4594 .48981 .45602 .48393 .44973 Mtetra
.48393 .44973 .48981 .45602 .50035 .45262 .4945 .44631 Mtetra
.4945 .44631 .50035 .45262 .51093 .44921 .50511 .44287 Mtetra
.50511 .44287 .51093 .44921 .52156 .44578 .51576 .43942 Mtetra
.51576 .43942 .52156 .44578 .53222 .44234 .52645 .43596 Mtetra
.52645 .43596 .53222 .44234 .54293 .43889 .53718 .43248 Mtetra
.53718 .43248 .54293 .43889 .55368 .43543 .54796 .42899 Mtetra
.54796 .42899 .55368 .43543 .56447 .43195 .55878 .42549 Mtetra
.55878 .42549 .56447 .43195 .5753 .42846 .56964 .42197 Mtetra
.56964 .42197 .5753 .42846 .58617 .42495 .58054 .41844 Mtetra
.58054 .41844 .58617 .42495 .59709 .42143 .59149 .4149 Mtetra
.59149 .4149 .59709 .42143 .60805 .4179 .60247 .41134 Mtetra
.60247 .41134 .60805 .4179 .61906 .41435 .61351 .40776 Mtetra
.61351 .40776 .61906 .41435 .6301 .41079 .62458 .40418 Mtetra
.62458 .40418 .6301 .41079 .64119 .40721 .6357 .40057 Mtetra
.6357 .40057 .64119 .40721 .65233 .40362 .64687 .39696 Mtetra
.64687 .39696 .65233 .40362 .66351 .40002 .65808 .39333 Mtetra
.65808 .39333 .66351 .40002 .67473 .3964 .66933 .38968 Mtetra
.66933 .38968 .67473 .3964 .686 .39277 .68063 .38602 Mtetra
.68063 .38602 .686 .39277 .69731 .38912 .69198 .38235 Mtetra
.69198 .38235 .69731 .38912 .70867 .38546 .70336 .37866 Mtetra
.70336 .37866 .70867 .38546 .72007 .38178 .7148 .37496 Mtetra
.7148 .37496 .72007 .38178 .73152 .37809 .72628 .37124 Mtetra
.72628 .37124 .73152 .37809 .74302 .37439 .73781 .3675 Mtetra
.73781 .3675 .74302 .37439 .75456 .37067 .74939 .36376 Mtetra
.74939 .36376 .75456 .37067 .76615 .36693 .76101 .35999 Mtetra
.76101 .35999 .76615 .36693 .77779 .36318 .77268 .35621 Mtetra
.77268 .35621 .77779 .36318 .78947 .35941 .78439 .35242 Mtetra
.78439 .35242 .78947 .35941 .8012 .35563 .79616 .34861 Mtetra
.79616 .34861 .8012 .35563 .81298 .35183 .80797 .34478 Mtetra
.80797 .34478 .81298 .35183 .82481 .34802 .81983 .34094 Mtetra
.81983 .34094 .82481 .34802 .83668 .34419 .83174 .33708 Mtetra
.83174 .33708 .83668 .34419 .84861 .34035 .8437 .33321 Mtetra
.20671 .53168 .21326 .53739 .2228 .5343 .21628 .52857 Mtetra
.21628 .52857 .2228 .5343 .23238 .5312 .22588 .52544 Mtetra
.22588 .52544 .23238 .5312 .242 .52809 .23551 .52231 Mtetra
.23551 .52231 .242 .52809 .25165 .52496 .24519 .51916 Mtetra
.24519 .51916 .25165 .52496 .26134 .52182 .25489 .516 Mtetra
.25489 .516 .26134 .52182 .27106 .51867 .26464 .51283 Mtetra
.26464 .51283 .27106 .51867 .28082 .51551 .27442 .50965 Mtetra
.27442 .50965 .28082 .51551 .29062 .51234 .28424 .50645 Mtetra
.28424 .50645 .29062 .51234 .30045 .50916 .29409 .50324 Mtetra
.29409 .50324 .30045 .50916 .31032 .50596 .30398 .50003 Mtetra
.30398 .50003 .31032 .50596 .32022 .50275 .31391 .4968 Mtetra
.31391 .4968 .32022 .50275 .33017 .49953 .32388 .49355 Mtetra
.32388 .49355 .33017 .49953 .34015 .4963 .33388 .4903 Mtetra
.33388 .4903 .34015 .4963 .35017 .49305 .34392 .48703 Mtetra
.34392 .48703 .35017 .49305 .36022 .4898 .354 .48375 Mtetra
.354 .48375 .36022 .4898 .37032 .48653 .36412 .48046 Mtetra
.36412 .48046 .37032 .48653 .38045 .48325 .37428 .47715 Mtetra
.37428 .47715 .38045 .48325 .39062 .47995 .38447 .47384 Mtetra
.38447 .47384 .39062 .47995 .40083 .47664 .3947 .47051 Mtetra
.3947 .47051 .40083 .47664 .41108 .47333 .40498 .46716 Mtetra
.40498 .46716 .41108 .47333 .42137 .46999 .41529 .46381 Mtetra
.41529 .46381 .42137 .46999 .43169 .46665 .42564 .46044 Mtetra
.42564 .46044 .43169 .46665 .44206 .46329 .43603 .45706 Mtetra
.43603 .45706 .44206 .46329 .45247 .45992 .44647 .45366 Mtetra
.44647 .45366 .45247 .45992 .46291 .45654 .45694 .45026 Mtetra
.45694 .45026 .46291 .45654 .4734 .45314 .46745 .44684 Mtetra
.46745 .44684 .4734 .45314 .48393 .44973 .47801 .4434 Mtetra
.47801 .4434 .48393 .44973 .4945 .44631 .4886 .43995 Mtetra
.4886 .43995 .4945 .44631 .50511 .44287 .49924 .43649 Mtetra
.49924 .43649 .50511 .44287 .51576 .43942 .50991 .43302 Mtetra
.50991 .43302 .51576 .43942 .52645 .43596 .52063 .42953 Mtetra
.52063 .42953 .52645 .43596 .53718 .43248 .53139 .42603 Mtetra
.53139 .42603 .53718 .43248 .54796 .42899 .5422 .42251 Mtetra
.5422 .42251 .54796 .42899 .55878 .42549 .55304 .41899 Mtetra
.55304 .41899 .55878 .42549 .56964 .42197 .56393 .41544 Mtetra
.56393 .41544 .56964 .42197 .58054 .41844 .57486 .41189 Mtetra
.57486 .41189 .58054 .41844 .59149 .4149 .58584 .40831 Mtetra
.58584 .40831 .59149 .4149 .60247 .41134 .59686 .40473 Mtetra
.59686 .40473 .60247 .41134 .61351 .40776 .60792 .40113 Mtetra
.60792 .40113 .61351 .40776 .62458 .40418 .61902 .39752 Mtetra
.61902 .39752 .62458 .40418 .6357 .40057 .63017 .39389 Mtetra
.63017 .39389 .6357 .40057 .64687 .39696 .64137 .39025 Mtetra
.64137 .39025 .64687 .39696 .65808 .39333 .65261 .38659 Mtetra
.65261 .38659 .65808 .39333 .66933 .38968 .66389 .38292 Mtetra
.66389 .38292 .66933 .38968 .68063 .38602 .67522 .37923 Mtetra
.67522 .37923 .68063 .38602 .69198 .38235 .6866 .37553 Mtetra
.6866 .37553 .69198 .38235 .70336 .37866 .69802 .37181 Mtetra
.69802 .37181 .70336 .37866 .7148 .37496 .70949 .36808 Mtetra
.70949 .36808 .7148 .37496 .72628 .37124 .721 .36433 Mtetra
.721 .36433 .72628 .37124 .73781 .3675 .73256 .36057 Mtetra
.73256 .36057 .73781 .3675 .74939 .36376 .74417 .35679 Mtetra
.74417 .35679 .74939 .36376 .76101 .35999 .75583 .353 Mtetra
.75583 .353 .76101 .35999 .77268 .35621 .76753 .34919 Mtetra
.76753 .34919 .77268 .35621 .78439 .35242 .77928 .34537 Mtetra
.77928 .34537 .78439 .35242 .79616 .34861 .79108 .34153 Mtetra
.79108 .34153 .79616 .34861 .80797 .34478 .80293 .33768 Mtetra
.80293 .33768 .80797 .34478 .81983 .34094 .81482 .33381 Mtetra
.81482 .33381 .81983 .34094 .83174 .33708 .82677 .32992 Mtetra
.82677 .32992 .83174 .33708 .8437 .33321 .83876 .32602 Mtetra
.20012 .52592 .20671 .53168 .21628 .52857 .2097 .52279 Mtetra
.2097 .52279 .21628 .52857 .22588 .52544 .21932 .51964 Mtetra
.21932 .51964 .22588 .52544 .23551 .52231 .22898 .51649 Mtetra
.22898 .51649 .23551 .52231 .24519 .51916 .23867 .51332 Mtetra
.23867 .51332 .24519 .51916 .25489 .516 .2484 .51014 Mtetra
.2484 .51014 .25489 .516 .26464 .51283 .25817 .50694 Mtetra
.25817 .50694 .26464 .51283 .27442 .50965 .26797 .50374 Mtetra
.26797 .50374 .27442 .50965 .28424 .50645 .27781 .50052 Mtetra
.27781 .50052 .28424 .50645 .29409 .50324 .28769 .49729 Mtetra
.28769 .49729 .29409 .50324 .30398 .50003 .2976 .49405 Mtetra
.2976 .49405 .30398 .50003 .31391 .4968 .30755 .4908 Mtetra
.30755 .4908 .31391 .4968 .32388 .49355 .31754 .48753 Mtetra
.31754 .48753 .32388 .49355 .33388 .4903 .32757 .48426 Mtetra
.32757 .48426 .33388 .4903 .34392 .48703 .33763 .48097 Mtetra
.33763 .48097 .34392 .48703 .354 .48375 .34774 .47766 Mtetra
.34774 .47766 .354 .48375 .36412 .48046 .35788 .47435 Mtetra
.35788 .47435 .36412 .48046 .37428 .47715 .36806 .47102 Mtetra
.36806 .47102 .37428 .47715 .38447 .47384 .37828 .46768 Mtetra
.37828 .46768 .38447 .47384 .3947 .47051 .38854 .46433 Mtetra
.38854 .46433 .3947 .47051 .40498 .46716 .39883 .46096 Mtetra
.39883 .46096 .40498 .46716 .41529 .46381 .40917 .45758 Mtetra
.40917 .45758 .41529 .46381 .42564 .46044 .41955 .45419 Mtetra
.41955 .45419 .42564 .46044 .43603 .45706 .42996 .45078 Mtetra
.42996 .45078 .43603 .45706 .44647 .45366 .44042 .44736 Mtetra
.44042 .44736 .44647 .45366 .45694 .45026 .45092 .44393 Mtetra
.45092 .44393 .45694 .45026 .46745 .44684 .46146 .44049 Mtetra
.46146 .44049 .46745 .44684 .47801 .4434 .47204 .43703 Mtetra
.47204 .43703 .47801 .4434 .4886 .43995 .48266 .43355 Mtetra
.48266 .43355 .4886 .43995 .49924 .43649 .49332 .43007 Mtetra
.49332 .43007 .49924 .43649 .50991 .43302 .50403 .42657 Mtetra
.50403 .42657 .50991 .43302 .52063 .42953 .51477 .42306 Mtetra
.51477 .42306 .52063 .42953 .53139 .42603 .52556 .41953 Mtetra
.52556 .41953 .53139 .42603 .5422 .42251 .53639 .41599 Mtetra
.53639 .41599 .5422 .42251 .55304 .41899 .54727 .41243 Mtetra
.54727 .41243 .55304 .41899 .56393 .41544 .55818 .40886 Mtetra
.55818 .40886 .56393 .41544 .57486 .41189 .56914 .40528 Mtetra
.56914 .40528 .57486 .41189 .58584 .40831 .58015 .40168 Mtetra
.58015 .40168 .58584 .40831 .59686 .40473 .5912 .39807 Mtetra
.5912 .39807 .59686 .40473 .60792 .40113 .60229 .39445 Mtetra
.60229 .39445 .60792 .40113 .61902 .39752 .61342 .39081 Mtetra
.61342 .39081 .61902 .39752 .63017 .39389 .6246 .38715 Mtetra
.6246 .38715 .63017 .39389 .64137 .39025 .63583 .38348 Mtetra
.63583 .38348 .64137 .39025 .65261 .38659 .6471 .3798 Mtetra
.6471 .3798 .65261 .38659 .66389 .38292 .65841 .3761 Mtetra
.65841 .3761 .66389 .38292 .67522 .37923 .66977 .37238 Mtetra
.66977 .37238 .67522 .37923 .6866 .37553 .68118 .36866 Mtetra
.68118 .36866 .6866 .37553 .69802 .37181 .69263 .36491 Mtetra
.69263 .36491 .69802 .37181 .70949 .36808 .70413 .36115 Mtetra
.70413 .36115 .70949 .36808 .721 .36433 .71568 .35738 Mtetra
.71568 .35738 .721 .36433 .73256 .36057 .72727 .35359 Mtetra
.72727 .35359 .73256 .36057 .74417 .35679 .73892 .34978 Mtetra
.73892 .34978 .74417 .35679 .75583 .353 .7506 .34596 Mtetra
.7506 .34596 .75583 .353 .76753 .34919 .76234 .34212 Mtetra
.76234 .34212 .76753 .34919 .77928 .34537 .77412 .33827 Mtetra
.77412 .33827 .77928 .34537 .79108 .34153 .78596 .3344 Mtetra
.78596 .3344 .79108 .34153 .80293 .33768 .79784 .33052 Mtetra
.79784 .33052 .80293 .33768 .81482 .33381 .80977 .32662 Mtetra
.80977 .32662 .81482 .33381 .82677 .32992 .82175 .3227 Mtetra
.82175 .3227 .82677 .32992 .83876 .32602 .83378 .31877 Mtetra
.19348 .52013 .20012 .52592 .2097 .52279 .20308 .51697 Mtetra
.20308 .51697 .2097 .52279 .21932 .51964 .21272 .51381 Mtetra
.21272 .51381 .21932 .51964 .22898 .51649 .2224 .51063 Mtetra
.2224 .51063 .22898 .51649 .23867 .51332 .23212 .50744 Mtetra
.23212 .50744 .23867 .51332 .2484 .51014 .24187 .50423 Mtetra
.24187 .50423 .2484 .51014 .25817 .50694 .25166 .50102 Mtetra
.25166 .50102 .25817 .50694 .26797 .50374 .26148 .49779 Mtetra
.26148 .49779 .26797 .50374 .27781 .50052 .27134 .49455 Mtetra
.27134 .49455 .27781 .50052 .28769 .49729 .28124 .4913 Mtetra
.28124 .4913 .28769 .49729 .2976 .49405 .29118 .48804 Mtetra
.29118 .48804 .2976 .49405 .30755 .4908 .30115 .48476 Mtetra
.30115 .48476 .30755 .4908 .31754 .48753 .31116 .48147 Mtetra
.31116 .48147 .31754 .48753 .32757 .48426 .32121 .47817 Mtetra
.32121 .47817 .32757 .48426 .33763 .48097 .3313 .47486 Mtetra
.3313 .47486 .33763 .48097 .34774 .47766 .34143 .47153 Mtetra
.34143 .47153 .34774 .47766 .35788 .47435 .35159 .46819 Mtetra
.35159 .46819 .35788 .47435 .36806 .47102 .3618 .46484 Mtetra
.3618 .46484 .36806 .47102 .37828 .46768 .37204 .46148 Mtetra
.37204 .46148 .37828 .46768 .38854 .46433 .38232 .4581 Mtetra
.38232 .4581 .38854 .46433 .39883 .46096 .39264 .45471 Mtetra
.39264 .45471 .39883 .46096 .40917 .45758 .40301 .45131 Mtetra
.40301 .45131 .40917 .45758 .41955 .45419 .41341 .44789 Mtetra
.41341 .44789 .41955 .45419 .42996 .45078 .42385 .44446 Mtetra
.42385 .44446 .42996 .45078 .44042 .44736 .43434 .44102 Mtetra
.43434 .44102 .44042 .44736 .45092 .44393 .44486 .43756 Mtetra
.44486 .43756 .45092 .44393 .46146 .44049 .45542 .43409 Mtetra
.45542 .43409 .46146 .44049 .47204 .43703 .46603 .43061 Mtetra
.46603 .43061 .47204 .43703 .48266 .43355 .47668 .42711 Mtetra
.47668 .42711 .48266 .43355 .49332 .43007 .48737 .4236 Mtetra
.48737 .4236 .49332 .43007 .50403 .42657 .4981 .42007 Mtetra
.4981 .42007 .50403 .42657 .51477 .42306 .50887 .41653 Mtetra
.50887 .41653 .51477 .42306 .52556 .41953 .51969 .41298 Mtetra
.51969 .41298 .52556 .41953 .53639 .41599 .53055 .40941 Mtetra
.53055 .40941 .53639 .41599 .54727 .41243 .54145 .40583 Mtetra
.54145 .40583 .54727 .41243 .55818 .40886 .5524 .40224 Mtetra
.5524 .40224 .55818 .40886 .56914 .40528 .56338 .39863 Mtetra
.56338 .39863 .56914 .40528 .58015 .40168 .57442 .39501 Mtetra
.57442 .39501 .58015 .40168 .5912 .39807 .58549 .39137 Mtetra
.58549 .39137 .5912 .39807 .60229 .39445 .59661 .38772 Mtetra
.59661 .38772 .60229 .39445 .61342 .39081 .60778 .38405 Mtetra
.60778 .38405 .61342 .39081 .6246 .38715 .61899 .38037 Mtetra
.61899 .38037 .6246 .38715 .63583 .38348 .63025 .37667 Mtetra
.63025 .37667 .63583 .38348 .6471 .3798 .64155 .37296 Mtetra
.64155 .37296 .6471 .3798 .65841 .3761 .65289 .36923 Mtetra
.65289 .36923 .65841 .3761 .66977 .37238 .66429 .36549 Mtetra
.66429 .36549 .66977 .37238 .68118 .36866 .67572 .36173 Mtetra
.67572 .36173 .68118 .36866 .69263 .36491 .68721 .35796 Mtetra
.68721 .35796 .69263 .36491 .70413 .36115 .69874 .35417 Mtetra
.69874 .35417 .70413 .36115 .71568 .35738 .71032 .35037 Mtetra
.71032 .35037 .71568 .35738 .72727 .35359 .72195 .34655 Mtetra
.72195 .34655 .72727 .35359 .73892 .34978 .73362 .34271 Mtetra
.73362 .34271 .73892 .34978 .7506 .34596 .74534 .33886 Mtetra
.74534 .33886 .7506 .34596 .76234 .34212 .75711 .335 Mtetra
.75711 .335 .76234 .34212 .77412 .33827 .76893 .33112 Mtetra
.76893 .33112 .77412 .33827 .78596 .3344 .7808 .32722 Mtetra
.7808 .32722 .78596 .3344 .79784 .33052 .79272 .3233 Mtetra
.79272 .3233 .79784 .33052 .80977 .32662 .80468 .31937 Mtetra
.80468 .31937 .80977 .32662 .82175 .3227 .8167 .31543 Mtetra
.8167 .31543 .82175 .3227 .83378 .31877 .82876 .31146 Mtetra
.18679 .51429 .19348 .52013 .20308 .51697 .19642 .51112 Mtetra
.19642 .51112 .20308 .51697 .21272 .51381 .20608 .50793 Mtetra
.20608 .50793 .21272 .51381 .2224 .51063 .21578 .50473 Mtetra
.21578 .50473 .2224 .51063 .23212 .50744 .22552 .50151 Mtetra
.22552 .50151 .23212 .50744 .24187 .50423 .23529 .49829 Mtetra
.23529 .49829 .24187 .50423 .25166 .50102 .2451 .49505 Mtetra
.2451 .49505 .25166 .50102 .26148 .49779 .25494 .4918 Mtetra
.25494 .4918 .26148 .49779 .27134 .49455 .26483 .48854 Mtetra
.26483 .48854 .27134 .49455 .28124 .4913 .27475 .48527 Mtetra
.27475 .48527 .28124 .4913 .29118 .48804 .28471 .48198 Mtetra
.28471 .48198 .29118 .48804 .30115 .48476 .2947 .47868 Mtetra
.2947 .47868 .30115 .48476 .31116 .48147 .30474 .47537 Mtetra
.30474 .47537 .31116 .48147 .32121 .47817 .31481 .47205 Mtetra
.31481 .47205 .32121 .47817 .3313 .47486 .32492 .46871 Mtetra
.32492 .46871 .3313 .47486 .34143 .47153 .33507 .46536 Mtetra
.33507 .46536 .34143 .47153 .35159 .46819 .34526 .462 Mtetra
.34526 .462 .35159 .46819 .3618 .46484 .35549 .45862 Mtetra
.35549 .45862 .3618 .46484 .37204 .46148 .36576 .45523 Mtetra
.36576 .45523 .37204 .46148 .38232 .4581 .37607 .45183 Mtetra
.37607 .45183 .38232 .4581 .39264 .45471 .38641 .44842 Mtetra
.38641 .44842 .39264 .45471 .40301 .45131 .3968 .44499 Mtetra
.3968 .44499 .40301 .45131 .41341 .44789 .40723 .44155 Mtetra
.40723 .44155 .41341 .44789 .42385 .44446 .41769 .43809 Mtetra
.41769 .43809 .42385 .44446 .43434 .44102 .4282 .43462 Mtetra
.4282 .43462 .43434 .44102 .44486 .43756 .43875 .43114 Mtetra
.43875 .43114 .44486 .43756 .45542 .43409 .44934 .42765 Mtetra
.44934 .42765 .45542 .43409 .46603 .43061 .45998 .42414 Mtetra
.45998 .42414 .46603 .43061 .47668 .42711 .47065 .42062 Mtetra
.47065 .42062 .47668 .42711 .48737 .4236 .48137 .41708 Mtetra
.48137 .41708 .48737 .4236 .4981 .42007 .49213 .41353 Mtetra
.49213 .41353 .4981 .42007 .50887 .41653 .50293 .40996 Mtetra
.50293 .40996 .50887 .41653 .51969 .41298 .51377 .40639 Mtetra
.51377 .40639 .51969 .41298 .53055 .40941 .52466 .40279 Mtetra
.52466 .40279 .53055 .40941 .54145 .40583 .53559 .39919 Mtetra
.53559 .39919 .54145 .40583 .5524 .40224 .54656 .39556 Mtetra
.54656 .39556 .5524 .40224 .56338 .39863 .55758 .39193 Mtetra
.55758 .39193 .56338 .39863 .57442 .39501 .56864 .38828 Mtetra
.56864 .38828 .57442 .39501 .58549 .39137 .57975 .38461 Mtetra
.57975 .38461 .58549 .39137 .59661 .38772 .5909 .38093 Mtetra
.5909 .38093 .59661 .38772 .60778 .38405 .6021 .37724 Mtetra
.6021 .37724 .60778 .38405 .61899 .38037 .61334 .37353 Mtetra
.61334 .37353 .61899 .38037 .63025 .37667 .62462 .3698 Mtetra
.62462 .3698 .63025 .37667 .64155 .37296 .63595 .36606 Mtetra
.63595 .36606 .64155 .37296 .65289 .36923 .64733 .36231 Mtetra
.64733 .36231 .65289 .36923 .66429 .36549 .65875 .35854 Mtetra
.65875 .35854 .66429 .36549 .67572 .36173 .67023 .35475 Mtetra
.67023 .35475 .67572 .36173 .68721 .35796 .68174 .35095 Mtetra
.68174 .35095 .68721 .35796 .69874 .35417 .69331 .34714 Mtetra
.69331 .34714 .69874 .35417 .71032 .35037 .70492 .34331 Mtetra
.70492 .34331 .71032 .35037 .72195 .34655 .71658 .33946 Mtetra
.71658 .33946 .72195 .34655 .73362 .34271 .72829 .33559 Mtetra
.72829 .33559 .73362 .34271 .74534 .33886 .74004 .33171 Mtetra
.74004 .33171 .74534 .33886 .75711 .335 .75184 .32782 Mtetra
.75184 .32782 .75711 .335 .76893 .33112 .7637 .32391 Mtetra
.7637 .32391 .76893 .33112 .7808 .32722 .7756 .31998 Mtetra
.7756 .31998 .7808 .32722 .79272 .3233 .78755 .31604 Mtetra
.78755 .31604 .79272 .3233 .80468 .31937 .79955 .31208 Mtetra
.79955 .31208 .80468 .31937 .8167 .31543 .8116 .3081 Mtetra
.8116 .3081 .8167 .31543 .82876 .31146 .82371 .3041 Mtetra
.18006 .50842 .18679 .51429 .19642 .51112 .18971 .50522 Mtetra
.18971 .50522 .19642 .51112 .20608 .50793 .19939 .50201 Mtetra
.19939 .50201 .20608 .50793 .21578 .50473 .20911 .49879 Mtetra
.20911 .49879 .21578 .50473 .22552 .50151 .21887 .49555 Mtetra
.21887 .49555 .22552 .50151 .23529 .49829 .22866 .4923 Mtetra
.22866 .4923 .23529 .49829 .2451 .49505 .23849 .48904 Mtetra
.23849 .48904 .2451 .49505 .25494 .4918 .24836 .48577 Mtetra
.24836 .48577 .25494 .4918 .26483 .48854 .25827 .48249 Mtetra
.25827 .48249 .26483 .48854 .27475 .48527 .26821 .47919 Mtetra
.26821 .47919 .27475 .48527 .28471 .48198 .27819 .47588 Mtetra
.27819 .47588 .28471 .48198 .2947 .47868 .28821 .47256 Mtetra
.28821 .47256 .2947 .47868 .30474 .47537 .29827 .46922 Mtetra
.29827 .46922 .30474 .47537 .31481 .47205 .30837 .46587 Mtetra
.30837 .46587 .31481 .47205 .32492 .46871 .3185 .46251 Mtetra
.3185 .46251 .32492 .46871 .33507 .46536 .32867 .45914 Mtetra
.32867 .45914 .33507 .46536 .34526 .462 .33889 .45575 Mtetra
.33889 .45575 .34526 .462 .35549 .45862 .34914 .45235 Mtetra
.34914 .45235 .35549 .45862 .36576 .45523 .35943 .44894 Mtetra
.35943 .44894 .36576 .45523 .37607 .45183 .36976 .44552 Mtetra
.36976 .44552 .37607 .45183 .38641 .44842 .38013 .44208 Mtetra
.38013 .44208 .38641 .44842 .3968 .44499 .39055 .43862 Mtetra
.39055 .43862 .3968 .44499 .40723 .44155 .401 .43516 Mtetra
.401 .43516 .40723 .44155 .41769 .43809 .41149 .43168 Mtetra
.41149 .43168 .41769 .43809 .4282 .43462 .42203 .42819 Mtetra
.42203 .42819 .4282 .43462 .43875 .43114 .4326 .42468 Mtetra
.4326 .42468 .43875 .43114 .44934 .42765 .44322 .42116 Mtetra
.44322 .42116 .44934 .42765 .45998 .42414 .45388 .41762 Mtetra
.45388 .41762 .45998 .42414 .47065 .42062 .46458 .41408 Mtetra
.46458 .41408 .47065 .42062 .48137 .41708 .47533 .41051 Mtetra
.47533 .41051 .48137 .41708 .49213 .41353 .48611 .40694 Mtetra
.48611 .40694 .49213 .41353 .50293 .40996 .49694 .40335 Mtetra
.49694 .40335 .50293 .40996 .51377 .40639 .50781 .39974 Mtetra
.50781 .39974 .51377 .40639 .52466 .40279 .51873 .39612 Mtetra
.51873 .39612 .52466 .40279 .53559 .39919 .52969 .39249 Mtetra
.52969 .39249 .53559 .39919 .54656 .39556 .54069 .38884 Mtetra
.54069 .38884 .54656 .39556 .55758 .39193 .55174 .38518 Mtetra
.55174 .38518 .55758 .39193 .56864 .38828 .56283 .3815 Mtetra
.56283 .3815 .56864 .38828 .57975 .38461 .57396 .37781 Mtetra
.57396 .37781 .57975 .38461 .5909 .38093 .58514 .3741 Mtetra
.58514 .3741 .5909 .38093 .6021 .37724 .59637 .37038 Mtetra
.59637 .37038 .6021 .37724 .61334 .37353 .60764 .36664 Mtetra
.60764 .36664 .61334 .37353 .62462 .3698 .61896 .36289 Mtetra
.61896 .36289 .62462 .3698 .63595 .36606 .63032 .35912 Mtetra
.63032 .35912 .63595 .36606 .64733 .36231 .64173 .35534 Mtetra
.64173 .35534 .64733 .36231 .65875 .35854 .65318 .35154 Mtetra
.65318 .35154 .65875 .35854 .67023 .35475 .66469 .34773 Mtetra
.66469 .34773 .67023 .35475 .68174 .35095 .67623 .3439 Mtetra
.67623 .3439 .68174 .35095 .69331 .34714 .68783 .34005 Mtetra
.68783 .34005 .69331 .34714 .70492 .34331 .69948 .33619 Mtetra
.69948 .33619 .70492 .34331 .71658 .33946 .71117 .33231 Mtetra
.71117 .33231 .71658 .33946 .72829 .33559 .72291 .32842 Mtetra
.72291 .32842 .72829 .33559 .74004 .33171 .7347 .32451 Mtetra
.7347 .32451 .74004 .33171 .75184 .32782 .74654 .32059 Mtetra
.74654 .32059 .75184 .32782 .7637 .32391 .75842 .31664 Mtetra
.75842 .31664 .7637 .32391 .7756 .31998 .77036 .31269 Mtetra
.77036 .31269 .7756 .31998 .78755 .31604 .78235 .30871 Mtetra
.78235 .30871 .78755 .31604 .79955 .31208 .79438 .30472 Mtetra
.79438 .30472 .79955 .31208 .8116 .3081 .80647 .30071 Mtetra
.80647 .30071 .8116 .3081 .82371 .3041 .81861 .29669 Mtetra
.17328 .5025 .18006 .50842 .18971 .50522 .18295 .49928 Mtetra
.18295 .49928 .18971 .50522 .19939 .50201 .19266 .49605 Mtetra
.19266 .49605 .19939 .50201 .20911 .49879 .2024 .4928 Mtetra
.2024 .4928 .20911 .49879 .21887 .49555 .21218 .48955 Mtetra
.21218 .48955 .21887 .49555 .22866 .4923 .22199 .48627 Mtetra
.22199 .48627 .22866 .4923 .23849 .48904 .23184 .48299 Mtetra
.23184 .48299 .23849 .48904 .24836 .48577 .24173 .4797 Mtetra
.24173 .4797 .24836 .48577 .25827 .48249 .25166 .47639 Mtetra
.25166 .47639 .25827 .48249 .26821 .47919 .26163 .47307 Mtetra
.26163 .47307 .26821 .47919 .27819 .47588 .27163 .46974 Mtetra
.27163 .46974 .27819 .47588 .28821 .47256 .28167 .46639 Mtetra
.28167 .46639 .28821 .47256 .29827 .46922 .29175 .46303 Mtetra
.29175 .46303 .29827 .46922 .30837 .46587 .30187 .45966 Mtetra
.30187 .45966 .30837 .46587 .3185 .46251 .31203 .45628 Mtetra
.31203 .45628 .3185 .46251 .32867 .45914 .32223 .45288 Mtetra
.32223 .45288 .32867 .45914 .33889 .45575 .33247 .44947 Mtetra
.33247 .44947 .33889 .45575 .34914 .45235 .34274 .44604 Mtetra
.34274 .44604 .34914 .45235 .35943 .44894 .35306 .44261 Mtetra
.35306 .44261 .35943 .44894 .36976 .44552 .36342 .43916 Mtetra
.36342 .43916 .36976 .44552 .38013 .44208 .37381 .43569 Mtetra
.37381 .43569 .38013 .44208 .39055 .43862 .38425 .43222 Mtetra
.38425 .43222 .39055 .43862 .401 .43516 .39473 .42872 Mtetra
.39473 .42872 .401 .43516 .41149 .43168 .40525 .42522 Mtetra
.40525 .42522 .41149 .43168 .42203 .42819 .41581 .4217 Mtetra
.41581 .4217 .42203 .42819 .4326 .42468 .42641 .41817 Mtetra
.42641 .41817 .4326 .42468 .44322 .42116 .43705 .41462 Mtetra
.43705 .41462 .44322 .42116 .45388 .41762 .44774 .41106 Mtetra
.44774 .41106 .45388 .41762 .46458 .41408 .45847 .40749 Mtetra
.45847 .40749 .46458 .41408 .47533 .41051 .46924 .4039 Mtetra
.46924 .4039 .47533 .41051 .48611 .40694 .48005 .4003 Mtetra
.48005 .4003 .48611 .40694 .49694 .40335 .49091 .39668 Mtetra
.49091 .39668 .49694 .40335 .50781 .39974 .50181 .39305 Mtetra
.50181 .39305 .50781 .39974 .51873 .39612 .51275 .3894 Mtetra
.51275 .3894 .51873 .39612 .52969 .39249 .52374 .38574 Mtetra
.52374 .38574 .52969 .39249 .54069 .38884 .53477 .38207 Mtetra
.53477 .38207 .54069 .38884 .55174 .38518 .54585 .37838 Mtetra
.54585 .37838 .55174 .38518 .56283 .3815 .55697 .37467 Mtetra
.55697 .37467 .56283 .3815 .57396 .37781 .56813 .37095 Mtetra
.56813 .37095 .57396 .37781 .58514 .3741 .57934 .36722 Mtetra
.57934 .36722 .58514 .3741 .59637 .37038 .5906 .36347 Mtetra
.5906 .36347 .59637 .37038 .60764 .36664 .6019 .3597 Mtetra
.6019 .3597 .60764 .36664 .61896 .36289 .61325 .35592 Mtetra
.61325 .35592 .61896 .36289 .63032 .35912 .62464 .35213 Mtetra
.62464 .35213 .63032 .35912 .64173 .35534 .63608 .34831 Mtetra
.63608 .34831 .64173 .35534 .65318 .35154 .64757 .34449 Mtetra
.64757 .34449 .65318 .35154 .66469 .34773 .6591 .34064 Mtetra
.6591 .34064 .66469 .34773 .67623 .3439 .67069 .33678 Mtetra
.67069 .33678 .67623 .3439 .68783 .34005 .68231 .33291 Mtetra
.68231 .33291 .68783 .34005 .69948 .33619 .69399 .32902 Mtetra
.69399 .32902 .69948 .33619 .71117 .33231 .70572 .32511 Mtetra
.70572 .32511 .71117 .33231 .72291 .32842 .71749 .32119 Mtetra
.71749 .32119 .72291 .32842 .7347 .32451 .72932 .31725 Mtetra
.72932 .31725 .7347 .32451 .74654 .32059 .74119 .3133 Mtetra
.74119 .3133 .74654 .32059 .75842 .31664 .75311 .30932 Mtetra
.75311 .30932 .75842 .31664 .77036 .31269 .76508 .30533 Mtetra
.76508 .30533 .77036 .31269 .78235 .30871 .7771 .30133 Mtetra
.7771 .30133 .78235 .30871 .79438 .30472 .78918 .29731 Mtetra
.78918 .29731 .79438 .30472 .80647 .30071 .8013 .29327 Mtetra
.8013 .29327 .80647 .30071 .81861 .29669 .81347 .28921 Mtetra
.16646 .49655 .17328 .5025 .18295 .49928 .17615 .4933 Mtetra
.17615 .4933 .18295 .49928 .19266 .49605 .18587 .49005 Mtetra
.18587 .49005 .19266 .49605 .2024 .4928 .19564 .48678 Mtetra
.19564 .48678 .2024 .4928 .21218 .48955 .20544 .4835 Mtetra
.20544 .4835 .21218 .48955 .22199 .48627 .21527 .4802 Mtetra
.21527 .4802 .22199 .48627 .23184 .48299 .22515 .4769 Mtetra
.22515 .4769 .23184 .48299 .24173 .4797 .23506 .47358 Mtetra
.23506 .47358 .24173 .4797 .25166 .47639 .24501 .47025 Mtetra
.24501 .47025 .25166 .47639 .26163 .47307 .255 .46691 Mtetra
.255 .46691 .26163 .47307 .27163 .46974 .26502 .46355 Mtetra
.26502 .46355 .27163 .46974 .28167 .46639 .27509 .46018 Mtetra
.27509 .46018 .28167 .46639 .29175 .46303 .28519 .4568 Mtetra
.28519 .4568 .29175 .46303 .30187 .45966 .29534 .4534 Mtetra
.29534 .4534 .30187 .45966 .31203 .45628 .30552 .44999 Mtetra
.30552 .44999 .31203 .45628 .32223 .45288 .31574 .44657 Mtetra
.31574 .44657 .32223 .45288 .33247 .44947 .326 .44314 Mtetra
.326 .44314 .33247 .44947 .34274 .44604 .3363 .43969 Mtetra
.3363 .43969 .34274 .44604 .35306 .44261 .34664 .43623 Mtetra
.34664 .43623 .35306 .44261 .36342 .43916 .35702 .43275 Mtetra
.35702 .43275 .36342 .43916 .37381 .43569 .36744 .42926 Mtetra
.36744 .42926 .37381 .43569 .38425 .43222 .37791 .42576 Mtetra
.37791 .42576 .38425 .43222 .39473 .42872 .38841 .42224 Mtetra
.38841 .42224 .39473 .42872 .40525 .42522 .39896 .41871 Mtetra
.39896 .41871 .40525 .42522 .41581 .4217 .40954 .41517 Mtetra
.40954 .41517 .41581 .4217 .42641 .41817 .42017 .41161 Mtetra
.42017 .41161 .42641 .41817 .43705 .41462 .43084 .40804 Mtetra
.43084 .40804 .43705 .41462 .44774 .41106 .44155 .40445 Mtetra
.44155 .40445 .44774 .41106 .45847 .40749 .45231 .40085 Mtetra
.45231 .40085 .45847 .40749 .46924 .4039 .46311 .39724 Mtetra
.46311 .39724 .46924 .4039 .48005 .4003 .47395 .39361 Mtetra
.47395 .39361 .48005 .4003 .49091 .39668 .48483 .38996 Mtetra
.48483 .38996 .49091 .39668 .50181 .39305 .49576 .38631 Mtetra
.49576 .38631 .50181 .39305 .51275 .3894 .50673 .38263 Mtetra
.50673 .38263 .51275 .3894 .52374 .38574 .51775 .37895 Mtetra
.51775 .37895 .52374 .38574 .53477 .38207 .52881 .37524 Mtetra
.52881 .37524 .53477 .38207 .54585 .37838 .53991 .37153 Mtetra
.53991 .37153 .54585 .37838 .55697 .37467 .55106 .36779 Mtetra
.55106 .36779 .55697 .37467 .56813 .37095 .56226 .36404 Mtetra
.56226 .36404 .56813 .37095 .57934 .36722 .5735 .36028 Mtetra
.5735 .36028 .57934 .36722 .5906 .36347 .58479 .3565 Mtetra
.58479 .3565 .5906 .36347 .6019 .3597 .59612 .35271 Mtetra
.59612 .35271 .6019 .3597 .61325 .35592 .6075 .3489 Mtetra
.6075 .3489 .61325 .35592 .62464 .35213 .61892 .34508 Mtetra
.61892 .34508 .62464 .35213 .63608 .34831 .63039 .34124 Mtetra
.63039 .34124 .63608 .34831 .64757 .34449 .64191 .33738 Mtetra
.64191 .33738 .64757 .34449 .6591 .34064 .65348 .33351 Mtetra
.65348 .33351 .6591 .34064 .67069 .33678 .66509 .32962 Mtetra
.66509 .32962 .67069 .33678 .68231 .33291 .67676 .32572 Mtetra
.67676 .32572 .68231 .33291 .69399 .32902 .68847 .32179 Mtetra
.68847 .32179 .69399 .32902 .70572 .32511 .70023 .31786 Mtetra
.70023 .31786 .70572 .32511 .71749 .32119 .71203 .31391 Mtetra
.71203 .31391 .71749 .32119 .72932 .31725 .72389 .30994 Mtetra
.72389 .30994 .72932 .31725 .74119 .3133 .7358 .30595 Mtetra
.7358 .30595 .74119 .3133 .75311 .30932 .74775 .30195 Mtetra
.74775 .30195 .75311 .30932 .76508 .30533 .75976 .29793 Mtetra
.75976 .29793 .76508 .30533 .7771 .30133 .77182 .29389 Mtetra
.77182 .29389 .7771 .30133 .78918 .29731 .78393 .28984 Mtetra
.78393 .28984 .78918 .29731 .8013 .29327 .79609 .28577 Mtetra
.79609 .28577 .8013 .29327 .81347 .28921 .8083 .28168 Mtetra
.15958 .49055 .16646 .49655 .17615 .4933 .16929 .48728 Mtetra
.16929 .48728 .17615 .4933 .18587 .49005 .17904 .484 Mtetra
.17904 .484 .18587 .49005 .19564 .48678 .18883 .48071 Mtetra
.18883 .48071 .19564 .48678 .20544 .4835 .19865 .47741 Mtetra
.19865 .47741 .20544 .4835 .21527 .4802 .20851 .47409 Mtetra
.20851 .47409 .21527 .4802 .22515 .4769 .2184 .47076 Mtetra
.2184 .47076 .22515 .4769 .23506 .47358 .22834 .46742 Mtetra
.22834 .46742 .23506 .47358 .24501 .47025 .23831 .46407 Mtetra
.23831 .46407 .24501 .47025 .255 .46691 .24832 .4607 Mtetra
.24832 .4607 .255 .46691 .26502 .46355 .25837 .45732 Mtetra
.25837 .45732 .26502 .46355 .27509 .46018 .26846 .45393 Mtetra
.26846 .45393 .27509 .46018 .28519 .4568 .27858 .45052 Mtetra
.27858 .45052 .28519 .4568 .29534 .4534 .28875 .4471 Mtetra
.28875 .4471 .29534 .4534 .30552 .44999 .29896 .44367 Mtetra
.29896 .44367 .30552 .44999 .31574 .44657 .3092 .44022 Mtetra
.3092 .44022 .31574 .44657 .326 .44314 .31949 .43676 Mtetra
.31949 .43676 .326 .44314 .3363 .43969 .32981 .43329 Mtetra
.32981 .43329 .3363 .43969 .34664 .43623 .34018 .4298 Mtetra
.34018 .4298 .34664 .43623 .35702 .43275 .35058 .4263 Mtetra
.35058 .4263 .35702 .43275 .36744 .42926 .36103 .42279 Mtetra
.36103 .42279 .36744 .42926 .37791 .42576 .37152 .41926 Mtetra
.37152 .41926 .37791 .42576 .38841 .42224 .38205 .41572 Mtetra
.38205 .41572 .38841 .42224 .39896 .41871 .39262 .41216 Mtetra
.39262 .41216 .39896 .41871 .40954 .41517 .40323 .40859 Mtetra
.40323 .40859 .40954 .41517 .42017 .41161 .41389 .40501 Mtetra
.41389 .40501 .42017 .41161 .43084 .40804 .42458 .40141 Mtetra
.42458 .40141 .43084 .40804 .44155 .40445 .43532 .39779 Mtetra
.43532 .39779 .44155 .40445 .45231 .40085 .44611 .39417 Mtetra
.44611 .39417 .45231 .40085 .46311 .39724 .45693 .39053 Mtetra
.45693 .39053 .46311 .39724 .47395 .39361 .4678 .38687 Mtetra
.4678 .38687 .47395 .39361 .48483 .38996 .47871 .3832 Mtetra
.47871 .3832 .48483 .38996 .49576 .38631 .48967 .37951 Mtetra
.48967 .37951 .49576 .38631 .50673 .38263 .50067 .37581 Mtetra
.50067 .37581 .50673 .38263 .51775 .37895 .51171 .3721 Mtetra
.51171 .3721 .51775 .37895 .52881 .37524 .5228 .36837 Mtetra
.5228 .36837 .52881 .37524 .53991 .37153 .53394 .36462 Mtetra
.53394 .36462 .53991 .37153 .55106 .36779 .54512 .36086 Mtetra
.54512 .36086 .55106 .36779 .56226 .36404 .55634 .35709 Mtetra
.55634 .35709 .56226 .36404 .5735 .36028 .56761 .35329 Mtetra
.56761 .35329 .5735 .36028 .58479 .3565 .57893 .34949 Mtetra
.57893 .34949 .58479 .3565 .59612 .35271 .59029 .34567 Mtetra
.59029 .34567 .59612 .35271 .6075 .3489 .6017 .34183 Mtetra
.6017 .34183 .6075 .3489 .61892 .34508 .61316 .33797 Mtetra
.61316 .33797 .61892 .34508 .63039 .34124 .62466 .3341 Mtetra
.62466 .3341 .63039 .34124 .64191 .33738 .63621 .33022 Mtetra
.63621 .33022 .64191 .33738 .65348 .33351 .64781 .32632 Mtetra
.64781 .32632 .65348 .33351 .66509 .32962 .65946 .3224 Mtetra
.65946 .3224 .66509 .32962 .67676 .32572 .67115 .31846 Mtetra
.67115 .31846 .67676 .32572 .68847 .32179 .6829 .31451 Mtetra
.6829 .31451 .68847 .32179 .70023 .31786 .69469 .31055 Mtetra
.69469 .31055 .70023 .31786 .71203 .31391 .70653 .30656 Mtetra
.70653 .30656 .71203 .31391 .72389 .30994 .71842 .30256 Mtetra
.71842 .30256 .72389 .30994 .7358 .30595 .73037 .29855 Mtetra
.73037 .29855 .7358 .30595 .74775 .30195 .74236 .29451 Mtetra
.74236 .29451 .74775 .30195 .75976 .29793 .7544 .29046 Mtetra
.7544 .29046 .75976 .29793 .77182 .29389 .76649 .28639 Mtetra
.76649 .28639 .77182 .29389 .78393 .28984 .77864 .28231 Mtetra
.77864 .28231 .78393 .28984 .79609 .28577 .79083 .27821 Mtetra
.79083 .27821 .79609 .28577 .8083 .28168 .80308 .27409 Mtetra
.15266 .48451 .15958 .49055 .16929 .48728 .16239 .48122 Mtetra
.16239 .48122 .16929 .48728 .17904 .484 .17216 .47792 Mtetra
.17216 .47792 .17904 .484 .18883 .48071 .18197 .4746 Mtetra
.18197 .4746 .18883 .48071 .19865 .47741 .19181 .47128 Mtetra
.19181 .47128 .19865 .47741 .20851 .47409 .20169 .46794 Mtetra
.20169 .46794 .20851 .47409 .2184 .47076 .21161 .46458 Mtetra
.21161 .46458 .2184 .47076 .22834 .46742 .22157 .46122 Mtetra
.22157 .46122 .22834 .46742 .23831 .46407 .23156 .45784 Mtetra
.23156 .45784 .23831 .46407 .24832 .4607 .2416 .45445 Mtetra
.2416 .45445 .24832 .4607 .25837 .45732 .25167 .45104 Mtetra
.25167 .45104 .25837 .45732 .26846 .45393 .26178 .44763 Mtetra
.26178 .44763 .26846 .45393 .27858 .45052 .27193 .4442 Mtetra
.27193 .4442 .27858 .45052 .28875 .4471 .28212 .44075 Mtetra
.28212 .44075 .28875 .4471 .29896 .44367 .29235 .43729 Mtetra
.29235 .43729 .29896 .44367 .3092 .44022 .30262 .43382 Mtetra
.30262 .43382 .3092 .44022 .31949 .43676 .31293 .43034 Mtetra
.31293 .43034 .31949 .43676 .32981 .43329 .32328 .42684 Mtetra
.32328 .42684 .32981 .43329 .34018 .4298 .33367 .42333 Mtetra
.33367 .42333 .34018 .4298 .35058 .4263 .3441 .4198 Mtetra
.3441 .4198 .35058 .4263 .36103 .42279 .35457 .41626 Mtetra
.35457 .41626 .36103 .42279 .37152 .41926 .36508 .41271 Mtetra
.36508 .41271 .37152 .41926 .38205 .41572 .37564 .40914 Mtetra
.37564 .40914 .38205 .41572 .39262 .41216 .38623 .40556 Mtetra
.38623 .40556 .39262 .41216 .40323 .40859 .39687 .40196 Mtetra
.39687 .40196 .40323 .40859 .41389 .40501 .40756 .39835 Mtetra
.40756 .39835 .41389 .40501 .42458 .40141 .41828 .39473 Mtetra
.41828 .39473 .42458 .40141 .43532 .39779 .42905 .39109 Mtetra
.42905 .39109 .43532 .39779 .44611 .39417 .43986 .38743 Mtetra
.43986 .38743 .44611 .39417 .45693 .39053 .45071 .38376 Mtetra
.45071 .38376 .45693 .39053 .4678 .38687 .4616 .38008 Mtetra
.4616 .38008 .4678 .38687 .47871 .3832 .47255 .37638 Mtetra
.47255 .37638 .47871 .3832 .48967 .37951 .48353 .37267 Mtetra
.48353 .37267 .48967 .37951 .50067 .37581 .49456 .36894 Mtetra
.49456 .36894 .50067 .37581 .51171 .3721 .50563 .3652 Mtetra
.50563 .3652 .51171 .3721 .5228 .36837 .51675 .36144 Mtetra
.51675 .36144 .5228 .36837 .53394 .36462 .52791 .35767 Mtetra
.52791 .35767 .53394 .36462 .54512 .36086 .53912 .35388 Mtetra
.53912 .35388 .54512 .36086 .55634 .35709 .55038 .35007 Mtetra
.55038 .35007 .55634 .35709 .56761 .35329 .56168 .34625 Mtetra
.56168 .34625 .56761 .35329 .57893 .34949 .57303 .34242 Mtetra
.57303 .34242 .57893 .34949 .59029 .34567 .58442 .33857 Mtetra
.58442 .33857 .59029 .34567 .6017 .34183 .59586 .3347 Mtetra
.59586 .3347 .6017 .34183 .61316 .33797 .60735 .33082 Mtetra
.60735 .33082 .61316 .33797 .62466 .3341 .61889 .32692 Mtetra
.61889 .32692 .62466 .3341 .63621 .33022 .63047 .323 Mtetra
.63047 .323 .63621 .33022 .64781 .32632 .6421 .31907 Mtetra
.6421 .31907 .64781 .32632 .65946 .3224 .65378 .31512 Mtetra
.65378 .31512 .65946 .3224 .67115 .31846 .66551 .31116 Mtetra
.66551 .31116 .67115 .31846 .6829 .31451 .67729 .30718 Mtetra
.67729 .30718 .6829 .31451 .69469 .31055 .68911 .30318 Mtetra
.68911 .30318 .69469 .31055 .70653 .30656 .70099 .29917 Mtetra
.70099 .29917 .70653 .30656 .71842 .30256 .71292 .29513 Mtetra
.71292 .29513 .71842 .30256 .73037 .29855 .72489 .29109 Mtetra
.72489 .29109 .73037 .29855 .74236 .29451 .73692 .28702 Mtetra
.73692 .28702 .74236 .29451 .7544 .29046 .749 .28294 Mtetra
.749 .28294 .7544 .29046 .76649 .28639 .76113 .27884 Mtetra
.76113 .27884 .76649 .28639 .77864 .28231 .77331 .27472 Mtetra
.77331 .27472 .77864 .28231 .79083 .27821 .78554 .27059 Mtetra
.78554 .27059 .79083 .27821 .80308 .27409 .79782 .26643 Mtetra
.14569 .47843 .15266 .48451 .16239 .48122 .15545 .47511 Mtetra
.15545 .47511 .16239 .48122 .17216 .47792 .16524 .47179 Mtetra
.16524 .47179 .17216 .47792 .18197 .4746 .17506 .46845 Mtetra
.17506 .46845 .18197 .4746 .19181 .47128 .18493 .4651 Mtetra
.18493 .4651 .19181 .47128 .20169 .46794 .19483 .46174 Mtetra
.19483 .46174 .20169 .46794 .21161 .46458 .20477 .45836 Mtetra
.20477 .45836 .21161 .46458 .22157 .46122 .21475 .45497 Mtetra
.21475 .45497 .22157 .46122 .23156 .45784 .22477 .45157 Mtetra
.22477 .45157 .23156 .45784 .2416 .45445 .23482 .44815 Mtetra
.23482 .44815 .2416 .45445 .25167 .45104 .24492 .44472 Mtetra
.24492 .44472 .25167 .45104 .26178 .44763 .25505 .44128 Mtetra
.25505 .44128 .26178 .44763 .27193 .4442 .26523 .43783 Mtetra
.26523 .43783 .27193 .4442 .28212 .44075 .27544 .43436 Mtetra
.27544 .43436 .28212 .44075 .29235 .43729 .28569 .43087 Mtetra
.28569 .43087 .29235 .43729 .30262 .43382 .29598 .42738 Mtetra
.29598 .42738 .30262 .43382 .31293 .43034 .30632 .42387 Mtetra
.30632 .42387 .31293 .43034 .32328 .42684 .31669 .42034 Mtetra
.31669 .42034 .32328 .42684 .33367 .42333 .32711 .41681 Mtetra
.32711 .41681 .33367 .42333 .3441 .4198 .33756 .41326 Mtetra
.33756 .41326 .3441 .4198 .35457 .41626 .34806 .40969 Mtetra
.34806 .40969 .35457 .41626 .36508 .41271 .3586 .40611 Mtetra
.3586 .40611 .36508 .41271 .37564 .40914 .36918 .40252 Mtetra
.36918 .40252 .37564 .40914 .38623 .40556 .3798 .39891 Mtetra
.3798 .39891 .38623 .40556 .39687 .40196 .39047 .39529 Mtetra
.39047 .39529 .39687 .40196 .40756 .39835 .40118 .39165 Mtetra
.40118 .39165 .40756 .39835 .41828 .39473 .41193 .388 Mtetra
.41193 .388 .41828 .39473 .42905 .39109 .42272 .38433 Mtetra
.42272 .38433 .42905 .39109 .43986 .38743 .43356 .38065 Mtetra
.43356 .38065 .43986 .38743 .45071 .38376 .44444 .37695 Mtetra
.44444 .37695 .45071 .38376 .4616 .38008 .45536 .37324 Mtetra
.45536 .37324 .4616 .38008 .47255 .37638 .46633 .36952 Mtetra
.46633 .36952 .47255 .37638 .48353 .37267 .47735 .36578 Mtetra
.47735 .36578 .48353 .37267 .49456 .36894 .4884 .36202 Mtetra
.4884 .36202 .49456 .36894 .50563 .3652 .49951 .35825 Mtetra
.49951 .35825 .50563 .3652 .51675 .36144 .51065 .35446 Mtetra
.51065 .35446 .51675 .36144 .52791 .35767 .52185 .35066 Mtetra
.52185 .35066 .52791 .35767 .53912 .35388 .53309 .34684 Mtetra
.53309 .34684 .53912 .35388 .55038 .35007 .54437 .34301 Mtetra
.54437 .34301 .55038 .35007 .56168 .34625 .5557 .33916 Mtetra
.5557 .33916 .56168 .34625 .57303 .34242 .56708 .3353 Mtetra
.56708 .3353 .57303 .34242 .58442 .33857 .57851 .33142 Mtetra
.57851 .33142 .58442 .33857 .59586 .3347 .58998 .32752 Mtetra
.58998 .32752 .59586 .3347 .60735 .33082 .6015 .32361 Mtetra
.6015 .32361 .60735 .33082 .61889 .32692 .61307 .31968 Mtetra
.61307 .31968 .61889 .32692 .63047 .323 .62468 .31573 Mtetra
.62468 .31573 .63047 .323 .6421 .31907 .63635 .31177 Mtetra
.63635 .31177 .6421 .31907 .65378 .31512 .64806 .30779 Mtetra
.64806 .30779 .65378 .31512 .66551 .31116 .65982 .3038 Mtetra
.65982 .3038 .66551 .31116 .67729 .30718 .67163 .29978 Mtetra
.67163 .29978 .67729 .30718 .68911 .30318 .68349 .29576 Mtetra
.68349 .29576 .68911 .30318 .70099 .29917 .6954 .29171 Mtetra
.6954 .29171 .70099 .29917 .71292 .29513 .70736 .28765 Mtetra
.70736 .28765 .71292 .29513 .72489 .29109 .71938 .28357 Mtetra
.71938 .28357 .72489 .29109 .73692 .28702 .73144 .27947 Mtetra
.73144 .27947 .73692 .28702 .749 .28294 .74355 .27536 Mtetra
.74355 .27536 .749 .28294 .76113 .27884 .75572 .27122 Mtetra
.75572 .27122 .76113 .27884 .77331 .27472 .76793 .26707 Mtetra
.76793 .26707 .77331 .27472 .78554 .27059 .7802 .26291 Mtetra
.7802 .26291 .78554 .27059 .79782 .26643 .79252 .25872 Mtetra
.13868 .4723 .14569 .47843 .15545 .47511 .14845 .46897 Mtetra
.14845 .46897 .15545 .47511 .16524 .47179 .15826 .46562 Mtetra
.15826 .46562 .16524 .47179 .17506 .46845 .16811 .46226 Mtetra
.16811 .46226 .17506 .46845 .18493 .4651 .17799 .45888 Mtetra
.17799 .45888 .18493 .4651 .19483 .46174 .18792 .45549 Mtetra
.18792 .45549 .19483 .46174 .20477 .45836 .19788 .45209 Mtetra
.19788 .45209 .20477 .45836 .21475 .45497 .20788 .44868 Mtetra
.20788 .44868 .21475 .45497 .22477 .45157 .21792 .44525 Mtetra
.21792 .44525 .22477 .45157 .23482 .44815 .228 .44181 Mtetra
.228 .44181 .23482 .44815 .24492 .44472 .23812 .43836 Mtetra
.23812 .43836 .24492 .44472 .25505 .44128 .24828 .43489 Mtetra
.24828 .43489 .25505 .44128 .26523 .43783 .25847 .43141 Mtetra
.25847 .43141 .26523 .43783 .27544 .43436 .26871 .42792 Mtetra
.26871 .42792 .27544 .43436 .28569 .43087 .27899 .42441 Mtetra
.27899 .42441 .28569 .43087 .29598 .42738 .2893 .42089 Mtetra
.2893 .42089 .29598 .42738 .30632 .42387 .29966 .41735 Mtetra
.29966 .41735 .30632 .42387 .31669 .42034 .31006 .4138 Mtetra
.31006 .4138 .31669 .42034 .32711 .41681 .3205 .41024 Mtetra
.3205 .41024 .32711 .41681 .33756 .41326 .33098 .40666 Mtetra
.33098 .40666 .33756 .41326 .34806 .40969 .34151 .40307 Mtetra
.34151 .40307 .34806 .40969 .3586 .40611 .35207 .39946 Mtetra
.35207 .39946 .3586 .40611 .36918 .40252 .36268 .39584 Mtetra
.36268 .39584 .36918 .40252 .3798 .39891 .37333 .39221 Mtetra
.37333 .39221 .3798 .39891 .39047 .39529 .38402 .38856 Mtetra
.38402 .38856 .39047 .39529 .40118 .39165 .39475 .3849 Mtetra
.39475 .3849 .40118 .39165 .41193 .388 .40553 .38122 Mtetra
.40553 .38122 .41193 .388 .42272 .38433 .41635 .37752 Mtetra
.41635 .37752 .42272 .38433 .43356 .38065 .42722 .37381 Mtetra
.42722 .37381 .43356 .38065 .44444 .37695 .43812 .37009 Mtetra
.43812 .37009 .44444 .37695 .45536 .37324 .44908 .36635 Mtetra
.44908 .36635 .45536 .37324 .46633 .36952 .46007 .3626 Mtetra
.46007 .3626 .46633 .36952 .47735 .36578 .47112 .35883 Mtetra
.47112 .35883 .47735 .36578 .4884 .36202 .4822 .35505 Mtetra
.4822 .35505 .4884 .36202 .49951 .35825 .49333 .35125 Mtetra
.49333 .35125 .49951 .35825 .51065 .35446 .50451 .34743 Mtetra
.50451 .34743 .51065 .35446 .52185 .35066 .51573 .3436 Mtetra
.51573 .3436 .52185 .35066 .53309 .34684 .527 .33975 Mtetra
.527 .33975 .53309 .34684 .54437 .34301 .53832 .33589 Mtetra
.53832 .33589 .54437 .34301 .5557 .33916 .54968 .33201 Mtetra
.54968 .33201 .5557 .33916 .56708 .3353 .56109 .32812 Mtetra
.56109 .32812 .56708 .3353 .57851 .33142 .57255 .32421 Mtetra
.57255 .32421 .57851 .33142 .58998 .32752 .58405 .32028 Mtetra
.58405 .32028 .58998 .32752 .6015 .32361 .5956 .31634 Mtetra
.5956 .31634 .6015 .32361 .61307 .31968 .6072 .31238 Mtetra
.6072 .31238 .61307 .31968 .62468 .31573 .61885 .3084 Mtetra
.61885 .3084 .62468 .31573 .63635 .31177 .63055 .30441 Mtetra
.63055 .30441 .63635 .31177 .64806 .30779 .64229 .3004 Mtetra
.64229 .3004 .64806 .30779 .65982 .3038 .65409 .29638 Mtetra
.65409 .29638 .65982 .3038 .67163 .29978 .66593 .29233 Mtetra
.66593 .29233 .67163 .29978 .68349 .29576 .67783 .28827 Mtetra
.67783 .28827 .68349 .29576 .6954 .29171 .68977 .2842 Mtetra
.68977 .2842 .6954 .29171 .70736 .28765 .70177 .2801 Mtetra
.70177 .2801 .70736 .28765 .71938 .28357 .71382 .27599 Mtetra
.71382 .27599 .71938 .28357 .73144 .27947 .72591 .27186 Mtetra
.72591 .27186 .73144 .27947 .74355 .27536 .73806 .26771 Mtetra
.73806 .26771 .74355 .27536 .75572 .27122 .75026 .26355 Mtetra
.75026 .26355 .75572 .27122 .76793 .26707 .76252 .25937 Mtetra
.76252 .25937 .76793 .26707 .7802 .26291 .77482 .25517 Mtetra
.77482 .25517 .7802 .26291 .79252 .25872 .78718 .25095 Mtetra
.13161 .46613 .13868 .4723 .14845 .46897 .1414 .46277 Mtetra
.1414 .46277 .14845 .46897 .15826 .46562 .15123 .4594 Mtetra
.15123 .4594 .15826 .46562 .16811 .46226 .1611 .45602 Mtetra
.1611 .45602 .16811 .46226 .17799 .45888 .17101 .45262 Mtetra
.17101 .45262 .17799 .45888 .18792 .45549 .18096 .44921 Mtetra
.18096 .44921 .18792 .45549 .19788 .45209 .19094 .44578 Mtetra
.19094 .44578 .19788 .45209 .20788 .44868 .20097 .44234 Mtetra
.20097 .44234 .20788 .44868 .21792 .44525 .21103 .43889 Mtetra
.21103 .43889 .21792 .44525 .228 .44181 .22113 .43543 Mtetra
.22113 .43543 .228 .44181 .23812 .43836 .23127 .43195 Mtetra
.23127 .43195 .23812 .43836 .24828 .43489 .24145 .42846 Mtetra
.24145 .42846 .24828 .43489 .25847 .43141 .25167 .42495 Mtetra
.25167 .42495 .25847 .43141 .26871 .42792 .26193 .42143 Mtetra
.26193 .42143 .26871 .42792 .27899 .42441 .27223 .4179 Mtetra
.27223 .4179 .27899 .42441 .2893 .42089 .28258 .41435 Mtetra
.28258 .41435 .2893 .42089 .29966 .41735 .29296 .41079 Mtetra
.29296 .41079 .29966 .41735 .31006 .4138 .30338 .40721 Mtetra
.30338 .40721 .31006 .4138 .3205 .41024 .31385 .40362 Mtetra
.31385 .40362 .3205 .41024 .33098 .40666 .32435 .40002 Mtetra
.32435 .40002 .33098 .40666 .34151 .40307 .3349 .3964 Mtetra
.3349 .3964 .34151 .40307 .35207 .39946 .34549 .39277 Mtetra
.34549 .39277 .35207 .39946 .36268 .39584 .35613 .38912 Mtetra
.35613 .38912 .36268 .39584 .37333 .39221 .3668 .38546 Mtetra
.3668 .38546 .37333 .39221 .38402 .38856 .37752 .38178 Mtetra
.37752 .38178 .38402 .38856 .39475 .3849 .38828 .37809 Mtetra
.38828 .37809 .39475 .3849 .40553 .38122 .39908 .37439 Mtetra
.39908 .37439 .40553 .38122 .41635 .37752 .40993 .37067 Mtetra
.40993 .37067 .41635 .37752 .42722 .37381 .42083 .36693 Mtetra
.42083 .36693 .42722 .37381 .43812 .37009 .43176 .36318 Mtetra
.43176 .36318 .43812 .37009 .44908 .36635 .44274 .35941 Mtetra
.44274 .35941 .44908 .36635 .46007 .3626 .45377 .35563 Mtetra
.45377 .35563 .46007 .3626 .47112 .35883 .46484 .35183 Mtetra
.46484 .35183 .47112 .35883 .4822 .35505 .47595 .34802 Mtetra
.47595 .34802 .4822 .35505 .49333 .35125 .48711 .34419 Mtetra
.48711 .34419 .49333 .35125 .50451 .34743 .49832 .34035 Mtetra
.49832 .34035 .50451 .34743 .51573 .3436 .50957 .33649 Mtetra
.50957 .33649 .51573 .3436 .527 .33975 .52087 .33261 Mtetra
.52087 .33261 .527 .33975 .53832 .33589 .53222 .32872 Mtetra
.53222 .32872 .53832 .33589 .54968 .33201 .54361 .32481 Mtetra
.54361 .32481 .54968 .33201 .56109 .32812 .55505 .32089 Mtetra
.55505 .32089 .56109 .32812 .57255 .32421 .56654 .31695 Mtetra
.56654 .31695 .57255 .32421 .58405 .32028 .57808 .31299 Mtetra
.57808 .31299 .58405 .32028 .5956 .31634 .58966 .30902 Mtetra
.58966 .30902 .5956 .31634 .6072 .31238 .60129 .30503 Mtetra
.60129 .30503 .6072 .31238 .61885 .3084 .61297 .30102 Mtetra
.61297 .30102 .61885 .3084 .63055 .30441 .6247 .297 Mtetra
.6247 .297 .63055 .30441 .64229 .3004 .63648 .29296 Mtetra
.63648 .29296 .64229 .3004 .65409 .29638 .64831 .2889 Mtetra
.64831 .2889 .65409 .29638 .66593 .29233 .66019 .28483 Mtetra
.66019 .28483 .66593 .29233 .67783 .28827 .67212 .28073 Mtetra
.67212 .28073 .67783 .28827 .68977 .2842 .6841 .27662 Mtetra
.6841 .27662 .68977 .2842 .70177 .2801 .69613 .2725 Mtetra
.69613 .2725 .70177 .2801 .71382 .27599 .70821 .26835 Mtetra
.70821 .26835 .71382 .27599 .72591 .27186 .72035 .26419 Mtetra
.72035 .26419 .72591 .27186 .73806 .26771 .73253 .26001 Mtetra
.73253 .26001 .73806 .26771 .75026 .26355 .74477 .25581 Mtetra
.74477 .25581 .75026 .26355 .76252 .25937 .75706 .2516 Mtetra
.75706 .2516 .76252 .25937 .77482 .25517 .7694 .24736 Mtetra
.7694 .24736 .77482 .25517 .78718 .25095 .7818 .24311 Mtetra
.12449 .45992 .13161 .46613 .1414 .46277 .13431 .45654 Mtetra
.13431 .45654 .1414 .46277 .15123 .4594 .14416 .45314 Mtetra
.14416 .45314 .15123 .4594 .1611 .45602 .15405 .44973 Mtetra
.15405 .44973 .1611 .45602 .17101 .45262 .16398 .44631 Mtetra
.16398 .44631 .17101 .45262 .18096 .44921 .17395 .44287 Mtetra
.17395 .44287 .18096 .44921 .19094 .44578 .18396 .43942 Mtetra
.18396 .43942 .19094 .44578 .20097 .44234 .194 .43596 Mtetra
.194 .43596 .20097 .44234 .21103 .43889 .20409 .43248 Mtetra
.20409 .43248 .21103 .43889 .22113 .43543 .21421 .42899 Mtetra
.21421 .42899 .22113 .43543 .23127 .43195 .22437 .42549 Mtetra
.22437 .42549 .23127 .43195 .24145 .42846 .23458 .42197 Mtetra
.23458 .42197 .24145 .42846 .25167 .42495 .24482 .41844 Mtetra
.24482 .41844 .25167 .42495 .26193 .42143 .25511 .4149 Mtetra
.25511 .4149 .26193 .42143 .27223 .4179 .26543 .41134 Mtetra
.26543 .41134 .27223 .4179 .28258 .41435 .2758 .40776 Mtetra
.2758 .40776 .28258 .41435 .29296 .41079 .28621 .40418 Mtetra
.28621 .40418 .29296 .41079 .30338 .40721 .29665 .40057 Mtetra
.29665 .40057 .30338 .40721 .31385 .40362 .30714 .39696 Mtetra
.30714 .39696 .31385 .40362 .32435 .40002 .31768 .39333 Mtetra
.31768 .39333 .32435 .40002 .3349 .3964 .32825 .38968 Mtetra
.32825 .38968 .3349 .3964 .34549 .39277 .33887 .38602 Mtetra
.33887 .38602 .34549 .39277 .35613 .38912 .34952 .38235 Mtetra
.34952 .38235 .35613 .38912 .3668 .38546 .36023 .37866 Mtetra
.36023 .37866 .3668 .38546 .37752 .38178 .37097 .37496 Mtetra
.37097 .37496 .37752 .38178 .38828 .37809 .38176 .37124 Mtetra
.38176 .37124 .38828 .37809 .39908 .37439 .39259 .3675 Mtetra
.39259 .3675 .39908 .37439 .40993 .37067 .40347 .36376 Mtetra
.40347 .36376 .40993 .37067 .42083 .36693 .41439 .35999 Mtetra
.41439 .35999 .42083 .36693 .43176 .36318 .42535 .35621 Mtetra
.42535 .35621 .43176 .36318 .44274 .35941 .43636 .35242 Mtetra
.43636 .35242 .44274 .35941 .45377 .35563 .44741 .34861 Mtetra
.44741 .34861 .45377 .35563 .46484 .35183 .45851 .34478 Mtetra
.45851 .34478 .46484 .35183 .47595 .34802 .46966 .34094 Mtetra
.46966 .34094 .47595 .34802 .48711 .34419 .48085 .33708 Mtetra
.48085 .33708 .48711 .34419 .49832 .34035 .49208 .33321 Mtetra
.49208 .33321 .49832 .34035 .50957 .33649 .50337 .32932 Mtetra
.50337 .32932 .50957 .33649 .52087 .33261 .5147 .32541 Mtetra
.5147 .32541 .52087 .33261 .53222 .32872 .52607 .32149 Mtetra
.52607 .32149 .53222 .32872 .54361 .32481 .5375 .31755 Mtetra
.5375 .31755 .54361 .32481 .55505 .32089 .54897 .3136 Mtetra
.54897 .3136 .55505 .32089 .56654 .31695 .56049 .30963 Mtetra
.56049 .30963 .56654 .31695 .57808 .31299 .57206 .30564 Mtetra
.57206 .30564 .57808 .31299 .58966 .30902 .58367 .30164 Mtetra
.58367 .30164 .58966 .30902 .60129 .30503 .59534 .29762 Mtetra
.59534 .29762 .60129 .30503 .61297 .30102 .60705 .29358 Mtetra
.60705 .29358 .61297 .30102 .6247 .297 .61881 .28952 Mtetra
.61881 .28952 .6247 .297 .63648 .29296 .63063 .28545 Mtetra
.63063 .28545 .63648 .29296 .64831 .2889 .64249 .28136 Mtetra
.64249 .28136 .64831 .2889 .66019 .28483 .6544 .27726 Mtetra
.6544 .27726 .66019 .28483 .67212 .28073 .66637 .27313 Mtetra
.66637 .27313 .67212 .28073 .6841 .27662 .67838 .26899 Mtetra
.67838 .26899 .6841 .27662 .69613 .2725 .69045 .26483 Mtetra
.69045 .26483 .69613 .2725 .70821 .26835 .70256 .26066 Mtetra
.70256 .26066 .70821 .26835 .72035 .26419 .71473 .25646 Mtetra
.71473 .25646 .72035 .26419 .73253 .26001 .72695 .25225 Mtetra
.72695 .25225 .73253 .26001 .74477 .25581 .73923 .24802 Mtetra
.73923 .24802 .74477 .25581 .75706 .2516 .75156 .24377 Mtetra
.75156 .24377 .75706 .2516 .7694 .24736 .76394 .2395 Mtetra
.76394 .2395 .7694 .24736 .7818 .24311 .77637 .23521 Mtetra
.11732 .45366 .12449 .45992 .13431 .45654 .12716 .45026 Mtetra
.12716 .45026 .13431 .45654 .14416 .45314 .13703 .44684 Mtetra
.13703 .44684 .14416 .45314 .15405 .44973 .14695 .4434 Mtetra
.14695 .4434 .15405 .44973 .16398 .44631 .1569 .43995 Mtetra
.1569 .43995 .16398 .44631 .17395 .44287 .16689 .43649 Mtetra
.16689 .43649 .17395 .44287 .18396 .43942 .17692 .43302 Mtetra
.17692 .43302 .18396 .43942 .194 .43596 .18699 .42953 Mtetra
.18699 .42953 .194 .43596 .20409 .43248 .19709 .42603 Mtetra
.19709 .42603 .20409 .43248 .21421 .42899 .20724 .42251 Mtetra
.20724 .42251 .21421 .42899 .22437 .42549 .21743 .41899 Mtetra
.21743 .41899 .22437 .42549 .23458 .42197 .22766 .41544 Mtetra
.22766 .41544 .23458 .42197 .24482 .41844 .23792 .41189 Mtetra
.23792 .41189 .24482 .41844 .25511 .4149 .24823 .40831 Mtetra
.24823 .40831 .25511 .4149 .26543 .41134 .25858 .40473 Mtetra
.25858 .40473 .26543 .41134 .2758 .40776 .26897 .40113 Mtetra
.26897 .40113 .2758 .40776 .28621 .40418 .2794 .39752 Mtetra
.2794 .39752 .28621 .40418 .29665 .40057 .28988 .39389 Mtetra
.28988 .39389 .29665 .40057 .30714 .39696 .30039 .39025 Mtetra
.30039 .39025 .30714 .39696 .31768 .39333 .31095 .38659 Mtetra
.31095 .38659 .31768 .39333 .32825 .38968 .32155 .38292 Mtetra
.32155 .38292 .32825 .38968 .33887 .38602 .33219 .37923 Mtetra
.33219 .37923 .33887 .38602 .34952 .38235 .34288 .37553 Mtetra
.34288 .37553 .34952 .38235 .36023 .37866 .3536 .37181 Mtetra
.3536 .37181 .36023 .37866 .37097 .37496 .36437 .36808 Mtetra
.36437 .36808 .37097 .37496 .38176 .37124 .37519 .36433 Mtetra
.37519 .36433 .38176 .37124 .39259 .3675 .38605 .36057 Mtetra
.38605 .36057 .39259 .3675 .40347 .36376 .39695 .35679 Mtetra
.39695 .35679 .40347 .36376 .41439 .35999 .4079 .353 Mtetra
.4079 .353 .41439 .35999 .42535 .35621 .41889 .34919 Mtetra
.41889 .34919 .42535 .35621 .43636 .35242 .42993 .34537 Mtetra
.42993 .34537 .43636 .35242 .44741 .34861 .44101 .34153 Mtetra
.44101 .34153 .44741 .34861 .45851 .34478 .45214 .33768 Mtetra
.45214 .33768 .45851 .34478 .46966 .34094 .46331 .33381 Mtetra
.46331 .33381 .46966 .34094 .48085 .33708 .47453 .32992 Mtetra
.47453 .32992 .48085 .33708 .49208 .33321 .4858 .32602 Mtetra
.4858 .32602 .49208 .33321 .50337 .32932 .49711 .3221 Mtetra
.49711 .3221 .50337 .32932 .5147 .32541 .50847 .31816 Mtetra
.50847 .31816 .5147 .32541 .52607 .32149 .51988 .31421 Mtetra
.51988 .31421 .52607 .32149 .5375 .31755 .53134 .31024 Mtetra
.53134 .31024 .5375 .31755 .54897 .3136 .54284 .30626 Mtetra
.54284 .30626 .54897 .3136 .56049 .30963 .55439 .30226 Mtetra
.55439 .30226 .56049 .30963 .57206 .30564 .56599 .29824 Mtetra
.56599 .29824 .57206 .30564 .58367 .30164 .57764 .2942 Mtetra
.57764 .2942 .58367 .30164 .59534 .29762 .58933 .29015 Mtetra
.58933 .29015 .59534 .29762 .60705 .29358 .60108 .28608 Mtetra
.60108 .28608 .60705 .29358 .61881 .28952 .61288 .28199 Mtetra
.61288 .28199 .61881 .28952 .63063 .28545 .62472 .27789 Mtetra
.62472 .27789 .63063 .28545 .64249 .28136 .63662 .27377 Mtetra
.63662 .27377 .64249 .28136 .6544 .27726 .64857 .26963 Mtetra
.64857 .26963 .6544 .27726 .66637 .27313 .66057 .26547 Mtetra
.66057 .26547 .66637 .27313 .67838 .26899 .67262 .2613 Mtetra
.67262 .2613 .67838 .26899 .69045 .26483 .68472 .25711 Mtetra
.68472 .25711 .69045 .26483 .70256 .26066 .69687 .2529 Mtetra
.69687 .2529 .70256 .26066 .71473 .25646 .70908 .24867 Mtetra
.70908 .24867 .71473 .25646 .72695 .25225 .72133 .24442 Mtetra
.72133 .24442 .72695 .25225 .73923 .24802 .73365 .24016 Mtetra
.73365 .24016 .73923 .24802 .75156 .24377 .74601 .23587 Mtetra
.74601 .23587 .75156 .24377 .76394 .2395 .75843 .23157 Mtetra
.75843 .23157 .76394 .2395 .77637 .23521 .7709 .22725 Mtetra
.1101 .44736 .11732 .45366 .12716 .45026 .11996 .44393 Mtetra
.11996 .44393 .12716 .45026 .13703 .44684 .12986 .44049 Mtetra
.12986 .44049 .13703 .44684 .14695 .4434 .13979 .43703 Mtetra
.13979 .43703 .14695 .4434 .1569 .43995 .14976 .43355 Mtetra
.14976 .43355 .1569 .43995 .16689 .43649 .15978 .43007 Mtetra
.15978 .43007 .16689 .43649 .17692 .43302 .16983 .42657 Mtetra
.16983 .42657 .17692 .43302 .18699 .42953 .17992 .42306 Mtetra
.17992 .42306 .18699 .42953 .19709 .42603 .19005 .41953 Mtetra
.19005 .41953 .19709 .42603 .20724 .42251 .20022 .41599 Mtetra
.20022 .41599 .20724 .42251 .21743 .41899 .21043 .41243 Mtetra
.21043 .41243 .21743 .41899 .22766 .41544 .22068 .40886 Mtetra
.22068 .40886 .22766 .41544 .23792 .41189 .23097 .40528 Mtetra
.23097 .40528 .23792 .41189 .24823 .40831 .24131 .40168 Mtetra
.24131 .40168 .24823 .40831 .25858 .40473 .25168 .39807 Mtetra
.25168 .39807 .25858 .40473 .26897 .40113 .26209 .39445 Mtetra
.26209 .39445 .26897 .40113 .2794 .39752 .27255 .39081 Mtetra
.27255 .39081 .2794 .39752 .28988 .39389 .28305 .38715 Mtetra
.28305 .38715 .28988 .39389 .30039 .39025 .29359 .38348 Mtetra
.29359 .38348 .30039 .39025 .31095 .38659 .30417 .3798 Mtetra
.30417 .3798 .31095 .38659 .32155 .38292 .3148 .3761 Mtetra
.3148 .3761 .32155 .38292 .33219 .37923 .32546 .37238 Mtetra
.32546 .37238 .33219 .37923 .34288 .37553 .33618 .36866 Mtetra
.33618 .36866 .34288 .37553 .3536 .37181 .34693 .36491 Mtetra
.34693 .36491 .3536 .37181 .36437 .36808 .35773 .36115 Mtetra
.35773 .36115 .36437 .36808 .37519 .36433 .36857 .35738 Mtetra
.36857 .35738 .37519 .36433 .38605 .36057 .37946 .35359 Mtetra
.37946 .35359 .38605 .36057 .39695 .35679 .39039 .34978 Mtetra
.39039 .34978 .39695 .35679 .4079 .353 .40136 .34596 Mtetra
.40136 .34596 .4079 .353 .41889 .34919 .41238 .34212 Mtetra
.41238 .34212 .41889 .34919 .42993 .34537 .42345 .33827 Mtetra
.42345 .33827 .42993 .34537 .44101 .34153 .43456 .3344 Mtetra
.43456 .3344 .44101 .34153 .45214 .33768 .44572 .33052 Mtetra
.44572 .33052 .45214 .33768 .46331 .33381 .45692 .32662 Mtetra
.45692 .32662 .46331 .33381 .47453 .32992 .46817 .3227 Mtetra
.46817 .3227 .47453 .32992 .4858 .32602 .47947 .31877 Mtetra
.47947 .31877 .4858 .32602 .49711 .3221 .49081 .31482 Mtetra
.49081 .31482 .49711 .3221 .50847 .31816 .5022 .31085 Mtetra
.5022 .31085 .50847 .31816 .51988 .31421 .51364 .30687 Mtetra
.51364 .30687 .51988 .31421 .53134 .31024 .52513 .30287 Mtetra
.52513 .30287 .53134 .31024 .54284 .30626 .53666 .29886 Mtetra
.53666 .29886 .54284 .30626 .55439 .30226 .54824 .29482 Mtetra
.54824 .29482 .55439 .30226 .56599 .29824 .55988 .29077 Mtetra
.55988 .29077 .56599 .29824 .57764 .2942 .57156 .28671 Mtetra
.57156 .28671 .57764 .2942 .58933 .29015 .58329 .28262 Mtetra
.58329 .28262 .58933 .29015 .60108 .28608 .59507 .27852 Mtetra
.59507 .27852 .60108 .28608 .61288 .28199 .6069 .2744 Mtetra
.6069 .2744 .61288 .28199 .62472 .27789 .61878 .27027 Mtetra
.61878 .27027 .62472 .27789 .63662 .27377 .63071 .26611 Mtetra
.63071 .26611 .63662 .27377 .64857 .26963 .64269 .26194 Mtetra
.64269 .26194 .64857 .26963 .66057 .26547 .65472 .25775 Mtetra
.65472 .25775 .66057 .26547 .67262 .2613 .66681 .25355 Mtetra
.66681 .25355 .67262 .2613 .68472 .25711 .67894 .24932 Mtetra
.67894 .24932 .68472 .25711 .69687 .2529 .69113 .24508 Mtetra
.69113 .24508 .69687 .2529 .70908 .24867 .70337 .24082 Mtetra
.70337 .24082 .70908 .24867 .72133 .24442 .71567 .23653 Mtetra
.71567 .23653 .72133 .24442 .73365 .24016 .72802 .23224 Mtetra
.72802 .23224 .73365 .24016 .74601 .23587 .74042 .22792 Mtetra
.74042 .22792 .74601 .23587 .75843 .23157 .75288 .22358 Mtetra
.75288 .22358 .75843 .23157 .7709 .22725 .76539 .21923 Mtetra
.10283 .44102 .1101 .44736 .11996 .44393 .11271 .43756 Mtetra
.11271 .43756 .11996 .44393 .12986 .44049 .12263 .43409 Mtetra
.12263 .43409 .12986 .44049 .13979 .43703 .13258 .43061 Mtetra
.13258 .43061 .13979 .43703 .14976 .43355 .14258 .42711 Mtetra
.14258 .42711 .14976 .43355 .15978 .43007 .15261 .4236 Mtetra
.15261 .4236 .15978 .43007 .16983 .42657 .16269 .42007 Mtetra
.16269 .42007 .16983 .42657 .17992 .42306 .1728 .41653 Mtetra
.1728 .41653 .17992 .42306 .19005 .41953 .18295 .41298 Mtetra
.18295 .41298 .19005 .41953 .20022 .41599 .19315 .40941 Mtetra
.19315 .40941 .20022 .41599 .21043 .41243 .20338 .40583 Mtetra
.20338 .40583 .21043 .41243 .22068 .40886 .21366 .40224 Mtetra
.21366 .40224 .22068 .40886 .23097 .40528 .22397 .39863 Mtetra
.22397 .39863 .23097 .40528 .24131 .40168 .23433 .39501 Mtetra
.23433 .39501 .24131 .40168 .25168 .39807 .24473 .39137 Mtetra
.24473 .39137 .25168 .39807 .26209 .39445 .25516 .38772 Mtetra
.25516 .38772 .26209 .39445 .27255 .39081 .26565 .38405 Mtetra
.26565 .38405 .27255 .39081 .28305 .38715 .27617 .38037 Mtetra
.27617 .38037 .28305 .38715 .29359 .38348 .28674 .37667 Mtetra
.28674 .37667 .29359 .38348 .30417 .3798 .29734 .37296 Mtetra
.29734 .37296 .30417 .3798 .3148 .3761 .30799 .36923 Mtetra
.30799 .36923 .3148 .3761 .32546 .37238 .31869 .36549 Mtetra
.31869 .36549 .32546 .37238 .33618 .36866 .32943 .36173 Mtetra
.32943 .36173 .33618 .36866 .34693 .36491 .34021 .35796 Mtetra
.34021 .35796 .34693 .36491 .35773 .36115 .35103 .35417 Mtetra
.35103 .35417 .35773 .36115 .36857 .35738 .3619 .35037 Mtetra
.3619 .35037 .36857 .35738 .37946 .35359 .37282 .34655 Mtetra
.37282 .34655 .37946 .35359 .39039 .34978 .38377 .34271 Mtetra
.38377 .34271 .39039 .34978 .40136 .34596 .39478 .33886 Mtetra
.39478 .33886 .40136 .34596 .41238 .34212 .40583 .335 Mtetra
.40583 .335 .41238 .34212 .42345 .33827 .41692 .33112 Mtetra
.41692 .33112 .42345 .33827 .43456 .3344 .42806 .32722 Mtetra
.42806 .32722 .43456 .3344 .44572 .33052 .43925 .3233 Mtetra
.43925 .3233 .44572 .33052 .45692 .32662 .45048 .31937 Mtetra
.45048 .31937 .45692 .32662 .46817 .3227 .46176 .31543 Mtetra
.46176 .31543 .46817 .3227 .47947 .31877 .47309 .31146 Mtetra
.47309 .31146 .47947 .31877 .49081 .31482 .48446 .30748 Mtetra
.48446 .30748 .49081 .31482 .5022 .31085 .49588 .30349 Mtetra
.49588 .30349 .5022 .31085 .51364 .30687 .50735 .29948 Mtetra
.50735 .29948 .51364 .30687 .52513 .30287 .51887 .29545 Mtetra
.51887 .29545 .52513 .30287 .53666 .29886 .53043 .2914 Mtetra
.53043 .2914 .53666 .29886 .54824 .29482 .54205 .28733 Mtetra
.54205 .28733 .54824 .29482 .55988 .29077 .55371 .28325 Mtetra
.55371 .28325 .55988 .29077 .57156 .28671 .56543 .27915 Mtetra
.56543 .27915 .57156 .28671 .58329 .28262 .57719 .27504 Mtetra
.57719 .27504 .58329 .28262 .59507 .27852 .589 .27091 Mtetra
.589 .27091 .59507 .27852 .6069 .2744 .60087 .26675 Mtetra
.60087 .26675 .6069 .2744 .61878 .27027 .61278 .26259 Mtetra
.61278 .26259 .61878 .27027 .63071 .26611 .62475 .2584 Mtetra
.62475 .2584 .63071 .26611 .64269 .26194 .63676 .25419 Mtetra
.63676 .25419 .64269 .26194 .65472 .25775 .64883 .24997 Mtetra
.64883 .24997 .65472 .25775 .66681 .25355 .66095 .24573 Mtetra
.66095 .24573 .66681 .25355 .67894 .24932 .67312 .24147 Mtetra
.67312 .24147 .67894 .24932 .69113 .24508 .68535 .23719 Mtetra
.68535 .23719 .69113 .24508 .70337 .24082 .69763 .2329 Mtetra
.69763 .2329 .70337 .24082 .71567 .23653 .70996 .22858 Mtetra
.70996 .22858 .71567 .23653 .72802 .23224 .72234 .22425 Mtetra
.72234 .22425 .72802 .23224 .74042 .22792 .73478 .2199 Mtetra
.73478 .2199 .74042 .22792 .75288 .22358 .74728 .21553 Mtetra
.74728 .21553 .75288 .22358 .76539 .21923 .75983 .21113 Mtetra
.09551 .43462 .10283 .44102 .11271 .43756 .10541 .43114 Mtetra
.10541 .43114 .11271 .43756 .12263 .43409 .11535 .42765 Mtetra
.11535 .42765 .12263 .43409 .13258 .43061 .12532 .42414 Mtetra
.12532 .42414 .13258 .43061 .14258 .42711 .13534 .42062 Mtetra
.13534 .42062 .14258 .42711 .15261 .4236 .1454 .41708 Mtetra
.1454 .41708 .15261 .4236 .16269 .42007 .15549 .41353 Mtetra
.15549 .41353 .16269 .42007 .1728 .41653 .16563 .40996 Mtetra
.16563 .40996 .1728 .41653 .18295 .41298 .17581 .40639 Mtetra
.17581 .40639 .18295 .41298 .19315 .40941 .18602 .40279 Mtetra
.18602 .40279 .19315 .40941 .20338 .40583 .19628 .39919 Mtetra
.19628 .39919 .20338 .40583 .21366 .40224 .20658 .39556 Mtetra
.20658 .39556 .21366 .40224 .22397 .39863 .21692 .39193 Mtetra
.21692 .39193 .22397 .39863 .23433 .39501 .2273 .38828 Mtetra
.2273 .38828 .23433 .39501 .24473 .39137 .23772 .38461 Mtetra
.23772 .38461 .24473 .39137 .25516 .38772 .24819 .38093 Mtetra
.24819 .38093 .25516 .38772 .26565 .38405 .25869 .37724 Mtetra
.25869 .37724 .26565 .38405 .27617 .38037 .26924 .37353 Mtetra
.26924 .37353 .27617 .38037 .28674 .37667 .27983 .3698 Mtetra
.27983 .3698 .28674 .37667 .29734 .37296 .29046 .36606 Mtetra
.29046 .36606 .29734 .37296 .30799 .36923 .30114 .36231 Mtetra
.30114 .36231 .30799 .36923 .31869 .36549 .31186 .35854 Mtetra
.31186 .35854 .31869 .36549 .32943 .36173 .32263 .35475 Mtetra
.32263 .35475 .32943 .36173 .34021 .35796 .33343 .35095 Mtetra
.33343 .35095 .34021 .35796 .35103 .35417 .34429 .34714 Mtetra
.34429 .34714 .35103 .35417 .3619 .35037 .35518 .34331 Mtetra
.35518 .34331 .3619 .35037 .37282 .34655 .36612 .33946 Mtetra
.36612 .33946 .37282 .34655 .38377 .34271 .37711 .33559 Mtetra
.37711 .33559 .38377 .34271 .39478 .33886 .38814 .33171 Mtetra
.38814 .33171 .39478 .33886 .40583 .335 .39922 .32782 Mtetra
.39922 .32782 .40583 .335 .41692 .33112 .41034 .32391 Mtetra
.41034 .32391 .41692 .33112 .42806 .32722 .42151 .31998 Mtetra
.42151 .31998 .42806 .32722 .43925 .3233 .43273 .31604 Mtetra
.43273 .31604 .43925 .3233 .45048 .31937 .44399 .31208 Mtetra
.44399 .31208 .45048 .31937 .46176 .31543 .4553 .3081 Mtetra
.4553 .3081 .46176 .31543 .47309 .31146 .46666 .3041 Mtetra
.46666 .3041 .47309 .31146 .48446 .30748 .47806 .30009 Mtetra
.47806 .30009 .48446 .30748 .49588 .30349 .48951 .29607 Mtetra
.48951 .29607 .49588 .30349 .50735 .29948 .50101 .29202 Mtetra
.50101 .29202 .50735 .29948 .51887 .29545 .51256 .28796 Mtetra
.51256 .28796 .51887 .29545 .53043 .2914 .52416 .28388 Mtetra
.52416 .28388 .53043 .2914 .54205 .28733 .53581 .27979 Mtetra
.53581 .27979 .54205 .28733 .55371 .28325 .5475 .27567 Mtetra
.5475 .27567 .55371 .28325 .56543 .27915 .55925 .27154 Mtetra
.55925 .27154 .56543 .27915 .57719 .27504 .57105 .26739 Mtetra
.57105 .26739 .57719 .27504 .589 .27091 .58289 .26323 Mtetra
.58289 .26323 .589 .27091 .60087 .26675 .59479 .25904 Mtetra
.59479 .25904 .60087 .26675 .61278 .26259 .60674 .25484 Mtetra
.60674 .25484 .61278 .26259 .62475 .2584 .61874 .25062 Mtetra
.61874 .25062 .62475 .2584 .63676 .25419 .63079 .24638 Mtetra
.63079 .24638 .63676 .25419 .64883 .24997 .64289 .24213 Mtetra
.64289 .24213 .64883 .24997 .66095 .24573 .65505 .23785 Mtetra
.65505 .23785 .66095 .24573 .67312 .24147 .66726 .23356 Mtetra
.66726 .23356 .67312 .24147 .68535 .23719 .67952 .22925 Mtetra
.67952 .22925 .68535 .23719 .69763 .2329 .69183 .22492 Mtetra
.69183 .22492 .69763 .2329 .70996 .22858 .7042 .22057 Mtetra
.7042 .22057 .70996 .22858 .72234 .22425 .71663 .2162 Mtetra
.71663 .2162 .72234 .22425 .73478 .2199 .7291 .21181 Mtetra
.7291 .21181 .73478 .2199 .74728 .21553 .74163 .2074 Mtetra
.74163 .2074 .74728 .21553 .75983 .21113 .75422 .20298 Mtetra
.08813 .42819 .09551 .43462 .10541 .43114 .09805 .42468 Mtetra
.09805 .42468 .10541 .43114 .11535 .42765 .10801 .42116 Mtetra
.10801 .42116 .11535 .42765 .12532 .42414 .11801 .41762 Mtetra
.11801 .41762 .12532 .42414 .13534 .42062 .12805 .41408 Mtetra
.12805 .41408 .13534 .42062 .1454 .41708 .13813 .41051 Mtetra
.13813 .41051 .1454 .41708 .15549 .41353 .14825 .40694 Mtetra
.14825 .40694 .15549 .41353 .16563 .40996 .15841 .40335 Mtetra
.15841 .40335 .16563 .40996 .17581 .40639 .16861 .39974 Mtetra
.16861 .39974 .17581 .40639 .18602 .40279 .17885 .39612 Mtetra
.17885 .39612 .18602 .40279 .19628 .39919 .18913 .39249 Mtetra
.18913 .39249 .19628 .39919 .20658 .39556 .19945 .38884 Mtetra
.19945 .38884 .20658 .39556 .21692 .39193 .20981 .38518 Mtetra
.20981 .38518 .21692 .39193 .2273 .38828 .22022 .3815 Mtetra
.22022 .3815 .2273 .38828 .23772 .38461 .23066 .37781 Mtetra
.23066 .37781 .23772 .38461 .24819 .38093 .24115 .3741 Mtetra
.24115 .3741 .24819 .38093 .25869 .37724 .25168 .37038 Mtetra
.25168 .37038 .25869 .37724 .26924 .37353 .26226 .36664 Mtetra
.26226 .36664 .26924 .37353 .27983 .3698 .27287 .36289 Mtetra
.27287 .36289 .27983 .3698 .29046 .36606 .28353 .35912 Mtetra
.28353 .35912 .29046 .36606 .30114 .36231 .29424 .35534 Mtetra
.29424 .35534 .30114 .36231 .31186 .35854 .30498 .35154 Mtetra
.30498 .35154 .31186 .35854 .32263 .35475 .31577 .34773 Mtetra
.31577 .34773 .32263 .35475 .33343 .35095 .32661 .3439 Mtetra
.32661 .3439 .33343 .35095 .34429 .34714 .33749 .34005 Mtetra
.33749 .34005 .34429 .34714 .35518 .34331 .34841 .33619 Mtetra
.34841 .33619 .35518 .34331 .36612 .33946 .35938 .33231 Mtetra
.35938 .33231 .36612 .33946 .37711 .33559 .3704 .32842 Mtetra
.3704 .32842 .37711 .33559 .38814 .33171 .38146 .32451 Mtetra
.38146 .32451 .38814 .33171 .39922 .32782 .39256 .32059 Mtetra
.39256 .32059 .39922 .32782 .41034 .32391 .40371 .31664 Mtetra
.40371 .31664 .41034 .32391 .42151 .31998 .41491 .31269 Mtetra
.41491 .31269 .42151 .31998 .43273 .31604 .42616 .30871 Mtetra
.42616 .30871 .43273 .31604 .44399 .31208 .43745 .30472 Mtetra
.43745 .30472 .44399 .31208 .4553 .3081 .44879 .30071 Mtetra
.44879 .30071 .4553 .3081 .46666 .3041 .46018 .29669 Mtetra
.46018 .29669 .46666 .3041 .47806 .30009 .47161 .29265 Mtetra
.47161 .29265 .47806 .30009 .48951 .29607 .48309 .28859 Mtetra
.48309 .28859 .48951 .29607 .50101 .29202 .49463 .28451 Mtetra
.49463 .28451 .50101 .29202 .51256 .28796 .50621 .28042 Mtetra
.50621 .28042 .51256 .28796 .52416 .28388 .51784 .27631 Mtetra
.51784 .27631 .52416 .28388 .53581 .27979 .52952 .27218 Mtetra
.52952 .27218 .53581 .27979 .5475 .27567 .54124 .26803 Mtetra
.54124 .26803 .5475 .27567 .55925 .27154 .55302 .26387 Mtetra
.55302 .26387 .55925 .27154 .57105 .26739 .56485 .25969 Mtetra
.56485 .25969 .57105 .26739 .58289 .26323 .57673 .25549 Mtetra
.57673 .25549 .58289 .26323 .59479 .25904 .58866 .25127 Mtetra
.58866 .25127 .59479 .25904 .60674 .25484 .60065 .24704 Mtetra
.60065 .24704 .60674 .25484 .61874 .25062 .61268 .24278 Mtetra
.61268 .24278 .61874 .25062 .63079 .24638 .62477 .23851 Mtetra
.62477 .23851 .63079 .24638 .64289 .24213 .63691 .23422 Mtetra
.63691 .23422 .64289 .24213 .65505 .23785 .6491 .22991 Mtetra
.6491 .22991 .65505 .23785 .66726 .23356 .66134 .22559 Mtetra
.66134 .22559 .66726 .23356 .67952 .22925 .67364 .22124 Mtetra
.67364 .22124 .67952 .22925 .69183 .22492 .68599 .21687 Mtetra
.68599 .21687 .69183 .22492 .7042 .22057 .6984 .21249 Mtetra
.6984 .21249 .7042 .22057 .71663 .2162 .71086 .20808 Mtetra
.71086 .20808 .71663 .2162 .7291 .21181 .72338 .20366 Mtetra
.72338 .20366 .7291 .21181 .74163 .2074 .73595 .19922 Mtetra
.73595 .19922 .74163 .2074 .75422 .20298 .74857 .19475 Mtetra
.0807 .4217 .08813 .42819 .09805 .42468 .09064 .41817 Mtetra
.09064 .41817 .09805 .42468 .10801 .42116 .10063 .41462 Mtetra
.10063 .41462 .10801 .42116 .11801 .41762 .11065 .41106 Mtetra
.11065 .41106 .11801 .41762 .12805 .41408 .12071 .40749 Mtetra
.12071 .40749 .12805 .41408 .13813 .41051 .13081 .4039 Mtetra
.13081 .4039 .13813 .41051 .14825 .40694 .14095 .4003 Mtetra
.14095 .4003 .14825 .40694 .15841 .40335 .15113 .39668 Mtetra
.15113 .39668 .15841 .40335 .16861 .39974 .16136 .39305 Mtetra
.16136 .39305 .16861 .39974 .17885 .39612 .17162 .3894 Mtetra
.17162 .3894 .17885 .39612 .18913 .39249 .18192 .38574 Mtetra
.18192 .38574 .18913 .39249 .19945 .38884 .19227 .38207 Mtetra
.19227 .38207 .19945 .38884 .20981 .38518 .20266 .37838 Mtetra
.20266 .37838 .20981 .38518 .22022 .3815 .21308 .37467 Mtetra
.21308 .37467 .22022 .3815 .23066 .37781 .22356 .37095 Mtetra
.22356 .37095 .23066 .37781 .24115 .3741 .23407 .36722 Mtetra
.23407 .36722 .24115 .3741 .25168 .37038 .24463 .36347 Mtetra
.24463 .36347 .25168 .37038 .26226 .36664 .25522 .3597 Mtetra
.25522 .3597 .26226 .36664 .27287 .36289 .26587 .35592 Mtetra
.26587 .35592 .27287 .36289 .28353 .35912 .27655 .35213 Mtetra
.27655 .35213 .28353 .35912 .29424 .35534 .28728 .34831 Mtetra
.28728 .34831 .29424 .35534 .30498 .35154 .29805 .34449 Mtetra
.29805 .34449 .30498 .35154 .31577 .34773 .30887 .34064 Mtetra
.30887 .34064 .31577 .34773 .32661 .3439 .31973 .33678 Mtetra
.31973 .33678 .32661 .3439 .33749 .34005 .33064 .33291 Mtetra
.33064 .33291 .33749 .34005 .34841 .33619 .34159 .32902 Mtetra
.34159 .32902 .34841 .33619 .35938 .33231 .35259 .32511 Mtetra
.35259 .32511 .35938 .33231 .3704 .32842 .36363 .32119 Mtetra
.36363 .32119 .3704 .32842 .38146 .32451 .37472 .31725 Mtetra
.37472 .31725 .38146 .32451 .39256 .32059 .38585 .3133 Mtetra
.38585 .3133 .39256 .32059 .40371 .31664 .39703 .30932 Mtetra
.39703 .30932 .40371 .31664 .41491 .31269 .40826 .30533 Mtetra
.40826 .30533 .41491 .31269 .42616 .30871 .41954 .30133 Mtetra
.41954 .30133 .42616 .30871 .43745 .30472 .43086 .29731 Mtetra
.43086 .29731 .43745 .30472 .44879 .30071 .44223 .29327 Mtetra
.44223 .29327 .44879 .30071 .46018 .29669 .45365 .28921 Mtetra
.45365 .28921 .46018 .29669 .47161 .29265 .46511 .28514 Mtetra
.46511 .28514 .47161 .29265 .48309 .28859 .47663 .28105 Mtetra
.47663 .28105 .48309 .28859 .49463 .28451 .48819 .27694 Mtetra
.48819 .27694 .49463 .28451 .50621 .28042 .4998 .27282 Mtetra
.4998 .27282 .50621 .28042 .51784 .27631 .51146 .26867 Mtetra
.51146 .26867 .51784 .27631 .52952 .27218 .52317 .26451 Mtetra
.52317 .26451 .52952 .27218 .54124 .26803 .53494 .26033 Mtetra
.53494 .26033 .54124 .26803 .55302 .26387 .54675 .25614 Mtetra
.54675 .25614 .55302 .26387 .56485 .25969 .55861 .25192 Mtetra
.55861 .25192 .56485 .25969 .57673 .25549 .57053 .24769 Mtetra
.57053 .24769 .57673 .25549 .58866 .25127 .58249 .24344 Mtetra
.58249 .24344 .58866 .25127 .60065 .24704 .59451 .23917 Mtetra
.59451 .23917 .60065 .24704 .61268 .24278 .60658 .23488 Mtetra
.60658 .23488 .61268 .24278 .62477 .23851 .6187 .23058 Mtetra
.6187 .23058 .62477 .23851 .63691 .23422 .63087 .22625 Mtetra
.63087 .22625 .63691 .23422 .6491 .22991 .6431 .22191 Mtetra
.6431 .22191 .6491 .22991 .66134 .22559 .65538 .21755 Mtetra
.65538 .21755 .66134 .22559 .67364 .22124 .66772 .21316 Mtetra
.66772 .21316 .67364 .22124 .68599 .21687 .68011 .20876 Mtetra
.68011 .20876 .68599 .21687 .6984 .21249 .69255 .20434 Mtetra
.69255 .20434 .6984 .21249 .71086 .20808 .70505 .1999 Mtetra
.70505 .1999 .71086 .20808 .72338 .20366 .7176 .19544 Mtetra
.7176 .19544 .72338 .20366 .73595 .19922 .73021 .19096 Mtetra
.73021 .19096 .73595 .19922 .74857 .19475 .74288 .18646 Mtetra
.07322 .41517 .0807 .4217 .09064 .41817 .08318 .41161 Mtetra
.08318 .41161 .09064 .41817 .10063 .41462 .09318 .40804 Mtetra
.09318 .40804 .10063 .41462 .11065 .41106 .10323 .40445 Mtetra
.10323 .40445 .11065 .41106 .12071 .40749 .11331 .40085 Mtetra
.11331 .40085 .12071 .40749 .13081 .4039 .12343 .39724 Mtetra
.12343 .39724 .13081 .4039 .14095 .4003 .1336 .39361 Mtetra
.1336 .39361 .14095 .4003 .15113 .39668 .1438 .38996 Mtetra
.1438 .38996 .15113 .39668 .16136 .39305 .15405 .38631 Mtetra
.15405 .38631 .16136 .39305 .17162 .3894 .16434 .38263 Mtetra
.16434 .38263 .17162 .3894 .18192 .38574 .17466 .37895 Mtetra
.17466 .37895 .18192 .38574 .19227 .38207 .18503 .37524 Mtetra
.18503 .37524 .19227 .38207 .20266 .37838 .19544 .37153 Mtetra
.19544 .37153 .20266 .37838 .21308 .37467 .2059 .36779 Mtetra
.2059 .36779 .21308 .37467 .22356 .37095 .21639 .36404 Mtetra
.21639 .36404 .22356 .37095 .23407 .36722 .22693 .36028 Mtetra
.22693 .36028 .23407 .36722 .24463 .36347 .23751 .3565 Mtetra
.23751 .3565 .24463 .36347 .25522 .3597 .24814 .35271 Mtetra
.24814 .35271 .25522 .3597 .26587 .35592 .2588 .3489 Mtetra
.2588 .3489 .26587 .35592 .27655 .35213 .26952 .34508 Mtetra
.26952 .34508 .27655 .35213 .28728 .34831 .28027 .34124 Mtetra
.28027 .34124 .28728 .34831 .29805 .34449 .29107 .33738 Mtetra
.29107 .33738 .29805 .34449 .30887 .34064 .30192 .33351 Mtetra
.30192 .33351 .30887 .34064 .31973 .33678 .3128 .32962 Mtetra
.3128 .32962 .31973 .33678 .33064 .33291 .32374 .32572 Mtetra
.32374 .32572 .33064 .33291 .34159 .32902 .33472 .32179 Mtetra
.33472 .32179 .34159 .32902 .35259 .32511 .34574 .31786 Mtetra
.34574 .31786 .35259 .32511 .36363 .32119 .35681 .31391 Mtetra
.35681 .31391 .36363 .32119 .37472 .31725 .36793 .30994 Mtetra
.36793 .30994 .37472 .31725 .38585 .3133 .37909 .30595 Mtetra
.37909 .30595 .38585 .3133 .39703 .30932 .3903 .30195 Mtetra
.3903 .30195 .39703 .30932 .40826 .30533 .40156 .29793 Mtetra
.40156 .29793 .40826 .30533 .41954 .30133 .41286 .29389 Mtetra
.41286 .29389 .41954 .30133 .43086 .29731 .42422 .28984 Mtetra
.42422 .28984 .43086 .29731 .44223 .29327 .43562 .28577 Mtetra
.43562 .28577 .44223 .29327 .45365 .28921 .44706 .28168 Mtetra
.44706 .28168 .45365 .28921 .46511 .28514 .45856 .27757 Mtetra
.45856 .27757 .46511 .28514 .47663 .28105 .47011 .27345 Mtetra
.47011 .27345 .47663 .28105 .48819 .27694 .4817 .26931 Mtetra
.4817 .26931 .48819 .27694 .4998 .27282 .49335 .26515 Mtetra
.49335 .26515 .4998 .27282 .51146 .26867 .50504 .26098 Mtetra
.50504 .26098 .51146 .26867 .52317 .26451 .51678 .25678 Mtetra
.51678 .25678 .52317 .26451 .53494 .26033 .52858 .25257 Mtetra
.52858 .25257 .53494 .26033 .54675 .25614 .54042 .24834 Mtetra
.54042 .24834 .54675 .25614 .55861 .25192 .55232 .2441 Mtetra
.55232 .2441 .55861 .25192 .57053 .24769 .56427 .23983 Mtetra
.56427 .23983 .57053 .24769 .58249 .24344 .57627 .23554 Mtetra
.57627 .23554 .58249 .24344 .59451 .23917 .58832 .23124 Mtetra
.58832 .23124 .59451 .23917 .60658 .23488 .60042 .22692 Mtetra
.60042 .22692 .60658 .23488 .6187 .23058 .61258 .22258 Mtetra
.61258 .22258 .6187 .23058 .63087 .22625 .62479 .21822 Mtetra
.62479 .21822 .63087 .22625 .6431 .22191 .63705 .21384 Mtetra
.63705 .21384 .6431 .22191 .65538 .21755 .64937 .20944 Mtetra
.64937 .20944 .65538 .21755 .66772 .21316 .66174 .20502 Mtetra
.66174 .20502 .66772 .21316 .68011 .20876 .67417 .20059 Mtetra
.67417 .20059 .68011 .20876 .69255 .20434 .68665 .19613 Mtetra
.68665 .19613 .69255 .20434 .70505 .1999 .69919 .19165 Mtetra
.69919 .19165 .70505 .1999 .7176 .19544 .71178 .18716 Mtetra
.71178 .18716 .7176 .19544 .73021 .19096 .72443 .18264 Mtetra
.72443 .18264 .73021 .19096 .74288 .18646 .73713 .1781 Mtetra
.06568 .40859 .07322 .41517 .08318 .41161 .07566 .40501 Mtetra
.07566 .40501 .08318 .41161 .09318 .40804 .08569 .40141 Mtetra
.08569 .40141 .09318 .40804 .10323 .40445 .09575 .39779 Mtetra
.09575 .39779 .10323 .40445 .11331 .40085 .10586 .39417 Mtetra
.10586 .39417 .11331 .40085 .12343 .39724 .11601 .39053 Mtetra
.11601 .39053 .12343 .39724 .1336 .39361 .12619 .38687 Mtetra
.12619 .38687 .1336 .39361 .1438 .38996 .13642 .3832 Mtetra
.13642 .3832 .1438 .38996 .15405 .38631 .14669 .37951 Mtetra
.14669 .37951 .15405 .38631 .16434 .38263 .157 .37581 Mtetra
.157 .37581 .16434 .38263 .17466 .37895 .16735 .3721 Mtetra
.16735 .3721 .17466 .37895 .18503 .37524 .17774 .36837 Mtetra
.17774 .36837 .18503 .37524 .19544 .37153 .18818 .36462 Mtetra
.18818 .36462 .19544 .37153 .2059 .36779 .19866 .36086 Mtetra
.19866 .36086 .2059 .36779 .21639 .36404 .20918 .35709 Mtetra
.20918 .35709 .21639 .36404 .22693 .36028 .21974 .35329 Mtetra
.21974 .35329 .22693 .36028 .23751 .3565 .23035 .34949 Mtetra
.23035 .34949 .23751 .3565 .24814 .35271 .241 .34567 Mtetra
.241 .34567 .24814 .35271 .2588 .3489 .25169 .34183 Mtetra
.25169 .34183 .2588 .3489 .26952 .34508 .26243 .33797 Mtetra
.26243 .33797 .26952 .34508 .28027 .34124 .27321 .3341 Mtetra
.27321 .3341 .28027 .34124 .29107 .33738 .28404 .33022 Mtetra
.28404 .33022 .29107 .33738 .30192 .33351 .29491 .32632 Mtetra
.29491 .32632 .30192 .33351 .3128 .32962 .30582 .3224 Mtetra
.30582 .3224 .3128 .32962 .32374 .32572 .31678 .31846 Mtetra
.31678 .31846 .32374 .32572 .33472 .32179 .32779 .31451 Mtetra
.32779 .31451 .33472 .32179 .34574 .31786 .33884 .31055 Mtetra
.33884 .31055 .34574 .31786 .35681 .31391 .34994 .30656 Mtetra
.34994 .30656 .35681 .31391 .36793 .30994 .36109 .30256 Mtetra
.36109 .30256 .36793 .30994 .37909 .30595 .37228 .29855 Mtetra
.37228 .29855 .37909 .30595 .3903 .30195 .38352 .29451 Mtetra
.38352 .29451 .3903 .30195 .40156 .29793 .39481 .29046 Mtetra
.39481 .29046 .40156 .29793 .41286 .29389 .40614 .28639 Mtetra
.40614 .28639 .41286 .29389 .42422 .28984 .41752 .28231 Mtetra
.41752 .28231 .42422 .28984 .43562 .28577 .42895 .27821 Mtetra
.42895 .27821 .43562 .28577 .44706 .28168 .44043 .27409 Mtetra
.44043 .27409 .44706 .28168 .45856 .27757 .45196 .26995 Mtetra
.45196 .26995 .45856 .27757 .47011 .27345 .46354 .26579 Mtetra
.46354 .26579 .47011 .27345 .4817 .26931 .47516 .26162 Mtetra
.47516 .26162 .4817 .26931 .49335 .26515 .48684 .25743 Mtetra
.48684 .25743 .49335 .26515 .50504 .26098 .49856 .25322 Mtetra
.49856 .25322 .50504 .26098 .51678 .25678 .51034 .24899 Mtetra
.51034 .24899 .51678 .25678 .52858 .25257 .52217 .24475 Mtetra
.52217 .24475 .52858 .25257 .54042 .24834 .53405 .24049 Mtetra
.53405 .24049 .54042 .24834 .55232 .2441 .54598 .2362 Mtetra
.54598 .2362 .55232 .2441 .56427 .23983 .55796 .2319 Mtetra
.55796 .2319 .56427 .23983 .57627 .23554 .56999 .22758 Mtetra
.56999 .22758 .57627 .23554 .58832 .23124 .58208 .22325 Mtetra
.58208 .22325 .58832 .23124 .60042 .22692 .59422 .21889 Mtetra
.59422 .21889 .60042 .22692 .61258 .22258 .60641 .21451 Mtetra
.60641 .21451 .61258 .22258 .62479 .21822 .61866 .21012 Mtetra
.61866 .21012 .62479 .21822 .63705 .21384 .63096 .2057 Mtetra
.63096 .2057 .63705 .21384 .64937 .20944 .64331 .20127 Mtetra
.64331 .20127 .64937 .20944 .66174 .20502 .65572 .19682 Mtetra
.65572 .19682 .66174 .20502 .67417 .20059 .66819 .19234 Mtetra
.66819 .19234 .67417 .20059 .68665 .19613 .6807 .18785 Mtetra
.6807 .18785 .68665 .19613 .69919 .19165 .69328 .18334 Mtetra
.69328 .18334 .69919 .19165 .71178 .18716 .70591 .1788 Mtetra
.70591 .1788 .71178 .18716 .72443 .18264 .7186 .17425 Mtetra
.7186 .17425 .72443 .18264 .73713 .1781 .73134 .16968 Mtetra
.05808 .40196 .06568 .40859 .07566 .40501 .06809 .39835 Mtetra
.06809 .39835 .07566 .40501 .08569 .40141 .07814 .39473 Mtetra
.07814 .39473 .08569 .40141 .09575 .39779 .08823 .39109 Mtetra
.08823 .39109 .09575 .39779 .10586 .39417 .09835 .38743 Mtetra
.09835 .38743 .10586 .39417 .11601 .39053 .10852 .38376 Mtetra
.10852 .38376 .11601 .39053 .12619 .38687 .11873 .38008 Mtetra
.11873 .38008 .12619 .38687 .13642 .3832 .12898 .37638 Mtetra
.12898 .37638 .13642 .3832 .14669 .37951 .13927 .37267 Mtetra
.13927 .37267 .14669 .37951 .157 .37581 .14961 .36894 Mtetra
.14961 .36894 .157 .37581 .16735 .3721 .15998 .3652 Mtetra
.15998 .3652 .16735 .3721 .17774 .36837 .1704 .36144 Mtetra
.1704 .36144 .17774 .36837 .18818 .36462 .18086 .35767 Mtetra
.18086 .35767 .18818 .36462 .19866 .36086 .19136 .35388 Mtetra
.19136 .35388 .19866 .36086 .20918 .35709 .20191 .35007 Mtetra
.20191 .35007 .20918 .35709 .21974 .35329 .2125 .34625 Mtetra
.2125 .34625 .21974 .35329 .23035 .34949 .22313 .34242 Mtetra
.22313 .34242 .23035 .34949 .241 .34567 .2338 .33857 Mtetra
.2338 .33857 .241 .34567 .25169 .34183 .24452 .3347 Mtetra
.24452 .3347 .25169 .34183 .26243 .33797 .25529 .33082 Mtetra
.25529 .33082 .26243 .33797 .27321 .3341 .26609 .32692 Mtetra
.26609 .32692 .27321 .3341 .28404 .33022 .27695 .323 Mtetra
.27695 .323 .28404 .33022 .29491 .32632 .28784 .31907 Mtetra
.28784 .31907 .29491 .32632 .30582 .3224 .29879 .31512 Mtetra
.29879 .31512 .30582 .3224 .31678 .31846 .30978 .31116 Mtetra
.30978 .31116 .31678 .31846 .32779 .31451 .32081 .30718 Mtetra
.32081 .30718 .32779 .31451 .33884 .31055 .33189 .30318 Mtetra
.33189 .30318 .33884 .31055 .34994 .30656 .34302 .29917 Mtetra
.34302 .29917 .34994 .30656 .36109 .30256 .35419 .29513 Mtetra
.35419 .29513 .36109 .30256 .37228 .29855 .36541 .29109 Mtetra
.36541 .29109 .37228 .29855 .38352 .29451 .37668 .28702 Mtetra
.37668 .28702 .38352 .29451 .39481 .29046 .388 .28294 Mtetra
.388 .28294 .39481 .29046 .40614 .28639 .39936 .27884 Mtetra
.39936 .27884 .40614 .28639 .41752 .28231 .41077 .27472 Mtetra
.41077 .27472 .41752 .28231 .42895 .27821 .42224 .27059 Mtetra
.42224 .27059 .42895 .27821 .44043 .27409 .43375 .26643 Mtetra
.43375 .26643 .44043 .27409 .45196 .26995 .4453 .26226 Mtetra
.4453 .26226 .45196 .26995 .46354 .26579 .45691 .25808 Mtetra
.45691 .25808 .46354 .26579 .47516 .26162 .46857 .25387 Mtetra
.46857 .25387 .47516 .26162 .48684 .25743 .48028 .24965 Mtetra
.48028 .24965 .48684 .25743 .49856 .25322 .49204 .2454 Mtetra
.49204 .2454 .49856 .25322 .51034 .24899 .50385 .24114 Mtetra
.50385 .24114 .51034 .24899 .52217 .24475 .51571 .23686 Mtetra
.51571 .23686 .52217 .24475 .53405 .24049 .52762 .23257 Mtetra
.52762 .23257 .53405 .24049 .54598 .2362 .53959 .22825 Mtetra
.53959 .22825 .54598 .2362 .55796 .2319 .5516 .22392 Mtetra
.5516 .22392 .55796 .2319 .56999 .22758 .56367 .21956 Mtetra
.56367 .21956 .56999 .22758 .58208 .22325 .57579 .21519 Mtetra
.57579 .21519 .58208 .22325 .59422 .21889 .58797 .2108 Mtetra
.58797 .2108 .59422 .21889 .60641 .21451 .6002 .20638 Mtetra
.6002 .20638 .60641 .21451 .61866 .21012 .61248 .20195 Mtetra
.61248 .20195 .61866 .21012 .63096 .2057 .62481 .1975 Mtetra
.62481 .1975 .63096 .2057 .64331 .20127 .6372 .19303 Mtetra
.6372 .19303 .64331 .20127 .65572 .19682 .64965 .18854 Mtetra
.64965 .18854 .65572 .19682 .66819 .19234 .66215 .18403 Mtetra
.66215 .18403 .66819 .19234 .6807 .18785 .67471 .1795 Mtetra
.67471 .1795 .6807 .18785 .69328 .18334 .68732 .17495 Mtetra
.68732 .17495 .69328 .18334 .70591 .1788 .69999 .17038 Mtetra
.69999 .17038 .70591 .1788 .7186 .17425 .71272 .16579 Mtetra
.71272 .16579 .7186 .17425 .73134 .16968 .7255 .16118 Mtetra
.05043 .39529 .05808 .40196 .06809 .39835 .06046 .39165 Mtetra
.06046 .39165 .06809 .39835 .07814 .39473 .07053 .388 Mtetra
.07053 .388 .07814 .39473 .08823 .39109 .08064 .38433 Mtetra
.08064 .38433 .08823 .39109 .09835 .38743 .09079 .38065 Mtetra
.09079 .38065 .09835 .38743 .10852 .38376 .10098 .37695 Mtetra
.10098 .37695 .10852 .38376 .11873 .38008 .11121 .37324 Mtetra
.11121 .37324 .11873 .38008 .12898 .37638 .12149 .36952 Mtetra
.12149 .36952 .12898 .37638 .13927 .37267 .1318 .36578 Mtetra
.1318 .36578 .13927 .37267 .14961 .36894 .14216 .36202 Mtetra
.14216 .36202 .14961 .36894 .15998 .3652 .15256 .35825 Mtetra
.15256 .35825 .15998 .3652 .1704 .36144 .163 .35446 Mtetra
.163 .35446 .1704 .36144 .18086 .35767 .17348 .35066 Mtetra
.17348 .35066 .18086 .35767 .19136 .35388 .18401 .34684 Mtetra
.18401 .34684 .19136 .35388 .20191 .35007 .19458 .34301 Mtetra
.19458 .34301 .20191 .35007 .2125 .34625 .20519 .33916 Mtetra
.20519 .33916 .2125 .34625 .22313 .34242 .21585 .3353 Mtetra
.21585 .3353 .22313 .34242 .2338 .33857 .22655 .33142 Mtetra
.22655 .33142 .2338 .33857 .24452 .3347 .2373 .32752 Mtetra
.2373 .32752 .24452 .3347 .25529 .33082 .24809 .32361 Mtetra
.24809 .32361 .25529 .33082 .26609 .32692 .25892 .31968 Mtetra
.25892 .31968 .26609 .32692 .27695 .323 .2698 .31573 Mtetra
.2698 .31573 .27695 .323 .28784 .31907 .28073 .31177 Mtetra
.28073 .31177 .28784 .31907 .29879 .31512 .2917 .30779 Mtetra
.2917 .30779 .29879 .31512 .30978 .31116 .30271 .3038 Mtetra
.30271 .3038 .30978 .31116 .32081 .30718 .31378 .29978 Mtetra
.31378 .29978 .32081 .30718 .33189 .30318 .32489 .29576 Mtetra
.32489 .29576 .33189 .30318 .34302 .29917 .33604 .29171 Mtetra
.33604 .29171 .34302 .29917 .35419 .29513 .34724 .28765 Mtetra
.34724 .28765 .35419 .29513 .36541 .29109 .35849 .28357 Mtetra
.35849 .28357 .36541 .29109 .37668 .28702 .36979 .27947 Mtetra
.36979 .27947 .37668 .28702 .388 .28294 .38114 .27536 Mtetra
.38114 .27536 .388 .28294 .39936 .27884 .39253 .27122 Mtetra
.39253 .27122 .39936 .27884 .41077 .27472 .40397 .26707 Mtetra
.40397 .26707 .41077 .27472 .42224 .27059 .41547 .26291 Mtetra
.41547 .26291 .42224 .27059 .43375 .26643 .42701 .25872 Mtetra
.42701 .25872 .43375 .26643 .4453 .26226 .4386 .25452 Mtetra
.4386 .25452 .4453 .26226 .45691 .25808 .45024 .2503 Mtetra
.45024 .2503 .45691 .25808 .46857 .25387 .46193 .24606 Mtetra
.46193 .24606 .46857 .25387 .48028 .24965 .47367 .2418 Mtetra
.47367 .2418 .48028 .24965 .49204 .2454 .48546 .23752 Mtetra
.48546 .23752 .49204 .2454 .50385 .24114 .4973 .23323 Mtetra
.4973 .23323 .50385 .24114 .51571 .23686 .5092 .22892 Mtetra
.5092 .22892 .51571 .23686 .52762 .23257 .52114 .22458 Mtetra
.52114 .22458 .52762 .23257 .53959 .22825 .53314 .22023 Mtetra
.53314 .22023 .53959 .22825 .5516 .22392 .54519 .21586 Mtetra
.54519 .21586 .5516 .22392 .56367 .21956 .5573 .21147 Mtetra
.5573 .21147 .56367 .21956 .57579 .21519 .56945 .20706 Mtetra
.56945 .20706 .57579 .21519 .58797 .2108 .58166 .20264 Mtetra
.58166 .20264 .58797 .2108 .6002 .20638 .59393 .19819 Mtetra
.59393 .19819 .6002 .20638 .61248 .20195 .60625 .19372 Mtetra
.60625 .19372 .61248 .20195 .62481 .1975 .61862 .18923 Mtetra
.61862 .18923 .62481 .1975 .6372 .19303 .63105 .18473 Mtetra
.63105 .18473 .6372 .19303 .64965 .18854 .64353 .1802 Mtetra
.64353 .1802 .64965 .18854 .66215 .18403 .65607 .17565 Mtetra
.65607 .17565 .66215 .18403 .67471 .1795 .66866 .17109 Mtetra
.66866 .17109 .67471 .1795 .68732 .17495 .68132 .1665 Mtetra
.68132 .1665 .68732 .17495 .69999 .17038 .69402 .16189 Mtetra
.69402 .16189 .69999 .17038 .71272 .16579 .70679 .15726 Mtetra
.70679 .15726 .71272 .16579 .7255 .16118 .71961 .15261 Mtetra
.04273 .38856 .05043 .39529 .06046 .39165 .05278 .3849 Mtetra
.05278 .3849 .06046 .39165 .07053 .388 .06287 .38122 Mtetra
.06287 .38122 .07053 .388 .08064 .38433 .073 .37752 Mtetra
.073 .37752 .08064 .38433 .09079 .38065 .08317 .37381 Mtetra
.08317 .37381 .09079 .38065 .10098 .37695 .09339 .37009 Mtetra
.09339 .37009 .10098 .37695 .11121 .37324 .10364 .36635 Mtetra
.10364 .36635 .11121 .37324 .12149 .36952 .11394 .3626 Mtetra
.11394 .3626 .12149 .36952 .1318 .36578 .12428 .35883 Mtetra
.12428 .35883 .1318 .36578 .14216 .36202 .13466 .35505 Mtetra
.13466 .35505 .14216 .36202 .15256 .35825 .14508 .35125 Mtetra
.14508 .35125 .15256 .35825 .163 .35446 .15555 .34743 Mtetra
.15555 .34743 .163 .35446 .17348 .35066 .16605 .3436 Mtetra
.16605 .3436 .17348 .35066 .18401 .34684 .17661 .33975 Mtetra
.17661 .33975 .18401 .34684 .19458 .34301 .1872 .33589 Mtetra
.1872 .33589 .19458 .34301 .20519 .33916 .19784 .33201 Mtetra
.19784 .33201 .20519 .33916 .21585 .3353 .20852 .32812 Mtetra
.20852 .32812 .21585 .3353 .22655 .33142 .21925 .32421 Mtetra
.21925 .32421 .22655 .33142 .2373 .32752 .23002 .32028 Mtetra
.23002 .32028 .2373 .32752 .24809 .32361 .24084 .31634 Mtetra
.24084 .31634 .24809 .32361 .25892 .31968 .2517 .31238 Mtetra
.2517 .31238 .25892 .31968 .2698 .31573 .2626 .3084 Mtetra
.2626 .3084 .2698 .31573 .28073 .31177 .27355 .30441 Mtetra
.27355 .30441 .28073 .31177 .2917 .30779 .28455 .3004 Mtetra
.28455 .3004 .2917 .30779 .30271 .3038 .2956 .29638 Mtetra
.2956 .29638 .30271 .3038 .31378 .29978 .30669 .29233 Mtetra
.30669 .29233 .31378 .29978 .32489 .29576 .31782 .28827 Mtetra
.31782 .28827 .32489 .29576 .33604 .29171 .32901 .2842 Mtetra
.32901 .2842 .33604 .29171 .34724 .28765 .34024 .2801 Mtetra
.34024 .2801 .34724 .28765 .35849 .28357 .35152 .27599 Mtetra
.35152 .27599 .35849 .28357 .36979 .27947 .36285 .27186 Mtetra
.36285 .27186 .36979 .27947 .38114 .27536 .37422 .26771 Mtetra
.37422 .26771 .38114 .27536 .39253 .27122 .38565 .26355 Mtetra
.38565 .26355 .39253 .27122 .40397 .26707 .39712 .25937 Mtetra
.39712 .25937 .40397 .26707 .41547 .26291 .40864 .25517 Mtetra
.40864 .25517 .41547 .26291 .42701 .25872 .42021 .25095 Mtetra
.42021 .25095 .42701 .25872 .4386 .25452 .43184 .24671 Mtetra
.43184 .24671 .4386 .25452 .45024 .2503 .44351 .24246 Mtetra
.44351 .24246 .45024 .2503 .46193 .24606 .45523 .23818 Mtetra
.45523 .23818 .46193 .24606 .47367 .2418 .467 .23389 Mtetra
.467 .23389 .47367 .2418 .48546 .23752 .47883 .22958 Mtetra
.47883 .22958 .48546 .23752 .4973 .23323 .4907 .22525 Mtetra
.4907 .22525 .4973 .23323 .5092 .22892 .50263 .2209 Mtetra
.50263 .2209 .5092 .22892 .52114 .22458 .51461 .21654 Mtetra
.51461 .21654 .52114 .22458 .53314 .22023 .52664 .21215 Mtetra
.52664 .21215 .53314 .22023 .54519 .21586 .53873 .20774 Mtetra
.53873 .20774 .54519 .21586 .5573 .21147 .55087 .20332 Mtetra
.55087 .20332 .5573 .21147 .56945 .20706 .56306 .19887 Mtetra
.56306 .19887 .56945 .20706 .58166 .20264 .57531 .19441 Mtetra
.57531 .19441 .58166 .20264 .59393 .19819 .58761 .18993 Mtetra
.58761 .18993 .59393 .19819 .60625 .19372 .59996 .18542 Mtetra
.59996 .18542 .60625 .19372 .61862 .18923 .61237 .1809 Mtetra
.61237 .1809 .61862 .18923 .63105 .18473 .62484 .17635 Mtetra
.62484 .17635 .63105 .18473 .64353 .1802 .63736 .17179 Mtetra
.63736 .17179 .64353 .1802 .65607 .17565 .64994 .1672 Mtetra
.64994 .1672 .65607 .17565 .66866 .17109 .66257 .1626 Mtetra
.66257 .1626 .66866 .17109 .68132 .1665 .67526 .15797 Mtetra
.67526 .15797 .68132 .1665 .69402 .16189 .68801 .15333 Mtetra
.68801 .15333 .69402 .16189 .70679 .15726 .70081 .14866 Mtetra
.70081 .14866 .70679 .15726 .71961 .15261 .71368 .14397 Mtetra
.03496 .38178 .04273 .38856 .05278 .3849 .04504 .37809 Mtetra
.04504 .37809 .05278 .3849 .06287 .38122 .05515 .37439 Mtetra
.05515 .37439 .06287 .38122 .073 .37752 .0653 .37067 Mtetra
.0653 .37067 .073 .37752 .08317 .37381 .0755 .36693 Mtetra
.0755 .36693 .08317 .37381 .09339 .37009 .08573 .36318 Mtetra
.08573 .36318 .09339 .37009 .10364 .36635 .09601 .35941 Mtetra
.09601 .35941 .10364 .36635 .11394 .3626 .10633 .35563 Mtetra
.10633 .35563 .11394 .3626 .12428 .35883 .11669 .35183 Mtetra
.11669 .35183 .12428 .35883 .13466 .35505 .1271 .34802 Mtetra
.1271 .34802 .13466 .35505 .14508 .35125 .13754 .34419 Mtetra
.13754 .34419 .14508 .35125 .15555 .34743 .14803 .34035 Mtetra
.14803 .34035 .15555 .34743 .16605 .3436 .15857 .33649 Mtetra
.15857 .33649 .16605 .3436 .17661 .33975 .16914 .33261 Mtetra
.16914 .33261 .17661 .33975 .1872 .33589 .17976 .32872 Mtetra
.17976 .32872 .1872 .33589 .19784 .33201 .19043 .32481 Mtetra
.19043 .32481 .19784 .33201 .20852 .32812 .20113 .32089 Mtetra
.20113 .32089 .20852 .32812 .21925 .32421 .21189 .31695 Mtetra
.21189 .31695 .21925 .32421 .23002 .32028 .22268 .31299 Mtetra
.22268 .31299 .23002 .32028 .24084 .31634 .23353 .30902 Mtetra
.23353 .30902 .24084 .31634 .2517 .31238 .24441 .30503 Mtetra
.24441 .30503 .2517 .31238 .2626 .3084 .25535 .30102 Mtetra
.25535 .30102 .2626 .3084 .27355 .30441 .26633 .297 Mtetra
.26633 .297 .27355 .30441 .28455 .3004 .27735 .29296 Mtetra
.27735 .29296 .28455 .3004 .2956 .29638 .28842 .2889 Mtetra
.28842 .2889 .2956 .29638 .30669 .29233 .29954 .28483 Mtetra
.29954 .28483 .30669 .29233 .31782 .28827 .31071 .28073 Mtetra
.31071 .28073 .31782 .28827 .32901 .2842 .32192 .27662 Mtetra
.32192 .27662 .32901 .2842 .34024 .2801 .33318 .2725 Mtetra
.33318 .2725 .34024 .2801 .35152 .27599 .34449 .26835 Mtetra
.34449 .26835 .35152 .27599 .36285 .27186 .35585 .26419 Mtetra
.35585 .26419 .36285 .27186 .37422 .26771 .36725 .26001 Mtetra
.36725 .26001 .37422 .26771 .38565 .26355 .37871 .25581 Mtetra
.37871 .25581 .38565 .26355 .39712 .25937 .39021 .2516 Mtetra
.39021 .2516 .39712 .25937 .40864 .25517 .40177 .24736 Mtetra
.40177 .24736 .40864 .25517 .42021 .25095 .41337 .24311 Mtetra
.41337 .24311 .42021 .25095 .43184 .24671 .42502 .23884 Mtetra
.42502 .23884 .43184 .24671 .44351 .24246 .43673 .23455 Mtetra
.43673 .23455 .44351 .24246 .45523 .23818 .44848 .23025 Mtetra
.44848 .23025 .45523 .23818 .467 .23389 .46029 .22592 Mtetra
.46029 .22592 .467 .23389 .47883 .22958 .47214 .22157 Mtetra
.47214 .22157 .47883 .22958 .4907 .22525 .48405 .21721 Mtetra
.48405 .21721 .4907 .22525 .50263 .2209 .49601 .21283 Mtetra
.49601 .21283 .50263 .2209 .51461 .21654 .50803 .20842 Mtetra
.50803 .20842 .51461 .21654 .52664 .21215 .5201 .204 Mtetra
.5201 .204 .52664 .21215 .53873 .20774 .53222 .19956 Mtetra
.53222 .19956 .53873 .20774 .55087 .20332 .54439 .1951 Mtetra
.54439 .1951 .55087 .20332 .56306 .19887 .55662 .19062 Mtetra
.55662 .19062 .56306 .19887 .57531 .19441 .5689 .18612 Mtetra
.5689 .18612 .57531 .19441 .58761 .18993 .58124 .1816 Mtetra
.58124 .1816 .58761 .18993 .59996 .18542 .59363 .17705 Mtetra
.59363 .17705 .59996 .18542 .61237 .1809 .60607 .17249 Mtetra
.60607 .17249 .61237 .1809 .62484 .17635 .61858 .16791 Mtetra
.61858 .16791 .62484 .17635 .63736 .17179 .63114 .16331 Mtetra
.63114 .16331 .63736 .17179 .64994 .1672 .64375 .15869 Mtetra
.64375 .15869 .64994 .1672 .66257 .1626 .65642 .15404 Mtetra
.65642 .15404 .66257 .1626 .67526 .15797 .66915 .14938 Mtetra
.66915 .14938 .67526 .15797 .68801 .15333 .68194 .14469 Mtetra
.68194 .14469 .68801 .15333 .70081 .14866 .69479 .13998 Mtetra
.69479 .13998 .70081 .14866 .71368 .14397 .70769 .13525 Mtetra
.02714 .37496 .03496 .38178 .04504 .37809 .03724 .37124 Mtetra
.03724 .37124 .04504 .37809 .05515 .37439 .04737 .3675 Mtetra
.04737 .3675 .05515 .37439 .0653 .37067 .05755 .36376 Mtetra
.05755 .36376 .0653 .37067 .0755 .36693 .06776 .35999 Mtetra
.06776 .35999 .0755 .36693 .08573 .36318 .07802 .35621 Mtetra
.07802 .35621 .08573 .36318 .09601 .35941 .08832 .35242 Mtetra
.08832 .35242 .09601 .35941 .10633 .35563 .09867 .34861 Mtetra
.09867 .34861 .10633 .35563 .11669 .35183 .10905 .34478 Mtetra
.10905 .34478 .11669 .35183 .1271 .34802 .11948 .34094 Mtetra
.11948 .34094 .1271 .34802 .13754 .34419 .12995 .33708 Mtetra
.12995 .33708 .13754 .34419 .14803 .34035 .14047 .33321 Mtetra
.14047 .33321 .14803 .34035 .15857 .33649 .15102 .32932 Mtetra
.15102 .32932 .15857 .33649 .16914 .33261 .16162 .32541 Mtetra
.16162 .32541 .16914 .33261 .17976 .32872 .17227 .32149 Mtetra
.17227 .32149 .17976 .32872 .19043 .32481 .18296 .31755 Mtetra
.18296 .31755 .19043 .32481 .20113 .32089 .19369 .3136 Mtetra
.19369 .3136 .20113 .32089 .21189 .31695 .20447 .30963 Mtetra
.20447 .30963 .21189 .31695 .22268 .31299 .21529 .30564 Mtetra
.21529 .30564 .22268 .31299 .23353 .30902 .22616 .30164 Mtetra
.22616 .30164 .23353 .30902 .24441 .30503 .23708 .29762 Mtetra
.23708 .29762 .24441 .30503 .25535 .30102 .24804 .29358 Mtetra
.24804 .29358 .25535 .30102 .26633 .297 .25904 .28952 Mtetra
.25904 .28952 .26633 .297 .27735 .29296 .2701 .28545 Mtetra
.2701 .28545 .27735 .29296 .28842 .2889 .2812 .28136 Mtetra
.2812 .28136 .28842 .2889 .29954 .28483 .29234 .27726 Mtetra
.29234 .27726 .29954 .28483 .31071 .28073 .30354 .27313 Mtetra
.30354 .27313 .31071 .28073 .32192 .27662 .31478 .26899 Mtetra
.31478 .26899 .32192 .27662 .33318 .2725 .32607 .26483 Mtetra
.32607 .26483 .33318 .2725 .34449 .26835 .33741 .26066 Mtetra
.33741 .26066 .34449 .26835 .35585 .26419 .34879 .25646 Mtetra
.34879 .25646 .35585 .26419 .36725 .26001 .36023 .25225 Mtetra
.36023 .25225 .36725 .26001 .37871 .25581 .37171 .24802 Mtetra
.37171 .24802 .37871 .25581 .39021 .2516 .38325 .24377 Mtetra
.38325 .24377 .39021 .2516 .40177 .24736 .39483 .2395 Mtetra
.39483 .2395 .40177 .24736 .41337 .24311 .40647 .23521 Mtetra
.40647 .23521 .41337 .24311 .42502 .23884 .41815 .23091 Mtetra
.41815 .23091 .42502 .23884 .43673 .23455 .42989 .22659 Mtetra
.42989 .22659 .43673 .23455 .44848 .23025 .44168 .22224 Mtetra
.44168 .22224 .44848 .23025 .46029 .22592 .45351 .21788 Mtetra
.45351 .21788 .46029 .22592 .47214 .22157 .46541 .2135 Mtetra
.46541 .2135 .47214 .22157 .48405 .21721 .47735 .2091 Mtetra
.47735 .2091 .48405 .21721 .49601 .21283 .48934 .20468 Mtetra
.48934 .20468 .49601 .21283 .50803 .20842 .50139 .20024 Mtetra
.50139 .20024 .50803 .20842 .5201 .204 .51349 .19579 Mtetra
.51349 .19579 .5201 .204 .53222 .19956 .52565 .19131 Mtetra
.52565 .19131 .53222 .19956 .54439 .1951 .53786 .18681 Mtetra
.53786 .18681 .54439 .1951 .55662 .19062 .55012 .18229 Mtetra
.55012 .18229 .55662 .19062 .5689 .18612 .56244 .17775 Mtetra
.56244 .17775 .5689 .18612 .58124 .1816 .57481 .1732 Mtetra
.57481 .1732 .58124 .1816 .59363 .17705 .58724 .16862 Mtetra
.58724 .16862 .59363 .17705 .60607 .17249 .59972 .16402 Mtetra
.59972 .16402 .60607 .17249 .61858 .16791 .61226 .1594 Mtetra
.61226 .1594 .61858 .16791 .63114 .16331 .62486 .15476 Mtetra
.62486 .15476 .63114 .16331 .64375 .15869 .63752 .1501 Mtetra
.63752 .1501 .64375 .15869 .65642 .15404 .65023 .14541 Mtetra
.65023 .14541 .65642 .15404 .66915 .14938 .663 .14071 Mtetra
.663 .14071 .66915 .14938 .68194 .14469 .67582 .13598 Mtetra
.67582 .13598 .68194 .14469 .69479 .13998 .68871 .13124 Mtetra
.68871 .13124 .69479 .13998 .70769 .13525 .70165 .12647 Mtetra
.01926 .36808 .02714 .37496 .03724 .37124 .02938 .36433 Mtetra
.02938 .36433 .03724 .37124 .04737 .3675 .03954 .36057 Mtetra
.03954 .36057 .04737 .3675 .05755 .36376 .04973 .35679 Mtetra
.04973 .35679 .05755 .36376 .06776 .35999 .05997 .353 Mtetra
.05997 .353 .06776 .35999 .07802 .35621 .07026 .34919 Mtetra
.07026 .34919 .07802 .35621 .08832 .35242 .08058 .34537 Mtetra
.08058 .34537 .08832 .35242 .09867 .34861 .09095 .34153 Mtetra
.09095 .34153 .09867 .34861 .10905 .34478 .10135 .33768 Mtetra
.10135 .33768 .10905 .34478 .11948 .34094 .11181 .33381 Mtetra
.11181 .33381 .11948 .34094 .12995 .33708 .1223 .32992 Mtetra
.1223 .32992 .12995 .33708 .14047 .33321 .13284 .32602 Mtetra
.13284 .32602 .14047 .33321 .15102 .32932 .14342 .3221 Mtetra
.14342 .3221 .15102 .32932 .16162 .32541 .15405 .31816 Mtetra
.15405 .31816 .16162 .32541 .17227 .32149 .16472 .31421 Mtetra
.16472 .31421 .17227 .32149 .18296 .31755 .17543 .31024 Mtetra
.17543 .31024 .18296 .31755 .19369 .3136 .18619 .30626 Mtetra
.18619 .30626 .19369 .3136 .20447 .30963 .197 .30226 Mtetra
.197 .30226 .20447 .30963 .21529 .30564 .20785 .29824 Mtetra
.20785 .29824 .21529 .30564 .22616 .30164 .21874 .2942 Mtetra
.21874 .2942 .22616 .30164 .23708 .29762 .22968 .29015 Mtetra
.22968 .29015 .23708 .29762 .24804 .29358 .24067 .28608 Mtetra
.24067 .28608 .24804 .29358 .25904 .28952 .2517 .28199 Mtetra
.2517 .28199 .25904 .28952 .2701 .28545 .26278 .27789 Mtetra
.26278 .27789 .2701 .28545 .2812 .28136 .27391 .27377 Mtetra
.27391 .27377 .2812 .28136 .29234 .27726 .28509 .26963 Mtetra
.28509 .26963 .29234 .27726 .30354 .27313 .29631 .26547 Mtetra
.29631 .26547 .30354 .27313 .31478 .26899 .30758 .2613 Mtetra
.30758 .2613 .31478 .26899 .32607 .26483 .3189 .25711 Mtetra
.3189 .25711 .32607 .26483 .33741 .26066 .33027 .2529 Mtetra
.33027 .2529 .33741 .26066 .34879 .25646 .34168 .24867 Mtetra
.34168 .24867 .34879 .25646 .36023 .25225 .35315 .24442 Mtetra
.35315 .24442 .36023 .25225 .37171 .24802 .36466 .24016 Mtetra
.36466 .24016 .37171 .24802 .38325 .24377 .37623 .23587 Mtetra
.37623 .23587 .38325 .24377 .39483 .2395 .38785 .23157 Mtetra
.38785 .23157 .39483 .2395 .40647 .23521 .39951 .22725 Mtetra
.39951 .22725 .40647 .23521 .41815 .23091 .41123 .22291 Mtetra
.41123 .22291 .41815 .23091 .42989 .22659 .423 .21855 Mtetra
.423 .21855 .42989 .22659 .44168 .22224 .43482 .21418 Mtetra
.43482 .21418 .44168 .22224 .45351 .21788 .44669 .20978 Mtetra
.44669 .20978 .45351 .21788 .46541 .2135 .45861 .20536 Mtetra
.45861 .20536 .46541 .2135 .47735 .2091 .47059 .20093 Mtetra
.47059 .20093 .47735 .2091 .48934 .20468 .48262 .19647 Mtetra
.48262 .19647 .48934 .20468 .50139 .20024 .4947 .192 Mtetra
.4947 .192 .50139 .20024 .51349 .19579 .50684 .1875 Mtetra
.50684 .1875 .51349 .19579 .52565 .19131 .51903 .18299 Mtetra
.51903 .18299 .52565 .19131 .53786 .18681 .53127 .17845 Mtetra
.53127 .17845 .53786 .18681 .55012 .18229 .54357 .1739 Mtetra
.54357 .1739 .55012 .18229 .56244 .17775 .55592 .16932 Mtetra
.55592 .16932 .56244 .17775 .57481 .1732 .56833 .16473 Mtetra
.56833 .16473 .57481 .1732 .58724 .16862 .5808 .16011 Mtetra
.5808 .16011 .58724 .16862 .59972 .16402 .59332 .15547 Mtetra
.59332 .15547 .59972 .16402 .61226 .1594 .6059 .15081 Mtetra
.6059 .15081 .61226 .1594 .62486 .15476 .61853 .14614 Mtetra
.61853 .14614 .62486 .15476 .63752 .1501 .63123 .14143 Mtetra
.63123 .14143 .63752 .1501 .65023 .14541 .64398 .13671 Mtetra
.64398 .13671 .65023 .14541 .663 .14071 .65679 .13197 Mtetra
.65679 .13197 .663 .14071 .67582 .13598 .66965 .1272 Mtetra
.66965 .1272 .67582 .13598 .68871 .13124 .68258 .12242 Mtetra
.68258 .12242 .68871 .13124 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Rooooo`;oYl3[00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`1Aooooo`00H?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B47ooooo`03o`000?oooooooooo01gooooo0ol00002ooooo`03o`000?oooooooooo05gooooo1OnW
`>/00ol0003oYl3[ooooo`0Eooooo`03o`000?oooooooooo053ooooo001Pooooo`05oa0@4?oooooo
ooooooooool@41002oooool5o`0001cooooo0_l0001Sooooo`OoYl3[00?o0000ojO0joooool05?oo
ool00ol0003oooooo`00001Aooooo`00H?ooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00006_ooool3o`0006;ooooo2_nW`>/00ol0003oYl3[ojO0j`0Fooooo`03o`00
0?oooooooooo04oooooo001Pooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEE
ooooool0000Hooooo`;o0000H_ooool=ojO0j`04o`000?nW`>_oYl3[ojO0jaKooooo00?o0000oooo
ooooool0C_ooool0063ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co0000
01Gooooo0ol00002ooooo`03o`000?oooooooooo05cooooo4?nW`>/01?l0003oYl3[ojO0jonW`>/F
ooooo`03o`000?oooooooooo04kooooo001Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0oo^k^koA4A4o`00000Cooooo`;o0000HOoooolCojO0j`03o`000?nW`>_oYl3[00;oYl3[5_ooool0
0ol0003oooooooooo`1=ooooo`00H?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMg
o`000?ooool03oooool3o`00063ooooo5_nW`>/00ol0003oYl3[ojO0j`03ojO0jaKooooo00?o0000
ooooooooool0C?ooool008;ooooo0_l0001QoooooaSoYl3[00?o0000ojO0jonW`>/00onW`>/Foooo
o`03o`000?oooooooooo04cooooo001oooooo`?o00000_ooool00ol0003oooooooooo`1Koooooa_o
Yl3[00?o0000ojO0jonW`>/01?nW`>/Dooooo`?o0000COooool007cooooo0ol0001PoooooakoYl3[
00?o0000ojO0jonW`>/01?nW`>/Gooooo`03o`000?oooooooooo04[ooooo001jooooo`;o0000HOoo
oolQojO0j`03o`000?nW`>_oYl3[00CoYl3[5_ooool00ol0003oooooooooo`1:ooooo`00Moooool3
o`00063ooooo9?nW`>/00ol0003oYl3[ojO0j`05ojO0jaKooooo00?o0000ooooooooool0BOooool0
07Gooooo0_l00002ooooo`03o`000?oooooooooo05_ooooo9onW`>/00ol0003oYl3[ojO0j`05ojO0
jaOooooo00?o0000ooooooooool0B?ooool007;ooooo0ol00005ooooo`03o`000?oooooooooo05So
oooo:OnW`>/00ol0003oYl3[ojO0j`06ojO0jaKooooo00?o0000ooooooooool0B?ooool0073ooooo
0_l0001Qooooob_oYl3[00?o0000ojO0jonW`>/01onW`>/Fooooo`03o`000?oooooooooo04Oooooo
000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000Pooooo`?o0000
Goooool_ojO0j`03o`000?nW`>_oYl3[00OoYl3[5Oooool3o`0004Sooooo000hooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Nooooo`;o
00000oooool00ol0003oooooooooo`1Ioooooc;oYl3[00?o0000ojO0jonW`>/02?nW`>/Fooooo`03
o`000?oooooooooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`00
0003oa0@4?oooooooooo02Wooooo000hooooo`05oa0@4?ooooooooooooooool@41003?ooool00onH
V9So8B4Qonk^kP0Looooo`?o0000GoooooldojO0j`03o`000?nW`>_oYl3[00WoYl3[5_ooool00ol0
003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:_ooool003Sooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^01Sooooo0ol0001OooooocOoYl3[00?o0000ojO0jonW`>/02_nW`>/Fooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000:oooool003Sooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo01Gooooo0ol0001Noooooc[oYl3[00?o
0000ojO0jonW`>/02onW`>/Eooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`00000;ooooo`04odA4A?oMgMgoooooo`0002cooooo000hooooo`05oa0@4?ooooooooooooooool@
41003oooool00ol0003oooooooooo`0Aooooo`?o00000oooool00ol0003oooooooooo`1Iooooocco
Yl3[00?o0000ojO0jonW`>/02onW`>/Fooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002cooooo000hooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@017ooooo0_l0001OooooocooYl3[00?o
0000ojO0jonW`>/03?nW`>/Fooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03ogMgMoo<c<co000002cooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00kooooo0ol0001Noooood;oYl3[00?o0000ojO0jonW
`>/03OnW`>/Dooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4
A?l00000;?ooool005Wooooo0ol0001NooooodCoYl3[00?o0000ojO0jonW`>/03OnW`>/Cooooo`04
o`000?ooooooooooo`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003o
oooo02_ooooo001Fooooo`?o00000oooool00ol0003oooooooooo`1HooooodOoYl3[00?o0000ojO0
jonW`>/03_nW`>/Fooooo`03o`000?oooooooooo043ooooo001Dooooo`;o0000G_oooom:ojO0j`03
o`000?nW`>_oYl3[00koYl3[5_ooool00ol0003oooooooooo`10ooooo`00DOooool3o`0005gooooo
COnW`>/00ol0003oYl3[ojO0j`0?ojO0jaKooooo00?o0000ooooooooool0?oooool004kooooo1Ol0
001LooooodooYl3[00?o0000ojO0jonW`>/04?nW`>/Fooooo`03o`000?oooooooooo03kooooo001<
ooooo`;o00001Oooool00ol0003oooooooooo`1Foooooe;oYl3[00?o0000ojO0jonW`>/04?nW`>/F
ooooo`03o`000?oooooooooo03kooooo0019ooooo`?o0000GOoooomFojO0j`03o`000?nW`>_oYl3[
013oYl3[5?ooool3o`0003oooooo000Rooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08?ooool2o`00
05koooooF?nW`>/00ol0003oYl3[ojO0j`0AojO0jaGooooo00?o0000ooooooooool0?Oooool002;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`?o00000_ooool00ol0003oooooooooo`1Ioooo
oe[oYl3[00?o0000ojO0jonW`>/04_nW`>/Eooooo`03o`000?oooooooooo03cooooo000Rooooo`05
oa0@4?ooooooooooooooool@41006oooool2o`0005goooooG_nW`>/00ol0003oYl3[ojO0j`0CojO0
jaGooooo00?o0000ooooooooool0>oooool002;ooooo00Go0000ooooooooooooooooo`00000Hoooo
o`?o0000G?oooomQojO0j`03o`000?nW`>_oYl3[01?oYl3[5Oooool00ol0003oooooooooo`0koooo
o`008_ooool01Ol0003ooooooooooooooooo000001Kooooo0ol0001Looooof?oYl3[00?o0000ojO0
jonW`>/05?nW`>/Eooooo`03o`000?oooooooooo03[ooooo000Rooooo`05oa0@4?oooooooooooooo
ool@41004oooool3o`0000;ooooo00?o0000ooooooooool0F?oooomUojO0j`03o`000?nW`>_oYl3[
01CoYl3[5_ooool00ol0003oooooooooo`0iooooo`008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
013ooooo0ol0001LooooofWoYl3[00?o0000ojO0jonW`>/05OnW`>/Dooooo`;o0000>oooool002;o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`;o0000G?oooom/ojO0j`03o`000?nW`>_oYl3[
01KoYl3[5Oooool00ol0003oooooooooo`0hooooo`00<_ooool5o`0005[oooooKOnW`>/2o`0001So
Yl3[5_ooool00ol0003oooooooooo`0gooooo`00<?ooool2o`0005goooooK?nW`>/3o`000003ojO0
jol0003oYl3[01SoYl3[5Oooool00ol0003oooooooooo`0gooooo`00;Oooool3o`0005_oooooKOnW
`>/3o`0000GoYl3[00?o0000ojO0jonW`>/05onW`>/Eooooo`03o`000?oooooooooo03Kooooo000/
ooooo`;o0000F_oooom]ojO0j`?o00002OnW`>/00ol0003oYl3[ojO0j`0GojO0jaGooooo00?o0000
ooooooooool0=Oooool002cooooo0ol0001GooooofcoYl3[0ol0000=ojO0j`03o`000?nW`>_oYl3[
01OoYl3[5?ooool00ol0003oooooooooo`0eooooo`00;?ooool01?l0003oooooo`000?l0001Doooo
of_oYl3[0ol0000@ojO0j`03o`000?nW`>_oYl3[01OoYl3[4oooool00ol0003oooooo`000008oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<
c00Iooooo`00;?ooool2o`0000;ooooo00?o0000ooooooooool0COoooom/ojO0j`?o00005?nW`>/0
0ol0003oYl3[ojO0j`0GojO0jaGooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B406Oooool002_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`19ooooofgoYl3[0_l0000HojO0j`03o`000?nW
`>_oYl3[01KoYl3[5Oooool00ol0003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000001Wooooo000[ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0Aooooom[ojO0j`?o00006_nW`>/00ol0003oYl3[ojO0j`0GojO0jaGooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oo
ooooV9RHob4Q8@0Iooooo`00:oooool3o`0000Gooooo00?o0000ooooooooool0@ooooom[ojO0j`?o
00007_nW`>/00ol0003oYl3[ojO0j`0GojO0jaGooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Iooooo`00:oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo03ooooooJonW`>/3o`0002;oYl3[00?o0000ojO0
jonW`>/05_nW`>/Eooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooooooooa0@400;
ooooo`03oeEEEOn7QhOooooo01_ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0>ooooom[ojO0j`?o00009_nW`>/00ol0003oYl3[ojO0j`0FojO0ja?ooooo0ol00004oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00Kooooo`004?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo03SoooooJ_nW`>/3o`0002WoYl3[00?o0000
ojO0jonW`>/05onW`>/Eooooo`09o`000?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo00Coc<c<odA4A?l0003o410@6Oooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`?o00002_ooool00ol0003oooooooooo`0eoooo
ofWoYl3[0ol0000]ojO0j`03o`000?nW`>_oYl3[01KoYl3[5Oooool00ol0003oooooooooo`0_oooo
o`002?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo033oooooJonW`>/2o`00037oYl3[00?o0000ojO0
jonW`>/05_nW`>/Eooooo`03o`000?oooooooooo02kooooo000@ooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool00006ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0;?oooom[ojO0j`?o0000<onW`>/00ol0003oYl3[ojO0j`0GojO0jaGooooo00?o0000
ooooooooool0;Oooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0000Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0ZooooofWoYl3[0ol0
000gojO0j`03o`000?nW`>_oYl3[01OoYl3[5?ooool00ol0003oooooooooo`0]ooooo`004?ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool2o`0000oooooo0_l0
000WooooofWoYl3[0ol0000kojO0j`03o`000?nW`>_oYl3[01KoYl3[5Oooool00ol0003ooooooooo
o`0/ooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo027oooooJOnW`>/3o`0003ooYl3[00?o
0000ojO0jonW`>/05_nW`>/Cooooo`;o0000;_ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Looooof[oYl3[0ol00012ojO0j`03o`000?nW`>_oYl3[01KoYl3[5Oooool00ol0003ooooooooo
o`0[ooooo`00:Oooool2o`0001Cooooo00?o0000ooooooooool06?oooomZojO0j`?o0000A_nW`>/0
0ol0003oYl3[ojO0j`0FojO0jaGooooo00?o0000ooooooooool0:_ooool002Wooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0FooooofWoYl3[0_l0001:ojO0j`03o`000?nW`>_oYl3[
01KoYl3[5?ooool00ol0003oooooooooo`0Zooooo`00:Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo01;oooooJOnW`>/3o`0004goYl3[00?o0000ojO0jonW`>/05_nW`>/Dooooo`03
o`000?oooooooooo02Wooooo000Yooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
3_oooomYojO0j`?o0000D?nW`>/00ol0003oYl3[ojO0j`0GojO0jaCooooo00?o0000ooooooooool0
:?ooool002Wooooo0ol0000Gooooo`03o`000?oooooooooo00[oooooJOnW`>/3o`0005CoYl3[00?o
0000ojO0jonW`>/05_nW`>/Cooooo`;o0000:_ooool002Wooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`06ooooofWoYl3[0ol0001HojO0j`03o`000?nW`>_oYl3[01KoYl3[5?ooool0
0ol0003oooooooooo`0Wooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`Go00001Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00?oooooJ?nW`>/3
o`0005_oYl3[00?o0000ojO0jonW`>/05_nW`>/Eooooo`03o`000?oooooooooo02Kooooo000>oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A005ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0IonW`>/3o`0005ooYl3[00?o
0000ojO0jonW`>/05_nW`>/Dooooo`03o`000?oooooooooo02Kooooo0006ooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool2o`0001coooooJ?nW
`>/2o`0006?oYl3[00?o0000ojO0jonW`>/05_nW`>/Dooooo`03o`000?oooooooooo02Gooooo000>
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oo
oooooooo01OoooooJOnW`>/3o`0006KoYl3[00?o0000ojO0jonW`>/05OnW`>/Eooooo`03o`000?oo
oooooooo02Cooooo000>ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`04ooooo`03o`000?oooooooooo01CoooooJOnW`>/3o`0006WoYl3[00?o0000ojO0jonW`>/05_nW
`>/Cooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<
c?lQ8B7o0000ob4Q8Oo<c<`02Oooool000kooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00?ooooo0_l0000DooooofOoYl3[0ol0001]ojO0j`03o`000?nW`>_oYl3[01Ko
Yl3[5?ooool00ol0003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@09ooooo`003_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`;o00004ooooomVojO0j`?o0000LOnW
`>/00ol0003oYl3[ojO0j`0FojO0jaCooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go0000ooooooooooooooooo`000009ooooo`003_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`03o`000?oooooooooo
00ooooooI_nW`>/3o`0007GoYl3[00?o0000ojO0jonW`>/05OnW`>/Dooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S802Ooo
ool002Oooooo00?o0000ooooooooool02ooooomWojO0j`?o0000N?nW`>/00ol0003oYl3[ojO0j`0F
ojO0jaCooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
c<c<o`000?l0003o0000olc<c009ooooo`009oooool2o`0000WoooooJ?nW`>/2o`0007coYl3[00?o
0000ojO0jonW`>/05OnW`>/Eooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41002Oooool002Oooooo00?o0000ooooooooool0
1OoooomXojO0j`?o0000OonW`>/00ol0003oYl3[ojO0j`0EojO0ja;ooooo0ol00004ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Wooooo000Wooooo`03
o`000?oooooooooo00CoooooI_nW`>/3o`0008;oYl3[00?o0000ojO0jonW`>/05_nW`>/Dooooo`09
o`000?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@09ooooo`009_ooool3o`0000?oooooIOnW`>/3o`0008KoYl3[00?o0000ojO0jonW`>/05OnW
`>/Eooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?ooooooYl3[06GoYl3[0ol0002:
ojO0j`03o`000?nW`>_oYl3[01GoYl3[5?ooool00ol0003oooooooooo`0Nooooo`006oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooonW`>/0H_nW`>/3o`0008koYl3[00?o0000
ojO0jonW`>/05OnW`>/Dooooo`03o`000?oooooooooo01gooooo000Kooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01_ooool00ol0003oooooooooo`1OojO0j`?o0000TOnW`>/00ol0003oYl3[ojO0j`0F
ojO0ja?ooooo0_l0000Nooooo`006oooool01Ol@413ooooooooooooooooo410@00Kooooo0_l00002
oooooe_oYl3[0ol0002EojO0j`03o`000?nW`>_oYl3[01GoYl3[4_ooool00ol0003oooooo`00000N
ooooo`006oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_oooomH
ojO0j`;o0000VOnW`>/00ol0003oYl3[ojO0j`0EojO0jaCooooo00?o0000ooooooooool06oooool0
01_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?oooooE?nW`>/3
o`0009_oYl3[00?o0000ojO0jonW`>/05OnW`>/Eooooo`03o`000?oooooooooo01[ooooo000Koooo
o`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`05oooooe3oYl3[0ol0002O
ojO0j`03o`000?nW`>_oYl3[01GoYl3[5?ooool00ol0003oooooooooo`0Jooooo`006oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00007ooooodcoYl3[0ol0002SojO0j`03o`000?nW`>_o
Yl3[01GoYl3[5?ooool00ol0003oooooooooo`0Iooooo`006oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo00?o0000ooooooooool01ooooom8ojO0j`?o0000YonW`>/00ol0003oYl3[ojO0j`0D
ojO0jaCooooo00?o0000ooooooooool06Oooool002Gooooo00?o0000ooooooooool02?oooom4ojO0
j`?o0000Z_nW`>/00ol0003oYl3[ojO0j`0EojO0ja;ooooo00?o0000ooooool000006_ooool002Go
oooo00?o0000ooooooooool02_ooooloojO0j`?o0000[_nW`>/00ol0003oYl3[ojO0j`0EojO0jaCo
oooo00?o0000ooooooooool05oooool002Gooooo0_l0000<oooooccoYl3[0_l0002bojO0j`03o`00
0?nW`>_oYl3[01GoYl3[4oooool00ol0003oooooooooo`0Gooooo`009?ooool00ol0003ooooooooo
o`0=ooooocSoYl3[0ol0002eojO0j`03o`000?nW`>_oYl3[01CoYl3[5?ooool00ol0003ooooooooo
o`0Fooooo`009?ooool00ol0003oooooooooo`0>ooooocCoYl3[0ol0002hojO0j`03o`000?nW`>_o
Yl3[01GoYl3[5?ooool00ol0003oooooooooo`0Eooooo`009?ooool3o`0000oooooo<?nW`>/3o`00
0;coYl3[00?o0000ojO0jonW`>/05OnW`>/Booooo`;o00002Oooool4o`000003oa0@4?oooooooooo
00Oooooo000Tooooo`03o`000?oooooooooo013ooooo;?nW`>/3o`000<3oYl3[00?o0000ojO0jonW
`>/05OnW`>/Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool000Wooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000oooooooo
ool04_oooolWojO0j`?o0000`onW`>/00ol0003oYl3[ojO0j`0EojO0jaCooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`09ooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0Coooo
ob?oYl3[0ol00037ojO0j`03o`000?nW`>_oYl3[01GoYl3[4oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Wooooo0009ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onH
V9So8B4Qonk^kP06ooooo`03o`000?oooooooooo01Gooooo8?nW`>/2o`000<_oYl3[00?o0000ojO0
jonW`>/05OnW`>/Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool000Wo
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0ol0000Foooo
oacoYl3[0ol0003>ojO0j`03o`000?nW`>_oYl3[01GoYl3[4Oooool3o`0000Oooooo00?o0000oooo
ooooool02Oooool000Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00Cooooo00?o0000ooooooooool06?oooolGojO0j`?o0000dOnW`>/00ol0003oYl3[ojO0j`0EojO0
j`kooooo1?l000000ooooooo0000ooooo`06ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05
oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Wooooo4onW`>/3o`000=GoYl3[00?o0000ojO0jonW`>/05OnW`>/:ooooo`?o00001Oooool00ol0
003oooooooooo`03ooooo`03oeEEEOmVIVKo000000_ooooo0009ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo0_l0000Kooooo`ooYl3[0ol0003I
ojO0j`03o`000?nW`>_oYl3[01CoYl3[1_ooool4o`0000Sooooo00?o0000ooooooooool04Oooool0
00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Ooo
ool00ol0003oooooooooo`0Kooooo`_oYl3[0ol0003LojO0j`03o`000?nW`>_oYl3[01GoYl3[0_oo
ool3o`0000cooooo00?o0000ooooooooool04Oooool002;ooooo00?o0000ooooooooool07Oooool7
ojO0j`?o0000h?nW`>/00ol0003oYl3[ojO0j`0EojO0j`03o`000?oooooooooo00kooooo00?o0000
ooooooooool04?ooool002;ooooo00?o0000ooooooooool07_ooool4ojO0j`;o0000i?nW`>/00ol0
003oYl3[ojO0j`0EojO0ja3ooooo00?o0000ooooooooool04?ooool002;ooooo0_l0000Pooooo`?o
0000ionW`>/00ol0003oYl3[ojO0j`0DojO0ja3ooooo00?o0000ooooooooool04?ooool002;ooooo
00?o0000ooooooooool07?ooool3o`000003oooooonW`>_oYl3[0>OoYl3[00?o0000ojO0jonW`>/0
5OnW`>/?ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo01Wooooo0ol0
0006ooooonSoYl3[00?o0000ojO0jonW`>/05?nW`>/?ooooo`03o`000?oooooooooo013ooooo000R
ooooo`03o`000?oooooooooo01Kooooo0ol0000:ooooonSoYl3[00?o0000ojO0jonW`>/05?nW`>/>
ooooo`03o`000?oooooooooo013ooooo000Rooooo`;o00005?ooool3o`0000koooooj?nW`>/00ol0
003oYl3[ojO0j`0DojO0j`gooooo00?o0000ooooooooool04?ooool0027ooooo0_l0000Booooo`?o
00004_oooooWojO0j`03o`000?nW`>_oYl3[01GoYl3[3?ooool00ol0003oooooooooo`0@ooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@oooooooo
ool00oooool00ol0003oooooooooo`0?ooooo`;o00005_oooooWojO0j`03o`000?nW`>_oYl3[01Co
Yl3[3Oooool00ol0003oooooooooo`0?ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool3o`0001Wo
ooooionW`>/00ol0003oYl3[ojO0j`0DojO0j`cooooo00?o0000ooooooooool03oooool000Oooooo
00Go410@oooooooooooooooooa0@400;ooooo`Go00001Oooool2o`0000[ooooo0ol0000MooooonKo
Yl3[00?o0000ojO0jonW`>/05OnW`>/;ooooo`03o`000?oooooooooo00oooooo0007ooooo`05o`00
0?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00006ooooo`03o`000?oooooooooo
00Kooooo0ol0000QooooonKoYl3[00?o0000ojO0jonW`>/05OnW`>/:ooooo`03o`000?oooooooooo
00oooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00006
ooooo`03o`000?oooooooooo00?ooooo0ol0000VooooonGoYl3[00?o0000ojO0jonW`>/05?nW`>/:
ooooo`03o`000?oooooooooo00oooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0omgMgOoc<c<o`000005ooooo`04o`000?ooooooooooooooo`?o0000:_oooooUojO0j`03o`000?nW
`>_oYl3[01CoYl3[2Oooool00ol0003oooooooooo`0?ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?ok^k^odA4A?l000001Oooool4o`0002koooooi?nW`>/00ol0003oYl3[ojO0
j`0DojO0j`Wooooo00?o0000ooooooooool03oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00Cooooo0_l0000aooooonCoYl3[00?o0000ojO0jonW`>/05?nW
`>/8ooooo`03o`000?oooooooooo00oooooo000Rooooo`03o`000?oooooooooo02ooooooi?nW`>/0
0ol0003oYl3[ojO0j`0CojO0j`Wooooo00?o0000ooooooooool03_ooool002?ooooo00?o0000oooo
ooooool0;ooooooSojO0j`03o`000?nW`>_oYl3[01CoYl3[2?ooool00ol0003oooooooooo`0>oooo
o`009?ooool00ol0003oooooooooo`0_ooooon?oYl3[00?o0000ojO0jonW`>/05?nW`>/7ooooo`03
o`000?oooooooooo00kooooo000Uooooo`;o0000<?oooooSojO0j`03o`000?nW`>_oYl3[01CoYl3[
1_ooool00ol0003oooooooooo`0>ooooo`009oooool00ol0003oooooooooo`0^ooooon?oYl3[00?o
0000ojO0jonW`>/04onW`>/6ooooo`03o`000?oooooooooo00kooooo000Xooooo`03o`000?oooooo
oooo02koooooh_nW`>/00ol0003oYl3[ojO0j`0DojO0j`Gooooo00?o0000ooooooooool03_ooool0
02Wooooo00?o0000ooooooooool0;ooooooQojO0j`03o`000?nW`>_oYl3[01CoYl3[1?ooool00ol0
003oooooooooo`0>ooooo`00:_ooool2o`00037oooooh?nW`>/00ol0003oYl3[ojO0j`0DojO0j`?o
oooo00?o0000ooooooooool03_ooool002cooooo00?o0000ooooooooool0;ooooooPojO0j`03o`00
0?nW`>_oYl3[01CoYl3[0oooool00ol0003oooooooooo`0=ooooo`00;Oooool00ol0003ooooooooo
o`0_ooooomooYl3[00?o0000ojO0jonW`>/05?nW`>/3ooooo`03o`000?oooooooooo00gooooo000^
ooooo`03o`000?oooooooooo02oooooogonW`>/00ol0003oYl3[ojO0j`0DojO0j`;ooooo00?o0000
ooooooooool03Oooool002oooooo00?o0000ooooooooool0;ooooooOojO0j`03o`000?nW`>_oYl3[
01?oYl3[0_ooool00ol0003oooooooooo`0=ooooo`00<?ooool2o`00033ooooog_nW`>/00ol0003o
Yl3[ojO0j`0DojO0j`03ooooool0003ooooo00kooooo000booooo`03o`000?oooooooooo02kooooo
g_nW`>/00ol0003oYl3[ojO0j`0CojO0j`03ooooool0003ooooo00kooooo000cooooo`03o`000?oo
oooooooo02kooooog_nW`>/00ol0003oYl3[ojO0j`0CojO0j`03o`000?oooooooooo00gooooo000d
ooooo`03o`000?oooooooooo02kooooog_nW`>/00ol0003oYl3[ojO0j`0AojO0j`03ooooool0003o
oooo00kooooo000eooooo`;o0000;ooooooMojO0j`03o`000?nW`>_oYl3[00goYl3[1_ooool00ol0
003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`0^ooooomcoYl3[00?o0000ojO0jonW
`>/02OnW`>/9ooooo`03o`000?oooooooooo00cooooo000hooooo`03o`000?oooooooooo02kooooo
g?nW`>/00ol0003oYl3[ojO0j`05ojO0j`cooooo00?o0000ooooooooool03?ooool003Wooooo00?o
0000ooooooooool0;_oooooLojO0j`03o`000?nW`>_oYl3[013ooooo00?o0000ooooooooool03?oo
ool003[ooooo0_l0000_ooooom_oYl3[00?o0000ooooooooool04?ooool00ol0003oooooooooo`0<
ooooo`00??ooool00ol0003oooooooooo`0]ooooomKoYl3[1Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00cooooo000mooooo`03o`000?oooooooooo02goooood_nW`>/9ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool003kooooo00?o0000ooooooooool0
;Oooooo:ojO0ja3ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`00?ooo
ool2o`0002ooooooaOnW`>/Dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02ooo
ool0047ooooo00?o0000ooooooooool0;Oooooo1ojO0jaSooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0;ooooo`00@_ooool00ol0003oooooooooo`0]oooookcoYl3[7Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0013ooooo`03o`000?oooooooooo02go
oooo^?nW`>/Pooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool004Cooooo
00?o0000ooooooooool0;OoooondojO0jbCooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`00AOooool2o`0002oooooo[_nW`>/Yooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02oooool004Oooooo00?o0000ooooooooool0;OoooonZojO0jbcooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`00B?ooool00ol0003oooooooooo`0]oooo
ojKoYl3[<?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo0019ooooo`03
o`000?oooooooooo02goooooX_nW`>/dooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02_ooool004[ooooo0_l0000^oooooigoYl3[>Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00[ooooo001<ooooo`03o`000?oooooooooo02coooooVOnW`>/looooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02_ooool004gooooo00?o0000ooooooooool0;?oooonB
ojO0jd?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`00C_ooool00ol0
003oooooooooo`0]ooooohgoYl3[Aoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00[ooooo001?ooooo`;o0000;_oooon8ojO0jdcooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0:ooooo`00DOooool00ol0003oooooooooo`0/ooooohCoYl3[Coooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00[ooooo001Booooo`03o`000?oooooooooo02_oooooPOnW
`>]Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool005?ooooo00?o0000
ooooooooool0:ooooommojO0jeOooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09
ooooo`00E?ooool2o`0002goooooN?nW`>]Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02Oooool005Kooooo00?o0000ooooooooool0:ooooomdojO0jekooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`09ooooo`00Eoooool00ol0003oooooooooo`0[ooooofcoYl3[
I_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo001Hooooo`03o`000?oo
oooooooo02coooooIonW`>]Zooooo`05o`000?ooooooooooooooool000002oooool005Wooooo00?o
0000ooooooooool0;?oooomSojO0jfgooooo00Go0000ooooooooooooooooo`00000;ooooo`00F_oo
ool2o`0002goooooGonW`>]aooooo`04o`000?ooooooooooo`0000_ooooo001Looooo`03o`000?oo
oooooooo02_oooooFonW`>]eooooo`03o`000?oooooo000000_ooooo001Mooooo`03o`000?oooooo
oooo02_oooooEonW`>]hooooo`04o`000?ooooooooooo`0000[ooooo001Nooooo`03o`000?oooooo
oooo02_oooooDonW`>]looooo`03o`000?oooooo000000[ooooo001Oooooo`;o0000;?oooom<ojO0
jh?ooooo0_l0000:ooooo`00HOooool00ol0003oooooooooo`0ZooooodSoYl3[QOooool3o`0000[o
oooo001Rooooo`03o`000?oooooooooo02_ooooo@onW`>^4ooooo`Co00003Oooool006?ooooo00?o
0000ooooooooool0:oooooloojO0jh?ooooo1?l0000Aooooo`00I?ooool2o`0002cooooo>onW`>^3
ooooo`?o00005Oooool006Kooooo00?o0000ooooooooool0:ooooolcojO0jhGooooo1?l0000Hoooo
o`00Ioooool00ol0003oooooooooo`0Zoooooc3oYl3[Q?ooool4o`0001cooooo001Xooooo`03o`00
0?oooooooooo02[ooooo;?nW`>^3ooooo`Co00008?ooool006Wooooo0_l0000/ooooobOoYl3[P_oo
ool4o`0002Cooooo001[ooooo`03o`000?oooooooooo02[ooooo8onW`>^2ooooo`?o0000:?ooool0
06cooooo00?o0000ooooooooool0:_oooolMojO0jh?ooooo1?l0000[ooooo`00KOooool00ol0003o
ooooooooo`0[oooooaSoYl3[P_ooool4o`0002oooooo001^ooooo`03o`000?oooooooooo02[ooooo
5OnW`>^1ooooo`Co0000<oooool006oooooo0_l0000[oooooa7oYl3[P?ooool4o`0003Oooooo001a
ooooo`03o`000?oooooooooo02[ooooo2OnW`>^2ooooo`Co0000>oooool007;ooooo00?o0000oooo
ooooool0:_ooool5ojO0jh;ooooo0ol0000oooooo`00Loooool00ol0003oooooooooo`0Zooooo`03
ojO0jooooooooooo07oooooo1?l00012ooooo`00M?ooool2o`0002[ooooo00?o0000ooooooooool0
Noooool4o`0004Kooooo001fooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0N?oo
ool4o`0004[ooooo001gooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0M?ooool4
o`0004kooooo001hooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0LOooool3o`00
05;ooooo001iooooo`;o00009?ooool00ol0003oooooooooo`1]ooooo`Co0000EOooool007_ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Yooooo`Co0000FOooool007cooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`1Uooooo`Co0000GOooool007gooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`1Qooooo`Co0000HOooool007kooooo0_l0000Ooooo
o`03o`000?oooooooooo05gooooo1?l0001Uooooo`00P?ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo05[ooooo0ol0001Yooooo`00POooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo05Kooooo1?l0001/ooooo`00P_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo05;ooooo1?l0001`ooooo`00Poooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04kooooo1?l0001dooooo`00Q?ooool2o`0001Wooooo00?o0000ooooooooool0B_ooool4o`00
07Sooooo0026ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0A_ooool4o`0007co
oooo0027ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@oooool3o`00083ooooo
0028ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?oooool4o`0008?ooooo0029
ooooo`;o00005?ooool00ol0003oooooooooo`0kooooo`Co0000Qoooool008_ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0gooooo`Co0000Roooool008cooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0cooooo`Co0000Soooool008gooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0`ooooo`?o0000Toooool008kooooo0_l0000?ooooo`03o`000?oo
oooooooo02cooooo1?l0002Fooooo`00T?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo02Sooooo1?l0002Jooooo`00TOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
02Cooooo1?l0002Nooooo`00T_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027o
oooo1?l0002Rooooo`00Toooool2o`0000Wooooo00?o0000ooooooooool07Oooool4o`000:Kooooo
002Eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool3o`000:[ooooo002F
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool4o`000:gooooo002Goooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool4o`000;7ooooo002Hooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool4o`000;Gooooo002Iooooo`;o0000
0oooool00ol0003oooooooooo`0:ooooo`Co0000^Oooool009_ooooo00Co0000oooooooooooo0000
2Oooool3o`000;gooooo002Looooo`03o`000?oooooo000000Gooooo1?l00030ooooo`00WOooool2
o`000003ooooool0003o000000;o0000a?ooool009kooooo0_l00038ooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00]_ooool01OnHV9So0000o`000?m4A4Co^[Zj00Wooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP2Oooooo`00]_ooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00000_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg09oooooo002fooooo`03o`000?oooooooooo00_ooooo00Go410@oooo
oooooooooooooa0@402Oooooo`00]_ooool00ol0003oooooooooo`03ooooo`Ko00000_ooool01Ol0
003ooooooooooooooooo000009oooooo002fooooo`03o`000?oooooooooo00_ooooo00Go0000oooo
ooooooooooooo`00002Oooooo`00]?ooool00ol@413o0000o`000003o`0000[ooooo00Go410@oooo
oooooooooooooa0@402Oooooo`00]_ooool00ol0003oooooooooo`0;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0Woooool00;Kooooo00?o0000ooooooooool02oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^09oooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -17 0 ]
[.5 .82364 17 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69467 Mtetra
.4053 .69467 .41061 .69934 .41957 .69681 .41427 .69213 Mtetra
.41427 .69213 .41957 .69681 .42855 .69428 .42327 .68958 Mtetra
.42327 .68958 .42855 .69428 .43756 .69174 .43231 .68703 Mtetra
.43231 .68703 .43756 .69174 .4466 .68919 .44137 .68446 Mtetra
.44137 .68446 .4466 .68919 .45567 .68663 .45046 .68189 Mtetra
.45046 .68189 .45567 .68663 .46478 .68407 .45958 .67931 Mtetra
.45958 .67931 .46478 .68407 .47391 .68149 .46873 .67671 Mtetra
.46873 .67671 .47391 .68149 .48307 .67891 .47792 .67412 Mtetra
.47792 .67412 .48307 .67891 .49227 .67632 .48713 .67151 Mtetra
.48713 .67151 .49227 .67632 .50149 .67371 .49638 .66889 Mtetra
.49638 .66889 .50149 .67371 .51075 .6711 .50565 .66626 Mtetra
.50565 .66626 .51075 .6711 .52004 .66849 .51496 .66363 Mtetra
.51496 .66363 .52004 .66849 .52936 .66586 .5243 .66098 Mtetra
.5243 .66098 .52936 .66586 .53871 .66322 .53367 .65833 Mtetra
.53367 .65833 .53871 .66322 .54809 .66058 .54308 .65567 Mtetra
.54308 .65567 .54809 .66058 .55751 .65792 .55251 .653 Mtetra
.55251 .653 .55751 .65792 .56695 .65526 .56198 .65032 Mtetra
.56198 .65032 .56695 .65526 .57643 .65259 .57148 .64763 Mtetra
.57148 .64763 .57643 .65259 .58595 .6499 .58102 .64493 Mtetra
.58102 .64493 .58595 .6499 .59549 .64721 .59058 .64222 Mtetra
.59058 .64222 .59549 .64721 .60507 .64451 .60018 .6395 Mtetra
.60018 .6395 .60507 .64451 .61468 .6418 .60982 .63678 Mtetra
.60982 .63678 .61468 .6418 .62432 .63908 .61948 .63404 Mtetra
.61948 .63404 .62432 .63908 .634 .63636 .62918 .63129 Mtetra
.62918 .63129 .634 .63636 .64371 .63362 .63892 .62854 Mtetra
.63892 .62854 .64371 .63362 .65345 .63087 .64868 .62577 Mtetra
.64868 .62577 .65345 .63087 .66323 .62811 .65848 .623 Mtetra
.65848 .623 .66323 .62811 .67304 .62535 .66832 .62021 Mtetra
.66832 .62021 .67304 .62535 .68289 .62257 .67819 .61742 Mtetra
.67819 .61742 .68289 .62257 .69277 .61979 .68809 .61462 Mtetra
.68809 .61462 .69277 .61979 .70269 .61699 .69803 .6118 Mtetra
.69803 .6118 .70269 .61699 .71264 .61418 .70801 .60898 Mtetra
.70801 .60898 .71264 .61418 .72262 .61137 .71802 .60615 Mtetra
.71802 .60615 .72262 .61137 .73264 .60854 .72806 .6033 Mtetra
.72806 .6033 .73264 .60854 .7427 .60571 .73814 .60045 Mtetra
.73814 .60045 .7427 .60571 .75279 .60286 .74826 .59759 Mtetra
.74826 .59759 .75279 .60286 .76291 .60001 .75841 .59471 Mtetra
.75841 .59471 .76291 .60001 .77308 .59714 .7686 .59183 Mtetra
.7686 .59183 .77308 .59714 .78328 .59427 .77882 .58893 Mtetra
.77882 .58893 .78328 .59427 .79351 .59138 .78908 .58603 Mtetra
.78908 .58603 .79351 .59138 .80378 .58849 .79938 .58311 Mtetra
.79938 .58311 .80378 .58849 .81409 .58558 .80971 .58019 Mtetra
.80971 .58019 .81409 .58558 .82443 .58267 .82008 .57725 Mtetra
.82008 .57725 .82443 .58267 .83482 .57974 .83049 .57431 Mtetra
.83049 .57431 .83482 .57974 .84523 .5768 .84094 .57135 Mtetra
.84094 .57135 .84523 .5768 .85569 .57385 .85142 .56838 Mtetra
.85142 .56838 .85569 .57385 .86618 .57089 .86194 .5654 Mtetra
.86194 .5654 .86618 .57089 .87672 .56792 .8725 .56241 Mtetra
.8725 .56241 .87672 .56792 .88729 .56494 .8831 .55941 Mtetra
.8831 .55941 .88729 .56494 .89789 .56195 .89374 .5564 Mtetra
.89374 .5564 .89789 .56195 .90854 .55895 .90441 .55338 Mtetra
.90441 .55338 .90854 .55895 .91923 .55594 .91512 .55035 Mtetra
.91512 .55035 .91923 .55594 .92995 .55292 .92588 .5473 Mtetra
.92588 .5473 .92995 .55292 .94071 .54988 .93667 .54425 Mtetra
.93667 .54425 .94071 .54988 .95152 .54684 .9475 .54118 Mtetra
.9475 .54118 .95152 .54684 .96236 .54378 .95837 .53811 Mtetra
.95837 .53811 .96236 .54378 .97324 .54071 .96928 .53502 Mtetra
.96928 .53502 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.391 .69252 .39636 .6972 .4053 .69467 .39996 .68998 Mtetra
.39996 .68998 .4053 .69467 .41427 .69213 .40895 .68742 Mtetra
.40895 .68742 .41427 .69213 .42327 .68958 .41797 .68486 Mtetra
.41797 .68486 .42327 .68958 .43231 .68703 .42702 .68228 Mtetra
.42702 .68228 .43231 .68703 .44137 .68446 .4361 .6797 Mtetra
.4361 .6797 .44137 .68446 .45046 .68189 .44521 .67711 Mtetra
.44521 .67711 .45046 .68189 .45958 .67931 .45435 .67452 Mtetra
.45435 .67452 .45958 .67931 .46873 .67671 .46352 .67191 Mtetra
.46352 .67191 .46873 .67671 .47792 .67412 .47273 .66929 Mtetra
.47273 .66929 .47792 .67412 .48713 .67151 .48196 .66667 Mtetra
.48196 .66667 .48713 .67151 .49638 .66889 .49123 .66403 Mtetra
.49123 .66403 .49638 .66889 .50565 .66626 .50053 .66139 Mtetra
.50053 .66139 .50565 .66626 .51496 .66363 .50985 .65874 Mtetra
.50985 .65874 .51496 .66363 .5243 .66098 .51922 .65608 Mtetra
.51922 .65608 .5243 .66098 .53367 .65833 .52861 .65341 Mtetra
.52861 .65341 .53367 .65833 .54308 .65567 .53803 .65073 Mtetra
.53803 .65073 .54308 .65567 .55251 .653 .54749 .64804 Mtetra
.54749 .64804 .55251 .653 .56198 .65032 .55698 .64534 Mtetra
.55698 .64534 .56198 .65032 .57148 .64763 .5665 .64264 Mtetra
.5665 .64264 .57148 .64763 .58102 .64493 .57606 .63992 Mtetra
.57606 .63992 .58102 .64493 .59058 .64222 .58565 .6372 Mtetra
.58565 .6372 .59058 .64222 .60018 .6395 .59527 .63446 Mtetra
.59527 .63446 .60018 .6395 .60982 .63678 .60493 .63172 Mtetra
.60493 .63172 .60982 .63678 .61948 .63404 .61461 .62896 Mtetra
.61461 .62896 .61948 .63404 .62918 .63129 .62434 .6262 Mtetra
.62434 .6262 .62918 .63129 .63892 .62854 .63409 .62343 Mtetra
.63409 .62343 .63892 .62854 .64868 .62577 .64388 .62064 Mtetra
.64388 .62064 .64868 .62577 .65848 .623 .65371 .61785 Mtetra
.65371 .61785 .65848 .623 .66832 .62021 .66357 .61505 Mtetra
.66357 .61505 .66832 .62021 .67819 .61742 .67346 .61224 Mtetra
.67346 .61224 .67819 .61742 .68809 .61462 .68339 .60942 Mtetra
.68339 .60942 .68809 .61462 .69803 .6118 .69335 .60658 Mtetra
.69335 .60658 .69803 .6118 .70801 .60898 .70335 .60374 Mtetra
.70335 .60374 .70801 .60898 .71802 .60615 .71338 .60089 Mtetra
.71338 .60089 .71802 .60615 .72806 .6033 .72345 .59803 Mtetra
.72345 .59803 .72806 .6033 .73814 .60045 .73356 .59516 Mtetra
.73356 .59516 .73814 .60045 .74826 .59759 .7437 .59227 Mtetra
.7437 .59227 .74826 .59759 .75841 .59471 .75387 .58938 Mtetra
.75387 .58938 .75841 .59471 .7686 .59183 .76409 .58648 Mtetra
.76409 .58648 .7686 .59183 .77882 .58893 .77434 .58356 Mtetra
.77434 .58356 .77882 .58893 .78908 .58603 .78462 .58064 Mtetra
.78462 .58064 .78908 .58603 .79938 .58311 .79495 .57771 Mtetra
.79495 .57771 .79938 .58311 .80971 .58019 .80531 .57476 Mtetra
.80531 .57476 .80971 .58019 .82008 .57725 .81571 .57181 Mtetra
.81571 .57181 .82008 .57725 .83049 .57431 .82614 .56884 Mtetra
.82614 .56884 .83049 .57431 .84094 .57135 .83661 .56586 Mtetra
.83661 .56586 .84094 .57135 .85142 .56838 .84712 .56288 Mtetra
.84712 .56288 .85142 .56838 .86194 .5654 .85767 .55988 Mtetra
.85767 .55988 .86194 .5654 .8725 .56241 .86826 .55687 Mtetra
.86826 .55687 .8725 .56241 .8831 .55941 .87889 .55385 Mtetra
.87889 .55385 .8831 .55941 .89374 .5564 .88955 .55082 Mtetra
.88955 .55082 .89374 .5564 .90441 .55338 .90025 .54777 Mtetra
.90025 .54777 .90441 .55338 .91512 .55035 .911 .54472 Mtetra
.911 .54472 .91512 .55035 .92588 .5473 .92178 .54166 Mtetra
.92178 .54166 .92588 .5473 .93667 .54425 .9326 .53858 Mtetra
.9326 .53858 .93667 .54425 .9475 .54118 .94346 .53549 Mtetra
.94346 .53549 .9475 .54118 .95837 .53811 .95436 .53239 Mtetra
.95436 .53239 .95837 .53811 .96928 .53502 .9653 .52928 Mtetra
.9653 .52928 .96928 .53502 .98024 .53192 .97628 .52616 Mtetra
.38561 .68781 .391 .69252 .39996 .68998 .39459 .68525 Mtetra
.39459 .68525 .39996 .68998 .40895 .68742 .40359 .68268 Mtetra
.40359 .68268 .40895 .68742 .41797 .68486 .41263 .6801 Mtetra
.41263 .6801 .41797 .68486 .42702 .68228 .4217 .67751 Mtetra
.4217 .67751 .42702 .68228 .4361 .6797 .4308 .67492 Mtetra
.4308 .67492 .4361 .6797 .44521 .67711 .43993 .67231 Mtetra
.43993 .67231 .44521 .67711 .45435 .67452 .44909 .6697 Mtetra
.44909 .6697 .45435 .67452 .46352 .67191 .45828 .66707 Mtetra
.45828 .66707 .46352 .67191 .47273 .66929 .46751 .66444 Mtetra
.46751 .66444 .47273 .66929 .48196 .66667 .47676 .6618 Mtetra
.47676 .6618 .48196 .66667 .49123 .66403 .48605 .65915 Mtetra
.48605 .65915 .49123 .66403 .50053 .66139 .49537 .65649 Mtetra
.49537 .65649 .50053 .66139 .50985 .65874 .50472 .65382 Mtetra
.50472 .65382 .50985 .65874 .51922 .65608 .5141 .65114 Mtetra
.5141 .65114 .51922 .65608 .52861 .65341 .52351 .64846 Mtetra
.52351 .64846 .52861 .65341 .53803 .65073 .53296 .64576 Mtetra
.53296 .64576 .53803 .65073 .54749 .64804 .54244 .64305 Mtetra
.54244 .64305 .54749 .64804 .55698 .64534 .55195 .64034 Mtetra
.55195 .64034 .55698 .64534 .5665 .64264 .56149 .63762 Mtetra
.56149 .63762 .5665 .64264 .57606 .63992 .57107 .63488 Mtetra
.57107 .63488 .57606 .63992 .58565 .6372 .58068 .63214 Mtetra
.58068 .63214 .58565 .6372 .59527 .63446 .59032 .62939 Mtetra
.59032 .62939 .59527 .63446 .60493 .63172 .6 .62663 Mtetra
.6 .62663 .60493 .63172 .61461 .62896 .60971 .62385 Mtetra
.60971 .62385 .61461 .62896 .62434 .6262 .61946 .62107 Mtetra
.61946 .62107 .62434 .6262 .63409 .62343 .62924 .61828 Mtetra
.62924 .61828 .63409 .62343 .64388 .62064 .63905 .61548 Mtetra
.63905 .61548 .64388 .62064 .65371 .61785 .6489 .61267 Mtetra
.6489 .61267 .65371 .61785 .66357 .61505 .65878 .60985 Mtetra
.65878 .60985 .66357 .61505 .67346 .61224 .6687 .60702 Mtetra
.6687 .60702 .67346 .61224 .68339 .60942 .67865 .60418 Mtetra
.67865 .60418 .68339 .60942 .69335 .60658 .68864 .60133 Mtetra
.68864 .60133 .69335 .60658 .70335 .60374 .69866 .59847 Mtetra
.69866 .59847 .70335 .60374 .71338 .60089 .70872 .5956 Mtetra
.70872 .5956 .71338 .60089 .72345 .59803 .71881 .59272 Mtetra
.71881 .59272 .72345 .59803 .73356 .59516 .72894 .58983 Mtetra
.72894 .58983 .73356 .59516 .7437 .59227 .73911 .58692 Mtetra
.73911 .58692 .7437 .59227 .75387 .58938 .74931 .58401 Mtetra
.74931 .58401 .75387 .58938 .76409 .58648 .75955 .58109 Mtetra
.75955 .58109 .76409 .58648 .77434 .58356 .76982 .57816 Mtetra
.76982 .57816 .77434 .58356 .78462 .58064 .78014 .57521 Mtetra
.78014 .57521 .78462 .58064 .79495 .57771 .79049 .57226 Mtetra
.79049 .57226 .79495 .57771 .80531 .57476 .80087 .5693 Mtetra
.80087 .5693 .80531 .57476 .81571 .57181 .8113 .56632 Mtetra
.8113 .56632 .81571 .57181 .82614 .56884 .82176 .56334 Mtetra
.82176 .56334 .82614 .56884 .83661 .56586 .83226 .56034 Mtetra
.83226 .56034 .83661 .56586 .84712 .56288 .8428 .55733 Mtetra
.8428 .55733 .84712 .56288 .85767 .55988 .85337 .55431 Mtetra
.85337 .55431 .85767 .55988 .86826 .55687 .86399 .55128 Mtetra
.86399 .55128 .86826 .55687 .87889 .55385 .87464 .54824 Mtetra
.87464 .54824 .87889 .55385 .88955 .55082 .88533 .54519 Mtetra
.88533 .54519 .88955 .55082 .90025 .54777 .89607 .54213 Mtetra
.89607 .54213 .90025 .54777 .911 .54472 .90684 .53905 Mtetra
.90684 .53905 .911 .54472 .92178 .54166 .91765 .53597 Mtetra
.91765 .53597 .92178 .54166 .9326 .53858 .9285 .53287 Mtetra
.9285 .53287 .9326 .53858 .94346 .53549 .93939 .52976 Mtetra
.93939 .52976 .94346 .53549 .95436 .53239 .95032 .52664 Mtetra
.95032 .52664 .95436 .53239 .9653 .52928 .96129 .52351 Mtetra
.96129 .52351 .9653 .52928 .97628 .52616 .9723 .52037 Mtetra
.38018 .68308 .38561 .68781 .39459 .68525 .38918 .6805 Mtetra
.38918 .6805 .39459 .68525 .40359 .68268 .3982 .67791 Mtetra
.3982 .67791 .40359 .68268 .41263 .6801 .40726 .67532 Mtetra
.40726 .67532 .41263 .6801 .4217 .67751 .41635 .67271 Mtetra
.41635 .67271 .4217 .67751 .4308 .67492 .42547 .6701 Mtetra
.42547 .6701 .4308 .67492 .43993 .67231 .43462 .66748 Mtetra
.43462 .66748 .43993 .67231 .44909 .6697 .4438 .66485 Mtetra
.4438 .66485 .44909 .6697 .45828 .66707 .45301 .66221 Mtetra
.45301 .66221 .45828 .66707 .46751 .66444 .46225 .65956 Mtetra
.46225 .65956 .46751 .66444 .47676 .6618 .47153 .6569 Mtetra
.47153 .6569 .47676 .6618 .48605 .65915 .48083 .65423 Mtetra
.48083 .65423 .48605 .65915 .49537 .65649 .49017 .65156 Mtetra
.49017 .65156 .49537 .65649 .50472 .65382 .49954 .64887 Mtetra
.49954 .64887 .50472 .65382 .5141 .65114 .50895 .64618 Mtetra
.50895 .64618 .5141 .65114 .52351 .64846 .51838 .64347 Mtetra
.51838 .64347 .52351 .64846 .53296 .64576 .52785 .64076 Mtetra
.52785 .64076 .53296 .64576 .54244 .64305 .53735 .63804 Mtetra
.53735 .63804 .54244 .64305 .55195 .64034 .54688 .6353 Mtetra
.54688 .6353 .55195 .64034 .56149 .63762 .55645 .63256 Mtetra
.55645 .63256 .56149 .63762 .57107 .63488 .56605 .62981 Mtetra
.56605 .62981 .57107 .63488 .58068 .63214 .57568 .62705 Mtetra
.57568 .62705 .58068 .63214 .59032 .62939 .58535 .62428 Mtetra
.58535 .62428 .59032 .62939 .6 .62663 .59505 .6215 Mtetra
.59505 .6215 .6 .62663 .60971 .62385 .60478 .61871 Mtetra
.60478 .61871 .60971 .62385 .61946 .62107 .61455 .61591 Mtetra
.61455 .61591 .61946 .62107 .62924 .61828 .62435 .6131 Mtetra
.62435 .6131 .62924 .61828 .63905 .61548 .63419 .61028 Mtetra
.63419 .61028 .63905 .61548 .6489 .61267 .64406 .60746 Mtetra
.64406 .60746 .6489 .61267 .65878 .60985 .65396 .60462 Mtetra
.65396 .60462 .65878 .60985 .6687 .60702 .66391 .60177 Mtetra
.66391 .60177 .6687 .60702 .67865 .60418 .67388 .59891 Mtetra
.67388 .59891 .67865 .60418 .68864 .60133 .68389 .59604 Mtetra
.68389 .59604 .68864 .60133 .69866 .59847 .69394 .59316 Mtetra
.69394 .59316 .69866 .59847 .70872 .5956 .70402 .59027 Mtetra
.70402 .59027 .70872 .5956 .71881 .59272 .71414 .58737 Mtetra
.71414 .58737 .71881 .59272 .72894 .58983 .7243 .58446 Mtetra
.7243 .58446 .72894 .58983 .73911 .58692 .73449 .58154 Mtetra
.73449 .58154 .73911 .58692 .74931 .58401 .74472 .57861 Mtetra
.74472 .57861 .74931 .58401 .75955 .58109 .75498 .57567 Mtetra
.75498 .57567 .75955 .58109 .76982 .57816 .76528 .57272 Mtetra
.76528 .57272 .76982 .57816 .78014 .57521 .77562 .56975 Mtetra
.77562 .56975 .78014 .57521 .79049 .57226 .786 .56678 Mtetra
.786 .56678 .79049 .57226 .80087 .5693 .79641 .5638 Mtetra
.79641 .5638 .80087 .5693 .8113 .56632 .80686 .5608 Mtetra
.80686 .5608 .8113 .56632 .82176 .56334 .81735 .55779 Mtetra
.81735 .55779 .82176 .56334 .83226 .56034 .82788 .55478 Mtetra
.82788 .55478 .83226 .56034 .8428 .55733 .83844 .55175 Mtetra
.83844 .55175 .8428 .55733 .85337 .55431 .84905 .54871 Mtetra
.84905 .54871 .85337 .55431 .86399 .55128 .85969 .54566 Mtetra
.85969 .54566 .86399 .55128 .87464 .54824 .87037 .5426 Mtetra
.87037 .5426 .87464 .54824 .88533 .54519 .88109 .53953 Mtetra
.88109 .53953 .88533 .54519 .89607 .54213 .89185 .53644 Mtetra
.89185 .53644 .89607 .54213 .90684 .53905 .90265 .53335 Mtetra
.90265 .53335 .90684 .53905 .91765 .53597 .91349 .53024 Mtetra
.91349 .53024 .91765 .53597 .9285 .53287 .92437 .52712 Mtetra
.92437 .52712 .9285 .53287 .93939 .52976 .93529 .524 Mtetra
.93529 .524 .93939 .52976 .95032 .52664 .94625 .52085 Mtetra
.94625 .52085 .95032 .52664 .96129 .52351 .95725 .5177 Mtetra
.95725 .5177 .96129 .52351 .9723 .52037 .96829 .51454 Mtetra
.37472 .67831 .38018 .68308 .38918 .6805 .38373 .67572 Mtetra
.38373 .67572 .38918 .6805 .3982 .67791 .39278 .67311 Mtetra
.39278 .67311 .3982 .67791 .40726 .67532 .40186 .6705 Mtetra
.40186 .6705 .40726 .67532 .41635 .67271 .41096 .66788 Mtetra
.41096 .66788 .41635 .67271 .42547 .6701 .4201 .66525 Mtetra
.4201 .66525 .42547 .6701 .43462 .66748 .42927 .66261 Mtetra
.42927 .66261 .43462 .66748 .4438 .66485 .43847 .65996 Mtetra
.43847 .65996 .4438 .66485 .45301 .66221 .4477 .65731 Mtetra
.4477 .65731 .45301 .66221 .46225 .65956 .45697 .65464 Mtetra
.45697 .65464 .46225 .65956 .47153 .6569 .46626 .65197 Mtetra
.46626 .65197 .47153 .6569 .48083 .65423 .47559 .64928 Mtetra
.47559 .64928 .48083 .65423 .49017 .65156 .48495 .64659 Mtetra
.48495 .64659 .49017 .65156 .49954 .64887 .49434 .64389 Mtetra
.49434 .64389 .49954 .64887 .50895 .64618 .50376 .64118 Mtetra
.50376 .64118 .50895 .64618 .51838 .64347 .51322 .63846 Mtetra
.51322 .63846 .51838 .64347 .52785 .64076 .52271 .63572 Mtetra
.52271 .63572 .52785 .64076 .53735 .63804 .53223 .63298 Mtetra
.53223 .63298 .53735 .63804 .54688 .6353 .54178 .63024 Mtetra
.54178 .63024 .54688 .6353 .55645 .63256 .55137 .62748 Mtetra
.55137 .62748 .55645 .63256 .56605 .62981 .56099 .62471 Mtetra
.56099 .62471 .56605 .62981 .57568 .62705 .57065 .62193 Mtetra
.57065 .62193 .57568 .62705 .58535 .62428 .58034 .61914 Mtetra
.58034 .61914 .58535 .62428 .59505 .6215 .59006 .61634 Mtetra
.59006 .61634 .59505 .6215 .60478 .61871 .59982 .61354 Mtetra
.59982 .61354 .60478 .61871 .61455 .61591 .60961 .61072 Mtetra
.60961 .61072 .61455 .61591 .62435 .6131 .61943 .60789 Mtetra
.61943 .60789 .62435 .6131 .63419 .61028 .62929 .60505 Mtetra
.62929 .60505 .63419 .61028 .64406 .60746 .63919 .60221 Mtetra
.63919 .60221 .64406 .60746 .65396 .60462 .64912 .59935 Mtetra
.64912 .59935 .65396 .60462 .66391 .60177 .65908 .59648 Mtetra
.65908 .59648 .66391 .60177 .67388 .59891 .66908 .5936 Mtetra
.66908 .5936 .67388 .59891 .68389 .59604 .67912 .59072 Mtetra
.67912 .59072 .68389 .59604 .69394 .59316 .68919 .58782 Mtetra
.68919 .58782 .69394 .59316 .70402 .59027 .6993 .58491 Mtetra
.6993 .58491 .70402 .59027 .71414 .58737 .70944 .58199 Mtetra
.70944 .58199 .71414 .58737 .7243 .58446 .71962 .57906 Mtetra
.71962 .57906 .7243 .58446 .73449 .58154 .72984 .57612 Mtetra
.72984 .57612 .73449 .58154 .74472 .57861 .74009 .57317 Mtetra
.74009 .57317 .74472 .57861 .75498 .57567 .75038 .57021 Mtetra
.75038 .57021 .75498 .57567 .76528 .57272 .76071 .56724 Mtetra
.76071 .56724 .76528 .57272 .77562 .56975 .77107 .56426 Mtetra
.77107 .56426 .77562 .56975 .786 .56678 .78148 .56126 Mtetra
.78148 .56126 .786 .56678 .79641 .5638 .79192 .55826 Mtetra
.79192 .55826 .79641 .5638 .80686 .5608 .80239 .55524 Mtetra
.80239 .55524 .80686 .5608 .81735 .55779 .81291 .55222 Mtetra
.81291 .55222 .81735 .55779 .82788 .55478 .82346 .54918 Mtetra
.82346 .54918 .82788 .55478 .83844 .55175 .83406 .54613 Mtetra
.83406 .54613 .83844 .55175 .84905 .54871 .84469 .54307 Mtetra
.84469 .54307 .84905 .54871 .85969 .54566 .85536 .54 Mtetra
.85536 .54 .85969 .54566 .87037 .5426 .86607 .53692 Mtetra
.86607 .53692 .87037 .5426 .88109 .53953 .87682 .53383 Mtetra
.87682 .53383 .88109 .53953 .89185 .53644 .88761 .53072 Mtetra
.88761 .53072 .89185 .53644 .90265 .53335 .89844 .52761 Mtetra
.89844 .52761 .90265 .53335 .91349 .53024 .90931 .52448 Mtetra
.90931 .52448 .91349 .53024 .92437 .52712 .92022 .52134 Mtetra
.92022 .52134 .92437 .52712 .93529 .524 .93116 .51819 Mtetra
.93116 .51819 .93529 .524 .94625 .52085 .94216 .51503 Mtetra
.94216 .51503 .94625 .52085 .95725 .5177 .95319 .51185 Mtetra
.95319 .51185 .95725 .5177 .96829 .51454 .96426 .50866 Mtetra
.36922 .67351 .37472 .67831 .38373 .67572 .37826 .6709 Mtetra
.37826 .6709 .38373 .67572 .39278 .67311 .38732 .66828 Mtetra
.38732 .66828 .39278 .67311 .40186 .6705 .39642 .66566 Mtetra
.39642 .66566 .40186 .6705 .41096 .66788 .40554 .66302 Mtetra
.40554 .66302 .41096 .66788 .4201 .66525 .4147 .66037 Mtetra
.4147 .66037 .4201 .66525 .42927 .66261 .42389 .65772 Mtetra
.42389 .65772 .42927 .66261 .43847 .65996 .43311 .65505 Mtetra
.43311 .65505 .43847 .65996 .4477 .65731 .44236 .65238 Mtetra
.44236 .65238 .4477 .65731 .45697 .65464 .45165 .6497 Mtetra
.45165 .6497 .45697 .65464 .46626 .65197 .46096 .64701 Mtetra
.46096 .64701 .46626 .65197 .47559 .64928 .47031 .6443 Mtetra
.47031 .6443 .47559 .64928 .48495 .64659 .47969 .64159 Mtetra
.47969 .64159 .48495 .64659 .49434 .64389 .4891 .63887 Mtetra
.4891 .63887 .49434 .64389 .50376 .64118 .49855 .63615 Mtetra
.49855 .63615 .50376 .64118 .51322 .63846 .50802 .63341 Mtetra
.50802 .63341 .51322 .63846 .52271 .63572 .51753 .63066 Mtetra
.51753 .63066 .52271 .63572 .53223 .63298 .52708 .6279 Mtetra
.52708 .6279 .53223 .63298 .54178 .63024 .53665 .62513 Mtetra
.53665 .62513 .54178 .63024 .55137 .62748 .54626 .62236 Mtetra
.54626 .62236 .55137 .62748 .56099 .62471 .55591 .61957 Mtetra
.55591 .61957 .56099 .62471 .57065 .62193 .56558 .61677 Mtetra
.56558 .61677 .57065 .62193 .58034 .61914 .57529 .61397 Mtetra
.57529 .61397 .58034 .61914 .59006 .61634 .58504 .61115 Mtetra
.58504 .61115 .59006 .61634 .59982 .61354 .59482 .60833 Mtetra
.59482 .60833 .59982 .61354 .60961 .61072 .60463 .60549 Mtetra
.60463 .60549 .60961 .61072 .61943 .60789 .61448 .60265 Mtetra
.61448 .60265 .61943 .60789 .62929 .60505 .62437 .59979 Mtetra
.62437 .59979 .62929 .60505 .63919 .60221 .63428 .59692 Mtetra
.63428 .59692 .63919 .60221 .64912 .59935 .64424 .59405 Mtetra
.64424 .59405 .64912 .59935 .65908 .59648 .65423 .59116 Mtetra
.65423 .59116 .65908 .59648 .66908 .5936 .66425 .58826 Mtetra
.66425 .58826 .66908 .5936 .67912 .59072 .67431 .58536 Mtetra
.67431 .58536 .67912 .59072 .68919 .58782 .68441 .58244 Mtetra
.68441 .58244 .68919 .58782 .6993 .58491 .69454 .57951 Mtetra
.69454 .57951 .6993 .58491 .70944 .58199 .70471 .57657 Mtetra
.70471 .57657 .70944 .58199 .71962 .57906 .71491 .57363 Mtetra
.71491 .57363 .71962 .57906 .72984 .57612 .72516 .57067 Mtetra
.72516 .57067 .72984 .57612 .74009 .57317 .73544 .5677 Mtetra
.73544 .5677 .74009 .57317 .75038 .57021 .74575 .56471 Mtetra
.74575 .56471 .75038 .57021 .76071 .56724 .75611 .56172 Mtetra
.75611 .56172 .76071 .56724 .77107 .56426 .7665 .55872 Mtetra
.7665 .55872 .77107 .56426 .78148 .56126 .77693 .55571 Mtetra
.77693 .55571 .78148 .56126 .79192 .55826 .78739 .55268 Mtetra
.78739 .55268 .79192 .55826 .80239 .55524 .7979 .54965 Mtetra
.7979 .54965 .80239 .55524 .81291 .55222 .80844 .5466 Mtetra
.80844 .5466 .81291 .55222 .82346 .54918 .81902 .54354 Mtetra
.81902 .54354 .82346 .54918 .83406 .54613 .82964 .54047 Mtetra
.82964 .54047 .83406 .54613 .84469 .54307 .8403 .53739 Mtetra
.8403 .53739 .84469 .54307 .85536 .54 .851 .5343 Mtetra
.851 .5343 .85536 .54 .86607 .53692 .86174 .5312 Mtetra
.86174 .5312 .86607 .53692 .87682 .53383 .87252 .52809 Mtetra
.87252 .52809 .87682 .53383 .88761 .53072 .88334 .52496 Mtetra
.88334 .52496 .88761 .53072 .89844 .52761 .89419 .52182 Mtetra
.89419 .52182 .89844 .52761 .90931 .52448 .90509 .51867 Mtetra
.90509 .51867 .90931 .52448 .92022 .52134 .91603 .51551 Mtetra
.91603 .51551 .92022 .52134 .93116 .51819 .92701 .51234 Mtetra
.92701 .51234 .93116 .51819 .94216 .51503 .93803 .50916 Mtetra
.93803 .50916 .94216 .51503 .95319 .51185 .94909 .50596 Mtetra
.94909 .50596 .95319 .51185 .96426 .50866 .9602 .50275 Mtetra
.36369 .66869 .36922 .67351 .37826 .6709 .37275 .66606 Mtetra
.37275 .66606 .37826 .6709 .38732 .66828 .38183 .66342 Mtetra
.38183 .66342 .38732 .66828 .39642 .66566 .39094 .66078 Mtetra
.39094 .66078 .39642 .66566 .40554 .66302 .40009 .65813 Mtetra
.40009 .65813 .40554 .66302 .4147 .66037 .40927 .65546 Mtetra
.40927 .65546 .4147 .66037 .42389 .65772 .41848 .65279 Mtetra
.41848 .65279 .42389 .65772 .43311 .65505 .42772 .65011 Mtetra
.42772 .65011 .43311 .65505 .44236 .65238 .43699 .64742 Mtetra
.43699 .64742 .44236 .65238 .45165 .6497 .44629 .64472 Mtetra
.44629 .64472 .45165 .6497 .46096 .64701 .45563 .64201 Mtetra
.45563 .64201 .46096 .64701 .47031 .6443 .465 .63929 Mtetra
.465 .63929 .47031 .6443 .47969 .64159 .4744 .63657 Mtetra
.4744 .63657 .47969 .64159 .4891 .63887 .48383 .63383 Mtetra
.48383 .63383 .4891 .63887 .49855 .63615 .4933 .63108 Mtetra
.4933 .63108 .49855 .63615 .50802 .63341 .50279 .62833 Mtetra
.50279 .62833 .50802 .63341 .51753 .63066 .51233 .62556 Mtetra
.51233 .62556 .51753 .63066 .52708 .6279 .52189 .62279 Mtetra
.52189 .62279 .52708 .6279 .53665 .62513 .53149 .62 Mtetra
.53149 .62 .53665 .62513 .54626 .62236 .54112 .61721 Mtetra
.54112 .61721 .54626 .62236 .55591 .61957 .55079 .6144 Mtetra
.55079 .6144 .55591 .61957 .56558 .61677 .56049 .61159 Mtetra
.56049 .61159 .56558 .61677 .57529 .61397 .57022 .60876 Mtetra
.57022 .60876 .57529 .61397 .58504 .61115 .57999 .60593 Mtetra
.57999 .60593 .58504 .61115 .59482 .60833 .58979 .60308 Mtetra
.58979 .60308 .59482 .60833 .60463 .60549 .59963 .60023 Mtetra
.59963 .60023 .60463 .60549 .61448 .60265 .6095 .59737 Mtetra
.6095 .59737 .61448 .60265 .62437 .59979 .61941 .59449 Mtetra
.61941 .59449 .62437 .59979 .63428 .59692 .62935 .59161 Mtetra
.62935 .59161 .63428 .59692 .64424 .59405 .63933 .58871 Mtetra
.63933 .58871 .64424 .59405 .65423 .59116 .64934 .58581 Mtetra
.64934 .58581 .65423 .59116 .66425 .58826 .65939 .58289 Mtetra
.65939 .58289 .66425 .58826 .67431 .58536 .66947 .57996 Mtetra
.66947 .57996 .67431 .58536 .68441 .58244 .67959 .57703 Mtetra
.67959 .57703 .68441 .58244 .69454 .57951 .68975 .57408 Mtetra
.68975 .57408 .69454 .57951 .70471 .57657 .69995 .57112 Mtetra
.69995 .57112 .70471 .57657 .71491 .57363 .71018 .56815 Mtetra
.71018 .56815 .71491 .57363 .72516 .57067 .72044 .56517 Mtetra
.72044 .56517 .72516 .57067 .73544 .5677 .73075 .56218 Mtetra
.73075 .56218 .73544 .5677 .74575 .56471 .74109 .55918 Mtetra
.74109 .55918 .74575 .56471 .75611 .56172 .75147 .55617 Mtetra
.75147 .55617 .75611 .56172 .7665 .55872 .76189 .55315 Mtetra
.76189 .55315 .7665 .55872 .77693 .55571 .77234 .55012 Mtetra
.77234 .55012 .77693 .55571 .78739 .55268 .78284 .54707 Mtetra
.78284 .54707 .78739 .55268 .7979 .54965 .79337 .54401 Mtetra
.79337 .54401 .7979 .54965 .80844 .5466 .80394 .54095 Mtetra
.80394 .54095 .80844 .5466 .81902 .54354 .81455 .53787 Mtetra
.81455 .53787 .81902 .54354 .82964 .54047 .8252 .53478 Mtetra
.8252 .53478 .82964 .54047 .8403 .53739 .83589 .53168 Mtetra
.83589 .53168 .8403 .53739 .851 .5343 .84661 .52857 Mtetra
.84661 .52857 .851 .5343 .86174 .5312 .85738 .52544 Mtetra
.85738 .52544 .86174 .5312 .87252 .52809 .86819 .52231 Mtetra
.86819 .52231 .87252 .52809 .88334 .52496 .87903 .51916 Mtetra
.87903 .51916 .88334 .52496 .89419 .52182 .88992 .516 Mtetra
.88992 .516 .89419 .52182 .90509 .51867 .90085 .51283 Mtetra
.90085 .51283 .90509 .51867 .91603 .51551 .91182 .50965 Mtetra
.91182 .50965 .91603 .51551 .92701 .51234 .92283 .50645 Mtetra
.92283 .50645 .92701 .51234 .93803 .50916 .93388 .50324 Mtetra
.93388 .50324 .93803 .50916 .94909 .50596 .94497 .50003 Mtetra
.94497 .50003 .94909 .50596 .9602 .50275 .9561 .4968 Mtetra
.35813 .66383 .36369 .66869 .37275 .66606 .3672 .66119 Mtetra
.3672 .66119 .37275 .66606 .38183 .66342 .3763 .65854 Mtetra
.3763 .65854 .38183 .66342 .39094 .66078 .38544 .65587 Mtetra
.38544 .65587 .39094 .66078 .40009 .65813 .3946 .6532 Mtetra
.3946 .6532 .40009 .65813 .40927 .65546 .4038 .65052 Mtetra
.4038 .65052 .40927 .65546 .41848 .65279 .41303 .64783 Mtetra
.41303 .64783 .41848 .65279 .42772 .65011 .42229 .64514 Mtetra
.42229 .64514 .42772 .65011 .43699 .64742 .43158 .64243 Mtetra
.43158 .64243 .43699 .64742 .44629 .64472 .4409 .63971 Mtetra
.4409 .63971 .44629 .64472 .45563 .64201 .45026 .63699 Mtetra
.45026 .63699 .45563 .64201 .465 .63929 .45965 .63425 Mtetra
.45965 .63425 .465 .63929 .4744 .63657 .46907 .63151 Mtetra
.46907 .63151 .4744 .63657 .48383 .63383 .47853 .62875 Mtetra
.47853 .62875 .48383 .63383 .4933 .63108 .48801 .62599 Mtetra
.48801 .62599 .4933 .63108 .50279 .62833 .49753 .62321 Mtetra
.49753 .62321 .50279 .62833 .51233 .62556 .50709 .62043 Mtetra
.50709 .62043 .51233 .62556 .52189 .62279 .51667 .61764 Mtetra
.51667 .61764 .52189 .62279 .53149 .62 .52629 .61483 Mtetra
.52629 .61483 .53149 .62 .54112 .61721 .53595 .61202 Mtetra
.53595 .61202 .54112 .61721 .55079 .6144 .54563 .6092 Mtetra
.54563 .6092 .55079 .6144 .56049 .61159 .55536 .60636 Mtetra
.55536 .60636 .56049 .61159 .57022 .60876 .56511 .60352 Mtetra
.56511 .60352 .57022 .60876 .57999 .60593 .5749 .60067 Mtetra
.5749 .60067 .57999 .60593 .58979 .60308 .58473 .59781 Mtetra
.58473 .59781 .58979 .60308 .59963 .60023 .59459 .59493 Mtetra
.59459 .59493 .59963 .60023 .6095 .59737 .60448 .59205 Mtetra
.60448 .59205 .6095 .59737 .61941 .59449 .61441 .58916 Mtetra
.61441 .58916 .61941 .59449 .62935 .59161 .62438 .58625 Mtetra
.62438 .58625 .62935 .59161 .63933 .58871 .63438 .58334 Mtetra
.63438 .58334 .63933 .58871 .64934 .58581 .64442 .58041 Mtetra
.64442 .58041 .64934 .58581 .65939 .58289 .65449 .57748 Mtetra
.65449 .57748 .65939 .58289 .66947 .57996 .6646 .57453 Mtetra
.6646 .57453 .66947 .57996 .67959 .57703 .67475 .57158 Mtetra
.67475 .57158 .67959 .57703 .68975 .57408 .68493 .56861 Mtetra
.68493 .56861 .68975 .57408 .69995 .57112 .69515 .56563 Mtetra
.69515 .56563 .69995 .57112 .71018 .56815 .70541 .56264 Mtetra
.70541 .56264 .71018 .56815 .72044 .56517 .7157 .55965 Mtetra
.7157 .55965 .72044 .56517 .73075 .56218 .72603 .55664 Mtetra
.72603 .55664 .73075 .56218 .74109 .55918 .7364 .55361 Mtetra
.7364 .55361 .74109 .55918 .75147 .55617 .7468 .55058 Mtetra
.7468 .55058 .75147 .55617 .76189 .55315 .75725 .54754 Mtetra
.75725 .54754 .76189 .55315 .77234 .55012 .76773 .54449 Mtetra
.76773 .54449 .77234 .55012 .78284 .54707 .77825 .54142 Mtetra
.77825 .54142 .78284 .54707 .79337 .54401 .78881 .53834 Mtetra
.78881 .53834 .79337 .54401 .80394 .54095 .79941 .53526 Mtetra
.79941 .53526 .80394 .54095 .81455 .53787 .81005 .53216 Mtetra
.81005 .53216 .81455 .53787 .8252 .53478 .82072 .52905 Mtetra
.82072 .52905 .8252 .53478 .83589 .53168 .83144 .52592 Mtetra
.83144 .52592 .83589 .53168 .84661 .52857 .84219 .52279 Mtetra
.84219 .52279 .84661 .52857 .85738 .52544 .85299 .51964 Mtetra
.85299 .51964 .85738 .52544 .86819 .52231 .86383 .51649 Mtetra
.86383 .51649 .86819 .52231 .87903 .51916 .8747 .51332 Mtetra
.8747 .51332 .87903 .51916 .88992 .516 .88562 .51014 Mtetra
.88562 .51014 .88992 .516 .90085 .51283 .89658 .50694 Mtetra
.89658 .50694 .90085 .51283 .91182 .50965 .90758 .50374 Mtetra
.90758 .50374 .91182 .50965 .92283 .50645 .91862 .50052 Mtetra
.91862 .50052 .92283 .50645 .93388 .50324 .9297 .49729 Mtetra
.9297 .49729 .93388 .50324 .94497 .50003 .94082 .49405 Mtetra
.94082 .49405 .94497 .50003 .9561 .4968 .95198 .4908 Mtetra
.35253 .65894 .35813 .66383 .3672 .66119 .36162 .65628 Mtetra
.36162 .65628 .3672 .66119 .3763 .65854 .37074 .65361 Mtetra
.37074 .65361 .3763 .65854 .38544 .65587 .3799 .65094 Mtetra
.3799 .65094 .38544 .65587 .3946 .6532 .38908 .64825 Mtetra
.38908 .64825 .3946 .6532 .4038 .65052 .3983 .64555 Mtetra
.3983 .64555 .4038 .65052 .41303 .64783 .40755 .64285 Mtetra
.40755 .64285 .41303 .64783 .42229 .64514 .41683 .64013 Mtetra
.41683 .64013 .42229 .64514 .43158 .64243 .42614 .63741 Mtetra
.42614 .63741 .43158 .64243 .4409 .63971 .43548 .63467 Mtetra
.43548 .63467 .4409 .63971 .45026 .63699 .44486 .63193 Mtetra
.44486 .63193 .45026 .63699 .45965 .63425 .45427 .62918 Mtetra
.45427 .62918 .45965 .63425 .46907 .63151 .46371 .62641 Mtetra
.46371 .62641 .46907 .63151 .47853 .62875 .47319 .62364 Mtetra
.47319 .62364 .47853 .62875 .48801 .62599 .48269 .62086 Mtetra
.48269 .62086 .48801 .62599 .49753 .62321 .49224 .61807 Mtetra
.49224 .61807 .49753 .62321 .50709 .62043 .50181 .61527 Mtetra
.50181 .61527 .50709 .62043 .51667 .61764 .51142 .61245 Mtetra
.51142 .61245 .51667 .61764 .52629 .61483 .52106 .60963 Mtetra
.52106 .60963 .52629 .61483 .53595 .61202 .53074 .6068 Mtetra
.53074 .6068 .53595 .61202 .54563 .6092 .54045 .60396 Mtetra
.54045 .60396 .54563 .6092 .55536 .60636 .55019 .60111 Mtetra
.55019 .60111 .55536 .60636 .56511 .60352 .55997 .59825 Mtetra
.55997 .59825 .56511 .60352 .5749 .60067 .56978 .59538 Mtetra
.56978 .59538 .5749 .60067 .58473 .59781 .57963 .59249 Mtetra
.57963 .59249 .58473 .59781 .59459 .59493 .58952 .5896 Mtetra
.58952 .5896 .59459 .59493 .60448 .59205 .59944 .5867 Mtetra
.59944 .5867 .60448 .59205 .61441 .58916 .60939 .58379 Mtetra
.60939 .58379 .61441 .58916 .62438 .58625 .61938 .58087 Mtetra
.61938 .58087 .62438 .58625 .63438 .58334 .62941 .57793 Mtetra
.62941 .57793 .63438 .58334 .64442 .58041 .63947 .57499 Mtetra
.63947 .57499 .64442 .58041 .65449 .57748 .64957 .57203 Mtetra
.64957 .57203 .65449 .57748 .6646 .57453 .6597 .56907 Mtetra
.6597 .56907 .6646 .57453 .67475 .57158 .66987 .56609 Mtetra
.66987 .56609 .67475 .57158 .68493 .56861 .68008 .56311 Mtetra
.68008 .56311 .68493 .56861 .69515 .56563 .69032 .56011 Mtetra
.69032 .56011 .69515 .56563 .70541 .56264 .7006 .5571 Mtetra
.7006 .5571 .70541 .56264 .7157 .55965 .71092 .55408 Mtetra
.71092 .55408 .7157 .55965 .72603 .55664 .72128 .55105 Mtetra
.72128 .55105 .72603 .55664 .7364 .55361 .73168 .54801 Mtetra
.73168 .54801 .7364 .55361 .7468 .55058 .74211 .54496 Mtetra
.74211 .54496 .7468 .55058 .75725 .54754 .75258 .54189 Mtetra
.75258 .54189 .75725 .54754 .76773 .54449 .76309 .53882 Mtetra
.76309 .53882 .76773 .54449 .77825 .54142 .77364 .53573 Mtetra
.77364 .53573 .77825 .54142 .78881 .53834 .78422 .53263 Mtetra
.78422 .53263 .78881 .53834 .79941 .53526 .79485 .52952 Mtetra
.79485 .52952 .79941 .53526 .81005 .53216 .80551 .5264 Mtetra
.80551 .5264 .81005 .53216 .82072 .52905 .81622 .52327 Mtetra
.81622 .52327 .82072 .52905 .83144 .52592 .82696 .52013 Mtetra
.82696 .52013 .83144 .52592 .84219 .52279 .83775 .51697 Mtetra
.83775 .51697 .84219 .52279 .85299 .51964 .84857 .51381 Mtetra
.84857 .51381 .85299 .51964 .86383 .51649 .85944 .51063 Mtetra
.85944 .51063 .86383 .51649 .8747 .51332 .87034 .50744 Mtetra
.87034 .50744 .8747 .51332 .88562 .51014 .88129 .50423 Mtetra
.88129 .50423 .88562 .51014 .89658 .50694 .89227 .50102 Mtetra
.89227 .50102 .89658 .50694 .90758 .50374 .9033 .49779 Mtetra
.9033 .49779 .90758 .50374 .91862 .50052 .91437 .49455 Mtetra
.91437 .49455 .91862 .50052 .9297 .49729 .92549 .4913 Mtetra
.92549 .4913 .9297 .49729 .94082 .49405 .93664 .48804 Mtetra
.93664 .48804 .94082 .49405 .95198 .4908 .94784 .48476 Mtetra
.34689 .65403 .35253 .65894 .36162 .65628 .356 .65135 Mtetra
.356 .65135 .36162 .65628 .37074 .65361 .36515 .64866 Mtetra
.36515 .64866 .37074 .65361 .3799 .65094 .37432 .64597 Mtetra
.37432 .64597 .3799 .65094 .38908 .64825 .38352 .64326 Mtetra
.38352 .64326 .38908 .64825 .3983 .64555 .39276 .64055 Mtetra
.39276 .64055 .3983 .64555 .40755 .64285 .40203 .63783 Mtetra
.40203 .63783 .40755 .64285 .41683 .64013 .41133 .63509 Mtetra
.41133 .63509 .41683 .64013 .42614 .63741 .42066 .63235 Mtetra
.42066 .63235 .42614 .63741 .43548 .63467 .43003 .6296 Mtetra
.43003 .6296 .43548 .63467 .44486 .63193 .43942 .62684 Mtetra
.43942 .62684 .44486 .63193 .45427 .62918 .44885 .62407 Mtetra
.44885 .62407 .45427 .62918 .46371 .62641 .45832 .62129 Mtetra
.45832 .62129 .46371 .62641 .47319 .62364 .46781 .6185 Mtetra
.46781 .6185 .47319 .62364 .48269 .62086 .47734 .6157 Mtetra
.47734 .6157 .48269 .62086 .49224 .61807 .4869 .61289 Mtetra
.4869 .61289 .49224 .61807 .50181 .61527 .4965 .61007 Mtetra
.4965 .61007 .50181 .61527 .51142 .61245 .50613 .60724 Mtetra
.50613 .60724 .51142 .61245 .52106 .60963 .5158 .6044 Mtetra
.5158 .6044 .52106 .60963 .53074 .6068 .52549 .60155 Mtetra
.52549 .60155 .53074 .6068 .54045 .60396 .53523 .59869 Mtetra
.53523 .59869 .54045 .60396 .55019 .60111 .54499 .59582 Mtetra
.54499 .59582 .55019 .60111 .55997 .59825 .5548 .59294 Mtetra
.5548 .59294 .55997 .59825 .56978 .59538 .56463 .59005 Mtetra
.56463 .59005 .56978 .59538 .57963 .59249 .5745 .58715 Mtetra
.5745 .58715 .57963 .59249 .58952 .5896 .58441 .58424 Mtetra
.58441 .58424 .58952 .5896 .59944 .5867 .59435 .58132 Mtetra
.59435 .58132 .59944 .5867 .60939 .58379 .60433 .57838 Mtetra
.60433 .57838 .60939 .58379 .61938 .58087 .61435 .57544 Mtetra
.61435 .57544 .61938 .58087 .62941 .57793 .6244 .57249 Mtetra
.6244 .57249 .62941 .57793 .63947 .57499 .63448 .56952 Mtetra
.63448 .56952 .63947 .57499 .64957 .57203 .6446 .56655 Mtetra
.6446 .56655 .64957 .57203 .6597 .56907 .65476 .56357 Mtetra
.65476 .56357 .6597 .56907 .66987 .56609 .66496 .56057 Mtetra
.66496 .56057 .66987 .56609 .68008 .56311 .67519 .55756 Mtetra
.67519 .55756 .68008 .56311 .69032 .56011 .68546 .55455 Mtetra
.68546 .55455 .69032 .56011 .7006 .5571 .69577 .55152 Mtetra
.69577 .55152 .7006 .5571 .71092 .55408 .70612 .54848 Mtetra
.70612 .54848 .71092 .55408 .72128 .55105 .7165 .54543 Mtetra
.7165 .54543 .72128 .55105 .73168 .54801 .72692 .54236 Mtetra
.72692 .54236 .73168 .54801 .74211 .54496 .73738 .53929 Mtetra
.73738 .53929 .74211 .54496 .75258 .54189 .74788 .53621 Mtetra
.74788 .53621 .75258 .54189 .76309 .53882 .75841 .53311 Mtetra
.75841 .53311 .76309 .53882 .77364 .53573 .76899 .53 Mtetra
.76899 .53 .77364 .53573 .78422 .53263 .7796 .52688 Mtetra
.7796 .52688 .78422 .53263 .79485 .52952 .79026 .52375 Mtetra
.79026 .52375 .79485 .52952 .80551 .5264 .80095 .52061 Mtetra
.80095 .52061 .80551 .5264 .81622 .52327 .81168 .51746 Mtetra
.81168 .51746 .81622 .52327 .82696 .52013 .82245 .51429 Mtetra
.82245 .51429 .82696 .52013 .83775 .51697 .83327 .51112 Mtetra
.83327 .51112 .83775 .51697 .84857 .51381 .84412 .50793 Mtetra
.84412 .50793 .84857 .51381 .85944 .51063 .85501 .50473 Mtetra
.85501 .50473 .85944 .51063 .87034 .50744 .86595 .50151 Mtetra
.86595 .50151 .87034 .50744 .88129 .50423 .87693 .49829 Mtetra
.87693 .49829 .88129 .50423 .89227 .50102 .88794 .49505 Mtetra
.88794 .49505 .89227 .50102 .9033 .49779 .899 .4918 Mtetra
.899 .4918 .9033 .49779 .91437 .49455 .9101 .48854 Mtetra
.9101 .48854 .91437 .49455 .92549 .4913 .92125 .48527 Mtetra
.92125 .48527 .92549 .4913 .93664 .48804 .93243 .48198 Mtetra
.93243 .48198 .93664 .48804 .94784 .48476 .94366 .47868 Mtetra
.34122 .64908 .34689 .65403 .356 .65135 .35035 .64638 Mtetra
.35035 .64638 .356 .65135 .36515 .64866 .35951 .64368 Mtetra
.35951 .64368 .36515 .64866 .37432 .64597 .36871 .64097 Mtetra
.36871 .64097 .37432 .64597 .38352 .64326 .37793 .63825 Mtetra
.37793 .63825 .38352 .64326 .39276 .64055 .38719 .63551 Mtetra
.38719 .63551 .39276 .64055 .40203 .63783 .39647 .63277 Mtetra
.39647 .63277 .40203 .63783 .41133 .63509 .40579 .63002 Mtetra
.40579 .63002 .41133 .63509 .42066 .63235 .41515 .62726 Mtetra
.41515 .62726 .42066 .63235 .43003 .6296 .42453 .62449 Mtetra
.42453 .62449 .43003 .6296 .43942 .62684 .43395 .62172 Mtetra
.43395 .62172 .43942 .62684 .44885 .62407 .4434 .61893 Mtetra
.4434 .61893 .44885 .62407 .45832 .62129 .45289 .61613 Mtetra
.45289 .61613 .45832 .62129 .46781 .6185 .4624 .61332 Mtetra
.4624 .61332 .46781 .6185 .47734 .6157 .47195 .6105 Mtetra
.47195 .6105 .47734 .6157 .4869 .61289 .48154 .60767 Mtetra
.48154 .60767 .4869 .61289 .4965 .61007 .49116 .60484 Mtetra
.49116 .60484 .4965 .61007 .50613 .60724 .50081 .60199 Mtetra
.50081 .60199 .50613 .60724 .5158 .6044 .5105 .59913 Mtetra
.5105 .59913 .5158 .6044 .52549 .60155 .52022 .59626 Mtetra
.52022 .59626 .52549 .60155 .53523 .59869 .52997 .59338 Mtetra
.52997 .59338 .53523 .59869 .54499 .59582 .53976 .59049 Mtetra
.53976 .59049 .54499 .59582 .5548 .59294 .54959 .58759 Mtetra
.54959 .58759 .5548 .59294 .56463 .59005 .55945 .58469 Mtetra
.55945 .58469 .56463 .59005 .5745 .58715 .56934 .58177 Mtetra
.56934 .58177 .5745 .58715 .58441 .58424 .57927 .57884 Mtetra
.57927 .57884 .58441 .58424 .59435 .58132 .58924 .57589 Mtetra
.58924 .57589 .59435 .58132 .60433 .57838 .59924 .57294 Mtetra
.59924 .57294 .60433 .57838 .61435 .57544 .60928 .56998 Mtetra
.60928 .56998 .61435 .57544 .6244 .57249 .61935 .56701 Mtetra
.61935 .56701 .6244 .57249 .63448 .56952 .62946 .56403 Mtetra
.62946 .56403 .63448 .56952 .6446 .56655 .63961 .56103 Mtetra
.63961 .56103 .6446 .56655 .65476 .56357 .64979 .55803 Mtetra
.64979 .55803 .65476 .56357 .66496 .56057 .66002 .55501 Mtetra
.66002 .55501 .66496 .56057 .67519 .55756 .67027 .55198 Mtetra
.67027 .55198 .67519 .55756 .68546 .55455 .68057 .54895 Mtetra
.68057 .54895 .68546 .55455 .69577 .55152 .6909 .5459 Mtetra
.6909 .5459 .69577 .55152 .70612 .54848 .70127 .54284 Mtetra
.70127 .54284 .70612 .54848 .7165 .54543 .71168 .53976 Mtetra
.71168 .53976 .7165 .54543 .72692 .54236 .72213 .53668 Mtetra
.72213 .53668 .72692 .54236 .73738 .53929 .73262 .53359 Mtetra
.73262 .53359 .73738 .53929 .74788 .53621 .74314 .53048 Mtetra
.74314 .53048 .74788 .53621 .75841 .53311 .75371 .52737 Mtetra
.75371 .52737 .75841 .53311 .76899 .53 .76431 .52424 Mtetra
.76431 .52424 .76899 .53 .7796 .52688 .77495 .5211 Mtetra
.77495 .5211 .7796 .52688 .79026 .52375 .78563 .51794 Mtetra
.78563 .51794 .79026 .52375 .80095 .52061 .79635 .51478 Mtetra
.79635 .51478 .80095 .52061 .81168 .51746 .80711 .51161 Mtetra
.80711 .51161 .81168 .51746 .82245 .51429 .81792 .50842 Mtetra
.81792 .50842 .82245 .51429 .83327 .51112 .82876 .50522 Mtetra
.82876 .50522 .83327 .51112 .84412 .50793 .83964 .50201 Mtetra
.83964 .50201 .84412 .50793 .85501 .50473 .85056 .49879 Mtetra
.85056 .49879 .85501 .50473 .86595 .50151 .86153 .49555 Mtetra
.86153 .49555 .86595 .50151 .87693 .49829 .87253 .4923 Mtetra
.87253 .4923 .87693 .49829 .88794 .49505 .88358 .48904 Mtetra
.88358 .48904 .88794 .49505 .899 .4918 .89467 .48577 Mtetra
.89467 .48577 .899 .4918 .9101 .48854 .9058 .48249 Mtetra
.9058 .48249 .9101 .48854 .92125 .48527 .91698 .47919 Mtetra
.91698 .47919 .92125 .48527 .93243 .48198 .92819 .47588 Mtetra
.92819 .47588 .93243 .48198 .94366 .47868 .93945 .47256 Mtetra
.33552 .6441 .34122 .64908 .35035 .64638 .34467 .64139 Mtetra
.34467 .64139 .35035 .64638 .35951 .64368 .35385 .63866 Mtetra
.35385 .63866 .35951 .64368 .36871 .64097 .36306 .63594 Mtetra
.36306 .63594 .36871 .64097 .37793 .63825 .3723 .6332 Mtetra
.3723 .6332 .37793 .63825 .38719 .63551 .38158 .63045 Mtetra
.38158 .63045 .38719 .63551 .39647 .63277 .39089 .62769 Mtetra
.39089 .62769 .39647 .63277 .40579 .63002 .40023 .62492 Mtetra
.40023 .62492 .40579 .63002 .41515 .62726 .4096 .62214 Mtetra
.4096 .62214 .41515 .62726 .42453 .62449 .41901 .61936 Mtetra
.41901 .61936 .42453 .62449 .43395 .62172 .42844 .61656 Mtetra
.42844 .61656 .43395 .62172 .4434 .61893 .43792 .61375 Mtetra
.43792 .61375 .4434 .61893 .45289 .61613 .44742 .61094 Mtetra
.44742 .61094 .45289 .61613 .4624 .61332 .45696 .60811 Mtetra
.45696 .60811 .4624 .61332 .47195 .6105 .46653 .60527 Mtetra
.46653 .60527 .47195 .6105 .48154 .60767 .47614 .60243 Mtetra
.47614 .60243 .48154 .60767 .49116 .60484 .48578 .59957 Mtetra
.48578 .59957 .49116 .60484 .50081 .60199 .49545 .5967 Mtetra
.49545 .5967 .50081 .60199 .5105 .59913 .50516 .59383 Mtetra
.50516 .59383 .5105 .59913 .52022 .59626 .5149 .59094 Mtetra
.5149 .59094 .52022 .59626 .52997 .59338 .52468 .58804 Mtetra
.52468 .58804 .52997 .59338 .53976 .59049 .5345 .58513 Mtetra
.5345 .58513 .53976 .59049 .54959 .58759 .54434 .58222 Mtetra
.54434 .58222 .54959 .58759 .55945 .58469 .55423 .57929 Mtetra
.55423 .57929 .55945 .58469 .56934 .58177 .56414 .57635 Mtetra
.56414 .57635 .56934 .58177 .57927 .57884 .5741 .5734 Mtetra
.5741 .5734 .57927 .57884 .58924 .57589 .58409 .57044 Mtetra
.58409 .57044 .58924 .57589 .59924 .57294 .59412 .56747 Mtetra
.59412 .56747 .59924 .57294 .60928 .56998 .60418 .56449 Mtetra
.60418 .56449 .60928 .56998 .61935 .56701 .61428 .56149 Mtetra
.61428 .56149 .61935 .56701 .62946 .56403 .62441 .55849 Mtetra
.62441 .55849 .62946 .56403 .63961 .56103 .63458 .55547 Mtetra
.63458 .55547 .63961 .56103 .64979 .55803 .64479 .55245 Mtetra
.64479 .55245 .64979 .55803 .66002 .55501 .65504 .54941 Mtetra
.65504 .54941 .66002 .55501 .67027 .55198 .66532 .54637 Mtetra
.66532 .54637 .67027 .55198 .68057 .54895 .67564 .54331 Mtetra
.67564 .54331 .68057 .54895 .6909 .5459 .686 .54024 Mtetra
.686 .54024 .6909 .5459 .70127 .54284 .6964 .53716 Mtetra
.6964 .53716 .70127 .54284 .71168 .53976 .70684 .53406 Mtetra
.70684 .53406 .71168 .53976 .72213 .53668 .71731 .53096 Mtetra
.71731 .53096 .72213 .53668 .73262 .53359 .72782 .52785 Mtetra
.72782 .52785 .73262 .53359 .74314 .53048 .73838 .52472 Mtetra
.73838 .52472 .74314 .53048 .75371 .52737 .74897 .52158 Mtetra
.74897 .52158 .75371 .52737 .76431 .52424 .7596 .51843 Mtetra
.7596 .51843 .76431 .52424 .77495 .5211 .77027 .51527 Mtetra
.77027 .51527 .77495 .5211 .78563 .51794 .78098 .5121 Mtetra
.78098 .5121 .78563 .51794 .79635 .51478 .79173 .50891 Mtetra
.79173 .50891 .79635 .51478 .80711 .51161 .80251 .50571 Mtetra
.80251 .50571 .80711 .51161 .81792 .50842 .81335 .5025 Mtetra
.81335 .5025 .81792 .50842 .82876 .50522 .82422 .49928 Mtetra
.82422 .49928 .82876 .50522 .83964 .50201 .83513 .49605 Mtetra
.83513 .49605 .83964 .50201 .85056 .49879 .84608 .4928 Mtetra
.84608 .4928 .85056 .49879 .86153 .49555 .85707 .48955 Mtetra
.85707 .48955 .86153 .49555 .87253 .4923 .86811 .48627 Mtetra
.86811 .48627 .87253 .4923 .88358 .48904 .87919 .48299 Mtetra
.87919 .48299 .88358 .48904 .89467 .48577 .89031 .4797 Mtetra
.89031 .4797 .89467 .48577 .9058 .48249 .90147 .47639 Mtetra
.90147 .47639 .9058 .48249 .91698 .47919 .91268 .47307 Mtetra
.91268 .47307 .91698 .47919 .92819 .47588 .92392 .46974 Mtetra
.92392 .46974 .92819 .47588 .93945 .47256 .93521 .46639 Mtetra
.32977 .63908 .33552 .6441 .34467 .64139 .33894 .63636 Mtetra
.33894 .63636 .34467 .64139 .35385 .63866 .34814 .63362 Mtetra
.34814 .63362 .35385 .63866 .36306 .63594 .35737 .63087 Mtetra
.35737 .63087 .36306 .63594 .3723 .6332 .36664 .62811 Mtetra
.36664 .62811 .3723 .6332 .38158 .63045 .37593 .62535 Mtetra
.37593 .62535 .38158 .63045 .39089 .62769 .38526 .62257 Mtetra
.38526 .62257 .39089 .62769 .40023 .62492 .39462 .61979 Mtetra
.39462 .61979 .40023 .62492 .4096 .62214 .40402 .61699 Mtetra
.40402 .61699 .4096 .62214 .41901 .61936 .41344 .61418 Mtetra
.41344 .61418 .41901 .61936 .42844 .61656 .4229 .61137 Mtetra
.4229 .61137 .42844 .61656 .43792 .61375 .43239 .60854 Mtetra
.43239 .60854 .43792 .61375 .44742 .61094 .44192 .60571 Mtetra
.44192 .60571 .44742 .61094 .45696 .60811 .45148 .60286 Mtetra
.45148 .60286 .45696 .60811 .46653 .60527 .46108 .60001 Mtetra
.46108 .60001 .46653 .60527 .47614 .60243 .4707 .59714 Mtetra
.4707 .59714 .47614 .60243 .48578 .59957 .48037 .59427 Mtetra
.48037 .59427 .48578 .59957 .49545 .5967 .49006 .59138 Mtetra
.49006 .59138 .49545 .5967 .50516 .59383 .49979 .58849 Mtetra
.49979 .58849 .50516 .59383 .5149 .59094 .50956 .58558 Mtetra
.50956 .58558 .5149 .59094 .52468 .58804 .51936 .58267 Mtetra
.51936 .58267 .52468 .58804 .5345 .58513 .52919 .57974 Mtetra
.52919 .57974 .5345 .58513 .54434 .58222 .53907 .5768 Mtetra
.53907 .5768 .54434 .58222 .55423 .57929 .54897 .57385 Mtetra
.54897 .57385 .55423 .57929 .56414 .57635 .55891 .57089 Mtetra
.55891 .57089 .56414 .57635 .5741 .5734 .56889 .56792 Mtetra
.56889 .56792 .5741 .5734 .58409 .57044 .57891 .56494 Mtetra
.57891 .56494 .58409 .57044 .59412 .56747 .58896 .56195 Mtetra
.58896 .56195 .59412 .56747 .60418 .56449 .59904 .55895 Mtetra
.59904 .55895 .60418 .56449 .61428 .56149 .60917 .55594 Mtetra
.60917 .55594 .61428 .56149 .62441 .55849 .61933 .55292 Mtetra
.61933 .55292 .62441 .55849 .63458 .55547 .62952 .54988 Mtetra
.62952 .54988 .63458 .55547 .64479 .55245 .63976 .54684 Mtetra
.63976 .54684 .64479 .55245 .65504 .54941 .65003 .54378 Mtetra
.65003 .54378 .65504 .54941 .66532 .54637 .66034 .54071 Mtetra
.66034 .54071 .66532 .54637 .67564 .54331 .67069 .53763 Mtetra
.67069 .53763 .67564 .54331 .686 .54024 .68107 .53454 Mtetra
.68107 .53454 .686 .54024 .6964 .53716 .69149 .53144 Mtetra
.69149 .53144 .6964 .53716 .70684 .53406 .70196 .52833 Mtetra
.70196 .52833 .70684 .53406 .71731 .53096 .71246 .5252 Mtetra
.71246 .5252 .71731 .53096 .72782 .52785 .723 .52206 Mtetra
.723 .52206 .72782 .52785 .73838 .52472 .73358 .51892 Mtetra
.73358 .51892 .73838 .52472 .74897 .52158 .74419 .51576 Mtetra
.74419 .51576 .74897 .52158 .7596 .51843 .75485 .51258 Mtetra
.75485 .51258 .7596 .51843 .77027 .51527 .76555 .5094 Mtetra
.76555 .5094 .77027 .51527 .78098 .5121 .77629 .50621 Mtetra
.77629 .50621 .78098 .5121 .79173 .50891 .78707 .503 Mtetra
.78707 .503 .79173 .50891 .80251 .50571 .79788 .49978 Mtetra
.79788 .49978 .80251 .50571 .81335 .5025 .80874 .49655 Mtetra
.80874 .49655 .81335 .5025 .82422 .49928 .81964 .4933 Mtetra
.81964 .4933 .82422 .49928 .83513 .49605 .83058 .49005 Mtetra
.83058 .49005 .83513 .49605 .84608 .4928 .84157 .48678 Mtetra
.84157 .48678 .84608 .4928 .85707 .48955 .85259 .4835 Mtetra
.85259 .4835 .85707 .48955 .86811 .48627 .86366 .4802 Mtetra
.86366 .4802 .86811 .48627 .87919 .48299 .87477 .4769 Mtetra
.87477 .4769 .87919 .48299 .89031 .4797 .88592 .47358 Mtetra
.88592 .47358 .89031 .4797 .90147 .47639 .89711 .47025 Mtetra
.89711 .47025 .90147 .47639 .91268 .47307 .90834 .46691 Mtetra
.90834 .46691 .91268 .47307 .92392 .46974 .91962 .46355 Mtetra
.91962 .46355 .92392 .46974 .93521 .46639 .93095 .46018 Mtetra
.32399 .63404 .32977 .63908 .33894 .63636 .33318 .63129 Mtetra
.33318 .63129 .33894 .63636 .34814 .63362 .3424 .62854 Mtetra
.3424 .62854 .34814 .63362 .35737 .63087 .35165 .62577 Mtetra
.35165 .62577 .35737 .63087 .36664 .62811 .36094 .623 Mtetra
.36094 .623 .36664 .62811 .37593 .62535 .37025 .62021 Mtetra
.37025 .62021 .37593 .62535 .38526 .62257 .3796 .61742 Mtetra
.3796 .61742 .38526 .62257 .39462 .61979 .38898 .61462 Mtetra
.38898 .61462 .39462 .61979 .40402 .61699 .3984 .6118 Mtetra
.3984 .6118 .40402 .61699 .41344 .61418 .40784 .60898 Mtetra
.40784 .60898 .41344 .61418 .4229 .61137 .41732 .60615 Mtetra
.41732 .60615 .4229 .61137 .43239 .60854 .42684 .6033 Mtetra
.42684 .6033 .43239 .60854 .44192 .60571 .43639 .60045 Mtetra
.43639 .60045 .44192 .60571 .45148 .60286 .44597 .59759 Mtetra
.44597 .59759 .45148 .60286 .46108 .60001 .45558 .59471 Mtetra
.45558 .59471 .46108 .60001 .4707 .59714 .46523 .59183 Mtetra
.46523 .59183 .4707 .59714 .48037 .59427 .47492 .58893 Mtetra
.47492 .58893 .48037 .59427 .49006 .59138 .48463 .58603 Mtetra
.48463 .58603 .49006 .59138 .49979 .58849 .49439 .58311 Mtetra
.49439 .58311 .49979 .58849 .50956 .58558 .50418 .58019 Mtetra
.50418 .58019 .50956 .58558 .51936 .58267 .514 .57725 Mtetra
.514 .57725 .51936 .58267 .52919 .57974 .52386 .57431 Mtetra
.52386 .57431 .52919 .57974 .53907 .5768 .53375 .57135 Mtetra
.53375 .57135 .53907 .5768 .54897 .57385 .54368 .56838 Mtetra
.54368 .56838 .54897 .57385 .55891 .57089 .55365 .5654 Mtetra
.55365 .5654 .55891 .57089 .56889 .56792 .56365 .56241 Mtetra
.56365 .56241 .56889 .56792 .57891 .56494 .57369 .55941 Mtetra
.57369 .55941 .57891 .56494 .58896 .56195 .58376 .5564 Mtetra
.58376 .5564 .58896 .56195 .59904 .55895 .59387 .55338 Mtetra
.59387 .55338 .59904 .55895 .60917 .55594 .60402 .55035 Mtetra
.60402 .55035 .60917 .55594 .61933 .55292 .61421 .5473 Mtetra
.61421 .5473 .61933 .55292 .62952 .54988 .62443 .54425 Mtetra
.62443 .54425 .62952 .54988 .63976 .54684 .63469 .54118 Mtetra
.63469 .54118 .63976 .54684 .65003 .54378 .64498 .53811 Mtetra
.64498 .53811 .65003 .54378 .66034 .54071 .65532 .53502 Mtetra
.65532 .53502 .66034 .54071 .67069 .53763 .66569 .53192 Mtetra
.66569 .53192 .67069 .53763 .68107 .53454 .6761 .52881 Mtetra
.6761 .52881 .68107 .53454 .69149 .53144 .68655 .52568 Mtetra
.68655 .52568 .69149 .53144 .70196 .52833 .69704 .52255 Mtetra
.69704 .52255 .70196 .52833 .71246 .5252 .70757 .5194 Mtetra
.70757 .5194 .71246 .5252 .723 .52206 .71814 .51624 Mtetra
.71814 .51624 .723 .52206 .73358 .51892 .72874 .51307 Mtetra
.72874 .51307 .73358 .51892 .74419 .51576 .73939 .50989 Mtetra
.73939 .50989 .74419 .51576 .75485 .51258 .75008 .5067 Mtetra
.75008 .5067 .75485 .51258 .76555 .5094 .7608 .50349 Mtetra
.7608 .50349 .76555 .5094 .77629 .50621 .77157 .50027 Mtetra
.77157 .50027 .77629 .50621 .78707 .503 .78237 .49704 Mtetra
.78237 .49704 .78707 .503 .79788 .49978 .79322 .4938 Mtetra
.79322 .4938 .79788 .49978 .80874 .49655 .80411 .49055 Mtetra
.80411 .49055 .80874 .49655 .81964 .4933 .81504 .48728 Mtetra
.81504 .48728 .81964 .4933 .83058 .49005 .82601 .484 Mtetra
.82601 .484 .83058 .49005 .84157 .48678 .83702 .48071 Mtetra
.83702 .48071 .84157 .48678 .85259 .4835 .84808 .47741 Mtetra
.84808 .47741 .85259 .4835 .86366 .4802 .85917 .47409 Mtetra
.85917 .47409 .86366 .4802 .87477 .4769 .87031 .47076 Mtetra
.87031 .47076 .87477 .4769 .88592 .47358 .88149 .46742 Mtetra
.88149 .46742 .88592 .47358 .89711 .47025 .89272 .46407 Mtetra
.89272 .46407 .89711 .47025 .90834 .46691 .90398 .4607 Mtetra
.90398 .4607 .90834 .46691 .91962 .46355 .91529 .45732 Mtetra
.91529 .45732 .91962 .46355 .93095 .46018 .92665 .45393 Mtetra
.31818 .62896 .32399 .63404 .33318 .63129 .32738 .6262 Mtetra
.32738 .6262 .33318 .63129 .3424 .62854 .33662 .62343 Mtetra
.33662 .62343 .3424 .62854 .35165 .62577 .34589 .62064 Mtetra
.34589 .62064 .35165 .62577 .36094 .623 .3552 .61785 Mtetra
.3552 .61785 .36094 .623 .37025 .62021 .36453 .61505 Mtetra
.36453 .61505 .37025 .62021 .3796 .61742 .3739 .61224 Mtetra
.3739 .61224 .3796 .61742 .38898 .61462 .3833 .60942 Mtetra
.3833 .60942 .38898 .61462 .3984 .6118 .39274 .60658 Mtetra
.39274 .60658 .3984 .6118 .40784 .60898 .40221 .60374 Mtetra
.40221 .60374 .40784 .60898 .41732 .60615 .41171 .60089 Mtetra
.41171 .60089 .41732 .60615 .42684 .6033 .42124 .59803 Mtetra
.42124 .59803 .42684 .6033 .43639 .60045 .43081 .59516 Mtetra
.43081 .59516 .43639 .60045 .44597 .59759 .44042 .59227 Mtetra
.44042 .59227 .44597 .59759 .45558 .59471 .45005 .58938 Mtetra
.45005 .58938 .45558 .59471 .46523 .59183 .45972 .58648 Mtetra
.45972 .58648 .46523 .59183 .47492 .58893 .46943 .58356 Mtetra
.46943 .58356 .47492 .58893 .48463 .58603 .47917 .58064 Mtetra
.47917 .58064 .48463 .58603 .49439 .58311 .48895 .57771 Mtetra
.48895 .57771 .49439 .58311 .50418 .58019 .49876 .57476 Mtetra
.49876 .57476 .50418 .58019 .514 .57725 .5086 .57181 Mtetra
.5086 .57181 .514 .57725 .52386 .57431 .51849 .56884 Mtetra
.51849 .56884 .52386 .57431 .53375 .57135 .5284 .56586 Mtetra
.5284 .56586 .53375 .57135 .54368 .56838 .53836 .56288 Mtetra
.53836 .56288 .54368 .56838 .55365 .5654 .54835 .55988 Mtetra
.54835 .55988 .55365 .5654 .56365 .56241 .55837 .55687 Mtetra
.55837 .55687 .56365 .56241 .57369 .55941 .56843 .55385 Mtetra
.56843 .55385 .57369 .55941 .58376 .5564 .57853 .55082 Mtetra
.57853 .55082 .58376 .5564 .59387 .55338 .58867 .54777 Mtetra
.58867 .54777 .59387 .55338 .60402 .55035 .59884 .54472 Mtetra
.59884 .54472 .60402 .55035 .61421 .5473 .60905 .54166 Mtetra
.60905 .54166 .61421 .5473 .62443 .54425 .6193 .53858 Mtetra
.6193 .53858 .62443 .54425 .63469 .54118 .62958 .53549 Mtetra
.62958 .53549 .63469 .54118 .64498 .53811 .63991 .53239 Mtetra
.63991 .53239 .64498 .53811 .65532 .53502 .65027 .52928 Mtetra
.65027 .52928 .65532 .53502 .66569 .53192 .66067 .52616 Mtetra
.66067 .52616 .66569 .53192 .6761 .52881 .6711 .52303 Mtetra
.6711 .52303 .6761 .52881 .68655 .52568 .68158 .51989 Mtetra
.68158 .51989 .68655 .52568 .69704 .52255 .6921 .51673 Mtetra
.6921 .51673 .69704 .52255 .70757 .5194 .70265 .51356 Mtetra
.70265 .51356 .70757 .5194 .71814 .51624 .71324 .51038 Mtetra
.71324 .51038 .71814 .51624 .72874 .51307 .72388 .50719 Mtetra
.72388 .50719 .72874 .51307 .73939 .50989 .73455 .50399 Mtetra
.73455 .50399 .73939 .50989 .75008 .5067 .74527 .50077 Mtetra
.74527 .50077 .75008 .5067 .7608 .50349 .75602 .49754 Mtetra
.75602 .49754 .7608 .50349 .77157 .50027 .76681 .4943 Mtetra
.76681 .4943 .77157 .50027 .78237 .49704 .77765 .49105 Mtetra
.77765 .49105 .78237 .49704 .79322 .4938 .78852 .48779 Mtetra
.78852 .48779 .79322 .4938 .80411 .49055 .79944 .48451 Mtetra
.79944 .48451 .80411 .49055 .81504 .48728 .8104 .48122 Mtetra
.8104 .48122 .81504 .48728 .82601 .484 .8214 .47792 Mtetra
.8214 .47792 .82601 .484 .83702 .48071 .83244 .4746 Mtetra
.83244 .4746 .83702 .48071 .84808 .47741 .84353 .47128 Mtetra
.84353 .47128 .84808 .47741 .85917 .47409 .85465 .46794 Mtetra
.85465 .46794 .85917 .47409 .87031 .47076 .86582 .46458 Mtetra
.86582 .46458 .87031 .47076 .88149 .46742 .87704 .46122 Mtetra
.87704 .46122 .88149 .46742 .89272 .46407 .88829 .45784 Mtetra
.88829 .45784 .89272 .46407 .90398 .4607 .89959 .45445 Mtetra
.89959 .45445 .90398 .4607 .91529 .45732 .91093 .45104 Mtetra
.91093 .45104 .91529 .45732 .92665 .45393 .92232 .44763 Mtetra
.31232 .62385 .31818 .62896 .32738 .6262 .32155 .62107 Mtetra
.32155 .62107 .32738 .6262 .33662 .62343 .33081 .61828 Mtetra
.33081 .61828 .33662 .62343 .34589 .62064 .3401 .61548 Mtetra
.3401 .61548 .34589 .62064 .3552 .61785 .34942 .61267 Mtetra
.34942 .61267 .3552 .61785 .36453 .61505 .35878 .60985 Mtetra
.35878 .60985 .36453 .61505 .3739 .61224 .36817 .60702 Mtetra
.36817 .60702 .3739 .61224 .3833 .60942 .37759 .60418 Mtetra
.37759 .60418 .3833 .60942 .39274 .60658 .38704 .60133 Mtetra
.38704 .60133 .39274 .60658 .40221 .60374 .39653 .59847 Mtetra
.39653 .59847 .40221 .60374 .41171 .60089 .40606 .5956 Mtetra
.40606 .5956 .41171 .60089 .42124 .59803 .41561 .59272 Mtetra
.41561 .59272 .42124 .59803 .43081 .59516 .4252 .58983 Mtetra
.4252 .58983 .43081 .59516 .44042 .59227 .43483 .58692 Mtetra
.43483 .58692 .44042 .59227 .45005 .58938 .44449 .58401 Mtetra
.44449 .58401 .45005 .58938 .45972 .58648 .45418 .58109 Mtetra
.45418 .58109 .45972 .58648 .46943 .58356 .46391 .57816 Mtetra
.46391 .57816 .46943 .58356 .47917 .58064 .47367 .57521 Mtetra
.47367 .57521 .47917 .58064 .48895 .57771 .48347 .57226 Mtetra
.48347 .57226 .48895 .57771 .49876 .57476 .4933 .5693 Mtetra
.4933 .5693 .49876 .57476 .5086 .57181 .50317 .56632 Mtetra
.50317 .56632 .5086 .57181 .51849 .56884 .51308 .56334 Mtetra
.51308 .56334 .51849 .56884 .5284 .56586 .52302 .56034 Mtetra
.52302 .56034 .5284 .56586 .53836 .56288 .533 .55733 Mtetra
.533 .55733 .53836 .56288 .54835 .55988 .54301 .55431 Mtetra
.54301 .55431 .54835 .55988 .55837 .55687 .55306 .55128 Mtetra
.55306 .55128 .55837 .55687 .56843 .55385 .56314 .54824 Mtetra
.56314 .54824 .56843 .55385 .57853 .55082 .57327 .54519 Mtetra
.57327 .54519 .57853 .55082 .58867 .54777 .58343 .54213 Mtetra
.58343 .54213 .58867 .54777 .59884 .54472 .59363 .53905 Mtetra
.59363 .53905 .59884 .54472 .60905 .54166 .60386 .53597 Mtetra
.60386 .53597 .60905 .54166 .6193 .53858 .61413 .53287 Mtetra
.61413 .53287 .6193 .53858 .62958 .53549 .62444 .52976 Mtetra
.62444 .52976 .62958 .53549 .63991 .53239 .63479 .52664 Mtetra
.63479 .52664 .63991 .53239 .65027 .52928 .64518 .52351 Mtetra
.64518 .52351 .65027 .52928 .66067 .52616 .6556 .52037 Mtetra
.6556 .52037 .66067 .52616 .6711 .52303 .66607 .51722 Mtetra
.66607 .51722 .6711 .52303 .68158 .51989 .67657 .51405 Mtetra
.67657 .51405 .68158 .51989 .6921 .51673 .68711 .51087 Mtetra
.68711 .51087 .6921 .51673 .70265 .51356 .6977 .50768 Mtetra
.6977 .50768 .70265 .51356 .71324 .51038 .70832 .50448 Mtetra
.70832 .50448 .71324 .51038 .72388 .50719 .71898 .50127 Mtetra
.71898 .50127 .72388 .50719 .73455 .50399 .72968 .49804 Mtetra
.72968 .49804 .73455 .50399 .74527 .50077 .74042 .4948 Mtetra
.74042 .4948 .74527 .50077 .75602 .49754 .7512 .49155 Mtetra
.7512 .49155 .75602 .49754 .76681 .4943 .76203 .48829 Mtetra
.76203 .48829 .76681 .4943 .77765 .49105 .77289 .48501 Mtetra
.77289 .48501 .77765 .49105 .78852 .48779 .7838 .48173 Mtetra
.7838 .48173 .78852 .48779 .79944 .48451 .79474 .47843 Mtetra
.79474 .47843 .79944 .48451 .8104 .48122 .80573 .47511 Mtetra
.80573 .47511 .8104 .48122 .8214 .47792 .81676 .47179 Mtetra
.81676 .47179 .8214 .47792 .83244 .4746 .82783 .46845 Mtetra
.82783 .46845 .83244 .4746 .84353 .47128 .83895 .4651 Mtetra
.83895 .4651 .84353 .47128 .85465 .46794 .85011 .46174 Mtetra
.85011 .46174 .85465 .46794 .86582 .46458 .86131 .45836 Mtetra
.86131 .45836 .86582 .46458 .87704 .46122 .87255 .45497 Mtetra
.87255 .45497 .87704 .46122 .88829 .45784 .88384 .45157 Mtetra
.88384 .45157 .88829 .45784 .89959 .45445 .89517 .44815 Mtetra
.89517 .44815 .89959 .45445 .91093 .45104 .90654 .44472 Mtetra
.90654 .44472 .91093 .45104 .92232 .44763 .91796 .44128 Mtetra
.30643 .61871 .31232 .62385 .32155 .62107 .31568 .61591 Mtetra
.31568 .61591 .32155 .62107 .33081 .61828 .32495 .6131 Mtetra
.32495 .6131 .33081 .61828 .3401 .61548 .33427 .61028 Mtetra
.33427 .61028 .3401 .61548 .34942 .61267 .34361 .60746 Mtetra
.34361 .60746 .34942 .61267 .35878 .60985 .35299 .60462 Mtetra
.35299 .60462 .35878 .60985 .36817 .60702 .36239 .60177 Mtetra
.36239 .60177 .36817 .60702 .37759 .60418 .37184 .59891 Mtetra
.37184 .59891 .37759 .60418 .38704 .60133 .38131 .59604 Mtetra
.38131 .59604 .38704 .60133 .39653 .59847 .39082 .59316 Mtetra
.39082 .59316 .39653 .59847 .40606 .5956 .40037 .59027 Mtetra
.40037 .59027 .40606 .5956 .41561 .59272 .40995 .58737 Mtetra
.40995 .58737 .41561 .59272 .4252 .58983 .41956 .58446 Mtetra
.41956 .58446 .4252 .58983 .43483 .58692 .4292 .58154 Mtetra
.4292 .58154 .43483 .58692 .44449 .58401 .43888 .57861 Mtetra
.43888 .57861 .44449 .58401 .45418 .58109 .4486 .57567 Mtetra
.4486 .57567 .45418 .58109 .46391 .57816 .45835 .57272 Mtetra
.45835 .57272 .46391 .57816 .47367 .57521 .46814 .56975 Mtetra
.46814 .56975 .47367 .57521 .48347 .57226 .47796 .56678 Mtetra
.47796 .56678 .48347 .57226 .4933 .5693 .48781 .5638 Mtetra
.48781 .5638 .4933 .5693 .50317 .56632 .49771 .5608 Mtetra
.49771 .5608 .50317 .56632 .51308 .56334 .50763 .55779 Mtetra
.50763 .55779 .51308 .56334 .52302 .56034 .5176 .55478 Mtetra
.5176 .55478 .52302 .56034 .533 .55733 .5276 .55175 Mtetra
.5276 .55175 .533 .55733 .54301 .55431 .53764 .54871 Mtetra
.53764 .54871 .54301 .55431 .55306 .55128 .54771 .54566 Mtetra
.54771 .54566 .55306 .55128 .56314 .54824 .55782 .5426 Mtetra
.55782 .5426 .56314 .54824 .57327 .54519 .56797 .53953 Mtetra
.56797 .53953 .57327 .54519 .58343 .54213 .57815 .53644 Mtetra
.57815 .53644 .58343 .54213 .59363 .53905 .58837 .53335 Mtetra
.58837 .53335 .59363 .53905 .60386 .53597 .59864 .53024 Mtetra
.59864 .53024 .60386 .53597 .61413 .53287 .60893 .52712 Mtetra
.60893 .52712 .61413 .53287 .62444 .52976 .61927 .524 Mtetra
.61927 .524 .62444 .52976 .63479 .52664 .62964 .52085 Mtetra
.62964 .52085 .63479 .52664 .64518 .52351 .64006 .5177 Mtetra
.64006 .5177 .64518 .52351 .6556 .52037 .65051 .51454 Mtetra
.65051 .51454 .6556 .52037 .66607 .51722 .661 .51136 Mtetra
.661 .51136 .66607 .51722 .67657 .51405 .67153 .50817 Mtetra
.67153 .50817 .67657 .51405 .68711 .51087 .6821 .50497 Mtetra
.6821 .50497 .68711 .51087 .6977 .50768 .69271 .50176 Mtetra
.69271 .50176 .6977 .50768 .70832 .50448 .70336 .49854 Mtetra
.70336 .49854 .70832 .50448 .71898 .50127 .71405 .4953 Mtetra
.71405 .4953 .71898 .50127 .72968 .49804 .72477 .49205 Mtetra
.72477 .49205 .72968 .49804 .74042 .4948 .73554 .48879 Mtetra
.73554 .48879 .74042 .4948 .7512 .49155 .74636 .48552 Mtetra
.74636 .48552 .7512 .49155 .76203 .48829 .75721 .48223 Mtetra
.75721 .48223 .76203 .48829 .77289 .48501 .7681 .47893 Mtetra
.7681 .47893 .77289 .48501 .7838 .48173 .77903 .47562 Mtetra
.77903 .47562 .7838 .48173 .79474 .47843 .79001 .4723 Mtetra
.79001 .4723 .79474 .47843 .80573 .47511 .80103 .46897 Mtetra
.80103 .46897 .80573 .47511 .81676 .47179 .81209 .46562 Mtetra
.81209 .46562 .81676 .47179 .82783 .46845 .82319 .46226 Mtetra
.82319 .46226 .82783 .46845 .83895 .4651 .83434 .45888 Mtetra
.83434 .45888 .83895 .4651 .85011 .46174 .84552 .45549 Mtetra
.84552 .45549 .85011 .46174 .86131 .45836 .85676 .45209 Mtetra
.85676 .45209 .86131 .45836 .87255 .45497 .86803 .44868 Mtetra
.86803 .44868 .87255 .45497 .88384 .45157 .87935 .44525 Mtetra
.87935 .44525 .88384 .45157 .89517 .44815 .89071 .44181 Mtetra
.89071 .44181 .89517 .44815 .90654 .44472 .90212 .43836 Mtetra
.90212 .43836 .90654 .44472 .91796 .44128 .91357 .43489 Mtetra
.3005 .61354 .30643 .61871 .31568 .61591 .30977 .61072 Mtetra
.30977 .61072 .31568 .61591 .32495 .6131 .31906 .60789 Mtetra
.31906 .60789 .32495 .6131 .33427 .61028 .32839 .60505 Mtetra
.32839 .60505 .33427 .61028 .34361 .60746 .33776 .60221 Mtetra
.33776 .60221 .34361 .60746 .35299 .60462 .34715 .59935 Mtetra
.34715 .59935 .35299 .60462 .36239 .60177 .35658 .59648 Mtetra
.35658 .59648 .36239 .60177 .37184 .59891 .36605 .5936 Mtetra
.36605 .5936 .37184 .59891 .38131 .59604 .37555 .59072 Mtetra
.37555 .59072 .38131 .59604 .39082 .59316 .38508 .58782 Mtetra
.38508 .58782 .39082 .59316 .40037 .59027 .39464 .58491 Mtetra
.39464 .58491 .40037 .59027 .40995 .58737 .40424 .58199 Mtetra
.40424 .58199 .40995 .58737 .41956 .58446 .41387 .57906 Mtetra
.41387 .57906 .41956 .58446 .4292 .58154 .42354 .57612 Mtetra
.42354 .57612 .4292 .58154 .43888 .57861 .43324 .57317 Mtetra
.43324 .57317 .43888 .57861 .4486 .57567 .44298 .57021 Mtetra
.44298 .57021 .4486 .57567 .45835 .57272 .45276 .56724 Mtetra
.45276 .56724 .45835 .57272 .46814 .56975 .46256 .56426 Mtetra
.46256 .56426 .46814 .56975 .47796 .56678 .47241 .56126 Mtetra
.47241 .56126 .47796 .56678 .48781 .5638 .48229 .55826 Mtetra
.48229 .55826 .48781 .5638 .49771 .5608 .4922 .55524 Mtetra
.4922 .55524 .49771 .5608 .50763 .55779 .50215 .55222 Mtetra
.50215 .55222 .50763 .55779 .5176 .55478 .51214 .54918 Mtetra
.51214 .54918 .5176 .55478 .5276 .55175 .52217 .54613 Mtetra
.52217 .54613 .5276 .55175 .53764 .54871 .53223 .54307 Mtetra
.53223 .54307 .53764 .54871 .54771 .54566 .54232 .54 Mtetra
.54232 .54 .54771 .54566 .55782 .5426 .55246 .53692 Mtetra
.55246 .53692 .55782 .5426 .56797 .53953 .56263 .53383 Mtetra
.56263 .53383 .56797 .53953 .57815 .53644 .57284 .53072 Mtetra
.57284 .53072 .57815 .53644 .58837 .53335 .58309 .52761 Mtetra
.58309 .52761 .58837 .53335 .59864 .53024 .59337 .52448 Mtetra
.59337 .52448 .59864 .53024 .60893 .52712 .6037 .52134 Mtetra
.6037 .52134 .60893 .52712 .61927 .524 .61406 .51819 Mtetra
.61406 .51819 .61927 .524 .62964 .52085 .62446 .51503 Mtetra
.62446 .51503 .62964 .52085 .64006 .5177 .6349 .51185 Mtetra
.6349 .51185 .64006 .5177 .65051 .51454 .64538 .50866 Mtetra
.64538 .50866 .65051 .51454 .661 .51136 .65589 .50547 Mtetra
.65589 .50547 .661 .51136 .67153 .50817 .66645 .50226 Mtetra
.66645 .50226 .67153 .50817 .6821 .50497 .67705 .49903 Mtetra
.67705 .49903 .6821 .50497 .69271 .50176 .68768 .4958 Mtetra
.68768 .4958 .69271 .50176 .70336 .49854 .69836 .49255 Mtetra
.69836 .49255 .70336 .49854 .71405 .4953 .70908 .48929 Mtetra
.70908 .48929 .71405 .4953 .72477 .49205 .71984 .48602 Mtetra
.71984 .48602 .72477 .49205 .73554 .48879 .73063 .48274 Mtetra
.73063 .48274 .73554 .48879 .74636 .48552 .74147 .47944 Mtetra
.74147 .47944 .74636 .48552 .75721 .48223 .75235 .47613 Mtetra
.75235 .47613 .75721 .48223 .7681 .47893 .76328 .47281 Mtetra
.76328 .47281 .7681 .47893 .77903 .47562 .77424 .46948 Mtetra
.77424 .46948 .77903 .47562 .79001 .4723 .78524 .46613 Mtetra
.78524 .46613 .79001 .4723 .80103 .46897 .79629 .46277 Mtetra
.79629 .46277 .80103 .46897 .81209 .46562 .80738 .4594 Mtetra
.80738 .4594 .81209 .46562 .82319 .46226 .81852 .45602 Mtetra
.81852 .45602 .82319 .46226 .83434 .45888 .82969 .45262 Mtetra
.82969 .45262 .83434 .45888 .84552 .45549 .84091 .44921 Mtetra
.84091 .44921 .84552 .45549 .85676 .45209 .85217 .44578 Mtetra
.85217 .44578 .85676 .45209 .86803 .44868 .86348 .44234 Mtetra
.86348 .44234 .86803 .44868 .87935 .44525 .87483 .43889 Mtetra
.87483 .43889 .87935 .44525 .89071 .44181 .88623 .43543 Mtetra
.88623 .43543 .89071 .44181 .90212 .43836 .89766 .43195 Mtetra
.89766 .43195 .90212 .43836 .91357 .43489 .90915 .42846 Mtetra
.29453 .60833 .3005 .61354 .30977 .61072 .30382 .60549 Mtetra
.30382 .60549 .30977 .61072 .31906 .60789 .31314 .60265 Mtetra
.31314 .60265 .31906 .60789 .32839 .60505 .32249 .59979 Mtetra
.32249 .59979 .32839 .60505 .33776 .60221 .33187 .59692 Mtetra
.33187 .59692 .33776 .60221 .34715 .59935 .34129 .59405 Mtetra
.34129 .59405 .34715 .59935 .35658 .59648 .35074 .59116 Mtetra
.35074 .59116 .35658 .59648 .36605 .5936 .36022 .58826 Mtetra
.36022 .58826 .36605 .5936 .37555 .59072 .36974 .58536 Mtetra
.36974 .58536 .37555 .59072 .38508 .58782 .37929 .58244 Mtetra
.37929 .58244 .38508 .58782 .39464 .58491 .38888 .57951 Mtetra
.38888 .57951 .39464 .58491 .40424 .58199 .3985 .57657 Mtetra
.3985 .57657 .40424 .58199 .41387 .57906 .40815 .57363 Mtetra
.40815 .57363 .41387 .57906 .42354 .57612 .41784 .57067 Mtetra
.41784 .57067 .42354 .57612 .43324 .57317 .42757 .5677 Mtetra
.42757 .5677 .43324 .57317 .44298 .57021 .43733 .56471 Mtetra
.43733 .56471 .44298 .57021 .45276 .56724 .44712 .56172 Mtetra
.44712 .56172 .45276 .56724 .46256 .56426 .45695 .55872 Mtetra
.45695 .55872 .46256 .56426 .47241 .56126 .46682 .55571 Mtetra
.46682 .55571 .47241 .56126 .48229 .55826 .47672 .55268 Mtetra
.47672 .55268 .48229 .55826 .4922 .55524 .48666 .54965 Mtetra
.48666 .54965 .4922 .55524 .50215 .55222 .49664 .5466 Mtetra
.49664 .5466 .50215 .55222 .51214 .54918 .50665 .54354 Mtetra
.50665 .54354 .51214 .54918 .52217 .54613 .5167 .54047 Mtetra
.5167 .54047 .52217 .54613 .53223 .54307 .52678 .53739 Mtetra
.52678 .53739 .53223 .54307 .54232 .54 .5369 .5343 Mtetra
.5369 .5343 .54232 .54 .55246 .53692 .54706 .5312 Mtetra
.54706 .5312 .55246 .53692 .56263 .53383 .55726 .52809 Mtetra
.55726 .52809 .56263 .53383 .57284 .53072 .56749 .52496 Mtetra
.56749 .52496 .57284 .53072 .58309 .52761 .57777 .52182 Mtetra
.57777 .52182 .58309 .52761 .59337 .52448 .58808 .51867 Mtetra
.58808 .51867 .59337 .52448 .6037 .52134 .59843 .51551 Mtetra
.59843 .51551 .6037 .52134 .61406 .51819 .60881 .51234 Mtetra
.60881 .51234 .61406 .51819 .62446 .51503 .61924 .50916 Mtetra
.61924 .50916 .62446 .51503 .6349 .51185 .62971 .50596 Mtetra
.62971 .50596 .6349 .51185 .64538 .50866 .64021 .50275 Mtetra
.64021 .50275 .64538 .50866 .65589 .50547 .65075 .49953 Mtetra
.65075 .49953 .65589 .50547 .66645 .50226 .66134 .4963 Mtetra
.66134 .4963 .66645 .50226 .67705 .49903 .67196 .49305 Mtetra
.67196 .49305 .67705 .49903 .68768 .4958 .68263 .4898 Mtetra
.68263 .4898 .68768 .4958 .69836 .49255 .69333 .48653 Mtetra
.69333 .48653 .69836 .49255 .70908 .48929 .70408 .48325 Mtetra
.70408 .48325 .70908 .48929 .71984 .48602 .71486 .47995 Mtetra
.71486 .47995 .71984 .48602 .73063 .48274 .72569 .47664 Mtetra
.72569 .47664 .73063 .48274 .74147 .47944 .73656 .47333 Mtetra
.73656 .47333 .74147 .47944 .75235 .47613 .74746 .46999 Mtetra
.74746 .46999 .75235 .47613 .76328 .47281 .75842 .46665 Mtetra
.75842 .46665 .76328 .47281 .77424 .46948 .76941 .46329 Mtetra
.76941 .46329 .77424 .46948 .78524 .46613 .78044 .45992 Mtetra
.78044 .45992 .78524 .46613 .79629 .46277 .79152 .45654 Mtetra
.79152 .45654 .79629 .46277 .80738 .4594 .80264 .45314 Mtetra
.80264 .45314 .80738 .4594 .81852 .45602 .81381 .44973 Mtetra
.81381 .44973 .81852 .45602 .82969 .45262 .82501 .44631 Mtetra
.82501 .44631 .82969 .45262 .84091 .44921 .83626 .44287 Mtetra
.83626 .44287 .84091 .44921 .85217 .44578 .84756 .43942 Mtetra
.84756 .43942 .85217 .44578 .86348 .44234 .8589 .43596 Mtetra
.8589 .43596 .86348 .44234 .87483 .43889 .87028 .43248 Mtetra
.87028 .43248 .87483 .43889 .88623 .43543 .88171 .42899 Mtetra
.88171 .42899 .88623 .43543 .89766 .43195 .89318 .42549 Mtetra
.89318 .42549 .89766 .43195 .90915 .42846 .90469 .42197 Mtetra
.28853 .60308 .29453 .60833 .30382 .60549 .29783 .60023 Mtetra
.29783 .60023 .30382 .60549 .31314 .60265 .30717 .59737 Mtetra
.30717 .59737 .31314 .60265 .32249 .59979 .31654 .59449 Mtetra
.31654 .59449 .32249 .59979 .33187 .59692 .32594 .59161 Mtetra
.32594 .59161 .33187 .59692 .34129 .59405 .33538 .58871 Mtetra
.33538 .58871 .34129 .59405 .35074 .59116 .34485 .58581 Mtetra
.34485 .58581 .35074 .59116 .36022 .58826 .35435 .58289 Mtetra
.35435 .58289 .36022 .58826 .36974 .58536 .36389 .57996 Mtetra
.36389 .57996 .36974 .58536 .37929 .58244 .37347 .57703 Mtetra
.37347 .57703 .37929 .58244 .38888 .57951 .38307 .57408 Mtetra
.38307 .57408 .38888 .57951 .3985 .57657 .39272 .57112 Mtetra
.39272 .57112 .3985 .57657 .40815 .57363 .40239 .56815 Mtetra
.40239 .56815 .40815 .57363 .41784 .57067 .41211 .56517 Mtetra
.41211 .56517 .41784 .57067 .42757 .5677 .42185 .56218 Mtetra
.42185 .56218 .42757 .5677 .43733 .56471 .43163 .55918 Mtetra
.43163 .55918 .43733 .56471 .44712 .56172 .44145 .55617 Mtetra
.44145 .55617 .44712 .56172 .45695 .55872 .45131 .55315 Mtetra
.45131 .55315 .45695 .55872 .46682 .55571 .4612 .55012 Mtetra
.4612 .55012 .46682 .55571 .47672 .55268 .47112 .54707 Mtetra
.47112 .54707 .47672 .55268 .48666 .54965 .48108 .54401 Mtetra
.48108 .54401 .48666 .54965 .49664 .5466 .49108 .54095 Mtetra
.49108 .54095 .49664 .5466 .50665 .54354 .50112 .53787 Mtetra
.50112 .53787 .50665 .54354 .5167 .54047 .51119 .53478 Mtetra
.51119 .53478 .5167 .54047 .52678 .53739 .5213 .53168 Mtetra
.5213 .53168 .52678 .53739 .5369 .5343 .53144 .52857 Mtetra
.53144 .52857 .5369 .5343 .54706 .5312 .54163 .52544 Mtetra
.54163 .52544 .54706 .5312 .55726 .52809 .55185 .52231 Mtetra
.55185 .52231 .55726 .52809 .56749 .52496 .56211 .51916 Mtetra
.56211 .51916 .56749 .52496 .57777 .52182 .57241 .516 Mtetra
.57241 .516 .57777 .52182 .58808 .51867 .58274 .51283 Mtetra
.58274 .51283 .58808 .51867 .59843 .51551 .59312 .50965 Mtetra
.59312 .50965 .59843 .51551 .60881 .51234 .60353 .50645 Mtetra
.60353 .50645 .60881 .51234 .61924 .50916 .61398 .50324 Mtetra
.61398 .50324 .61924 .50916 .62971 .50596 .62448 .50003 Mtetra
.62448 .50003 .62971 .50596 .64021 .50275 .63501 .4968 Mtetra
.63501 .4968 .64021 .50275 .65075 .49953 .64558 .49355 Mtetra
.64558 .49355 .65075 .49953 .66134 .4963 .65619 .4903 Mtetra
.65619 .4903 .66134 .4963 .67196 .49305 .66684 .48703 Mtetra
.66684 .48703 .67196 .49305 .68263 .4898 .67753 .48375 Mtetra
.67753 .48375 .68263 .4898 .69333 .48653 .68826 .48046 Mtetra
.68826 .48046 .69333 .48653 .70408 .48325 .69904 .47715 Mtetra
.69904 .47715 .70408 .48325 .71486 .47995 .70985 .47384 Mtetra
.70985 .47384 .71486 .47995 .72569 .47664 .72071 .47051 Mtetra
.72071 .47051 .72569 .47664 .73656 .47333 .7316 .46716 Mtetra
.7316 .46716 .73656 .47333 .74746 .46999 .74254 .46381 Mtetra
.74254 .46381 .74746 .46999 .75842 .46665 .75352 .46044 Mtetra
.75352 .46044 .75842 .46665 .76941 .46329 .76455 .45706 Mtetra
.76455 .45706 .76941 .46329 .78044 .45992 .77561 .45366 Mtetra
.77561 .45366 .78044 .45992 .79152 .45654 .78672 .45026 Mtetra
.78672 .45026 .79152 .45654 .80264 .45314 .79787 .44684 Mtetra
.79787 .44684 .80264 .45314 .81381 .44973 .80906 .4434 Mtetra
.80906 .4434 .81381 .44973 .82501 .44631 .8203 .43995 Mtetra
.8203 .43995 .82501 .44631 .83626 .44287 .83158 .43649 Mtetra
.83158 .43649 .83626 .44287 .84756 .43942 .84291 .43302 Mtetra
.84291 .43302 .84756 .43942 .8589 .43596 .85428 .42953 Mtetra
.85428 .42953 .8589 .43596 .87028 .43248 .86569 .42603 Mtetra
.86569 .42603 .87028 .43248 .88171 .42899 .87715 .42251 Mtetra
.87715 .42251 .88171 .42899 .89318 .42549 .88866 .41899 Mtetra
.88866 .41899 .89318 .42549 .90469 .42197 .90021 .41544 Mtetra
.28248 .59781 .28853 .60308 .29783 .60023 .2918 .59493 Mtetra
.2918 .59493 .29783 .60023 .30717 .59737 .30116 .59205 Mtetra
.30116 .59205 .30717 .59737 .31654 .59449 .31055 .58916 Mtetra
.31055 .58916 .31654 .59449 .32594 .59161 .31998 .58625 Mtetra
.31998 .58625 .32594 .59161 .33538 .58871 .32943 .58334 Mtetra
.32943 .58334 .33538 .58871 .34485 .58581 .33892 .58041 Mtetra
.33892 .58041 .34485 .58581 .35435 .58289 .34845 .57748 Mtetra
.34845 .57748 .35435 .58289 .36389 .57996 .35801 .57453 Mtetra
.35801 .57453 .36389 .57996 .37347 .57703 .3676 .57158 Mtetra
.3676 .57158 .37347 .57703 .38307 .57408 .37723 .56861 Mtetra
.37723 .56861 .38307 .57408 .39272 .57112 .3869 .56563 Mtetra
.3869 .56563 .39272 .57112 .40239 .56815 .3966 .56264 Mtetra
.3966 .56264 .40239 .56815 .41211 .56517 .40633 .55965 Mtetra
.40633 .55965 .41211 .56517 .42185 .56218 .4161 .55664 Mtetra
.4161 .55664 .42185 .56218 .43163 .55918 .4259 .55361 Mtetra
.4259 .55361 .43163 .55918 .44145 .55617 .43574 .55058 Mtetra
.43574 .55058 .44145 .55617 .45131 .55315 .44562 .54754 Mtetra
.44562 .54754 .45131 .55315 .4612 .55012 .45553 .54449 Mtetra
.45553 .54449 .4612 .55012 .47112 .54707 .46548 .54142 Mtetra
.46548 .54142 .47112 .54707 .48108 .54401 .47547 .53834 Mtetra
.47547 .53834 .48108 .54401 .49108 .54095 .48549 .53526 Mtetra
.48549 .53526 .49108 .54095 .50112 .53787 .49555 .53216 Mtetra
.49555 .53216 .50112 .53787 .51119 .53478 .50564 .52905 Mtetra
.50564 .52905 .51119 .53478 .5213 .53168 .51578 .52592 Mtetra
.51578 .52592 .5213 .53168 .53144 .52857 .52595 .52279 Mtetra
.52595 .52279 .53144 .52857 .54163 .52544 .53616 .51964 Mtetra
.53616 .51964 .54163 .52544 .55185 .52231 .5464 .51649 Mtetra
.5464 .51649 .55185 .52231 .56211 .51916 .55669 .51332 Mtetra
.55669 .51332 .56211 .51916 .57241 .516 .56701 .51014 Mtetra
.56701 .51014 .57241 .516 .58274 .51283 .57737 .50694 Mtetra
.57737 .50694 .58274 .51283 .59312 .50965 .58777 .50374 Mtetra
.58777 .50374 .59312 .50965 .60353 .50645 .59821 .50052 Mtetra
.59821 .50052 .60353 .50645 .61398 .50324 .60869 .49729 Mtetra
.60869 .49729 .61398 .50324 .62448 .50003 .61921 .49405 Mtetra
.61921 .49405 .62448 .50003 .63501 .4968 .62977 .4908 Mtetra
.62977 .4908 .63501 .4968 .64558 .49355 .64037 .48753 Mtetra
.64037 .48753 .64558 .49355 .65619 .4903 .65101 .48426 Mtetra
.65101 .48426 .65619 .4903 .66684 .48703 .66168 .48097 Mtetra
.66168 .48097 .66684 .48703 .67753 .48375 .6724 .47766 Mtetra
.6724 .47766 .67753 .48375 .68826 .48046 .68316 .47435 Mtetra
.68316 .47435 .68826 .48046 .69904 .47715 .69396 .47102 Mtetra
.69396 .47102 .69904 .47715 .70985 .47384 .70481 .46768 Mtetra
.70481 .46768 .70985 .47384 .72071 .47051 .71569 .46433 Mtetra
.71569 .46433 .72071 .47051 .7316 .46716 .72662 .46096 Mtetra
.72662 .46096 .7316 .46716 .74254 .46381 .73758 .45758 Mtetra
.73758 .45758 .74254 .46381 .75352 .46044 .74859 .45419 Mtetra
.74859 .45419 .75352 .46044 .76455 .45706 .75965 .45078 Mtetra
.75965 .45078 .76455 .45706 .77561 .45366 .77074 .44736 Mtetra
.77074 .44736 .77561 .45366 .78672 .45026 .78188 .44393 Mtetra
.78188 .44393 .78672 .45026 .79787 .44684 .79306 .44049 Mtetra
.79306 .44049 .79787 .44684 .80906 .4434 .80429 .43703 Mtetra
.80429 .43703 .80906 .4434 .8203 .43995 .81556 .43355 Mtetra
.81556 .43355 .8203 .43995 .83158 .43649 .82687 .43007 Mtetra
.82687 .43007 .83158 .43649 .84291 .43302 .83823 .42657 Mtetra
.83823 .42657 .84291 .43302 .85428 .42953 .84963 .42306 Mtetra
.84963 .42306 .85428 .42953 .86569 .42603 .86108 .41953 Mtetra
.86108 .41953 .86569 .42603 .87715 .42251 .87257 .41599 Mtetra
.87257 .41599 .87715 .42251 .88866 .41899 .8841 .41243 Mtetra
.8841 .41243 .88866 .41899 .90021 .41544 .89569 .40886 Mtetra
.27639 .59249 .28248 .59781 .2918 .59493 .28574 .5896 Mtetra
.28574 .5896 .2918 .59493 .30116 .59205 .29511 .5867 Mtetra
.29511 .5867 .30116 .59205 .31055 .58916 .30452 .58379 Mtetra
.30452 .58379 .31055 .58916 .31998 .58625 .31397 .58087 Mtetra
.31397 .58087 .31998 .58625 .32943 .58334 .32345 .57793 Mtetra
.32345 .57793 .32943 .58334 .33892 .58041 .33296 .57499 Mtetra
.33296 .57499 .33892 .58041 .34845 .57748 .34251 .57203 Mtetra
.34251 .57203 .34845 .57748 .35801 .57453 .35209 .56907 Mtetra
.35209 .56907 .35801 .57453 .3676 .57158 .3617 .56609 Mtetra
.3617 .56609 .3676 .57158 .37723 .56861 .37135 .56311 Mtetra
.37135 .56311 .37723 .56861 .3869 .56563 .38104 .56011 Mtetra
.38104 .56011 .3869 .56563 .3966 .56264 .39076 .5571 Mtetra
.39076 .5571 .3966 .56264 .40633 .55965 .40052 .55408 Mtetra
.40052 .55408 .40633 .55965 .4161 .55664 .41031 .55105 Mtetra
.41031 .55105 .4161 .55664 .4259 .55361 .42013 .54801 Mtetra
.42013 .54801 .4259 .55361 .43574 .55058 .43 .54496 Mtetra
.43 .54496 .43574 .55058 .44562 .54754 .4399 .54189 Mtetra
.4399 .54189 .44562 .54754 .45553 .54449 .44983 .53882 Mtetra
.44983 .53882 .45553 .54449 .46548 .54142 .4598 .53573 Mtetra
.4598 .53573 .46548 .54142 .47547 .53834 .46981 .53263 Mtetra
.46981 .53263 .47547 .53834 .48549 .53526 .47986 .52952 Mtetra
.47986 .52952 .48549 .53526 .49555 .53216 .48994 .5264 Mtetra
.48994 .5264 .49555 .53216 .50564 .52905 .50006 .52327 Mtetra
.50006 .52327 .50564 .52905 .51578 .52592 .51022 .52013 Mtetra
.51022 .52013 .51578 .52592 .52595 .52279 .52041 .51697 Mtetra
.52041 .51697 .52595 .52279 .53616 .51964 .53065 .51381 Mtetra
.53065 .51381 .53616 .51964 .5464 .51649 .54092 .51063 Mtetra
.54092 .51063 .5464 .51649 .55669 .51332 .55123 .50744 Mtetra
.55123 .50744 .55669 .51332 .56701 .51014 .56158 .50423 Mtetra
.56158 .50423 .56701 .51014 .57737 .50694 .57197 .50102 Mtetra
.57197 .50102 .57737 .50694 .58777 .50374 .58239 .49779 Mtetra
.58239 .49779 .58777 .50374 .59821 .50052 .59286 .49455 Mtetra
.59286 .49455 .59821 .50052 .60869 .49729 .60336 .4913 Mtetra
.60336 .4913 .60869 .49729 .61921 .49405 .61391 .48804 Mtetra
.61391 .48804 .61921 .49405 .62977 .4908 .62449 .48476 Mtetra
.62449 .48476 .62977 .4908 .64037 .48753 .63512 .48147 Mtetra
.63512 .48147 .64037 .48753 .65101 .48426 .64578 .47817 Mtetra
.64578 .47817 .65101 .48426 .66168 .48097 .65649 .47486 Mtetra
.65649 .47486 .66168 .48097 .6724 .47766 .66724 .47153 Mtetra
.66724 .47153 .6724 .47766 .68316 .47435 .67803 .46819 Mtetra
.67803 .46819 .68316 .47435 .69396 .47102 .68886 .46484 Mtetra
.68886 .46484 .69396 .47102 .70481 .46768 .69973 .46148 Mtetra
.69973 .46148 .70481 .46768 .71569 .46433 .71064 .4581 Mtetra
.71064 .4581 .71569 .46433 .72662 .46096 .72159 .45471 Mtetra
.72159 .45471 .72662 .46096 .73758 .45758 .73259 .45131 Mtetra
.73259 .45131 .73758 .45758 .74859 .45419 .74363 .44789 Mtetra
.74363 .44789 .74859 .45419 .75965 .45078 .75471 .44446 Mtetra
.75471 .44446 .75965 .45078 .77074 .44736 .76584 .44102 Mtetra
.76584 .44102 .77074 .44736 .78188 .44393 .77701 .43756 Mtetra
.77701 .43756 .78188 .44393 .79306 .44049 .78822 .43409 Mtetra
.78822 .43409 .79306 .44049 .80429 .43703 .79948 .43061 Mtetra
.79948 .43061 .80429 .43703 .81556 .43355 .81078 .42711 Mtetra
.81078 .42711 .81556 .43355 .82687 .43007 .82212 .4236 Mtetra
.82212 .4236 .82687 .43007 .83823 .42657 .83351 .42007 Mtetra
.83351 .42007 .83823 .42657 .84963 .42306 .84494 .41653 Mtetra
.84494 .41653 .84963 .42306 .86108 .41953 .85642 .41298 Mtetra
.85642 .41298 .86108 .41953 .87257 .41599 .86795 .40941 Mtetra
.86795 .40941 .87257 .41599 .8841 .41243 .87952 .40583 Mtetra
.87952 .40583 .8841 .41243 .89569 .40886 .89113 .40224 Mtetra
.27027 .58715 .27639 .59249 .28574 .5896 .27963 .58424 Mtetra
.27963 .58424 .28574 .5896 .29511 .5867 .28903 .58132 Mtetra
.28903 .58132 .29511 .5867 .30452 .58379 .29846 .57838 Mtetra
.29846 .57838 .30452 .58379 .31397 .58087 .30792 .57544 Mtetra
.30792 .57544 .31397 .58087 .32345 .57793 .31742 .57249 Mtetra
.31742 .57249 .32345 .57793 .33296 .57499 .32696 .56952 Mtetra
.32696 .56952 .33296 .57499 .34251 .57203 .33652 .56655 Mtetra
.33652 .56655 .34251 .57203 .35209 .56907 .34613 .56357 Mtetra
.34613 .56357 .35209 .56907 .3617 .56609 .35576 .56057 Mtetra
.35576 .56057 .3617 .56609 .37135 .56311 .36543 .55756 Mtetra
.36543 .55756 .37135 .56311 .38104 .56011 .37514 .55455 Mtetra
.37514 .55455 .38104 .56011 .39076 .5571 .38488 .55152 Mtetra
.38488 .55152 .39076 .5571 .40052 .55408 .39466 .54848 Mtetra
.39466 .54848 .40052 .55408 .41031 .55105 .40448 .54543 Mtetra
.40448 .54543 .41031 .55105 .42013 .54801 .41432 .54236 Mtetra
.41432 .54236 .42013 .54801 .43 .54496 .42421 .53929 Mtetra
.42421 .53929 .43 .54496 .4399 .54189 .43413 .53621 Mtetra
.43413 .53621 .4399 .54189 .44983 .53882 .44409 .53311 Mtetra
.44409 .53311 .44983 .53882 .4598 .53573 .45409 .53 Mtetra
.45409 .53 .4598 .53573 .46981 .53263 .46412 .52688 Mtetra
.46412 .52688 .46981 .53263 .47986 .52952 .47419 .52375 Mtetra
.47419 .52375 .47986 .52952 .48994 .5264 .4843 .52061 Mtetra
.4843 .52061 .48994 .5264 .50006 .52327 .49444 .51746 Mtetra
.49444 .51746 .50006 .52327 .51022 .52013 .50462 .51429 Mtetra
.50462 .51429 .51022 .52013 .52041 .51697 .51484 .51112 Mtetra
.51484 .51112 .52041 .51697 .53065 .51381 .5251 .50793 Mtetra
.5251 .50793 .53065 .51381 .54092 .51063 .5354 .50473 Mtetra
.5354 .50473 .54092 .51063 .55123 .50744 .54573 .50151 Mtetra
.54573 .50151 .55123 .50744 .56158 .50423 .55611 .49829 Mtetra
.55611 .49829 .56158 .50423 .57197 .50102 .56652 .49505 Mtetra
.56652 .49505 .57197 .50102 .58239 .49779 .57697 .4918 Mtetra
.57697 .4918 .58239 .49779 .59286 .49455 .58747 .48854 Mtetra
.58747 .48854 .59286 .49455 .60336 .4913 .598 .48527 Mtetra
.598 .48527 .60336 .4913 .61391 .48804 .60857 .48198 Mtetra
.60857 .48198 .61391 .48804 .62449 .48476 .61918 .47868 Mtetra
.61918 .47868 .62449 .48476 .63512 .48147 .62983 .47537 Mtetra
.62983 .47537 .63512 .48147 .64578 .47817 .64053 .47205 Mtetra
.64053 .47205 .64578 .47817 .65649 .47486 .65126 .46871 Mtetra
.65126 .46871 .65649 .47486 .66724 .47153 .66204 .46536 Mtetra
.66204 .46536 .66724 .47153 .67803 .46819 .67285 .462 Mtetra
.67285 .462 .67803 .46819 .68886 .46484 .68371 .45862 Mtetra
.68371 .45862 .68886 .46484 .69973 .46148 .69461 .45523 Mtetra
.69461 .45523 .69973 .46148 .71064 .4581 .70555 .45183 Mtetra
.70555 .45183 .71064 .4581 .72159 .45471 .71654 .44842 Mtetra
.71654 .44842 .72159 .45471 .73259 .45131 .72756 .44499 Mtetra
.72756 .44499 .73259 .45131 .74363 .44789 .73863 .44155 Mtetra
.73863 .44155 .74363 .44789 .75471 .44446 .74974 .43809 Mtetra
.74974 .43809 .75471 .44446 .76584 .44102 .7609 .43462 Mtetra
.7609 .43462 .76584 .44102 .77701 .43756 .7721 .43114 Mtetra
.7721 .43114 .77701 .43756 .78822 .43409 .78334 .42765 Mtetra
.78334 .42765 .78822 .43409 .79948 .43061 .79463 .42414 Mtetra
.79463 .42414 .79948 .43061 .81078 .42711 .80596 .42062 Mtetra
.80596 .42062 .81078 .42711 .82212 .4236 .81734 .41708 Mtetra
.81734 .41708 .82212 .4236 .83351 .42007 .82876 .41353 Mtetra
.82876 .41353 .83351 .42007 .84494 .41653 .84023 .40996 Mtetra
.84023 .40996 .84494 .41653 .85642 .41298 .85174 .40639 Mtetra
.85174 .40639 .85642 .41298 .86795 .40941 .8633 .40279 Mtetra
.8633 .40279 .86795 .40941 .87952 .40583 .8749 .39919 Mtetra
.8749 .39919 .87952 .40583 .89113 .40224 .88655 .39556 Mtetra
.2641 .58177 .27027 .58715 .27963 .58424 .27348 .57884 Mtetra
.27348 .57884 .27963 .58424 .28903 .58132 .2829 .57589 Mtetra
.2829 .57589 .28903 .58132 .29846 .57838 .29235 .57294 Mtetra
.29235 .57294 .29846 .57838 .30792 .57544 .30184 .56998 Mtetra
.30184 .56998 .30792 .57544 .31742 .57249 .31136 .56701 Mtetra
.31136 .56701 .31742 .57249 .32696 .56952 .32091 .56403 Mtetra
.32091 .56403 .32696 .56952 .33652 .56655 .3305 .56103 Mtetra
.3305 .56103 .33652 .56655 .34613 .56357 .34012 .55803 Mtetra
.34012 .55803 .34613 .56357 .35576 .56057 .34978 .55501 Mtetra
.34978 .55501 .35576 .56057 .36543 .55756 .35947 .55198 Mtetra
.35947 .55198 .36543 .55756 .37514 .55455 .3692 .54895 Mtetra
.3692 .54895 .37514 .55455 .38488 .55152 .37897 .5459 Mtetra
.37897 .5459 .38488 .55152 .39466 .54848 .38877 .54284 Mtetra
.38877 .54284 .39466 .54848 .40448 .54543 .3986 .53976 Mtetra
.3986 .53976 .40448 .54543 .41432 .54236 .40848 .53668 Mtetra
.40848 .53668 .41432 .54236 .42421 .53929 .41839 .53359 Mtetra
.41839 .53359 .42421 .53929 .43413 .53621 .42833 .53048 Mtetra
.42833 .53048 .43413 .53621 .44409 .53311 .43831 .52737 Mtetra
.43831 .52737 .44409 .53311 .45409 .53 .44833 .52424 Mtetra
.44833 .52424 .45409 .53 .46412 .52688 .45839 .5211 Mtetra
.45839 .5211 .46412 .52688 .47419 .52375 .46848 .51794 Mtetra
.46848 .51794 .47419 .52375 .4843 .52061 .47861 .51478 Mtetra
.47861 .51478 .4843 .52061 .49444 .51746 .48878 .51161 Mtetra
.48878 .51161 .49444 .51746 .50462 .51429 .49899 .50842 Mtetra
.49899 .50842 .50462 .51429 .51484 .51112 .50923 .50522 Mtetra
.50923 .50522 .51484 .51112 .5251 .50793 .51952 .50201 Mtetra
.51952 .50201 .5251 .50793 .5354 .50473 .52984 .49879 Mtetra
.52984 .49879 .5354 .50473 .54573 .50151 .5402 .49555 Mtetra
.5402 .49555 .54573 .50151 .55611 .49829 .5506 .4923 Mtetra
.5506 .4923 .55611 .49829 .56652 .49505 .56104 .48904 Mtetra
.56104 .48904 .56652 .49505 .57697 .4918 .57152 .48577 Mtetra
.57152 .48577 .57697 .4918 .58747 .48854 .58203 .48249 Mtetra
.58203 .48249 .58747 .48854 .598 .48527 .59259 .47919 Mtetra
.59259 .47919 .598 .48527 .60857 .48198 .60319 .47588 Mtetra
.60319 .47588 .60857 .48198 .61918 .47868 .61383 .47256 Mtetra
.61383 .47256 .61918 .47868 .62983 .47537 .62451 .46922 Mtetra
.62451 .46922 .62983 .47537 .64053 .47205 .63523 .46587 Mtetra
.63523 .46587 .64053 .47205 .65126 .46871 .64599 .46251 Mtetra
.64599 .46251 .65126 .46871 .66204 .46536 .6568 .45914 Mtetra
.6568 .45914 .66204 .46536 .67285 .462 .66764 .45575 Mtetra
.66764 .45575 .67285 .462 .68371 .45862 .67853 .45235 Mtetra
.67853 .45235 .68371 .45862 .69461 .45523 .68946 .44894 Mtetra
.68946 .44894 .69461 .45523 .70555 .45183 .70043 .44552 Mtetra
.70043 .44552 .70555 .45183 .71654 .44842 .71144 .44208 Mtetra
.71144 .44208 .71654 .44842 .72756 .44499 .7225 .43862 Mtetra
.7225 .43862 .72756 .44499 .73863 .44155 .7336 .43516 Mtetra
.7336 .43516 .73863 .44155 .74974 .43809 .74474 .43168 Mtetra
.74474 .43168 .74974 .43809 .7609 .43462 .75593 .42819 Mtetra
.75593 .42819 .7609 .43462 .7721 .43114 .76716 .42468 Mtetra
.76716 .42468 .7721 .43114 .78334 .42765 .77843 .42116 Mtetra
.77843 .42116 .78334 .42765 .79463 .42414 .78975 .41762 Mtetra
.78975 .41762 .79463 .42414 .80596 .42062 .80111 .41408 Mtetra
.80111 .41408 .80596 .42062 .81734 .41708 .81252 .41051 Mtetra
.81252 .41051 .81734 .41708 .82876 .41353 .82397 .40694 Mtetra
.82397 .40694 .82876 .41353 .84023 .40996 .83547 .40335 Mtetra
.83547 .40335 .84023 .40996 .85174 .40639 .84702 .39974 Mtetra
.84702 .39974 .85174 .40639 .8633 .40279 .85861 .39612 Mtetra
.85861 .39612 .8633 .40279 .8749 .39919 .87025 .39249 Mtetra
.87025 .39249 .8749 .39919 .88655 .39556 .88193 .38884 Mtetra
.25789 .57635 .2641 .58177 .27348 .57884 .2673 .5734 Mtetra
.2673 .5734 .27348 .57884 .2829 .57589 .27673 .57044 Mtetra
.27673 .57044 .2829 .57589 .29235 .57294 .2862 .56747 Mtetra
.2862 .56747 .29235 .57294 .30184 .56998 .29571 .56449 Mtetra
.29571 .56449 .30184 .56998 .31136 .56701 .30525 .56149 Mtetra
.30525 .56149 .31136 .56701 .32091 .56403 .31483 .55849 Mtetra
.31483 .55849 .32091 .56403 .3305 .56103 .32444 .55547 Mtetra
.32444 .55547 .3305 .56103 .34012 .55803 .33408 .55245 Mtetra
.33408 .55245 .34012 .55803 .34978 .55501 .34376 .54941 Mtetra
.34376 .54941 .34978 .55501 .35947 .55198 .35348 .54637 Mtetra
.35348 .54637 .35947 .55198 .3692 .54895 .36323 .54331 Mtetra
.36323 .54331 .3692 .54895 .37897 .5459 .37301 .54024 Mtetra
.37301 .54024 .37897 .5459 .38877 .54284 .38284 .53716 Mtetra
.38284 .53716 .38877 .54284 .3986 .53976 .39269 .53406 Mtetra
.39269 .53406 .3986 .53976 .40848 .53668 .40259 .53096 Mtetra
.40259 .53096 .40848 .53668 .41839 .53359 .41252 .52785 Mtetra
.41252 .52785 .41839 .53359 .42833 .53048 .42249 .52472 Mtetra
.42249 .52472 .42833 .53048 .43831 .52737 .43249 .52158 Mtetra
.43249 .52158 .43831 .52737 .44833 .52424 .44254 .51843 Mtetra
.44254 .51843 .44833 .52424 .45839 .5211 .45262 .51527 Mtetra
.45262 .51527 .45839 .5211 .46848 .51794 .46273 .5121 Mtetra
.46273 .5121 .46848 .51794 .47861 .51478 .47289 .50891 Mtetra
.47289 .50891 .47861 .51478 .48878 .51161 .48308 .50571 Mtetra
.48308 .50571 .48878 .51161 .49899 .50842 .49331 .5025 Mtetra
.49331 .5025 .49899 .50842 .50923 .50522 .50358 .49928 Mtetra
.50358 .49928 .50923 .50522 .51952 .50201 .51389 .49605 Mtetra
.51389 .49605 .51952 .50201 .52984 .49879 .52424 .4928 Mtetra
.52424 .4928 .52984 .49879 .5402 .49555 .53463 .48955 Mtetra
.53463 .48955 .5402 .49555 .5506 .4923 .54505 .48627 Mtetra
.54505 .48627 .5506 .4923 .56104 .48904 .55552 .48299 Mtetra
.55552 .48299 .56104 .48904 .57152 .48577 .56602 .4797 Mtetra
.56602 .4797 .57152 .48577 .58203 .48249 .57657 .47639 Mtetra
.57657 .47639 .58203 .48249 .59259 .47919 .58715 .47307 Mtetra
.58715 .47307 .59259 .47919 .60319 .47588 .59778 .46974 Mtetra
.59778 .46974 .60319 .47588 .61383 .47256 .60844 .46639 Mtetra
.60844 .46639 .61383 .47256 .62451 .46922 .61915 .46303 Mtetra
.61915 .46303 .62451 .46922 .63523 .46587 .6299 .45966 Mtetra
.6299 .45966 .63523 .46587 .64599 .46251 .64069 .45628 Mtetra
.64069 .45628 .64599 .46251 .6568 .45914 .65152 .45288 Mtetra
.65152 .45288 .6568 .45914 .66764 .45575 .66239 .44947 Mtetra
.66239 .44947 .66764 .45575 .67853 .45235 .67331 .44604 Mtetra
.67331 .44604 .67853 .45235 .68946 .44894 .68427 .44261 Mtetra
.68427 .44261 .68946 .44894 .70043 .44552 .69527 .43916 Mtetra
.69527 .43916 .70043 .44552 .71144 .44208 .70631 .43569 Mtetra
.70631 .43569 .71144 .44208 .7225 .43862 .7174 .43222 Mtetra
.7174 .43222 .7225 .43862 .7336 .43516 .72853 .42872 Mtetra
.72853 .42872 .7336 .43516 .74474 .43168 .7397 .42522 Mtetra
.7397 .42522 .74474 .43168 .75593 .42819 .75092 .4217 Mtetra
.75092 .4217 .75593 .42819 .76716 .42468 .76218 .41817 Mtetra
.76218 .41817 .76716 .42468 .77843 .42116 .77348 .41462 Mtetra
.77348 .41462 .77843 .42116 .78975 .41762 .78483 .41106 Mtetra
.78483 .41106 .78975 .41762 .80111 .41408 .79623 .40749 Mtetra
.79623 .40749 .80111 .41408 .81252 .41051 .80767 .4039 Mtetra
.80767 .4039 .81252 .41051 .82397 .40694 .81915 .4003 Mtetra
.81915 .4003 .82397 .40694 .83547 .40335 .83069 .39668 Mtetra
.83069 .39668 .83547 .40335 .84702 .39974 .84226 .39305 Mtetra
.84226 .39305 .84702 .39974 .85861 .39612 .85389 .3894 Mtetra
.85389 .3894 .85861 .39612 .87025 .39249 .86556 .38574 Mtetra
.86556 .38574 .87025 .39249 .88193 .38884 .87727 .38207 Mtetra
.25164 .57089 .25789 .57635 .2673 .5734 .26107 .56792 Mtetra
.26107 .56792 .2673 .5734 .27673 .57044 .27052 .56494 Mtetra
.27052 .56494 .27673 .57044 .2862 .56747 .28002 .56195 Mtetra
.28002 .56195 .2862 .56747 .29571 .56449 .28954 .55895 Mtetra
.28954 .55895 .29571 .56449 .30525 .56149 .2991 .55594 Mtetra
.2991 .55594 .30525 .56149 .31483 .55849 .3087 .55292 Mtetra
.3087 .55292 .31483 .55849 .32444 .55547 .31833 .54988 Mtetra
.31833 .54988 .32444 .55547 .33408 .55245 .328 .54684 Mtetra
.328 .54684 .33408 .55245 .34376 .54941 .3377 .54378 Mtetra
.3377 .54378 .34376 .54941 .35348 .54637 .34744 .54071 Mtetra
.34744 .54071 .35348 .54637 .36323 .54331 .35721 .53763 Mtetra
.35721 .53763 .36323 .54331 .37301 .54024 .36702 .53454 Mtetra
.36702 .53454 .37301 .54024 .38284 .53716 .37686 .53144 Mtetra
.37686 .53144 .38284 .53716 .39269 .53406 .38674 .52833 Mtetra
.38674 .52833 .39269 .53406 .40259 .53096 .39666 .5252 Mtetra
.39666 .5252 .40259 .53096 .41252 .52785 .40662 .52206 Mtetra
.40662 .52206 .41252 .52785 .42249 .52472 .41661 .51892 Mtetra
.41661 .51892 .42249 .52472 .43249 .52158 .42664 .51576 Mtetra
.42664 .51576 .43249 .52158 .44254 .51843 .4367 .51258 Mtetra
.4367 .51258 .44254 .51843 .45262 .51527 .44681 .5094 Mtetra
.44681 .5094 .45262 .51527 .46273 .5121 .45695 .50621 Mtetra
.45695 .50621 .46273 .5121 .47289 .50891 .46713 .503 Mtetra
.46713 .503 .47289 .50891 .48308 .50571 .47734 .49978 Mtetra
.47734 .49978 .48308 .50571 .49331 .5025 .4876 .49655 Mtetra
.4876 .49655 .49331 .5025 .50358 .49928 .49789 .4933 Mtetra
.49789 .4933 .50358 .49928 .51389 .49605 .50823 .49005 Mtetra
.50823 .49005 .51389 .49605 .52424 .4928 .5186 .48678 Mtetra
.5186 .48678 .52424 .4928 .53463 .48955 .52901 .4835 Mtetra
.52901 .4835 .53463 .48955 .54505 .48627 .53946 .4802 Mtetra
.53946 .4802 .54505 .48627 .55552 .48299 .54996 .4769 Mtetra
.54996 .4769 .55552 .48299 .56602 .4797 .56049 .47358 Mtetra
.56049 .47358 .56602 .4797 .57657 .47639 .57106 .47025 Mtetra
.57106 .47025 .57657 .47639 .58715 .47307 .58167 .46691 Mtetra
.58167 .46691 .58715 .47307 .59778 .46974 .59232 .46355 Mtetra
.59232 .46355 .59778 .46974 .60844 .46639 .60302 .46018 Mtetra
.60302 .46018 .60844 .46639 .61915 .46303 .61375 .4568 Mtetra
.61375 .4568 .61915 .46303 .6299 .45966 .62453 .4534 Mtetra
.62453 .4534 .6299 .45966 .64069 .45628 .63535 .44999 Mtetra
.63535 .44999 .64069 .45628 .65152 .45288 .64621 .44657 Mtetra
.64621 .44657 .65152 .45288 .66239 .44947 .65711 .44314 Mtetra
.65711 .44314 .66239 .44947 .67331 .44604 .66805 .43969 Mtetra
.66805 .43969 .67331 .44604 .68427 .44261 .67904 .43623 Mtetra
.67904 .43623 .68427 .44261 .69527 .43916 .69007 .43275 Mtetra
.69007 .43275 .69527 .43916 .70631 .43569 .70114 .42926 Mtetra
.70114 .42926 .70631 .43569 .7174 .43222 .71226 .42576 Mtetra
.71226 .42576 .7174 .43222 .72853 .42872 .72342 .42224 Mtetra
.72342 .42224 .72853 .42872 .7397 .42522 .73462 .41871 Mtetra
.73462 .41871 .7397 .42522 .75092 .4217 .74587 .41517 Mtetra
.74587 .41517 .75092 .4217 .76218 .41817 .75716 .41161 Mtetra
.75716 .41161 .76218 .41817 .77348 .41462 .7685 .40804 Mtetra
.7685 .40804 .77348 .41462 .78483 .41106 .77988 .40445 Mtetra
.77988 .40445 .78483 .41106 .79623 .40749 .79131 .40085 Mtetra
.79131 .40085 .79623 .40749 .80767 .4039 .80278 .39724 Mtetra
.80278 .39724 .80767 .4039 .81915 .4003 .8143 .39361 Mtetra
.8143 .39361 .81915 .4003 .83069 .39668 .82586 .38996 Mtetra
.82586 .38996 .83069 .39668 .84226 .39305 .83747 .38631 Mtetra
.83747 .38631 .84226 .39305 .85389 .3894 .84913 .38263 Mtetra
.84913 .38263 .85389 .3894 .86556 .38574 .86083 .37895 Mtetra
.86083 .37895 .86556 .38574 .87727 .38207 .87259 .37524 Mtetra
.24535 .5654 .25164 .57089 .26107 .56792 .2548 .56241 Mtetra
.2548 .56241 .26107 .56792 .27052 .56494 .26427 .55941 Mtetra
.26427 .55941 .27052 .56494 .28002 .56195 .27379 .5564 Mtetra
.27379 .5564 .28002 .56195 .28954 .55895 .28333 .55338 Mtetra
.28333 .55338 .28954 .55895 .2991 .55594 .29292 .55035 Mtetra
.29292 .55035 .2991 .55594 .3087 .55292 .30253 .5473 Mtetra
.30253 .5473 .3087 .55292 .31833 .54988 .31218 .54425 Mtetra
.31218 .54425 .31833 .54988 .328 .54684 .32187 .54118 Mtetra
.32187 .54118 .328 .54684 .3377 .54378 .3316 .53811 Mtetra
.3316 .53811 .3377 .54378 .34744 .54071 .34135 .53502 Mtetra
.34135 .53502 .34744 .54071 .35721 .53763 .35115 .53192 Mtetra
.35115 .53192 .35721 .53763 .36702 .53454 .36098 .52881 Mtetra
.36098 .52881 .36702 .53454 .37686 .53144 .37085 .52568 Mtetra
.37085 .52568 .37686 .53144 .38674 .52833 .38075 .52255 Mtetra
.38075 .52255 .38674 .52833 .39666 .5252 .39069 .5194 Mtetra
.39069 .5194 .39666 .5252 .40662 .52206 .40067 .51624 Mtetra
.40067 .51624 .40662 .52206 .41661 .51892 .41068 .51307 Mtetra
.41068 .51307 .41661 .51892 .42664 .51576 .42074 .50989 Mtetra
.42074 .50989 .42664 .51576 .4367 .51258 .43083 .5067 Mtetra
.43083 .5067 .4367 .51258 .44681 .5094 .44095 .50349 Mtetra
.44095 .50349 .44681 .5094 .45695 .50621 .45112 .50027 Mtetra
.45112 .50027 .45695 .50621 .46713 .503 .46132 .49704 Mtetra
.46132 .49704 .46713 .503 .47734 .49978 .47157 .4938 Mtetra
.47157 .4938 .47734 .49978 .4876 .49655 .48185 .49055 Mtetra
.48185 .49055 .4876 .49655 .49789 .4933 .49217 .48728 Mtetra
.49217 .48728 .49789 .4933 .50823 .49005 .50253 .484 Mtetra
.50253 .484 .50823 .49005 .5186 .48678 .51292 .48071 Mtetra
.51292 .48071 .5186 .48678 .52901 .4835 .52336 .47741 Mtetra
.52336 .47741 .52901 .4835 .53946 .4802 .53384 .47409 Mtetra
.53384 .47409 .53946 .4802 .54996 .4769 .54436 .47076 Mtetra
.54436 .47076 .54996 .4769 .56049 .47358 .55491 .46742 Mtetra
.55491 .46742 .56049 .47358 .57106 .47025 .56551 .46407 Mtetra
.56551 .46407 .57106 .47025 .58167 .46691 .57615 .4607 Mtetra
.57615 .4607 .58167 .46691 .59232 .46355 .58683 .45732 Mtetra
.58683 .45732 .59232 .46355 .60302 .46018 .59755 .45393 Mtetra
.59755 .45393 .60302 .46018 .61375 .4568 .60832 .45052 Mtetra
.60832 .45052 .61375 .4568 .62453 .4534 .61912 .4471 Mtetra
.61912 .4471 .62453 .4534 .63535 .44999 .62997 .44367 Mtetra
.62997 .44367 .63535 .44999 .64621 .44657 .64085 .44022 Mtetra
.64085 .44022 .64621 .44657 .65711 .44314 .65178 .43676 Mtetra
.65178 .43676 .65711 .44314 .66805 .43969 .66276 .43329 Mtetra
.66276 .43329 .66805 .43969 .67904 .43623 .67377 .4298 Mtetra
.67377 .4298 .67904 .43623 .69007 .43275 .68483 .4263 Mtetra
.68483 .4263 .69007 .43275 .70114 .42926 .69594 .42279 Mtetra
.69594 .42279 .70114 .42926 .71226 .42576 .70708 .41926 Mtetra
.70708 .41926 .71226 .42576 .72342 .42224 .71827 .41572 Mtetra
.71827 .41572 .72342 .42224 .73462 .41871 .72951 .41216 Mtetra
.72951 .41216 .73462 .41871 .74587 .41517 .74079 .40859 Mtetra
.74079 .40859 .74587 .41517 .75716 .41161 .75211 .40501 Mtetra
.75211 .40501 .75716 .41161 .7685 .40804 .76348 .40141 Mtetra
.76348 .40141 .7685 .40804 .77988 .40445 .77489 .39779 Mtetra
.77489 .39779 .77988 .40445 .79131 .40085 .78635 .39417 Mtetra
.78635 .39417 .79131 .40085 .80278 .39724 .79786 .39053 Mtetra
.79786 .39053 .80278 .39724 .8143 .39361 .80941 .38687 Mtetra
.80941 .38687 .8143 .39361 .82586 .38996 .821 .3832 Mtetra
.821 .3832 .82586 .38996 .83747 .38631 .83265 .37951 Mtetra
.83265 .37951 .83747 .38631 .84913 .38263 .84434 .37581 Mtetra
.84434 .37581 .84913 .38263 .86083 .37895 .85608 .3721 Mtetra
.85608 .3721 .86083 .37895 .87259 .37524 .86786 .36837 Mtetra
.23902 .55988 .24535 .5654 .2548 .56241 .24848 .55687 Mtetra
.24848 .55687 .2548 .56241 .26427 .55941 .25798 .55385 Mtetra
.25798 .55385 .26427 .55941 .27379 .5564 .26751 .55082 Mtetra
.26751 .55082 .27379 .5564 .28333 .55338 .27708 .54777 Mtetra
.27708 .54777 .28333 .55338 .29292 .55035 .28669 .54472 Mtetra
.28669 .54472 .29292 .55035 .30253 .5473 .29632 .54166 Mtetra
.29632 .54166 .30253 .5473 .31218 .54425 .306 .53858 Mtetra
.306 .53858 .31218 .54425 .32187 .54118 .31571 .53549 Mtetra
.31571 .53549 .32187 .54118 .3316 .53811 .32545 .53239 Mtetra
.32545 .53239 .3316 .53811 .34135 .53502 .33523 .52928 Mtetra
.33523 .52928 .34135 .53502 .35115 .53192 .34505 .52616 Mtetra
.34505 .52616 .35115 .53192 .36098 .52881 .3549 .52303 Mtetra
.3549 .52303 .36098 .52881 .37085 .52568 .36479 .51989 Mtetra
.36479 .51989 .37085 .52568 .38075 .52255 .37472 .51673 Mtetra
.37472 .51673 .38075 .52255 .39069 .5194 .38468 .51356 Mtetra
.38468 .51356 .39069 .5194 .40067 .51624 .39468 .51038 Mtetra
.39468 .51038 .40067 .51624 .41068 .51307 .40472 .50719 Mtetra
.40472 .50719 .41068 .51307 .42074 .50989 .4148 .50399 Mtetra
.4148 .50399 .42074 .50989 .43083 .5067 .42491 .50077 Mtetra
.42491 .50077 .43083 .5067 .44095 .50349 .43506 .49754 Mtetra
.43506 .49754 .44095 .50349 .45112 .50027 .44525 .4943 Mtetra
.44525 .4943 .45112 .50027 .46132 .49704 .45548 .49105 Mtetra
.45548 .49105 .46132 .49704 .47157 .4938 .46575 .48779 Mtetra
.46575 .48779 .47157 .4938 .48185 .49055 .47605 .48451 Mtetra
.47605 .48451 .48185 .49055 .49217 .48728 .4864 .48122 Mtetra
.4864 .48122 .49217 .48728 .50253 .484 .49678 .47792 Mtetra
.49678 .47792 .50253 .484 .51292 .48071 .50721 .4746 Mtetra
.50721 .4746 .51292 .48071 .52336 .47741 .51767 .47128 Mtetra
.51767 .47128 .52336 .47741 .53384 .47409 .52817 .46794 Mtetra
.52817 .46794 .53384 .47409 .54436 .47076 .53872 .46458 Mtetra
.53872 .46458 .54436 .47076 .55491 .46742 .5493 .46122 Mtetra
.5493 .46122 .55491 .46742 .56551 .46407 .55993 .45784 Mtetra
.55993 .45784 .56551 .46407 .57615 .4607 .57059 .45445 Mtetra
.57059 .45445 .57615 .4607 .58683 .45732 .5813 .45104 Mtetra
.5813 .45104 .58683 .45732 .59755 .45393 .59205 .44763 Mtetra
.59205 .44763 .59755 .45393 .60832 .45052 .60284 .4442 Mtetra
.60284 .4442 .60832 .45052 .61912 .4471 .61367 .44075 Mtetra
.61367 .44075 .61912 .4471 .62997 .44367 .62455 .43729 Mtetra
.62455 .43729 .62997 .44367 .64085 .44022 .63546 .43382 Mtetra
.63546 .43382 .64085 .44022 .65178 .43676 .64642 .43034 Mtetra
.64642 .43034 .65178 .43676 .66276 .43329 .65743 .42684 Mtetra
.65743 .42684 .66276 .43329 .67377 .4298 .66847 .42333 Mtetra
.66847 .42333 .67377 .4298 .68483 .4263 .67956 .4198 Mtetra
.67956 .4198 .68483 .4263 .69594 .42279 .69069 .41626 Mtetra
.69069 .41626 .69594 .42279 .70708 .41926 .70187 .41271 Mtetra
.70187 .41271 .70708 .41926 .71827 .41572 .71309 .40914 Mtetra
.71309 .40914 .71827 .41572 .72951 .41216 .72436 .40556 Mtetra
.72436 .40556 .72951 .41216 .74079 .40859 .73566 .40196 Mtetra
.73566 .40196 .74079 .40859 .75211 .40501 .74702 .39835 Mtetra
.74702 .39835 .75211 .40501 .76348 .40141 .75842 .39473 Mtetra
.75842 .39473 .76348 .40141 .77489 .39779 .76987 .39109 Mtetra
.76987 .39109 .77489 .39779 .78635 .39417 .78136 .38743 Mtetra
.78136 .38743 .78635 .39417 .79786 .39053 .79289 .38376 Mtetra
.79289 .38376 .79786 .39053 .80941 .38687 .80448 .38008 Mtetra
.80448 .38008 .80941 .38687 .821 .3832 .81611 .37638 Mtetra
.81611 .37638 .821 .3832 .83265 .37951 .82779 .37267 Mtetra
.82779 .37267 .83265 .37951 .84434 .37581 .83951 .36894 Mtetra
.83951 .36894 .84434 .37581 .85608 .3721 .85128 .3652 Mtetra
.85128 .3652 .85608 .3721 .86786 .36837 .8631 .36144 Mtetra
.23264 .55431 .23902 .55988 .24848 .55687 .24213 .55128 Mtetra
.24213 .55128 .24848 .55687 .25798 .55385 .25165 .54824 Mtetra
.25165 .54824 .25798 .55385 .26751 .55082 .2612 .54519 Mtetra
.2612 .54519 .26751 .55082 .27708 .54777 .27079 .54213 Mtetra
.27079 .54213 .27708 .54777 .28669 .54472 .28041 .53905 Mtetra
.28041 .53905 .28669 .54472 .29632 .54166 .29007 .53597 Mtetra
.29007 .53597 .29632 .54166 .306 .53858 .29977 .53287 Mtetra
.29977 .53287 .306 .53858 .31571 .53549 .3095 .52976 Mtetra
.3095 .52976 .31571 .53549 .32545 .53239 .31926 .52664 Mtetra
.31926 .52664 .32545 .53239 .33523 .52928 .32907 .52351 Mtetra
.32907 .52351 .33523 .52928 .34505 .52616 .33891 .52037 Mtetra
.33891 .52037 .34505 .52616 .3549 .52303 .34878 .51722 Mtetra
.34878 .51722 .3549 .52303 .36479 .51989 .35869 .51405 Mtetra
.35869 .51405 .36479 .51989 .37472 .51673 .36864 .51087 Mtetra
.36864 .51087 .37472 .51673 .38468 .51356 .37863 .50768 Mtetra
.37863 .50768 .38468 .51356 .39468 .51038 .38865 .50448 Mtetra
.38865 .50448 .39468 .51038 .40472 .50719 .39872 .50127 Mtetra
.39872 .50127 .40472 .50719 .4148 .50399 .40882 .49804 Mtetra
.40882 .49804 .4148 .50399 .42491 .50077 .41895 .4948 Mtetra
.41895 .4948 .42491 .50077 .43506 .49754 .42913 .49155 Mtetra
.42913 .49155 .43506 .49754 .44525 .4943 .43934 .48829 Mtetra
.43934 .48829 .44525 .4943 .45548 .49105 .4496 .48501 Mtetra
.4496 .48501 .45548 .49105 .46575 .48779 .45989 .48173 Mtetra
.45989 .48173 .46575 .48779 .47605 .48451 .47022 .47843 Mtetra
.47022 .47843 .47605 .48451 .4864 .48122 .48059 .47511 Mtetra
.48059 .47511 .4864 .48122 .49678 .47792 .491 .47179 Mtetra
.491 .47179 .49678 .47792 .50721 .4746 .50145 .46845 Mtetra
.50145 .46845 .50721 .4746 .51767 .47128 .51194 .4651 Mtetra
.51194 .4651 .51767 .47128 .52817 .46794 .52247 .46174 Mtetra
.52247 .46174 .52817 .46794 .53872 .46458 .53304 .45836 Mtetra
.53304 .45836 .53872 .46458 .5493 .46122 .54365 .45497 Mtetra
.54365 .45497 .5493 .46122 .55993 .45784 .5543 .45157 Mtetra
.5543 .45157 .55993 .45784 .57059 .45445 .565 .44815 Mtetra
.565 .44815 .57059 .45445 .5813 .45104 .57573 .44472 Mtetra
.57573 .44472 .5813 .45104 .59205 .44763 .58651 .44128 Mtetra
.58651 .44128 .59205 .44763 .60284 .4442 .59732 .43783 Mtetra
.59732 .43783 .60284 .4442 .61367 .44075 .60819 .43436 Mtetra
.60819 .43436 .61367 .44075 .62455 .43729 .61909 .43087 Mtetra
.61909 .43087 .62455 .43729 .63546 .43382 .63003 .42738 Mtetra
.63003 .42738 .63546 .43382 .64642 .43034 .64102 .42387 Mtetra
.64102 .42387 .64642 .43034 .65743 .42684 .65205 .42034 Mtetra
.65205 .42034 .65743 .42684 .66847 .42333 .66313 .41681 Mtetra
.66313 .41681 .66847 .42333 .67956 .4198 .67425 .41326 Mtetra
.67425 .41326 .67956 .4198 .69069 .41626 .68541 .40969 Mtetra
.68541 .40969 .69069 .41626 .70187 .41271 .69662 .40611 Mtetra
.69662 .40611 .70187 .41271 .71309 .40914 .70787 .40252 Mtetra
.70787 .40252 .71309 .40914 .72436 .40556 .71917 .39891 Mtetra
.71917 .39891 .72436 .40556 .73566 .40196 .73051 .39529 Mtetra
.73051 .39529 .73566 .40196 .74702 .39835 .74189 .39165 Mtetra
.74189 .39165 .74702 .39835 .75842 .39473 .75332 .388 Mtetra
.75332 .388 .75842 .39473 .76987 .39109 .7648 .38433 Mtetra
.7648 .38433 .76987 .39109 .78136 .38743 .77633 .38065 Mtetra
.77633 .38065 .78136 .38743 .79289 .38376 .7879 .37695 Mtetra
.7879 .37695 .79289 .38376 .80448 .38008 .79951 .37324 Mtetra
.79951 .37324 .80448 .38008 .81611 .37638 .81118 .36952 Mtetra
.81118 .36952 .81611 .37638 .82779 .37267 .82289 .36578 Mtetra
.82289 .36578 .82779 .37267 .83951 .36894 .83465 .36202 Mtetra
.83465 .36202 .83951 .36894 .85128 .3652 .84645 .35825 Mtetra
.84645 .35825 .85128 .3652 .8631 .36144 .85831 .35446 Mtetra
.22623 .54871 .23264 .55431 .24213 .55128 .23573 .54566 Mtetra
.23573 .54566 .24213 .55128 .25165 .54824 .24527 .5426 Mtetra
.24527 .5426 .25165 .54824 .2612 .54519 .25484 .53953 Mtetra
.25484 .53953 .2612 .54519 .27079 .54213 .26445 .53644 Mtetra
.26445 .53644 .27079 .54213 .28041 .53905 .2741 .53335 Mtetra
.2741 .53335 .28041 .53905 .29007 .53597 .28378 .53024 Mtetra
.28378 .53024 .29007 .53597 .29977 .53287 .2935 .52712 Mtetra
.2935 .52712 .29977 .53287 .3095 .52976 .30325 .524 Mtetra
.30325 .524 .3095 .52976 .31926 .52664 .31304 .52085 Mtetra
.31304 .52085 .31926 .52664 .32907 .52351 .32286 .5177 Mtetra
.32286 .5177 .32907 .52351 .33891 .52037 .33272 .51454 Mtetra
.33272 .51454 .33891 .52037 .34878 .51722 .34262 .51136 Mtetra
.34262 .51136 .34878 .51722 .35869 .51405 .35256 .50817 Mtetra
.35256 .50817 .35869 .51405 .36864 .51087 .36253 .50497 Mtetra
.36253 .50497 .36864 .51087 .37863 .50768 .37254 .50176 Mtetra
.37254 .50176 .37863 .50768 .38865 .50448 .38258 .49854 Mtetra
.38258 .49854 .38865 .50448 .39872 .50127 .39267 .4953 Mtetra
.39267 .4953 .39872 .50127 .40882 .49804 .40279 .49205 Mtetra
.40279 .49205 .40882 .49804 .41895 .4948 .41295 .48879 Mtetra
.41295 .48879 .41895 .4948 .42913 .49155 .42315 .48552 Mtetra
.42315 .48552 .42913 .49155 .43934 .48829 .43339 .48223 Mtetra
.43339 .48223 .43934 .48829 .4496 .48501 .44367 .47893 Mtetra
.44367 .47893 .4496 .48501 .45989 .48173 .45399 .47562 Mtetra
.45399 .47562 .45989 .48173 .47022 .47843 .46434 .4723 Mtetra
.46434 .4723 .47022 .47843 .48059 .47511 .47474 .46897 Mtetra
.47474 .46897 .48059 .47511 .491 .47179 .48517 .46562 Mtetra
.48517 .46562 .491 .47179 .50145 .46845 .49565 .46226 Mtetra
.49565 .46226 .50145 .46845 .51194 .4651 .50617 .45888 Mtetra
.50617 .45888 .51194 .4651 .52247 .46174 .51672 .45549 Mtetra
.51672 .45549 .52247 .46174 .53304 .45836 .52732 .45209 Mtetra
.52732 .45209 .53304 .45836 .54365 .45497 .53796 .44868 Mtetra
.53796 .44868 .54365 .45497 .5543 .45157 .54864 .44525 Mtetra
.54864 .44525 .5543 .45157 .565 .44815 .55936 .44181 Mtetra
.55936 .44181 .565 .44815 .57573 .44472 .57012 .43836 Mtetra
.57012 .43836 .57573 .44472 .58651 .44128 .58092 .43489 Mtetra
.58092 .43489 .58651 .44128 .59732 .43783 .59177 .43141 Mtetra
.59177 .43141 .59732 .43783 .60819 .43436 .60266 .42792 Mtetra
.60266 .42792 .60819 .43436 .61909 .43087 .61359 .42441 Mtetra
.61359 .42441 .61909 .43087 .63003 .42738 .62456 .42089 Mtetra
.62456 .42089 .63003 .42738 .64102 .42387 .63558 .41735 Mtetra
.63558 .41735 .64102 .42387 .65205 .42034 .64664 .4138 Mtetra
.64664 .4138 .65205 .42034 .66313 .41681 .65775 .41024 Mtetra
.65775 .41024 .66313 .41681 .67425 .41326 .6689 .40666 Mtetra
.6689 .40666 .67425 .41326 .68541 .40969 .68009 .40307 Mtetra
.68009 .40307 .68541 .40969 .69662 .40611 .69133 .39946 Mtetra
.69133 .39946 .69662 .40611 .70787 .40252 .70261 .39584 Mtetra
.70261 .39584 .70787 .40252 .71917 .39891 .71394 .39221 Mtetra
.71394 .39221 .71917 .39891 .73051 .39529 .72531 .38856 Mtetra
.72531 .38856 .73051 .39529 .74189 .39165 .73673 .3849 Mtetra
.73673 .3849 .74189 .39165 .75332 .388 .74819 .38122 Mtetra
.74819 .38122 .75332 .388 .7648 .38433 .7597 .37752 Mtetra
.7597 .37752 .7648 .38433 .77633 .38065 .77126 .37381 Mtetra
.77126 .37381 .77633 .38065 .7879 .37695 .78286 .37009 Mtetra
.78286 .37009 .7879 .37695 .79951 .37324 .79451 .36635 Mtetra
.79451 .36635 .79951 .37324 .81118 .36952 .80621 .3626 Mtetra
.80621 .3626 .81118 .36952 .82289 .36578 .81795 .35883 Mtetra
.81795 .35883 .82289 .36578 .83465 .36202 .82975 .35505 Mtetra
.82975 .35505 .83465 .36202 .84645 .35825 .84159 .35125 Mtetra
.84159 .35125 .84645 .35825 .85831 .35446 .85348 .34743 Mtetra
.21976 .54307 .22623 .54871 .23573 .54566 .22929 .54 Mtetra
.22929 .54 .23573 .54566 .24527 .5426 .23885 .53692 Mtetra
.23885 .53692 .24527 .5426 .25484 .53953 .24844 .53383 Mtetra
.24844 .53383 .25484 .53953 .26445 .53644 .25807 .53072 Mtetra
.25807 .53072 .26445 .53644 .2741 .53335 .26774 .52761 Mtetra
.26774 .52761 .2741 .53335 .28378 .53024 .27744 .52448 Mtetra
.27744 .52448 .28378 .53024 .2935 .52712 .28718 .52134 Mtetra
.28718 .52134 .2935 .52712 .30325 .524 .29695 .51819 Mtetra
.29695 .51819 .30325 .524 .31304 .52085 .30676 .51503 Mtetra
.30676 .51503 .31304 .52085 .32286 .5177 .31661 .51185 Mtetra
.31661 .51185 .32286 .5177 .33272 .51454 .3265 .50866 Mtetra
.3265 .50866 .33272 .51454 .34262 .51136 .33642 .50547 Mtetra
.33642 .50547 .34262 .51136 .35256 .50817 .34637 .50226 Mtetra
.34637 .50226 .35256 .50817 .36253 .50497 .35637 .49903 Mtetra
.35637 .49903 .36253 .50497 .37254 .50176 .3664 .4958 Mtetra
.3664 .4958 .37254 .50176 .38258 .49854 .37647 .49255 Mtetra
.37647 .49255 .38258 .49854 .39267 .4953 .38658 .48929 Mtetra
.38658 .48929 .39267 .4953 .40279 .49205 .39673 .48602 Mtetra
.39673 .48602 .40279 .49205 .41295 .48879 .40691 .48274 Mtetra
.40691 .48274 .41295 .48879 .42315 .48552 .41714 .47944 Mtetra
.41714 .47944 .42315 .48552 .43339 .48223 .4274 .47613 Mtetra
.4274 .47613 .43339 .48223 .44367 .47893 .4377 .47281 Mtetra
.4377 .47281 .44367 .47893 .45399 .47562 .44805 .46948 Mtetra
.44805 .46948 .45399 .47562 .46434 .4723 .45843 .46613 Mtetra
.45843 .46613 .46434 .4723 .47474 .46897 .46885 .46277 Mtetra
.46885 .46277 .47474 .46897 .48517 .46562 .47931 .4594 Mtetra
.47931 .4594 .48517 .46562 .49565 .46226 .48981 .45602 Mtetra
.48981 .45602 .49565 .46226 .50617 .45888 .50035 .45262 Mtetra
.50035 .45262 .50617 .45888 .51672 .45549 .51093 .44921 Mtetra
.51093 .44921 .51672 .45549 .52732 .45209 .52156 .44578 Mtetra
.52156 .44578 .52732 .45209 .53796 .44868 .53222 .44234 Mtetra
.53222 .44234 .53796 .44868 .54864 .44525 .54293 .43889 Mtetra
.54293 .43889 .54864 .44525 .55936 .44181 .55368 .43543 Mtetra
.55368 .43543 .55936 .44181 .57012 .43836 .56447 .43195 Mtetra
.56447 .43195 .57012 .43836 .58092 .43489 .5753 .42846 Mtetra
.5753 .42846 .58092 .43489 .59177 .43141 .58617 .42495 Mtetra
.58617 .42495 .59177 .43141 .60266 .42792 .59709 .42143 Mtetra
.59709 .42143 .60266 .42792 .61359 .42441 .60805 .4179 Mtetra
.60805 .4179 .61359 .42441 .62456 .42089 .61906 .41435 Mtetra
.61906 .41435 .62456 .42089 .63558 .41735 .6301 .41079 Mtetra
.6301 .41079 .63558 .41735 .64664 .4138 .64119 .40721 Mtetra
.64119 .40721 .64664 .4138 .65775 .41024 .65233 .40362 Mtetra
.65233 .40362 .65775 .41024 .6689 .40666 .66351 .40002 Mtetra
.66351 .40002 .6689 .40666 .68009 .40307 .67473 .3964 Mtetra
.67473 .3964 .68009 .40307 .69133 .39946 .686 .39277 Mtetra
.686 .39277 .69133 .39946 .70261 .39584 .69731 .38912 Mtetra
.69731 .38912 .70261 .39584 .71394 .39221 .70867 .38546 Mtetra
.70867 .38546 .71394 .39221 .72531 .38856 .72007 .38178 Mtetra
.72007 .38178 .72531 .38856 .73673 .3849 .73152 .37809 Mtetra
.73152 .37809 .73673 .3849 .74819 .38122 .74302 .37439 Mtetra
.74302 .37439 .74819 .38122 .7597 .37752 .75456 .37067 Mtetra
.75456 .37067 .7597 .37752 .77126 .37381 .76615 .36693 Mtetra
.76615 .36693 .77126 .37381 .78286 .37009 .77779 .36318 Mtetra
.77779 .36318 .78286 .37009 .79451 .36635 .78947 .35941 Mtetra
.78947 .35941 .79451 .36635 .80621 .3626 .8012 .35563 Mtetra
.8012 .35563 .80621 .3626 .81795 .35883 .81298 .35183 Mtetra
.81298 .35183 .81795 .35883 .82975 .35505 .82481 .34802 Mtetra
.82481 .34802 .82975 .35505 .84159 .35125 .83668 .34419 Mtetra
.83668 .34419 .84159 .35125 .85348 .34743 .84861 .34035 Mtetra
.21326 .53739 .21976 .54307 .22929 .54 .2228 .5343 Mtetra
.2228 .5343 .22929 .54 .23885 .53692 .23238 .5312 Mtetra
.23238 .5312 .23885 .53692 .24844 .53383 .242 .52809 Mtetra
.242 .52809 .24844 .53383 .25807 .53072 .25165 .52496 Mtetra
.25165 .52496 .25807 .53072 .26774 .52761 .26134 .52182 Mtetra
.26134 .52182 .26774 .52761 .27744 .52448 .27106 .51867 Mtetra
.27106 .51867 .27744 .52448 .28718 .52134 .28082 .51551 Mtetra
.28082 .51551 .28718 .52134 .29695 .51819 .29062 .51234 Mtetra
.29062 .51234 .29695 .51819 .30676 .51503 .30045 .50916 Mtetra
.30045 .50916 .30676 .51503 .31661 .51185 .31032 .50596 Mtetra
.31032 .50596 .31661 .51185 .3265 .50866 .32022 .50275 Mtetra
.32022 .50275 .3265 .50866 .33642 .50547 .33017 .49953 Mtetra
.33017 .49953 .33642 .50547 .34637 .50226 .34015 .4963 Mtetra
.34015 .4963 .34637 .50226 .35637 .49903 .35017 .49305 Mtetra
.35017 .49305 .35637 .49903 .3664 .4958 .36022 .4898 Mtetra
.36022 .4898 .3664 .4958 .37647 .49255 .37032 .48653 Mtetra
.37032 .48653 .37647 .49255 .38658 .48929 .38045 .48325 Mtetra
.38045 .48325 .38658 .48929 .39673 .48602 .39062 .47995 Mtetra
.39062 .47995 .39673 .48602 .40691 .48274 .40083 .47664 Mtetra
.40083 .47664 .40691 .48274 .41714 .47944 .41108 .47333 Mtetra
.41108 .47333 .41714 .47944 .4274 .47613 .42137 .46999 Mtetra
.42137 .46999 .4274 .47613 .4377 .47281 .43169 .46665 Mtetra
.43169 .46665 .4377 .47281 .44805 .46948 .44206 .46329 Mtetra
.44206 .46329 .44805 .46948 .45843 .46613 .45247 .45992 Mtetra
.45247 .45992 .45843 .46613 .46885 .46277 .46291 .45654 Mtetra
.46291 .45654 .46885 .46277 .47931 .4594 .4734 .45314 Mtetra
.4734 .45314 .47931 .4594 .48981 .45602 .48393 .44973 Mtetra
.48393 .44973 .48981 .45602 .50035 .45262 .4945 .44631 Mtetra
.4945 .44631 .50035 .45262 .51093 .44921 .50511 .44287 Mtetra
.50511 .44287 .51093 .44921 .52156 .44578 .51576 .43942 Mtetra
.51576 .43942 .52156 .44578 .53222 .44234 .52645 .43596 Mtetra
.52645 .43596 .53222 .44234 .54293 .43889 .53718 .43248 Mtetra
.53718 .43248 .54293 .43889 .55368 .43543 .54796 .42899 Mtetra
.54796 .42899 .55368 .43543 .56447 .43195 .55878 .42549 Mtetra
.55878 .42549 .56447 .43195 .5753 .42846 .56964 .42197 Mtetra
.56964 .42197 .5753 .42846 .58617 .42495 .58054 .41844 Mtetra
.58054 .41844 .58617 .42495 .59709 .42143 .59149 .4149 Mtetra
.59149 .4149 .59709 .42143 .60805 .4179 .60247 .41134 Mtetra
.60247 .41134 .60805 .4179 .61906 .41435 .61351 .40776 Mtetra
.61351 .40776 .61906 .41435 .6301 .41079 .62458 .40418 Mtetra
.62458 .40418 .6301 .41079 .64119 .40721 .6357 .40057 Mtetra
.6357 .40057 .64119 .40721 .65233 .40362 .64687 .39696 Mtetra
.64687 .39696 .65233 .40362 .66351 .40002 .65808 .39333 Mtetra
.65808 .39333 .66351 .40002 .67473 .3964 .66933 .38968 Mtetra
.66933 .38968 .67473 .3964 .686 .39277 .68063 .38602 Mtetra
.68063 .38602 .686 .39277 .69731 .38912 .69198 .38235 Mtetra
.69198 .38235 .69731 .38912 .70867 .38546 .70336 .37866 Mtetra
.70336 .37866 .70867 .38546 .72007 .38178 .7148 .37496 Mtetra
.7148 .37496 .72007 .38178 .73152 .37809 .72628 .37124 Mtetra
.72628 .37124 .73152 .37809 .74302 .37439 .73781 .3675 Mtetra
.73781 .3675 .74302 .37439 .75456 .37067 .74939 .36376 Mtetra
.74939 .36376 .75456 .37067 .76615 .36693 .76101 .35999 Mtetra
.76101 .35999 .76615 .36693 .77779 .36318 .77268 .35621 Mtetra
.77268 .35621 .77779 .36318 .78947 .35941 .78439 .35242 Mtetra
.78439 .35242 .78947 .35941 .8012 .35563 .79616 .34861 Mtetra
.79616 .34861 .8012 .35563 .81298 .35183 .80797 .34478 Mtetra
.80797 .34478 .81298 .35183 .82481 .34802 .81983 .34094 Mtetra
.81983 .34094 .82481 .34802 .83668 .34419 .83174 .33708 Mtetra
.83174 .33708 .83668 .34419 .84861 .34035 .8437 .33321 Mtetra
.20671 .53168 .21326 .53739 .2228 .5343 .21628 .52857 Mtetra
.21628 .52857 .2228 .5343 .23238 .5312 .22588 .52544 Mtetra
.22588 .52544 .23238 .5312 .242 .52809 .23551 .52231 Mtetra
.23551 .52231 .242 .52809 .25165 .52496 .24519 .51916 Mtetra
.24519 .51916 .25165 .52496 .26134 .52182 .25489 .516 Mtetra
.25489 .516 .26134 .52182 .27106 .51867 .26464 .51283 Mtetra
.26464 .51283 .27106 .51867 .28082 .51551 .27442 .50965 Mtetra
.27442 .50965 .28082 .51551 .29062 .51234 .28424 .50645 Mtetra
.28424 .50645 .29062 .51234 .30045 .50916 .29409 .50324 Mtetra
.29409 .50324 .30045 .50916 .31032 .50596 .30398 .50003 Mtetra
.30398 .50003 .31032 .50596 .32022 .50275 .31391 .4968 Mtetra
.31391 .4968 .32022 .50275 .33017 .49953 .32388 .49355 Mtetra
.32388 .49355 .33017 .49953 .34015 .4963 .33388 .4903 Mtetra
.33388 .4903 .34015 .4963 .35017 .49305 .34392 .48703 Mtetra
.34392 .48703 .35017 .49305 .36022 .4898 .354 .48375 Mtetra
.354 .48375 .36022 .4898 .37032 .48653 .36412 .48046 Mtetra
.36412 .48046 .37032 .48653 .38045 .48325 .37428 .47715 Mtetra
.37428 .47715 .38045 .48325 .39062 .47995 .38447 .47384 Mtetra
.38447 .47384 .39062 .47995 .40083 .47664 .3947 .47051 Mtetra
.3947 .47051 .40083 .47664 .41108 .47333 .40498 .46716 Mtetra
.40498 .46716 .41108 .47333 .42137 .46999 .41529 .46381 Mtetra
.41529 .46381 .42137 .46999 .43169 .46665 .42564 .46044 Mtetra
.42564 .46044 .43169 .46665 .44206 .46329 .43603 .45706 Mtetra
.43603 .45706 .44206 .46329 .45247 .45992 .44647 .45366 Mtetra
.44647 .45366 .45247 .45992 .46291 .45654 .45694 .45026 Mtetra
.45694 .45026 .46291 .45654 .4734 .45314 .46745 .44684 Mtetra
.46745 .44684 .4734 .45314 .48393 .44973 .47801 .4434 Mtetra
.47801 .4434 .48393 .44973 .4945 .44631 .4886 .43995 Mtetra
.4886 .43995 .4945 .44631 .50511 .44287 .49924 .43649 Mtetra
.49924 .43649 .50511 .44287 .51576 .43942 .50991 .43302 Mtetra
.50991 .43302 .51576 .43942 .52645 .43596 .52063 .42953 Mtetra
.52063 .42953 .52645 .43596 .53718 .43248 .53139 .42603 Mtetra
.53139 .42603 .53718 .43248 .54796 .42899 .5422 .42251 Mtetra
.5422 .42251 .54796 .42899 .55878 .42549 .55304 .41899 Mtetra
.55304 .41899 .55878 .42549 .56964 .42197 .56393 .41544 Mtetra
.56393 .41544 .56964 .42197 .58054 .41844 .57486 .41189 Mtetra
.57486 .41189 .58054 .41844 .59149 .4149 .58584 .40831 Mtetra
.58584 .40831 .59149 .4149 .60247 .41134 .59686 .40473 Mtetra
.59686 .40473 .60247 .41134 .61351 .40776 .60792 .40113 Mtetra
.60792 .40113 .61351 .40776 .62458 .40418 .61902 .39752 Mtetra
.61902 .39752 .62458 .40418 .6357 .40057 .63017 .39389 Mtetra
.63017 .39389 .6357 .40057 .64687 .39696 .64137 .39025 Mtetra
.64137 .39025 .64687 .39696 .65808 .39333 .65261 .38659 Mtetra
.65261 .38659 .65808 .39333 .66933 .38968 .66389 .38292 Mtetra
.66389 .38292 .66933 .38968 .68063 .38602 .67522 .37923 Mtetra
.67522 .37923 .68063 .38602 .69198 .38235 .6866 .37553 Mtetra
.6866 .37553 .69198 .38235 .70336 .37866 .69802 .37181 Mtetra
.69802 .37181 .70336 .37866 .7148 .37496 .70949 .36808 Mtetra
.70949 .36808 .7148 .37496 .72628 .37124 .721 .36433 Mtetra
.721 .36433 .72628 .37124 .73781 .3675 .73256 .36057 Mtetra
.73256 .36057 .73781 .3675 .74939 .36376 .74417 .35679 Mtetra
.74417 .35679 .74939 .36376 .76101 .35999 .75583 .353 Mtetra
.75583 .353 .76101 .35999 .77268 .35621 .76753 .34919 Mtetra
.76753 .34919 .77268 .35621 .78439 .35242 .77928 .34537 Mtetra
.77928 .34537 .78439 .35242 .79616 .34861 .79108 .34153 Mtetra
.79108 .34153 .79616 .34861 .80797 .34478 .80293 .33768 Mtetra
.80293 .33768 .80797 .34478 .81983 .34094 .81482 .33381 Mtetra
.81482 .33381 .81983 .34094 .83174 .33708 .82677 .32992 Mtetra
.82677 .32992 .83174 .33708 .8437 .33321 .83876 .32602 Mtetra
.20012 .52592 .20671 .53168 .21628 .52857 .2097 .52279 Mtetra
.2097 .52279 .21628 .52857 .22588 .52544 .21932 .51964 Mtetra
.21932 .51964 .22588 .52544 .23551 .52231 .22898 .51649 Mtetra
.22898 .51649 .23551 .52231 .24519 .51916 .23867 .51332 Mtetra
.23867 .51332 .24519 .51916 .25489 .516 .2484 .51014 Mtetra
.2484 .51014 .25489 .516 .26464 .51283 .25817 .50694 Mtetra
.25817 .50694 .26464 .51283 .27442 .50965 .26797 .50374 Mtetra
.26797 .50374 .27442 .50965 .28424 .50645 .27781 .50052 Mtetra
.27781 .50052 .28424 .50645 .29409 .50324 .28769 .49729 Mtetra
.28769 .49729 .29409 .50324 .30398 .50003 .2976 .49405 Mtetra
.2976 .49405 .30398 .50003 .31391 .4968 .30755 .4908 Mtetra
.30755 .4908 .31391 .4968 .32388 .49355 .31754 .48753 Mtetra
.31754 .48753 .32388 .49355 .33388 .4903 .32757 .48426 Mtetra
.32757 .48426 .33388 .4903 .34392 .48703 .33763 .48097 Mtetra
.33763 .48097 .34392 .48703 .354 .48375 .34774 .47766 Mtetra
.34774 .47766 .354 .48375 .36412 .48046 .35788 .47435 Mtetra
.35788 .47435 .36412 .48046 .37428 .47715 .36806 .47102 Mtetra
.36806 .47102 .37428 .47715 .38447 .47384 .37828 .46768 Mtetra
.37828 .46768 .38447 .47384 .3947 .47051 .38854 .46433 Mtetra
.38854 .46433 .3947 .47051 .40498 .46716 .39883 .46096 Mtetra
.39883 .46096 .40498 .46716 .41529 .46381 .40917 .45758 Mtetra
.40917 .45758 .41529 .46381 .42564 .46044 .41955 .45419 Mtetra
.41955 .45419 .42564 .46044 .43603 .45706 .42996 .45078 Mtetra
.42996 .45078 .43603 .45706 .44647 .45366 .44042 .44736 Mtetra
.44042 .44736 .44647 .45366 .45694 .45026 .45092 .44393 Mtetra
.45092 .44393 .45694 .45026 .46745 .44684 .46146 .44049 Mtetra
.46146 .44049 .46745 .44684 .47801 .4434 .47204 .43703 Mtetra
.47204 .43703 .47801 .4434 .4886 .43995 .48266 .43355 Mtetra
.48266 .43355 .4886 .43995 .49924 .43649 .49332 .43007 Mtetra
.49332 .43007 .49924 .43649 .50991 .43302 .50403 .42657 Mtetra
.50403 .42657 .50991 .43302 .52063 .42953 .51477 .42306 Mtetra
.51477 .42306 .52063 .42953 .53139 .42603 .52556 .41953 Mtetra
.52556 .41953 .53139 .42603 .5422 .42251 .53639 .41599 Mtetra
.53639 .41599 .5422 .42251 .55304 .41899 .54727 .41243 Mtetra
.54727 .41243 .55304 .41899 .56393 .41544 .55818 .40886 Mtetra
.55818 .40886 .56393 .41544 .57486 .41189 .56914 .40528 Mtetra
.56914 .40528 .57486 .41189 .58584 .40831 .58015 .40168 Mtetra
.58015 .40168 .58584 .40831 .59686 .40473 .5912 .39807 Mtetra
.5912 .39807 .59686 .40473 .60792 .40113 .60229 .39445 Mtetra
.60229 .39445 .60792 .40113 .61902 .39752 .61342 .39081 Mtetra
.61342 .39081 .61902 .39752 .63017 .39389 .6246 .38715 Mtetra
.6246 .38715 .63017 .39389 .64137 .39025 .63583 .38348 Mtetra
.63583 .38348 .64137 .39025 .65261 .38659 .6471 .3798 Mtetra
.6471 .3798 .65261 .38659 .66389 .38292 .65841 .3761 Mtetra
.65841 .3761 .66389 .38292 .67522 .37923 .66977 .37238 Mtetra
.66977 .37238 .67522 .37923 .6866 .37553 .68118 .36866 Mtetra
.68118 .36866 .6866 .37553 .69802 .37181 .69263 .36491 Mtetra
.69263 .36491 .69802 .37181 .70949 .36808 .70413 .36115 Mtetra
.70413 .36115 .70949 .36808 .721 .36433 .71568 .35738 Mtetra
.71568 .35738 .721 .36433 .73256 .36057 .72727 .35359 Mtetra
.72727 .35359 .73256 .36057 .74417 .35679 .73892 .34978 Mtetra
.73892 .34978 .74417 .35679 .75583 .353 .7506 .34596 Mtetra
.7506 .34596 .75583 .353 .76753 .34919 .76234 .34212 Mtetra
.76234 .34212 .76753 .34919 .77928 .34537 .77412 .33827 Mtetra
.77412 .33827 .77928 .34537 .79108 .34153 .78596 .3344 Mtetra
.78596 .3344 .79108 .34153 .80293 .33768 .79784 .33052 Mtetra
.79784 .33052 .80293 .33768 .81482 .33381 .80977 .32662 Mtetra
.80977 .32662 .81482 .33381 .82677 .32992 .82175 .3227 Mtetra
.82175 .3227 .82677 .32992 .83876 .32602 .83378 .31877 Mtetra
.19348 .52013 .20012 .52592 .2097 .52279 .20308 .51697 Mtetra
.20308 .51697 .2097 .52279 .21932 .51964 .21272 .51381 Mtetra
.21272 .51381 .21932 .51964 .22898 .51649 .2224 .51063 Mtetra
.2224 .51063 .22898 .51649 .23867 .51332 .23212 .50744 Mtetra
.23212 .50744 .23867 .51332 .2484 .51014 .24187 .50423 Mtetra
.24187 .50423 .2484 .51014 .25817 .50694 .25166 .50102 Mtetra
.25166 .50102 .25817 .50694 .26797 .50374 .26148 .49779 Mtetra
.26148 .49779 .26797 .50374 .27781 .50052 .27134 .49455 Mtetra
.27134 .49455 .27781 .50052 .28769 .49729 .28124 .4913 Mtetra
.28124 .4913 .28769 .49729 .2976 .49405 .29118 .48804 Mtetra
.29118 .48804 .2976 .49405 .30755 .4908 .30115 .48476 Mtetra
.30115 .48476 .30755 .4908 .31754 .48753 .31116 .48147 Mtetra
.31116 .48147 .31754 .48753 .32757 .48426 .32121 .47817 Mtetra
.32121 .47817 .32757 .48426 .33763 .48097 .3313 .47486 Mtetra
.3313 .47486 .33763 .48097 .34774 .47766 .34143 .47153 Mtetra
.34143 .47153 .34774 .47766 .35788 .47435 .35159 .46819 Mtetra
.35159 .46819 .35788 .47435 .36806 .47102 .3618 .46484 Mtetra
.3618 .46484 .36806 .47102 .37828 .46768 .37204 .46148 Mtetra
.37204 .46148 .37828 .46768 .38854 .46433 .38232 .4581 Mtetra
.38232 .4581 .38854 .46433 .39883 .46096 .39264 .45471 Mtetra
.39264 .45471 .39883 .46096 .40917 .45758 .40301 .45131 Mtetra
.40301 .45131 .40917 .45758 .41955 .45419 .41341 .44789 Mtetra
.41341 .44789 .41955 .45419 .42996 .45078 .42385 .44446 Mtetra
.42385 .44446 .42996 .45078 .44042 .44736 .43434 .44102 Mtetra
.43434 .44102 .44042 .44736 .45092 .44393 .44486 .43756 Mtetra
.44486 .43756 .45092 .44393 .46146 .44049 .45542 .43409 Mtetra
.45542 .43409 .46146 .44049 .47204 .43703 .46603 .43061 Mtetra
.46603 .43061 .47204 .43703 .48266 .43355 .47668 .42711 Mtetra
.47668 .42711 .48266 .43355 .49332 .43007 .48737 .4236 Mtetra
.48737 .4236 .49332 .43007 .50403 .42657 .4981 .42007 Mtetra
.4981 .42007 .50403 .42657 .51477 .42306 .50887 .41653 Mtetra
.50887 .41653 .51477 .42306 .52556 .41953 .51969 .41298 Mtetra
.51969 .41298 .52556 .41953 .53639 .41599 .53055 .40941 Mtetra
.53055 .40941 .53639 .41599 .54727 .41243 .54145 .40583 Mtetra
.54145 .40583 .54727 .41243 .55818 .40886 .5524 .40224 Mtetra
.5524 .40224 .55818 .40886 .56914 .40528 .56338 .39863 Mtetra
.56338 .39863 .56914 .40528 .58015 .40168 .57442 .39501 Mtetra
.57442 .39501 .58015 .40168 .5912 .39807 .58549 .39137 Mtetra
.58549 .39137 .5912 .39807 .60229 .39445 .59661 .38772 Mtetra
.59661 .38772 .60229 .39445 .61342 .39081 .60778 .38405 Mtetra
.60778 .38405 .61342 .39081 .6246 .38715 .61899 .38037 Mtetra
.61899 .38037 .6246 .38715 .63583 .38348 .63025 .37667 Mtetra
.63025 .37667 .63583 .38348 .6471 .3798 .64155 .37296 Mtetra
.64155 .37296 .6471 .3798 .65841 .3761 .65289 .36923 Mtetra
.65289 .36923 .65841 .3761 .66977 .37238 .66429 .36549 Mtetra
.66429 .36549 .66977 .37238 .68118 .36866 .67572 .36173 Mtetra
.67572 .36173 .68118 .36866 .69263 .36491 .68721 .35796 Mtetra
.68721 .35796 .69263 .36491 .70413 .36115 .69874 .35417 Mtetra
.69874 .35417 .70413 .36115 .71568 .35738 .71032 .35037 Mtetra
.71032 .35037 .71568 .35738 .72727 .35359 .72195 .34655 Mtetra
.72195 .34655 .72727 .35359 .73892 .34978 .73362 .34271 Mtetra
.73362 .34271 .73892 .34978 .7506 .34596 .74534 .33886 Mtetra
.74534 .33886 .7506 .34596 .76234 .34212 .75711 .335 Mtetra
.75711 .335 .76234 .34212 .77412 .33827 .76893 .33112 Mtetra
.76893 .33112 .77412 .33827 .78596 .3344 .7808 .32722 Mtetra
.7808 .32722 .78596 .3344 .79784 .33052 .79272 .3233 Mtetra
.79272 .3233 .79784 .33052 .80977 .32662 .80468 .31937 Mtetra
.80468 .31937 .80977 .32662 .82175 .3227 .8167 .31543 Mtetra
.8167 .31543 .82175 .3227 .83378 .31877 .82876 .31146 Mtetra
.18679 .51429 .19348 .52013 .20308 .51697 .19642 .51112 Mtetra
.19642 .51112 .20308 .51697 .21272 .51381 .20608 .50793 Mtetra
.20608 .50793 .21272 .51381 .2224 .51063 .21578 .50473 Mtetra
.21578 .50473 .2224 .51063 .23212 .50744 .22552 .50151 Mtetra
.22552 .50151 .23212 .50744 .24187 .50423 .23529 .49829 Mtetra
.23529 .49829 .24187 .50423 .25166 .50102 .2451 .49505 Mtetra
.2451 .49505 .25166 .50102 .26148 .49779 .25494 .4918 Mtetra
.25494 .4918 .26148 .49779 .27134 .49455 .26483 .48854 Mtetra
.26483 .48854 .27134 .49455 .28124 .4913 .27475 .48527 Mtetra
.27475 .48527 .28124 .4913 .29118 .48804 .28471 .48198 Mtetra
.28471 .48198 .29118 .48804 .30115 .48476 .2947 .47868 Mtetra
.2947 .47868 .30115 .48476 .31116 .48147 .30474 .47537 Mtetra
.30474 .47537 .31116 .48147 .32121 .47817 .31481 .47205 Mtetra
.31481 .47205 .32121 .47817 .3313 .47486 .32492 .46871 Mtetra
.32492 .46871 .3313 .47486 .34143 .47153 .33507 .46536 Mtetra
.33507 .46536 .34143 .47153 .35159 .46819 .34526 .462 Mtetra
.34526 .462 .35159 .46819 .3618 .46484 .35549 .45862 Mtetra
.35549 .45862 .3618 .46484 .37204 .46148 .36576 .45523 Mtetra
.36576 .45523 .37204 .46148 .38232 .4581 .37607 .45183 Mtetra
.37607 .45183 .38232 .4581 .39264 .45471 .38641 .44842 Mtetra
.38641 .44842 .39264 .45471 .40301 .45131 .3968 .44499 Mtetra
.3968 .44499 .40301 .45131 .41341 .44789 .40723 .44155 Mtetra
.40723 .44155 .41341 .44789 .42385 .44446 .41769 .43809 Mtetra
.41769 .43809 .42385 .44446 .43434 .44102 .4282 .43462 Mtetra
.4282 .43462 .43434 .44102 .44486 .43756 .43875 .43114 Mtetra
.43875 .43114 .44486 .43756 .45542 .43409 .44934 .42765 Mtetra
.44934 .42765 .45542 .43409 .46603 .43061 .45998 .42414 Mtetra
.45998 .42414 .46603 .43061 .47668 .42711 .47065 .42062 Mtetra
.47065 .42062 .47668 .42711 .48737 .4236 .48137 .41708 Mtetra
.48137 .41708 .48737 .4236 .4981 .42007 .49213 .41353 Mtetra
.49213 .41353 .4981 .42007 .50887 .41653 .50293 .40996 Mtetra
.50293 .40996 .50887 .41653 .51969 .41298 .51377 .40639 Mtetra
.51377 .40639 .51969 .41298 .53055 .40941 .52466 .40279 Mtetra
.52466 .40279 .53055 .40941 .54145 .40583 .53559 .39919 Mtetra
.53559 .39919 .54145 .40583 .5524 .40224 .54656 .39556 Mtetra
.54656 .39556 .5524 .40224 .56338 .39863 .55758 .39193 Mtetra
.55758 .39193 .56338 .39863 .57442 .39501 .56864 .38828 Mtetra
.56864 .38828 .57442 .39501 .58549 .39137 .57975 .38461 Mtetra
.57975 .38461 .58549 .39137 .59661 .38772 .5909 .38093 Mtetra
.5909 .38093 .59661 .38772 .60778 .38405 .6021 .37724 Mtetra
.6021 .37724 .60778 .38405 .61899 .38037 .61334 .37353 Mtetra
.61334 .37353 .61899 .38037 .63025 .37667 .62462 .3698 Mtetra
.62462 .3698 .63025 .37667 .64155 .37296 .63595 .36606 Mtetra
.63595 .36606 .64155 .37296 .65289 .36923 .64733 .36231 Mtetra
.64733 .36231 .65289 .36923 .66429 .36549 .65875 .35854 Mtetra
.65875 .35854 .66429 .36549 .67572 .36173 .67023 .35475 Mtetra
.67023 .35475 .67572 .36173 .68721 .35796 .68174 .35095 Mtetra
.68174 .35095 .68721 .35796 .69874 .35417 .69331 .34714 Mtetra
.69331 .34714 .69874 .35417 .71032 .35037 .70492 .34331 Mtetra
.70492 .34331 .71032 .35037 .72195 .34655 .71658 .33946 Mtetra
.71658 .33946 .72195 .34655 .73362 .34271 .72829 .33559 Mtetra
.72829 .33559 .73362 .34271 .74534 .33886 .74004 .33171 Mtetra
.74004 .33171 .74534 .33886 .75711 .335 .75184 .32782 Mtetra
.75184 .32782 .75711 .335 .76893 .33112 .7637 .32391 Mtetra
.7637 .32391 .76893 .33112 .7808 .32722 .7756 .31998 Mtetra
.7756 .31998 .7808 .32722 .79272 .3233 .78755 .31604 Mtetra
.78755 .31604 .79272 .3233 .80468 .31937 .79955 .31208 Mtetra
.79955 .31208 .80468 .31937 .8167 .31543 .8116 .3081 Mtetra
.8116 .3081 .8167 .31543 .82876 .31146 .82371 .3041 Mtetra
.18006 .50842 .18679 .51429 .19642 .51112 .18971 .50522 Mtetra
.18971 .50522 .19642 .51112 .20608 .50793 .19939 .50201 Mtetra
.19939 .50201 .20608 .50793 .21578 .50473 .20911 .49879 Mtetra
.20911 .49879 .21578 .50473 .22552 .50151 .21887 .49555 Mtetra
.21887 .49555 .22552 .50151 .23529 .49829 .22866 .4923 Mtetra
.22866 .4923 .23529 .49829 .2451 .49505 .23849 .48904 Mtetra
.23849 .48904 .2451 .49505 .25494 .4918 .24836 .48577 Mtetra
.24836 .48577 .25494 .4918 .26483 .48854 .25827 .48249 Mtetra
.25827 .48249 .26483 .48854 .27475 .48527 .26821 .47919 Mtetra
.26821 .47919 .27475 .48527 .28471 .48198 .27819 .47588 Mtetra
.27819 .47588 .28471 .48198 .2947 .47868 .28821 .47256 Mtetra
.28821 .47256 .2947 .47868 .30474 .47537 .29827 .46922 Mtetra
.29827 .46922 .30474 .47537 .31481 .47205 .30837 .46587 Mtetra
.30837 .46587 .31481 .47205 .32492 .46871 .3185 .46251 Mtetra
.3185 .46251 .32492 .46871 .33507 .46536 .32867 .45914 Mtetra
.32867 .45914 .33507 .46536 .34526 .462 .33889 .45575 Mtetra
.33889 .45575 .34526 .462 .35549 .45862 .34914 .45235 Mtetra
.34914 .45235 .35549 .45862 .36576 .45523 .35943 .44894 Mtetra
.35943 .44894 .36576 .45523 .37607 .45183 .36976 .44552 Mtetra
.36976 .44552 .37607 .45183 .38641 .44842 .38013 .44208 Mtetra
.38013 .44208 .38641 .44842 .3968 .44499 .39055 .43862 Mtetra
.39055 .43862 .3968 .44499 .40723 .44155 .401 .43516 Mtetra
.401 .43516 .40723 .44155 .41769 .43809 .41149 .43168 Mtetra
.41149 .43168 .41769 .43809 .4282 .43462 .42203 .42819 Mtetra
.42203 .42819 .4282 .43462 .43875 .43114 .4326 .42468 Mtetra
.4326 .42468 .43875 .43114 .44934 .42765 .44322 .42116 Mtetra
.44322 .42116 .44934 .42765 .45998 .42414 .45388 .41762 Mtetra
.45388 .41762 .45998 .42414 .47065 .42062 .46458 .41408 Mtetra
.46458 .41408 .47065 .42062 .48137 .41708 .47533 .41051 Mtetra
.47533 .41051 .48137 .41708 .49213 .41353 .48611 .40694 Mtetra
.48611 .40694 .49213 .41353 .50293 .40996 .49694 .40335 Mtetra
.49694 .40335 .50293 .40996 .51377 .40639 .50781 .39974 Mtetra
.50781 .39974 .51377 .40639 .52466 .40279 .51873 .39612 Mtetra
.51873 .39612 .52466 .40279 .53559 .39919 .52969 .39249 Mtetra
.52969 .39249 .53559 .39919 .54656 .39556 .54069 .38884 Mtetra
.54069 .38884 .54656 .39556 .55758 .39193 .55174 .38518 Mtetra
.55174 .38518 .55758 .39193 .56864 .38828 .56283 .3815 Mtetra
.56283 .3815 .56864 .38828 .57975 .38461 .57396 .37781 Mtetra
.57396 .37781 .57975 .38461 .5909 .38093 .58514 .3741 Mtetra
.58514 .3741 .5909 .38093 .6021 .37724 .59637 .37038 Mtetra
.59637 .37038 .6021 .37724 .61334 .37353 .60764 .36664 Mtetra
.60764 .36664 .61334 .37353 .62462 .3698 .61896 .36289 Mtetra
.61896 .36289 .62462 .3698 .63595 .36606 .63032 .35912 Mtetra
.63032 .35912 .63595 .36606 .64733 .36231 .64173 .35534 Mtetra
.64173 .35534 .64733 .36231 .65875 .35854 .65318 .35154 Mtetra
.65318 .35154 .65875 .35854 .67023 .35475 .66469 .34773 Mtetra
.66469 .34773 .67023 .35475 .68174 .35095 .67623 .3439 Mtetra
.67623 .3439 .68174 .35095 .69331 .34714 .68783 .34005 Mtetra
.68783 .34005 .69331 .34714 .70492 .34331 .69948 .33619 Mtetra
.69948 .33619 .70492 .34331 .71658 .33946 .71117 .33231 Mtetra
.71117 .33231 .71658 .33946 .72829 .33559 .72291 .32842 Mtetra
.72291 .32842 .72829 .33559 .74004 .33171 .7347 .32451 Mtetra
.7347 .32451 .74004 .33171 .75184 .32782 .74654 .32059 Mtetra
.74654 .32059 .75184 .32782 .7637 .32391 .75842 .31664 Mtetra
.75842 .31664 .7637 .32391 .7756 .31998 .77036 .31269 Mtetra
.77036 .31269 .7756 .31998 .78755 .31604 .78235 .30871 Mtetra
.78235 .30871 .78755 .31604 .79955 .31208 .79438 .30472 Mtetra
.79438 .30472 .79955 .31208 .8116 .3081 .80647 .30071 Mtetra
.80647 .30071 .8116 .3081 .82371 .3041 .81861 .29669 Mtetra
.17328 .5025 .18006 .50842 .18971 .50522 .18295 .49928 Mtetra
.18295 .49928 .18971 .50522 .19939 .50201 .19266 .49605 Mtetra
.19266 .49605 .19939 .50201 .20911 .49879 .2024 .4928 Mtetra
.2024 .4928 .20911 .49879 .21887 .49555 .21218 .48955 Mtetra
.21218 .48955 .21887 .49555 .22866 .4923 .22199 .48627 Mtetra
.22199 .48627 .22866 .4923 .23849 .48904 .23184 .48299 Mtetra
.23184 .48299 .23849 .48904 .24836 .48577 .24173 .4797 Mtetra
.24173 .4797 .24836 .48577 .25827 .48249 .25166 .47639 Mtetra
.25166 .47639 .25827 .48249 .26821 .47919 .26163 .47307 Mtetra
.26163 .47307 .26821 .47919 .27819 .47588 .27163 .46974 Mtetra
.27163 .46974 .27819 .47588 .28821 .47256 .28167 .46639 Mtetra
.28167 .46639 .28821 .47256 .29827 .46922 .29175 .46303 Mtetra
.29175 .46303 .29827 .46922 .30837 .46587 .30187 .45966 Mtetra
.30187 .45966 .30837 .46587 .3185 .46251 .31203 .45628 Mtetra
.31203 .45628 .3185 .46251 .32867 .45914 .32223 .45288 Mtetra
.32223 .45288 .32867 .45914 .33889 .45575 .33247 .44947 Mtetra
.33247 .44947 .33889 .45575 .34914 .45235 .34274 .44604 Mtetra
.34274 .44604 .34914 .45235 .35943 .44894 .35306 .44261 Mtetra
.35306 .44261 .35943 .44894 .36976 .44552 .36342 .43916 Mtetra
.36342 .43916 .36976 .44552 .38013 .44208 .37381 .43569 Mtetra
.37381 .43569 .38013 .44208 .39055 .43862 .38425 .43222 Mtetra
.38425 .43222 .39055 .43862 .401 .43516 .39473 .42872 Mtetra
.39473 .42872 .401 .43516 .41149 .43168 .40525 .42522 Mtetra
.40525 .42522 .41149 .43168 .42203 .42819 .41581 .4217 Mtetra
.41581 .4217 .42203 .42819 .4326 .42468 .42641 .41817 Mtetra
.42641 .41817 .4326 .42468 .44322 .42116 .43705 .41462 Mtetra
.43705 .41462 .44322 .42116 .45388 .41762 .44774 .41106 Mtetra
.44774 .41106 .45388 .41762 .46458 .41408 .45847 .40749 Mtetra
.45847 .40749 .46458 .41408 .47533 .41051 .46924 .4039 Mtetra
.46924 .4039 .47533 .41051 .48611 .40694 .48005 .4003 Mtetra
.48005 .4003 .48611 .40694 .49694 .40335 .49091 .39668 Mtetra
.49091 .39668 .49694 .40335 .50781 .39974 .50181 .39305 Mtetra
.50181 .39305 .50781 .39974 .51873 .39612 .51275 .3894 Mtetra
.51275 .3894 .51873 .39612 .52969 .39249 .52374 .38574 Mtetra
.52374 .38574 .52969 .39249 .54069 .38884 .53477 .38207 Mtetra
.53477 .38207 .54069 .38884 .55174 .38518 .54585 .37838 Mtetra
.54585 .37838 .55174 .38518 .56283 .3815 .55697 .37467 Mtetra
.55697 .37467 .56283 .3815 .57396 .37781 .56813 .37095 Mtetra
.56813 .37095 .57396 .37781 .58514 .3741 .57934 .36722 Mtetra
.57934 .36722 .58514 .3741 .59637 .37038 .5906 .36347 Mtetra
.5906 .36347 .59637 .37038 .60764 .36664 .6019 .3597 Mtetra
.6019 .3597 .60764 .36664 .61896 .36289 .61325 .35592 Mtetra
.61325 .35592 .61896 .36289 .63032 .35912 .62464 .35213 Mtetra
.62464 .35213 .63032 .35912 .64173 .35534 .63608 .34831 Mtetra
.63608 .34831 .64173 .35534 .65318 .35154 .64757 .34449 Mtetra
.64757 .34449 .65318 .35154 .66469 .34773 .6591 .34064 Mtetra
.6591 .34064 .66469 .34773 .67623 .3439 .67069 .33678 Mtetra
.67069 .33678 .67623 .3439 .68783 .34005 .68231 .33291 Mtetra
.68231 .33291 .68783 .34005 .69948 .33619 .69399 .32902 Mtetra
.69399 .32902 .69948 .33619 .71117 .33231 .70572 .32511 Mtetra
.70572 .32511 .71117 .33231 .72291 .32842 .71749 .32119 Mtetra
.71749 .32119 .72291 .32842 .7347 .32451 .72932 .31725 Mtetra
.72932 .31725 .7347 .32451 .74654 .32059 .74119 .3133 Mtetra
.74119 .3133 .74654 .32059 .75842 .31664 .75311 .30932 Mtetra
.75311 .30932 .75842 .31664 .77036 .31269 .76508 .30533 Mtetra
.76508 .30533 .77036 .31269 .78235 .30871 .7771 .30133 Mtetra
.7771 .30133 .78235 .30871 .79438 .30472 .78918 .29731 Mtetra
.78918 .29731 .79438 .30472 .80647 .30071 .8013 .29327 Mtetra
.8013 .29327 .80647 .30071 .81861 .29669 .81347 .28921 Mtetra
.16646 .49655 .17328 .5025 .18295 .49928 .17615 .4933 Mtetra
.17615 .4933 .18295 .49928 .19266 .49605 .18587 .49005 Mtetra
.18587 .49005 .19266 .49605 .2024 .4928 .19564 .48678 Mtetra
.19564 .48678 .2024 .4928 .21218 .48955 .20544 .4835 Mtetra
.20544 .4835 .21218 .48955 .22199 .48627 .21527 .4802 Mtetra
.21527 .4802 .22199 .48627 .23184 .48299 .22515 .4769 Mtetra
.22515 .4769 .23184 .48299 .24173 .4797 .23506 .47358 Mtetra
.23506 .47358 .24173 .4797 .25166 .47639 .24501 .47025 Mtetra
.24501 .47025 .25166 .47639 .26163 .47307 .255 .46691 Mtetra
.255 .46691 .26163 .47307 .27163 .46974 .26502 .46355 Mtetra
.26502 .46355 .27163 .46974 .28167 .46639 .27509 .46018 Mtetra
.27509 .46018 .28167 .46639 .29175 .46303 .28519 .4568 Mtetra
.28519 .4568 .29175 .46303 .30187 .45966 .29534 .4534 Mtetra
.29534 .4534 .30187 .45966 .31203 .45628 .30552 .44999 Mtetra
.30552 .44999 .31203 .45628 .32223 .45288 .31574 .44657 Mtetra
.31574 .44657 .32223 .45288 .33247 .44947 .326 .44314 Mtetra
.326 .44314 .33247 .44947 .34274 .44604 .3363 .43969 Mtetra
.3363 .43969 .34274 .44604 .35306 .44261 .34664 .43623 Mtetra
.34664 .43623 .35306 .44261 .36342 .43916 .35702 .43275 Mtetra
.35702 .43275 .36342 .43916 .37381 .43569 .36744 .42926 Mtetra
.36744 .42926 .37381 .43569 .38425 .43222 .37791 .42576 Mtetra
.37791 .42576 .38425 .43222 .39473 .42872 .38841 .42224 Mtetra
.38841 .42224 .39473 .42872 .40525 .42522 .39896 .41871 Mtetra
.39896 .41871 .40525 .42522 .41581 .4217 .40954 .41517 Mtetra
.40954 .41517 .41581 .4217 .42641 .41817 .42017 .41161 Mtetra
.42017 .41161 .42641 .41817 .43705 .41462 .43084 .40804 Mtetra
.43084 .40804 .43705 .41462 .44774 .41106 .44155 .40445 Mtetra
.44155 .40445 .44774 .41106 .45847 .40749 .45231 .40085 Mtetra
.45231 .40085 .45847 .40749 .46924 .4039 .46311 .39724 Mtetra
.46311 .39724 .46924 .4039 .48005 .4003 .47395 .39361 Mtetra
.47395 .39361 .48005 .4003 .49091 .39668 .48483 .38996 Mtetra
.48483 .38996 .49091 .39668 .50181 .39305 .49576 .38631 Mtetra
.49576 .38631 .50181 .39305 .51275 .3894 .50673 .38263 Mtetra
.50673 .38263 .51275 .3894 .52374 .38574 .51775 .37895 Mtetra
.51775 .37895 .52374 .38574 .53477 .38207 .52881 .37524 Mtetra
.52881 .37524 .53477 .38207 .54585 .37838 .53991 .37153 Mtetra
.53991 .37153 .54585 .37838 .55697 .37467 .55106 .36779 Mtetra
.55106 .36779 .55697 .37467 .56813 .37095 .56226 .36404 Mtetra
.56226 .36404 .56813 .37095 .57934 .36722 .5735 .36028 Mtetra
.5735 .36028 .57934 .36722 .5906 .36347 .58479 .3565 Mtetra
.58479 .3565 .5906 .36347 .6019 .3597 .59612 .35271 Mtetra
.59612 .35271 .6019 .3597 .61325 .35592 .6075 .3489 Mtetra
.6075 .3489 .61325 .35592 .62464 .35213 .61892 .34508 Mtetra
.61892 .34508 .62464 .35213 .63608 .34831 .63039 .34124 Mtetra
.63039 .34124 .63608 .34831 .64757 .34449 .64191 .33738 Mtetra
.64191 .33738 .64757 .34449 .6591 .34064 .65348 .33351 Mtetra
.65348 .33351 .6591 .34064 .67069 .33678 .66509 .32962 Mtetra
.66509 .32962 .67069 .33678 .68231 .33291 .67676 .32572 Mtetra
.67676 .32572 .68231 .33291 .69399 .32902 .68847 .32179 Mtetra
.68847 .32179 .69399 .32902 .70572 .32511 .70023 .31786 Mtetra
.70023 .31786 .70572 .32511 .71749 .32119 .71203 .31391 Mtetra
.71203 .31391 .71749 .32119 .72932 .31725 .72389 .30994 Mtetra
.72389 .30994 .72932 .31725 .74119 .3133 .7358 .30595 Mtetra
.7358 .30595 .74119 .3133 .75311 .30932 .74775 .30195 Mtetra
.74775 .30195 .75311 .30932 .76508 .30533 .75976 .29793 Mtetra
.75976 .29793 .76508 .30533 .7771 .30133 .77182 .29389 Mtetra
.77182 .29389 .7771 .30133 .78918 .29731 .78393 .28984 Mtetra
.78393 .28984 .78918 .29731 .8013 .29327 .79609 .28577 Mtetra
.79609 .28577 .8013 .29327 .81347 .28921 .8083 .28168 Mtetra
.15958 .49055 .16646 .49655 .17615 .4933 .16929 .48728 Mtetra
.16929 .48728 .17615 .4933 .18587 .49005 .17904 .484 Mtetra
.17904 .484 .18587 .49005 .19564 .48678 .18883 .48071 Mtetra
.18883 .48071 .19564 .48678 .20544 .4835 .19865 .47741 Mtetra
.19865 .47741 .20544 .4835 .21527 .4802 .20851 .47409 Mtetra
.20851 .47409 .21527 .4802 .22515 .4769 .2184 .47076 Mtetra
.2184 .47076 .22515 .4769 .23506 .47358 .22834 .46742 Mtetra
.22834 .46742 .23506 .47358 .24501 .47025 .23831 .46407 Mtetra
.23831 .46407 .24501 .47025 .255 .46691 .24832 .4607 Mtetra
.24832 .4607 .255 .46691 .26502 .46355 .25837 .45732 Mtetra
.25837 .45732 .26502 .46355 .27509 .46018 .26846 .45393 Mtetra
.26846 .45393 .27509 .46018 .28519 .4568 .27858 .45052 Mtetra
.27858 .45052 .28519 .4568 .29534 .4534 .28875 .4471 Mtetra
.28875 .4471 .29534 .4534 .30552 .44999 .29896 .44367 Mtetra
.29896 .44367 .30552 .44999 .31574 .44657 .3092 .44022 Mtetra
.3092 .44022 .31574 .44657 .326 .44314 .31949 .43676 Mtetra
.31949 .43676 .326 .44314 .3363 .43969 .32981 .43329 Mtetra
.32981 .43329 .3363 .43969 .34664 .43623 .34018 .4298 Mtetra
.34018 .4298 .34664 .43623 .35702 .43275 .35058 .4263 Mtetra
.35058 .4263 .35702 .43275 .36744 .42926 .36103 .42279 Mtetra
.36103 .42279 .36744 .42926 .37791 .42576 .37152 .41926 Mtetra
.37152 .41926 .37791 .42576 .38841 .42224 .38205 .41572 Mtetra
.38205 .41572 .38841 .42224 .39896 .41871 .39262 .41216 Mtetra
.39262 .41216 .39896 .41871 .40954 .41517 .40323 .40859 Mtetra
.40323 .40859 .40954 .41517 .42017 .41161 .41389 .40501 Mtetra
.41389 .40501 .42017 .41161 .43084 .40804 .42458 .40141 Mtetra
.42458 .40141 .43084 .40804 .44155 .40445 .43532 .39779 Mtetra
.43532 .39779 .44155 .40445 .45231 .40085 .44611 .39417 Mtetra
.44611 .39417 .45231 .40085 .46311 .39724 .45693 .39053 Mtetra
.45693 .39053 .46311 .39724 .47395 .39361 .4678 .38687 Mtetra
.4678 .38687 .47395 .39361 .48483 .38996 .47871 .3832 Mtetra
.47871 .3832 .48483 .38996 .49576 .38631 .48967 .37951 Mtetra
.48967 .37951 .49576 .38631 .50673 .38263 .50067 .37581 Mtetra
.50067 .37581 .50673 .38263 .51775 .37895 .51171 .3721 Mtetra
.51171 .3721 .51775 .37895 .52881 .37524 .5228 .36837 Mtetra
.5228 .36837 .52881 .37524 .53991 .37153 .53394 .36462 Mtetra
.53394 .36462 .53991 .37153 .55106 .36779 .54512 .36086 Mtetra
.54512 .36086 .55106 .36779 .56226 .36404 .55634 .35709 Mtetra
.55634 .35709 .56226 .36404 .5735 .36028 .56761 .35329 Mtetra
.56761 .35329 .5735 .36028 .58479 .3565 .57893 .34949 Mtetra
.57893 .34949 .58479 .3565 .59612 .35271 .59029 .34567 Mtetra
.59029 .34567 .59612 .35271 .6075 .3489 .6017 .34183 Mtetra
.6017 .34183 .6075 .3489 .61892 .34508 .61316 .33797 Mtetra
.61316 .33797 .61892 .34508 .63039 .34124 .62466 .3341 Mtetra
.62466 .3341 .63039 .34124 .64191 .33738 .63621 .33022 Mtetra
.63621 .33022 .64191 .33738 .65348 .33351 .64781 .32632 Mtetra
.64781 .32632 .65348 .33351 .66509 .32962 .65946 .3224 Mtetra
.65946 .3224 .66509 .32962 .67676 .32572 .67115 .31846 Mtetra
.67115 .31846 .67676 .32572 .68847 .32179 .6829 .31451 Mtetra
.6829 .31451 .68847 .32179 .70023 .31786 .69469 .31055 Mtetra
.69469 .31055 .70023 .31786 .71203 .31391 .70653 .30656 Mtetra
.70653 .30656 .71203 .31391 .72389 .30994 .71842 .30256 Mtetra
.71842 .30256 .72389 .30994 .7358 .30595 .73037 .29855 Mtetra
.73037 .29855 .7358 .30595 .74775 .30195 .74236 .29451 Mtetra
.74236 .29451 .74775 .30195 .75976 .29793 .7544 .29046 Mtetra
.7544 .29046 .75976 .29793 .77182 .29389 .76649 .28639 Mtetra
.76649 .28639 .77182 .29389 .78393 .28984 .77864 .28231 Mtetra
.77864 .28231 .78393 .28984 .79609 .28577 .79083 .27821 Mtetra
.79083 .27821 .79609 .28577 .8083 .28168 .80308 .27409 Mtetra
.15266 .48451 .15958 .49055 .16929 .48728 .16239 .48122 Mtetra
.16239 .48122 .16929 .48728 .17904 .484 .17216 .47792 Mtetra
.17216 .47792 .17904 .484 .18883 .48071 .18197 .4746 Mtetra
.18197 .4746 .18883 .48071 .19865 .47741 .19181 .47128 Mtetra
.19181 .47128 .19865 .47741 .20851 .47409 .20169 .46794 Mtetra
.20169 .46794 .20851 .47409 .2184 .47076 .21161 .46458 Mtetra
.21161 .46458 .2184 .47076 .22834 .46742 .22157 .46122 Mtetra
.22157 .46122 .22834 .46742 .23831 .46407 .23156 .45784 Mtetra
.23156 .45784 .23831 .46407 .24832 .4607 .2416 .45445 Mtetra
.2416 .45445 .24832 .4607 .25837 .45732 .25167 .45104 Mtetra
.25167 .45104 .25837 .45732 .26846 .45393 .26178 .44763 Mtetra
.26178 .44763 .26846 .45393 .27858 .45052 .27193 .4442 Mtetra
.27193 .4442 .27858 .45052 .28875 .4471 .28212 .44075 Mtetra
.28212 .44075 .28875 .4471 .29896 .44367 .29235 .43729 Mtetra
.29235 .43729 .29896 .44367 .3092 .44022 .30262 .43382 Mtetra
.30262 .43382 .3092 .44022 .31949 .43676 .31293 .43034 Mtetra
.31293 .43034 .31949 .43676 .32981 .43329 .32328 .42684 Mtetra
.32328 .42684 .32981 .43329 .34018 .4298 .33367 .42333 Mtetra
.33367 .42333 .34018 .4298 .35058 .4263 .3441 .4198 Mtetra
.3441 .4198 .35058 .4263 .36103 .42279 .35457 .41626 Mtetra
.35457 .41626 .36103 .42279 .37152 .41926 .36508 .41271 Mtetra
.36508 .41271 .37152 .41926 .38205 .41572 .37564 .40914 Mtetra
.37564 .40914 .38205 .41572 .39262 .41216 .38623 .40556 Mtetra
.38623 .40556 .39262 .41216 .40323 .40859 .39687 .40196 Mtetra
.39687 .40196 .40323 .40859 .41389 .40501 .40756 .39835 Mtetra
.40756 .39835 .41389 .40501 .42458 .40141 .41828 .39473 Mtetra
.41828 .39473 .42458 .40141 .43532 .39779 .42905 .39109 Mtetra
.42905 .39109 .43532 .39779 .44611 .39417 .43986 .38743 Mtetra
.43986 .38743 .44611 .39417 .45693 .39053 .45071 .38376 Mtetra
.45071 .38376 .45693 .39053 .4678 .38687 .4616 .38008 Mtetra
.4616 .38008 .4678 .38687 .47871 .3832 .47255 .37638 Mtetra
.47255 .37638 .47871 .3832 .48967 .37951 .48353 .37267 Mtetra
.48353 .37267 .48967 .37951 .50067 .37581 .49456 .36894 Mtetra
.49456 .36894 .50067 .37581 .51171 .3721 .50563 .3652 Mtetra
.50563 .3652 .51171 .3721 .5228 .36837 .51675 .36144 Mtetra
.51675 .36144 .5228 .36837 .53394 .36462 .52791 .35767 Mtetra
.52791 .35767 .53394 .36462 .54512 .36086 .53912 .35388 Mtetra
.53912 .35388 .54512 .36086 .55634 .35709 .55038 .35007 Mtetra
.55038 .35007 .55634 .35709 .56761 .35329 .56168 .34625 Mtetra
.56168 .34625 .56761 .35329 .57893 .34949 .57303 .34242 Mtetra
.57303 .34242 .57893 .34949 .59029 .34567 .58442 .33857 Mtetra
.58442 .33857 .59029 .34567 .6017 .34183 .59586 .3347 Mtetra
.59586 .3347 .6017 .34183 .61316 .33797 .60735 .33082 Mtetra
.60735 .33082 .61316 .33797 .62466 .3341 .61889 .32692 Mtetra
.61889 .32692 .62466 .3341 .63621 .33022 .63047 .323 Mtetra
.63047 .323 .63621 .33022 .64781 .32632 .6421 .31907 Mtetra
.6421 .31907 .64781 .32632 .65946 .3224 .65378 .31512 Mtetra
.65378 .31512 .65946 .3224 .67115 .31846 .66551 .31116 Mtetra
.66551 .31116 .67115 .31846 .6829 .31451 .67729 .30718 Mtetra
.67729 .30718 .6829 .31451 .69469 .31055 .68911 .30318 Mtetra
.68911 .30318 .69469 .31055 .70653 .30656 .70099 .29917 Mtetra
.70099 .29917 .70653 .30656 .71842 .30256 .71292 .29513 Mtetra
.71292 .29513 .71842 .30256 .73037 .29855 .72489 .29109 Mtetra
.72489 .29109 .73037 .29855 .74236 .29451 .73692 .28702 Mtetra
.73692 .28702 .74236 .29451 .7544 .29046 .749 .28294 Mtetra
.749 .28294 .7544 .29046 .76649 .28639 .76113 .27884 Mtetra
.76113 .27884 .76649 .28639 .77864 .28231 .77331 .27472 Mtetra
.77331 .27472 .77864 .28231 .79083 .27821 .78554 .27059 Mtetra
.78554 .27059 .79083 .27821 .80308 .27409 .79782 .26643 Mtetra
.14569 .47843 .15266 .48451 .16239 .48122 .15545 .47511 Mtetra
.15545 .47511 .16239 .48122 .17216 .47792 .16524 .47179 Mtetra
.16524 .47179 .17216 .47792 .18197 .4746 .17506 .46845 Mtetra
.17506 .46845 .18197 .4746 .19181 .47128 .18493 .4651 Mtetra
.18493 .4651 .19181 .47128 .20169 .46794 .19483 .46174 Mtetra
.19483 .46174 .20169 .46794 .21161 .46458 .20477 .45836 Mtetra
.20477 .45836 .21161 .46458 .22157 .46122 .21475 .45497 Mtetra
.21475 .45497 .22157 .46122 .23156 .45784 .22477 .45157 Mtetra
.22477 .45157 .23156 .45784 .2416 .45445 .23482 .44815 Mtetra
.23482 .44815 .2416 .45445 .25167 .45104 .24492 .44472 Mtetra
.24492 .44472 .25167 .45104 .26178 .44763 .25505 .44128 Mtetra
.25505 .44128 .26178 .44763 .27193 .4442 .26523 .43783 Mtetra
.26523 .43783 .27193 .4442 .28212 .44075 .27544 .43436 Mtetra
.27544 .43436 .28212 .44075 .29235 .43729 .28569 .43087 Mtetra
.28569 .43087 .29235 .43729 .30262 .43382 .29598 .42738 Mtetra
.29598 .42738 .30262 .43382 .31293 .43034 .30632 .42387 Mtetra
.30632 .42387 .31293 .43034 .32328 .42684 .31669 .42034 Mtetra
.31669 .42034 .32328 .42684 .33367 .42333 .32711 .41681 Mtetra
.32711 .41681 .33367 .42333 .3441 .4198 .33756 .41326 Mtetra
.33756 .41326 .3441 .4198 .35457 .41626 .34806 .40969 Mtetra
.34806 .40969 .35457 .41626 .36508 .41271 .3586 .40611 Mtetra
.3586 .40611 .36508 .41271 .37564 .40914 .36918 .40252 Mtetra
.36918 .40252 .37564 .40914 .38623 .40556 .3798 .39891 Mtetra
.3798 .39891 .38623 .40556 .39687 .40196 .39047 .39529 Mtetra
.39047 .39529 .39687 .40196 .40756 .39835 .40118 .39165 Mtetra
.40118 .39165 .40756 .39835 .41828 .39473 .41193 .388 Mtetra
.41193 .388 .41828 .39473 .42905 .39109 .42272 .38433 Mtetra
.42272 .38433 .42905 .39109 .43986 .38743 .43356 .38065 Mtetra
.43356 .38065 .43986 .38743 .45071 .38376 .44444 .37695 Mtetra
.44444 .37695 .45071 .38376 .4616 .38008 .45536 .37324 Mtetra
.45536 .37324 .4616 .38008 .47255 .37638 .46633 .36952 Mtetra
.46633 .36952 .47255 .37638 .48353 .37267 .47735 .36578 Mtetra
.47735 .36578 .48353 .37267 .49456 .36894 .4884 .36202 Mtetra
.4884 .36202 .49456 .36894 .50563 .3652 .49951 .35825 Mtetra
.49951 .35825 .50563 .3652 .51675 .36144 .51065 .35446 Mtetra
.51065 .35446 .51675 .36144 .52791 .35767 .52185 .35066 Mtetra
.52185 .35066 .52791 .35767 .53912 .35388 .53309 .34684 Mtetra
.53309 .34684 .53912 .35388 .55038 .35007 .54437 .34301 Mtetra
.54437 .34301 .55038 .35007 .56168 .34625 .5557 .33916 Mtetra
.5557 .33916 .56168 .34625 .57303 .34242 .56708 .3353 Mtetra
.56708 .3353 .57303 .34242 .58442 .33857 .57851 .33142 Mtetra
.57851 .33142 .58442 .33857 .59586 .3347 .58998 .32752 Mtetra
.58998 .32752 .59586 .3347 .60735 .33082 .6015 .32361 Mtetra
.6015 .32361 .60735 .33082 .61889 .32692 .61307 .31968 Mtetra
.61307 .31968 .61889 .32692 .63047 .323 .62468 .31573 Mtetra
.62468 .31573 .63047 .323 .6421 .31907 .63635 .31177 Mtetra
.63635 .31177 .6421 .31907 .65378 .31512 .64806 .30779 Mtetra
.64806 .30779 .65378 .31512 .66551 .31116 .65982 .3038 Mtetra
.65982 .3038 .66551 .31116 .67729 .30718 .67163 .29978 Mtetra
.67163 .29978 .67729 .30718 .68911 .30318 .68349 .29576 Mtetra
.68349 .29576 .68911 .30318 .70099 .29917 .6954 .29171 Mtetra
.6954 .29171 .70099 .29917 .71292 .29513 .70736 .28765 Mtetra
.70736 .28765 .71292 .29513 .72489 .29109 .71938 .28357 Mtetra
.71938 .28357 .72489 .29109 .73692 .28702 .73144 .27947 Mtetra
.73144 .27947 .73692 .28702 .749 .28294 .74355 .27536 Mtetra
.74355 .27536 .749 .28294 .76113 .27884 .75572 .27122 Mtetra
.75572 .27122 .76113 .27884 .77331 .27472 .76793 .26707 Mtetra
.76793 .26707 .77331 .27472 .78554 .27059 .7802 .26291 Mtetra
.7802 .26291 .78554 .27059 .79782 .26643 .79252 .25872 Mtetra
.13868 .4723 .14569 .47843 .15545 .47511 .14845 .46897 Mtetra
.14845 .46897 .15545 .47511 .16524 .47179 .15826 .46562 Mtetra
.15826 .46562 .16524 .47179 .17506 .46845 .16811 .46226 Mtetra
.16811 .46226 .17506 .46845 .18493 .4651 .17799 .45888 Mtetra
.17799 .45888 .18493 .4651 .19483 .46174 .18792 .45549 Mtetra
.18792 .45549 .19483 .46174 .20477 .45836 .19788 .45209 Mtetra
.19788 .45209 .20477 .45836 .21475 .45497 .20788 .44868 Mtetra
.20788 .44868 .21475 .45497 .22477 .45157 .21792 .44525 Mtetra
.21792 .44525 .22477 .45157 .23482 .44815 .228 .44181 Mtetra
.228 .44181 .23482 .44815 .24492 .44472 .23812 .43836 Mtetra
.23812 .43836 .24492 .44472 .25505 .44128 .24828 .43489 Mtetra
.24828 .43489 .25505 .44128 .26523 .43783 .25847 .43141 Mtetra
.25847 .43141 .26523 .43783 .27544 .43436 .26871 .42792 Mtetra
.26871 .42792 .27544 .43436 .28569 .43087 .27899 .42441 Mtetra
.27899 .42441 .28569 .43087 .29598 .42738 .2893 .42089 Mtetra
.2893 .42089 .29598 .42738 .30632 .42387 .29966 .41735 Mtetra
.29966 .41735 .30632 .42387 .31669 .42034 .31006 .4138 Mtetra
.31006 .4138 .31669 .42034 .32711 .41681 .3205 .41024 Mtetra
.3205 .41024 .32711 .41681 .33756 .41326 .33098 .40666 Mtetra
.33098 .40666 .33756 .41326 .34806 .40969 .34151 .40307 Mtetra
.34151 .40307 .34806 .40969 .3586 .40611 .35207 .39946 Mtetra
.35207 .39946 .3586 .40611 .36918 .40252 .36268 .39584 Mtetra
.36268 .39584 .36918 .40252 .3798 .39891 .37333 .39221 Mtetra
.37333 .39221 .3798 .39891 .39047 .39529 .38402 .38856 Mtetra
.38402 .38856 .39047 .39529 .40118 .39165 .39475 .3849 Mtetra
.39475 .3849 .40118 .39165 .41193 .388 .40553 .38122 Mtetra
.40553 .38122 .41193 .388 .42272 .38433 .41635 .37752 Mtetra
.41635 .37752 .42272 .38433 .43356 .38065 .42722 .37381 Mtetra
.42722 .37381 .43356 .38065 .44444 .37695 .43812 .37009 Mtetra
.43812 .37009 .44444 .37695 .45536 .37324 .44908 .36635 Mtetra
.44908 .36635 .45536 .37324 .46633 .36952 .46007 .3626 Mtetra
.46007 .3626 .46633 .36952 .47735 .36578 .47112 .35883 Mtetra
.47112 .35883 .47735 .36578 .4884 .36202 .4822 .35505 Mtetra
.4822 .35505 .4884 .36202 .49951 .35825 .49333 .35125 Mtetra
.49333 .35125 .49951 .35825 .51065 .35446 .50451 .34743 Mtetra
.50451 .34743 .51065 .35446 .52185 .35066 .51573 .3436 Mtetra
.51573 .3436 .52185 .35066 .53309 .34684 .527 .33975 Mtetra
.527 .33975 .53309 .34684 .54437 .34301 .53832 .33589 Mtetra
.53832 .33589 .54437 .34301 .5557 .33916 .54968 .33201 Mtetra
.54968 .33201 .5557 .33916 .56708 .3353 .56109 .32812 Mtetra
.56109 .32812 .56708 .3353 .57851 .33142 .57255 .32421 Mtetra
.57255 .32421 .57851 .33142 .58998 .32752 .58405 .32028 Mtetra
.58405 .32028 .58998 .32752 .6015 .32361 .5956 .31634 Mtetra
.5956 .31634 .6015 .32361 .61307 .31968 .6072 .31238 Mtetra
.6072 .31238 .61307 .31968 .62468 .31573 .61885 .3084 Mtetra
.61885 .3084 .62468 .31573 .63635 .31177 .63055 .30441 Mtetra
.63055 .30441 .63635 .31177 .64806 .30779 .64229 .3004 Mtetra
.64229 .3004 .64806 .30779 .65982 .3038 .65409 .29638 Mtetra
.65409 .29638 .65982 .3038 .67163 .29978 .66593 .29233 Mtetra
.66593 .29233 .67163 .29978 .68349 .29576 .67783 .28827 Mtetra
.67783 .28827 .68349 .29576 .6954 .29171 .68977 .2842 Mtetra
.68977 .2842 .6954 .29171 .70736 .28765 .70177 .2801 Mtetra
.70177 .2801 .70736 .28765 .71938 .28357 .71382 .27599 Mtetra
.71382 .27599 .71938 .28357 .73144 .27947 .72591 .27186 Mtetra
.72591 .27186 .73144 .27947 .74355 .27536 .73806 .26771 Mtetra
.73806 .26771 .74355 .27536 .75572 .27122 .75026 .26355 Mtetra
.75026 .26355 .75572 .27122 .76793 .26707 .76252 .25937 Mtetra
.76252 .25937 .76793 .26707 .7802 .26291 .77482 .25517 Mtetra
.77482 .25517 .7802 .26291 .79252 .25872 .78718 .25095 Mtetra
.13161 .46613 .13868 .4723 .14845 .46897 .1414 .46277 Mtetra
.1414 .46277 .14845 .46897 .15826 .46562 .15123 .4594 Mtetra
.15123 .4594 .15826 .46562 .16811 .46226 .1611 .45602 Mtetra
.1611 .45602 .16811 .46226 .17799 .45888 .17101 .45262 Mtetra
.17101 .45262 .17799 .45888 .18792 .45549 .18096 .44921 Mtetra
.18096 .44921 .18792 .45549 .19788 .45209 .19094 .44578 Mtetra
.19094 .44578 .19788 .45209 .20788 .44868 .20097 .44234 Mtetra
.20097 .44234 .20788 .44868 .21792 .44525 .21103 .43889 Mtetra
.21103 .43889 .21792 .44525 .228 .44181 .22113 .43543 Mtetra
.22113 .43543 .228 .44181 .23812 .43836 .23127 .43195 Mtetra
.23127 .43195 .23812 .43836 .24828 .43489 .24145 .42846 Mtetra
.24145 .42846 .24828 .43489 .25847 .43141 .25167 .42495 Mtetra
.25167 .42495 .25847 .43141 .26871 .42792 .26193 .42143 Mtetra
.26193 .42143 .26871 .42792 .27899 .42441 .27223 .4179 Mtetra
.27223 .4179 .27899 .42441 .2893 .42089 .28258 .41435 Mtetra
.28258 .41435 .2893 .42089 .29966 .41735 .29296 .41079 Mtetra
.29296 .41079 .29966 .41735 .31006 .4138 .30338 .40721 Mtetra
.30338 .40721 .31006 .4138 .3205 .41024 .31385 .40362 Mtetra
.31385 .40362 .3205 .41024 .33098 .40666 .32435 .40002 Mtetra
.32435 .40002 .33098 .40666 .34151 .40307 .3349 .3964 Mtetra
.3349 .3964 .34151 .40307 .35207 .39946 .34549 .39277 Mtetra
.34549 .39277 .35207 .39946 .36268 .39584 .35613 .38912 Mtetra
.35613 .38912 .36268 .39584 .37333 .39221 .3668 .38546 Mtetra
.3668 .38546 .37333 .39221 .38402 .38856 .37752 .38178 Mtetra
.37752 .38178 .38402 .38856 .39475 .3849 .38828 .37809 Mtetra
.38828 .37809 .39475 .3849 .40553 .38122 .39908 .37439 Mtetra
.39908 .37439 .40553 .38122 .41635 .37752 .40993 .37067 Mtetra
.40993 .37067 .41635 .37752 .42722 .37381 .42083 .36693 Mtetra
.42083 .36693 .42722 .37381 .43812 .37009 .43176 .36318 Mtetra
.43176 .36318 .43812 .37009 .44908 .36635 .44274 .35941 Mtetra
.44274 .35941 .44908 .36635 .46007 .3626 .45377 .35563 Mtetra
.45377 .35563 .46007 .3626 .47112 .35883 .46484 .35183 Mtetra
.46484 .35183 .47112 .35883 .4822 .35505 .47595 .34802 Mtetra
.47595 .34802 .4822 .35505 .49333 .35125 .48711 .34419 Mtetra
.48711 .34419 .49333 .35125 .50451 .34743 .49832 .34035 Mtetra
.49832 .34035 .50451 .34743 .51573 .3436 .50957 .33649 Mtetra
.50957 .33649 .51573 .3436 .527 .33975 .52087 .33261 Mtetra
.52087 .33261 .527 .33975 .53832 .33589 .53222 .32872 Mtetra
.53222 .32872 .53832 .33589 .54968 .33201 .54361 .32481 Mtetra
.54361 .32481 .54968 .33201 .56109 .32812 .55505 .32089 Mtetra
.55505 .32089 .56109 .32812 .57255 .32421 .56654 .31695 Mtetra
.56654 .31695 .57255 .32421 .58405 .32028 .57808 .31299 Mtetra
.57808 .31299 .58405 .32028 .5956 .31634 .58966 .30902 Mtetra
.58966 .30902 .5956 .31634 .6072 .31238 .60129 .30503 Mtetra
.60129 .30503 .6072 .31238 .61885 .3084 .61297 .30102 Mtetra
.61297 .30102 .61885 .3084 .63055 .30441 .6247 .297 Mtetra
.6247 .297 .63055 .30441 .64229 .3004 .63648 .29296 Mtetra
.63648 .29296 .64229 .3004 .65409 .29638 .64831 .2889 Mtetra
.64831 .2889 .65409 .29638 .66593 .29233 .66019 .28483 Mtetra
.66019 .28483 .66593 .29233 .67783 .28827 .67212 .28073 Mtetra
.67212 .28073 .67783 .28827 .68977 .2842 .6841 .27662 Mtetra
.6841 .27662 .68977 .2842 .70177 .2801 .69613 .2725 Mtetra
.69613 .2725 .70177 .2801 .71382 .27599 .70821 .26835 Mtetra
.70821 .26835 .71382 .27599 .72591 .27186 .72035 .26419 Mtetra
.72035 .26419 .72591 .27186 .73806 .26771 .73253 .26001 Mtetra
.73253 .26001 .73806 .26771 .75026 .26355 .74477 .25581 Mtetra
.74477 .25581 .75026 .26355 .76252 .25937 .75706 .2516 Mtetra
.75706 .2516 .76252 .25937 .77482 .25517 .7694 .24736 Mtetra
.7694 .24736 .77482 .25517 .78718 .25095 .7818 .24311 Mtetra
.12449 .45992 .13161 .46613 .1414 .46277 .13431 .45654 Mtetra
.13431 .45654 .1414 .46277 .15123 .4594 .14416 .45314 Mtetra
.14416 .45314 .15123 .4594 .1611 .45602 .15405 .44973 Mtetra
.15405 .44973 .1611 .45602 .17101 .45262 .16398 .44631 Mtetra
.16398 .44631 .17101 .45262 .18096 .44921 .17395 .44287 Mtetra
.17395 .44287 .18096 .44921 .19094 .44578 .18396 .43942 Mtetra
.18396 .43942 .19094 .44578 .20097 .44234 .194 .43596 Mtetra
.194 .43596 .20097 .44234 .21103 .43889 .20409 .43248 Mtetra
.20409 .43248 .21103 .43889 .22113 .43543 .21421 .42899 Mtetra
.21421 .42899 .22113 .43543 .23127 .43195 .22437 .42549 Mtetra
.22437 .42549 .23127 .43195 .24145 .42846 .23458 .42197 Mtetra
.23458 .42197 .24145 .42846 .25167 .42495 .24482 .41844 Mtetra
.24482 .41844 .25167 .42495 .26193 .42143 .25511 .4149 Mtetra
.25511 .4149 .26193 .42143 .27223 .4179 .26543 .41134 Mtetra
.26543 .41134 .27223 .4179 .28258 .41435 .2758 .40776 Mtetra
.2758 .40776 .28258 .41435 .29296 .41079 .28621 .40418 Mtetra
.28621 .40418 .29296 .41079 .30338 .40721 .29665 .40057 Mtetra
.29665 .40057 .30338 .40721 .31385 .40362 .30714 .39696 Mtetra
.30714 .39696 .31385 .40362 .32435 .40002 .31768 .39333 Mtetra
.31768 .39333 .32435 .40002 .3349 .3964 .32825 .38968 Mtetra
.32825 .38968 .3349 .3964 .34549 .39277 .33887 .38602 Mtetra
.33887 .38602 .34549 .39277 .35613 .38912 .34952 .38235 Mtetra
.34952 .38235 .35613 .38912 .3668 .38546 .36023 .37866 Mtetra
.36023 .37866 .3668 .38546 .37752 .38178 .37097 .37496 Mtetra
.37097 .37496 .37752 .38178 .38828 .37809 .38176 .37124 Mtetra
.38176 .37124 .38828 .37809 .39908 .37439 .39259 .3675 Mtetra
.39259 .3675 .39908 .37439 .40993 .37067 .40347 .36376 Mtetra
.40347 .36376 .40993 .37067 .42083 .36693 .41439 .35999 Mtetra
.41439 .35999 .42083 .36693 .43176 .36318 .42535 .35621 Mtetra
.42535 .35621 .43176 .36318 .44274 .35941 .43636 .35242 Mtetra
.43636 .35242 .44274 .35941 .45377 .35563 .44741 .34861 Mtetra
.44741 .34861 .45377 .35563 .46484 .35183 .45851 .34478 Mtetra
.45851 .34478 .46484 .35183 .47595 .34802 .46966 .34094 Mtetra
.46966 .34094 .47595 .34802 .48711 .34419 .48085 .33708 Mtetra
.48085 .33708 .48711 .34419 .49832 .34035 .49208 .33321 Mtetra
.49208 .33321 .49832 .34035 .50957 .33649 .50337 .32932 Mtetra
.50337 .32932 .50957 .33649 .52087 .33261 .5147 .32541 Mtetra
.5147 .32541 .52087 .33261 .53222 .32872 .52607 .32149 Mtetra
.52607 .32149 .53222 .32872 .54361 .32481 .5375 .31755 Mtetra
.5375 .31755 .54361 .32481 .55505 .32089 .54897 .3136 Mtetra
.54897 .3136 .55505 .32089 .56654 .31695 .56049 .30963 Mtetra
.56049 .30963 .56654 .31695 .57808 .31299 .57206 .30564 Mtetra
.57206 .30564 .57808 .31299 .58966 .30902 .58367 .30164 Mtetra
.58367 .30164 .58966 .30902 .60129 .30503 .59534 .29762 Mtetra
.59534 .29762 .60129 .30503 .61297 .30102 .60705 .29358 Mtetra
.60705 .29358 .61297 .30102 .6247 .297 .61881 .28952 Mtetra
.61881 .28952 .6247 .297 .63648 .29296 .63063 .28545 Mtetra
.63063 .28545 .63648 .29296 .64831 .2889 .64249 .28136 Mtetra
.64249 .28136 .64831 .2889 .66019 .28483 .6544 .27726 Mtetra
.6544 .27726 .66019 .28483 .67212 .28073 .66637 .27313 Mtetra
.66637 .27313 .67212 .28073 .6841 .27662 .67838 .26899 Mtetra
.67838 .26899 .6841 .27662 .69613 .2725 .69045 .26483 Mtetra
.69045 .26483 .69613 .2725 .70821 .26835 .70256 .26066 Mtetra
.70256 .26066 .70821 .26835 .72035 .26419 .71473 .25646 Mtetra
.71473 .25646 .72035 .26419 .73253 .26001 .72695 .25225 Mtetra
.72695 .25225 .73253 .26001 .74477 .25581 .73923 .24802 Mtetra
.73923 .24802 .74477 .25581 .75706 .2516 .75156 .24377 Mtetra
.75156 .24377 .75706 .2516 .7694 .24736 .76394 .2395 Mtetra
.76394 .2395 .7694 .24736 .7818 .24311 .77637 .23521 Mtetra
.11732 .45366 .12449 .45992 .13431 .45654 .12716 .45026 Mtetra
.12716 .45026 .13431 .45654 .14416 .45314 .13703 .44684 Mtetra
.13703 .44684 .14416 .45314 .15405 .44973 .14695 .4434 Mtetra
.14695 .4434 .15405 .44973 .16398 .44631 .1569 .43995 Mtetra
.1569 .43995 .16398 .44631 .17395 .44287 .16689 .43649 Mtetra
.16689 .43649 .17395 .44287 .18396 .43942 .17692 .43302 Mtetra
.17692 .43302 .18396 .43942 .194 .43596 .18699 .42953 Mtetra
.18699 .42953 .194 .43596 .20409 .43248 .19709 .42603 Mtetra
.19709 .42603 .20409 .43248 .21421 .42899 .20724 .42251 Mtetra
.20724 .42251 .21421 .42899 .22437 .42549 .21743 .41899 Mtetra
.21743 .41899 .22437 .42549 .23458 .42197 .22766 .41544 Mtetra
.22766 .41544 .23458 .42197 .24482 .41844 .23792 .41189 Mtetra
.23792 .41189 .24482 .41844 .25511 .4149 .24823 .40831 Mtetra
.24823 .40831 .25511 .4149 .26543 .41134 .25858 .40473 Mtetra
.25858 .40473 .26543 .41134 .2758 .40776 .26897 .40113 Mtetra
.26897 .40113 .2758 .40776 .28621 .40418 .2794 .39752 Mtetra
.2794 .39752 .28621 .40418 .29665 .40057 .28988 .39389 Mtetra
.28988 .39389 .29665 .40057 .30714 .39696 .30039 .39025 Mtetra
.30039 .39025 .30714 .39696 .31768 .39333 .31095 .38659 Mtetra
.31095 .38659 .31768 .39333 .32825 .38968 .32155 .38292 Mtetra
.32155 .38292 .32825 .38968 .33887 .38602 .33219 .37923 Mtetra
.33219 .37923 .33887 .38602 .34952 .38235 .34288 .37553 Mtetra
.34288 .37553 .34952 .38235 .36023 .37866 .3536 .37181 Mtetra
.3536 .37181 .36023 .37866 .37097 .37496 .36437 .36808 Mtetra
.36437 .36808 .37097 .37496 .38176 .37124 .37519 .36433 Mtetra
.37519 .36433 .38176 .37124 .39259 .3675 .38605 .36057 Mtetra
.38605 .36057 .39259 .3675 .40347 .36376 .39695 .35679 Mtetra
.39695 .35679 .40347 .36376 .41439 .35999 .4079 .353 Mtetra
.4079 .353 .41439 .35999 .42535 .35621 .41889 .34919 Mtetra
.41889 .34919 .42535 .35621 .43636 .35242 .42993 .34537 Mtetra
.42993 .34537 .43636 .35242 .44741 .34861 .44101 .34153 Mtetra
.44101 .34153 .44741 .34861 .45851 .34478 .45214 .33768 Mtetra
.45214 .33768 .45851 .34478 .46966 .34094 .46331 .33381 Mtetra
.46331 .33381 .46966 .34094 .48085 .33708 .47453 .32992 Mtetra
.47453 .32992 .48085 .33708 .49208 .33321 .4858 .32602 Mtetra
.4858 .32602 .49208 .33321 .50337 .32932 .49711 .3221 Mtetra
.49711 .3221 .50337 .32932 .5147 .32541 .50847 .31816 Mtetra
.50847 .31816 .5147 .32541 .52607 .32149 .51988 .31421 Mtetra
.51988 .31421 .52607 .32149 .5375 .31755 .53134 .31024 Mtetra
.53134 .31024 .5375 .31755 .54897 .3136 .54284 .30626 Mtetra
.54284 .30626 .54897 .3136 .56049 .30963 .55439 .30226 Mtetra
.55439 .30226 .56049 .30963 .57206 .30564 .56599 .29824 Mtetra
.56599 .29824 .57206 .30564 .58367 .30164 .57764 .2942 Mtetra
.57764 .2942 .58367 .30164 .59534 .29762 .58933 .29015 Mtetra
.58933 .29015 .59534 .29762 .60705 .29358 .60108 .28608 Mtetra
.60108 .28608 .60705 .29358 .61881 .28952 .61288 .28199 Mtetra
.61288 .28199 .61881 .28952 .63063 .28545 .62472 .27789 Mtetra
.62472 .27789 .63063 .28545 .64249 .28136 .63662 .27377 Mtetra
.63662 .27377 .64249 .28136 .6544 .27726 .64857 .26963 Mtetra
.64857 .26963 .6544 .27726 .66637 .27313 .66057 .26547 Mtetra
.66057 .26547 .66637 .27313 .67838 .26899 .67262 .2613 Mtetra
.67262 .2613 .67838 .26899 .69045 .26483 .68472 .25711 Mtetra
.68472 .25711 .69045 .26483 .70256 .26066 .69687 .2529 Mtetra
.69687 .2529 .70256 .26066 .71473 .25646 .70908 .24867 Mtetra
.70908 .24867 .71473 .25646 .72695 .25225 .72133 .24442 Mtetra
.72133 .24442 .72695 .25225 .73923 .24802 .73365 .24016 Mtetra
.73365 .24016 .73923 .24802 .75156 .24377 .74601 .23587 Mtetra
.74601 .23587 .75156 .24377 .76394 .2395 .75843 .23157 Mtetra
.75843 .23157 .76394 .2395 .77637 .23521 .7709 .22725 Mtetra
.1101 .44736 .11732 .45366 .12716 .45026 .11996 .44393 Mtetra
.11996 .44393 .12716 .45026 .13703 .44684 .12986 .44049 Mtetra
.12986 .44049 .13703 .44684 .14695 .4434 .13979 .43703 Mtetra
.13979 .43703 .14695 .4434 .1569 .43995 .14976 .43355 Mtetra
.14976 .43355 .1569 .43995 .16689 .43649 .15978 .43007 Mtetra
.15978 .43007 .16689 .43649 .17692 .43302 .16983 .42657 Mtetra
.16983 .42657 .17692 .43302 .18699 .42953 .17992 .42306 Mtetra
.17992 .42306 .18699 .42953 .19709 .42603 .19005 .41953 Mtetra
.19005 .41953 .19709 .42603 .20724 .42251 .20022 .41599 Mtetra
.20022 .41599 .20724 .42251 .21743 .41899 .21043 .41243 Mtetra
.21043 .41243 .21743 .41899 .22766 .41544 .22068 .40886 Mtetra
.22068 .40886 .22766 .41544 .23792 .41189 .23097 .40528 Mtetra
.23097 .40528 .23792 .41189 .24823 .40831 .24131 .40168 Mtetra
.24131 .40168 .24823 .40831 .25858 .40473 .25168 .39807 Mtetra
.25168 .39807 .25858 .40473 .26897 .40113 .26209 .39445 Mtetra
.26209 .39445 .26897 .40113 .2794 .39752 .27255 .39081 Mtetra
.27255 .39081 .2794 .39752 .28988 .39389 .28305 .38715 Mtetra
.28305 .38715 .28988 .39389 .30039 .39025 .29359 .38348 Mtetra
.29359 .38348 .30039 .39025 .31095 .38659 .30417 .3798 Mtetra
.30417 .3798 .31095 .38659 .32155 .38292 .3148 .3761 Mtetra
.3148 .3761 .32155 .38292 .33219 .37923 .32546 .37238 Mtetra
.32546 .37238 .33219 .37923 .34288 .37553 .33618 .36866 Mtetra
.33618 .36866 .34288 .37553 .3536 .37181 .34693 .36491 Mtetra
.34693 .36491 .3536 .37181 .36437 .36808 .35773 .36115 Mtetra
.35773 .36115 .36437 .36808 .37519 .36433 .36857 .35738 Mtetra
.36857 .35738 .37519 .36433 .38605 .36057 .37946 .35359 Mtetra
.37946 .35359 .38605 .36057 .39695 .35679 .39039 .34978 Mtetra
.39039 .34978 .39695 .35679 .4079 .353 .40136 .34596 Mtetra
.40136 .34596 .4079 .353 .41889 .34919 .41238 .34212 Mtetra
.41238 .34212 .41889 .34919 .42993 .34537 .42345 .33827 Mtetra
.42345 .33827 .42993 .34537 .44101 .34153 .43456 .3344 Mtetra
.43456 .3344 .44101 .34153 .45214 .33768 .44572 .33052 Mtetra
.44572 .33052 .45214 .33768 .46331 .33381 .45692 .32662 Mtetra
.45692 .32662 .46331 .33381 .47453 .32992 .46817 .3227 Mtetra
.46817 .3227 .47453 .32992 .4858 .32602 .47947 .31877 Mtetra
.47947 .31877 .4858 .32602 .49711 .3221 .49081 .31482 Mtetra
.49081 .31482 .49711 .3221 .50847 .31816 .5022 .31085 Mtetra
.5022 .31085 .50847 .31816 .51988 .31421 .51364 .30687 Mtetra
.51364 .30687 .51988 .31421 .53134 .31024 .52513 .30287 Mtetra
.52513 .30287 .53134 .31024 .54284 .30626 .53666 .29886 Mtetra
.53666 .29886 .54284 .30626 .55439 .30226 .54824 .29482 Mtetra
.54824 .29482 .55439 .30226 .56599 .29824 .55988 .29077 Mtetra
.55988 .29077 .56599 .29824 .57764 .2942 .57156 .28671 Mtetra
.57156 .28671 .57764 .2942 .58933 .29015 .58329 .28262 Mtetra
.58329 .28262 .58933 .29015 .60108 .28608 .59507 .27852 Mtetra
.59507 .27852 .60108 .28608 .61288 .28199 .6069 .2744 Mtetra
.6069 .2744 .61288 .28199 .62472 .27789 .61878 .27027 Mtetra
.61878 .27027 .62472 .27789 .63662 .27377 .63071 .26611 Mtetra
.63071 .26611 .63662 .27377 .64857 .26963 .64269 .26194 Mtetra
.64269 .26194 .64857 .26963 .66057 .26547 .65472 .25775 Mtetra
.65472 .25775 .66057 .26547 .67262 .2613 .66681 .25355 Mtetra
.66681 .25355 .67262 .2613 .68472 .25711 .67894 .24932 Mtetra
.67894 .24932 .68472 .25711 .69687 .2529 .69113 .24508 Mtetra
.69113 .24508 .69687 .2529 .70908 .24867 .70337 .24082 Mtetra
.70337 .24082 .70908 .24867 .72133 .24442 .71567 .23653 Mtetra
.71567 .23653 .72133 .24442 .73365 .24016 .72802 .23224 Mtetra
.72802 .23224 .73365 .24016 .74601 .23587 .74042 .22792 Mtetra
.74042 .22792 .74601 .23587 .75843 .23157 .75288 .22358 Mtetra
.75288 .22358 .75843 .23157 .7709 .22725 .76539 .21923 Mtetra
.10283 .44102 .1101 .44736 .11996 .44393 .11271 .43756 Mtetra
.11271 .43756 .11996 .44393 .12986 .44049 .12263 .43409 Mtetra
.12263 .43409 .12986 .44049 .13979 .43703 .13258 .43061 Mtetra
.13258 .43061 .13979 .43703 .14976 .43355 .14258 .42711 Mtetra
.14258 .42711 .14976 .43355 .15978 .43007 .15261 .4236 Mtetra
.15261 .4236 .15978 .43007 .16983 .42657 .16269 .42007 Mtetra
.16269 .42007 .16983 .42657 .17992 .42306 .1728 .41653 Mtetra
.1728 .41653 .17992 .42306 .19005 .41953 .18295 .41298 Mtetra
.18295 .41298 .19005 .41953 .20022 .41599 .19315 .40941 Mtetra
.19315 .40941 .20022 .41599 .21043 .41243 .20338 .40583 Mtetra
.20338 .40583 .21043 .41243 .22068 .40886 .21366 .40224 Mtetra
.21366 .40224 .22068 .40886 .23097 .40528 .22397 .39863 Mtetra
.22397 .39863 .23097 .40528 .24131 .40168 .23433 .39501 Mtetra
.23433 .39501 .24131 .40168 .25168 .39807 .24473 .39137 Mtetra
.24473 .39137 .25168 .39807 .26209 .39445 .25516 .38772 Mtetra
.25516 .38772 .26209 .39445 .27255 .39081 .26565 .38405 Mtetra
.26565 .38405 .27255 .39081 .28305 .38715 .27617 .38037 Mtetra
.27617 .38037 .28305 .38715 .29359 .38348 .28674 .37667 Mtetra
.28674 .37667 .29359 .38348 .30417 .3798 .29734 .37296 Mtetra
.29734 .37296 .30417 .3798 .3148 .3761 .30799 .36923 Mtetra
.30799 .36923 .3148 .3761 .32546 .37238 .31869 .36549 Mtetra
.31869 .36549 .32546 .37238 .33618 .36866 .32943 .36173 Mtetra
.32943 .36173 .33618 .36866 .34693 .36491 .34021 .35796 Mtetra
.34021 .35796 .34693 .36491 .35773 .36115 .35103 .35417 Mtetra
.35103 .35417 .35773 .36115 .36857 .35738 .3619 .35037 Mtetra
.3619 .35037 .36857 .35738 .37946 .35359 .37282 .34655 Mtetra
.37282 .34655 .37946 .35359 .39039 .34978 .38377 .34271 Mtetra
.38377 .34271 .39039 .34978 .40136 .34596 .39478 .33886 Mtetra
.39478 .33886 .40136 .34596 .41238 .34212 .40583 .335 Mtetra
.40583 .335 .41238 .34212 .42345 .33827 .41692 .33112 Mtetra
.41692 .33112 .42345 .33827 .43456 .3344 .42806 .32722 Mtetra
.42806 .32722 .43456 .3344 .44572 .33052 .43925 .3233 Mtetra
.43925 .3233 .44572 .33052 .45692 .32662 .45048 .31937 Mtetra
.45048 .31937 .45692 .32662 .46817 .3227 .46176 .31543 Mtetra
.46176 .31543 .46817 .3227 .47947 .31877 .47309 .31146 Mtetra
.47309 .31146 .47947 .31877 .49081 .31482 .48446 .30748 Mtetra
.48446 .30748 .49081 .31482 .5022 .31085 .49588 .30349 Mtetra
.49588 .30349 .5022 .31085 .51364 .30687 .50735 .29948 Mtetra
.50735 .29948 .51364 .30687 .52513 .30287 .51887 .29545 Mtetra
.51887 .29545 .52513 .30287 .53666 .29886 .53043 .2914 Mtetra
.53043 .2914 .53666 .29886 .54824 .29482 .54205 .28733 Mtetra
.54205 .28733 .54824 .29482 .55988 .29077 .55371 .28325 Mtetra
.55371 .28325 .55988 .29077 .57156 .28671 .56543 .27915 Mtetra
.56543 .27915 .57156 .28671 .58329 .28262 .57719 .27504 Mtetra
.57719 .27504 .58329 .28262 .59507 .27852 .589 .27091 Mtetra
.589 .27091 .59507 .27852 .6069 .2744 .60087 .26675 Mtetra
.60087 .26675 .6069 .2744 .61878 .27027 .61278 .26259 Mtetra
.61278 .26259 .61878 .27027 .63071 .26611 .62475 .2584 Mtetra
.62475 .2584 .63071 .26611 .64269 .26194 .63676 .25419 Mtetra
.63676 .25419 .64269 .26194 .65472 .25775 .64883 .24997 Mtetra
.64883 .24997 .65472 .25775 .66681 .25355 .66095 .24573 Mtetra
.66095 .24573 .66681 .25355 .67894 .24932 .67312 .24147 Mtetra
.67312 .24147 .67894 .24932 .69113 .24508 .68535 .23719 Mtetra
.68535 .23719 .69113 .24508 .70337 .24082 .69763 .2329 Mtetra
.69763 .2329 .70337 .24082 .71567 .23653 .70996 .22858 Mtetra
.70996 .22858 .71567 .23653 .72802 .23224 .72234 .22425 Mtetra
.72234 .22425 .72802 .23224 .74042 .22792 .73478 .2199 Mtetra
.73478 .2199 .74042 .22792 .75288 .22358 .74728 .21553 Mtetra
.74728 .21553 .75288 .22358 .76539 .21923 .75983 .21113 Mtetra
.09551 .43462 .10283 .44102 .11271 .43756 .10541 .43114 Mtetra
.10541 .43114 .11271 .43756 .12263 .43409 .11535 .42765 Mtetra
.11535 .42765 .12263 .43409 .13258 .43061 .12532 .42414 Mtetra
.12532 .42414 .13258 .43061 .14258 .42711 .13534 .42062 Mtetra
.13534 .42062 .14258 .42711 .15261 .4236 .1454 .41708 Mtetra
.1454 .41708 .15261 .4236 .16269 .42007 .15549 .41353 Mtetra
.15549 .41353 .16269 .42007 .1728 .41653 .16563 .40996 Mtetra
.16563 .40996 .1728 .41653 .18295 .41298 .17581 .40639 Mtetra
.17581 .40639 .18295 .41298 .19315 .40941 .18602 .40279 Mtetra
.18602 .40279 .19315 .40941 .20338 .40583 .19628 .39919 Mtetra
.19628 .39919 .20338 .40583 .21366 .40224 .20658 .39556 Mtetra
.20658 .39556 .21366 .40224 .22397 .39863 .21692 .39193 Mtetra
.21692 .39193 .22397 .39863 .23433 .39501 .2273 .38828 Mtetra
.2273 .38828 .23433 .39501 .24473 .39137 .23772 .38461 Mtetra
.23772 .38461 .24473 .39137 .25516 .38772 .24819 .38093 Mtetra
.24819 .38093 .25516 .38772 .26565 .38405 .25869 .37724 Mtetra
.25869 .37724 .26565 .38405 .27617 .38037 .26924 .37353 Mtetra
.26924 .37353 .27617 .38037 .28674 .37667 .27983 .3698 Mtetra
.27983 .3698 .28674 .37667 .29734 .37296 .29046 .36606 Mtetra
.29046 .36606 .29734 .37296 .30799 .36923 .30114 .36231 Mtetra
.30114 .36231 .30799 .36923 .31869 .36549 .31186 .35854 Mtetra
.31186 .35854 .31869 .36549 .32943 .36173 .32263 .35475 Mtetra
.32263 .35475 .32943 .36173 .34021 .35796 .33343 .35095 Mtetra
.33343 .35095 .34021 .35796 .35103 .35417 .34429 .34714 Mtetra
.34429 .34714 .35103 .35417 .3619 .35037 .35518 .34331 Mtetra
.35518 .34331 .3619 .35037 .37282 .34655 .36612 .33946 Mtetra
.36612 .33946 .37282 .34655 .38377 .34271 .37711 .33559 Mtetra
.37711 .33559 .38377 .34271 .39478 .33886 .38814 .33171 Mtetra
.38814 .33171 .39478 .33886 .40583 .335 .39922 .32782 Mtetra
.39922 .32782 .40583 .335 .41692 .33112 .41034 .32391 Mtetra
.41034 .32391 .41692 .33112 .42806 .32722 .42151 .31998 Mtetra
.42151 .31998 .42806 .32722 .43925 .3233 .43273 .31604 Mtetra
.43273 .31604 .43925 .3233 .45048 .31937 .44399 .31208 Mtetra
.44399 .31208 .45048 .31937 .46176 .31543 .4553 .3081 Mtetra
.4553 .3081 .46176 .31543 .47309 .31146 .46666 .3041 Mtetra
.46666 .3041 .47309 .31146 .48446 .30748 .47806 .30009 Mtetra
.47806 .30009 .48446 .30748 .49588 .30349 .48951 .29607 Mtetra
.48951 .29607 .49588 .30349 .50735 .29948 .50101 .29202 Mtetra
.50101 .29202 .50735 .29948 .51887 .29545 .51256 .28796 Mtetra
.51256 .28796 .51887 .29545 .53043 .2914 .52416 .28388 Mtetra
.52416 .28388 .53043 .2914 .54205 .28733 .53581 .27979 Mtetra
.53581 .27979 .54205 .28733 .55371 .28325 .5475 .27567 Mtetra
.5475 .27567 .55371 .28325 .56543 .27915 .55925 .27154 Mtetra
.55925 .27154 .56543 .27915 .57719 .27504 .57105 .26739 Mtetra
.57105 .26739 .57719 .27504 .589 .27091 .58289 .26323 Mtetra
.58289 .26323 .589 .27091 .60087 .26675 .59479 .25904 Mtetra
.59479 .25904 .60087 .26675 .61278 .26259 .60674 .25484 Mtetra
.60674 .25484 .61278 .26259 .62475 .2584 .61874 .25062 Mtetra
.61874 .25062 .62475 .2584 .63676 .25419 .63079 .24638 Mtetra
.63079 .24638 .63676 .25419 .64883 .24997 .64289 .24213 Mtetra
.64289 .24213 .64883 .24997 .66095 .24573 .65505 .23785 Mtetra
.65505 .23785 .66095 .24573 .67312 .24147 .66726 .23356 Mtetra
.66726 .23356 .67312 .24147 .68535 .23719 .67952 .22925 Mtetra
.67952 .22925 .68535 .23719 .69763 .2329 .69183 .22492 Mtetra
.69183 .22492 .69763 .2329 .70996 .22858 .7042 .22057 Mtetra
.7042 .22057 .70996 .22858 .72234 .22425 .71663 .2162 Mtetra
.71663 .2162 .72234 .22425 .73478 .2199 .7291 .21181 Mtetra
.7291 .21181 .73478 .2199 .74728 .21553 .74163 .2074 Mtetra
.74163 .2074 .74728 .21553 .75983 .21113 .75422 .20298 Mtetra
.08813 .42819 .09551 .43462 .10541 .43114 .09805 .42468 Mtetra
.09805 .42468 .10541 .43114 .11535 .42765 .10801 .42116 Mtetra
.10801 .42116 .11535 .42765 .12532 .42414 .11801 .41762 Mtetra
.11801 .41762 .12532 .42414 .13534 .42062 .12805 .41407 Mtetra
.12805 .41407 .13534 .42062 .1454 .41708 .13813 .41051 Mtetra
.13813 .41051 .1454 .41708 .15549 .41353 .14825 .40693 Mtetra
.14825 .40693 .15549 .41353 .16563 .40996 .15841 .40334 Mtetra
.15841 .40334 .16563 .40996 .17581 .40639 .16861 .39973 Mtetra
.16861 .39973 .17581 .40639 .18602 .40279 .17885 .39612 Mtetra
.17885 .39612 .18602 .40279 .19628 .39919 .18913 .39248 Mtetra
.18913 .39248 .19628 .39919 .20658 .39556 .19945 .38883 Mtetra
.19945 .38883 .20658 .39556 .21692 .39193 .20981 .38517 Mtetra
.20981 .38517 .21692 .39193 .2273 .38828 .22022 .38149 Mtetra
.22022 .38149 .2273 .38828 .23772 .38461 .23067 .3778 Mtetra
.23067 .3778 .23772 .38461 .24819 .38093 .24115 .37409 Mtetra
.24115 .37409 .24819 .38093 .25869 .37724 .25169 .37037 Mtetra
.25169 .37037 .25869 .37724 .26924 .37353 .26226 .36663 Mtetra
.26226 .36663 .26924 .37353 .27983 .3698 .27288 .36288 Mtetra
.27288 .36288 .27983 .3698 .29046 .36606 .28353 .35911 Mtetra
.28353 .35911 .29046 .36606 .30114 .36231 .29424 .35533 Mtetra
.29424 .35533 .30114 .36231 .31186 .35854 .30498 .35153 Mtetra
.30498 .35153 .31186 .35854 .32263 .35475 .31578 .34772 Mtetra
.31578 .34772 .32263 .35475 .33343 .35095 .32661 .34389 Mtetra
.32661 .34389 .33343 .35095 .34429 .34714 .33749 .34004 Mtetra
.33749 .34004 .34429 .34714 .35518 .34331 .34841 .33618 Mtetra
.34841 .33618 .35518 .34331 .36612 .33946 .35938 .3323 Mtetra
.35938 .3323 .36612 .33946 .37711 .33559 .3704 .32841 Mtetra
.3704 .32841 .37711 .33559 .38814 .33171 .38146 .3245 Mtetra
.38146 .3245 .38814 .33171 .39922 .32782 .39256 .32058 Mtetra
.39256 .32058 .39922 .32782 .41034 .32391 .40371 .31663 Mtetra
.40371 .31663 .41034 .32391 .42151 .31998 .41491 .31268 Mtetra
.41491 .31268 .42151 .31998 .43273 .31604 .42616 .3087 Mtetra
.42616 .3087 .43273 .31604 .44399 .31208 .43745 .30471 Mtetra
.43745 .30471 .44399 .31208 .4553 .3081 .44879 .3007 Mtetra
.44879 .3007 .4553 .3081 .46666 .3041 .46018 .29668 Mtetra
.46018 .29668 .46666 .3041 .47806 .30009 .47161 .29264 Mtetra
.47161 .29264 .47806 .30009 .48951 .29607 .48309 .28858 Mtetra
.48309 .28858 .48951 .29607 .50101 .29202 .49463 .2845 Mtetra
.49463 .2845 .50101 .29202 .51256 .28796 .50621 .28041 Mtetra
.50621 .28041 .51256 .28796 .52416 .28388 .51784 .2763 Mtetra
.51784 .2763 .52416 .28388 .53581 .27979 .52952 .27217 Mtetra
.52952 .27217 .53581 .27979 .5475 .27567 .54124 .26802 Mtetra
.54124 .26802 .5475 .27567 .55925 .27154 .55302 .26386 Mtetra
.55302 .26386 .55925 .27154 .57105 .26739 .56485 .25968 Mtetra
.56485 .25968 .57105 .26739 .58289 .26323 .57673 .25548 Mtetra
.57673 .25548 .58289 .26323 .59479 .25904 .58866 .25126 Mtetra
.58866 .25126 .59479 .25904 .60674 .25484 .60065 .24703 Mtetra
.60065 .24703 .60674 .25484 .61874 .25062 .61268 .24278 Mtetra
.61268 .24278 .61874 .25062 .63079 .24638 .62477 .2385 Mtetra
.62477 .2385 .63079 .24638 .64289 .24213 .63691 .23421 Mtetra
.63691 .23421 .64289 .24213 .65505 .23785 .6491 .22991 Mtetra
.6491 .22991 .65505 .23785 .66726 .23356 .66134 .22558 Mtetra
.66134 .22558 .66726 .23356 .67952 .22925 .67364 .22123 Mtetra
.67364 .22123 .67952 .22925 .69183 .22492 .68599 .21687 Mtetra
.68599 .21687 .69183 .22492 .7042 .22057 .6984 .21248 Mtetra
.6984 .21248 .7042 .22057 .71663 .2162 .71086 .20808 Mtetra
.71086 .20808 .71663 .2162 .7291 .21181 .72337 .20366 Mtetra
.72337 .20366 .7291 .21181 .74163 .2074 .73595 .19922 Mtetra
.73595 .19922 .74163 .2074 .75422 .20298 .74857 .19475 Mtetra
.0807 .4217 .08813 .42819 .09805 .42468 .09064 .41817 Mtetra
.09064 .41817 .09805 .42468 .10801 .42116 .10063 .41462 Mtetra
.10063 .41462 .10801 .42116 .11801 .41762 .11065 .41106 Mtetra
.11065 .41106 .11801 .41762 .12805 .41407 .12071 .40749 Mtetra
.12071 .40749 .12805 .41407 .13813 .41051 .13081 .4039 Mtetra
.656 .752 .92 r
.13081 .4039 .13813 .41051 .14825 .40693 .14095 .4003 Mtetra
.14095 .4003 .14825 .40693 .15841 .40334 .15113 .39668 Mtetra
.15113 .39668 .15841 .40334 .16861 .39973 .16136 .39305 Mtetra
.16136 .39305 .16861 .39973 .17885 .39612 .17162 .3894 Mtetra
.17162 .3894 .17885 .39612 .18913 .39248 .18192 .38574 Mtetra
.18192 .38574 .18913 .39248 .19945 .38883 .19227 .38206 Mtetra
.19227 .38206 .19945 .38883 .20981 .38517 .20266 .37837 Mtetra
.20266 .37837 .20981 .38517 .22022 .38149 .21308 .37467 Mtetra
.21308 .37467 .22022 .38149 .23067 .3778 .22356 .37095 Mtetra
.22356 .37095 .23067 .3778 .24115 .37409 .23407 .36721 Mtetra
.23407 .36721 .24115 .37409 .25169 .37037 .24463 .36346 Mtetra
.24463 .36346 .25169 .37037 .26226 .36663 .25522 .3597 Mtetra
.25522 .3597 .26226 .36663 .27288 .36288 .26587 .35592 Mtetra
.26587 .35592 .27288 .36288 .28353 .35911 .27655 .35212 Mtetra
.27655 .35212 .28353 .35911 .29424 .35533 .28728 .34831 Mtetra
.28728 .34831 .29424 .35533 .30498 .35153 .29805 .34448 Mtetra
.29805 .34448 .30498 .35153 .31578 .34772 .30887 .34064 Mtetra
.30887 .34064 .31578 .34772 .32661 .34389 .31973 .33678 Mtetra
.31973 .33678 .32661 .34389 .33749 .34004 .33064 .33291 Mtetra
.33064 .33291 .33749 .34004 .34841 .33618 .34159 .32902 Mtetra
.34159 .32902 .34841 .33618 .35938 .3323 .35259 .32511 Mtetra
.35259 .32511 .35938 .3323 .3704 .32841 .36363 .32119 Mtetra
.36363 .32119 .3704 .32841 .38146 .3245 .37472 .31725 Mtetra
.37472 .31725 .38146 .3245 .39256 .32058 .38585 .31329 Mtetra
.38585 .31329 .39256 .32058 .40371 .31663 .39703 .30932 Mtetra
.39703 .30932 .40371 .31663 .41491 .31268 .40826 .30533 Mtetra
.40826 .30533 .41491 .31268 .42616 .3087 .41954 .30133 Mtetra
.41954 .30133 .42616 .3087 .43745 .30471 .43086 .2973 Mtetra
.43086 .2973 .43745 .30471 .44879 .3007 .44223 .29327 Mtetra
.44223 .29327 .44879 .3007 .46018 .29668 .45365 .28921 Mtetra
.45365 .28921 .46018 .29668 .47161 .29264 .46511 .28514 Mtetra
.46511 .28514 .47161 .29264 .48309 .28858 .47663 .28105 Mtetra
.47663 .28105 .48309 .28858 .49463 .2845 .48819 .27694 Mtetra
.48819 .27694 .49463 .2845 .50621 .28041 .4998 .27281 Mtetra
.4998 .27281 .50621 .28041 .51784 .2763 .51146 .26867 Mtetra
.51146 .26867 .51784 .2763 .52952 .27217 .52317 .26451 Mtetra
.52317 .26451 .52952 .27217 .54124 .26802 .53494 .26033 Mtetra
.53494 .26033 .54124 .26802 .55302 .26386 .54675 .25613 Mtetra
.54675 .25613 .55302 .26386 .56485 .25968 .55861 .25192 Mtetra
.55861 .25192 .56485 .25968 .57673 .25548 .57053 .24769 Mtetra
.57053 .24769 .57673 .25548 .58866 .25126 .58249 .24344 Mtetra
.58249 .24344 .58866 .25126 .60065 .24703 .59451 .23917 Mtetra
.59451 .23917 .60065 .24703 .61268 .24278 .60658 .23488 Mtetra
.60658 .23488 .61268 .24278 .62477 .2385 .6187 .23057 Mtetra
.6187 .23057 .62477 .2385 .63691 .23421 .63087 .22625 Mtetra
.63087 .22625 .63691 .23421 .6491 .22991 .6431 .22191 Mtetra
.6431 .22191 .6491 .22991 .66134 .22558 .65538 .21754 Mtetra
.65538 .21754 .66134 .22558 .67364 .22123 .66772 .21316 Mtetra
.66772 .21316 .67364 .22123 .68599 .21687 .68011 .20876 Mtetra
.656 .751 .92 r
.68011 .20876 .68599 .21687 .6984 .21248 .69255 .20434 Mtetra
.69255 .20434 .6984 .21248 .71086 .20808 .70505 .1999 Mtetra
.70505 .1999 .71086 .20808 .72337 .20366 .7176 .19544 Mtetra
.7176 .19544 .72337 .20366 .73595 .19922 .73021 .19096 Mtetra
.73021 .19096 .73595 .19922 .74857 .19475 .74288 .18646 Mtetra
.656 .752 .92 r
.07322 .41517 .0807 .4217 .09064 .41817 .08318 .4116 Mtetra
.656 .751 .92 r
.08318 .4116 .09064 .41817 .10063 .41462 .09319 .40801 Mtetra
.656 .751 .919 r
.09319 .40801 .10063 .41462 .11065 .41106 .10323 .40441 Mtetra
.656 .75 .919 r
.10323 .40441 .11065 .41106 .12071 .40749 .11332 .40079 Mtetra
.11332 .40079 .12071 .40749 .13081 .4039 .12344 .39716 Mtetra
.656 .749 .918 r
.12344 .39716 .13081 .4039 .14095 .4003 .13361 .39352 Mtetra
.13361 .39352 .14095 .4003 .15113 .39668 .14382 .38987 Mtetra
.14382 .38987 .15113 .39668 .16136 .39305 .15406 .3862 Mtetra
.656 .748 .918 r
.15406 .3862 .16136 .39305 .17162 .3894 .16435 .38252 Mtetra
.656 .748 .917 r
.16435 .38252 .17162 .3894 .18192 .38574 .17468 .37882 Mtetra
.17468 .37882 .18192 .38574 .19227 .38206 .18505 .37511 Mtetra
.656 .747 .917 r
.18505 .37511 .19227 .38206 .20266 .37837 .19546 .37138 Mtetra
.19546 .37138 .20266 .37837 .21308 .37467 .20591 .36764 Mtetra
.20591 .36764 .21308 .37467 .22356 .37095 .21641 .36389 Mtetra
.21641 .36389 .22356 .37095 .23407 .36721 .22695 .36012 Mtetra
.656 .746 .917 r
.22695 .36012 .23407 .36721 .24463 .36346 .23753 .35634 Mtetra
.656 .746 .916 r
.23753 .35634 .24463 .36346 .25522 .3597 .24815 .35254 Mtetra
.24815 .35254 .25522 .3597 .26587 .35592 .25882 .34872 Mtetra
.25882 .34872 .26587 .35592 .27655 .35212 .26953 .3449 Mtetra
.26953 .3449 .27655 .35212 .28728 .34831 .28029 .34105 Mtetra
.28029 .34105 .28728 .34831 .29805 .34448 .29109 .33719 Mtetra
.29109 .33719 .29805 .34448 .30887 .34064 .30193 .33332 Mtetra
.30193 .33332 .30887 .34064 .31973 .33678 .31282 .32943 Mtetra
.31282 .32943 .31973 .33678 .33064 .33291 .32375 .32552 Mtetra
.32375 .32552 .33064 .33291 .34159 .32902 .33473 .3216 Mtetra
.656 .745 .916 r
.33473 .3216 .34159 .32902 .35259 .32511 .34575 .31766 Mtetra
.34575 .31766 .35259 .32511 .36363 .32119 .35682 .31371 Mtetra
.35682 .31371 .36363 .32119 .37472 .31725 .36794 .30974 Mtetra
.36794 .30974 .37472 .31725 .38585 .31329 .3791 .30575 Mtetra
.3791 .30575 .38585 .31329 .39703 .30932 .39031 .30175 Mtetra
.39031 .30175 .39703 .30932 .40826 .30533 .40157 .29773 Mtetra
.40157 .29773 .40826 .30533 .41954 .30133 .41287 .29369 Mtetra
.41287 .29369 .41954 .30133 .43086 .2973 .42422 .28964 Mtetra
.42422 .28964 .43086 .2973 .44223 .29327 .43562 .28557 Mtetra
.43562 .28557 .44223 .29327 .45365 .28921 .44707 .28148 Mtetra
.44707 .28148 .45365 .28921 .46511 .28514 .45856 .27738 Mtetra
.656 .746 .916 r
.45856 .27738 .46511 .28514 .47663 .28105 .47011 .27326 Mtetra
.47011 .27326 .47663 .28105 .48819 .27694 .4817 .26912 Mtetra
.4817 .26912 .48819 .27694 .4998 .27281 .49335 .26497 Mtetra
.49335 .26497 .4998 .27281 .51146 .26867 .50504 .26079 Mtetra
.50504 .26079 .51146 .26867 .52317 .26451 .51678 .2566 Mtetra
.51678 .2566 .52317 .26451 .53494 .26033 .52858 .2524 Mtetra
.52858 .2524 .53494 .26033 .54675 .25613 .54042 .24817 Mtetra
.656 .746 .917 r
.54042 .24817 .54675 .25613 .55861 .25192 .55232 .24393 Mtetra
.655 .746 .917 r
.55232 .24393 .55861 .25192 .57053 .24769 .56427 .23967 Mtetra
.655 .747 .917 r
.56427 .23967 .57053 .24769 .58249 .24344 .57626 .23539 Mtetra
.57626 .23539 .58249 .24344 .59451 .23917 .58832 .23109 Mtetra
.58832 .23109 .59451 .23917 .60658 .23488 .60042 .22678 Mtetra
.60042 .22678 .60658 .23488 .6187 .23057 .61258 .22245 Mtetra
.655 .747 .918 r
.61258 .22245 .6187 .23057 .63087 .22625 .62479 .2181 Mtetra
.655 .748 .918 r
.62479 .2181 .63087 .22625 .6431 .22191 .63705 .21373 Mtetra
.63705 .21373 .6431 .22191 .65538 .21754 .64937 .20934 Mtetra
.64937 .20934 .65538 .21754 .66772 .21316 .66174 .20493 Mtetra
.655 .749 .918 r
.66174 .20493 .66772 .21316 .68011 .20876 .67417 .20051 Mtetra
.655 .749 .919 r
.67417 .20051 .68011 .20876 .69255 .20434 .68665 .19607 Mtetra
.68665 .19607 .69255 .20434 .70505 .1999 .69918 .1916 Mtetra
.655 .75 .919 r
.69918 .1916 .70505 .1999 .7176 .19544 .71178 .18712 Mtetra
.655 .75 .92 r
.71178 .18712 .7176 .19544 .73021 .19096 .72443 .18262 Mtetra
.655 .751 .92 r
.72443 .18262 .73021 .19096 .74288 .18646 .73713 .1781 Mtetra
.655 .751 .921 r
.06568 .40859 .07322 .41517 .08318 .4116 .07566 .40502 Mtetra
.655 .752 .921 r
.07566 .40502 .08318 .4116 .09319 .40801 .08568 .40143 Mtetra
.655 .753 .922 r
.08568 .40143 .09319 .40801 .10323 .40441 .09575 .39783 Mtetra
.655 .754 .922 r
.09575 .39783 .10323 .40441 .11332 .40079 .10585 .39422 Mtetra
.655 .755 .923 r
.10585 .39422 .11332 .40079 .12344 .39716 .116 .39058 Mtetra
.656 .755 .923 r
.116 .39058 .12344 .39716 .13361 .39352 .12618 .38693 Mtetra
.656 .756 .924 r
.12618 .38693 .13361 .39352 .14382 .38987 .13641 .38327 Mtetra
.656 .757 .924 r
.13641 .38327 .14382 .38987 .15406 .3862 .14668 .37959 Mtetra
.14668 .37959 .15406 .3862 .16435 .38252 .15699 .37589 Mtetra
.656 .757 .925 r
.15699 .37589 .16435 .38252 .17468 .37882 .16734 .37218 Mtetra
.656 .758 .925 r
.16734 .37218 .17468 .37882 .18505 .37511 .17773 .36845 Mtetra
.17773 .36845 .18505 .37511 .19546 .37138 .18817 .3647 Mtetra
.18817 .3647 .19546 .37138 .20591 .36764 .19865 .36095 Mtetra
.656 .759 .926 r
.19865 .36095 .20591 .36764 .21641 .36389 .20917 .35717 Mtetra
.20917 .35717 .21641 .36389 .22695 .36012 .21973 .35338 Mtetra
.21973 .35338 .22695 .36012 .23753 .35634 .23034 .34957 Mtetra
.23034 .34957 .23753 .35634 .24815 .35254 .24099 .34575 Mtetra
.24099 .34575 .24815 .35254 .25882 .34872 .25168 .34191 Mtetra
.656 .76 .926 r
.25168 .34191 .25882 .34872 .26953 .3449 .26242 .33806 Mtetra
.26242 .33806 .26953 .3449 .28029 .34105 .2732 .33419 Mtetra
.2732 .33419 .28029 .34105 .29109 .33719 .28403 .3303 Mtetra
.28403 .3303 .29109 .33719 .30193 .33332 .2949 .3264 Mtetra
.2949 .3264 .30193 .33332 .31282 .32943 .30582 .32248 Mtetra
.30582 .32248 .31282 .32943 .32375 .32552 .31678 .31855 Mtetra
.31678 .31855 .32375 .32552 .33473 .3216 .32779 .31459 Mtetra
.32779 .31459 .33473 .3216 .34575 .31766 .33884 .31063 Mtetra
.33884 .31063 .34575 .31766 .35682 .31371 .34994 .30664 Mtetra
.34994 .30664 .35682 .31371 .36794 .30974 .36108 .30264 Mtetra
.36108 .30264 .36794 .30974 .3791 .30575 .37228 .29863 Mtetra
.37228 .29863 .3791 .30575 .39031 .30175 .38352 .29459 Mtetra
.38352 .29459 .39031 .30175 .40157 .29773 .3948 .29054 Mtetra
.3948 .29054 .40157 .29773 .41287 .29369 .40614 .28647 Mtetra
.40614 .28647 .41287 .29369 .42422 .28964 .41752 .28239 Mtetra
.41752 .28239 .42422 .28964 .43562 .28557 .42895 .27829 Mtetra
.42895 .27829 .43562 .28557 .44707 .28148 .44043 .27417 Mtetra
.44043 .27417 .44707 .28148 .45856 .27738 .45196 .27003 Mtetra
.45196 .27003 .45856 .27738 .47011 .27326 .46353 .26588 Mtetra
.46353 .26588 .47011 .27326 .4817 .26912 .47516 .2617 Mtetra
.47516 .2617 .4817 .26912 .49335 .26497 .48684 .25751 Mtetra
.48684 .25751 .49335 .26497 .50504 .26079 .49856 .25331 Mtetra
.49856 .25331 .50504 .26079 .51678 .2566 .51034 .24908 Mtetra
.51034 .24908 .51678 .2566 .52858 .2524 .52217 .24484 Mtetra
.656 .759 .926 r
.52217 .24484 .52858 .2524 .54042 .24817 .53405 .24057 Mtetra
.53405 .24057 .54042 .24817 .55232 .24393 .54598 .23629 Mtetra
.54598 .23629 .55232 .24393 .56427 .23967 .55796 .23199 Mtetra
.55796 .23199 .56427 .23967 .57626 .23539 .57 .22767 Mtetra
.57 .22767 .57626 .23539 .58832 .23109 .58208 .22333 Mtetra
.656 .759 .925 r
.58208 .22333 .58832 .23109 .60042 .22678 .59422 .21897 Mtetra
.656 .758 .925 r
.59422 .21897 .60042 .22678 .61258 .22245 .60642 .21459 Mtetra
.60642 .21459 .61258 .22245 .62479 .2181 .61866 .2102 Mtetra
.61866 .2102 .62479 .2181 .63705 .21373 .63096 .20578 Mtetra
.656 .757 .924 r
.63096 .20578 .63705 .21373 .64937 .20934 .64332 .20134 Mtetra
.64332 .20134 .64937 .20934 .66174 .20493 .65572 .19688 Mtetra
.656 .756 .924 r
.65572 .19688 .66174 .20493 .67417 .20051 .66819 .1924 Mtetra
.656 .756 .923 r
.66819 .1924 .67417 .20051 .68665 .19607 .68071 .1879 Mtetra
.656 .755 .923 r
.68071 .1879 .68665 .19607 .69918 .1916 .69328 .18338 Mtetra
.656 .754 .922 r
.69328 .18338 .69918 .1916 .71178 .18712 .70591 .17883 Mtetra
.656 .753 .921 r
.70591 .17883 .71178 .18712 .72443 .18262 .7186 .17427 Mtetra
.7186 .17427 .72443 .18262 .73713 .1781 .73134 .16968 Mtetra
.651 .75 .922 r
.05808 .40196 .06568 .40859 .07566 .40502 .06808 .39846 Mtetra
.652 .753 .924 r
.06808 .39846 .07566 .40502 .08568 .40143 .07811 .39492 Mtetra
.653 .756 .925 r
.07811 .39492 .08568 .40143 .09575 .39783 .08819 .39136 Mtetra
.653 .758 .927 r
.08819 .39136 .09575 .39783 .10585 .39422 .09831 .38778 Mtetra
.653 .76 .928 r
.09831 .38778 .10585 .39422 .116 .39058 .10847 .38417 Mtetra
.654 .762 .929 r
.10847 .38417 .116 .39058 .12618 .38693 .11867 .38053 Mtetra
.654 .763 .93 r
.11867 .38053 .12618 .38693 .13641 .38327 .12892 .37687 Mtetra
.654 .764 .93 r
.12892 .37687 .13641 .38327 .14668 .37959 .13921 .37319 Mtetra
.655 .765 .931 r
.13921 .37319 .14668 .37959 .15699 .37589 .14954 .36949 Mtetra
.655 .766 .931 r
.14954 .36949 .15699 .37589 .16734 .37218 .15992 .36576 Mtetra
.655 .767 .931 r
.15992 .36576 .16734 .37218 .17773 .36845 .17034 .36202 Mtetra
.17034 .36202 .17773 .36845 .18817 .3647 .1808 .35825 Mtetra
.656 .767 .932 r
.1808 .35825 .18817 .3647 .19865 .36095 .1913 .35447 Mtetra
.1913 .35447 .19865 .36095 .20917 .35717 .20185 .35066 Mtetra
.656 .767 .931 r
.20185 .35066 .20917 .35717 .21973 .35338 .21244 .34684 Mtetra
.21244 .34684 .21973 .35338 .23034 .34957 .22307 .343 Mtetra
.22307 .343 .23034 .34957 .24099 .34575 .23375 .33914 Mtetra
.23375 .33914 .24099 .34575 .25168 .34191 .24447 .33526 Mtetra
.24447 .33526 .25168 .34191 .26242 .33806 .25524 .33137 Mtetra
.656 .766 .931 r
.25524 .33137 .26242 .33806 .2732 .33419 .26605 .32746 Mtetra
.656 .766 .93 r
.26605 .32746 .2732 .33419 .28403 .3303 .2769 .32354 Mtetra
.2769 .32354 .28403 .3303 .2949 .3264 .2878 .3196 Mtetra
.656 .765 .93 r
.2878 .3196 .2949 .3264 .30582 .32248 .29875 .31564 Mtetra
.29875 .31564 .30582 .32248 .31678 .31855 .30974 .31167 Mtetra
.30974 .31167 .31678 .31855 .32779 .31459 .32078 .30768 Mtetra
.32078 .30768 .32779 .31459 .33884 .31063 .33186 .30368 Mtetra
.656 .764 .929 r
.33186 .30368 .33884 .31063 .34994 .30664 .34299 .29966 Mtetra
.34299 .29966 .34994 .30664 .36108 .30264 .35417 .29562 Mtetra
.35417 .29562 .36108 .30264 .37228 .29863 .36539 .29157 Mtetra
.36539 .29157 .37228 .29863 .38352 .29459 .37666 .28751 Mtetra
.37666 .28751 .38352 .29459 .3948 .29054 .38798 .28343 Mtetra
.38798 .28343 .3948 .29054 .40614 .28647 .39934 .27933 Mtetra
.39934 .27933 .40614 .28647 .41752 .28239 .41076 .27522 Mtetra
.656 .764 .93 r
.41076 .27522 .41752 .28239 .42895 .27829 .42222 .27109 Mtetra
.655 .764 .93 r
.42222 .27109 .42895 .27829 .44043 .27417 .43373 .26695 Mtetra
.655 .765 .93 r
.43373 .26695 .44043 .27417 .45196 .27003 .44529 .26279 Mtetra
.44529 .26279 .45196 .27003 .46353 .26588 .4569 .25861 Mtetra
.4569 .25861 .46353 .26588 .47516 .2617 .46856 .25441 Mtetra
.46856 .25441 .47516 .2617 .48684 .25751 .48027 .2502 Mtetra
.655 .766 .931 r
.48027 .2502 .48684 .25751 .49856 .25331 .49203 .24597 Mtetra
.49203 .24597 .49856 .25331 .51034 .24908 .50384 .24172 Mtetra
.50384 .24172 .51034 .24908 .52217 .24484 .51571 .23745 Mtetra
.655 .767 .931 r
.51571 .23745 .52217 .24484 .53405 .24057 .52762 .23316 Mtetra
.52762 .23316 .53405 .24057 .54598 .23629 .53959 .22885 Mtetra
.656 .767 .931 r
.53959 .22885 .54598 .23629 .55796 .23199 .55161 .22452 Mtetra
.656 .767 .932 r
.55161 .22452 .55796 .23199 .57 .22767 .56368 .22016 Mtetra
.56368 .22016 .57 .22767 .58208 .22333 .5758 .21579 Mtetra
.656 .767 .931 r
.5758 .21579 .58208 .22333 .59422 .21897 .58798 .21139 Mtetra
.58798 .21139 .59422 .21897 .60642 .21459 .60021 .20697 Mtetra
.60021 .20697 .60642 .21459 .61866 .2102 .61249 .20252 Mtetra
.657 .767 .931 r
.61249 .20252 .61866 .2102 .63096 .20578 .62483 .19804 Mtetra
.657 .766 .93 r
.62483 .19804 .63096 .20578 .64332 .20134 .63722 .19354 Mtetra
.657 .765 .929 r
.63722 .19354 .64332 .20134 .65572 .19688 .64967 .18901 Mtetra
.658 .764 .928 r
.64967 .18901 .65572 .19688 .66819 .1924 .66217 .18445 Mtetra
.658 .763 .927 r
.66217 .18445 .66819 .1924 .68071 .1879 .67473 .17986 Mtetra
.658 .762 .926 r
.67473 .17986 .68071 .1879 .69328 .18338 .68734 .17524 Mtetra
.659 .76 .925 r
.68734 .17524 .69328 .18338 .70591 .17883 .7 .17058 Mtetra
.659 .758 .923 r
.7 .17058 .70591 .17883 .7186 .17427 .71272 .1659 Mtetra
.66 .756 .921 r
.71272 .1659 .7186 .17427 .73134 .16968 .7255 .16118 Mtetra
.638 .747 .928 r
.05043 .39529 .05808 .40196 .06808 .39846 .0604 .39208 Mtetra
.638 .757 .934 r
.0604 .39208 .06808 .39846 .07811 .39492 .07041 .38882 Mtetra
.639 .768 .941 r
.07041 .38882 .07811 .39492 .08819 .39136 .08048 .38553 Mtetra
.639 .777 .947 r
.08048 .38553 .08819 .39136 .09831 .38778 .09058 .38219 Mtetra
.64 .786 .952 r
.09058 .38219 .09831 .38778 .10847 .38417 .10074 .3788 Mtetra
.64 .795 .957 r
.10074 .3788 .10847 .38417 .11867 .38053 .11094 .37537 Mtetra
.64 .803 .961 r
.11094 .37537 .11867 .38053 .12892 .37687 .12119 .3719 Mtetra
.639 .81 .965 r
.12119 .3719 .12892 .37687 .13921 .37319 .13148 .36839 Mtetra
.639 .817 .968 r
.13148 .36839 .13921 .37319 .14954 .36949 .14182 .36485 Mtetra
.638 .823 .971 r
.14182 .36485 .14954 .36949 .15992 .36576 .15221 .36126 Mtetra
.638 .829 .974 r
.15221 .36126 .15992 .36576 .17034 .36202 .16264 .35764 Mtetra
.637 .834 .976 r
.16264 .35764 .17034 .36202 .1808 .35825 .17312 .35399 Mtetra
.636 .839 .978 r
.17312 .35399 .1808 .35825 .1913 .35447 .18364 .35031 Mtetra
.635 .843 .98 r
.18364 .35031 .1913 .35447 .20185 .35066 .19421 .34659 Mtetra
.635 .847 .981 r
.19421 .34659 .20185 .35066 .21244 .34684 .20482 .34284 Mtetra
.634 .85 .982 r
.20482 .34284 .21244 .34684 .22307 .343 .21548 .33907 Mtetra
.633 .853 .983 r
.21548 .33907 .22307 .343 .23375 .33914 .22619 .33527 Mtetra
.632 .856 .984 r
.22619 .33527 .23375 .33914 .24447 .33526 .23694 .33144 Mtetra
.632 .858 .985 r
.23694 .33144 .24447 .33526 .25524 .33137 .24774 .32759 Mtetra
.631 .86 .985 r
.24774 .32759 .25524 .33137 .26605 .32746 .25858 .32371 Mtetra
.63 .862 .986 r
.25858 .32371 .26605 .32746 .2769 .32354 .26947 .31981 Mtetra
.63 .863 .986 r
.26947 .31981 .2769 .32354 .2878 .3196 .28041 .31588 Mtetra
.629 .865 .987 r
.28041 .31588 .2878 .3196 .29875 .31564 .29139 .31194 Mtetra
.629 .866 .987 r
.29139 .31194 .29875 .31564 .30974 .31167 .30242 .30797 Mtetra
.629 .867 .987 r
.30242 .30797 .30974 .31167 .32078 .30768 .31349 .30398 Mtetra
.628 .867 .987 r
.31349 .30398 .32078 .30768 .33186 .30368 .32462 .29997 Mtetra
.628 .868 .987 r
.32462 .29997 .33186 .30368 .34299 .29966 .33578 .29593 Mtetra
.628 .869 .987 r
.33578 .29593 .34299 .29966 .35417 .29562 .347 .29188 Mtetra
.347 .29188 .35417 .29562 .36539 .29157 .35827 .28781 Mtetra
.35827 .28781 .36539 .29157 .37666 .28751 .36958 .28371 Mtetra
.629 .869 .987 r
.36958 .28371 .37666 .28751 .38798 .28343 .38094 .2796 Mtetra
.38094 .2796 .38798 .28343 .39934 .27933 .39235 .27546 Mtetra
.39235 .27546 .39934 .27933 .41076 .27522 .40381 .27131 Mtetra
.63 .869 .987 r
.40381 .27131 .41076 .27522 .42222 .27109 .41532 .26713 Mtetra
.63 .868 .987 r
.41532 .26713 .42222 .27109 .43373 .26695 .42687 .26293 Mtetra
.631 .867 .986 r
.42687 .26293 .43373 .26695 .44529 .26279 .43848 .25871 Mtetra
.632 .867 .986 r
.43848 .25871 .44529 .26279 .4569 .25861 .45014 .25446 Mtetra
.633 .866 .986 r
.45014 .25446 .4569 .25861 .46856 .25441 .46184 .25019 Mtetra
.634 .865 .985 r
.46184 .25019 .46856 .25441 .48027 .2502 .4736 .24589 Mtetra
.635 .863 .985 r
.4736 .24589 .48027 .2502 .49203 .24597 .48541 .24157 Mtetra
.637 .862 .984 r
.48541 .24157 .49203 .24597 .50384 .24172 .49727 .23722 Mtetra
.638 .86 .983 r
.49727 .23722 .50384 .24172 .51571 .23745 .50918 .23285 Mtetra
.64 .858 .982 r
.50918 .23285 .51571 .23745 .52762 .23316 .52114 .22844 Mtetra
.642 .856 .981 r
.52114 .22844 .52762 .23316 .53959 .22885 .53315 .224 Mtetra
.644 .853 .98 r
.53315 .224 .53959 .22885 .55161 .22452 .54522 .21953 Mtetra
.646 .85 .978 r
.54522 .21953 .55161 .22452 .56368 .22016 .55733 .21503 Mtetra
.648 .847 .976 r
.55733 .21503 .56368 .22016 .5758 .21579 .5695 .21049 Mtetra
.651 .843 .974 r
.5695 .21049 .5758 .21579 .58798 .21139 .58172 .20591 Mtetra
.653 .839 .972 r
.58172 .20591 .58798 .21139 .60021 .20697 .594 .2013 Mtetra
.655 .834 .969 r
.594 .2013 .60021 .20697 .61249 .20252 .60632 .19664 Mtetra
.658 .829 .966 r
.60632 .19664 .61249 .20252 .62483 .19804 .6187 .19194 Mtetra
.66 .823 .962 r
.6187 .19194 .62483 .19804 .63722 .19354 .63113 .1872 Mtetra
.662 .817 .958 r
.63113 .1872 .63722 .19354 .64967 .18901 .64362 .18241 Mtetra
.664 .81 .953 r
.64362 .18241 .64967 .18901 .66217 .18445 .65615 .17757 Mtetra
.666 .803 .948 r
.65615 .17757 .66217 .18445 .67473 .17986 .66874 .17269 Mtetra
.668 .795 .943 r
.66874 .17269 .67473 .17986 .68734 .17524 .68138 .16775 Mtetra
.669 .787 .936 r
.68138 .16775 .68734 .17524 .7 .17058 .69407 .16275 Mtetra
.671 .778 .93 r
.69407 .16275 .7 .17058 .71272 .1659 .70682 .15771 Mtetra
.671 .768 .923 r
.70682 .15771 .71272 .1659 .7255 .16118 .71961 .15261 Mtetra
.593 .734 .942 r
.04273 .38856 .05043 .39529 .0604 .39208 .05258 .38624 Mtetra
.589 .763 .962 r
.05258 .38624 .0604 .39208 .07041 .38882 .06249 .38385 Mtetra
.581 .792 .979 r
.06249 .38385 .07041 .38882 .08048 .38553 .07245 .38139 Mtetra
.57 .819 .992 r
.07245 .38139 .08048 .38553 .09058 .38219 .08248 .37885 Mtetra
.554 .842 .998 r
.08248 .37885 .09058 .38219 .10074 .3788 .09256 .37622 Mtetra
.534 .859 .996 r
.09256 .37622 .10074 .3788 .11094 .37537 .1027 .37351 Mtetra
.507 .869 .985 r
.1027 .37351 .11094 .37537 .12119 .3719 .11289 .37071 Mtetra
.477 .872 .966 r
.11289 .37071 .12119 .3719 .13148 .36839 .12314 .36784 Mtetra
.442 .866 .938 r
.12314 .36784 .13148 .36839 .14182 .36485 .13345 .36489 Mtetra
.405 .854 .903 r
.13345 .36489 .14182 .36485 .15221 .36126 .14381 .36187 Mtetra
.367 .836 .863 r
.14381 .36187 .15221 .36126 .16264 .35764 .15422 .35877 Mtetra
.33 .814 .821 r
.15422 .35877 .16264 .35764 .17312 .35399 .16469 .35561 Mtetra
.294 .79 .777 r
.16469 .35561 .17312 .35399 .18364 .35031 .17522 .35237 Mtetra
.26 .764 .734 r
.17522 .35237 .18364 .35031 .19421 .34659 .18579 .34907 Mtetra
.229 .738 .694 r
.18579 .34907 .19421 .34659 .20482 .34284 .19642 .34571 Mtetra
0 0 0 r
.19642 .34571 .20482 .34284 .21548 .33907 .2071 .34228 Mtetra
.2071 .34228 .21548 .33907 .22619 .33527 .21783 .3388 Mtetra
.21783 .3388 .22619 .33527 .23694 .33144 .22861 .33526 Mtetra
.22861 .33526 .23694 .33144 .24774 .32759 .23945 .33166 Mtetra
.23945 .33166 .24774 .32759 .25858 .32371 .25033 .32801 Mtetra
.25033 .32801 .25858 .32371 .26947 .31981 .26127 .32431 Mtetra
.26127 .32431 .26947 .31981 .28041 .31588 .27226 .32056 Mtetra
.27226 .32056 .28041 .31588 .29139 .31194 .28329 .31676 Mtetra
.28329 .31676 .29139 .31194 .30242 .30797 .29438 .31292 Mtetra
.29438 .31292 .30242 .30797 .31349 .30398 .30552 .30902 Mtetra
.30552 .30902 .31349 .30398 .32462 .29997 .31671 .30508 Mtetra
.31671 .30508 .32462 .29997 .33578 .29593 .32794 .3011 Mtetra
.32794 .3011 .33578 .29593 .347 .29188 .33923 .29707 Mtetra
.33923 .29707 .347 .29188 .35827 .28781 .35057 .293 Mtetra
.35057 .293 .35827 .28781 .36958 .28371 .36196 .28889 Mtetra
.36196 .28889 .36958 .28371 .38094 .2796 .37339 .28473 Mtetra
.37339 .28473 .38094 .2796 .39235 .27546 .38488 .28052 Mtetra
.38488 .28052 .39235 .27546 .40381 .27131 .39642 .27627 Mtetra
.39642 .27627 .40381 .27131 .41532 .26713 .40801 .27198 Mtetra
.40801 .27198 .41532 .26713 .42687 .26293 .41965 .26763 Mtetra
.41965 .26763 .42687 .26293 .43848 .25871 .43134 .26324 Mtetra
.43134 .26324 .43848 .25871 .45014 .25446 .44307 .2588 Mtetra
.44307 .2588 .45014 .25446 .46184 .25019 .45486 .25431 Mtetra
.45486 .25431 .46184 .25019 .4736 .24589 .4667 .24976 Mtetra
.4667 .24976 .4736 .24589 .48541 .24157 .47859 .24516 Mtetra
.47859 .24516 .48541 .24157 .49727 .23722 .49053 .24051 Mtetra
.49053 .24051 .49727 .23722 .50918 .23285 .50252 .23579 Mtetra
.50252 .23579 .50918 .23285 .52114 .22844 .51456 .23101 Mtetra
.268 .755 .663 r
.51456 .23101 .52114 .22844 .53315 .224 .52665 .22617 Mtetra
.304 .784 .701 r
.52665 .22617 .53315 .224 .54522 .21953 .53879 .22125 Mtetra
.342 .813 .741 r
.53879 .22125 .54522 .21953 .55733 .21503 .55098 .21627 Mtetra
.383 .842 .782 r
.55098 .21627 .55733 .21503 .5695 .21049 .56322 .21122 Mtetra
.426 .869 .823 r
.56322 .21122 .5695 .21049 .58172 .20591 .5755 .20609 Mtetra
.47 .893 .862 r
.5755 .20609 .58172 .20591 .594 .2013 .58784 .20088 Mtetra
.514 .913 .898 r
.58784 .20088 .594 .2013 .60632 .19664 .60022 .1956 Mtetra
.555 .926 .929 r
.60022 .1956 .60632 .19664 .6187 .19194 .61264 .19022 Mtetra
.592 .932 .953 r
.61264 .19022 .6187 .19194 .63113 .1872 .62512 .18476 Mtetra
.625 .93 .969 r
.62512 .18476 .63113 .1872 .64362 .18241 .63764 .17921 Mtetra
.652 .921 .977 r
.63764 .17921 .64362 .18241 .65615 .17757 .6502 .17357 Mtetra
.673 .904 .977 r
.6502 .17357 .65615 .17757 .66874 .17269 .66281 .16784 Mtetra
.689 .883 .97 r
.66281 .16784 .66874 .17269 .68138 .16775 .67546 .162 Mtetra
.698 .857 .958 r
.67546 .162 .68138 .16775 .69407 .16275 .68816 .15608 Mtetra
.703 .829 .942 r
.68816 .15608 .69407 .16275 .70682 .15771 .7009 .15006 Mtetra
.704 .799 .924 r
.7009 .15006 .70682 .15771 .71961 .15261 .71368 .14397 Mtetra
.528 .712 .956 r
.03496 .38178 .04273 .38856 .05258 .38624 .04467 .38051 Mtetra
.516 .744 .978 r
.04467 .38051 .05258 .38624 .06249 .38385 .05445 .37915 Mtetra
.497 .775 .994 r
.05445 .37915 .06249 .38385 .07245 .38139 .06429 .37769 Mtetra
.472 .801 .999 r
.06429 .37769 .07245 .38139 .08248 .37885 .0742 .37611 Mtetra
.44 .817 .991 r
.0742 .37611 .08248 .37885 .09256 .37622 .08419 .3744 Mtetra
.399 .822 .967 r
.08419 .3744 .09256 .37622 .1027 .37351 .09424 .37257 Mtetra
.351 .813 .927 r
.09424 .37257 .1027 .37351 .11289 .37071 .10436 .37062 Mtetra
.299 .792 .872 r
.10436 .37062 .11289 .37071 .12314 .36784 .11454 .36855 Mtetra
.246 .761 .808 r
.11454 .36855 .12314 .36784 .13345 .36489 .1248 .36636 Mtetra
.194 .722 .74 r
.1248 .36636 .13345 .36489 .14381 .36187 .13511 .36406 Mtetra
0 0 0 r
.13511 .36406 .14381 .36187 .15422 .35877 .1455 .36164 Mtetra
.1455 .36164 .15422 .35877 .16469 .35561 .15594 .35911 Mtetra
.15594 .35911 .16469 .35561 .17522 .35237 .16645 .35648 Mtetra
.16645 .35648 .17522 .35237 .18579 .34907 .17702 .35374 Mtetra
.17702 .35374 .18579 .34907 .19642 .34571 .18766 .35089 Mtetra
.021 0 0 r
.18766 .35089 .19642 .34571 .2071 .34228 .19835 .34795 Mtetra
.042 0 0 r
.19835 .34795 .2071 .34228 .21783 .3388 .2091 .34491 Mtetra
.059 0 0 r
.2091 .34491 .21783 .3388 .22861 .33526 .21991 .34177 Mtetra
.074 0 0 r
.21991 .34177 .22861 .33526 .23945 .33166 .23078 .33855 Mtetra
.086 0 0 r
.23078 .33855 .23945 .33166 .25033 .32801 .24171 .33523 Mtetra
.096 0 0 r
.24171 .33523 .25033 .32801 .26127 .32431 .25269 .33182 Mtetra
.104 0 0 r
.25269 .33182 .26127 .32431 .27226 .32056 .26373 .32833 Mtetra
.111 0 0 r
.26373 .32833 .27226 .32056 .28329 .31676 .27483 .32475 Mtetra
.116 0 0 r
.27483 .32475 .28329 .31676 .29438 .31292 .28598 .32109 Mtetra
.119 0 0 r
.28598 .32109 .29438 .31292 .30552 .30902 .29718 .31735 Mtetra
.121 0 0 r
.29718 .31735 .30552 .30902 .31671 .30508 .30845 .31353 Mtetra
.122 0 0 r
.30845 .31353 .31671 .30508 .32794 .3011 .31976 .30963 Mtetra
.31976 .30963 .32794 .3011 .33923 .29707 .33113 .30565 Mtetra
.121 0 0 r
.33113 .30565 .33923 .29707 .35057 .293 .34255 .3016 Mtetra
.118 0 0 r
.34255 .3016 .35057 .293 .36196 .28889 .35403 .29746 Mtetra
.114 0 0 r
.35403 .29746 .36196 .28889 .37339 .28473 .36555 .29325 Mtetra
.108 0 0 r
.36555 .29325 .37339 .28473 .38488 .28052 .37713 .28896 Mtetra
.101 0 0 r
.37713 .28896 .38488 .28052 .39642 .27627 .38877 .28458 Mtetra
.093 0 0 r
.38877 .28458 .39642 .27627 .40801 .27198 .40045 .28013 Mtetra
.083 0 0 r
.40045 .28013 .40801 .27198 .41965 .26763 .41219 .27559 Mtetra
.071 0 0 r
.41219 .27559 .41965 .26763 .43134 .26324 .42397 .27097 Mtetra
.057 0 0 r
.42397 .27097 .43134 .26324 .44307 .2588 .43581 .26627 Mtetra
.041 0 0 r
.43581 .26627 .44307 .2588 .45486 .25431 .4477 .26147 Mtetra
.022 0 0 r
.4477 .26147 .45486 .25431 .4667 .24976 .45964 .25659 Mtetra
0 0 0 r
.45964 .25659 .4667 .24976 .47859 .24516 .47162 .25161 Mtetra
.47162 .25161 .47859 .24516 .49053 .24051 .48366 .24653 Mtetra
.48366 .24653 .49053 .24051 .50252 .23579 .49574 .24136 Mtetra
.49574 .24136 .50252 .23579 .51456 .23101 .50788 .23608 Mtetra
.50788 .23608 .51456 .23101 .52665 .22617 .52005 .2307 Mtetra
.52005 .2307 .52665 .22617 .53879 .22125 .53228 .22521 Mtetra
.53228 .22521 .53879 .22125 .55098 .21627 .54455 .2196 Mtetra
.54455 .2196 .55098 .21627 .56322 .21122 .55686 .21388 Mtetra
.329 .792 .671 r
.55686 .21388 .56322 .21122 .5755 .20609 .56922 .20805 Mtetra
.392 .839 .734 r
.56922 .20805 .5755 .20609 .58784 .20088 .58162 .20209 Mtetra
.456 .882 .795 r
.58162 .20209 .58784 .20088 .60022 .1956 .59406 .196 Mtetra
.52 .917 .851 r
.59406 .196 .60022 .1956 .61264 .19022 .60654 .18979 Mtetra
.578 .942 .898 r
.60654 .18979 .61264 .19022 .62512 .18476 .61906 .18345 Mtetra
.63 .953 .932 r
.61906 .18345 .62512 .18476 .63764 .17921 .63162 .17697 Mtetra
.671 .951 .954 r
.63162 .17697 .63764 .17921 .6502 .17357 .64422 .17035 Mtetra
.702 .937 .962 r
.64422 .17035 .6502 .17357 .66281 .16784 .65685 .1636 Mtetra
.723 .914 .96 r
.65685 .1636 .66281 .16784 .67546 .162 .66951 .1567 Mtetra
.735 .884 .949 r
.66951 .1567 .67546 .162 .68816 .15608 .6822 .14967 Mtetra
.74 .851 .932 r
.6822 .14967 .68816 .15608 .7009 .15006 .69493 .14252 Mtetra
.739 .816 .912 r
.69493 .14252 .7009 .15006 .71368 .14397 .70769 .13525 Mtetra
.458 .684 .963 r
.02714 .37496 .03496 .38178 .04467 .38051 .03672 .37461 Mtetra
.443 .711 .98 r
.03672 .37461 .04467 .38051 .05445 .37915 .04638 .37415 Mtetra
.424 .735 .991 r
.04638 .37415 .05445 .37915 .06429 .37769 .05611 .37356 Mtetra
.4 .756 .994 r
.05611 .37356 .06429 .37769 .0742 .37611 .06592 .37283 Mtetra
.372 .77 .986 r
.06592 .37283 .0742 .37611 .08419 .3744 .07581 .37195 Mtetra
.338 .776 .966 r
.07581 .37195 .08419 .3744 .09424 .37257 .08578 .37093 Mtetra
.299 .772 .933 r
.08578 .37093 .09424 .37257 .10436 .37062 .09582 .36976 Mtetra
.257 .759 .888 r
.09582 .36976 .10436 .37062 .11454 .36855 .10595 .36844 Mtetra
.213 .737 .834 r
.10595 .36844 .11454 .36855 .1248 .36636 .11614 .36698 Mtetra
.17 .708 .774 r
.11614 .36698 .1248 .36636 .13511 .36406 .12641 .36538 Mtetra
.129 .675 .712 r
.12641 .36538 .13511 .36406 .1455 .36164 .13676 .36364 Mtetra
0 0 0 r
.13676 .36364 .1455 .36164 .15594 .35911 .14718 .36175 Mtetra
.14718 .36175 .15594 .35911 .16645 .35648 .15766 .35973 Mtetra
.15766 .35973 .16645 .35648 .17702 .35374 .16822 .35757 Mtetra
.16822 .35757 .17702 .35374 .18766 .35089 .17885 .35528 Mtetra
.021 0 0 r
.17885 .35528 .18766 .35089 .19835 .34795 .18955 .35285 Mtetra
.041 0 0 r
.18955 .35285 .19835 .34795 .2091 .34491 .20031 .35029 Mtetra
.057 0 0 r
.20031 .35029 .2091 .34491 .21991 .34177 .21114 .3476 Mtetra
.071 0 0 r
.21114 .3476 .21991 .34177 .23078 .33855 .22204 .34478 Mtetra
.082 0 0 r
.22204 .34478 .23078 .33855 .24171 .33523 .233 .34183 Mtetra
.091 0 0 r
.233 .34183 .24171 .33523 .25269 .33182 .24402 .33876 Mtetra
.098 0 0 r
.24402 .33876 .25269 .33182 .26373 .32833 .25511 .33557 Mtetra
.103 0 0 r
.25511 .33557 .26373 .32833 .27483 .32475 .26626 .33225 Mtetra
.107 0 0 r
.26626 .33225 .27483 .32475 .28598 .32109 .27747 .32881 Mtetra
.109 0 0 r
.27747 .32881 .28598 .32109 .29718 .31735 .28874 .32525 Mtetra
.28874 .32525 .29718 .31735 .30845 .31353 .30007 .32157 Mtetra
.108 0 0 r
.30007 .32157 .30845 .31353 .31976 .30963 .31146 .31777 Mtetra
.106 0 0 r
.31146 .31777 .31976 .30963 .33113 .30565 .32291 .31386 Mtetra
.102 0 0 r
.32291 .31386 .33113 .30565 .34255 .3016 .33442 .30982 Mtetra
.096 0 0 r
.33442 .30982 .34255 .3016 .35403 .29746 .34598 .30566 Mtetra
.089 0 0 r
.34598 .30566 .35403 .29746 .36555 .29325 .3576 .30139 Mtetra
.08 0 0 r
.3576 .30139 .36555 .29325 .37713 .28896 .36927 .297 Mtetra
.07 0 0 r
.36927 .297 .37713 .28896 .38877 .28458 .381 .29248 Mtetra
.057 0 0 r
.381 .29248 .38877 .28458 .40045 .28013 .39278 .28784 Mtetra
.043 0 0 r
.39278 .28784 .40045 .28013 .41219 .27559 .40461 .28308 Mtetra
.025 0 0 r
.40461 .28308 .41219 .27559 .42397 .27097 .4165 .2782 Mtetra
.006 0 0 r
.4165 .2782 .42397 .27097 .43581 .26627 .42844 .27319 Mtetra
0 0 0 r
.42844 .27319 .43581 .26627 .4477 .26147 .44042 .26805 Mtetra
.44042 .26805 .4477 .26147 .45964 .25659 .45246 .26278 Mtetra
.45246 .26278 .45964 .25659 .47162 .25161 .46455 .25738 Mtetra
.46455 .25738 .47162 .25161 .48366 .24653 .47668 .25184 Mtetra
.47668 .25184 .48366 .24653 .49574 .24136 .48886 .24617 Mtetra
.48886 .24617 .49574 .24136 .50788 .23608 .50108 .24035 Mtetra
.50108 .24035 .50788 .23608 .52005 .2307 .51335 .2344 Mtetra
.51335 .2344 .52005 .2307 .53228 .22521 .52566 .2283 Mtetra
.34 .793 .654 r
.52566 .2283 .53228 .22521 .54455 .2196 .53801 .22205 Mtetra
.398 .838 .711 r
.53801 .22205 .54455 .2196 .55686 .21388 .5504 .21565 Mtetra
.458 .879 .766 r
.5504 .21565 .55686 .21388 .56922 .20805 .56283 .2091 Mtetra
.518 .914 .818 r
.56283 .2091 .56922 .20805 .58162 .20209 .5753 .20239 Mtetra
.574 .941 .863 r
.5753 .20239 .58162 .20209 .59406 .196 .5878 .19553 Mtetra
.625 .959 .9 r
.5878 .19553 .59406 .196 .60654 .18979 .60034 .1885 Mtetra
.668 .965 .927 r
.60034 .1885 .60654 .18979 .61906 .18345 .61291 .18132 Mtetra
.703 .962 .943 r
.61291 .18132 .61906 .18345 .63162 .17697 .62551 .17397 Mtetra
.73 .949 .95 r
.62551 .17397 .63162 .17697 .64422 .17035 .63814 .16645 Mtetra
.748 .93 .949 r
.63814 .16645 .64422 .17035 .65685 .1636 .65079 .15877 Mtetra
.76 .905 .94 r
.65079 .15877 .65685 .1636 .66951 .1567 .66347 .15092 Mtetra
.766 .878 .928 r
.66347 .15092 .66951 .1567 .6822 .14967 .67618 .14291 Mtetra
.767 .849 .913 r
.67618 .14291 .6822 .14967 .69493 .14252 .6889 .13476 Mtetra
.765 .82 .896 r
.6889 .13476 .69493 .14252 .70769 .13525 .70165 .12647 Mtetra
.413 .663 .963 r
.01926 .36808 .02714 .37496 .03672 .37461 .02877 .36824 Mtetra
.409 .681 .973 r
.02877 .36824 .03672 .37461 .04638 .37415 .03836 .36827 Mtetra
.405 .697 .98 r
.03836 .36827 .04638 .37415 .05611 .37356 .04803 .36816 Mtetra
.4 .713 .986 r
.04803 .36816 .05611 .37356 .06592 .37283 .05779 .36792 Mtetra
.394 .728 .99 r
.05779 .36792 .06592 .37283 .07581 .37195 .06763 .36753 Mtetra
.386 .742 .992 r
.06763 .36753 .07581 .37195 .08578 .37093 .07754 .36701 Mtetra
.376 .754 .99 r
.07754 .36701 .08578 .37093 .09582 .36976 .08754 .36635 Mtetra
.364 .764 .985 r
.08754 .36635 .09582 .36976 .10595 .36844 .09762 .36554 Mtetra
.35 .772 .975 r
.09762 .36554 .10595 .36844 .11614 .36698 .10778 .36459 Mtetra
.333 .777 .961 r
.10778 .36459 .11614 .36698 .12641 .36538 .11801 .3635 Mtetra
.315 .778 .943 r
.11801 .3635 .12641 .36538 .13676 .36364 .12833 .36226 Mtetra
.296 .776 .92 r
.12833 .36226 .13676 .36364 .14718 .36175 .13872 .36088 Mtetra
.275 .771 .893 r
.13872 .36088 .14718 .36175 .15766 .35973 .14918 .35935 Mtetra
.254 .762 .863 r
.14918 .35935 .15766 .35973 .16822 .35757 .15973 .35767 Mtetra
.233 .751 .831 r
.15973 .35767 .16822 .35757 .17885 .35528 .17035 .35583 Mtetra
.213 .738 .797 r
.17035 .35583 .17885 .35528 .18955 .35285 .18104 .35385 Mtetra
.193 .723 .762 r
.18104 .35385 .18955 .35285 .20031 .35029 .1918 .35172 Mtetra
.175 .708 .729 r
.1918 .35172 .20031 .35029 .21114 .3476 .20264 .34944 Mtetra
.159 .693 .696 r
.20264 .34944 .21114 .3476 .22204 .34478 .21355 .347 Mtetra
0 0 0 r
.21355 .347 .22204 .34478 .233 .34183 .22454 .3444 Mtetra
.22454 .3444 .233 .34183 .24402 .33876 .23559 .34166 Mtetra
.23559 .34166 .24402 .33876 .25511 .33557 .24671 .33875 Mtetra
.24671 .33875 .25511 .33557 .26626 .33225 .2579 .33569 Mtetra
.2579 .33569 .26626 .33225 .27747 .32881 .26915 .33247 Mtetra
.26915 .33247 .27747 .32881 .28874 .32525 .28047 .32909 Mtetra
.28047 .32909 .28874 .32525 .30007 .32157 .29186 .32556 Mtetra
.29186 .32556 .30007 .32157 .31146 .31777 .30331 .32186 Mtetra
.30331 .32186 .31146 .31777 .32291 .31386 .31483 .31801 Mtetra
.31483 .31801 .32291 .31386 .33442 .30982 .3264 .31399 Mtetra
.3264 .31399 .33442 .30982 .34598 .30566 .33804 .30981 Mtetra
.33804 .30981 .34598 .30566 .3576 .30139 .34973 .30547 Mtetra
.34973 .30547 .3576 .30139 .36927 .297 .36148 .30097 Mtetra
.36148 .30097 .36927 .297 .381 .29248 .37329 .2963 Mtetra
.37329 .2963 .381 .29248 .39278 .28784 .38516 .29147 Mtetra
.38516 .29147 .39278 .28784 .40461 .28308 .39708 .28648 Mtetra
.39708 .28648 .40461 .28308 .4165 .2782 .40905 .28133 Mtetra
.3 .773 .662 r
.40905 .28133 .4165 .2782 .42844 .27319 .42107 .27601 Mtetra
.334 .799 .692 r
.42107 .27601 .42844 .27319 .44042 .26805 .43315 .27052 Mtetra
.371 .826 .724 r
.43315 .27052 .44042 .26805 .45246 .26278 .44527 .26488 Mtetra
.411 .853 .756 r
.44527 .26488 .45246 .26278 .46455 .25738 .45744 .25907 Mtetra
.451 .879 .789 r
.45744 .25907 .46455 .25738 .47668 .25184 .46965 .25309 Mtetra
.492 .902 .821 r
.46965 .25309 .47668 .25184 .48886 .24617 .48191 .24695 Mtetra
.532 .923 .851 r
.48191 .24695 .48886 .24617 .50108 .24035 .49421 .24064 Mtetra
.57 .94 .879 r
.49421 .24064 .50108 .24035 .51335 .2344 .50656 .23417 Mtetra
.606 .952 .902 r
.50656 .23417 .51335 .2344 .52566 .2283 .51894 .22754 Mtetra
.639 .96 .921 r
.51894 .22754 .52566 .2283 .53801 .22205 .53136 .22074 Mtetra
.669 .962 .935 r
.53136 .22074 .53801 .22205 .5504 .21565 .54382 .21378 Mtetra
.694 .96 .945 r
.54382 .21378 .5504 .21565 .56283 .2091 .55631 .20665 Mtetra
.715 .954 .95 r
.55631 .20665 .56283 .2091 .5753 .20239 .56884 .19937 Mtetra
.732 .945 .951 r
.56884 .19937 .5753 .20239 .5878 .19553 .5814 .19191 Mtetra
.745 .933 .949 r
.5814 .19191 .5878 .19553 .60034 .1885 .59398 .1843 Mtetra
.756 .919 .945 r
.59398 .1843 .60034 .1885 .61291 .18132 .6066 .17652 Mtetra
.763 .904 .938 r
.6066 .17652 .61291 .18132 .62551 .17397 .61924 .16859 Mtetra
.769 .888 .93 r
.61924 .16859 .62551 .17397 .63814 .16645 .63191 .16049 Mtetra
.772 .872 .921 r
.63191 .16049 .63814 .16645 .65079 .15877 .6446 .15223 Mtetra
.774 .856 .911 r
.6446 .15223 .65079 .15877 .66347 .15092 .65731 .14381 Mtetra
.775 .841 .901 r
.65731 .14381 .66347 .15092 .67618 .14291 .67005 .13524 Mtetra
.776 .825 .891 r
.67005 .13524 .67618 .14291 .6889 .13476 .6828 .1265 Mtetra
.775 .81 .881 r
.6828 .1265 .6889 .13476 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Sooooo`03olK?hOl0003ooooo01Gooooo00?o
0000ooooooooool0DOooool0063ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`0Mooooo`?o00000_ooool00ol0003oooooooooo`1Oooooo`?oa/oQ00?o
0000olK?hOooool05Oooool00ol0003oooooooooo`1@ooooo`00H?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol0000Looooo`;o0000IOooool00oo6dnCoa/oQolK?h@02olK?h@03o`000?o3
dNGooooo01Cooooo00?o0000ooooool00000DOooool0063ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0001[ooooo0ol0001Vooooo`?oa]?T0oo6cn400ol0003o`m7U
ol?Ai@0Fooooo`03o`000?oooooooooo04oooooo001Pooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool0000Hooooo`;o0000J?ooool5olKCi003olK?hOo3dNGo000000?o
`m7U5_ooool00ol0003oooooooooo`1>ooooo`00H?ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l000005Oooool3o`0000;ooooo00?o0000ooooooooool0Hoooool00oo6enKo
a]?TolKCi003olKCi0;oa=WY00Go`m7Uo`000?o3dNGo`m7Uokg@j@0Fooooo`03o`000?oooooooooo
04kooooo001Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000Coooo
o`;o0000J_ooool3olKGiP?oa]?T1?o4fNT00ol0003o_M3Yokg@j@02okg@jAKooooo00?o0000oooo
ooooool0COooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo
00oooooo0ol0001[ooooo`Goa]OV00?oa]?TolCIjOo4fNT00_o4fNT00onmfNko0000okg@j@04okg@
jAKooooo00?o0000ooooooooool0C?ooool008;ooooo0_l0001/ooooo`;oa]_Y1?o6enH2olCPk@?o
a=WY0_nmfNh00ol0003o_M3Yokg@j@02okg@j@03okC<k?oooooooooo01Cooooo00?o0000oooooooo
ool0C?ooool007oooooo0ol00002ooooo`03o`000?oooooooooo06Sooooo1?o6fnT00oo6enKoa>3]
olCPk@03olCPk@07olCIjOnmfNko_MW^okgIk_l0003o_MW^okg@j@04okC<k1Cooooo0ol0001=oooo
o`00O?ooool3o`0006oooooo1?o6fnT2ol;Wl0Coa>3]00?o_>;bokgIk_nmfNh00_nmfNh00ol0003o
/mCaokC<k004okC<k1Oooooo00?o0000ooooooooool0B_ooool007[ooooo0_l0001`ooooo`;oaMo[
0oo6fnT4ol;Wl003olCPkOnlh_;o_>;b00;o_>;b00Ko_MW^ok?DlOnce?7o/mCao`000?nce?42okC<
k0?oZlC/5_ooool00ol0003oooooooooo`1:ooooo`00Moooool3o`00073ooooo1Oo5gn/00oo6fnWo
`^O`ol;Wl002ol;Wl003okWYmOnlh_;o_>;b00;o_>;b0_nbfoD3ok?Dl@03o`000?n[ankoZlC/00Go
ZlC/5_ooool00ol0003oooooooooo`19ooooo`00MOooool2o`0000;ooooo00?o0000ooooooooool0
K?ooool2olCSkPCoaMo[0onok_800oo2io3o^NWeokWYm@02okWYm@03okcRl_nbfoGo/]_e00?o/]_e
00?o/mCaoj_7k_l000000_n[anh4oj_4k003ojS1jooooooooooo01Gooooo00?o0000ooooooooool0
B?ooool007;ooooo0ol00005ooooo`03o`000?oooooooooo06[ooooo1?o4hnh00oo5gn_o_nkboko^
lP02oko^lP03ok?_m_nijOGo^NWe00;o^NWe0on`h_P2ok;Km@?oZlW_00?oZlO^o`000?n[anh00_n[
anh00on[a>coZ<7[ojS1j`02ojS1jaKooooo00?o0000ooooooooool0B?ooool0073ooooo0_l0001d
ooooo`Coa>?^0onjl_<00onok_;o/nofok?_mP02ok?_mP03okWYmOn`h_So/>;h00;o/>;h00?oZl_a
oj_9kon[bNl01?n[bNl01?l0003oZlO^ojS2k?nX`^`6ojS1jaKooooo00?o0000ooooooooool0Aooo
ool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00023ooooo0ol0
001dooooo`?o`nO`00?oa>?^ok[blonjl_<00_njl_<2oj_cm0;o/nof1?n/ioX00on`h_SoZl_aoj_;
l@02oj_;l@CoZlW_00?oZ<;/o`000?nX`^`00onX`^`4ojS1j`03ojO0jooooooooooo01?ooooo0ol0
0018ooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@07_ooool2o`0000?ooooo00?o0000ooooooooool0Koooool4ol?Wl0?o/oKa
00Co^_;coj_cm?n[loCoZo?d0_nVjoX4ojcWnP;oZ/gb1On[bo401On[bNooZ<;/ojS2k?nX`^co0000
00GoZ<;/00?oZ<7[ojO0jonW`>/00_nW`>/Fooooo`03o`000?oooooooooo00Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo02Wooooo000hoooo
o`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Looooo`?o0000MOooool2
ol7[l@?o`nO`0oncm_42oj7ckP03oj_cm?nVjo[oY^_j00?oY^_j00?o[>Ojoj[=l_nZcO800onZcO82
oj_;l@?oZ<?]0onX`^`01?l0003oZ<;/ojS2k?nX`^`8ojO0jaKooooo00?o0000ooooooooool01Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02[ooooo
000hooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Hooooo`?o0000
Moooool4ol7[l@03ol?Wl?ncm_7o/oKa00?oXO?^0onOk_P2ojK[nP?oZLoc1?nZcO87ojS3k@;oZ<;/
00?o0000ojO1k?nW`>/02_nW`>/Fooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooo
oooooa0@400;ooooo`Go0000:oooool003Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo01Gooooo0ol0001hooooo`Co`N_a0_n[mnd3oi?ai@04oj7ck_nOk_SoWnkhoio^
n0;oZM7e1OnYco<00onZcO;oZ<?]ojS3k@06ojS3k@?oYl7/00?o0000ojO1k?nW`N`01?nW`>/00onW
_n_oYl3[ojO0j`04ojO0jaGooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000_ooooo00CoA4A4omgMgOoooooo0000;?ooool003Sooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo017ooooo0ol00003ooooo`03o`000?oooooooooo07?ooooo0onn
k_800oo1jo7oZoO]oj_gk@04oi?ai@;oUnkc00?oWnkhojWAmOnYdOD00onYdOD2ojW?l`WoZ<?]1OnW
`N`01Ol0003oYl7/ojO1k?nW`NcoYl3[00CoYko[1OnW`>/Fooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002cooooo000hooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@017ooooo0_l0001j
ooooo`Co_^kb0_nOmNH3ohGZf@03oi?aiOnGk_?oUnkc00?oZ=;f1?nYdOD9ojS3k@SoYl7/00?o0000
ojO1k?nW_n/01onW_n/5ojO0jaKooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oMgMgolc<c?l00000;?ooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03_ooool3o`0007[ooooo0onklO<00onnk_;oWoGV
oioeiP03ohGZf@;oS^g]0_nXe?L5ojSBmP03ojWAmOnX`ngoZ<?]00KoZ<?]2OnW`N`2ojNoj`03o`00
0?nW_n_oYko[00GoYko[2?nW`>/Dooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?ok^k^odA4A?l00000;?ooool005Wooooo0ol0001kooooo`?o^o7c0_nBl=`2ogCQb`?oPnWU
00?oS^g]ojSDmonXe?L00_nXe?L2ojSBmP?oZ<C^1_nX`nd8ojO1k0GoYko[00?o0000ojNojonW_n/0
0_nW_n/;ojO0ja?ooooo00Co0000oooooooooooo00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00gooooo00?oMgMgo`000?ooool0:oooool005Kooooo0ol00003ooooo`03o`000?oooooooooo07Oo
oooo0_nklO<2oi;`g0;oM>7;0on3jND2ojOEn0CoZ=Cg1onXa>h2ojS3k@WoYl7/1onW_n/00ol0003o
Yko[ojNoj`0>ojO0jaKooooo00?o0000ooooooooool0@?ooool005Cooooo0_l0001nooooo`;o]oCc
0_n4jM42ofCF^`;oN>CL0_nWe_P4ojOEn003ojSDmonXa>koZ<C^00KoZ<C^2OnW`N`:ojNoj`03o`00
0?nW`>_oYl3[00koYl3[5_ooool00ol0003oooooooooo`10ooooo`00DOooool3o`0007kooooo0ong
m?<00on4jM7oI=JkofCF^`02ogSTg0GoYmKh0_nWeOP2ojO4kPKoZ<C^2?nW`N`9ojNoj`CoYl3[00?o
0000ojO0jonW`>/03onW`>/Fooooo`03o`000?oooooooooo03oooooo001>ooooo`Go0000OOooool3
ok7el@04okOdlomDbZ_oKMkBofgNdPCoY]Oi0_nWe_P7ojO4kP;oZ<C^0onW`^`6ojO1k0SoYko[1onW
`>/00ol0003oYl3[ojO0j`0@ojO0jaKooooo00?o0000ooooooooool0?_ooool004cooooo0_l00005
ooooo`03o`000?oooooooooo07Sooooo1?namO401?mRelSoYMSiojGHnOnUf?T4ojKGn@WoYlC^1onW
`^`2ojO1k0WoYko[2OnW`>/00ol0003oYl3[ojO0j`0@ojO0jaKooooo00?o0000ooooooooool0?_oo
ool004Wooooo0ol00020ooooo`?oZoK_00?o/OGaojGIn_nUfOX01OnUf?T00onVeoWoYlC^ojO4kP06
ojO4kPSoYl;/2_nW_n/=ojO0j`03o`000?nW`>_oYl3[013oYl3[5?ooool3o`0003oooooo000Roooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h08?ooool2o`00087ooooo1?n[m^l5ojGInP;oYMSi2OnWa>h7
ojO2k0[oYko[4?nW`>/00ol0003oYl3[ojO0j`0AojO0jaGooooo00?o0000ooooooooool0?Oooool0
02;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`?o00000_ooool00ol0003oooooooooo`1l
ooooo`?oXoG[00CoZoK_ojCJn_nTf_[oY=[j0_nUfOX:ojO4kPWoYl;/2OnW_n/BojO0j`03o`000?nW
`>_oYl3[01;oYl3[5Oooool00ol0003oooooooooo`0looooo`008_ooool01Ol@413ooooooooooooo
oooo410@01_ooooo0_l00022ooooo`CoXoG[1?nTf_X9ojO4kP;oYl;]2?nW`^`2ojNojPOoYko[5OnW
`>/00ol0003oYl3[ojO0j`0CojO0jaGooooo00?o0000ooooooooool0>oooool002;ooooo00Go0000
ooooooooooooooooo`00000Hooooo`?o0000P_ooool3oi_ciP05oj?ejonTfo_oY=_kojCKnonTf_X0
2?nWa>h6ojO2k@CoYl;/1_nW_nX2ojNojaWoYl3[00?o0000ojO0jonW`>/04onW`>/Eooooo`03o`00
0?oooooooooo03_ooooo000Rooooo`05o`000?ooooooooooooooool000005_ooool3o`0008?ooooo
0onKlnH2oj?Kn`;oY=_k2?nWa>h9ojO2k@03ojO2k?nW_n[oYkoZ00GoYkoZ7?nW`>/00ol0003oYl3[
ojO0j`0DojO0jaGooooo00?o0000ooooooooool0>_ooool002;ooooo00Go410@oooooooooooooooo
oa0@400Cooooo`?o00000_ooool00ol0003oooooooooo`1oooooo`03o`000?nKlnKoVo?V00?oXm_k
2?nWa>h:ojO2k@WoYkoZ7OnW`>/00ol0003oYl3[ojO0j`0DojO0jaKooooo00?o0000ooooooooool0
>Oooool002;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`?o0000QOooool00ol0003oTO3Q
oi7`h@02oj?Ln`03oj?KnonWa>koYlC^00GoYlC^2OnW`^d:ojNojR3oYl3[00?o0000ojO0jonW`>/0
5OnW`>/Dooooo`;o0000>oooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`;o0000
QOooool2o`0000;oTO3Q0_nSg?/9ojO4kPOoYl;]00?oYkkZojNoj_nW_nX01_nW_nXTojO0j`03o`00
0?nW`>_oYl3[01KoYl3[5Oooool00ol0003oooooooooo`0hooooo`00<_ooool5o`00087ooooo1?l0
00000on8k=WoXmckojO4kP09ojO4kPSoYl;]1?nW_^X4ojNojRKoYl3[0_l0000HojO0jaKooooo00?o
0000ooooooooool0=oooool0033ooooo0_l00023ooooo`Go000000?oX]clojO4k_nWa>h01onWa>h:
ojO2k@OoYkkZ00?oYkoZojO0jonW`>/08onW`>/3o`000003ojO0jol0003oYl3[01SoYl3[5Oooool0
0ol0003oooooooooo`0gooooo`00;Oooool3o`0008Cooooo1?l000000onRgOcoX]clojO4kP06ojO4
kPWoYl;]2OnW_^XUojO0j`?o00001OnW`>/00ol0003oYl3[ojO0j`0GojO0jaGooooo00?o0000oooo
ooooool0=_ooool002cooooo0_l00023ooooo`;o000000Co1@00o`000?l0003oX]gl0onW`nh5ojO4
kPSoYl;]2OnW_^XUojO0j`?o00002OnW`>/00ol0003oYl3[ojO0j`0GojO0jaGooooo00?o0000oooo
ooooool0=Oooool002cooooo0ol0001nooooo`;o000000Co2P00o`D00?l5003o1@000_mchLT6ojO3
kP;oYlC^2?nW`^d:ojNnjR?oYl3[0ol0000=ojO0j`03o`000?nW`>_oYl3[01OoYl3[5?ooool00ol0
003oooooooooo`0eooooo`00;?ooool01?l0003oooooo`000?l0001jooooo`;o000000Co3P00o`X0
0?l:003o1@000omYf/46ojO3kPWoYl;]2_nW_^XSojO0j`?o00004?nW`>/00ol0003oYl3[ojO0j`0G
ojO0ja?ooooo00?o0000ooooool000002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`06Oooool002cooooo0_l00002ooooo`03o`000?oo
oooooooo07Kooooo00Go0000o`h00?l>003o2P00o`000003ofWJ`@GoYl?^2OnW`^d9ojNnjRCoYl3[
0ol0000DojO0j`03o`000?nW`>_oYl3[01OoYl3[5Oooool00ol0003oooooooooo`05ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0Ioooo
o`00:oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000oa800?lB
00000_l>00000ol0003oG]>ioekC^@06ojO3kPSoYl;]2?nW_^XVojO0j`;o00006?nW`>/00ol0003o
Yl3[ojO0j`0FojO0jaGooooo00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`00000Iooooo`00:oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo06gooooo0_l000001olE003o4P00oa800?lB003o3P00o`400?l000001onW
`nh8ojO2k@OoYkkZ9_nW`>/3o`0001[oYl3[00?o0000ojO0jonW`>/05onW`>/Eooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B406Oooool002_ooooo0ol00005ooooo`03o`000?oooooooooo06Wooooo1?l00002oaD00004oa80
0?l6003o0@00o`4000GoYl?^2OnW`^d9ojNnjRCoYl3[0ol0000NojO0j`03o`000?nW`>_oYl3[01Oo
Yl3[5Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003oEEEEo`000?l@413oc<c<01Wooooo000[ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0Ioooool2o`000004oaL00?lE003o5@00oaD000;o1P0000?o0@00ojO3k_nW`nh00_nW`nh9
ojO2k@WoYkkZ9?nW`>/3o`0002;oYl3[00?o0000ojO0jonW`>/05_nW`>/Eooooo`03o`000?oooooo
oooo00?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo01_ooooo000[
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Hoooool00ol0003o6@00oaT00002
oaL00003oaD00?l;003o2`0000;o1P001?nW`nh8ojO2k@SoYkkZ9OnW`>/3o`0002KoYl3[00?o0000
ojO0jonW`>/05_nW`>/Cooooo`?o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o
gMgMoa0@4?nHV9P06oooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`1Nooooo`;o000000?o6`00oaT00?lI00000_lI00001Ol>003o2`00o`/00?l;003o1P0000;oYl?]
0_nW`nh8ojO2k@OoYkkZ9OnW`>/3o`0002WoYl3[00?o0000ojO0jonW`>/05onW`>/Eooooo`09o`00
0?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@6Ooo
ool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooooooo
o`04ooooo`?o00002_ooool00ol0003oooooooooo`1Jooooo`Co00000_lK0003oaT000;o3P0000Co
2`00ojO3kOnW`ngoYl?]2OnW`^d9ojNnjR?oYl3[0ol0000]ojO0j`03o`000?nW`>_oYl3[01KoYl3[
5Oooool00ol0003oooooooooo`0_ooooo`002?ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`Go00001Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Sooooo
0_l000001_lM003o6`00oa/00?lK003o6@00oa4000;o3P0000?o0000ojO3kOnW`^d02OnW`^d9ojNn
jRCoYl3[0_l0000aojO0j`03o`000?nW`>_oYl3[01KoYl3[5Oooool00ol0003oooooooooo`0^oooo
o`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Cooooo00?o0000oah00?lN00000_lM0000
0olK003o5000oa400002oa400003o`h00?l0003oYl;]00SoYl;]2_nW_^XTojO0j`?o0000<onW`>/0
0ol0003oYl3[ojO0j`0GojO0jaGooooo00?o0000ooooooooool0;Oooool0013ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`1@ooooo`03o`000?lN003o7P0000?o7P0000Co5P00oa@00?lD003o4@00
0_l00002ojO3k@OoYl;]2_nW_^XTojO0j`?o0000=onW`>/00ol0003oYl3[ojO0j`0GojO0jaCooooo
00?o0000ooooooooool0;Oooool0013ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMg
Moo<c<co000000Kooooo0_l0000?ooooo`;o0000C?ooool4o`0000Go7P000_lF0002o`0000;oYl?]
2OnW`^d9ojNnjR?oYl3[0ol0000kojO0j`03o`000?nW`>_oYl3[01KoYl3[5Oooool00ol0003ooooo
ooooo`0/ooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
1_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04Kooooo1?l000000olO003o7P00
oah00002oah00006oaP00?lF003o5P00oaH00?l0003oYl?]2OnW`^d9ojNnjR?oYl3[0ol0000oojO0
j`03o`000?nW`>_oYl3[01KoYl3[4oooool2o`0002kooooo000@ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03Oooool00omgMgOo0000ooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0A?ooool2o`0000?o7`0000?o7P00oaX00?lJ00000_lH00000olF003o0000ojO3k@08ojO2
k@[oYkkZ8onW`>/3o`0004;oYl3[00?o0000ojO0jonW`>/05_nW`>/Eooooo`03o`000?oooooooooo
02_ooooo000Yooooo`;o00005?ooool00ol0003oooooooooo`10ooooo`03o`000?lN003o7P0000?o
7`0000Ko6`00oaX00?lJ003o6P00oaP00?l00002ojO3k@OoYl;]2OnW_^XTojO0j`?o0000A_nW`>/0
0ol0003oYl3[ojO0j`0FojO0jaGooooo00?o0000ooooooooool0:_ooool002Wooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0looooo`03o`000?lN003o7P0000;o7P0000?o7`00oa/0
0?lK00000_lK0002oaX00003o`000?nW`ngoYl?]00SoYl;]1onW_^XUojO0j`;o0000B_nW`>/00ol0
003oYl3[ojO0j`0FojO0jaCooooo00?o0000ooooooooool0:_ooool002Wooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0gooooo`Co00001?lN0005oa/00003oaX00?l0003oYl;]00So
Yl;]2OnW_^XSojO0j`?o0000COnW`>/00ol0003oYl3[ojO0j`0FojO0jaCooooo00?o0000oooooooo
ool0:Oooool002Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0cooooo`Co0000
00?o7@00oah00?lN00000_lN0004oa/00003o`000?nW`nkoYl;]00SoYl;]2OnW_^XSojO0j`?o0000
D?nW`>/00ol0003oYl3[ojO0j`0GojO0jaCooooo00?o0000ooooooooool0:?ooool002Wooooo0ol0
000Gooooo`03o`000?oooooooooo037ooooo0_l00003oad00003oah00?lK003o6`0000;o6`0000?o
0000ojO3k_nW`nh02?nW`^d:ojNnjR?oYl3[0ol0001DojO0j`03o`000?nW`>_oYl3[01KoYl3[4ooo
ool2o`0002[ooooo000Yooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0;Oooool0
1Ol0003o6P00oa`00?lL003o7@0000Go6`0000Co0000ojO3k_nW`nkoYl?^1onW`^d9ojNnjRCoYl3[
0ol0001HojO0j`03o`000?nW`>_oYl3[01KoYl3[5?ooool00ol0003oooooooooo`0Wooooo`003_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo02Wooooo00Ko0000oaP00?lJ003o6P00oa`00?lJ0004oa/0
00?o00000_nW`nh8ojO2k@OoYkkZ9?nW`>/3o`0005_oYl3[00?o0000ojO0jonW`>/05_nW`>/Eoooo
o`03o`000?oooooooooo02Kooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool09?ooool00ol0003o5P00oaH00002oaP00003oaX00?lI003o6P0000;o6P000_lK0002
o`000003ojO4k_nW`^goYl;]00OoYl;]2OnW_^XRojO0j`?o0000GonW`>/00ol0003oYl3[ojO0j`0F
ojO0jaCooooo00?o0000ooooooooool09_ooool000Kooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP06ooooo`;o00007Oooool00ol0003oooooooooo`0P
ooooo`03o`000?lB003o5P0000;o5P000_lH0002oaT000?o6P0000?o6`00o`000?nWa>h02OnW`^d9
ojNnjR?oYl3[0_l0001SojO0j`03o`000?nW`>_oYl3[01KoYl3[5?ooool00ol0003oooooooooo`0U
ooooo`003_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01kooooo00?o0000oa800?lF00000_lF0000
1_lH003o5`00oaT00?lI003o6P00o`0000;oYlC^2OnW`^d9ojNnjR?oYl3[0ol0001VojO0j`03o`00
0?nW`>_oYl3[01GoYl3[5Oooool00ol0003oooooooooo`0Tooooo`003_ooool01Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`0Nooooo`;o0000
7?ooool01Ol?003o4P00oa800?lF003o500000?o5`0000?o6@00ojO4k_nWa>h00_nWa>h7ojO2k@Wo
YkkZ9?nW`>/3o`0006WoYl3[00?o0000ojO0jonW`>/05_nW`>/Cooooo`;o00002?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`02Oooool0
00kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00?ooooo0_l0000Q
ooooo`03o`000?oooooooooo01Gooooo00Co0000o`X00?l?003o3`000_lB0002oa@00003oaL00?l0
003oYlC^00CoYlC^1_nW`^d9ojNnjRCoYl3[0ol0001]ojO0j`03o`000?nW`>_oYl3[01KoYl3[5?oo
ool00ol0003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00Go8B4QoiRHV?ooooooV9RHob4Q8@09ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`;o00008oooool00ol0003oooooooooo`0Aoooo
o`05o`000?l:003o2P00o`X00?l?00000olB00000olD003oYlC^ojO4kP04ojO4kPSoYl;]2OnW_^XR
ojO0j`?o0000LOnW`>/00ol0003oYl3[ojO0j`0FojO0jaCooooo00?o0000ooooooooool01?ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000009ooooo`003_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool03?ooool01?m2`k_o0000o`D00?l50002o`X0
0003o`h00?lX/K;o:;6b00KoYlC^2OnW`^d9ojNnjR;oYl3[0ol0001eojO0j`03o`000?nW`>_oYl3[
01GoYl3[5?ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002oooool0
1Olb<S;oV9RHoooooonHV9So<S8b00Wooooo000Wooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool02?ooool01_m2`k_o0000o`000?l0003o1@00oc6i``WoYlC^2OnW`^d9ojNnjR;oYl3[
0ol0001hojO0j`03o`000?nW`>_oYl3[01KoYl3[5?ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Wooooo000Wooooo`;o
00009_ooool00ol0003oooooooooo`04ooooo`Go000000?o<KW3oj;Fn_nReoX01onWa>h9ojO2k@Wo
YkkZ8onW`>/2o`0007coYl3[00?o0000ojO0jonW`>/05OnW`>/Eooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41002Oooool0
02Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`02o`0000?o>l3D0_nSeOT2oj;F
nPSoYlC^1_nW`^d9ojNnjRCoYl3[0ol0001oojO0j`03o`000?nW`>_oYl3[01GoYl3[4_ooool3o`00
00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000002Ooo
ool002Oooooo00?o0000ooooooooool09?ooool3odK5i0;oGMKL0onSe?T2oj?En@WoYlC^1_nW`^d0
0onW_n[oYkkZojNnjP06ojNnjRCoYl3[0ol00022ojO0j`03o`000?nW`>_oYl3[01KoYl3[5?ooool0
2Ol0003oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT02Oooool002Kooooo0ol0000Oooooo`CoD<Oa0_m;a^/00omWf^OoXm;hoj?Bn002oj?Bn0;o
XmCi2OnWa>h3ojO2k0GoYl;]0onW_nX6ojNnjR;oYl3[0ol00026ojO0j`03o`000?nW`>_oYl3[01Go
Yl3[5Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Booooo`?oH<7m
1?mM`o`3oeW5n@;oELKf0_ln`/h3og7Ml0CoXm7g0_nSd_P9ojO4kPOoYl;/0_nW`^d6ojNojP;oYkkZ
8_nW`>/3o`0008[oYl3[00?o0000ojO0jonW`>/05OnW`>/Dooooo`03o`000?oooooooooo01kooooo
000Kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooofVYmP02ofVYmP?oJ:ki
0omW/_X3ofJfo0CoI;[m0omR_Od4of31o@;oGL?l0_m1`^<3odc:g`?oN]og0_nScoL4oj?Am`03ojO3
k_nWa>koYlC^00GoYlC^2OnW`^`9ojNojR;oYl3[0ol0002>ojO0j`03o`000?nW`>_oYl3[01GoYl3[
5?ooool00ol0003oooooooooo`0Mooooo`006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool00omYZOH3ofR^n@?oIk;j0omV]_`2ofBjo@CoGlGl0_mFa_L4ofKBm`;oFM3]
0_n1g_`3oj?=mPCoXlog00?oXm7gojO3k_nW`nh00_nW`nh3ojO4kP?oYl7/1_nW`^`9ojNojR;oYl3[
0ol0002AojO0j`03o`000?nW`>_oYl3[01KoYl3[4oooool2o`0001kooooo000Kooooo`05oa0@4?oo
ooooooooooooool@41001_ooool2o`0000;ooooo0ome[oH4og6fnPCoK;cm0omV`Oh2oeo5o0CoL=7m
0_mVd_L2ohSKoP?oXl_d1?nScOH2oj??m`OoYl?^00?oYlC^ojO1k?nW`N`00onW`N`2ojO2k0WoYkoZ
8_nW`>/3o`0009GoYl3[00?o0000ojO0jonW`>/05OnW`>/Booooo`03o`000?oooooo000001kooooo
000Kooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`?oMJof
1?ma]_X2ofblo@?oOlKn0_mhcOl4oi7Ao@;oSMOo0onSbO<4oj?;m0;oXlgf2OnW`nh6ojO1k0SoYkoZ
9?nW`>/2o`0009WoYl3[00?o0000ojO0jonW`>/05OnW`>/Dooooo`03o`000?oooooooooo01_ooooo
000Kooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`CoQkKd
1?n4__X2ogo6oP?oU<[j0onAdOd2oj?6lPGoXlWc0_nSbo@2ojO3k@OoYl?^1onW`N`7ojNojRCoYl3[
0ol0002KojO0j`03o`000?nW`>_oYl3[01GoYl3[5Oooool00ol0003oooooooooo`0Jooooo`006ooo
ool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool01Oooool4ohNfm0;oQ;kj
0onF`oH4oiC:nP03oi7AoOnSa_;oXlKb00;oXlKb0_nSbO<3ojO2k@CoYl?]0_nW`nh9ojO1k0?oYko[
1OnW_nXRojO0j`?o0000WonW`>/00ol0003oYl3[ojO0j`0EojO0jaCooooo00?o0000ooooooooool0
6_ooool001_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00001oooool2ohNfm0;oUk_a
1OnF`oH2oiC:nP?oXlC`0_nSa_87ojO2k@;oYl?]2OnW`N`7ojNoj`;oYkoZ8OnW`>/3o`000:?oYl3[
00?o0000ojO0jonW`>/05OnW`>/Dooooo`03o`000?oooooooooo01Wooooo000Kooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`07ooooo`CoUk_a0_nF`oH3oj?1k`?oXlC`
0onW`N`6ojO2k@WoYl7/2?nW_n/RojO0j`?o0000YonW`>/00ol0003oYl3[ojO0j`0DojO0jaCooooo
00?o0000ooooooooool06Oooool002Gooooo00?o0000ooooooooool02?ooool2oiNkl@?oXko]1?nS
`Nl00onSa?3oYl7/ojO1k003ojO1k0;oYl;]2?nW`N`9ojNojb;oYl3[0ol0002ZojO0j`03o`000?nW
`>_oYl3[01GoYl3[4_ooool00ol0003oooooo`00000Jooooo`009Oooool00ol0003oooooooooo`0:
ooooo`CoXko]0_nS`Nl2ojK0k0CoYl7/00?oYl3/ojO1k?nW`N`01OnW`N`9ojNojb;oYl3[0ol0002^
ojO0j`03o`000?nW`>_oYl3[01GoYl3[5?ooool00ol0003oooooooooo`0Gooooo`009Oooool2o`00
00cooooo0_nS_nd2ojJok0CoY/3/00?oYl7/ojO0k?nW`>`00_nW`>`3ojO1k0WoYko[8onW`>/2o`00
0;;oYl3[00?o0000ojO0jonW`>/05OnW`>/Cooooo`03o`000?oooooooooo01Oooooo000Tooooo`03
o`000?oooooooooo00gooooo1?nV_n`2ojK0k0?oYl3[1?nW`>`00onW`NcoYko[ojNoj`05ojNojb?o
Yl3[0ol0002eojO0j`03o`000?nW`>_oYl3[01CoYl3[5?ooool00ol0003oooooooooo`0Fooooo`00
9?ooool00ol0003oooooooooo`0>ooooo`;oY[o/1onW`>/2ojO0k0;oYl3[1_nW_n/QojO0j`?o0000
^?nW`>/00ol0003oYl3[ojO0j`0EojO0jaCooooo00?o0000ooooooooool05Oooool002Cooooo0ol0
000?ooooo`goYl3[0_nW_n/QojO0j`?o0000_?nW`>/00ol0003oYl3[ojO0j`0EojO0ja;ooooo0_l0
0009ooooo`Co000000?o410@ooooooooool01oooool002Cooooo00?o0000ooooooooool04?ooool/
ojO0j`?o0000`?nW`>/00ol0003oYl3[ojO0j`0EojO0ja?ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`09ooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`Go00001_ooool00ol0003oooooooooo`0BooooobOoYl3[0ol00033ojO0j`03o`000?nW`>_o
Yl3[01GoYl3[5?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo0009oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A006ooooo`03o`000?oooooooooo01?ooooo8onW`>/3o`000<OoYl3[00?o0000ojO0jonW`>/05OnW
`>/Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool000Wooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool05Ooo
oolPojO0j`;o0000bonW`>/00ol0003oYl3[ojO0j`0EojO0ja?ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`09ooooo`002Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01Oooool3o`0001Kooooo7?nW`>/3o`000<koYl3[00?o0000ojO0jonW`>/05OnW
`>/Aooooo`?o00001oooool00ol0003oooooooooo`09ooooo`002Oooool01Ol0003ooooooooooooo
oooo000000kooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`0HoooooaOoYl3[0ol0
003AojO0j`03o`000?nW`>_oYl3[01GoYl3[3_ooool4o`000003ooooool0003ooooo00Kooooo00?o
0000ooooooooool02Oooool000Wooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool06OoooolCojO0j`?o0000eOnW`>/00ol0003oYl3[ojO0
j`0EojO0j`[ooooo0ol00005ooooo`03o`000?oooooooooo00?ooooo00?oEEEEofIVI_l000002ooo
ool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1Oooool2o`0001_ooooo3onW`>/3o`000=WoYl3[00?o0000ojO0jonW`>/05?nW`>/6ooooo`Co0000
2?ooool00ol0003oooooooooo`0Aooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo01_ooooo2onW`>/3o`000=co
Yl3[00?o0000ojO0jonW`>/05OnW`>/2ooooo`?o00003?ooool00ol0003oooooooooo`0Aooooo`00
8_ooool00ol0003oooooooooo`0Mooooo`OoYl3[0ol0003PojO0j`03o`000?nW`>_oYl3[01GoYl3[
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0003ooooooooo
o`0Nooooo`CoYl3[0_l0003TojO0j`03o`000?nW`>_oYl3[01GoYl3[4?ooool00ol0003ooooooooo
o`0@ooooo`008_ooool2o`00023ooooo0ol0003WojO0j`03o`000?nW`>_oYl3[01CoYl3[4?ooool0
0ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0Looooo`?o000000?oooooojO0
jonW`>/0ionW`>/00ol0003oYl3[ojO0j`0EojO0j`oooooo00?o0000ooooooooool04?ooool002;o
oooo00?o0000ooooooooool06Oooool3o`0000Koooooj?nW`>/00ol0003oYl3[ojO0j`0DojO0j`oo
oooo00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool05_ooool3o`0000[ooooo
j?nW`>/00ol0003oYl3[ojO0j`0DojO0j`kooooo00?o0000ooooooooool04?ooool002;ooooo0_l0
000Dooooo`?o00003_oooooXojO0j`03o`000?nW`>_oYl3[01CoYl3[3Oooool00ol0003ooooooooo
o`0@ooooo`008Oooool2o`0001;ooooo0ol0000BooooonOoYl3[00?o0000ojO0jonW`>/05OnW`>/<
ooooo`03o`000?oooooooooo013ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00oooooo0_l0000F
ooooonOoYl3[00?o0000ojO0jonW`>/05?nW`>/=ooooo`03o`000?oooooooooo00oooooo0007oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0<ooooo`?o00006OoooooWojO0j`03o`000?nW`>_oYl3[01CoYl3[3?ooool0
0ol0003oooooooooo`0?ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00005
ooooo`;o00002_ooool3o`0001goooooi_nW`>/00ol0003oYl3[ojO0j`0EojO0j`_ooooo00?o0000
ooooooooool03oooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgo
ooooo`0000Kooooo00?o0000ooooooooool01_ooool3o`00027oooooi_nW`>/00ol0003oYl3[ojO0
j`0EojO0j`[ooooo00?o0000ooooooooool03oooool000Oooooo00Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool00oooool3o`0002Kooooo
iOnW`>/00ol0003oYl3[ojO0j`0DojO0j`[ooooo00?o0000ooooooooool03oooool000Oooooo00Go
410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Gooooo00Co0000oooooooooooo
oooo0ol0000ZooooonGoYl3[00?o0000ojO0jonW`>/05?nW`>/9ooooo`03o`000?oooooooooo00oo
oooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000005ooooo`Co
0000;_oooooTojO0j`03o`000?nW`>_oYl3[01CoYl3[2Oooool00ol0003oooooooooo`0?ooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01?ooool2o`00037o
ooooi?nW`>/00ol0003oYl3[ojO0j`0DojO0j`Sooooo00?o0000ooooooooool03oooool002;ooooo
00?o0000ooooooooool0;ooooooTojO0j`03o`000?nW`>_oYl3[01?oYl3[2Oooool00ol0003ooooo
ooooo`0>ooooo`008oooool00ol0003oooooooooo`0_ooooon?oYl3[00?o0000ojO0jonW`>/05?nW
`>/8ooooo`03o`000?oooooooooo00kooooo000Tooooo`03o`000?oooooooooo02oooooohonW`>/0
0ol0003oYl3[ojO0j`0DojO0j`Oooooo00?o0000ooooooooool03_ooool002Gooooo0_l0000`oooo
on?oYl3[00?o0000ojO0jonW`>/05?nW`>/6ooooo`03o`000?oooooooooo00kooooo000Wooooo`03
o`000?oooooooooo02kooooohonW`>/00ol0003oYl3[ojO0j`0CojO0j`Kooooo00?o0000oooooooo
ool03_ooool002Sooooo00?o0000ooooooooool0;_oooooRojO0j`03o`000?nW`>_oYl3[01CoYl3[
1Oooool00ol0003oooooooooo`0>ooooo`00:Oooool00ol0003oooooooooo`0_ooooon7oYl3[00?o
0000ojO0jonW`>/05?nW`>/4ooooo`03o`000?oooooooooo00kooooo000Zooooo`;o0000<OoooooP
ojO0j`03o`000?nW`>_oYl3[01CoYl3[0oooool00ol0003oooooooooo`0>ooooo`00;?ooool00ol0
003oooooooooo`0_ooooon3oYl3[00?o0000ojO0jonW`>/05?nW`>/3ooooo`03o`000?oooooooooo
00gooooo000]ooooo`03o`000?oooooooooo02oooooogonW`>/00ol0003oYl3[ojO0j`0DojO0j`?o
oooo00?o0000ooooooooool03Oooool002kooooo00?o0000ooooooooool0;ooooooOojO0j`03o`00
0?nW`>_oYl3[01CoYl3[0_ooool00ol0003oooooooooo`0=ooooo`00;oooool00ol0003ooooooooo
o`0_ooooomooYl3[00?o0000ojO0jonW`>/04onW`>/2ooooo`03o`000?oooooooooo00gooooo000`
ooooo`;o0000<?oooooNojO0j`03o`000?nW`>_oYl3[01CoYl3[00?oooooo`000?ooool03_ooool0
03;ooooo00?o0000ooooooooool0;_oooooNojO0j`03o`000?nW`>_oYl3[01?oYl3[00?oooooo`00
0?ooool03_ooool003?ooooo00?o0000ooooooooool0;_oooooNojO0j`03o`000?nW`>_oYl3[01?o
Yl3[00?o0000ooooooooool03Oooool003Cooooo00?o0000ooooooooool0;_oooooNojO0j`03o`00
0?nW`>_oYl3[017oYl3[00?oooooo`000?ooool03_ooool003Gooooo0_l0000_ooooomgoYl3[00?o
0000ojO0jonW`>/03OnW`>/6ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooo
oooo02kooooog?nW`>/00ol0003oYl3[ojO0j`09ojO0j`Wooooo00?o0000ooooooooool03?ooool0
03Sooooo00?o0000ooooooooool0;_oooooLojO0j`03o`000?nW`>_oYl3[00GoYl3[3?ooool00ol0
003oooooooooo`0<ooooo`00>Oooool00ol0003oooooooooo`0^ooooomcoYl3[00?o0000ojO0jonW
`>/04?ooool00ol0003oooooooooo`0<ooooo`00>_ooool2o`0002oooooofonW`>/00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00cooooo000looooo`03o`000?oooooooooo02goooooe_nW
`>/5ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03?ooool003gooooo00?o0000
ooooooooool0;OoooooBojO0j`Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<
ooooo`00?_ooool00ol0003oooooooooo`0]oooool[oYl3[4?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00cooooo000oooooo`;o0000;oooooo5ojO0jaCooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0;ooooo`00@Oooool00ol0003oooooooooo`0]oooool7oYl3[
6?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0012ooooo`03o`000?oo
oooooooo02gooooo_?nW`>/Mooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool004?ooooo00?o0000ooooooooool0;OoooonhojO0jb3ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`00A?ooool00ol0003oooooooooo`0]oooookCoYl3[9?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0015ooooo`;o0000;ooooon^ojO0jbWo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`00Aoooool00ol0003ooooo
ooooo`0]oooooj[oYl3[;?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
0018ooooo`03o`000?oooooooooo02goooooY_nW`>/`ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02oooool004Wooooo00?o0000ooooooooool0;OoooonRojO0jcCooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00B_ooool2o`0002koooooWOnW`>/ioooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool004cooooo00?o0000oooooooo
ool0;?oooonIojO0jccooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00
COooool00ol0003oooooooooo`0/oooooi;oYl3[@oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00[ooooo001>ooooo`03o`000?oooooooooo02goooooSOnW`>]7ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02_ooool004oooooo0_l0000^ooooohSoYl3[C?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo001Aooooo`03o`000?oooooooooo
02coooooQ?nW`>]?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool005;o
oooo00?o0000ooooooooool0:ooooon1ojO0je?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0:ooooo`00Doooool00ol0003oooooooooo`0[oooooggoYl3[Eoooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Wooooo001Dooooo`;o0000;OoooomhojO0je[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`00E_ooool00ol0003oooooooooo`0[
ooooogCoYl3[G_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo001Goooo
o`03o`000?oooooooooo02_oooooK?nW`>]Vooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02Oooool005Sooooo00?o0000ooooooooool0;?oooomWojO0jf[ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`00FOooool00ol0003oooooooooo`0/ooooof?oYl3[KOooool01Ol0003o
oooooooooooooooo000000_ooooo001Jooooo`;o0000;OoooomOojO0jg7ooooo00Co0000oooooooo
oooo00002oooool005cooooo00?o0000ooooooooool0:ooooomKojO0jgGooooo00?o0000ooooool0
00002oooool005gooooo00?o0000ooooooooool0:ooooomGojO0jgSooooo00Co0000oooooooooooo
00002_ooool005kooooo00?o0000ooooooooool0:ooooomCojO0jgcooooo00?o0000ooooool00000
2_ooool005oooooo0_l0000/ooooodcoYl3[Poooool2o`0000[ooooo001Qooooo`03o`000?oooooo
oooo02[oooooB?nW`>^5ooooo`?o00002_ooool006;ooooo00?o0000ooooooooool0:ooooom3ojO0
jhCooooo1?l0000=ooooo`00Hoooool00ol0003oooooooooo`0[ooooocooYl3[Poooool4o`00017o
oooo001Tooooo`;o0000;?oooolkojO0jh?ooooo0ol0000Eooooo`00I_ooool00ol0003ooooooooo
o`0[oooooc?oYl3[QOooool4o`0001Sooooo001Wooooo`03o`000?oooooooooo02[ooooo<?nW`>^4
ooooo`Co00007?ooool006Sooooo00?o0000ooooooooool0:_ooool/ojO0jh?ooooo1?l0000Poooo
o`00JOooool2o`0002cooooo9onW`>^2ooooo`Co00009?ooool006_ooooo00?o0000ooooooooool0
:_oooolSojO0jh;ooooo0ol0000Xooooo`00K?ooool00ol0003oooooooooo`0ZoooooagoYl3[Pooo
ool4o`0002_ooooo001]ooooo`03o`000?oooooooooo02_ooooo6?nW`>^2ooooo`Co0000;oooool0
06kooooo00?o0000ooooooooool0:_oooolEojO0jh7ooooo1?l0000cooooo`00Koooool2o`0002_o
oooo4OnW`>^0ooooo`Co0000=oooool0077ooooo00?o0000ooooooooool0:_ooool9ojO0jh;ooooo
1?l0000kooooo`00L_ooool00ol0003oooooooooo`0Zooooo`GoYl3[P_ooool3o`0003oooooo001c
ooooo`03o`000?oooooooooo02[ooooo00?oYl3[ooooooooool0Ooooool4o`0004;ooooo001doooo
o`;o0000:_ooool00ol0003oooooooooo`1kooooo`Co0000A_ooool007Kooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`1hooooo`Co0000B_ooool007Oooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1dooooo`Co0000C_ooool007Sooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1aooooo`?o0000D_ooool007Wooooo0_l0000Tooooo`03o`000?oooooo
oooo06gooooo1?l0001Eooooo`00Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
06Wooooo1?l0001Iooooo`00O?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06Go
oooo1?l0001Mooooo`00OOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo067ooooo
1?l0001Qooooo`00O_ooool2o`0001oooooo00?o0000ooooooooool0GOooool4o`0006Gooooo0020
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0F_ooool3o`0006Wooooo0021oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0E_ooool4o`0006cooooo0022ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0D_ooool4o`00073ooooo0023ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0C_ooool4o`0007Cooooo0024ooooo`;o00006Ooo
ool00ol0003oooooooooo`1:ooooo`Co0000N?ooool008Kooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`16ooooo`Co0000O?ooool008Oooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`13ooooo`?o0000P?ooool008Sooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0oooooo`Co0000Poooool008Wooooo0_l0000Dooooo`03o`000?oooooooooo03_ooooo
1?l00027ooooo`00Roooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Oooooo1?l0
002;ooooo`00S?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03?ooooo1?l0002?
ooooo`00SOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo033ooooo0ol0002Coooo
o`00S_ooool2o`0000oooooo00?o0000ooooooooool0;?ooool4o`0009Kooooo002@ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0:?ooool4o`0009[ooooo002Aooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool09?ooool4o`0009kooooo002Booooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool08Oooool4o`000:;ooooo002Cooooo`;o00002Oooool00ol0
003oooooooooo`0Mooooo`Co0000Y_ooool009Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Jooooo`?o0000Z_ooool009Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Fooooo`Co0000[Oooool009Oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Booooo`Co0000/Oooool009Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>
ooooo`Co0000]Oooool009Wooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo1?l0002ioooo
o`00Voooool01?l0003oooooooooool00009ooooo`?o0000_Oooool009cooooo00?o0000ooooool0
00001Oooool4o`000<3ooooo002Mooooo`;o000000?oooooo`000?l000000_l00034ooooo`00W_oo
ool2o`000<Sooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo002^ooooo`05oiRHV?l0003o0000odA4
A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o
0000ob4Q8Oo<c<`0Uoooool00:kooooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`Ko000000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q
09Oooooo002^ooooo`03o`000?oooooooooo00_ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool00000Uoooool00:kooooo00?o0000ooooooooool01?ooool6o`00
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So
<S8b09Oooooo002^ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05olc<c?l0003o0000o`000?o<c<`0Uoooool00:cooooo00?o410@o`000?l000000ol0000:
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@09Oooooo
002^ooooo`03o`000?oooooooooo00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l00000Uoooool00:kooooo00?o0000ooooooooool02oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2Gooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -17 0 ]
[.5 .82364 17 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69467 Mtetra
.4053 .69467 .41061 .69934 .41957 .69681 .41427 .69213 Mtetra
.41427 .69213 .41957 .69681 .42855 .69428 .42327 .68958 Mtetra
.42327 .68958 .42855 .69428 .43756 .69174 .43231 .68703 Mtetra
.43231 .68703 .43756 .69174 .4466 .68919 .44137 .68446 Mtetra
.44137 .68446 .4466 .68919 .45567 .68663 .45046 .68189 Mtetra
.45046 .68189 .45567 .68663 .46478 .68407 .45958 .67931 Mtetra
.45958 .67931 .46478 .68407 .47391 .68149 .46873 .67671 Mtetra
.46873 .67671 .47391 .68149 .48307 .67891 .47792 .67412 Mtetra
.47792 .67412 .48307 .67891 .49227 .67632 .48713 .67151 Mtetra
.48713 .67151 .49227 .67632 .50149 .67371 .49638 .66889 Mtetra
.49638 .66889 .50149 .67371 .51075 .6711 .50565 .66626 Mtetra
.50565 .66626 .51075 .6711 .52004 .66849 .51496 .66363 Mtetra
.51496 .66363 .52004 .66849 .52936 .66586 .5243 .66098 Mtetra
.5243 .66098 .52936 .66586 .53871 .66322 .53367 .65833 Mtetra
.53367 .65833 .53871 .66322 .54809 .66058 .54308 .65567 Mtetra
.54308 .65567 .54809 .66058 .55751 .65792 .55251 .653 Mtetra
.55251 .653 .55751 .65792 .56695 .65526 .56198 .65032 Mtetra
.56198 .65032 .56695 .65526 .57643 .65259 .57148 .64763 Mtetra
.57148 .64763 .57643 .65259 .58595 .6499 .58102 .64493 Mtetra
.58102 .64493 .58595 .6499 .59549 .64721 .59058 .64222 Mtetra
.59058 .64222 .59549 .64721 .60507 .64451 .60018 .6395 Mtetra
.60018 .6395 .60507 .64451 .61468 .6418 .60982 .63678 Mtetra
.60982 .63678 .61468 .6418 .62432 .63908 .61948 .63404 Mtetra
.61948 .63404 .62432 .63908 .634 .63636 .62918 .63129 Mtetra
.62918 .63129 .634 .63636 .64371 .63362 .63892 .62854 Mtetra
.63892 .62854 .64371 .63362 .65345 .63087 .64868 .62577 Mtetra
.64868 .62577 .65345 .63087 .66323 .62811 .65848 .623 Mtetra
.65848 .623 .66323 .62811 .67304 .62535 .66832 .62021 Mtetra
.66832 .62021 .67304 .62535 .68289 .62257 .67819 .61742 Mtetra
.67819 .61742 .68289 .62257 .69277 .61979 .68809 .61462 Mtetra
.68809 .61462 .69277 .61979 .70269 .61699 .69803 .6118 Mtetra
.69803 .6118 .70269 .61699 .71264 .61418 .70801 .60898 Mtetra
.70801 .60898 .71264 .61418 .72262 .61137 .71802 .60615 Mtetra
.71802 .60615 .72262 .61137 .73264 .60854 .72806 .6033 Mtetra
.72806 .6033 .73264 .60854 .7427 .60571 .73814 .60045 Mtetra
.73814 .60045 .7427 .60571 .75279 .60286 .74826 .59759 Mtetra
.74826 .59759 .75279 .60286 .76291 .60001 .75841 .59471 Mtetra
.75841 .59471 .76291 .60001 .77308 .59714 .7686 .59183 Mtetra
.7686 .59183 .77308 .59714 .78328 .59427 .77882 .58893 Mtetra
.77882 .58893 .78328 .59427 .79351 .59138 .78908 .58603 Mtetra
.78908 .58603 .79351 .59138 .80378 .58849 .79938 .58311 Mtetra
.79938 .58311 .80378 .58849 .81409 .58558 .80971 .58019 Mtetra
.80971 .58019 .81409 .58558 .82443 .58267 .82008 .57725 Mtetra
.82008 .57725 .82443 .58267 .83482 .57974 .83049 .57431 Mtetra
.83049 .57431 .83482 .57974 .84523 .5768 .84094 .57135 Mtetra
.84094 .57135 .84523 .5768 .85569 .57385 .85142 .56838 Mtetra
.85142 .56838 .85569 .57385 .86618 .57089 .86194 .5654 Mtetra
.86194 .5654 .86618 .57089 .87672 .56792 .8725 .56241 Mtetra
.8725 .56241 .87672 .56792 .88729 .56494 .8831 .55941 Mtetra
.8831 .55941 .88729 .56494 .89789 .56195 .89374 .5564 Mtetra
.89374 .5564 .89789 .56195 .90854 .55895 .90441 .55338 Mtetra
.90441 .55338 .90854 .55895 .91923 .55594 .91512 .55035 Mtetra
.91512 .55035 .91923 .55594 .92995 .55292 .92588 .5473 Mtetra
.92588 .5473 .92995 .55292 .94071 .54988 .93667 .54425 Mtetra
.93667 .54425 .94071 .54988 .95152 .54684 .9475 .54118 Mtetra
.9475 .54118 .95152 .54684 .96236 .54378 .95837 .53811 Mtetra
.95837 .53811 .96236 .54378 .97324 .54071 .96928 .53502 Mtetra
.96928 .53502 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.391 .69252 .39636 .6972 .4053 .69467 .39996 .68998 Mtetra
.39996 .68998 .4053 .69467 .41427 .69213 .40895 .68742 Mtetra
.40895 .68742 .41427 .69213 .42327 .68958 .41797 .68486 Mtetra
.41797 .68486 .42327 .68958 .43231 .68703 .42702 .68228 Mtetra
.42702 .68228 .43231 .68703 .44137 .68446 .4361 .6797 Mtetra
.4361 .6797 .44137 .68446 .45046 .68189 .44521 .67711 Mtetra
.44521 .67711 .45046 .68189 .45958 .67931 .45435 .67452 Mtetra
.45435 .67452 .45958 .67931 .46873 .67671 .46352 .67191 Mtetra
.46352 .67191 .46873 .67671 .47792 .67412 .47273 .66929 Mtetra
.47273 .66929 .47792 .67412 .48713 .67151 .48196 .66667 Mtetra
.48196 .66667 .48713 .67151 .49638 .66889 .49123 .66403 Mtetra
.49123 .66403 .49638 .66889 .50565 .66626 .50053 .66139 Mtetra
.50053 .66139 .50565 .66626 .51496 .66363 .50985 .65874 Mtetra
.50985 .65874 .51496 .66363 .5243 .66098 .51922 .65608 Mtetra
.51922 .65608 .5243 .66098 .53367 .65833 .52861 .65341 Mtetra
.52861 .65341 .53367 .65833 .54308 .65567 .53803 .65073 Mtetra
.53803 .65073 .54308 .65567 .55251 .653 .54749 .64804 Mtetra
.54749 .64804 .55251 .653 .56198 .65032 .55698 .64534 Mtetra
.55698 .64534 .56198 .65032 .57148 .64763 .5665 .64264 Mtetra
.5665 .64264 .57148 .64763 .58102 .64493 .57606 .63992 Mtetra
.57606 .63992 .58102 .64493 .59058 .64222 .58565 .6372 Mtetra
.58565 .6372 .59058 .64222 .60018 .6395 .59527 .63446 Mtetra
.59527 .63446 .60018 .6395 .60982 .63678 .60493 .63172 Mtetra
.60493 .63172 .60982 .63678 .61948 .63404 .61461 .62896 Mtetra
.61461 .62896 .61948 .63404 .62918 .63129 .62434 .6262 Mtetra
.62434 .6262 .62918 .63129 .63892 .62854 .63409 .62343 Mtetra
.63409 .62343 .63892 .62854 .64868 .62577 .64388 .62064 Mtetra
.64388 .62064 .64868 .62577 .65848 .623 .65371 .61785 Mtetra
.65371 .61785 .65848 .623 .66832 .62021 .66357 .61505 Mtetra
.66357 .61505 .66832 .62021 .67819 .61742 .67346 .61224 Mtetra
.67346 .61224 .67819 .61742 .68809 .61462 .68339 .60942 Mtetra
.68339 .60942 .68809 .61462 .69803 .6118 .69335 .60658 Mtetra
.69335 .60658 .69803 .6118 .70801 .60898 .70335 .60374 Mtetra
.70335 .60374 .70801 .60898 .71802 .60615 .71338 .60089 Mtetra
.71338 .60089 .71802 .60615 .72806 .6033 .72345 .59803 Mtetra
.72345 .59803 .72806 .6033 .73814 .60045 .73356 .59516 Mtetra
.73356 .59516 .73814 .60045 .74826 .59759 .7437 .59227 Mtetra
.7437 .59227 .74826 .59759 .75841 .59471 .75387 .58938 Mtetra
.75387 .58938 .75841 .59471 .7686 .59183 .76409 .58648 Mtetra
.76409 .58648 .7686 .59183 .77882 .58893 .77434 .58356 Mtetra
.77434 .58356 .77882 .58893 .78908 .58603 .78462 .58064 Mtetra
.78462 .58064 .78908 .58603 .79938 .58311 .79495 .57771 Mtetra
.79495 .57771 .79938 .58311 .80971 .58019 .80531 .57476 Mtetra
.80531 .57476 .80971 .58019 .82008 .57725 .81571 .57181 Mtetra
.81571 .57181 .82008 .57725 .83049 .57431 .82614 .56884 Mtetra
.82614 .56884 .83049 .57431 .84094 .57135 .83661 .56586 Mtetra
.83661 .56586 .84094 .57135 .85142 .56838 .84712 .56288 Mtetra
.84712 .56288 .85142 .56838 .86194 .5654 .85767 .55988 Mtetra
.85767 .55988 .86194 .5654 .8725 .56241 .86826 .55687 Mtetra
.86826 .55687 .8725 .56241 .8831 .55941 .87889 .55385 Mtetra
.87889 .55385 .8831 .55941 .89374 .5564 .88955 .55082 Mtetra
.88955 .55082 .89374 .5564 .90441 .55338 .90025 .54777 Mtetra
.90025 .54777 .90441 .55338 .91512 .55035 .911 .54472 Mtetra
.911 .54472 .91512 .55035 .92588 .5473 .92178 .54166 Mtetra
.92178 .54166 .92588 .5473 .93667 .54425 .9326 .53858 Mtetra
.9326 .53858 .93667 .54425 .9475 .54118 .94346 .53549 Mtetra
.94346 .53549 .9475 .54118 .95837 .53811 .95436 .53239 Mtetra
.95436 .53239 .95837 .53811 .96928 .53502 .9653 .52928 Mtetra
.9653 .52928 .96928 .53502 .98024 .53192 .97628 .52616 Mtetra
.38561 .68781 .391 .69252 .39996 .68998 .39459 .68525 Mtetra
.39459 .68525 .39996 .68998 .40895 .68742 .40359 .68268 Mtetra
.40359 .68268 .40895 .68742 .41797 .68486 .41263 .6801 Mtetra
.41263 .6801 .41797 .68486 .42702 .68228 .4217 .67751 Mtetra
.4217 .67751 .42702 .68228 .4361 .6797 .4308 .67492 Mtetra
.4308 .67492 .4361 .6797 .44521 .67711 .43993 .67231 Mtetra
.43993 .67231 .44521 .67711 .45435 .67452 .44909 .6697 Mtetra
.44909 .6697 .45435 .67452 .46352 .67191 .45828 .66707 Mtetra
.45828 .66707 .46352 .67191 .47273 .66929 .46751 .66444 Mtetra
.46751 .66444 .47273 .66929 .48196 .66667 .47676 .6618 Mtetra
.47676 .6618 .48196 .66667 .49123 .66403 .48605 .65915 Mtetra
.48605 .65915 .49123 .66403 .50053 .66139 .49537 .65649 Mtetra
.49537 .65649 .50053 .66139 .50985 .65874 .50472 .65382 Mtetra
.50472 .65382 .50985 .65874 .51922 .65608 .5141 .65114 Mtetra
.5141 .65114 .51922 .65608 .52861 .65341 .52351 .64846 Mtetra
.52351 .64846 .52861 .65341 .53803 .65073 .53296 .64576 Mtetra
.53296 .64576 .53803 .65073 .54749 .64804 .54244 .64305 Mtetra
.54244 .64305 .54749 .64804 .55698 .64534 .55195 .64034 Mtetra
.55195 .64034 .55698 .64534 .5665 .64264 .56149 .63762 Mtetra
.56149 .63762 .5665 .64264 .57606 .63992 .57107 .63488 Mtetra
.57107 .63488 .57606 .63992 .58565 .6372 .58068 .63214 Mtetra
.58068 .63214 .58565 .6372 .59527 .63446 .59032 .62939 Mtetra
.59032 .62939 .59527 .63446 .60493 .63172 .6 .62663 Mtetra
.6 .62663 .60493 .63172 .61461 .62896 .60971 .62385 Mtetra
.60971 .62385 .61461 .62896 .62434 .6262 .61946 .62107 Mtetra
.61946 .62107 .62434 .6262 .63409 .62343 .62924 .61828 Mtetra
.62924 .61828 .63409 .62343 .64388 .62064 .63905 .61548 Mtetra
.63905 .61548 .64388 .62064 .65371 .61785 .6489 .61267 Mtetra
.6489 .61267 .65371 .61785 .66357 .61505 .65878 .60985 Mtetra
.65878 .60985 .66357 .61505 .67346 .61224 .6687 .60702 Mtetra
.6687 .60702 .67346 .61224 .68339 .60942 .67865 .60418 Mtetra
.67865 .60418 .68339 .60942 .69335 .60658 .68864 .60133 Mtetra
.68864 .60133 .69335 .60658 .70335 .60374 .69866 .59847 Mtetra
.69866 .59847 .70335 .60374 .71338 .60089 .70872 .5956 Mtetra
.70872 .5956 .71338 .60089 .72345 .59803 .71881 .59272 Mtetra
.71881 .59272 .72345 .59803 .73356 .59516 .72894 .58983 Mtetra
.72894 .58983 .73356 .59516 .7437 .59227 .73911 .58692 Mtetra
.73911 .58692 .7437 .59227 .75387 .58938 .74931 .58401 Mtetra
.74931 .58401 .75387 .58938 .76409 .58648 .75955 .58109 Mtetra
.75955 .58109 .76409 .58648 .77434 .58356 .76982 .57816 Mtetra
.76982 .57816 .77434 .58356 .78462 .58064 .78014 .57521 Mtetra
.78014 .57521 .78462 .58064 .79495 .57771 .79049 .57226 Mtetra
.79049 .57226 .79495 .57771 .80531 .57476 .80087 .5693 Mtetra
.80087 .5693 .80531 .57476 .81571 .57181 .8113 .56632 Mtetra
.8113 .56632 .81571 .57181 .82614 .56884 .82176 .56334 Mtetra
.82176 .56334 .82614 .56884 .83661 .56586 .83226 .56034 Mtetra
.83226 .56034 .83661 .56586 .84712 .56288 .8428 .55733 Mtetra
.8428 .55733 .84712 .56288 .85767 .55988 .85337 .55431 Mtetra
.85337 .55431 .85767 .55988 .86826 .55687 .86399 .55128 Mtetra
.86399 .55128 .86826 .55687 .87889 .55385 .87464 .54824 Mtetra
.87464 .54824 .87889 .55385 .88955 .55082 .88533 .54519 Mtetra
.88533 .54519 .88955 .55082 .90025 .54777 .89607 .54213 Mtetra
.89607 .54213 .90025 .54777 .911 .54472 .90684 .53905 Mtetra
.90684 .53905 .911 .54472 .92178 .54166 .91765 .53597 Mtetra
.91765 .53597 .92178 .54166 .9326 .53858 .9285 .53287 Mtetra
.9285 .53287 .9326 .53858 .94346 .53549 .93939 .52976 Mtetra
.93939 .52976 .94346 .53549 .95436 .53239 .95032 .52664 Mtetra
.95032 .52664 .95436 .53239 .9653 .52928 .96129 .52351 Mtetra
.96129 .52351 .9653 .52928 .97628 .52616 .9723 .52037 Mtetra
.38018 .68308 .38561 .68781 .39459 .68525 .38918 .6805 Mtetra
.38918 .6805 .39459 .68525 .40359 .68268 .3982 .67791 Mtetra
.3982 .67791 .40359 .68268 .41263 .6801 .40726 .67532 Mtetra
.40726 .67532 .41263 .6801 .4217 .67751 .41635 .67271 Mtetra
.41635 .67271 .4217 .67751 .4308 .67492 .42547 .6701 Mtetra
.42547 .6701 .4308 .67492 .43993 .67231 .43462 .66748 Mtetra
.43462 .66748 .43993 .67231 .44909 .6697 .4438 .66485 Mtetra
.4438 .66485 .44909 .6697 .45828 .66707 .45301 .66221 Mtetra
.45301 .66221 .45828 .66707 .46751 .66444 .46225 .65956 Mtetra
.46225 .65956 .46751 .66444 .47676 .6618 .47153 .6569 Mtetra
.47153 .6569 .47676 .6618 .48605 .65915 .48083 .65423 Mtetra
.48083 .65423 .48605 .65915 .49537 .65649 .49017 .65156 Mtetra
.49017 .65156 .49537 .65649 .50472 .65382 .49954 .64887 Mtetra
.49954 .64887 .50472 .65382 .5141 .65114 .50895 .64618 Mtetra
.50895 .64618 .5141 .65114 .52351 .64846 .51838 .64347 Mtetra
.51838 .64347 .52351 .64846 .53296 .64576 .52785 .64076 Mtetra
.52785 .64076 .53296 .64576 .54244 .64305 .53735 .63804 Mtetra
.53735 .63804 .54244 .64305 .55195 .64034 .54688 .6353 Mtetra
.54688 .6353 .55195 .64034 .56149 .63762 .55645 .63256 Mtetra
.55645 .63256 .56149 .63762 .57107 .63488 .56605 .62981 Mtetra
.56605 .62981 .57107 .63488 .58068 .63214 .57568 .62705 Mtetra
.57568 .62705 .58068 .63214 .59032 .62939 .58535 .62428 Mtetra
.58535 .62428 .59032 .62939 .6 .62663 .59505 .6215 Mtetra
.59505 .6215 .6 .62663 .60971 .62385 .60478 .61871 Mtetra
.60478 .61871 .60971 .62385 .61946 .62107 .61455 .61591 Mtetra
.61455 .61591 .61946 .62107 .62924 .61828 .62435 .6131 Mtetra
.62435 .6131 .62924 .61828 .63905 .61548 .63419 .61028 Mtetra
.63419 .61028 .63905 .61548 .6489 .61267 .64406 .60746 Mtetra
.64406 .60746 .6489 .61267 .65878 .60985 .65396 .60462 Mtetra
.65396 .60462 .65878 .60985 .6687 .60702 .66391 .60177 Mtetra
.66391 .60177 .6687 .60702 .67865 .60418 .67388 .59891 Mtetra
.67388 .59891 .67865 .60418 .68864 .60133 .68389 .59604 Mtetra
.68389 .59604 .68864 .60133 .69866 .59847 .69394 .59316 Mtetra
.69394 .59316 .69866 .59847 .70872 .5956 .70402 .59027 Mtetra
.70402 .59027 .70872 .5956 .71881 .59272 .71414 .58737 Mtetra
.71414 .58737 .71881 .59272 .72894 .58983 .7243 .58446 Mtetra
.7243 .58446 .72894 .58983 .73911 .58692 .73449 .58154 Mtetra
.73449 .58154 .73911 .58692 .74931 .58401 .74472 .57861 Mtetra
.74472 .57861 .74931 .58401 .75955 .58109 .75498 .57567 Mtetra
.75498 .57567 .75955 .58109 .76982 .57816 .76528 .57272 Mtetra
.76528 .57272 .76982 .57816 .78014 .57521 .77562 .56975 Mtetra
.77562 .56975 .78014 .57521 .79049 .57226 .786 .56678 Mtetra
.786 .56678 .79049 .57226 .80087 .5693 .79641 .5638 Mtetra
.79641 .5638 .80087 .5693 .8113 .56632 .80686 .5608 Mtetra
.80686 .5608 .8113 .56632 .82176 .56334 .81735 .55779 Mtetra
.81735 .55779 .82176 .56334 .83226 .56034 .82788 .55478 Mtetra
.82788 .55478 .83226 .56034 .8428 .55733 .83844 .55175 Mtetra
.83844 .55175 .8428 .55733 .85337 .55431 .84905 .54871 Mtetra
.84905 .54871 .85337 .55431 .86399 .55128 .85969 .54566 Mtetra
.85969 .54566 .86399 .55128 .87464 .54824 .87037 .5426 Mtetra
.87037 .5426 .87464 .54824 .88533 .54519 .88109 .53953 Mtetra
.88109 .53953 .88533 .54519 .89607 .54213 .89185 .53644 Mtetra
.89185 .53644 .89607 .54213 .90684 .53905 .90265 .53335 Mtetra
.90265 .53335 .90684 .53905 .91765 .53597 .91349 .53024 Mtetra
.91349 .53024 .91765 .53597 .9285 .53287 .92437 .52712 Mtetra
.92437 .52712 .9285 .53287 .93939 .52976 .93529 .524 Mtetra
.93529 .524 .93939 .52976 .95032 .52664 .94625 .52085 Mtetra
.94625 .52085 .95032 .52664 .96129 .52351 .95725 .5177 Mtetra
.95725 .5177 .96129 .52351 .9723 .52037 .96829 .51454 Mtetra
.37472 .67831 .38018 .68308 .38918 .6805 .38373 .67572 Mtetra
.38373 .67572 .38918 .6805 .3982 .67791 .39278 .67311 Mtetra
.39278 .67311 .3982 .67791 .40726 .67532 .40186 .6705 Mtetra
.40186 .6705 .40726 .67532 .41635 .67271 .41096 .66788 Mtetra
.41096 .66788 .41635 .67271 .42547 .6701 .4201 .66525 Mtetra
.4201 .66525 .42547 .6701 .43462 .66748 .42927 .66261 Mtetra
.42927 .66261 .43462 .66748 .4438 .66485 .43847 .65996 Mtetra
.43847 .65996 .4438 .66485 .45301 .66221 .4477 .65731 Mtetra
.4477 .65731 .45301 .66221 .46225 .65956 .45697 .65464 Mtetra
.45697 .65464 .46225 .65956 .47153 .6569 .46626 .65197 Mtetra
.46626 .65197 .47153 .6569 .48083 .65423 .47559 .64928 Mtetra
.47559 .64928 .48083 .65423 .49017 .65156 .48495 .64659 Mtetra
.48495 .64659 .49017 .65156 .49954 .64887 .49434 .64389 Mtetra
.49434 .64389 .49954 .64887 .50895 .64618 .50376 .64118 Mtetra
.50376 .64118 .50895 .64618 .51838 .64347 .51322 .63846 Mtetra
.51322 .63846 .51838 .64347 .52785 .64076 .52271 .63572 Mtetra
.52271 .63572 .52785 .64076 .53735 .63804 .53223 .63298 Mtetra
.53223 .63298 .53735 .63804 .54688 .6353 .54178 .63024 Mtetra
.54178 .63024 .54688 .6353 .55645 .63256 .55137 .62748 Mtetra
.55137 .62748 .55645 .63256 .56605 .62981 .56099 .62471 Mtetra
.56099 .62471 .56605 .62981 .57568 .62705 .57065 .62193 Mtetra
.57065 .62193 .57568 .62705 .58535 .62428 .58034 .61914 Mtetra
.58034 .61914 .58535 .62428 .59505 .6215 .59006 .61634 Mtetra
.59006 .61634 .59505 .6215 .60478 .61871 .59982 .61354 Mtetra
.59982 .61354 .60478 .61871 .61455 .61591 .60961 .61072 Mtetra
.60961 .61072 .61455 .61591 .62435 .6131 .61943 .60789 Mtetra
.61943 .60789 .62435 .6131 .63419 .61028 .62929 .60505 Mtetra
.62929 .60505 .63419 .61028 .64406 .60746 .63919 .60221 Mtetra
.63919 .60221 .64406 .60746 .65396 .60462 .64912 .59935 Mtetra
.64912 .59935 .65396 .60462 .66391 .60177 .65908 .59648 Mtetra
.65908 .59648 .66391 .60177 .67388 .59891 .66908 .5936 Mtetra
.66908 .5936 .67388 .59891 .68389 .59604 .67912 .59072 Mtetra
.67912 .59072 .68389 .59604 .69394 .59316 .68919 .58782 Mtetra
.68919 .58782 .69394 .59316 .70402 .59027 .6993 .58491 Mtetra
.6993 .58491 .70402 .59027 .71414 .58737 .70944 .58199 Mtetra
.70944 .58199 .71414 .58737 .7243 .58446 .71962 .57906 Mtetra
.71962 .57906 .7243 .58446 .73449 .58154 .72984 .57612 Mtetra
.72984 .57612 .73449 .58154 .74472 .57861 .74009 .57317 Mtetra
.74009 .57317 .74472 .57861 .75498 .57567 .75038 .57021 Mtetra
.75038 .57021 .75498 .57567 .76528 .57272 .76071 .56724 Mtetra
.76071 .56724 .76528 .57272 .77562 .56975 .77107 .56426 Mtetra
.77107 .56426 .77562 .56975 .786 .56678 .78148 .56126 Mtetra
.78148 .56126 .786 .56678 .79641 .5638 .79192 .55826 Mtetra
.79192 .55826 .79641 .5638 .80686 .5608 .80239 .55524 Mtetra
.80239 .55524 .80686 .5608 .81735 .55779 .81291 .55222 Mtetra
.81291 .55222 .81735 .55779 .82788 .55478 .82346 .54918 Mtetra
.82346 .54918 .82788 .55478 .83844 .55175 .83406 .54613 Mtetra
.83406 .54613 .83844 .55175 .84905 .54871 .84469 .54307 Mtetra
.84469 .54307 .84905 .54871 .85969 .54566 .85536 .54 Mtetra
.85536 .54 .85969 .54566 .87037 .5426 .86607 .53692 Mtetra
.86607 .53692 .87037 .5426 .88109 .53953 .87682 .53383 Mtetra
.87682 .53383 .88109 .53953 .89185 .53644 .88761 .53072 Mtetra
.88761 .53072 .89185 .53644 .90265 .53335 .89844 .52761 Mtetra
.89844 .52761 .90265 .53335 .91349 .53024 .90931 .52448 Mtetra
.90931 .52448 .91349 .53024 .92437 .52712 .92022 .52134 Mtetra
.92022 .52134 .92437 .52712 .93529 .524 .93116 .51819 Mtetra
.93116 .51819 .93529 .524 .94625 .52085 .94216 .51503 Mtetra
.94216 .51503 .94625 .52085 .95725 .5177 .95319 .51185 Mtetra
.95319 .51185 .95725 .5177 .96829 .51454 .96426 .50866 Mtetra
.36922 .67351 .37472 .67831 .38373 .67572 .37826 .6709 Mtetra
.37826 .6709 .38373 .67572 .39278 .67311 .38732 .66828 Mtetra
.38732 .66828 .39278 .67311 .40186 .6705 .39642 .66566 Mtetra
.39642 .66566 .40186 .6705 .41096 .66788 .40554 .66302 Mtetra
.40554 .66302 .41096 .66788 .4201 .66525 .4147 .66037 Mtetra
.4147 .66037 .4201 .66525 .42927 .66261 .42389 .65772 Mtetra
.42389 .65772 .42927 .66261 .43847 .65996 .43311 .65505 Mtetra
.43311 .65505 .43847 .65996 .4477 .65731 .44236 .65238 Mtetra
.44236 .65238 .4477 .65731 .45697 .65464 .45165 .6497 Mtetra
.45165 .6497 .45697 .65464 .46626 .65197 .46096 .64701 Mtetra
.46096 .64701 .46626 .65197 .47559 .64928 .47031 .6443 Mtetra
.47031 .6443 .47559 .64928 .48495 .64659 .47969 .64159 Mtetra
.47969 .64159 .48495 .64659 .49434 .64389 .4891 .63887 Mtetra
.4891 .63887 .49434 .64389 .50376 .64118 .49855 .63615 Mtetra
.49855 .63615 .50376 .64118 .51322 .63846 .50802 .63341 Mtetra
.50802 .63341 .51322 .63846 .52271 .63572 .51753 .63066 Mtetra
.51753 .63066 .52271 .63572 .53223 .63298 .52708 .6279 Mtetra
.52708 .6279 .53223 .63298 .54178 .63024 .53665 .62513 Mtetra
.53665 .62513 .54178 .63024 .55137 .62748 .54626 .62236 Mtetra
.54626 .62236 .55137 .62748 .56099 .62471 .55591 .61957 Mtetra
.55591 .61957 .56099 .62471 .57065 .62193 .56558 .61677 Mtetra
.56558 .61677 .57065 .62193 .58034 .61914 .57529 .61397 Mtetra
.57529 .61397 .58034 .61914 .59006 .61634 .58504 .61115 Mtetra
.58504 .61115 .59006 .61634 .59982 .61354 .59482 .60833 Mtetra
.59482 .60833 .59982 .61354 .60961 .61072 .60463 .60549 Mtetra
.60463 .60549 .60961 .61072 .61943 .60789 .61448 .60265 Mtetra
.61448 .60265 .61943 .60789 .62929 .60505 .62437 .59979 Mtetra
.62437 .59979 .62929 .60505 .63919 .60221 .63428 .59692 Mtetra
.63428 .59692 .63919 .60221 .64912 .59935 .64424 .59405 Mtetra
.64424 .59405 .64912 .59935 .65908 .59648 .65423 .59116 Mtetra
.65423 .59116 .65908 .59648 .66908 .5936 .66425 .58826 Mtetra
.66425 .58826 .66908 .5936 .67912 .59072 .67431 .58536 Mtetra
.67431 .58536 .67912 .59072 .68919 .58782 .68441 .58244 Mtetra
.68441 .58244 .68919 .58782 .6993 .58491 .69454 .57951 Mtetra
.69454 .57951 .6993 .58491 .70944 .58199 .70471 .57657 Mtetra
.70471 .57657 .70944 .58199 .71962 .57906 .71491 .57363 Mtetra
.71491 .57363 .71962 .57906 .72984 .57612 .72516 .57067 Mtetra
.72516 .57067 .72984 .57612 .74009 .57317 .73544 .5677 Mtetra
.73544 .5677 .74009 .57317 .75038 .57021 .74575 .56471 Mtetra
.74575 .56471 .75038 .57021 .76071 .56724 .75611 .56172 Mtetra
.75611 .56172 .76071 .56724 .77107 .56426 .7665 .55872 Mtetra
.7665 .55872 .77107 .56426 .78148 .56126 .77693 .55571 Mtetra
.77693 .55571 .78148 .56126 .79192 .55826 .78739 .55268 Mtetra
.78739 .55268 .79192 .55826 .80239 .55524 .7979 .54965 Mtetra
.7979 .54965 .80239 .55524 .81291 .55222 .80844 .5466 Mtetra
.80844 .5466 .81291 .55222 .82346 .54918 .81902 .54354 Mtetra
.81902 .54354 .82346 .54918 .83406 .54613 .82964 .54047 Mtetra
.82964 .54047 .83406 .54613 .84469 .54307 .8403 .53739 Mtetra
.8403 .53739 .84469 .54307 .85536 .54 .851 .5343 Mtetra
.851 .5343 .85536 .54 .86607 .53692 .86174 .5312 Mtetra
.86174 .5312 .86607 .53692 .87682 .53383 .87252 .52809 Mtetra
.87252 .52809 .87682 .53383 .88761 .53072 .88334 .52496 Mtetra
.88334 .52496 .88761 .53072 .89844 .52761 .89419 .52182 Mtetra
.89419 .52182 .89844 .52761 .90931 .52448 .90509 .51867 Mtetra
.90509 .51867 .90931 .52448 .92022 .52134 .91603 .51551 Mtetra
.91603 .51551 .92022 .52134 .93116 .51819 .92701 .51234 Mtetra
.92701 .51234 .93116 .51819 .94216 .51503 .93803 .50916 Mtetra
.93803 .50916 .94216 .51503 .95319 .51185 .94909 .50596 Mtetra
.94909 .50596 .95319 .51185 .96426 .50866 .9602 .50275 Mtetra
.36369 .66869 .36922 .67351 .37826 .6709 .37275 .66606 Mtetra
.37275 .66606 .37826 .6709 .38732 .66828 .38183 .66342 Mtetra
.38183 .66342 .38732 .66828 .39642 .66566 .39094 .66078 Mtetra
.39094 .66078 .39642 .66566 .40554 .66302 .40009 .65813 Mtetra
.40009 .65813 .40554 .66302 .4147 .66037 .40927 .65546 Mtetra
.40927 .65546 .4147 .66037 .42389 .65772 .41848 .65279 Mtetra
.41848 .65279 .42389 .65772 .43311 .65505 .42772 .65011 Mtetra
.42772 .65011 .43311 .65505 .44236 .65238 .43699 .64742 Mtetra
.43699 .64742 .44236 .65238 .45165 .6497 .44629 .64472 Mtetra
.44629 .64472 .45165 .6497 .46096 .64701 .45563 .64201 Mtetra
.45563 .64201 .46096 .64701 .47031 .6443 .465 .63929 Mtetra
.465 .63929 .47031 .6443 .47969 .64159 .4744 .63657 Mtetra
.4744 .63657 .47969 .64159 .4891 .63887 .48383 .63383 Mtetra
.48383 .63383 .4891 .63887 .49855 .63615 .4933 .63108 Mtetra
.4933 .63108 .49855 .63615 .50802 .63341 .50279 .62833 Mtetra
.50279 .62833 .50802 .63341 .51753 .63066 .51233 .62556 Mtetra
.51233 .62556 .51753 .63066 .52708 .6279 .52189 .62279 Mtetra
.52189 .62279 .52708 .6279 .53665 .62513 .53149 .62 Mtetra
.53149 .62 .53665 .62513 .54626 .62236 .54112 .61721 Mtetra
.54112 .61721 .54626 .62236 .55591 .61957 .55079 .6144 Mtetra
.55079 .6144 .55591 .61957 .56558 .61677 .56049 .61159 Mtetra
.56049 .61159 .56558 .61677 .57529 .61397 .57022 .60876 Mtetra
.57022 .60876 .57529 .61397 .58504 .61115 .57999 .60593 Mtetra
.57999 .60593 .58504 .61115 .59482 .60833 .58979 .60308 Mtetra
.58979 .60308 .59482 .60833 .60463 .60549 .59963 .60023 Mtetra
.59963 .60023 .60463 .60549 .61448 .60265 .6095 .59737 Mtetra
.6095 .59737 .61448 .60265 .62437 .59979 .61941 .59449 Mtetra
.61941 .59449 .62437 .59979 .63428 .59692 .62935 .59161 Mtetra
.62935 .59161 .63428 .59692 .64424 .59405 .63933 .58871 Mtetra
.63933 .58871 .64424 .59405 .65423 .59116 .64934 .58581 Mtetra
.64934 .58581 .65423 .59116 .66425 .58826 .65939 .58289 Mtetra
.65939 .58289 .66425 .58826 .67431 .58536 .66947 .57996 Mtetra
.66947 .57996 .67431 .58536 .68441 .58244 .67959 .57703 Mtetra
.67959 .57703 .68441 .58244 .69454 .57951 .68975 .57408 Mtetra
.68975 .57408 .69454 .57951 .70471 .57657 .69995 .57112 Mtetra
.69995 .57112 .70471 .57657 .71491 .57363 .71018 .56815 Mtetra
.71018 .56815 .71491 .57363 .72516 .57067 .72044 .56517 Mtetra
.72044 .56517 .72516 .57067 .73544 .5677 .73075 .56218 Mtetra
.73075 .56218 .73544 .5677 .74575 .56471 .74109 .55918 Mtetra
.74109 .55918 .74575 .56471 .75611 .56172 .75147 .55617 Mtetra
.75147 .55617 .75611 .56172 .7665 .55872 .76189 .55315 Mtetra
.76189 .55315 .7665 .55872 .77693 .55571 .77234 .55012 Mtetra
.77234 .55012 .77693 .55571 .78739 .55268 .78284 .54707 Mtetra
.78284 .54707 .78739 .55268 .7979 .54965 .79337 .54401 Mtetra
.79337 .54401 .7979 .54965 .80844 .5466 .80394 .54095 Mtetra
.80394 .54095 .80844 .5466 .81902 .54354 .81455 .53787 Mtetra
.81455 .53787 .81902 .54354 .82964 .54047 .8252 .53478 Mtetra
.8252 .53478 .82964 .54047 .8403 .53739 .83589 .53168 Mtetra
.83589 .53168 .8403 .53739 .851 .5343 .84661 .52857 Mtetra
.84661 .52857 .851 .5343 .86174 .5312 .85738 .52544 Mtetra
.85738 .52544 .86174 .5312 .87252 .52809 .86819 .52231 Mtetra
.86819 .52231 .87252 .52809 .88334 .52496 .87903 .51916 Mtetra
.87903 .51916 .88334 .52496 .89419 .52182 .88992 .516 Mtetra
.88992 .516 .89419 .52182 .90509 .51867 .90085 .51283 Mtetra
.90085 .51283 .90509 .51867 .91603 .51551 .91182 .50965 Mtetra
.91182 .50965 .91603 .51551 .92701 .51234 .92283 .50645 Mtetra
.92283 .50645 .92701 .51234 .93803 .50916 .93388 .50324 Mtetra
.93388 .50324 .93803 .50916 .94909 .50596 .94497 .50003 Mtetra
.94497 .50003 .94909 .50596 .9602 .50275 .9561 .4968 Mtetra
.35813 .66383 .36369 .66869 .37275 .66606 .3672 .66119 Mtetra
.3672 .66119 .37275 .66606 .38183 .66342 .3763 .65854 Mtetra
.3763 .65854 .38183 .66342 .39094 .66078 .38544 .65587 Mtetra
.38544 .65587 .39094 .66078 .40009 .65813 .3946 .6532 Mtetra
.3946 .6532 .40009 .65813 .40927 .65546 .4038 .65052 Mtetra
.4038 .65052 .40927 .65546 .41848 .65279 .41303 .64783 Mtetra
.41303 .64783 .41848 .65279 .42772 .65011 .42229 .64514 Mtetra
.42229 .64514 .42772 .65011 .43699 .64742 .43158 .64243 Mtetra
.43158 .64243 .43699 .64742 .44629 .64472 .4409 .63971 Mtetra
.4409 .63971 .44629 .64472 .45563 .64201 .45026 .63699 Mtetra
.45026 .63699 .45563 .64201 .465 .63929 .45965 .63425 Mtetra
.45965 .63425 .465 .63929 .4744 .63657 .46907 .63151 Mtetra
.46907 .63151 .4744 .63657 .48383 .63383 .47853 .62875 Mtetra
.47853 .62875 .48383 .63383 .4933 .63108 .48801 .62599 Mtetra
.48801 .62599 .4933 .63108 .50279 .62833 .49753 .62321 Mtetra
.49753 .62321 .50279 .62833 .51233 .62556 .50709 .62043 Mtetra
.50709 .62043 .51233 .62556 .52189 .62279 .51667 .61764 Mtetra
.51667 .61764 .52189 .62279 .53149 .62 .52629 .61483 Mtetra
.52629 .61483 .53149 .62 .54112 .61721 .53595 .61202 Mtetra
.53595 .61202 .54112 .61721 .55079 .6144 .54563 .6092 Mtetra
.54563 .6092 .55079 .6144 .56049 .61159 .55536 .60636 Mtetra
.55536 .60636 .56049 .61159 .57022 .60876 .56511 .60352 Mtetra
.56511 .60352 .57022 .60876 .57999 .60593 .5749 .60067 Mtetra
.5749 .60067 .57999 .60593 .58979 .60308 .58473 .59781 Mtetra
.58473 .59781 .58979 .60308 .59963 .60023 .59459 .59493 Mtetra
.59459 .59493 .59963 .60023 .6095 .59737 .60448 .59205 Mtetra
.60448 .59205 .6095 .59737 .61941 .59449 .61441 .58916 Mtetra
.61441 .58916 .61941 .59449 .62935 .59161 .62438 .58625 Mtetra
.62438 .58625 .62935 .59161 .63933 .58871 .63438 .58334 Mtetra
.63438 .58334 .63933 .58871 .64934 .58581 .64442 .58041 Mtetra
.64442 .58041 .64934 .58581 .65939 .58289 .65449 .57748 Mtetra
.65449 .57748 .65939 .58289 .66947 .57996 .6646 .57453 Mtetra
.6646 .57453 .66947 .57996 .67959 .57703 .67475 .57158 Mtetra
.67475 .57158 .67959 .57703 .68975 .57408 .68493 .56861 Mtetra
.68493 .56861 .68975 .57408 .69995 .57112 .69515 .56563 Mtetra
.69515 .56563 .69995 .57112 .71018 .56815 .70541 .56264 Mtetra
.70541 .56264 .71018 .56815 .72044 .56517 .7157 .55965 Mtetra
.7157 .55965 .72044 .56517 .73075 .56218 .72603 .55664 Mtetra
.72603 .55664 .73075 .56218 .74109 .55918 .7364 .55361 Mtetra
.7364 .55361 .74109 .55918 .75147 .55617 .7468 .55058 Mtetra
.7468 .55058 .75147 .55617 .76189 .55315 .75725 .54754 Mtetra
.75725 .54754 .76189 .55315 .77234 .55012 .76773 .54449 Mtetra
.76773 .54449 .77234 .55012 .78284 .54707 .77825 .54142 Mtetra
.77825 .54142 .78284 .54707 .79337 .54401 .78881 .53834 Mtetra
.78881 .53834 .79337 .54401 .80394 .54095 .79941 .53526 Mtetra
.79941 .53526 .80394 .54095 .81455 .53787 .81005 .53216 Mtetra
.81005 .53216 .81455 .53787 .8252 .53478 .82072 .52905 Mtetra
.82072 .52905 .8252 .53478 .83589 .53168 .83144 .52592 Mtetra
.83144 .52592 .83589 .53168 .84661 .52857 .84219 .52279 Mtetra
.84219 .52279 .84661 .52857 .85738 .52544 .85299 .51964 Mtetra
.85299 .51964 .85738 .52544 .86819 .52231 .86383 .51649 Mtetra
.86383 .51649 .86819 .52231 .87903 .51916 .8747 .51332 Mtetra
.8747 .51332 .87903 .51916 .88992 .516 .88562 .51014 Mtetra
.88562 .51014 .88992 .516 .90085 .51283 .89658 .50694 Mtetra
.89658 .50694 .90085 .51283 .91182 .50965 .90758 .50374 Mtetra
.90758 .50374 .91182 .50965 .92283 .50645 .91862 .50052 Mtetra
.91862 .50052 .92283 .50645 .93388 .50324 .9297 .49729 Mtetra
.9297 .49729 .93388 .50324 .94497 .50003 .94082 .49405 Mtetra
.94082 .49405 .94497 .50003 .9561 .4968 .95198 .4908 Mtetra
.35253 .65894 .35813 .66383 .3672 .66119 .36162 .65628 Mtetra
.36162 .65628 .3672 .66119 .3763 .65854 .37074 .65361 Mtetra
.37074 .65361 .3763 .65854 .38544 .65587 .3799 .65094 Mtetra
.3799 .65094 .38544 .65587 .3946 .6532 .38908 .64825 Mtetra
.38908 .64825 .3946 .6532 .4038 .65052 .3983 .64555 Mtetra
.3983 .64555 .4038 .65052 .41303 .64783 .40755 .64285 Mtetra
.40755 .64285 .41303 .64783 .42229 .64514 .41683 .64013 Mtetra
.41683 .64013 .42229 .64514 .43158 .64243 .42614 .63741 Mtetra
.42614 .63741 .43158 .64243 .4409 .63971 .43548 .63467 Mtetra
.43548 .63467 .4409 .63971 .45026 .63699 .44486 .63193 Mtetra
.44486 .63193 .45026 .63699 .45965 .63425 .45427 .62918 Mtetra
.45427 .62918 .45965 .63425 .46907 .63151 .46371 .62641 Mtetra
.46371 .62641 .46907 .63151 .47853 .62875 .47319 .62364 Mtetra
.47319 .62364 .47853 .62875 .48801 .62599 .48269 .62086 Mtetra
.48269 .62086 .48801 .62599 .49753 .62321 .49224 .61807 Mtetra
.49224 .61807 .49753 .62321 .50709 .62043 .50181 .61527 Mtetra
.50181 .61527 .50709 .62043 .51667 .61764 .51142 .61245 Mtetra
.51142 .61245 .51667 .61764 .52629 .61483 .52106 .60963 Mtetra
.52106 .60963 .52629 .61483 .53595 .61202 .53074 .6068 Mtetra
.53074 .6068 .53595 .61202 .54563 .6092 .54045 .60396 Mtetra
.54045 .60396 .54563 .6092 .55536 .60636 .55019 .60111 Mtetra
.55019 .60111 .55536 .60636 .56511 .60352 .55997 .59825 Mtetra
.55997 .59825 .56511 .60352 .5749 .60067 .56978 .59538 Mtetra
.56978 .59538 .5749 .60067 .58473 .59781 .57963 .59249 Mtetra
.57963 .59249 .58473 .59781 .59459 .59493 .58952 .5896 Mtetra
.58952 .5896 .59459 .59493 .60448 .59205 .59944 .5867 Mtetra
.59944 .5867 .60448 .59205 .61441 .58916 .60939 .58379 Mtetra
.60939 .58379 .61441 .58916 .62438 .58625 .61938 .58087 Mtetra
.61938 .58087 .62438 .58625 .63438 .58334 .62941 .57793 Mtetra
.62941 .57793 .63438 .58334 .64442 .58041 .63947 .57499 Mtetra
.63947 .57499 .64442 .58041 .65449 .57748 .64957 .57203 Mtetra
.64957 .57203 .65449 .57748 .6646 .57453 .6597 .56907 Mtetra
.6597 .56907 .6646 .57453 .67475 .57158 .66987 .56609 Mtetra
.66987 .56609 .67475 .57158 .68493 .56861 .68008 .56311 Mtetra
.68008 .56311 .68493 .56861 .69515 .56563 .69032 .56011 Mtetra
.69032 .56011 .69515 .56563 .70541 .56264 .7006 .5571 Mtetra
.7006 .5571 .70541 .56264 .7157 .55965 .71092 .55408 Mtetra
.71092 .55408 .7157 .55965 .72603 .55664 .72128 .55105 Mtetra
.72128 .55105 .72603 .55664 .7364 .55361 .73168 .54801 Mtetra
.73168 .54801 .7364 .55361 .7468 .55058 .74211 .54496 Mtetra
.74211 .54496 .7468 .55058 .75725 .54754 .75258 .54189 Mtetra
.75258 .54189 .75725 .54754 .76773 .54449 .76309 .53882 Mtetra
.76309 .53882 .76773 .54449 .77825 .54142 .77364 .53573 Mtetra
.77364 .53573 .77825 .54142 .78881 .53834 .78422 .53263 Mtetra
.78422 .53263 .78881 .53834 .79941 .53526 .79485 .52952 Mtetra
.79485 .52952 .79941 .53526 .81005 .53216 .80551 .5264 Mtetra
.80551 .5264 .81005 .53216 .82072 .52905 .81622 .52327 Mtetra
.81622 .52327 .82072 .52905 .83144 .52592 .82696 .52013 Mtetra
.82696 .52013 .83144 .52592 .84219 .52279 .83775 .51697 Mtetra
.83775 .51697 .84219 .52279 .85299 .51964 .84857 .51381 Mtetra
.84857 .51381 .85299 .51964 .86383 .51649 .85944 .51063 Mtetra
.85944 .51063 .86383 .51649 .8747 .51332 .87034 .50744 Mtetra
.87034 .50744 .8747 .51332 .88562 .51014 .88129 .50423 Mtetra
.88129 .50423 .88562 .51014 .89658 .50694 .89227 .50102 Mtetra
.89227 .50102 .89658 .50694 .90758 .50374 .9033 .49779 Mtetra
.9033 .49779 .90758 .50374 .91862 .50052 .91437 .49455 Mtetra
.91437 .49455 .91862 .50052 .9297 .49729 .92549 .4913 Mtetra
.92549 .4913 .9297 .49729 .94082 .49405 .93664 .48804 Mtetra
.93664 .48804 .94082 .49405 .95198 .4908 .94784 .48476 Mtetra
.34689 .65403 .35253 .65894 .36162 .65628 .356 .65135 Mtetra
.356 .65135 .36162 .65628 .37074 .65361 .36515 .64866 Mtetra
.36515 .64866 .37074 .65361 .3799 .65094 .37432 .64597 Mtetra
.37432 .64597 .3799 .65094 .38908 .64825 .38352 .64326 Mtetra
.38352 .64326 .38908 .64825 .3983 .64555 .39276 .64055 Mtetra
.39276 .64055 .3983 .64555 .40755 .64285 .40203 .63783 Mtetra
.40203 .63783 .40755 .64285 .41683 .64013 .41133 .63509 Mtetra
.41133 .63509 .41683 .64013 .42614 .63741 .42066 .63235 Mtetra
.42066 .63235 .42614 .63741 .43548 .63467 .43003 .6296 Mtetra
.43003 .6296 .43548 .63467 .44486 .63193 .43942 .62684 Mtetra
.43942 .62684 .44486 .63193 .45427 .62918 .44885 .62407 Mtetra
.44885 .62407 .45427 .62918 .46371 .62641 .45832 .62129 Mtetra
.45832 .62129 .46371 .62641 .47319 .62364 .46781 .6185 Mtetra
.46781 .6185 .47319 .62364 .48269 .62086 .47734 .6157 Mtetra
.47734 .6157 .48269 .62086 .49224 .61807 .4869 .61289 Mtetra
.4869 .61289 .49224 .61807 .50181 .61527 .4965 .61007 Mtetra
.4965 .61007 .50181 .61527 .51142 .61245 .50613 .60724 Mtetra
.50613 .60724 .51142 .61245 .52106 .60963 .5158 .6044 Mtetra
.5158 .6044 .52106 .60963 .53074 .6068 .52549 .60155 Mtetra
.52549 .60155 .53074 .6068 .54045 .60396 .53523 .59869 Mtetra
.53523 .59869 .54045 .60396 .55019 .60111 .54499 .59582 Mtetra
.54499 .59582 .55019 .60111 .55997 .59825 .5548 .59294 Mtetra
.5548 .59294 .55997 .59825 .56978 .59538 .56463 .59005 Mtetra
.56463 .59005 .56978 .59538 .57963 .59249 .5745 .58715 Mtetra
.5745 .58715 .57963 .59249 .58952 .5896 .58441 .58424 Mtetra
.58441 .58424 .58952 .5896 .59944 .5867 .59435 .58132 Mtetra
.59435 .58132 .59944 .5867 .60939 .58379 .60433 .57838 Mtetra
.60433 .57838 .60939 .58379 .61938 .58087 .61435 .57544 Mtetra
.61435 .57544 .61938 .58087 .62941 .57793 .6244 .57249 Mtetra
.6244 .57249 .62941 .57793 .63947 .57499 .63448 .56952 Mtetra
.63448 .56952 .63947 .57499 .64957 .57203 .6446 .56655 Mtetra
.6446 .56655 .64957 .57203 .6597 .56907 .65476 .56357 Mtetra
.65476 .56357 .6597 .56907 .66987 .56609 .66496 .56057 Mtetra
.66496 .56057 .66987 .56609 .68008 .56311 .67519 .55756 Mtetra
.67519 .55756 .68008 .56311 .69032 .56011 .68546 .55455 Mtetra
.68546 .55455 .69032 .56011 .7006 .5571 .69577 .55152 Mtetra
.69577 .55152 .7006 .5571 .71092 .55408 .70612 .54848 Mtetra
.70612 .54848 .71092 .55408 .72128 .55105 .7165 .54543 Mtetra
.7165 .54543 .72128 .55105 .73168 .54801 .72692 .54236 Mtetra
.72692 .54236 .73168 .54801 .74211 .54496 .73738 .53929 Mtetra
.73738 .53929 .74211 .54496 .75258 .54189 .74788 .53621 Mtetra
.74788 .53621 .75258 .54189 .76309 .53882 .75841 .53311 Mtetra
.75841 .53311 .76309 .53882 .77364 .53573 .76899 .53 Mtetra
.76899 .53 .77364 .53573 .78422 .53263 .7796 .52688 Mtetra
.7796 .52688 .78422 .53263 .79485 .52952 .79026 .52375 Mtetra
.79026 .52375 .79485 .52952 .80551 .5264 .80095 .52061 Mtetra
.80095 .52061 .80551 .5264 .81622 .52327 .81168 .51746 Mtetra
.81168 .51746 .81622 .52327 .82696 .52013 .82245 .51429 Mtetra
.82245 .51429 .82696 .52013 .83775 .51697 .83327 .51112 Mtetra
.83327 .51112 .83775 .51697 .84857 .51381 .84412 .50793 Mtetra
.84412 .50793 .84857 .51381 .85944 .51063 .85501 .50473 Mtetra
.85501 .50473 .85944 .51063 .87034 .50744 .86595 .50151 Mtetra
.86595 .50151 .87034 .50744 .88129 .50423 .87693 .49829 Mtetra
.87693 .49829 .88129 .50423 .89227 .50102 .88794 .49505 Mtetra
.88794 .49505 .89227 .50102 .9033 .49779 .899 .4918 Mtetra
.899 .4918 .9033 .49779 .91437 .49455 .9101 .48854 Mtetra
.9101 .48854 .91437 .49455 .92549 .4913 .92125 .48527 Mtetra
.92125 .48527 .92549 .4913 .93664 .48804 .93243 .48198 Mtetra
.93243 .48198 .93664 .48804 .94784 .48476 .94366 .47868 Mtetra
.34122 .64908 .34689 .65403 .356 .65135 .35035 .64638 Mtetra
.35035 .64638 .356 .65135 .36515 .64866 .35951 .64368 Mtetra
.35951 .64368 .36515 .64866 .37432 .64597 .36871 .64097 Mtetra
.36871 .64097 .37432 .64597 .38352 .64326 .37793 .63825 Mtetra
.37793 .63825 .38352 .64326 .39276 .64055 .38719 .63551 Mtetra
.38719 .63551 .39276 .64055 .40203 .63783 .39647 .63277 Mtetra
.39647 .63277 .40203 .63783 .41133 .63509 .40579 .63002 Mtetra
.40579 .63002 .41133 .63509 .42066 .63235 .41515 .62726 Mtetra
.41515 .62726 .42066 .63235 .43003 .6296 .42453 .62449 Mtetra
.42453 .62449 .43003 .6296 .43942 .62684 .43395 .62172 Mtetra
.43395 .62172 .43942 .62684 .44885 .62407 .4434 .61893 Mtetra
.4434 .61893 .44885 .62407 .45832 .62129 .45289 .61613 Mtetra
.45289 .61613 .45832 .62129 .46781 .6185 .4624 .61332 Mtetra
.4624 .61332 .46781 .6185 .47734 .6157 .47195 .6105 Mtetra
.47195 .6105 .47734 .6157 .4869 .61289 .48154 .60767 Mtetra
.48154 .60767 .4869 .61289 .4965 .61007 .49116 .60484 Mtetra
.49116 .60484 .4965 .61007 .50613 .60724 .50081 .60199 Mtetra
.50081 .60199 .50613 .60724 .5158 .6044 .5105 .59913 Mtetra
.5105 .59913 .5158 .6044 .52549 .60155 .52022 .59626 Mtetra
.52022 .59626 .52549 .60155 .53523 .59869 .52997 .59338 Mtetra
.52997 .59338 .53523 .59869 .54499 .59582 .53976 .59049 Mtetra
.53976 .59049 .54499 .59582 .5548 .59294 .54959 .58759 Mtetra
.54959 .58759 .5548 .59294 .56463 .59005 .55945 .58469 Mtetra
.55945 .58469 .56463 .59005 .5745 .58715 .56934 .58177 Mtetra
.56934 .58177 .5745 .58715 .58441 .58424 .57927 .57884 Mtetra
.57927 .57884 .58441 .58424 .59435 .58132 .58924 .57589 Mtetra
.58924 .57589 .59435 .58132 .60433 .57838 .59924 .57294 Mtetra
.59924 .57294 .60433 .57838 .61435 .57544 .60928 .56998 Mtetra
.60928 .56998 .61435 .57544 .6244 .57249 .61935 .56701 Mtetra
.61935 .56701 .6244 .57249 .63448 .56952 .62946 .56403 Mtetra
.62946 .56403 .63448 .56952 .6446 .56655 .63961 .56103 Mtetra
.63961 .56103 .6446 .56655 .65476 .56357 .64979 .55803 Mtetra
.64979 .55803 .65476 .56357 .66496 .56057 .66002 .55501 Mtetra
.66002 .55501 .66496 .56057 .67519 .55756 .67027 .55198 Mtetra
.67027 .55198 .67519 .55756 .68546 .55455 .68057 .54895 Mtetra
.68057 .54895 .68546 .55455 .69577 .55152 .6909 .5459 Mtetra
.6909 .5459 .69577 .55152 .70612 .54848 .70127 .54284 Mtetra
.70127 .54284 .70612 .54848 .7165 .54543 .71168 .53976 Mtetra
.71168 .53976 .7165 .54543 .72692 .54236 .72213 .53668 Mtetra
.72213 .53668 .72692 .54236 .73738 .53929 .73262 .53359 Mtetra
.73262 .53359 .73738 .53929 .74788 .53621 .74314 .53048 Mtetra
.74314 .53048 .74788 .53621 .75841 .53311 .75371 .52737 Mtetra
.75371 .52737 .75841 .53311 .76899 .53 .76431 .52424 Mtetra
.76431 .52424 .76899 .53 .7796 .52688 .77495 .5211 Mtetra
.77495 .5211 .7796 .52688 .79026 .52375 .78563 .51794 Mtetra
.78563 .51794 .79026 .52375 .80095 .52061 .79635 .51478 Mtetra
.79635 .51478 .80095 .52061 .81168 .51746 .80711 .51161 Mtetra
.80711 .51161 .81168 .51746 .82245 .51429 .81792 .50842 Mtetra
.81792 .50842 .82245 .51429 .83327 .51112 .82876 .50522 Mtetra
.82876 .50522 .83327 .51112 .84412 .50793 .83964 .50201 Mtetra
.83964 .50201 .84412 .50793 .85501 .50473 .85056 .49879 Mtetra
.85056 .49879 .85501 .50473 .86595 .50151 .86153 .49555 Mtetra
.86153 .49555 .86595 .50151 .87693 .49829 .87253 .4923 Mtetra
.87253 .4923 .87693 .49829 .88794 .49505 .88358 .48904 Mtetra
.88358 .48904 .88794 .49505 .899 .4918 .89467 .48577 Mtetra
.89467 .48577 .899 .4918 .9101 .48854 .9058 .48249 Mtetra
.9058 .48249 .9101 .48854 .92125 .48527 .91698 .47919 Mtetra
.91698 .47919 .92125 .48527 .93243 .48198 .92819 .47588 Mtetra
.92819 .47588 .93243 .48198 .94366 .47868 .93945 .47256 Mtetra
.33552 .6441 .34122 .64908 .35035 .64638 .34467 .64139 Mtetra
.34467 .64139 .35035 .64638 .35951 .64368 .35385 .63866 Mtetra
.35385 .63866 .35951 .64368 .36871 .64097 .36306 .63594 Mtetra
.36306 .63594 .36871 .64097 .37793 .63825 .3723 .6332 Mtetra
.3723 .6332 .37793 .63825 .38719 .63551 .38158 .63045 Mtetra
.38158 .63045 .38719 .63551 .39647 .63277 .39089 .62769 Mtetra
.39089 .62769 .39647 .63277 .40579 .63002 .40023 .62492 Mtetra
.40023 .62492 .40579 .63002 .41515 .62726 .4096 .62214 Mtetra
.4096 .62214 .41515 .62726 .42453 .62449 .41901 .61936 Mtetra
.41901 .61936 .42453 .62449 .43395 .62172 .42844 .61656 Mtetra
.42844 .61656 .43395 .62172 .4434 .61893 .43792 .61375 Mtetra
.43792 .61375 .4434 .61893 .45289 .61613 .44742 .61094 Mtetra
.44742 .61094 .45289 .61613 .4624 .61332 .45696 .60811 Mtetra
.45696 .60811 .4624 .61332 .47195 .6105 .46653 .60527 Mtetra
.46653 .60527 .47195 .6105 .48154 .60767 .47614 .60243 Mtetra
.47614 .60243 .48154 .60767 .49116 .60484 .48578 .59957 Mtetra
.48578 .59957 .49116 .60484 .50081 .60199 .49545 .5967 Mtetra
.49545 .5967 .50081 .60199 .5105 .59913 .50516 .59383 Mtetra
.50516 .59383 .5105 .59913 .52022 .59626 .5149 .59094 Mtetra
.5149 .59094 .52022 .59626 .52997 .59338 .52468 .58804 Mtetra
.52468 .58804 .52997 .59338 .53976 .59049 .5345 .58513 Mtetra
.5345 .58513 .53976 .59049 .54959 .58759 .54434 .58222 Mtetra
.54434 .58222 .54959 .58759 .55945 .58469 .55423 .57929 Mtetra
.55423 .57929 .55945 .58469 .56934 .58177 .56414 .57635 Mtetra
.56414 .57635 .56934 .58177 .57927 .57884 .5741 .5734 Mtetra
.5741 .5734 .57927 .57884 .58924 .57589 .58409 .57044 Mtetra
.58409 .57044 .58924 .57589 .59924 .57294 .59412 .56747 Mtetra
.59412 .56747 .59924 .57294 .60928 .56998 .60418 .56449 Mtetra
.60418 .56449 .60928 .56998 .61935 .56701 .61428 .56149 Mtetra
.61428 .56149 .61935 .56701 .62946 .56403 .62441 .55849 Mtetra
.62441 .55849 .62946 .56403 .63961 .56103 .63458 .55547 Mtetra
.63458 .55547 .63961 .56103 .64979 .55803 .64479 .55245 Mtetra
.64479 .55245 .64979 .55803 .66002 .55501 .65504 .54941 Mtetra
.65504 .54941 .66002 .55501 .67027 .55198 .66532 .54637 Mtetra
.66532 .54637 .67027 .55198 .68057 .54895 .67564 .54331 Mtetra
.67564 .54331 .68057 .54895 .6909 .5459 .686 .54024 Mtetra
.686 .54024 .6909 .5459 .70127 .54284 .6964 .53716 Mtetra
.6964 .53716 .70127 .54284 .71168 .53976 .70684 .53406 Mtetra
.70684 .53406 .71168 .53976 .72213 .53668 .71731 .53096 Mtetra
.71731 .53096 .72213 .53668 .73262 .53359 .72782 .52785 Mtetra
.72782 .52785 .73262 .53359 .74314 .53048 .73838 .52472 Mtetra
.73838 .52472 .74314 .53048 .75371 .52737 .74897 .52158 Mtetra
.74897 .52158 .75371 .52737 .76431 .52424 .7596 .51843 Mtetra
.7596 .51843 .76431 .52424 .77495 .5211 .77027 .51527 Mtetra
.77027 .51527 .77495 .5211 .78563 .51794 .78098 .5121 Mtetra
.78098 .5121 .78563 .51794 .79635 .51478 .79173 .50891 Mtetra
.79173 .50891 .79635 .51478 .80711 .51161 .80251 .50571 Mtetra
.80251 .50571 .80711 .51161 .81792 .50842 .81335 .5025 Mtetra
.81335 .5025 .81792 .50842 .82876 .50522 .82422 .49928 Mtetra
.82422 .49928 .82876 .50522 .83964 .50201 .83513 .49605 Mtetra
.83513 .49605 .83964 .50201 .85056 .49879 .84608 .4928 Mtetra
.84608 .4928 .85056 .49879 .86153 .49555 .85707 .48955 Mtetra
.85707 .48955 .86153 .49555 .87253 .4923 .86811 .48627 Mtetra
.86811 .48627 .87253 .4923 .88358 .48904 .87919 .48299 Mtetra
.87919 .48299 .88358 .48904 .89467 .48577 .89031 .4797 Mtetra
.89031 .4797 .89467 .48577 .9058 .48249 .90147 .47639 Mtetra
.90147 .47639 .9058 .48249 .91698 .47919 .91268 .47307 Mtetra
.91268 .47307 .91698 .47919 .92819 .47588 .92392 .46974 Mtetra
.92392 .46974 .92819 .47588 .93945 .47256 .93521 .46639 Mtetra
.32977 .63908 .33552 .6441 .34467 .64139 .33894 .63636 Mtetra
.33894 .63636 .34467 .64139 .35385 .63866 .34814 .63362 Mtetra
.34814 .63362 .35385 .63866 .36306 .63594 .35737 .63087 Mtetra
.35737 .63087 .36306 .63594 .3723 .6332 .36664 .62811 Mtetra
.36664 .62811 .3723 .6332 .38158 .63045 .37593 .62535 Mtetra
.37593 .62535 .38158 .63045 .39089 .62769 .38526 .62257 Mtetra
.38526 .62257 .39089 .62769 .40023 .62492 .39462 .61979 Mtetra
.39462 .61979 .40023 .62492 .4096 .62214 .40402 .61699 Mtetra
.40402 .61699 .4096 .62214 .41901 .61936 .41344 .61418 Mtetra
.41344 .61418 .41901 .61936 .42844 .61656 .4229 .61137 Mtetra
.4229 .61137 .42844 .61656 .43792 .61375 .43239 .60854 Mtetra
.43239 .60854 .43792 .61375 .44742 .61094 .44192 .60571 Mtetra
.44192 .60571 .44742 .61094 .45696 .60811 .45148 .60286 Mtetra
.45148 .60286 .45696 .60811 .46653 .60527 .46108 .60001 Mtetra
.46108 .60001 .46653 .60527 .47614 .60243 .4707 .59714 Mtetra
.4707 .59714 .47614 .60243 .48578 .59957 .48037 .59427 Mtetra
.48037 .59427 .48578 .59957 .49545 .5967 .49006 .59138 Mtetra
.49006 .59138 .49545 .5967 .50516 .59383 .49979 .58849 Mtetra
.49979 .58849 .50516 .59383 .5149 .59094 .50956 .58558 Mtetra
.50956 .58558 .5149 .59094 .52468 .58804 .51936 .58267 Mtetra
.51936 .58267 .52468 .58804 .5345 .58513 .52919 .57974 Mtetra
.52919 .57974 .5345 .58513 .54434 .58222 .53907 .5768 Mtetra
.53907 .5768 .54434 .58222 .55423 .57929 .54897 .57385 Mtetra
.54897 .57385 .55423 .57929 .56414 .57635 .55891 .57089 Mtetra
.55891 .57089 .56414 .57635 .5741 .5734 .56889 .56792 Mtetra
.56889 .56792 .5741 .5734 .58409 .57044 .57891 .56494 Mtetra
.57891 .56494 .58409 .57044 .59412 .56747 .58896 .56195 Mtetra
.58896 .56195 .59412 .56747 .60418 .56449 .59904 .55895 Mtetra
.59904 .55895 .60418 .56449 .61428 .56149 .60917 .55594 Mtetra
.60917 .55594 .61428 .56149 .62441 .55849 .61933 .55292 Mtetra
.61933 .55292 .62441 .55849 .63458 .55547 .62952 .54988 Mtetra
.62952 .54988 .63458 .55547 .64479 .55245 .63976 .54684 Mtetra
.63976 .54684 .64479 .55245 .65504 .54941 .65003 .54378 Mtetra
.65003 .54378 .65504 .54941 .66532 .54637 .66034 .54071 Mtetra
.66034 .54071 .66532 .54637 .67564 .54331 .67069 .53763 Mtetra
.67069 .53763 .67564 .54331 .686 .54024 .68107 .53454 Mtetra
.68107 .53454 .686 .54024 .6964 .53716 .69149 .53144 Mtetra
.69149 .53144 .6964 .53716 .70684 .53406 .70196 .52833 Mtetra
.70196 .52833 .70684 .53406 .71731 .53096 .71246 .5252 Mtetra
.71246 .5252 .71731 .53096 .72782 .52785 .723 .52206 Mtetra
.723 .52206 .72782 .52785 .73838 .52472 .73358 .51892 Mtetra
.73358 .51892 .73838 .52472 .74897 .52158 .74419 .51576 Mtetra
.74419 .51576 .74897 .52158 .7596 .51843 .75485 .51258 Mtetra
.75485 .51258 .7596 .51843 .77027 .51527 .76555 .5094 Mtetra
.76555 .5094 .77027 .51527 .78098 .5121 .77629 .50621 Mtetra
.77629 .50621 .78098 .5121 .79173 .50891 .78707 .503 Mtetra
.78707 .503 .79173 .50891 .80251 .50571 .79788 .49978 Mtetra
.79788 .49978 .80251 .50571 .81335 .5025 .80874 .49655 Mtetra
.80874 .49655 .81335 .5025 .82422 .49928 .81964 .4933 Mtetra
.81964 .4933 .82422 .49928 .83513 .49605 .83058 .49005 Mtetra
.83058 .49005 .83513 .49605 .84608 .4928 .84157 .48678 Mtetra
.84157 .48678 .84608 .4928 .85707 .48955 .85259 .4835 Mtetra
.85259 .4835 .85707 .48955 .86811 .48627 .86366 .4802 Mtetra
.86366 .4802 .86811 .48627 .87919 .48299 .87477 .4769 Mtetra
.87477 .4769 .87919 .48299 .89031 .4797 .88592 .47358 Mtetra
.88592 .47358 .89031 .4797 .90147 .47639 .89711 .47025 Mtetra
.89711 .47025 .90147 .47639 .91268 .47307 .90834 .46691 Mtetra
.90834 .46691 .91268 .47307 .92392 .46974 .91962 .46355 Mtetra
.91962 .46355 .92392 .46974 .93521 .46639 .93095 .46018 Mtetra
.32399 .63404 .32977 .63908 .33894 .63636 .33318 .63129 Mtetra
.33318 .63129 .33894 .63636 .34814 .63362 .3424 .62854 Mtetra
.3424 .62854 .34814 .63362 .35737 .63087 .35165 .62577 Mtetra
.35165 .62577 .35737 .63087 .36664 .62811 .36094 .623 Mtetra
.36094 .623 .36664 .62811 .37593 .62535 .37025 .62021 Mtetra
.37025 .62021 .37593 .62535 .38526 .62257 .3796 .61742 Mtetra
.3796 .61742 .38526 .62257 .39462 .61979 .38898 .61462 Mtetra
.38898 .61462 .39462 .61979 .40402 .61699 .3984 .6118 Mtetra
.3984 .6118 .40402 .61699 .41344 .61418 .40784 .60898 Mtetra
.40784 .60898 .41344 .61418 .4229 .61137 .41732 .60615 Mtetra
.41732 .60615 .4229 .61137 .43239 .60854 .42684 .6033 Mtetra
.42684 .6033 .43239 .60854 .44192 .60571 .43639 .60045 Mtetra
.43639 .60045 .44192 .60571 .45148 .60286 .44597 .59759 Mtetra
.44597 .59759 .45148 .60286 .46108 .60001 .45558 .59471 Mtetra
.45558 .59471 .46108 .60001 .4707 .59714 .46523 .59183 Mtetra
.46523 .59183 .4707 .59714 .48037 .59427 .47492 .58893 Mtetra
.47492 .58893 .48037 .59427 .49006 .59138 .48463 .58603 Mtetra
.48463 .58603 .49006 .59138 .49979 .58849 .49439 .58311 Mtetra
.49439 .58311 .49979 .58849 .50956 .58558 .50418 .58019 Mtetra
.50418 .58019 .50956 .58558 .51936 .58267 .514 .57725 Mtetra
.514 .57725 .51936 .58267 .52919 .57974 .52386 .57431 Mtetra
.52386 .57431 .52919 .57974 .53907 .5768 .53375 .57135 Mtetra
.53375 .57135 .53907 .5768 .54897 .57385 .54368 .56838 Mtetra
.54368 .56838 .54897 .57385 .55891 .57089 .55365 .5654 Mtetra
.55365 .5654 .55891 .57089 .56889 .56792 .56365 .56241 Mtetra
.56365 .56241 .56889 .56792 .57891 .56494 .57369 .55941 Mtetra
.57369 .55941 .57891 .56494 .58896 .56195 .58376 .5564 Mtetra
.58376 .5564 .58896 .56195 .59904 .55895 .59387 .55338 Mtetra
.59387 .55338 .59904 .55895 .60917 .55594 .60402 .55035 Mtetra
.60402 .55035 .60917 .55594 .61933 .55292 .61421 .5473 Mtetra
.61421 .5473 .61933 .55292 .62952 .54988 .62443 .54425 Mtetra
.62443 .54425 .62952 .54988 .63976 .54684 .63469 .54118 Mtetra
.63469 .54118 .63976 .54684 .65003 .54378 .64498 .53811 Mtetra
.64498 .53811 .65003 .54378 .66034 .54071 .65532 .53502 Mtetra
.65532 .53502 .66034 .54071 .67069 .53763 .66569 .53192 Mtetra
.66569 .53192 .67069 .53763 .68107 .53454 .6761 .52881 Mtetra
.6761 .52881 .68107 .53454 .69149 .53144 .68655 .52568 Mtetra
.68655 .52568 .69149 .53144 .70196 .52833 .69704 .52255 Mtetra
.69704 .52255 .70196 .52833 .71246 .5252 .70757 .5194 Mtetra
.70757 .5194 .71246 .5252 .723 .52206 .71814 .51624 Mtetra
.71814 .51624 .723 .52206 .73358 .51892 .72874 .51307 Mtetra
.72874 .51307 .73358 .51892 .74419 .51576 .73939 .50989 Mtetra
.73939 .50989 .74419 .51576 .75485 .51258 .75008 .5067 Mtetra
.75008 .5067 .75485 .51258 .76555 .5094 .7608 .50349 Mtetra
.7608 .50349 .76555 .5094 .77629 .50621 .77157 .50027 Mtetra
.77157 .50027 .77629 .50621 .78707 .503 .78237 .49704 Mtetra
.78237 .49704 .78707 .503 .79788 .49978 .79322 .4938 Mtetra
.79322 .4938 .79788 .49978 .80874 .49655 .80411 .49055 Mtetra
.80411 .49055 .80874 .49655 .81964 .4933 .81504 .48728 Mtetra
.81504 .48728 .81964 .4933 .83058 .49005 .82601 .484 Mtetra
.82601 .484 .83058 .49005 .84157 .48678 .83702 .48071 Mtetra
.83702 .48071 .84157 .48678 .85259 .4835 .84808 .47741 Mtetra
.84808 .47741 .85259 .4835 .86366 .4802 .85917 .47409 Mtetra
.85917 .47409 .86366 .4802 .87477 .4769 .87031 .47076 Mtetra
.87031 .47076 .87477 .4769 .88592 .47358 .88149 .46742 Mtetra
.88149 .46742 .88592 .47358 .89711 .47025 .89272 .46407 Mtetra
.89272 .46407 .89711 .47025 .90834 .46691 .90398 .4607 Mtetra
.90398 .4607 .90834 .46691 .91962 .46355 .91529 .45732 Mtetra
.91529 .45732 .91962 .46355 .93095 .46018 .92665 .45393 Mtetra
.31818 .62896 .32399 .63404 .33318 .63129 .32738 .6262 Mtetra
.32738 .6262 .33318 .63129 .3424 .62854 .33662 .62343 Mtetra
.33662 .62343 .3424 .62854 .35165 .62577 .34589 .62064 Mtetra
.34589 .62064 .35165 .62577 .36094 .623 .3552 .61785 Mtetra
.3552 .61785 .36094 .623 .37025 .62021 .36453 .61505 Mtetra
.36453 .61505 .37025 .62021 .3796 .61742 .3739 .61224 Mtetra
.3739 .61224 .3796 .61742 .38898 .61462 .3833 .60942 Mtetra
.3833 .60942 .38898 .61462 .3984 .6118 .39274 .60658 Mtetra
.39274 .60658 .3984 .6118 .40784 .60898 .40221 .60374 Mtetra
.40221 .60374 .40784 .60898 .41732 .60615 .41171 .60089 Mtetra
.41171 .60089 .41732 .60615 .42684 .6033 .42124 .59803 Mtetra
.42124 .59803 .42684 .6033 .43639 .60045 .43081 .59516 Mtetra
.43081 .59516 .43639 .60045 .44597 .59759 .44042 .59227 Mtetra
.44042 .59227 .44597 .59759 .45558 .59471 .45005 .58938 Mtetra
.45005 .58938 .45558 .59471 .46523 .59183 .45972 .58648 Mtetra
.45972 .58648 .46523 .59183 .47492 .58893 .46943 .58356 Mtetra
.46943 .58356 .47492 .58893 .48463 .58603 .47917 .58064 Mtetra
.47917 .58064 .48463 .58603 .49439 .58311 .48895 .57771 Mtetra
.48895 .57771 .49439 .58311 .50418 .58019 .49876 .57476 Mtetra
.49876 .57476 .50418 .58019 .514 .57725 .5086 .57181 Mtetra
.5086 .57181 .514 .57725 .52386 .57431 .51849 .56884 Mtetra
.51849 .56884 .52386 .57431 .53375 .57135 .5284 .56586 Mtetra
.5284 .56586 .53375 .57135 .54368 .56838 .53836 .56288 Mtetra
.53836 .56288 .54368 .56838 .55365 .5654 .54835 .55988 Mtetra
.54835 .55988 .55365 .5654 .56365 .56241 .55837 .55687 Mtetra
.55837 .55687 .56365 .56241 .57369 .55941 .56843 .55385 Mtetra
.56843 .55385 .57369 .55941 .58376 .5564 .57853 .55082 Mtetra
.57853 .55082 .58376 .5564 .59387 .55338 .58867 .54777 Mtetra
.58867 .54777 .59387 .55338 .60402 .55035 .59884 .54472 Mtetra
.59884 .54472 .60402 .55035 .61421 .5473 .60905 .54166 Mtetra
.60905 .54166 .61421 .5473 .62443 .54425 .6193 .53858 Mtetra
.6193 .53858 .62443 .54425 .63469 .54118 .62958 .53549 Mtetra
.62958 .53549 .63469 .54118 .64498 .53811 .63991 .53239 Mtetra
.63991 .53239 .64498 .53811 .65532 .53502 .65027 .52928 Mtetra
.65027 .52928 .65532 .53502 .66569 .53192 .66067 .52616 Mtetra
.66067 .52616 .66569 .53192 .6761 .52881 .6711 .52303 Mtetra
.6711 .52303 .6761 .52881 .68655 .52568 .68158 .51989 Mtetra
.68158 .51989 .68655 .52568 .69704 .52255 .6921 .51673 Mtetra
.6921 .51673 .69704 .52255 .70757 .5194 .70265 .51356 Mtetra
.70265 .51356 .70757 .5194 .71814 .51624 .71324 .51038 Mtetra
.71324 .51038 .71814 .51624 .72874 .51307 .72388 .50719 Mtetra
.72388 .50719 .72874 .51307 .73939 .50989 .73455 .50399 Mtetra
.73455 .50399 .73939 .50989 .75008 .5067 .74527 .50077 Mtetra
.74527 .50077 .75008 .5067 .7608 .50349 .75602 .49754 Mtetra
.75602 .49754 .7608 .50349 .77157 .50027 .76681 .4943 Mtetra
.76681 .4943 .77157 .50027 .78237 .49704 .77765 .49105 Mtetra
.77765 .49105 .78237 .49704 .79322 .4938 .78852 .48779 Mtetra
.78852 .48779 .79322 .4938 .80411 .49055 .79944 .48451 Mtetra
.79944 .48451 .80411 .49055 .81504 .48728 .8104 .48122 Mtetra
.8104 .48122 .81504 .48728 .82601 .484 .8214 .47792 Mtetra
.8214 .47792 .82601 .484 .83702 .48071 .83244 .4746 Mtetra
.83244 .4746 .83702 .48071 .84808 .47741 .84353 .47128 Mtetra
.84353 .47128 .84808 .47741 .85917 .47409 .85465 .46794 Mtetra
.85465 .46794 .85917 .47409 .87031 .47076 .86582 .46458 Mtetra
.86582 .46458 .87031 .47076 .88149 .46742 .87704 .46122 Mtetra
.87704 .46122 .88149 .46742 .89272 .46407 .88829 .45784 Mtetra
.88829 .45784 .89272 .46407 .90398 .4607 .89959 .45445 Mtetra
.89959 .45445 .90398 .4607 .91529 .45732 .91093 .45104 Mtetra
.91093 .45104 .91529 .45732 .92665 .45393 .92232 .44763 Mtetra
.31232 .62385 .31818 .62896 .32738 .6262 .32155 .62107 Mtetra
.32155 .62107 .32738 .6262 .33662 .62343 .33081 .61828 Mtetra
.33081 .61828 .33662 .62343 .34589 .62064 .3401 .61548 Mtetra
.3401 .61548 .34589 .62064 .3552 .61785 .34942 .61267 Mtetra
.34942 .61267 .3552 .61785 .36453 .61505 .35878 .60985 Mtetra
.35878 .60985 .36453 .61505 .3739 .61224 .36817 .60702 Mtetra
.36817 .60702 .3739 .61224 .3833 .60942 .37759 .60418 Mtetra
.37759 .60418 .3833 .60942 .39274 .60658 .38704 .60133 Mtetra
.38704 .60133 .39274 .60658 .40221 .60374 .39653 .59847 Mtetra
.39653 .59847 .40221 .60374 .41171 .60089 .40606 .5956 Mtetra
.40606 .5956 .41171 .60089 .42124 .59803 .41561 .59272 Mtetra
.41561 .59272 .42124 .59803 .43081 .59516 .4252 .58983 Mtetra
.4252 .58983 .43081 .59516 .44042 .59227 .43483 .58692 Mtetra
.43483 .58692 .44042 .59227 .45005 .58938 .44449 .58401 Mtetra
.44449 .58401 .45005 .58938 .45972 .58648 .45418 .58109 Mtetra
.45418 .58109 .45972 .58648 .46943 .58356 .46391 .57816 Mtetra
.46391 .57816 .46943 .58356 .47917 .58064 .47367 .57521 Mtetra
.47367 .57521 .47917 .58064 .48895 .57771 .48347 .57226 Mtetra
.48347 .57226 .48895 .57771 .49876 .57476 .4933 .5693 Mtetra
.4933 .5693 .49876 .57476 .5086 .57181 .50317 .56632 Mtetra
.50317 .56632 .5086 .57181 .51849 .56884 .51308 .56334 Mtetra
.51308 .56334 .51849 .56884 .5284 .56586 .52302 .56034 Mtetra
.52302 .56034 .5284 .56586 .53836 .56288 .533 .55733 Mtetra
.533 .55733 .53836 .56288 .54835 .55988 .54301 .55431 Mtetra
.54301 .55431 .54835 .55988 .55837 .55687 .55306 .55128 Mtetra
.55306 .55128 .55837 .55687 .56843 .55385 .56314 .54824 Mtetra
.56314 .54824 .56843 .55385 .57853 .55082 .57327 .54519 Mtetra
.57327 .54519 .57853 .55082 .58867 .54777 .58343 .54213 Mtetra
.58343 .54213 .58867 .54777 .59884 .54472 .59363 .53905 Mtetra
.59363 .53905 .59884 .54472 .60905 .54166 .60386 .53597 Mtetra
.60386 .53597 .60905 .54166 .6193 .53858 .61413 .53287 Mtetra
.61413 .53287 .6193 .53858 .62958 .53549 .62444 .52976 Mtetra
.62444 .52976 .62958 .53549 .63991 .53239 .63479 .52664 Mtetra
.63479 .52664 .63991 .53239 .65027 .52928 .64518 .52351 Mtetra
.64518 .52351 .65027 .52928 .66067 .52616 .6556 .52037 Mtetra
.6556 .52037 .66067 .52616 .6711 .52303 .66607 .51722 Mtetra
.66607 .51722 .6711 .52303 .68158 .51989 .67657 .51405 Mtetra
.67657 .51405 .68158 .51989 .6921 .51673 .68711 .51087 Mtetra
.68711 .51087 .6921 .51673 .70265 .51356 .6977 .50768 Mtetra
.6977 .50768 .70265 .51356 .71324 .51038 .70832 .50448 Mtetra
.70832 .50448 .71324 .51038 .72388 .50719 .71898 .50127 Mtetra
.71898 .50127 .72388 .50719 .73455 .50399 .72968 .49804 Mtetra
.72968 .49804 .73455 .50399 .74527 .50077 .74042 .4948 Mtetra
.74042 .4948 .74527 .50077 .75602 .49754 .7512 .49155 Mtetra
.7512 .49155 .75602 .49754 .76681 .4943 .76203 .48829 Mtetra
.76203 .48829 .76681 .4943 .77765 .49105 .77289 .48501 Mtetra
.77289 .48501 .77765 .49105 .78852 .48779 .7838 .48173 Mtetra
.7838 .48173 .78852 .48779 .79944 .48451 .79474 .47843 Mtetra
.79474 .47843 .79944 .48451 .8104 .48122 .80573 .47511 Mtetra
.80573 .47511 .8104 .48122 .8214 .47792 .81676 .47179 Mtetra
.81676 .47179 .8214 .47792 .83244 .4746 .82783 .46845 Mtetra
.82783 .46845 .83244 .4746 .84353 .47128 .83895 .4651 Mtetra
.83895 .4651 .84353 .47128 .85465 .46794 .85011 .46174 Mtetra
.85011 .46174 .85465 .46794 .86582 .46458 .86131 .45836 Mtetra
.86131 .45836 .86582 .46458 .87704 .46122 .87255 .45497 Mtetra
.87255 .45497 .87704 .46122 .88829 .45784 .88384 .45157 Mtetra
.88384 .45157 .88829 .45784 .89959 .45445 .89517 .44815 Mtetra
.89517 .44815 .89959 .45445 .91093 .45104 .90654 .44472 Mtetra
.90654 .44472 .91093 .45104 .92232 .44763 .91796 .44128 Mtetra
.30643 .61871 .31232 .62385 .32155 .62107 .31568 .61591 Mtetra
.31568 .61591 .32155 .62107 .33081 .61828 .32495 .6131 Mtetra
.32495 .6131 .33081 .61828 .3401 .61548 .33427 .61028 Mtetra
.33427 .61028 .3401 .61548 .34942 .61267 .34361 .60746 Mtetra
.34361 .60746 .34942 .61267 .35878 .60985 .35299 .60462 Mtetra
.35299 .60462 .35878 .60985 .36817 .60702 .36239 .60177 Mtetra
.36239 .60177 .36817 .60702 .37759 .60418 .37184 .59891 Mtetra
.37184 .59891 .37759 .60418 .38704 .60133 .38131 .59604 Mtetra
.38131 .59604 .38704 .60133 .39653 .59847 .39082 .59316 Mtetra
.39082 .59316 .39653 .59847 .40606 .5956 .40037 .59027 Mtetra
.40037 .59027 .40606 .5956 .41561 .59272 .40995 .58737 Mtetra
.40995 .58737 .41561 .59272 .4252 .58983 .41956 .58446 Mtetra
.41956 .58446 .4252 .58983 .43483 .58692 .4292 .58154 Mtetra
.4292 .58154 .43483 .58692 .44449 .58401 .43888 .57861 Mtetra
.43888 .57861 .44449 .58401 .45418 .58109 .4486 .57567 Mtetra
.4486 .57567 .45418 .58109 .46391 .57816 .45835 .57272 Mtetra
.45835 .57272 .46391 .57816 .47367 .57521 .46814 .56975 Mtetra
.46814 .56975 .47367 .57521 .48347 .57226 .47796 .56678 Mtetra
.47796 .56678 .48347 .57226 .4933 .5693 .48781 .5638 Mtetra
.48781 .5638 .4933 .5693 .50317 .56632 .49771 .5608 Mtetra
.49771 .5608 .50317 .56632 .51308 .56334 .50763 .55779 Mtetra
.50763 .55779 .51308 .56334 .52302 .56034 .5176 .55478 Mtetra
.5176 .55478 .52302 .56034 .533 .55733 .5276 .55175 Mtetra
.5276 .55175 .533 .55733 .54301 .55431 .53764 .54871 Mtetra
.53764 .54871 .54301 .55431 .55306 .55128 .54771 .54566 Mtetra
.54771 .54566 .55306 .55128 .56314 .54824 .55782 .5426 Mtetra
.55782 .5426 .56314 .54824 .57327 .54519 .56797 .53953 Mtetra
.56797 .53953 .57327 .54519 .58343 .54213 .57815 .53644 Mtetra
.57815 .53644 .58343 .54213 .59363 .53905 .58837 .53335 Mtetra
.58837 .53335 .59363 .53905 .60386 .53597 .59864 .53024 Mtetra
.59864 .53024 .60386 .53597 .61413 .53287 .60893 .52712 Mtetra
.60893 .52712 .61413 .53287 .62444 .52976 .61927 .524 Mtetra
.61927 .524 .62444 .52976 .63479 .52664 .62964 .52085 Mtetra
.62964 .52085 .63479 .52664 .64518 .52351 .64006 .5177 Mtetra
.64006 .5177 .64518 .52351 .6556 .52037 .65051 .51454 Mtetra
.65051 .51454 .6556 .52037 .66607 .51722 .661 .51136 Mtetra
.661 .51136 .66607 .51722 .67657 .51405 .67153 .50817 Mtetra
.67153 .50817 .67657 .51405 .68711 .51087 .6821 .50497 Mtetra
.6821 .50497 .68711 .51087 .6977 .50768 .69271 .50176 Mtetra
.69271 .50176 .6977 .50768 .70832 .50448 .70336 .49854 Mtetra
.70336 .49854 .70832 .50448 .71898 .50127 .71405 .4953 Mtetra
.71405 .4953 .71898 .50127 .72968 .49804 .72477 .49205 Mtetra
.72477 .49205 .72968 .49804 .74042 .4948 .73554 .48879 Mtetra
.73554 .48879 .74042 .4948 .7512 .49155 .74636 .48552 Mtetra
.74636 .48552 .7512 .49155 .76203 .48829 .75721 .48223 Mtetra
.75721 .48223 .76203 .48829 .77289 .48501 .7681 .47893 Mtetra
.7681 .47893 .77289 .48501 .7838 .48173 .77903 .47562 Mtetra
.77903 .47562 .7838 .48173 .79474 .47843 .79001 .4723 Mtetra
.79001 .4723 .79474 .47843 .80573 .47511 .80103 .46897 Mtetra
.80103 .46897 .80573 .47511 .81676 .47179 .81209 .46562 Mtetra
.81209 .46562 .81676 .47179 .82783 .46845 .82319 .46226 Mtetra
.82319 .46226 .82783 .46845 .83895 .4651 .83434 .45888 Mtetra
.83434 .45888 .83895 .4651 .85011 .46174 .84552 .45549 Mtetra
.84552 .45549 .85011 .46174 .86131 .45836 .85676 .45209 Mtetra
.85676 .45209 .86131 .45836 .87255 .45497 .86803 .44868 Mtetra
.86803 .44868 .87255 .45497 .88384 .45157 .87935 .44525 Mtetra
.87935 .44525 .88384 .45157 .89517 .44815 .89071 .44181 Mtetra
.89071 .44181 .89517 .44815 .90654 .44472 .90212 .43836 Mtetra
.90212 .43836 .90654 .44472 .91796 .44128 .91357 .43489 Mtetra
.3005 .61354 .30643 .61871 .31568 .61591 .30977 .61072 Mtetra
.30977 .61072 .31568 .61591 .32495 .6131 .31906 .60789 Mtetra
.31906 .60789 .32495 .6131 .33427 .61028 .32839 .60505 Mtetra
.32839 .60505 .33427 .61028 .34361 .60746 .33776 .60221 Mtetra
.33776 .60221 .34361 .60746 .35299 .60462 .34715 .59935 Mtetra
.34715 .59935 .35299 .60462 .36239 .60177 .35658 .59648 Mtetra
.35658 .59648 .36239 .60177 .37184 .59891 .36605 .5936 Mtetra
.36605 .5936 .37184 .59891 .38131 .59604 .37555 .59072 Mtetra
.37555 .59072 .38131 .59604 .39082 .59316 .38508 .58782 Mtetra
.38508 .58782 .39082 .59316 .40037 .59027 .39464 .58491 Mtetra
.39464 .58491 .40037 .59027 .40995 .58737 .40424 .58199 Mtetra
.40424 .58199 .40995 .58737 .41956 .58446 .41387 .57906 Mtetra
.41387 .57906 .41956 .58446 .4292 .58154 .42354 .57612 Mtetra
.42354 .57612 .4292 .58154 .43888 .57861 .43324 .57317 Mtetra
.43324 .57317 .43888 .57861 .4486 .57567 .44298 .57021 Mtetra
.44298 .57021 .4486 .57567 .45835 .57272 .45276 .56724 Mtetra
.45276 .56724 .45835 .57272 .46814 .56975 .46256 .56426 Mtetra
.46256 .56426 .46814 .56975 .47796 .56678 .47241 .56126 Mtetra
.47241 .56126 .47796 .56678 .48781 .5638 .48229 .55826 Mtetra
.48229 .55826 .48781 .5638 .49771 .5608 .4922 .55524 Mtetra
.4922 .55524 .49771 .5608 .50763 .55779 .50215 .55222 Mtetra
.50215 .55222 .50763 .55779 .5176 .55478 .51214 .54918 Mtetra
.51214 .54918 .5176 .55478 .5276 .55175 .52217 .54613 Mtetra
.52217 .54613 .5276 .55175 .53764 .54871 .53223 .54307 Mtetra
.53223 .54307 .53764 .54871 .54771 .54566 .54232 .54 Mtetra
.54232 .54 .54771 .54566 .55782 .5426 .55246 .53692 Mtetra
.55246 .53692 .55782 .5426 .56797 .53953 .56263 .53383 Mtetra
.56263 .53383 .56797 .53953 .57815 .53644 .57284 .53072 Mtetra
.57284 .53072 .57815 .53644 .58837 .53335 .58309 .52761 Mtetra
.58309 .52761 .58837 .53335 .59864 .53024 .59337 .52448 Mtetra
.59337 .52448 .59864 .53024 .60893 .52712 .6037 .52134 Mtetra
.6037 .52134 .60893 .52712 .61927 .524 .61406 .51819 Mtetra
.61406 .51819 .61927 .524 .62964 .52085 .62446 .51503 Mtetra
.62446 .51503 .62964 .52085 .64006 .5177 .6349 .51185 Mtetra
.6349 .51185 .64006 .5177 .65051 .51454 .64538 .50866 Mtetra
.64538 .50866 .65051 .51454 .661 .51136 .65589 .50547 Mtetra
.65589 .50547 .661 .51136 .67153 .50817 .66645 .50226 Mtetra
.66645 .50226 .67153 .50817 .6821 .50497 .67705 .49903 Mtetra
.67705 .49903 .6821 .50497 .69271 .50176 .68768 .4958 Mtetra
.68768 .4958 .69271 .50176 .70336 .49854 .69836 .49255 Mtetra
.69836 .49255 .70336 .49854 .71405 .4953 .70908 .48929 Mtetra
.70908 .48929 .71405 .4953 .72477 .49205 .71984 .48602 Mtetra
.71984 .48602 .72477 .49205 .73554 .48879 .73063 .48274 Mtetra
.73063 .48274 .73554 .48879 .74636 .48552 .74147 .47944 Mtetra
.74147 .47944 .74636 .48552 .75721 .48223 .75235 .47613 Mtetra
.75235 .47613 .75721 .48223 .7681 .47893 .76328 .47281 Mtetra
.76328 .47281 .7681 .47893 .77903 .47562 .77424 .46948 Mtetra
.77424 .46948 .77903 .47562 .79001 .4723 .78524 .46613 Mtetra
.78524 .46613 .79001 .4723 .80103 .46897 .79629 .46277 Mtetra
.79629 .46277 .80103 .46897 .81209 .46562 .80738 .4594 Mtetra
.80738 .4594 .81209 .46562 .82319 .46226 .81852 .45602 Mtetra
.81852 .45602 .82319 .46226 .83434 .45888 .82969 .45262 Mtetra
.82969 .45262 .83434 .45888 .84552 .45549 .84091 .44921 Mtetra
.84091 .44921 .84552 .45549 .85676 .45209 .85217 .44578 Mtetra
.85217 .44578 .85676 .45209 .86803 .44868 .86348 .44234 Mtetra
.86348 .44234 .86803 .44868 .87935 .44525 .87483 .43889 Mtetra
.87483 .43889 .87935 .44525 .89071 .44181 .88623 .43543 Mtetra
.88623 .43543 .89071 .44181 .90212 .43836 .89766 .43195 Mtetra
.89766 .43195 .90212 .43836 .91357 .43489 .90915 .42846 Mtetra
.29453 .60833 .3005 .61354 .30977 .61072 .30382 .60549 Mtetra
.30382 .60549 .30977 .61072 .31906 .60789 .31314 .60265 Mtetra
.31314 .60265 .31906 .60789 .32839 .60505 .32249 .59979 Mtetra
.32249 .59979 .32839 .60505 .33776 .60221 .33187 .59692 Mtetra
.33187 .59692 .33776 .60221 .34715 .59935 .34129 .59405 Mtetra
.34129 .59405 .34715 .59935 .35658 .59648 .35074 .59116 Mtetra
.35074 .59116 .35658 .59648 .36605 .5936 .36022 .58826 Mtetra
.36022 .58826 .36605 .5936 .37555 .59072 .36974 .58536 Mtetra
.36974 .58536 .37555 .59072 .38508 .58782 .37929 .58244 Mtetra
.37929 .58244 .38508 .58782 .39464 .58491 .38888 .57951 Mtetra
.38888 .57951 .39464 .58491 .40424 .58199 .3985 .57657 Mtetra
.3985 .57657 .40424 .58199 .41387 .57906 .40815 .57363 Mtetra
.40815 .57363 .41387 .57906 .42354 .57612 .41784 .57067 Mtetra
.41784 .57067 .42354 .57612 .43324 .57317 .42757 .5677 Mtetra
.42757 .5677 .43324 .57317 .44298 .57021 .43733 .56471 Mtetra
.43733 .56471 .44298 .57021 .45276 .56724 .44712 .56172 Mtetra
.44712 .56172 .45276 .56724 .46256 .56426 .45695 .55872 Mtetra
.45695 .55872 .46256 .56426 .47241 .56126 .46682 .55571 Mtetra
.46682 .55571 .47241 .56126 .48229 .55826 .47672 .55268 Mtetra
.47672 .55268 .48229 .55826 .4922 .55524 .48666 .54965 Mtetra
.48666 .54965 .4922 .55524 .50215 .55222 .49664 .5466 Mtetra
.49664 .5466 .50215 .55222 .51214 .54918 .50665 .54354 Mtetra
.50665 .54354 .51214 .54918 .52217 .54613 .5167 .54047 Mtetra
.5167 .54047 .52217 .54613 .53223 .54307 .52678 .53739 Mtetra
.52678 .53739 .53223 .54307 .54232 .54 .5369 .5343 Mtetra
.5369 .5343 .54232 .54 .55246 .53692 .54706 .5312 Mtetra
.54706 .5312 .55246 .53692 .56263 .53383 .55726 .52809 Mtetra
.55726 .52809 .56263 .53383 .57284 .53072 .56749 .52496 Mtetra
.56749 .52496 .57284 .53072 .58309 .52761 .57777 .52182 Mtetra
.57777 .52182 .58309 .52761 .59337 .52448 .58808 .51867 Mtetra
.58808 .51867 .59337 .52448 .6037 .52134 .59843 .51551 Mtetra
.59843 .51551 .6037 .52134 .61406 .51819 .60881 .51234 Mtetra
.60881 .51234 .61406 .51819 .62446 .51503 .61924 .50916 Mtetra
.61924 .50916 .62446 .51503 .6349 .51185 .62971 .50596 Mtetra
.62971 .50596 .6349 .51185 .64538 .50866 .64021 .50275 Mtetra
.64021 .50275 .64538 .50866 .65589 .50547 .65075 .49953 Mtetra
.65075 .49953 .65589 .50547 .66645 .50226 .66134 .4963 Mtetra
.66134 .4963 .66645 .50226 .67705 .49903 .67196 .49305 Mtetra
.67196 .49305 .67705 .49903 .68768 .4958 .68263 .4898 Mtetra
.68263 .4898 .68768 .4958 .69836 .49255 .69333 .48653 Mtetra
.69333 .48653 .69836 .49255 .70908 .48929 .70408 .48325 Mtetra
.70408 .48325 .70908 .48929 .71984 .48602 .71486 .47995 Mtetra
.71486 .47995 .71984 .48602 .73063 .48274 .72569 .47664 Mtetra
.72569 .47664 .73063 .48274 .74147 .47944 .73656 .47333 Mtetra
.73656 .47333 .74147 .47944 .75235 .47613 .74746 .46999 Mtetra
.74746 .46999 .75235 .47613 .76328 .47281 .75842 .46665 Mtetra
.75842 .46665 .76328 .47281 .77424 .46948 .76941 .46329 Mtetra
.76941 .46329 .77424 .46948 .78524 .46613 .78044 .45992 Mtetra
.78044 .45992 .78524 .46613 .79629 .46277 .79152 .45654 Mtetra
.79152 .45654 .79629 .46277 .80738 .4594 .80264 .45314 Mtetra
.80264 .45314 .80738 .4594 .81852 .45602 .81381 .44973 Mtetra
.81381 .44973 .81852 .45602 .82969 .45262 .82501 .44631 Mtetra
.82501 .44631 .82969 .45262 .84091 .44921 .83626 .44287 Mtetra
.83626 .44287 .84091 .44921 .85217 .44578 .84756 .43942 Mtetra
.84756 .43942 .85217 .44578 .86348 .44234 .8589 .43596 Mtetra
.8589 .43596 .86348 .44234 .87483 .43889 .87028 .43248 Mtetra
.87028 .43248 .87483 .43889 .88623 .43543 .88171 .42899 Mtetra
.88171 .42899 .88623 .43543 .89766 .43195 .89318 .42549 Mtetra
.89318 .42549 .89766 .43195 .90915 .42846 .90469 .42197 Mtetra
.28853 .60308 .29453 .60833 .30382 .60549 .29783 .60023 Mtetra
.29783 .60023 .30382 .60549 .31314 .60265 .30717 .59737 Mtetra
.30717 .59737 .31314 .60265 .32249 .59979 .31654 .59449 Mtetra
.31654 .59449 .32249 .59979 .33187 .59692 .32594 .59161 Mtetra
.32594 .59161 .33187 .59692 .34129 .59405 .33538 .58871 Mtetra
.33538 .58871 .34129 .59405 .35074 .59116 .34485 .58581 Mtetra
.34485 .58581 .35074 .59116 .36022 .58826 .35435 .58289 Mtetra
.35435 .58289 .36022 .58826 .36974 .58536 .36389 .57996 Mtetra
.36389 .57996 .36974 .58536 .37929 .58244 .37347 .57703 Mtetra
.37347 .57703 .37929 .58244 .38888 .57951 .38307 .57408 Mtetra
.38307 .57408 .38888 .57951 .3985 .57657 .39272 .57112 Mtetra
.39272 .57112 .3985 .57657 .40815 .57363 .40239 .56815 Mtetra
.40239 .56815 .40815 .57363 .41784 .57067 .41211 .56517 Mtetra
.41211 .56517 .41784 .57067 .42757 .5677 .42185 .56218 Mtetra
.42185 .56218 .42757 .5677 .43733 .56471 .43163 .55918 Mtetra
.43163 .55918 .43733 .56471 .44712 .56172 .44145 .55617 Mtetra
.44145 .55617 .44712 .56172 .45695 .55872 .45131 .55315 Mtetra
.45131 .55315 .45695 .55872 .46682 .55571 .4612 .55012 Mtetra
.4612 .55012 .46682 .55571 .47672 .55268 .47112 .54707 Mtetra
.47112 .54707 .47672 .55268 .48666 .54965 .48108 .54401 Mtetra
.48108 .54401 .48666 .54965 .49664 .5466 .49108 .54095 Mtetra
.49108 .54095 .49664 .5466 .50665 .54354 .50112 .53787 Mtetra
.50112 .53787 .50665 .54354 .5167 .54047 .51119 .53478 Mtetra
.51119 .53478 .5167 .54047 .52678 .53739 .5213 .53168 Mtetra
.5213 .53168 .52678 .53739 .5369 .5343 .53144 .52857 Mtetra
.53144 .52857 .5369 .5343 .54706 .5312 .54163 .52544 Mtetra
.54163 .52544 .54706 .5312 .55726 .52809 .55185 .52231 Mtetra
.55185 .52231 .55726 .52809 .56749 .52496 .56211 .51916 Mtetra
.56211 .51916 .56749 .52496 .57777 .52182 .57241 .516 Mtetra
.57241 .516 .57777 .52182 .58808 .51867 .58274 .51283 Mtetra
.58274 .51283 .58808 .51867 .59843 .51551 .59312 .50965 Mtetra
.59312 .50965 .59843 .51551 .60881 .51234 .60353 .50645 Mtetra
.60353 .50645 .60881 .51234 .61924 .50916 .61398 .50324 Mtetra
.61398 .50324 .61924 .50916 .62971 .50596 .62448 .50003 Mtetra
.62448 .50003 .62971 .50596 .64021 .50275 .63501 .4968 Mtetra
.63501 .4968 .64021 .50275 .65075 .49953 .64558 .49355 Mtetra
.64558 .49355 .65075 .49953 .66134 .4963 .65619 .4903 Mtetra
.65619 .4903 .66134 .4963 .67196 .49305 .66684 .48703 Mtetra
.66684 .48703 .67196 .49305 .68263 .4898 .67753 .48375 Mtetra
.67753 .48375 .68263 .4898 .69333 .48653 .68826 .48046 Mtetra
.68826 .48046 .69333 .48653 .70408 .48325 .69904 .47715 Mtetra
.69904 .47715 .70408 .48325 .71486 .47995 .70985 .47384 Mtetra
.70985 .47384 .71486 .47995 .72569 .47664 .72071 .47051 Mtetra
.72071 .47051 .72569 .47664 .73656 .47333 .7316 .46716 Mtetra
.7316 .46716 .73656 .47333 .74746 .46999 .74254 .46381 Mtetra
.74254 .46381 .74746 .46999 .75842 .46665 .75352 .46044 Mtetra
.75352 .46044 .75842 .46665 .76941 .46329 .76455 .45706 Mtetra
.76455 .45706 .76941 .46329 .78044 .45992 .77561 .45366 Mtetra
.77561 .45366 .78044 .45992 .79152 .45654 .78672 .45026 Mtetra
.78672 .45026 .79152 .45654 .80264 .45314 .79787 .44684 Mtetra
.79787 .44684 .80264 .45314 .81381 .44973 .80906 .4434 Mtetra
.80906 .4434 .81381 .44973 .82501 .44631 .8203 .43995 Mtetra
.8203 .43995 .82501 .44631 .83626 .44287 .83158 .43649 Mtetra
.83158 .43649 .83626 .44287 .84756 .43942 .84291 .43302 Mtetra
.84291 .43302 .84756 .43942 .8589 .43596 .85428 .42953 Mtetra
.85428 .42953 .8589 .43596 .87028 .43248 .86569 .42603 Mtetra
.86569 .42603 .87028 .43248 .88171 .42899 .87715 .42251 Mtetra
.87715 .42251 .88171 .42899 .89318 .42549 .88866 .41899 Mtetra
.88866 .41899 .89318 .42549 .90469 .42197 .90021 .41544 Mtetra
.28248 .59781 .28853 .60308 .29783 .60023 .2918 .59493 Mtetra
.2918 .59493 .29783 .60023 .30717 .59737 .30116 .59205 Mtetra
.30116 .59205 .30717 .59737 .31654 .59449 .31055 .58916 Mtetra
.31055 .58916 .31654 .59449 .32594 .59161 .31998 .58625 Mtetra
.31998 .58625 .32594 .59161 .33538 .58871 .32943 .58334 Mtetra
.32943 .58334 .33538 .58871 .34485 .58581 .33892 .58041 Mtetra
.33892 .58041 .34485 .58581 .35435 .58289 .34845 .57748 Mtetra
.34845 .57748 .35435 .58289 .36389 .57996 .35801 .57453 Mtetra
.35801 .57453 .36389 .57996 .37347 .57703 .3676 .57158 Mtetra
.3676 .57158 .37347 .57703 .38307 .57408 .37723 .56861 Mtetra
.37723 .56861 .38307 .57408 .39272 .57112 .3869 .56563 Mtetra
.3869 .56563 .39272 .57112 .40239 .56815 .3966 .56264 Mtetra
.3966 .56264 .40239 .56815 .41211 .56517 .40633 .55965 Mtetra
.40633 .55965 .41211 .56517 .42185 .56218 .4161 .55664 Mtetra
.4161 .55664 .42185 .56218 .43163 .55918 .4259 .55361 Mtetra
.4259 .55361 .43163 .55918 .44145 .55617 .43574 .55058 Mtetra
.43574 .55058 .44145 .55617 .45131 .55315 .44562 .54754 Mtetra
.44562 .54754 .45131 .55315 .4612 .55012 .45553 .54449 Mtetra
.45553 .54449 .4612 .55012 .47112 .54707 .46548 .54142 Mtetra
.46548 .54142 .47112 .54707 .48108 .54401 .47547 .53834 Mtetra
.47547 .53834 .48108 .54401 .49108 .54095 .48549 .53526 Mtetra
.48549 .53526 .49108 .54095 .50112 .53787 .49555 .53216 Mtetra
.49555 .53216 .50112 .53787 .51119 .53478 .50564 .52905 Mtetra
.50564 .52905 .51119 .53478 .5213 .53168 .51578 .52592 Mtetra
.51578 .52592 .5213 .53168 .53144 .52857 .52595 .52279 Mtetra
.52595 .52279 .53144 .52857 .54163 .52544 .53616 .51964 Mtetra
.53616 .51964 .54163 .52544 .55185 .52231 .5464 .51649 Mtetra
.5464 .51649 .55185 .52231 .56211 .51916 .55669 .51332 Mtetra
.55669 .51332 .56211 .51916 .57241 .516 .56701 .51014 Mtetra
.56701 .51014 .57241 .516 .58274 .51283 .57737 .50694 Mtetra
.57737 .50694 .58274 .51283 .59312 .50965 .58777 .50374 Mtetra
.58777 .50374 .59312 .50965 .60353 .50645 .59821 .50052 Mtetra
.59821 .50052 .60353 .50645 .61398 .50324 .60869 .49729 Mtetra
.60869 .49729 .61398 .50324 .62448 .50003 .61921 .49405 Mtetra
.61921 .49405 .62448 .50003 .63501 .4968 .62977 .4908 Mtetra
.62977 .4908 .63501 .4968 .64558 .49355 .64037 .48753 Mtetra
.64037 .48753 .64558 .49355 .65619 .4903 .65101 .48426 Mtetra
.65101 .48426 .65619 .4903 .66684 .48703 .66168 .48097 Mtetra
.66168 .48097 .66684 .48703 .67753 .48375 .6724 .47766 Mtetra
.6724 .47766 .67753 .48375 .68826 .48046 .68316 .47435 Mtetra
.68316 .47435 .68826 .48046 .69904 .47715 .69396 .47102 Mtetra
.69396 .47102 .69904 .47715 .70985 .47384 .70481 .46768 Mtetra
.70481 .46768 .70985 .47384 .72071 .47051 .71569 .46433 Mtetra
.71569 .46433 .72071 .47051 .7316 .46716 .72662 .46096 Mtetra
.72662 .46096 .7316 .46716 .74254 .46381 .73758 .45758 Mtetra
.73758 .45758 .74254 .46381 .75352 .46044 .74859 .45419 Mtetra
.74859 .45419 .75352 .46044 .76455 .45706 .75965 .45078 Mtetra
.75965 .45078 .76455 .45706 .77561 .45366 .77074 .44736 Mtetra
.77074 .44736 .77561 .45366 .78672 .45026 .78188 .44393 Mtetra
.78188 .44393 .78672 .45026 .79787 .44684 .79306 .44049 Mtetra
.79306 .44049 .79787 .44684 .80906 .4434 .80429 .43703 Mtetra
.80429 .43703 .80906 .4434 .8203 .43995 .81556 .43355 Mtetra
.81556 .43355 .8203 .43995 .83158 .43649 .82687 .43007 Mtetra
.82687 .43007 .83158 .43649 .84291 .43302 .83823 .42657 Mtetra
.83823 .42657 .84291 .43302 .85428 .42953 .84963 .42306 Mtetra
.84963 .42306 .85428 .42953 .86569 .42603 .86108 .41953 Mtetra
.86108 .41953 .86569 .42603 .87715 .42251 .87257 .41599 Mtetra
.87257 .41599 .87715 .42251 .88866 .41899 .8841 .41243 Mtetra
.8841 .41243 .88866 .41899 .90021 .41544 .89569 .40886 Mtetra
.27639 .59249 .28248 .59781 .2918 .59493 .28574 .5896 Mtetra
.28574 .5896 .2918 .59493 .30116 .59205 .29511 .5867 Mtetra
.29511 .5867 .30116 .59205 .31055 .58916 .30452 .58379 Mtetra
.30452 .58379 .31055 .58916 .31998 .58625 .31397 .58087 Mtetra
.31397 .58087 .31998 .58625 .32943 .58334 .32345 .57793 Mtetra
.32345 .57793 .32943 .58334 .33892 .58041 .33296 .57499 Mtetra
.33296 .57499 .33892 .58041 .34845 .57748 .34251 .57203 Mtetra
.34251 .57203 .34845 .57748 .35801 .57453 .35209 .56907 Mtetra
.35209 .56907 .35801 .57453 .3676 .57158 .3617 .56609 Mtetra
.3617 .56609 .3676 .57158 .37723 .56861 .37135 .56311 Mtetra
.37135 .56311 .37723 .56861 .3869 .56563 .38104 .56011 Mtetra
.38104 .56011 .3869 .56563 .3966 .56264 .39076 .5571 Mtetra
.39076 .5571 .3966 .56264 .40633 .55965 .40052 .55408 Mtetra
.40052 .55408 .40633 .55965 .4161 .55664 .41031 .55105 Mtetra
.41031 .55105 .4161 .55664 .4259 .55361 .42013 .54801 Mtetra
.42013 .54801 .4259 .55361 .43574 .55058 .43 .54496 Mtetra
.43 .54496 .43574 .55058 .44562 .54754 .4399 .54189 Mtetra
.4399 .54189 .44562 .54754 .45553 .54449 .44983 .53882 Mtetra
.44983 .53882 .45553 .54449 .46548 .54142 .4598 .53573 Mtetra
.4598 .53573 .46548 .54142 .47547 .53834 .46981 .53263 Mtetra
.46981 .53263 .47547 .53834 .48549 .53526 .47986 .52952 Mtetra
.47986 .52952 .48549 .53526 .49555 .53216 .48994 .5264 Mtetra
.48994 .5264 .49555 .53216 .50564 .52905 .50006 .52327 Mtetra
.50006 .52327 .50564 .52905 .51578 .52592 .51022 .52013 Mtetra
.51022 .52013 .51578 .52592 .52595 .52279 .52041 .51697 Mtetra
.52041 .51697 .52595 .52279 .53616 .51964 .53065 .51381 Mtetra
.53065 .51381 .53616 .51964 .5464 .51649 .54092 .51063 Mtetra
.54092 .51063 .5464 .51649 .55669 .51332 .55123 .50744 Mtetra
.55123 .50744 .55669 .51332 .56701 .51014 .56158 .50423 Mtetra
.56158 .50423 .56701 .51014 .57737 .50694 .57197 .50102 Mtetra
.57197 .50102 .57737 .50694 .58777 .50374 .58239 .49779 Mtetra
.58239 .49779 .58777 .50374 .59821 .50052 .59286 .49455 Mtetra
.59286 .49455 .59821 .50052 .60869 .49729 .60336 .4913 Mtetra
.60336 .4913 .60869 .49729 .61921 .49405 .61391 .48804 Mtetra
.61391 .48804 .61921 .49405 .62977 .4908 .62449 .48476 Mtetra
.62449 .48476 .62977 .4908 .64037 .48753 .63512 .48147 Mtetra
.63512 .48147 .64037 .48753 .65101 .48426 .64578 .47817 Mtetra
.64578 .47817 .65101 .48426 .66168 .48097 .65649 .47486 Mtetra
.65649 .47486 .66168 .48097 .6724 .47766 .66724 .47153 Mtetra
.66724 .47153 .6724 .47766 .68316 .47435 .67803 .46819 Mtetra
.67803 .46819 .68316 .47435 .69396 .47102 .68886 .46484 Mtetra
.68886 .46484 .69396 .47102 .70481 .46768 .69973 .46148 Mtetra
.69973 .46148 .70481 .46768 .71569 .46433 .71064 .4581 Mtetra
.71064 .4581 .71569 .46433 .72662 .46096 .72159 .45471 Mtetra
.72159 .45471 .72662 .46096 .73758 .45758 .73259 .45131 Mtetra
.73259 .45131 .73758 .45758 .74859 .45419 .74363 .44789 Mtetra
.74363 .44789 .74859 .45419 .75965 .45078 .75471 .44446 Mtetra
.75471 .44446 .75965 .45078 .77074 .44736 .76584 .44102 Mtetra
.76584 .44102 .77074 .44736 .78188 .44393 .77701 .43756 Mtetra
.77701 .43756 .78188 .44393 .79306 .44049 .78822 .43409 Mtetra
.78822 .43409 .79306 .44049 .80429 .43703 .79948 .43061 Mtetra
.79948 .43061 .80429 .43703 .81556 .43355 .81078 .42711 Mtetra
.81078 .42711 .81556 .43355 .82687 .43007 .82212 .4236 Mtetra
.82212 .4236 .82687 .43007 .83823 .42657 .83351 .42007 Mtetra
.83351 .42007 .83823 .42657 .84963 .42306 .84494 .41653 Mtetra
.84494 .41653 .84963 .42306 .86108 .41953 .85642 .41298 Mtetra
.85642 .41298 .86108 .41953 .87257 .41599 .86795 .40941 Mtetra
.86795 .40941 .87257 .41599 .8841 .41243 .87952 .40583 Mtetra
.87952 .40583 .8841 .41243 .89569 .40886 .89113 .40224 Mtetra
.27027 .58715 .27639 .59249 .28574 .5896 .27963 .58424 Mtetra
.27963 .58424 .28574 .5896 .29511 .5867 .28903 .58132 Mtetra
.28903 .58132 .29511 .5867 .30452 .58379 .29846 .57838 Mtetra
.29846 .57838 .30452 .58379 .31397 .58087 .30792 .57544 Mtetra
.30792 .57544 .31397 .58087 .32345 .57793 .31742 .57249 Mtetra
.31742 .57249 .32345 .57793 .33296 .57499 .32696 .56952 Mtetra
.32696 .56952 .33296 .57499 .34251 .57203 .33652 .56655 Mtetra
.33652 .56655 .34251 .57203 .35209 .56907 .34613 .56357 Mtetra
.34613 .56357 .35209 .56907 .3617 .56609 .35576 .56057 Mtetra
.35576 .56057 .3617 .56609 .37135 .56311 .36543 .55756 Mtetra
.36543 .55756 .37135 .56311 .38104 .56011 .37514 .55455 Mtetra
.37514 .55455 .38104 .56011 .39076 .5571 .38488 .55152 Mtetra
.38488 .55152 .39076 .5571 .40052 .55408 .39466 .54848 Mtetra
.39466 .54848 .40052 .55408 .41031 .55105 .40448 .54543 Mtetra
.40448 .54543 .41031 .55105 .42013 .54801 .41432 .54236 Mtetra
.41432 .54236 .42013 .54801 .43 .54496 .42421 .53929 Mtetra
.42421 .53929 .43 .54496 .4399 .54189 .43413 .53621 Mtetra
.43413 .53621 .4399 .54189 .44983 .53882 .44409 .53311 Mtetra
.44409 .53311 .44983 .53882 .4598 .53573 .45409 .53 Mtetra
.45409 .53 .4598 .53573 .46981 .53263 .46412 .52688 Mtetra
.46412 .52688 .46981 .53263 .47986 .52952 .47419 .52375 Mtetra
.47419 .52375 .47986 .52952 .48994 .5264 .4843 .52061 Mtetra
.4843 .52061 .48994 .5264 .50006 .52327 .49444 .51746 Mtetra
.49444 .51746 .50006 .52327 .51022 .52013 .50462 .51429 Mtetra
.50462 .51429 .51022 .52013 .52041 .51697 .51484 .51112 Mtetra
.51484 .51112 .52041 .51697 .53065 .51381 .5251 .50793 Mtetra
.5251 .50793 .53065 .51381 .54092 .51063 .5354 .50473 Mtetra
.5354 .50473 .54092 .51063 .55123 .50744 .54573 .50151 Mtetra
.54573 .50151 .55123 .50744 .56158 .50423 .55611 .49829 Mtetra
.55611 .49829 .56158 .50423 .57197 .50102 .56652 .49505 Mtetra
.56652 .49505 .57197 .50102 .58239 .49779 .57697 .4918 Mtetra
.57697 .4918 .58239 .49779 .59286 .49455 .58747 .48854 Mtetra
.58747 .48854 .59286 .49455 .60336 .4913 .598 .48527 Mtetra
.598 .48527 .60336 .4913 .61391 .48804 .60857 .48198 Mtetra
.60857 .48198 .61391 .48804 .62449 .48476 .61918 .47868 Mtetra
.61918 .47868 .62449 .48476 .63512 .48147 .62983 .47537 Mtetra
.62983 .47537 .63512 .48147 .64578 .47817 .64053 .47205 Mtetra
.64053 .47205 .64578 .47817 .65649 .47486 .65126 .46871 Mtetra
.65126 .46871 .65649 .47486 .66724 .47153 .66204 .46536 Mtetra
.66204 .46536 .66724 .47153 .67803 .46819 .67285 .462 Mtetra
.67285 .462 .67803 .46819 .68886 .46484 .68371 .45862 Mtetra
.68371 .45862 .68886 .46484 .69973 .46148 .69461 .45523 Mtetra
.69461 .45523 .69973 .46148 .71064 .4581 .70555 .45183 Mtetra
.70555 .45183 .71064 .4581 .72159 .45471 .71654 .44842 Mtetra
.71654 .44842 .72159 .45471 .73259 .45131 .72756 .44499 Mtetra
.72756 .44499 .73259 .45131 .74363 .44789 .73863 .44155 Mtetra
.73863 .44155 .74363 .44789 .75471 .44446 .74974 .43809 Mtetra
.74974 .43809 .75471 .44446 .76584 .44102 .7609 .43462 Mtetra
.7609 .43462 .76584 .44102 .77701 .43756 .7721 .43114 Mtetra
.7721 .43114 .77701 .43756 .78822 .43409 .78334 .42765 Mtetra
.78334 .42765 .78822 .43409 .79948 .43061 .79463 .42414 Mtetra
.79463 .42414 .79948 .43061 .81078 .42711 .80596 .42062 Mtetra
.80596 .42062 .81078 .42711 .82212 .4236 .81734 .41708 Mtetra
.81734 .41708 .82212 .4236 .83351 .42007 .82876 .41353 Mtetra
.82876 .41353 .83351 .42007 .84494 .41653 .84023 .40996 Mtetra
.84023 .40996 .84494 .41653 .85642 .41298 .85174 .40639 Mtetra
.85174 .40639 .85642 .41298 .86795 .40941 .8633 .40279 Mtetra
.8633 .40279 .86795 .40941 .87952 .40583 .8749 .39919 Mtetra
.8749 .39919 .87952 .40583 .89113 .40224 .88655 .39556 Mtetra
.2641 .58177 .27027 .58715 .27963 .58424 .27348 .57884 Mtetra
.27348 .57884 .27963 .58424 .28903 .58132 .2829 .57589 Mtetra
.2829 .57589 .28903 .58132 .29846 .57838 .29235 .57294 Mtetra
.29235 .57294 .29846 .57838 .30792 .57544 .30184 .56998 Mtetra
.30184 .56998 .30792 .57544 .31742 .57249 .31136 .56701 Mtetra
.31136 .56701 .31742 .57249 .32696 .56952 .32091 .56403 Mtetra
.32091 .56403 .32696 .56952 .33652 .56655 .3305 .56103 Mtetra
.3305 .56103 .33652 .56655 .34613 .56357 .34012 .55803 Mtetra
.34012 .55803 .34613 .56357 .35576 .56057 .34978 .55501 Mtetra
.34978 .55501 .35576 .56057 .36543 .55756 .35947 .55198 Mtetra
.35947 .55198 .36543 .55756 .37514 .55455 .3692 .54895 Mtetra
.3692 .54895 .37514 .55455 .38488 .55152 .37897 .5459 Mtetra
.37897 .5459 .38488 .55152 .39466 .54848 .38877 .54284 Mtetra
.38877 .54284 .39466 .54848 .40448 .54543 .3986 .53976 Mtetra
.3986 .53976 .40448 .54543 .41432 .54236 .40848 .53668 Mtetra
.40848 .53668 .41432 .54236 .42421 .53929 .41839 .53359 Mtetra
.41839 .53359 .42421 .53929 .43413 .53621 .42833 .53048 Mtetra
.42833 .53048 .43413 .53621 .44409 .53311 .43831 .52737 Mtetra
.43831 .52737 .44409 .53311 .45409 .53 .44833 .52424 Mtetra
.44833 .52424 .45409 .53 .46412 .52688 .45839 .5211 Mtetra
.45839 .5211 .46412 .52688 .47419 .52375 .46848 .51794 Mtetra
.46848 .51794 .47419 .52375 .4843 .52061 .47861 .51478 Mtetra
.47861 .51478 .4843 .52061 .49444 .51746 .48878 .51161 Mtetra
.48878 .51161 .49444 .51746 .50462 .51429 .49899 .50842 Mtetra
.49899 .50842 .50462 .51429 .51484 .51112 .50923 .50522 Mtetra
.50923 .50522 .51484 .51112 .5251 .50793 .51952 .50201 Mtetra
.51952 .50201 .5251 .50793 .5354 .50473 .52984 .49879 Mtetra
.52984 .49879 .5354 .50473 .54573 .50151 .5402 .49555 Mtetra
.5402 .49555 .54573 .50151 .55611 .49829 .5506 .4923 Mtetra
.5506 .4923 .55611 .49829 .56652 .49505 .56104 .48904 Mtetra
.56104 .48904 .56652 .49505 .57697 .4918 .57152 .48577 Mtetra
.57152 .48577 .57697 .4918 .58747 .48854 .58203 .48249 Mtetra
.58203 .48249 .58747 .48854 .598 .48527 .59259 .47919 Mtetra
.59259 .47919 .598 .48527 .60857 .48198 .60319 .47588 Mtetra
.60319 .47588 .60857 .48198 .61918 .47868 .61383 .47256 Mtetra
.61383 .47256 .61918 .47868 .62983 .47537 .62451 .46922 Mtetra
.62451 .46922 .62983 .47537 .64053 .47205 .63523 .46587 Mtetra
.63523 .46587 .64053 .47205 .65126 .46871 .64599 .46251 Mtetra
.64599 .46251 .65126 .46871 .66204 .46536 .6568 .45914 Mtetra
.6568 .45914 .66204 .46536 .67285 .462 .66764 .45575 Mtetra
.66764 .45575 .67285 .462 .68371 .45862 .67853 .45235 Mtetra
.67853 .45235 .68371 .45862 .69461 .45523 .68946 .44894 Mtetra
.68946 .44894 .69461 .45523 .70555 .45183 .70043 .44552 Mtetra
.70043 .44552 .70555 .45183 .71654 .44842 .71144 .44208 Mtetra
.71144 .44208 .71654 .44842 .72756 .44499 .7225 .43862 Mtetra
.7225 .43862 .72756 .44499 .73863 .44155 .7336 .43516 Mtetra
.7336 .43516 .73863 .44155 .74974 .43809 .74474 .43168 Mtetra
.74474 .43168 .74974 .43809 .7609 .43462 .75593 .42819 Mtetra
.75593 .42819 .7609 .43462 .7721 .43114 .76716 .42468 Mtetra
.76716 .42468 .7721 .43114 .78334 .42765 .77843 .42116 Mtetra
.77843 .42116 .78334 .42765 .79463 .42414 .78975 .41762 Mtetra
.78975 .41762 .79463 .42414 .80596 .42062 .80111 .41408 Mtetra
.80111 .41408 .80596 .42062 .81734 .41708 .81252 .41051 Mtetra
.81252 .41051 .81734 .41708 .82876 .41353 .82397 .40694 Mtetra
.82397 .40694 .82876 .41353 .84023 .40996 .83547 .40335 Mtetra
.83547 .40335 .84023 .40996 .85174 .40639 .84702 .39974 Mtetra
.84702 .39974 .85174 .40639 .8633 .40279 .85861 .39612 Mtetra
.85861 .39612 .8633 .40279 .8749 .39919 .87025 .39249 Mtetra
.87025 .39249 .8749 .39919 .88655 .39556 .88193 .38884 Mtetra
.25789 .57635 .2641 .58177 .27348 .57884 .2673 .5734 Mtetra
.2673 .5734 .27348 .57884 .2829 .57589 .27673 .57044 Mtetra
.27673 .57044 .2829 .57589 .29235 .57294 .2862 .56747 Mtetra
.2862 .56747 .29235 .57294 .30184 .56998 .29571 .56449 Mtetra
.29571 .56449 .30184 .56998 .31136 .56701 .30525 .56149 Mtetra
.30525 .56149 .31136 .56701 .32091 .56403 .31483 .55849 Mtetra
.31483 .55849 .32091 .56403 .3305 .56103 .32444 .55547 Mtetra
.32444 .55547 .3305 .56103 .34012 .55803 .33408 .55245 Mtetra
.33408 .55245 .34012 .55803 .34978 .55501 .34376 .54941 Mtetra
.34376 .54941 .34978 .55501 .35947 .55198 .35348 .54637 Mtetra
.35348 .54637 .35947 .55198 .3692 .54895 .36323 .54331 Mtetra
.36323 .54331 .3692 .54895 .37897 .5459 .37301 .54024 Mtetra
.37301 .54024 .37897 .5459 .38877 .54284 .38284 .53716 Mtetra
.38284 .53716 .38877 .54284 .3986 .53976 .39269 .53406 Mtetra
.39269 .53406 .3986 .53976 .40848 .53668 .40259 .53096 Mtetra
.40259 .53096 .40848 .53668 .41839 .53359 .41252 .52785 Mtetra
.41252 .52785 .41839 .53359 .42833 .53048 .42249 .52472 Mtetra
.42249 .52472 .42833 .53048 .43831 .52737 .43249 .52158 Mtetra
.43249 .52158 .43831 .52737 .44833 .52424 .44254 .51843 Mtetra
.44254 .51843 .44833 .52424 .45839 .5211 .45262 .51527 Mtetra
.45262 .51527 .45839 .5211 .46848 .51794 .46273 .5121 Mtetra
.46273 .5121 .46848 .51794 .47861 .51478 .47289 .50891 Mtetra
.47289 .50891 .47861 .51478 .48878 .51161 .48308 .50571 Mtetra
.48308 .50571 .48878 .51161 .49899 .50842 .49331 .5025 Mtetra
.49331 .5025 .49899 .50842 .50923 .50522 .50358 .49928 Mtetra
.50358 .49928 .50923 .50522 .51952 .50201 .51389 .49605 Mtetra
.51389 .49605 .51952 .50201 .52984 .49879 .52424 .4928 Mtetra
.52424 .4928 .52984 .49879 .5402 .49555 .53463 .48955 Mtetra
.53463 .48955 .5402 .49555 .5506 .4923 .54505 .48627 Mtetra
.54505 .48627 .5506 .4923 .56104 .48904 .55552 .48299 Mtetra
.55552 .48299 .56104 .48904 .57152 .48577 .56602 .4797 Mtetra
.56602 .4797 .57152 .48577 .58203 .48249 .57657 .47639 Mtetra
.57657 .47639 .58203 .48249 .59259 .47919 .58715 .47307 Mtetra
.58715 .47307 .59259 .47919 .60319 .47588 .59778 .46974 Mtetra
.59778 .46974 .60319 .47588 .61383 .47256 .60844 .46639 Mtetra
.60844 .46639 .61383 .47256 .62451 .46922 .61915 .46303 Mtetra
.61915 .46303 .62451 .46922 .63523 .46587 .6299 .45966 Mtetra
.6299 .45966 .63523 .46587 .64599 .46251 .64069 .45628 Mtetra
.64069 .45628 .64599 .46251 .6568 .45914 .65152 .45288 Mtetra
.65152 .45288 .6568 .45914 .66764 .45575 .66239 .44947 Mtetra
.66239 .44947 .66764 .45575 .67853 .45235 .67331 .44604 Mtetra
.67331 .44604 .67853 .45235 .68946 .44894 .68427 .44261 Mtetra
.68427 .44261 .68946 .44894 .70043 .44552 .69527 .43916 Mtetra
.69527 .43916 .70043 .44552 .71144 .44208 .70631 .43569 Mtetra
.70631 .43569 .71144 .44208 .7225 .43862 .7174 .43222 Mtetra
.7174 .43222 .7225 .43862 .7336 .43516 .72853 .42872 Mtetra
.72853 .42872 .7336 .43516 .74474 .43168 .7397 .42522 Mtetra
.7397 .42522 .74474 .43168 .75593 .42819 .75092 .4217 Mtetra
.75092 .4217 .75593 .42819 .76716 .42468 .76218 .41817 Mtetra
.76218 .41817 .76716 .42468 .77843 .42116 .77348 .41462 Mtetra
.77348 .41462 .77843 .42116 .78975 .41762 .78483 .41106 Mtetra
.78483 .41106 .78975 .41762 .80111 .41408 .79623 .40749 Mtetra
.79623 .40749 .80111 .41408 .81252 .41051 .80767 .4039 Mtetra
.80767 .4039 .81252 .41051 .82397 .40694 .81915 .4003 Mtetra
.81915 .4003 .82397 .40694 .83547 .40335 .83069 .39668 Mtetra
.83069 .39668 .83547 .40335 .84702 .39974 .84226 .39305 Mtetra
.84226 .39305 .84702 .39974 .85861 .39612 .85389 .3894 Mtetra
.85389 .3894 .85861 .39612 .87025 .39249 .86556 .38574 Mtetra
.86556 .38574 .87025 .39249 .88193 .38884 .87727 .38207 Mtetra
.25164 .57089 .25789 .57635 .2673 .5734 .26107 .56792 Mtetra
.26107 .56792 .2673 .5734 .27673 .57044 .27052 .56494 Mtetra
.27052 .56494 .27673 .57044 .2862 .56747 .28002 .56195 Mtetra
.28002 .56195 .2862 .56747 .29571 .56449 .28954 .55895 Mtetra
.28954 .55895 .29571 .56449 .30525 .56149 .2991 .55594 Mtetra
.2991 .55594 .30525 .56149 .31483 .55849 .3087 .55292 Mtetra
.3087 .55292 .31483 .55849 .32444 .55547 .31833 .54988 Mtetra
.31833 .54988 .32444 .55547 .33408 .55245 .328 .54684 Mtetra
.328 .54684 .33408 .55245 .34376 .54941 .3377 .54378 Mtetra
.3377 .54378 .34376 .54941 .35348 .54637 .34744 .54071 Mtetra
.34744 .54071 .35348 .54637 .36323 .54331 .35721 .53763 Mtetra
.35721 .53763 .36323 .54331 .37301 .54024 .36702 .53454 Mtetra
.36702 .53454 .37301 .54024 .38284 .53716 .37686 .53144 Mtetra
.37686 .53144 .38284 .53716 .39269 .53406 .38674 .52833 Mtetra
.38674 .52833 .39269 .53406 .40259 .53096 .39666 .5252 Mtetra
.39666 .5252 .40259 .53096 .41252 .52785 .40662 .52206 Mtetra
.40662 .52206 .41252 .52785 .42249 .52472 .41661 .51892 Mtetra
.41661 .51892 .42249 .52472 .43249 .52158 .42664 .51576 Mtetra
.42664 .51576 .43249 .52158 .44254 .51843 .4367 .51258 Mtetra
.4367 .51258 .44254 .51843 .45262 .51527 .44681 .5094 Mtetra
.44681 .5094 .45262 .51527 .46273 .5121 .45695 .50621 Mtetra
.45695 .50621 .46273 .5121 .47289 .50891 .46713 .503 Mtetra
.46713 .503 .47289 .50891 .48308 .50571 .47734 .49978 Mtetra
.47734 .49978 .48308 .50571 .49331 .5025 .4876 .49655 Mtetra
.4876 .49655 .49331 .5025 .50358 .49928 .49789 .4933 Mtetra
.49789 .4933 .50358 .49928 .51389 .49605 .50823 .49005 Mtetra
.50823 .49005 .51389 .49605 .52424 .4928 .5186 .48678 Mtetra
.5186 .48678 .52424 .4928 .53463 .48955 .52901 .4835 Mtetra
.52901 .4835 .53463 .48955 .54505 .48627 .53946 .4802 Mtetra
.53946 .4802 .54505 .48627 .55552 .48299 .54996 .4769 Mtetra
.54996 .4769 .55552 .48299 .56602 .4797 .56049 .47358 Mtetra
.56049 .47358 .56602 .4797 .57657 .47639 .57106 .47025 Mtetra
.57106 .47025 .57657 .47639 .58715 .47307 .58167 .46691 Mtetra
.58167 .46691 .58715 .47307 .59778 .46974 .59232 .46355 Mtetra
.59232 .46355 .59778 .46974 .60844 .46639 .60302 .46018 Mtetra
.60302 .46018 .60844 .46639 .61915 .46303 .61375 .4568 Mtetra
.61375 .4568 .61915 .46303 .6299 .45966 .62453 .4534 Mtetra
.62453 .4534 .6299 .45966 .64069 .45628 .63535 .44999 Mtetra
.63535 .44999 .64069 .45628 .65152 .45288 .64621 .44657 Mtetra
.64621 .44657 .65152 .45288 .66239 .44947 .65711 .44314 Mtetra
.65711 .44314 .66239 .44947 .67331 .44604 .66805 .43969 Mtetra
.66805 .43969 .67331 .44604 .68427 .44261 .67904 .43623 Mtetra
.67904 .43623 .68427 .44261 .69527 .43916 .69007 .43275 Mtetra
.69007 .43275 .69527 .43916 .70631 .43569 .70114 .42926 Mtetra
.70114 .42926 .70631 .43569 .7174 .43222 .71226 .42576 Mtetra
.71226 .42576 .7174 .43222 .72853 .42872 .72342 .42224 Mtetra
.72342 .42224 .72853 .42872 .7397 .42522 .73462 .41871 Mtetra
.73462 .41871 .7397 .42522 .75092 .4217 .74587 .41517 Mtetra
.74587 .41517 .75092 .4217 .76218 .41817 .75716 .41161 Mtetra
.75716 .41161 .76218 .41817 .77348 .41462 .7685 .40804 Mtetra
.7685 .40804 .77348 .41462 .78483 .41106 .77988 .40445 Mtetra
.77988 .40445 .78483 .41106 .79623 .40749 .79131 .40085 Mtetra
.79131 .40085 .79623 .40749 .80767 .4039 .80278 .39724 Mtetra
.80278 .39724 .80767 .4039 .81915 .4003 .8143 .39361 Mtetra
.8143 .39361 .81915 .4003 .83069 .39668 .82586 .38996 Mtetra
.82586 .38996 .83069 .39668 .84226 .39305 .83747 .38631 Mtetra
.83747 .38631 .84226 .39305 .85389 .3894 .84913 .38263 Mtetra
.84913 .38263 .85389 .3894 .86556 .38574 .86083 .37895 Mtetra
.86083 .37895 .86556 .38574 .87727 .38207 .87259 .37524 Mtetra
.24535 .5654 .25164 .57089 .26107 .56792 .2548 .56241 Mtetra
.2548 .56241 .26107 .56792 .27052 .56494 .26427 .55941 Mtetra
.26427 .55941 .27052 .56494 .28002 .56195 .27379 .5564 Mtetra
.27379 .5564 .28002 .56195 .28954 .55895 .28333 .55338 Mtetra
.28333 .55338 .28954 .55895 .2991 .55594 .29292 .55035 Mtetra
.29292 .55035 .2991 .55594 .3087 .55292 .30253 .5473 Mtetra
.30253 .5473 .3087 .55292 .31833 .54988 .31218 .54425 Mtetra
.31218 .54425 .31833 .54988 .328 .54684 .32187 .54118 Mtetra
.32187 .54118 .328 .54684 .3377 .54378 .3316 .53811 Mtetra
.3316 .53811 .3377 .54378 .34744 .54071 .34135 .53502 Mtetra
.34135 .53502 .34744 .54071 .35721 .53763 .35115 .53192 Mtetra
.35115 .53192 .35721 .53763 .36702 .53454 .36098 .52881 Mtetra
.36098 .52881 .36702 .53454 .37686 .53144 .37085 .52568 Mtetra
.37085 .52568 .37686 .53144 .38674 .52833 .38075 .52255 Mtetra
.38075 .52255 .38674 .52833 .39666 .5252 .39069 .5194 Mtetra
.39069 .5194 .39666 .5252 .40662 .52206 .40067 .51624 Mtetra
.40067 .51624 .40662 .52206 .41661 .51892 .41068 .51307 Mtetra
.41068 .51307 .41661 .51892 .42664 .51576 .42074 .50989 Mtetra
.42074 .50989 .42664 .51576 .4367 .51258 .43083 .5067 Mtetra
.43083 .5067 .4367 .51258 .44681 .5094 .44095 .50349 Mtetra
.44095 .50349 .44681 .5094 .45695 .50621 .45112 .50027 Mtetra
.45112 .50027 .45695 .50621 .46713 .503 .46132 .49704 Mtetra
.46132 .49704 .46713 .503 .47734 .49978 .47157 .4938 Mtetra
.47157 .4938 .47734 .49978 .4876 .49655 .48185 .49055 Mtetra
.48185 .49055 .4876 .49655 .49789 .4933 .49217 .48728 Mtetra
.49217 .48728 .49789 .4933 .50823 .49005 .50253 .484 Mtetra
.50253 .484 .50823 .49005 .5186 .48678 .51292 .48071 Mtetra
.51292 .48071 .5186 .48678 .52901 .4835 .52336 .47741 Mtetra
.52336 .47741 .52901 .4835 .53946 .4802 .53384 .47409 Mtetra
.53384 .47409 .53946 .4802 .54996 .4769 .54436 .47076 Mtetra
.54436 .47076 .54996 .4769 .56049 .47358 .55491 .46742 Mtetra
.55491 .46742 .56049 .47358 .57106 .47025 .56551 .46407 Mtetra
.56551 .46407 .57106 .47025 .58167 .46691 .57615 .4607 Mtetra
.57615 .4607 .58167 .46691 .59232 .46355 .58683 .45732 Mtetra
.58683 .45732 .59232 .46355 .60302 .46018 .59755 .45393 Mtetra
.59755 .45393 .60302 .46018 .61375 .4568 .60832 .45052 Mtetra
.60832 .45052 .61375 .4568 .62453 .4534 .61912 .4471 Mtetra
.61912 .4471 .62453 .4534 .63535 .44999 .62997 .44367 Mtetra
.62997 .44367 .63535 .44999 .64621 .44657 .64085 .44022 Mtetra
.64085 .44022 .64621 .44657 .65711 .44314 .65178 .43676 Mtetra
.65178 .43676 .65711 .44314 .66805 .43969 .66276 .43329 Mtetra
.66276 .43329 .66805 .43969 .67904 .43623 .67377 .4298 Mtetra
.67377 .4298 .67904 .43623 .69007 .43275 .68483 .4263 Mtetra
.68483 .4263 .69007 .43275 .70114 .42926 .69594 .42279 Mtetra
.69594 .42279 .70114 .42926 .71226 .42576 .70708 .41926 Mtetra
.70708 .41926 .71226 .42576 .72342 .42224 .71827 .41572 Mtetra
.71827 .41572 .72342 .42224 .73462 .41871 .72951 .41216 Mtetra
.72951 .41216 .73462 .41871 .74587 .41517 .74079 .40859 Mtetra
.74079 .40859 .74587 .41517 .75716 .41161 .75211 .40501 Mtetra
.75211 .40501 .75716 .41161 .7685 .40804 .76348 .40141 Mtetra
.76348 .40141 .7685 .40804 .77988 .40445 .77489 .39779 Mtetra
.77489 .39779 .77988 .40445 .79131 .40085 .78635 .39417 Mtetra
.78635 .39417 .79131 .40085 .80278 .39724 .79786 .39053 Mtetra
.79786 .39053 .80278 .39724 .8143 .39361 .80941 .38687 Mtetra
.80941 .38687 .8143 .39361 .82586 .38996 .821 .3832 Mtetra
.821 .3832 .82586 .38996 .83747 .38631 .83265 .37951 Mtetra
.83265 .37951 .83747 .38631 .84913 .38263 .84434 .37581 Mtetra
.84434 .37581 .84913 .38263 .86083 .37895 .85608 .3721 Mtetra
.85608 .3721 .86083 .37895 .87259 .37524 .86786 .36837 Mtetra
.23902 .55988 .24535 .5654 .2548 .56241 .24848 .55687 Mtetra
.24848 .55687 .2548 .56241 .26427 .55941 .25798 .55385 Mtetra
.25798 .55385 .26427 .55941 .27379 .5564 .26751 .55082 Mtetra
.26751 .55082 .27379 .5564 .28333 .55338 .27708 .54777 Mtetra
.27708 .54777 .28333 .55338 .29292 .55035 .28669 .54472 Mtetra
.28669 .54472 .29292 .55035 .30253 .5473 .29632 .54166 Mtetra
.29632 .54166 .30253 .5473 .31218 .54425 .306 .53858 Mtetra
.306 .53858 .31218 .54425 .32187 .54118 .31571 .53549 Mtetra
.31571 .53549 .32187 .54118 .3316 .53811 .32545 .53239 Mtetra
.32545 .53239 .3316 .53811 .34135 .53502 .33523 .52928 Mtetra
.33523 .52928 .34135 .53502 .35115 .53192 .34505 .52616 Mtetra
.34505 .52616 .35115 .53192 .36098 .52881 .3549 .52303 Mtetra
.3549 .52303 .36098 .52881 .37085 .52568 .36479 .51989 Mtetra
.36479 .51989 .37085 .52568 .38075 .52255 .37472 .51673 Mtetra
.37472 .51673 .38075 .52255 .39069 .5194 .38468 .51356 Mtetra
.38468 .51356 .39069 .5194 .40067 .51624 .39468 .51038 Mtetra
.39468 .51038 .40067 .51624 .41068 .51307 .40472 .50719 Mtetra
.40472 .50719 .41068 .51307 .42074 .50989 .4148 .50399 Mtetra
.4148 .50399 .42074 .50989 .43083 .5067 .42491 .50077 Mtetra
.42491 .50077 .43083 .5067 .44095 .50349 .43506 .49754 Mtetra
.43506 .49754 .44095 .50349 .45112 .50027 .44525 .4943 Mtetra
.44525 .4943 .45112 .50027 .46132 .49704 .45548 .49105 Mtetra
.45548 .49105 .46132 .49704 .47157 .4938 .46575 .48779 Mtetra
.46575 .48779 .47157 .4938 .48185 .49055 .47605 .48451 Mtetra
.47605 .48451 .48185 .49055 .49217 .48728 .4864 .48122 Mtetra
.4864 .48122 .49217 .48728 .50253 .484 .49678 .47792 Mtetra
.49678 .47792 .50253 .484 .51292 .48071 .50721 .4746 Mtetra
.50721 .4746 .51292 .48071 .52336 .47741 .51767 .47128 Mtetra
.51767 .47128 .52336 .47741 .53384 .47409 .52817 .46794 Mtetra
.52817 .46794 .53384 .47409 .54436 .47076 .53872 .46458 Mtetra
.53872 .46458 .54436 .47076 .55491 .46742 .5493 .46122 Mtetra
.5493 .46122 .55491 .46742 .56551 .46407 .55993 .45784 Mtetra
.55993 .45784 .56551 .46407 .57615 .4607 .57059 .45445 Mtetra
.57059 .45445 .57615 .4607 .58683 .45732 .5813 .45104 Mtetra
.5813 .45104 .58683 .45732 .59755 .45393 .59205 .44763 Mtetra
.59205 .44763 .59755 .45393 .60832 .45052 .60284 .4442 Mtetra
.60284 .4442 .60832 .45052 .61912 .4471 .61367 .44075 Mtetra
.61367 .44075 .61912 .4471 .62997 .44367 .62455 .43729 Mtetra
.62455 .43729 .62997 .44367 .64085 .44022 .63546 .43382 Mtetra
.63546 .43382 .64085 .44022 .65178 .43676 .64642 .43034 Mtetra
.64642 .43034 .65178 .43676 .66276 .43329 .65743 .42684 Mtetra
.65743 .42684 .66276 .43329 .67377 .4298 .66847 .42333 Mtetra
.66847 .42333 .67377 .4298 .68483 .4263 .67956 .4198 Mtetra
.67956 .4198 .68483 .4263 .69594 .42279 .69069 .41626 Mtetra
.69069 .41626 .69594 .42279 .70708 .41926 .70187 .41271 Mtetra
.70187 .41271 .70708 .41926 .71827 .41572 .71309 .40914 Mtetra
.71309 .40914 .71827 .41572 .72951 .41216 .72436 .40556 Mtetra
.72436 .40556 .72951 .41216 .74079 .40859 .73566 .40196 Mtetra
.73566 .40196 .74079 .40859 .75211 .40501 .74702 .39835 Mtetra
.74702 .39835 .75211 .40501 .76348 .40141 .75842 .39473 Mtetra
.75842 .39473 .76348 .40141 .77489 .39779 .76987 .39109 Mtetra
.76987 .39109 .77489 .39779 .78635 .39417 .78136 .38743 Mtetra
.78136 .38743 .78635 .39417 .79786 .39053 .79289 .38376 Mtetra
.79289 .38376 .79786 .39053 .80941 .38687 .80448 .38008 Mtetra
.80448 .38008 .80941 .38687 .821 .3832 .81611 .37638 Mtetra
.81611 .37638 .821 .3832 .83265 .37951 .82779 .37267 Mtetra
.82779 .37267 .83265 .37951 .84434 .37581 .83951 .36894 Mtetra
.83951 .36894 .84434 .37581 .85608 .3721 .85128 .3652 Mtetra
.85128 .3652 .85608 .3721 .86786 .36837 .8631 .36144 Mtetra
.23264 .55431 .23902 .55988 .24848 .55687 .24213 .55128 Mtetra
.24213 .55128 .24848 .55687 .25798 .55385 .25165 .54824 Mtetra
.25165 .54824 .25798 .55385 .26751 .55082 .2612 .54519 Mtetra
.2612 .54519 .26751 .55082 .27708 .54777 .27079 .54213 Mtetra
.27079 .54213 .27708 .54777 .28669 .54472 .28041 .53905 Mtetra
.28041 .53905 .28669 .54472 .29632 .54166 .29007 .53597 Mtetra
.29007 .53597 .29632 .54166 .306 .53858 .29977 .53287 Mtetra
.29977 .53287 .306 .53858 .31571 .53549 .3095 .52976 Mtetra
.3095 .52976 .31571 .53549 .32545 .53239 .31926 .52664 Mtetra
.31926 .52664 .32545 .53239 .33523 .52928 .32907 .52351 Mtetra
.32907 .52351 .33523 .52928 .34505 .52616 .33891 .52037 Mtetra
.33891 .52037 .34505 .52616 .3549 .52303 .34878 .51722 Mtetra
.34878 .51722 .3549 .52303 .36479 .51989 .35869 .51405 Mtetra
.35869 .51405 .36479 .51989 .37472 .51673 .36864 .51087 Mtetra
.36864 .51087 .37472 .51673 .38468 .51356 .37863 .50768 Mtetra
.37863 .50768 .38468 .51356 .39468 .51038 .38865 .50448 Mtetra
.38865 .50448 .39468 .51038 .40472 .50719 .39872 .50127 Mtetra
.39872 .50127 .40472 .50719 .4148 .50399 .40882 .49804 Mtetra
.40882 .49804 .4148 .50399 .42491 .50077 .41895 .4948 Mtetra
.41895 .4948 .42491 .50077 .43506 .49754 .42913 .49155 Mtetra
.42913 .49155 .43506 .49754 .44525 .4943 .43934 .48829 Mtetra
.43934 .48829 .44525 .4943 .45548 .49105 .4496 .48501 Mtetra
.4496 .48501 .45548 .49105 .46575 .48779 .45989 .48173 Mtetra
.45989 .48173 .46575 .48779 .47605 .48451 .47022 .47843 Mtetra
.47022 .47843 .47605 .48451 .4864 .48122 .48059 .47511 Mtetra
.48059 .47511 .4864 .48122 .49678 .47792 .491 .47179 Mtetra
.491 .47179 .49678 .47792 .50721 .4746 .50145 .46845 Mtetra
.50145 .46845 .50721 .4746 .51767 .47128 .51194 .4651 Mtetra
.51194 .4651 .51767 .47128 .52817 .46794 .52247 .46174 Mtetra
.52247 .46174 .52817 .46794 .53872 .46458 .53304 .45836 Mtetra
.53304 .45836 .53872 .46458 .5493 .46122 .54365 .45497 Mtetra
.54365 .45497 .5493 .46122 .55993 .45784 .5543 .45157 Mtetra
.5543 .45157 .55993 .45784 .57059 .45445 .565 .44815 Mtetra
.565 .44815 .57059 .45445 .5813 .45104 .57573 .44472 Mtetra
.57573 .44472 .5813 .45104 .59205 .44763 .58651 .44128 Mtetra
.58651 .44128 .59205 .44763 .60284 .4442 .59732 .43783 Mtetra
.59732 .43783 .60284 .4442 .61367 .44075 .60819 .43436 Mtetra
.60819 .43436 .61367 .44075 .62455 .43729 .61909 .43087 Mtetra
.61909 .43087 .62455 .43729 .63546 .43382 .63003 .42738 Mtetra
.63003 .42738 .63546 .43382 .64642 .43034 .64102 .42387 Mtetra
.64102 .42387 .64642 .43034 .65743 .42684 .65205 .42034 Mtetra
.65205 .42034 .65743 .42684 .66847 .42333 .66313 .41681 Mtetra
.66313 .41681 .66847 .42333 .67956 .4198 .67425 .41326 Mtetra
.67425 .41326 .67956 .4198 .69069 .41626 .68541 .40969 Mtetra
.68541 .40969 .69069 .41626 .70187 .41271 .69662 .40611 Mtetra
.69662 .40611 .70187 .41271 .71309 .40914 .70787 .40252 Mtetra
.70787 .40252 .71309 .40914 .72436 .40556 .71917 .39891 Mtetra
.71917 .39891 .72436 .40556 .73566 .40196 .73051 .39529 Mtetra
.73051 .39529 .73566 .40196 .74702 .39835 .74189 .39165 Mtetra
.74189 .39165 .74702 .39835 .75842 .39473 .75332 .388 Mtetra
.75332 .388 .75842 .39473 .76987 .39109 .7648 .38433 Mtetra
.7648 .38433 .76987 .39109 .78136 .38743 .77633 .38065 Mtetra
.77633 .38065 .78136 .38743 .79289 .38376 .7879 .37695 Mtetra
.7879 .37695 .79289 .38376 .80448 .38008 .79951 .37324 Mtetra
.79951 .37324 .80448 .38008 .81611 .37638 .81118 .36952 Mtetra
.81118 .36952 .81611 .37638 .82779 .37267 .82289 .36578 Mtetra
.82289 .36578 .82779 .37267 .83951 .36894 .83465 .36202 Mtetra
.83465 .36202 .83951 .36894 .85128 .3652 .84645 .35825 Mtetra
.84645 .35825 .85128 .3652 .8631 .36144 .85831 .35446 Mtetra
.22623 .54871 .23264 .55431 .24213 .55128 .23573 .54566 Mtetra
.23573 .54566 .24213 .55128 .25165 .54824 .24527 .5426 Mtetra
.24527 .5426 .25165 .54824 .2612 .54519 .25484 .53953 Mtetra
.25484 .53953 .2612 .54519 .27079 .54213 .26445 .53644 Mtetra
.26445 .53644 .27079 .54213 .28041 .53905 .2741 .53335 Mtetra
.2741 .53335 .28041 .53905 .29007 .53597 .28378 .53024 Mtetra
.28378 .53024 .29007 .53597 .29977 .53287 .2935 .52712 Mtetra
.2935 .52712 .29977 .53287 .3095 .52976 .30325 .524 Mtetra
.30325 .524 .3095 .52976 .31926 .52664 .31304 .52085 Mtetra
.31304 .52085 .31926 .52664 .32907 .52351 .32286 .5177 Mtetra
.32286 .5177 .32907 .52351 .33891 .52037 .33272 .51454 Mtetra
.33272 .51454 .33891 .52037 .34878 .51722 .34262 .51136 Mtetra
.34262 .51136 .34878 .51722 .35869 .51405 .35256 .50817 Mtetra
.35256 .50817 .35869 .51405 .36864 .51087 .36253 .50497 Mtetra
.36253 .50497 .36864 .51087 .37863 .50768 .37254 .50176 Mtetra
.37254 .50176 .37863 .50768 .38865 .50448 .38258 .49854 Mtetra
.38258 .49854 .38865 .50448 .39872 .50127 .39267 .4953 Mtetra
.39267 .4953 .39872 .50127 .40882 .49804 .40279 .49205 Mtetra
.40279 .49205 .40882 .49804 .41895 .4948 .41295 .48879 Mtetra
.41295 .48879 .41895 .4948 .42913 .49155 .42315 .48552 Mtetra
.42315 .48552 .42913 .49155 .43934 .48829 .43339 .48223 Mtetra
.43339 .48223 .43934 .48829 .4496 .48501 .44367 .47893 Mtetra
.44367 .47893 .4496 .48501 .45989 .48173 .45399 .47562 Mtetra
.45399 .47562 .45989 .48173 .47022 .47843 .46434 .4723 Mtetra
.46434 .4723 .47022 .47843 .48059 .47511 .47474 .46897 Mtetra
.47474 .46897 .48059 .47511 .491 .47179 .48517 .46562 Mtetra
.48517 .46562 .491 .47179 .50145 .46845 .49565 .46226 Mtetra
.49565 .46226 .50145 .46845 .51194 .4651 .50617 .45888 Mtetra
.50617 .45888 .51194 .4651 .52247 .46174 .51672 .45549 Mtetra
.51672 .45549 .52247 .46174 .53304 .45836 .52732 .45209 Mtetra
.52732 .45209 .53304 .45836 .54365 .45497 .53796 .44868 Mtetra
.53796 .44868 .54365 .45497 .5543 .45157 .54864 .44525 Mtetra
.54864 .44525 .5543 .45157 .565 .44815 .55936 .44181 Mtetra
.55936 .44181 .565 .44815 .57573 .44472 .57012 .43836 Mtetra
.57012 .43836 .57573 .44472 .58651 .44128 .58092 .43489 Mtetra
.58092 .43489 .58651 .44128 .59732 .43783 .59177 .43141 Mtetra
.59177 .43141 .59732 .43783 .60819 .43436 .60266 .42792 Mtetra
.60266 .42792 .60819 .43436 .61909 .43087 .61359 .42441 Mtetra
.61359 .42441 .61909 .43087 .63003 .42738 .62456 .42089 Mtetra
.62456 .42089 .63003 .42738 .64102 .42387 .63558 .41735 Mtetra
.63558 .41735 .64102 .42387 .65205 .42034 .64664 .4138 Mtetra
.64664 .4138 .65205 .42034 .66313 .41681 .65775 .41024 Mtetra
.65775 .41024 .66313 .41681 .67425 .41326 .6689 .40666 Mtetra
.6689 .40666 .67425 .41326 .68541 .40969 .68009 .40307 Mtetra
.68009 .40307 .68541 .40969 .69662 .40611 .69133 .39946 Mtetra
.69133 .39946 .69662 .40611 .70787 .40252 .70261 .39584 Mtetra
.70261 .39584 .70787 .40252 .71917 .39891 .71394 .39221 Mtetra
.71394 .39221 .71917 .39891 .73051 .39529 .72531 .38856 Mtetra
.72531 .38856 .73051 .39529 .74189 .39165 .73673 .3849 Mtetra
.73673 .3849 .74189 .39165 .75332 .388 .74819 .38122 Mtetra
.74819 .38122 .75332 .388 .7648 .38433 .7597 .37752 Mtetra
.7597 .37752 .7648 .38433 .77633 .38065 .77126 .37381 Mtetra
.77126 .37381 .77633 .38065 .7879 .37695 .78286 .37009 Mtetra
.78286 .37009 .7879 .37695 .79951 .37324 .79451 .36635 Mtetra
.79451 .36635 .79951 .37324 .81118 .36952 .80621 .3626 Mtetra
.80621 .3626 .81118 .36952 .82289 .36578 .81795 .35883 Mtetra
.81795 .35883 .82289 .36578 .83465 .36202 .82975 .35505 Mtetra
.82975 .35505 .83465 .36202 .84645 .35825 .84159 .35125 Mtetra
.84159 .35125 .84645 .35825 .85831 .35446 .85348 .34743 Mtetra
.21976 .54307 .22623 .54871 .23573 .54566 .22929 .54 Mtetra
.22929 .54 .23573 .54566 .24527 .5426 .23885 .53692 Mtetra
.23885 .53692 .24527 .5426 .25484 .53953 .24844 .53383 Mtetra
.24844 .53383 .25484 .53953 .26445 .53644 .25807 .53072 Mtetra
.25807 .53072 .26445 .53644 .2741 .53335 .26774 .52761 Mtetra
.26774 .52761 .2741 .53335 .28378 .53024 .27744 .52448 Mtetra
.27744 .52448 .28378 .53024 .2935 .52712 .28718 .52134 Mtetra
.28718 .52134 .2935 .52712 .30325 .524 .29695 .51819 Mtetra
.29695 .51819 .30325 .524 .31304 .52085 .30676 .51503 Mtetra
.30676 .51503 .31304 .52085 .32286 .5177 .31661 .51185 Mtetra
.31661 .51185 .32286 .5177 .33272 .51454 .3265 .50866 Mtetra
.3265 .50866 .33272 .51454 .34262 .51136 .33642 .50547 Mtetra
.33642 .50547 .34262 .51136 .35256 .50817 .34637 .50226 Mtetra
.34637 .50226 .35256 .50817 .36253 .50497 .35637 .49903 Mtetra
.35637 .49903 .36253 .50497 .37254 .50176 .3664 .4958 Mtetra
.3664 .4958 .37254 .50176 .38258 .49854 .37647 .49255 Mtetra
.37647 .49255 .38258 .49854 .39267 .4953 .38658 .48929 Mtetra
.38658 .48929 .39267 .4953 .40279 .49205 .39673 .48602 Mtetra
.39673 .48602 .40279 .49205 .41295 .48879 .40691 .48274 Mtetra
.40691 .48274 .41295 .48879 .42315 .48552 .41714 .47944 Mtetra
.41714 .47944 .42315 .48552 .43339 .48223 .4274 .47613 Mtetra
.4274 .47613 .43339 .48223 .44367 .47893 .4377 .47281 Mtetra
.4377 .47281 .44367 .47893 .45399 .47562 .44805 .46948 Mtetra
.44805 .46948 .45399 .47562 .46434 .4723 .45843 .46613 Mtetra
.45843 .46613 .46434 .4723 .47474 .46897 .46885 .46277 Mtetra
.46885 .46277 .47474 .46897 .48517 .46562 .47931 .4594 Mtetra
.47931 .4594 .48517 .46562 .49565 .46226 .48981 .45602 Mtetra
.48981 .45602 .49565 .46226 .50617 .45888 .50035 .45262 Mtetra
.50035 .45262 .50617 .45888 .51672 .45549 .51093 .44921 Mtetra
.51093 .44921 .51672 .45549 .52732 .45209 .52156 .44578 Mtetra
.52156 .44578 .52732 .45209 .53796 .44868 .53222 .44234 Mtetra
.53222 .44234 .53796 .44868 .54864 .44525 .54293 .43889 Mtetra
.54293 .43889 .54864 .44525 .55936 .44181 .55368 .43543 Mtetra
.55368 .43543 .55936 .44181 .57012 .43836 .56447 .43195 Mtetra
.56447 .43195 .57012 .43836 .58092 .43489 .5753 .42846 Mtetra
.5753 .42846 .58092 .43489 .59177 .43141 .58617 .42495 Mtetra
.58617 .42495 .59177 .43141 .60266 .42792 .59709 .42143 Mtetra
.59709 .42143 .60266 .42792 .61359 .42441 .60805 .4179 Mtetra
.60805 .4179 .61359 .42441 .62456 .42089 .61906 .41435 Mtetra
.61906 .41435 .62456 .42089 .63558 .41735 .6301 .41079 Mtetra
.6301 .41079 .63558 .41735 .64664 .4138 .64119 .40721 Mtetra
.64119 .40721 .64664 .4138 .65775 .41024 .65233 .40362 Mtetra
.65233 .40362 .65775 .41024 .6689 .40666 .66351 .40002 Mtetra
.66351 .40002 .6689 .40666 .68009 .40307 .67473 .3964 Mtetra
.67473 .3964 .68009 .40307 .69133 .39946 .686 .39277 Mtetra
.686 .39277 .69133 .39946 .70261 .39584 .69731 .38912 Mtetra
.69731 .38912 .70261 .39584 .71394 .39221 .70867 .38546 Mtetra
.70867 .38546 .71394 .39221 .72531 .38856 .72007 .38178 Mtetra
.72007 .38178 .72531 .38856 .73673 .3849 .73152 .37809 Mtetra
.73152 .37809 .73673 .3849 .74819 .38122 .74302 .37439 Mtetra
.74302 .37439 .74819 .38122 .7597 .37752 .75456 .37067 Mtetra
.75456 .37067 .7597 .37752 .77126 .37381 .76615 .36693 Mtetra
.76615 .36693 .77126 .37381 .78286 .37009 .77779 .36318 Mtetra
.77779 .36318 .78286 .37009 .79451 .36635 .78947 .35941 Mtetra
.78947 .35941 .79451 .36635 .80621 .3626 .8012 .35563 Mtetra
.8012 .35563 .80621 .3626 .81795 .35883 .81298 .35183 Mtetra
.81298 .35183 .81795 .35883 .82975 .35505 .82481 .34802 Mtetra
.82481 .34802 .82975 .35505 .84159 .35125 .83668 .34419 Mtetra
.83668 .34419 .84159 .35125 .85348 .34743 .84861 .34035 Mtetra
.21326 .53739 .21976 .54307 .22929 .54 .2228 .5343 Mtetra
.2228 .5343 .22929 .54 .23885 .53692 .23238 .5312 Mtetra
.23238 .5312 .23885 .53692 .24844 .53383 .242 .52809 Mtetra
.242 .52809 .24844 .53383 .25807 .53072 .25165 .52496 Mtetra
.25165 .52496 .25807 .53072 .26774 .52761 .26134 .52182 Mtetra
.26134 .52182 .26774 .52761 .27744 .52448 .27106 .51867 Mtetra
.27106 .51867 .27744 .52448 .28718 .52134 .28082 .51551 Mtetra
.28082 .51551 .28718 .52134 .29695 .51819 .29062 .51234 Mtetra
.29062 .51234 .29695 .51819 .30676 .51503 .30045 .50916 Mtetra
.30045 .50916 .30676 .51503 .31661 .51185 .31032 .50596 Mtetra
.31032 .50596 .31661 .51185 .3265 .50866 .32022 .50275 Mtetra
.32022 .50275 .3265 .50866 .33642 .50547 .33017 .49953 Mtetra
.33017 .49953 .33642 .50547 .34637 .50226 .34015 .4963 Mtetra
.34015 .4963 .34637 .50226 .35637 .49903 .35017 .49305 Mtetra
.35017 .49305 .35637 .49903 .3664 .4958 .36022 .4898 Mtetra
.36022 .4898 .3664 .4958 .37647 .49255 .37032 .48653 Mtetra
.37032 .48653 .37647 .49255 .38658 .48929 .38045 .48325 Mtetra
.38045 .48325 .38658 .48929 .39673 .48602 .39062 .47995 Mtetra
.39062 .47995 .39673 .48602 .40691 .48274 .40083 .47664 Mtetra
.40083 .47664 .40691 .48274 .41714 .47944 .41108 .47333 Mtetra
.41108 .47333 .41714 .47944 .4274 .47613 .42137 .46999 Mtetra
.42137 .46999 .4274 .47613 .4377 .47281 .43169 .46665 Mtetra
.43169 .46665 .4377 .47281 .44805 .46948 .44206 .46329 Mtetra
.44206 .46329 .44805 .46948 .45843 .46613 .45247 .45992 Mtetra
.45247 .45992 .45843 .46613 .46885 .46277 .46291 .45654 Mtetra
.46291 .45654 .46885 .46277 .47931 .4594 .4734 .45314 Mtetra
.4734 .45314 .47931 .4594 .48981 .45602 .48393 .44973 Mtetra
.48393 .44973 .48981 .45602 .50035 .45262 .4945 .44631 Mtetra
.4945 .44631 .50035 .45262 .51093 .44921 .50511 .44287 Mtetra
.50511 .44287 .51093 .44921 .52156 .44578 .51576 .43942 Mtetra
.51576 .43942 .52156 .44578 .53222 .44234 .52645 .43596 Mtetra
.52645 .43596 .53222 .44234 .54293 .43889 .53718 .43248 Mtetra
.53718 .43248 .54293 .43889 .55368 .43543 .54796 .42899 Mtetra
.54796 .42899 .55368 .43543 .56447 .43195 .55878 .42549 Mtetra
.55878 .42549 .56447 .43195 .5753 .42846 .56964 .42197 Mtetra
.56964 .42197 .5753 .42846 .58617 .42495 .58054 .41844 Mtetra
.58054 .41844 .58617 .42495 .59709 .42143 .59149 .4149 Mtetra
.59149 .4149 .59709 .42143 .60805 .4179 .60247 .41134 Mtetra
.60247 .41134 .60805 .4179 .61906 .41435 .61351 .40776 Mtetra
.61351 .40776 .61906 .41435 .6301 .41079 .62458 .40418 Mtetra
.62458 .40418 .6301 .41079 .64119 .40721 .6357 .40057 Mtetra
.6357 .40057 .64119 .40721 .65233 .40362 .64687 .39696 Mtetra
.64687 .39696 .65233 .40362 .66351 .40002 .65808 .39333 Mtetra
.65808 .39333 .66351 .40002 .67473 .3964 .66933 .38968 Mtetra
.66933 .38968 .67473 .3964 .686 .39277 .68063 .38602 Mtetra
.68063 .38602 .686 .39277 .69731 .38912 .69198 .38235 Mtetra
.69198 .38235 .69731 .38912 .70867 .38546 .70336 .37866 Mtetra
.70336 .37866 .70867 .38546 .72007 .38178 .7148 .37496 Mtetra
.7148 .37496 .72007 .38178 .73152 .37809 .72628 .37124 Mtetra
.72628 .37124 .73152 .37809 .74302 .37439 .73781 .3675 Mtetra
.73781 .3675 .74302 .37439 .75456 .37067 .74939 .36376 Mtetra
.74939 .36376 .75456 .37067 .76615 .36693 .76101 .35999 Mtetra
.76101 .35999 .76615 .36693 .77779 .36318 .77268 .35621 Mtetra
.77268 .35621 .77779 .36318 .78947 .35941 .78439 .35242 Mtetra
.78439 .35242 .78947 .35941 .8012 .35563 .79616 .34861 Mtetra
.79616 .34861 .8012 .35563 .81298 .35183 .80797 .34478 Mtetra
.80797 .34478 .81298 .35183 .82481 .34802 .81983 .34094 Mtetra
.81983 .34094 .82481 .34802 .83668 .34419 .83174 .33708 Mtetra
.83174 .33708 .83668 .34419 .84861 .34035 .8437 .33321 Mtetra
.20671 .53168 .21326 .53739 .2228 .5343 .21628 .52857 Mtetra
.21628 .52857 .2228 .5343 .23238 .5312 .22588 .52544 Mtetra
.22588 .52544 .23238 .5312 .242 .52809 .23551 .52231 Mtetra
.23551 .52231 .242 .52809 .25165 .52496 .24519 .51916 Mtetra
.24519 .51916 .25165 .52496 .26134 .52182 .25489 .516 Mtetra
.25489 .516 .26134 .52182 .27106 .51867 .26464 .51283 Mtetra
.26464 .51283 .27106 .51867 .28082 .51551 .27442 .50965 Mtetra
.27442 .50965 .28082 .51551 .29062 .51234 .28424 .50645 Mtetra
.28424 .50645 .29062 .51234 .30045 .50916 .29409 .50324 Mtetra
.29409 .50324 .30045 .50916 .31032 .50596 .30398 .50003 Mtetra
.30398 .50003 .31032 .50596 .32022 .50275 .31391 .4968 Mtetra
.31391 .4968 .32022 .50275 .33017 .49953 .32388 .49355 Mtetra
.32388 .49355 .33017 .49953 .34015 .4963 .33388 .4903 Mtetra
.33388 .4903 .34015 .4963 .35017 .49305 .34392 .48703 Mtetra
.34392 .48703 .35017 .49305 .36022 .4898 .354 .48375 Mtetra
.354 .48375 .36022 .4898 .37032 .48653 .36412 .48046 Mtetra
.36412 .48046 .37032 .48653 .38045 .48325 .37428 .47715 Mtetra
.37428 .47715 .38045 .48325 .39062 .47995 .38447 .47384 Mtetra
.38447 .47384 .39062 .47995 .40083 .47664 .3947 .47051 Mtetra
.3947 .47051 .40083 .47664 .41108 .47333 .40498 .46716 Mtetra
.40498 .46716 .41108 .47333 .42137 .46999 .41529 .46381 Mtetra
.41529 .46381 .42137 .46999 .43169 .46665 .42564 .46044 Mtetra
.42564 .46044 .43169 .46665 .44206 .46329 .43603 .45706 Mtetra
.43603 .45706 .44206 .46329 .45247 .45992 .44647 .45366 Mtetra
.44647 .45366 .45247 .45992 .46291 .45654 .45694 .45026 Mtetra
.45694 .45026 .46291 .45654 .4734 .45314 .46745 .44684 Mtetra
.46745 .44684 .4734 .45314 .48393 .44973 .47801 .4434 Mtetra
.47801 .4434 .48393 .44973 .4945 .44631 .4886 .43995 Mtetra
.4886 .43995 .4945 .44631 .50511 .44287 .49924 .43649 Mtetra
.49924 .43649 .50511 .44287 .51576 .43942 .50991 .43302 Mtetra
.50991 .43302 .51576 .43942 .52645 .43596 .52063 .42953 Mtetra
.52063 .42953 .52645 .43596 .53718 .43248 .53139 .42603 Mtetra
.53139 .42603 .53718 .43248 .54796 .42899 .5422 .42251 Mtetra
.5422 .42251 .54796 .42899 .55878 .42549 .55304 .41899 Mtetra
.55304 .41899 .55878 .42549 .56964 .42197 .56393 .41544 Mtetra
.56393 .41544 .56964 .42197 .58054 .41844 .57486 .41189 Mtetra
.57486 .41189 .58054 .41844 .59149 .4149 .58584 .40831 Mtetra
.58584 .40831 .59149 .4149 .60247 .41134 .59686 .40473 Mtetra
.59686 .40473 .60247 .41134 .61351 .40776 .60792 .40113 Mtetra
.60792 .40113 .61351 .40776 .62458 .40418 .61902 .39752 Mtetra
.61902 .39752 .62458 .40418 .6357 .40057 .63017 .39389 Mtetra
.63017 .39389 .6357 .40057 .64687 .39696 .64137 .39025 Mtetra
.64137 .39025 .64687 .39696 .65808 .39333 .65261 .38659 Mtetra
.65261 .38659 .65808 .39333 .66933 .38968 .66389 .38292 Mtetra
.66389 .38292 .66933 .38968 .68063 .38602 .67522 .37923 Mtetra
.67522 .37923 .68063 .38602 .69198 .38235 .6866 .37553 Mtetra
.6866 .37553 .69198 .38235 .70336 .37866 .69802 .37181 Mtetra
.69802 .37181 .70336 .37866 .7148 .37496 .70949 .36808 Mtetra
.70949 .36808 .7148 .37496 .72628 .37124 .721 .36433 Mtetra
.721 .36433 .72628 .37124 .73781 .3675 .73256 .36057 Mtetra
.73256 .36057 .73781 .3675 .74939 .36376 .74417 .35679 Mtetra
.74417 .35679 .74939 .36376 .76101 .35999 .75583 .353 Mtetra
.75583 .353 .76101 .35999 .77268 .35621 .76753 .34919 Mtetra
.76753 .34919 .77268 .35621 .78439 .35242 .77928 .34537 Mtetra
.77928 .34537 .78439 .35242 .79616 .34861 .79108 .34153 Mtetra
.79108 .34153 .79616 .34861 .80797 .34478 .80293 .33768 Mtetra
.80293 .33768 .80797 .34478 .81983 .34094 .81482 .33381 Mtetra
.81482 .33381 .81983 .34094 .83174 .33708 .82677 .32992 Mtetra
.82677 .32992 .83174 .33708 .8437 .33321 .83876 .32602 Mtetra
.20012 .52592 .20671 .53168 .21628 .52857 .2097 .52279 Mtetra
.2097 .52279 .21628 .52857 .22588 .52544 .21932 .51964 Mtetra
.21932 .51964 .22588 .52544 .23551 .52231 .22898 .51649 Mtetra
.22898 .51649 .23551 .52231 .24519 .51916 .23867 .51332 Mtetra
.23867 .51332 .24519 .51916 .25489 .516 .2484 .51014 Mtetra
.2484 .51014 .25489 .516 .26464 .51283 .25817 .50694 Mtetra
.25817 .50694 .26464 .51283 .27442 .50965 .26797 .50374 Mtetra
.26797 .50374 .27442 .50965 .28424 .50645 .27781 .50052 Mtetra
.27781 .50052 .28424 .50645 .29409 .50324 .28769 .49729 Mtetra
.28769 .49729 .29409 .50324 .30398 .50003 .2976 .49405 Mtetra
.2976 .49405 .30398 .50003 .31391 .4968 .30755 .4908 Mtetra
.30755 .4908 .31391 .4968 .32388 .49355 .31754 .48753 Mtetra
.31754 .48753 .32388 .49355 .33388 .4903 .32757 .48426 Mtetra
.32757 .48426 .33388 .4903 .34392 .48703 .33763 .48097 Mtetra
.33763 .48097 .34392 .48703 .354 .48375 .34774 .47766 Mtetra
.34774 .47766 .354 .48375 .36412 .48046 .35788 .47435 Mtetra
.35788 .47435 .36412 .48046 .37428 .47715 .36806 .47102 Mtetra
.36806 .47102 .37428 .47715 .38447 .47384 .37828 .46768 Mtetra
.37828 .46768 .38447 .47384 .3947 .47051 .38854 .46433 Mtetra
.38854 .46433 .3947 .47051 .40498 .46716 .39883 .46096 Mtetra
.39883 .46096 .40498 .46716 .41529 .46381 .40917 .45758 Mtetra
.40917 .45758 .41529 .46381 .42564 .46044 .41955 .45419 Mtetra
.41955 .45419 .42564 .46044 .43603 .45706 .42996 .45078 Mtetra
.42996 .45078 .43603 .45706 .44647 .45366 .44042 .44736 Mtetra
.44042 .44736 .44647 .45366 .45694 .45026 .45092 .44393 Mtetra
.45092 .44393 .45694 .45026 .46745 .44684 .46146 .44049 Mtetra
.46146 .44049 .46745 .44684 .47801 .4434 .47204 .43703 Mtetra
.47204 .43703 .47801 .4434 .4886 .43995 .48266 .43355 Mtetra
.48266 .43355 .4886 .43995 .49924 .43649 .49332 .43007 Mtetra
.49332 .43007 .49924 .43649 .50991 .43302 .50403 .42657 Mtetra
.50403 .42657 .50991 .43302 .52063 .42953 .51477 .42306 Mtetra
.51477 .42306 .52063 .42953 .53139 .42603 .52556 .41953 Mtetra
.52556 .41953 .53139 .42603 .5422 .42251 .53639 .41599 Mtetra
.53639 .41599 .5422 .42251 .55304 .41899 .54727 .41243 Mtetra
.54727 .41243 .55304 .41899 .56393 .41544 .55818 .40886 Mtetra
.55818 .40886 .56393 .41544 .57486 .41189 .56914 .40528 Mtetra
.56914 .40528 .57486 .41189 .58584 .40831 .58015 .40168 Mtetra
.58015 .40168 .58584 .40831 .59686 .40473 .5912 .39807 Mtetra
.5912 .39807 .59686 .40473 .60792 .40113 .60229 .39445 Mtetra
.60229 .39445 .60792 .40113 .61902 .39752 .61342 .39081 Mtetra
.61342 .39081 .61902 .39752 .63017 .39389 .6246 .38715 Mtetra
.6246 .38715 .63017 .39389 .64137 .39025 .63583 .38348 Mtetra
.63583 .38348 .64137 .39025 .65261 .38659 .6471 .3798 Mtetra
.6471 .3798 .65261 .38659 .66389 .38292 .65841 .3761 Mtetra
.65841 .3761 .66389 .38292 .67522 .37923 .66977 .37238 Mtetra
.66977 .37238 .67522 .37923 .6866 .37553 .68118 .36866 Mtetra
.68118 .36866 .6866 .37553 .69802 .37181 .69263 .36491 Mtetra
.69263 .36491 .69802 .37181 .70949 .36808 .70413 .36115 Mtetra
.70413 .36115 .70949 .36808 .721 .36433 .71568 .35738 Mtetra
.71568 .35738 .721 .36433 .73256 .36057 .72727 .35359 Mtetra
.72727 .35359 .73256 .36057 .74417 .35679 .73892 .34978 Mtetra
.73892 .34978 .74417 .35679 .75583 .353 .7506 .34596 Mtetra
.7506 .34596 .75583 .353 .76753 .34919 .76234 .34212 Mtetra
.76234 .34212 .76753 .34919 .77928 .34537 .77412 .33827 Mtetra
.77412 .33827 .77928 .34537 .79108 .34153 .78596 .3344 Mtetra
.78596 .3344 .79108 .34153 .80293 .33768 .79784 .33052 Mtetra
.79784 .33052 .80293 .33768 .81482 .33381 .80977 .32662 Mtetra
.80977 .32662 .81482 .33381 .82677 .32992 .82175 .3227 Mtetra
.82175 .3227 .82677 .32992 .83876 .32602 .83378 .31877 Mtetra
.19348 .52013 .20012 .52592 .2097 .52279 .20308 .51697 Mtetra
.20308 .51697 .2097 .52279 .21932 .51964 .21272 .51381 Mtetra
.21272 .51381 .21932 .51964 .22898 .51649 .2224 .51063 Mtetra
.2224 .51063 .22898 .51649 .23867 .51332 .23212 .50744 Mtetra
.23212 .50744 .23867 .51332 .2484 .51014 .24187 .50423 Mtetra
.24187 .50423 .2484 .51014 .25817 .50694 .25166 .50102 Mtetra
.25166 .50102 .25817 .50694 .26797 .50374 .26148 .49779 Mtetra
.26148 .49779 .26797 .50374 .27781 .50052 .27134 .49455 Mtetra
.27134 .49455 .27781 .50052 .28769 .49729 .28124 .4913 Mtetra
.28124 .4913 .28769 .49729 .2976 .49405 .29118 .48804 Mtetra
.29118 .48804 .2976 .49405 .30755 .4908 .30115 .48476 Mtetra
.30115 .48476 .30755 .4908 .31754 .48753 .31116 .48147 Mtetra
.31116 .48147 .31754 .48753 .32757 .48426 .32121 .47817 Mtetra
.32121 .47817 .32757 .48426 .33763 .48097 .3313 .47486 Mtetra
.3313 .47486 .33763 .48097 .34774 .47766 .34143 .47153 Mtetra
.34143 .47153 .34774 .47766 .35788 .47435 .35159 .46819 Mtetra
.35159 .46819 .35788 .47435 .36806 .47102 .3618 .46484 Mtetra
.3618 .46484 .36806 .47102 .37828 .46768 .37204 .46148 Mtetra
.37204 .46148 .37828 .46768 .38854 .46433 .38232 .4581 Mtetra
.38232 .4581 .38854 .46433 .39883 .46096 .39264 .45471 Mtetra
.39264 .45471 .39883 .46096 .40917 .45758 .40301 .45131 Mtetra
.40301 .45131 .40917 .45758 .41955 .45419 .41341 .44789 Mtetra
.41341 .44789 .41955 .45419 .42996 .45078 .42385 .44446 Mtetra
.42385 .44446 .42996 .45078 .44042 .44736 .43434 .44102 Mtetra
.43434 .44102 .44042 .44736 .45092 .44393 .44486 .43756 Mtetra
.44486 .43756 .45092 .44393 .46146 .44049 .45542 .43409 Mtetra
.45542 .43409 .46146 .44049 .47204 .43703 .46603 .43061 Mtetra
.46603 .43061 .47204 .43703 .48266 .43355 .47668 .42711 Mtetra
.47668 .42711 .48266 .43355 .49332 .43007 .48737 .4236 Mtetra
.48737 .4236 .49332 .43007 .50403 .42657 .4981 .42007 Mtetra
.4981 .42007 .50403 .42657 .51477 .42306 .50887 .41653 Mtetra
.50887 .41653 .51477 .42306 .52556 .41953 .51969 .41298 Mtetra
.51969 .41298 .52556 .41953 .53639 .41599 .53055 .40941 Mtetra
.53055 .40941 .53639 .41599 .54727 .41243 .54145 .40583 Mtetra
.54145 .40583 .54727 .41243 .55818 .40886 .5524 .40224 Mtetra
.5524 .40224 .55818 .40886 .56914 .40528 .56338 .39863 Mtetra
.56338 .39863 .56914 .40528 .58015 .40168 .57442 .39501 Mtetra
.57442 .39501 .58015 .40168 .5912 .39807 .58549 .39137 Mtetra
.58549 .39137 .5912 .39807 .60229 .39445 .59661 .38772 Mtetra
.59661 .38772 .60229 .39445 .61342 .39081 .60778 .38405 Mtetra
.60778 .38405 .61342 .39081 .6246 .38715 .61899 .38037 Mtetra
.61899 .38037 .6246 .38715 .63583 .38348 .63025 .37667 Mtetra
.63025 .37667 .63583 .38348 .6471 .3798 .64155 .37296 Mtetra
.64155 .37296 .6471 .3798 .65841 .3761 .65289 .36923 Mtetra
.65289 .36923 .65841 .3761 .66977 .37238 .66429 .36549 Mtetra
.66429 .36549 .66977 .37238 .68118 .36866 .67572 .36173 Mtetra
.67572 .36173 .68118 .36866 .69263 .36491 .68721 .35796 Mtetra
.68721 .35796 .69263 .36491 .70413 .36115 .69874 .35417 Mtetra
.69874 .35417 .70413 .36115 .71568 .35738 .71032 .35037 Mtetra
.71032 .35037 .71568 .35738 .72727 .35359 .72195 .34655 Mtetra
.72195 .34655 .72727 .35359 .73892 .34978 .73362 .34271 Mtetra
.73362 .34271 .73892 .34978 .7506 .34596 .74534 .33886 Mtetra
.74534 .33886 .7506 .34596 .76234 .34212 .75711 .335 Mtetra
.75711 .335 .76234 .34212 .77412 .33827 .76893 .33112 Mtetra
.76893 .33112 .77412 .33827 .78596 .3344 .7808 .32722 Mtetra
.7808 .32722 .78596 .3344 .79784 .33052 .79272 .3233 Mtetra
.79272 .3233 .79784 .33052 .80977 .32662 .80468 .31937 Mtetra
.80468 .31937 .80977 .32662 .82175 .3227 .8167 .31543 Mtetra
.8167 .31543 .82175 .3227 .83378 .31877 .82876 .31146 Mtetra
.18679 .51429 .19348 .52013 .20308 .51697 .19642 .51112 Mtetra
.19642 .51112 .20308 .51697 .21272 .51381 .20608 .50793 Mtetra
.20608 .50793 .21272 .51381 .2224 .51063 .21578 .50473 Mtetra
.21578 .50473 .2224 .51063 .23212 .50744 .22552 .50151 Mtetra
.22552 .50151 .23212 .50744 .24187 .50423 .23529 .49829 Mtetra
.23529 .49829 .24187 .50423 .25166 .50102 .2451 .49505 Mtetra
.2451 .49505 .25166 .50102 .26148 .49779 .25494 .4918 Mtetra
.25494 .4918 .26148 .49779 .27134 .49455 .26483 .48854 Mtetra
.26483 .48854 .27134 .49455 .28124 .4913 .27475 .48527 Mtetra
.27475 .48527 .28124 .4913 .29118 .48804 .28471 .48198 Mtetra
.28471 .48198 .29118 .48804 .30115 .48476 .2947 .47868 Mtetra
.2947 .47868 .30115 .48476 .31116 .48147 .30474 .47537 Mtetra
.30474 .47537 .31116 .48147 .32121 .47817 .31481 .47205 Mtetra
.31481 .47205 .32121 .47817 .3313 .47486 .32492 .46871 Mtetra
.32492 .46871 .3313 .47486 .34143 .47153 .33507 .46536 Mtetra
.33507 .46536 .34143 .47153 .35159 .46819 .34526 .462 Mtetra
.34526 .462 .35159 .46819 .3618 .46484 .35549 .45862 Mtetra
.35549 .45862 .3618 .46484 .37204 .46148 .36576 .45523 Mtetra
.36576 .45523 .37204 .46148 .38232 .4581 .37607 .45183 Mtetra
.37607 .45183 .38232 .4581 .39264 .45471 .38641 .44842 Mtetra
.38641 .44842 .39264 .45471 .40301 .45131 .3968 .44499 Mtetra
.3968 .44499 .40301 .45131 .41341 .44789 .40723 .44155 Mtetra
.40723 .44155 .41341 .44789 .42385 .44446 .41769 .43809 Mtetra
.41769 .43809 .42385 .44446 .43434 .44102 .4282 .43462 Mtetra
.4282 .43462 .43434 .44102 .44486 .43756 .43875 .43114 Mtetra
.43875 .43114 .44486 .43756 .45542 .43409 .44934 .42765 Mtetra
.44934 .42765 .45542 .43409 .46603 .43061 .45998 .42414 Mtetra
.45998 .42414 .46603 .43061 .47668 .42711 .47065 .42062 Mtetra
.47065 .42062 .47668 .42711 .48737 .4236 .48137 .41708 Mtetra
.48137 .41708 .48737 .4236 .4981 .42007 .49213 .41353 Mtetra
.49213 .41353 .4981 .42007 .50887 .41653 .50293 .40996 Mtetra
.50293 .40996 .50887 .41653 .51969 .41298 .51377 .40639 Mtetra
.51377 .40639 .51969 .41298 .53055 .40941 .52466 .40279 Mtetra
.52466 .40279 .53055 .40941 .54145 .40583 .53559 .39919 Mtetra
.53559 .39919 .54145 .40583 .5524 .40224 .54656 .39556 Mtetra
.54656 .39556 .5524 .40224 .56338 .39863 .55758 .39193 Mtetra
.55758 .39193 .56338 .39863 .57442 .39501 .56864 .38828 Mtetra
.56864 .38828 .57442 .39501 .58549 .39137 .57975 .38461 Mtetra
.57975 .38461 .58549 .39137 .59661 .38772 .5909 .38093 Mtetra
.5909 .38093 .59661 .38772 .60778 .38405 .6021 .37724 Mtetra
.6021 .37724 .60778 .38405 .61899 .38037 .61334 .37353 Mtetra
.61334 .37353 .61899 .38037 .63025 .37667 .62462 .3698 Mtetra
.62462 .3698 .63025 .37667 .64155 .37296 .63595 .36606 Mtetra
.63595 .36606 .64155 .37296 .65289 .36923 .64733 .36231 Mtetra
.64733 .36231 .65289 .36923 .66429 .36549 .65875 .35854 Mtetra
.65875 .35854 .66429 .36549 .67572 .36173 .67023 .35475 Mtetra
.67023 .35475 .67572 .36173 .68721 .35796 .68174 .35095 Mtetra
.68174 .35095 .68721 .35796 .69874 .35417 .69331 .34714 Mtetra
.69331 .34714 .69874 .35417 .71032 .35037 .70492 .34331 Mtetra
.70492 .34331 .71032 .35037 .72195 .34655 .71658 .33946 Mtetra
.71658 .33946 .72195 .34655 .73362 .34271 .72829 .33559 Mtetra
.72829 .33559 .73362 .34271 .74534 .33886 .74004 .33171 Mtetra
.74004 .33171 .74534 .33886 .75711 .335 .75184 .32782 Mtetra
.75184 .32782 .75711 .335 .76893 .33112 .7637 .32391 Mtetra
.7637 .32391 .76893 .33112 .7808 .32722 .7756 .31998 Mtetra
.7756 .31998 .7808 .32722 .79272 .3233 .78755 .31604 Mtetra
.78755 .31604 .79272 .3233 .80468 .31937 .79955 .31208 Mtetra
.79955 .31208 .80468 .31937 .8167 .31543 .8116 .3081 Mtetra
.8116 .3081 .8167 .31543 .82876 .31146 .82371 .3041 Mtetra
.18006 .50842 .18679 .51429 .19642 .51112 .18971 .50522 Mtetra
.18971 .50522 .19642 .51112 .20608 .50793 .19939 .50201 Mtetra
.19939 .50201 .20608 .50793 .21578 .50473 .20911 .49879 Mtetra
.20911 .49879 .21578 .50473 .22552 .50151 .21887 .49555 Mtetra
.21887 .49555 .22552 .50151 .23529 .49829 .22866 .4923 Mtetra
.22866 .4923 .23529 .49829 .2451 .49505 .23849 .48904 Mtetra
.23849 .48904 .2451 .49505 .25494 .4918 .24836 .48577 Mtetra
.24836 .48577 .25494 .4918 .26483 .48854 .25827 .48249 Mtetra
.25827 .48249 .26483 .48854 .27475 .48527 .26821 .47919 Mtetra
.26821 .47919 .27475 .48527 .28471 .48198 .27819 .47588 Mtetra
.27819 .47588 .28471 .48198 .2947 .47868 .28821 .47256 Mtetra
.28821 .47256 .2947 .47868 .30474 .47537 .29827 .46922 Mtetra
.29827 .46922 .30474 .47537 .31481 .47205 .30837 .46587 Mtetra
.30837 .46587 .31481 .47205 .32492 .46871 .3185 .46251 Mtetra
.3185 .46251 .32492 .46871 .33507 .46536 .32867 .45914 Mtetra
.32867 .45914 .33507 .46536 .34526 .462 .33889 .45575 Mtetra
.33889 .45575 .34526 .462 .35549 .45862 .34914 .45235 Mtetra
.34914 .45235 .35549 .45862 .36576 .45523 .35943 .44894 Mtetra
.35943 .44894 .36576 .45523 .37607 .45183 .36976 .44552 Mtetra
.36976 .44552 .37607 .45183 .38641 .44842 .38013 .44208 Mtetra
.38013 .44208 .38641 .44842 .3968 .44499 .39055 .43862 Mtetra
.39055 .43862 .3968 .44499 .40723 .44155 .401 .43516 Mtetra
.401 .43516 .40723 .44155 .41769 .43809 .41149 .43168 Mtetra
.41149 .43168 .41769 .43809 .4282 .43462 .42203 .42819 Mtetra
.42203 .42819 .4282 .43462 .43875 .43114 .4326 .42468 Mtetra
.4326 .42468 .43875 .43114 .44934 .42765 .44322 .42116 Mtetra
.44322 .42116 .44934 .42765 .45998 .42414 .45388 .41762 Mtetra
.45388 .41762 .45998 .42414 .47065 .42062 .46458 .41408 Mtetra
.46458 .41408 .47065 .42062 .48137 .41708 .47533 .41051 Mtetra
.47533 .41051 .48137 .41708 .49213 .41353 .48611 .40694 Mtetra
.48611 .40694 .49213 .41353 .50293 .40996 .49694 .40335 Mtetra
.49694 .40335 .50293 .40996 .51377 .40639 .50781 .39974 Mtetra
.50781 .39974 .51377 .40639 .52466 .40279 .51873 .39612 Mtetra
.51873 .39612 .52466 .40279 .53559 .39919 .52969 .39249 Mtetra
.52969 .39249 .53559 .39919 .54656 .39556 .54069 .38884 Mtetra
.54069 .38884 .54656 .39556 .55758 .39193 .55174 .38518 Mtetra
.55174 .38518 .55758 .39193 .56864 .38828 .56283 .3815 Mtetra
.56283 .3815 .56864 .38828 .57975 .38461 .57396 .37781 Mtetra
.57396 .37781 .57975 .38461 .5909 .38093 .58514 .3741 Mtetra
.58514 .3741 .5909 .38093 .6021 .37724 .59637 .37038 Mtetra
.59637 .37038 .6021 .37724 .61334 .37353 .60764 .36664 Mtetra
.60764 .36664 .61334 .37353 .62462 .3698 .61896 .36289 Mtetra
.61896 .36289 .62462 .3698 .63595 .36606 .63032 .35912 Mtetra
.63032 .35912 .63595 .36606 .64733 .36231 .64173 .35534 Mtetra
.64173 .35534 .64733 .36231 .65875 .35854 .65318 .35154 Mtetra
.65318 .35154 .65875 .35854 .67023 .35475 .66469 .34773 Mtetra
.66469 .34773 .67023 .35475 .68174 .35095 .67623 .3439 Mtetra
.67623 .3439 .68174 .35095 .69331 .34714 .68783 .34005 Mtetra
.68783 .34005 .69331 .34714 .70492 .34331 .69948 .33619 Mtetra
.69948 .33619 .70492 .34331 .71658 .33946 .71117 .33231 Mtetra
.71117 .33231 .71658 .33946 .72829 .33559 .72291 .32842 Mtetra
.72291 .32842 .72829 .33559 .74004 .33171 .7347 .32451 Mtetra
.7347 .32451 .74004 .33171 .75184 .32782 .74654 .32059 Mtetra
.74654 .32059 .75184 .32782 .7637 .32391 .75842 .31664 Mtetra
.75842 .31664 .7637 .32391 .7756 .31998 .77036 .31269 Mtetra
.77036 .31269 .7756 .31998 .78755 .31604 .78235 .30871 Mtetra
.78235 .30871 .78755 .31604 .79955 .31208 .79438 .30472 Mtetra
.79438 .30472 .79955 .31208 .8116 .3081 .80647 .30071 Mtetra
.80647 .30071 .8116 .3081 .82371 .3041 .81861 .29669 Mtetra
.17328 .5025 .18006 .50842 .18971 .50522 .18295 .49928 Mtetra
.18295 .49928 .18971 .50522 .19939 .50201 .19266 .49605 Mtetra
.19266 .49605 .19939 .50201 .20911 .49879 .2024 .4928 Mtetra
.2024 .4928 .20911 .49879 .21887 .49555 .21218 .48955 Mtetra
.21218 .48955 .21887 .49555 .22866 .4923 .22199 .48627 Mtetra
.22199 .48627 .22866 .4923 .23849 .48904 .23184 .48299 Mtetra
.23184 .48299 .23849 .48904 .24836 .48577 .24173 .4797 Mtetra
.24173 .4797 .24836 .48577 .25827 .48249 .25166 .47639 Mtetra
.25166 .47639 .25827 .48249 .26821 .47919 .26163 .47307 Mtetra
.26163 .47307 .26821 .47919 .27819 .47588 .27163 .46974 Mtetra
.27163 .46974 .27819 .47588 .28821 .47256 .28167 .46639 Mtetra
.28167 .46639 .28821 .47256 .29827 .46922 .29175 .46303 Mtetra
.29175 .46303 .29827 .46922 .30837 .46587 .30187 .45966 Mtetra
.30187 .45966 .30837 .46587 .3185 .46251 .31203 .45628 Mtetra
.31203 .45628 .3185 .46251 .32867 .45914 .32223 .45288 Mtetra
.32223 .45288 .32867 .45914 .33889 .45575 .33247 .44947 Mtetra
.33247 .44947 .33889 .45575 .34914 .45235 .34274 .44604 Mtetra
.34274 .44604 .34914 .45235 .35943 .44894 .35306 .44261 Mtetra
.35306 .44261 .35943 .44894 .36976 .44552 .36342 .43916 Mtetra
.36342 .43916 .36976 .44552 .38013 .44208 .37381 .43569 Mtetra
.37381 .43569 .38013 .44208 .39055 .43862 .38425 .43222 Mtetra
.38425 .43222 .39055 .43862 .401 .43516 .39473 .42872 Mtetra
.39473 .42872 .401 .43516 .41149 .43168 .40525 .42522 Mtetra
.40525 .42522 .41149 .43168 .42203 .42819 .41581 .4217 Mtetra
.41581 .4217 .42203 .42819 .4326 .42468 .42641 .41817 Mtetra
.42641 .41817 .4326 .42468 .44322 .42116 .43705 .41462 Mtetra
.43705 .41462 .44322 .42116 .45388 .41762 .44774 .41106 Mtetra
.44774 .41106 .45388 .41762 .46458 .41408 .45847 .40749 Mtetra
.45847 .40749 .46458 .41408 .47533 .41051 .46924 .4039 Mtetra
.46924 .4039 .47533 .41051 .48611 .40694 .48005 .4003 Mtetra
.48005 .4003 .48611 .40694 .49694 .40335 .49091 .39668 Mtetra
.49091 .39668 .49694 .40335 .50781 .39974 .50181 .39305 Mtetra
.50181 .39305 .50781 .39974 .51873 .39612 .51275 .3894 Mtetra
.51275 .3894 .51873 .39612 .52969 .39249 .52374 .38574 Mtetra
.52374 .38574 .52969 .39249 .54069 .38884 .53477 .38207 Mtetra
.53477 .38207 .54069 .38884 .55174 .38518 .54585 .37838 Mtetra
.54585 .37838 .55174 .38518 .56283 .3815 .55697 .37467 Mtetra
.55697 .37467 .56283 .3815 .57396 .37781 .56813 .37095 Mtetra
.56813 .37095 .57396 .37781 .58514 .3741 .57934 .36722 Mtetra
.57934 .36722 .58514 .3741 .59637 .37038 .5906 .36347 Mtetra
.5906 .36347 .59637 .37038 .60764 .36664 .6019 .3597 Mtetra
.6019 .3597 .60764 .36664 .61896 .36289 .61325 .35592 Mtetra
.61325 .35592 .61896 .36289 .63032 .35912 .62464 .35213 Mtetra
.62464 .35213 .63032 .35912 .64173 .35534 .63608 .34831 Mtetra
.63608 .34831 .64173 .35534 .65318 .35154 .64757 .34449 Mtetra
.64757 .34449 .65318 .35154 .66469 .34773 .6591 .34064 Mtetra
.6591 .34064 .66469 .34773 .67623 .3439 .67069 .33678 Mtetra
.67069 .33678 .67623 .3439 .68783 .34005 .68231 .33291 Mtetra
.68231 .33291 .68783 .34005 .69948 .33619 .69399 .32902 Mtetra
.69399 .32902 .69948 .33619 .71117 .33231 .70572 .32511 Mtetra
.70572 .32511 .71117 .33231 .72291 .32842 .71749 .32119 Mtetra
.71749 .32119 .72291 .32842 .7347 .32451 .72932 .31725 Mtetra
.72932 .31725 .7347 .32451 .74654 .32059 .74119 .3133 Mtetra
.74119 .3133 .74654 .32059 .75842 .31664 .75311 .30932 Mtetra
.75311 .30932 .75842 .31664 .77036 .31269 .76508 .30533 Mtetra
.76508 .30533 .77036 .31269 .78235 .30871 .7771 .30133 Mtetra
.7771 .30133 .78235 .30871 .79438 .30472 .78918 .29731 Mtetra
.78918 .29731 .79438 .30472 .80647 .30071 .8013 .29327 Mtetra
.8013 .29327 .80647 .30071 .81861 .29669 .81347 .28921 Mtetra
.16646 .49655 .17328 .5025 .18295 .49928 .17615 .4933 Mtetra
.17615 .4933 .18295 .49928 .19266 .49605 .18587 .49005 Mtetra
.18587 .49005 .19266 .49605 .2024 .4928 .19564 .48678 Mtetra
.19564 .48678 .2024 .4928 .21218 .48955 .20544 .4835 Mtetra
.20544 .4835 .21218 .48955 .22199 .48627 .21527 .4802 Mtetra
.21527 .4802 .22199 .48627 .23184 .48299 .22515 .4769 Mtetra
.22515 .4769 .23184 .48299 .24173 .4797 .23506 .47358 Mtetra
.23506 .47358 .24173 .4797 .25166 .47639 .24501 .47025 Mtetra
.24501 .47025 .25166 .47639 .26163 .47307 .255 .46691 Mtetra
.255 .46691 .26163 .47307 .27163 .46974 .26502 .46355 Mtetra
.26502 .46355 .27163 .46974 .28167 .46639 .27509 .46018 Mtetra
.27509 .46018 .28167 .46639 .29175 .46303 .28519 .4568 Mtetra
.28519 .4568 .29175 .46303 .30187 .45966 .29534 .4534 Mtetra
.29534 .4534 .30187 .45966 .31203 .45628 .30552 .44999 Mtetra
.30552 .44999 .31203 .45628 .32223 .45288 .31574 .44657 Mtetra
.31574 .44657 .32223 .45288 .33247 .44947 .326 .44314 Mtetra
.326 .44314 .33247 .44947 .34274 .44604 .3363 .43969 Mtetra
.3363 .43969 .34274 .44604 .35306 .44261 .34664 .43623 Mtetra
.34664 .43623 .35306 .44261 .36342 .43916 .35702 .43275 Mtetra
.35702 .43275 .36342 .43916 .37381 .43569 .36744 .42926 Mtetra
.36744 .42926 .37381 .43569 .38425 .43222 .37791 .42576 Mtetra
.37791 .42576 .38425 .43222 .39473 .42872 .38841 .42224 Mtetra
.38841 .42224 .39473 .42872 .40525 .42522 .39896 .41871 Mtetra
.39896 .41871 .40525 .42522 .41581 .4217 .40954 .41517 Mtetra
.40954 .41517 .41581 .4217 .42641 .41817 .42017 .41161 Mtetra
.42017 .41161 .42641 .41817 .43705 .41462 .43084 .40804 Mtetra
.43084 .40804 .43705 .41462 .44774 .41106 .44155 .40445 Mtetra
.44155 .40445 .44774 .41106 .45847 .40749 .45231 .40085 Mtetra
.45231 .40085 .45847 .40749 .46924 .4039 .46311 .39724 Mtetra
.46311 .39724 .46924 .4039 .48005 .4003 .47395 .39361 Mtetra
.47395 .39361 .48005 .4003 .49091 .39668 .48483 .38996 Mtetra
.48483 .38996 .49091 .39668 .50181 .39305 .49576 .38631 Mtetra
.49576 .38631 .50181 .39305 .51275 .3894 .50673 .38263 Mtetra
.50673 .38263 .51275 .3894 .52374 .38574 .51775 .37895 Mtetra
.51775 .37895 .52374 .38574 .53477 .38207 .52881 .37524 Mtetra
.52881 .37524 .53477 .38207 .54585 .37838 .53991 .37153 Mtetra
.53991 .37153 .54585 .37838 .55697 .37467 .55106 .36779 Mtetra
.55106 .36779 .55697 .37467 .56813 .37095 .56226 .36404 Mtetra
.56226 .36404 .56813 .37095 .57934 .36722 .5735 .36028 Mtetra
.5735 .36028 .57934 .36722 .5906 .36347 .58479 .3565 Mtetra
.58479 .3565 .5906 .36347 .6019 .3597 .59612 .35271 Mtetra
.59612 .35271 .6019 .3597 .61325 .35592 .6075 .3489 Mtetra
.6075 .3489 .61325 .35592 .62464 .35213 .61892 .34508 Mtetra
.61892 .34508 .62464 .35213 .63608 .34831 .63039 .34124 Mtetra
.63039 .34124 .63608 .34831 .64757 .34449 .64191 .33738 Mtetra
.64191 .33738 .64757 .34449 .6591 .34064 .65348 .33351 Mtetra
.65348 .33351 .6591 .34064 .67069 .33678 .66509 .32962 Mtetra
.66509 .32962 .67069 .33678 .68231 .33291 .67676 .32572 Mtetra
.67676 .32572 .68231 .33291 .69399 .32902 .68847 .32179 Mtetra
.68847 .32179 .69399 .32902 .70572 .32511 .70023 .31786 Mtetra
.70023 .31786 .70572 .32511 .71749 .32119 .71203 .31391 Mtetra
.71203 .31391 .71749 .32119 .72932 .31725 .72389 .30994 Mtetra
.72389 .30994 .72932 .31725 .74119 .3133 .7358 .30595 Mtetra
.7358 .30595 .74119 .3133 .75311 .30932 .74775 .30195 Mtetra
.74775 .30195 .75311 .30932 .76508 .30533 .75976 .29793 Mtetra
.75976 .29793 .76508 .30533 .7771 .30133 .77182 .29389 Mtetra
.77182 .29389 .7771 .30133 .78918 .29731 .78393 .28984 Mtetra
.78393 .28984 .78918 .29731 .8013 .29327 .79609 .28577 Mtetra
.79609 .28577 .8013 .29327 .81347 .28921 .8083 .28168 Mtetra
.15958 .49055 .16646 .49655 .17615 .4933 .16929 .48728 Mtetra
.16929 .48728 .17615 .4933 .18587 .49005 .17904 .484 Mtetra
.17904 .484 .18587 .49005 .19564 .48678 .18883 .48071 Mtetra
.18883 .48071 .19564 .48678 .20544 .4835 .19865 .47741 Mtetra
.19865 .47741 .20544 .4835 .21527 .4802 .20851 .47409 Mtetra
.20851 .47409 .21527 .4802 .22515 .4769 .2184 .47076 Mtetra
.2184 .47076 .22515 .4769 .23506 .47358 .22834 .46742 Mtetra
.22834 .46742 .23506 .47358 .24501 .47025 .23831 .46407 Mtetra
.23831 .46407 .24501 .47025 .255 .46691 .24832 .4607 Mtetra
.24832 .4607 .255 .46691 .26502 .46355 .25837 .45732 Mtetra
.25837 .45732 .26502 .46355 .27509 .46018 .26846 .45393 Mtetra
.26846 .45393 .27509 .46018 .28519 .4568 .27858 .45052 Mtetra
.27858 .45052 .28519 .4568 .29534 .4534 .28875 .4471 Mtetra
.28875 .4471 .29534 .4534 .30552 .44999 .29896 .44367 Mtetra
.29896 .44367 .30552 .44999 .31574 .44657 .3092 .44022 Mtetra
.3092 .44022 .31574 .44657 .326 .44314 .31949 .43676 Mtetra
.31949 .43676 .326 .44314 .3363 .43969 .32981 .43329 Mtetra
.32981 .43329 .3363 .43969 .34664 .43623 .34018 .4298 Mtetra
.34018 .4298 .34664 .43623 .35702 .43275 .35058 .4263 Mtetra
.35058 .4263 .35702 .43275 .36744 .42926 .36103 .42279 Mtetra
.36103 .42279 .36744 .42926 .37791 .42576 .37152 .41926 Mtetra
.37152 .41926 .37791 .42576 .38841 .42224 .38205 .41572 Mtetra
.38205 .41572 .38841 .42224 .39896 .41871 .39262 .41216 Mtetra
.39262 .41216 .39896 .41871 .40954 .41517 .40323 .40859 Mtetra
.40323 .40859 .40954 .41517 .42017 .41161 .41389 .40501 Mtetra
.41389 .40501 .42017 .41161 .43084 .40804 .42458 .40141 Mtetra
.42458 .40141 .43084 .40804 .44155 .40445 .43532 .39779 Mtetra
.43532 .39779 .44155 .40445 .45231 .40085 .44611 .39417 Mtetra
.44611 .39417 .45231 .40085 .46311 .39724 .45693 .39053 Mtetra
.45693 .39053 .46311 .39724 .47395 .39361 .4678 .38687 Mtetra
.4678 .38687 .47395 .39361 .48483 .38996 .47871 .3832 Mtetra
.47871 .3832 .48483 .38996 .49576 .38631 .48967 .37951 Mtetra
.48967 .37951 .49576 .38631 .50673 .38263 .50067 .37581 Mtetra
.50067 .37581 .50673 .38263 .51775 .37895 .51171 .3721 Mtetra
.51171 .3721 .51775 .37895 .52881 .37524 .5228 .36837 Mtetra
.5228 .36837 .52881 .37524 .53991 .37153 .53394 .36462 Mtetra
.53394 .36462 .53991 .37153 .55106 .36779 .54512 .36086 Mtetra
.54512 .36086 .55106 .36779 .56226 .36404 .55634 .35709 Mtetra
.55634 .35709 .56226 .36404 .5735 .36028 .56761 .35329 Mtetra
.56761 .35329 .5735 .36028 .58479 .3565 .57893 .34949 Mtetra
.57893 .34949 .58479 .3565 .59612 .35271 .59029 .34567 Mtetra
.59029 .34567 .59612 .35271 .6075 .3489 .6017 .34183 Mtetra
.6017 .34183 .6075 .3489 .61892 .34508 .61316 .33797 Mtetra
.61316 .33797 .61892 .34508 .63039 .34124 .62466 .3341 Mtetra
.62466 .3341 .63039 .34124 .64191 .33738 .63621 .33022 Mtetra
.63621 .33022 .64191 .33738 .65348 .33351 .64781 .32632 Mtetra
.64781 .32632 .65348 .33351 .66509 .32962 .65946 .3224 Mtetra
.65946 .3224 .66509 .32962 .67676 .32572 .67115 .31846 Mtetra
.67115 .31846 .67676 .32572 .68847 .32179 .6829 .31451 Mtetra
.6829 .31451 .68847 .32179 .70023 .31786 .69469 .31055 Mtetra
.69469 .31055 .70023 .31786 .71203 .31391 .70653 .30656 Mtetra
.70653 .30656 .71203 .31391 .72389 .30994 .71842 .30256 Mtetra
.71842 .30256 .72389 .30994 .7358 .30595 .73037 .29855 Mtetra
.73037 .29855 .7358 .30595 .74775 .30195 .74236 .29451 Mtetra
.74236 .29451 .74775 .30195 .75976 .29793 .7544 .29046 Mtetra
.7544 .29046 .75976 .29793 .77182 .29389 .76649 .28639 Mtetra
.76649 .28639 .77182 .29389 .78393 .28984 .77864 .28231 Mtetra
.77864 .28231 .78393 .28984 .79609 .28577 .79083 .27821 Mtetra
.79083 .27821 .79609 .28577 .8083 .28168 .80308 .27409 Mtetra
.15266 .48451 .15958 .49055 .16929 .48728 .16239 .48122 Mtetra
.16239 .48122 .16929 .48728 .17904 .484 .17216 .47792 Mtetra
.17216 .47792 .17904 .484 .18883 .48071 .18197 .4746 Mtetra
.18197 .4746 .18883 .48071 .19865 .47741 .19181 .47128 Mtetra
.19181 .47128 .19865 .47741 .20851 .47409 .20169 .46794 Mtetra
.20169 .46794 .20851 .47409 .2184 .47076 .21161 .46458 Mtetra
.21161 .46458 .2184 .47076 .22834 .46742 .22157 .46122 Mtetra
.22157 .46122 .22834 .46742 .23831 .46407 .23156 .45784 Mtetra
.23156 .45784 .23831 .46407 .24832 .4607 .2416 .45445 Mtetra
.2416 .45445 .24832 .4607 .25837 .45732 .25167 .45104 Mtetra
.25167 .45104 .25837 .45732 .26846 .45393 .26178 .44763 Mtetra
.26178 .44763 .26846 .45393 .27858 .45052 .27193 .4442 Mtetra
.27193 .4442 .27858 .45052 .28875 .4471 .28212 .44075 Mtetra
.28212 .44075 .28875 .4471 .29896 .44367 .29235 .43729 Mtetra
.29235 .43729 .29896 .44367 .3092 .44022 .30262 .43382 Mtetra
.30262 .43382 .3092 .44022 .31949 .43676 .31293 .43034 Mtetra
.31293 .43034 .31949 .43676 .32981 .43329 .32328 .42684 Mtetra
.32328 .42684 .32981 .43329 .34018 .4298 .33367 .42333 Mtetra
.33367 .42333 .34018 .4298 .35058 .4263 .3441 .4198 Mtetra
.3441 .4198 .35058 .4263 .36103 .42279 .35457 .41626 Mtetra
.35457 .41626 .36103 .42279 .37152 .41926 .36508 .41271 Mtetra
.36508 .41271 .37152 .41926 .38205 .41572 .37564 .40914 Mtetra
.37564 .40914 .38205 .41572 .39262 .41216 .38623 .40556 Mtetra
.38623 .40556 .39262 .41216 .40323 .40859 .39687 .40196 Mtetra
.39687 .40196 .40323 .40859 .41389 .40501 .40756 .39835 Mtetra
.40756 .39835 .41389 .40501 .42458 .40141 .41828 .39473 Mtetra
.41828 .39473 .42458 .40141 .43532 .39779 .42905 .39109 Mtetra
.42905 .39109 .43532 .39779 .44611 .39417 .43986 .38743 Mtetra
.43986 .38743 .44611 .39417 .45693 .39053 .45071 .38376 Mtetra
.45071 .38376 .45693 .39053 .4678 .38687 .4616 .38008 Mtetra
.4616 .38008 .4678 .38687 .47871 .3832 .47255 .37638 Mtetra
.47255 .37638 .47871 .3832 .48967 .37951 .48353 .37267 Mtetra
.48353 .37267 .48967 .37951 .50067 .37581 .49456 .36894 Mtetra
.49456 .36894 .50067 .37581 .51171 .3721 .50563 .3652 Mtetra
.50563 .3652 .51171 .3721 .5228 .36837 .51675 .36144 Mtetra
.51675 .36144 .5228 .36837 .53394 .36462 .52791 .35767 Mtetra
.52791 .35767 .53394 .36462 .54512 .36086 .53912 .35388 Mtetra
.53912 .35388 .54512 .36086 .55634 .35709 .55038 .35007 Mtetra
.55038 .35007 .55634 .35709 .56761 .35329 .56168 .34625 Mtetra
.56168 .34625 .56761 .35329 .57893 .34949 .57303 .34242 Mtetra
.57303 .34242 .57893 .34949 .59029 .34567 .58442 .33857 Mtetra
.58442 .33857 .59029 .34567 .6017 .34183 .59586 .3347 Mtetra
.59586 .3347 .6017 .34183 .61316 .33797 .60735 .33082 Mtetra
.60735 .33082 .61316 .33797 .62466 .3341 .61889 .32692 Mtetra
.61889 .32692 .62466 .3341 .63621 .33022 .63047 .323 Mtetra
.63047 .323 .63621 .33022 .64781 .32632 .6421 .31907 Mtetra
.6421 .31907 .64781 .32632 .65946 .3224 .65378 .31512 Mtetra
.65378 .31512 .65946 .3224 .67115 .31846 .66551 .31116 Mtetra
.66551 .31116 .67115 .31846 .6829 .31451 .67729 .30718 Mtetra
.67729 .30718 .6829 .31451 .69469 .31055 .68911 .30318 Mtetra
.68911 .30318 .69469 .31055 .70653 .30656 .70099 .29917 Mtetra
.70099 .29917 .70653 .30656 .71842 .30256 .71292 .29513 Mtetra
.71292 .29513 .71842 .30256 .73037 .29855 .72489 .29109 Mtetra
.72489 .29109 .73037 .29855 .74236 .29451 .73692 .28702 Mtetra
.73692 .28702 .74236 .29451 .7544 .29046 .749 .28294 Mtetra
.749 .28294 .7544 .29046 .76649 .28639 .76113 .27884 Mtetra
.76113 .27884 .76649 .28639 .77864 .28231 .77331 .27472 Mtetra
.77331 .27472 .77864 .28231 .79083 .27821 .78554 .27059 Mtetra
.78554 .27059 .79083 .27821 .80308 .27409 .79782 .26643 Mtetra
.14569 .47843 .15266 .48451 .16239 .48122 .15545 .47511 Mtetra
.15545 .47511 .16239 .48122 .17216 .47792 .16524 .47179 Mtetra
.16524 .47179 .17216 .47792 .18197 .4746 .17506 .46845 Mtetra
.17506 .46845 .18197 .4746 .19181 .47128 .18493 .4651 Mtetra
.18493 .4651 .19181 .47128 .20169 .46794 .19483 .46174 Mtetra
.19483 .46174 .20169 .46794 .21161 .46458 .20477 .45836 Mtetra
.20477 .45836 .21161 .46458 .22157 .46122 .21475 .45497 Mtetra
.21475 .45497 .22157 .46122 .23156 .45784 .22477 .45157 Mtetra
.22477 .45157 .23156 .45784 .2416 .45445 .23482 .44815 Mtetra
.23482 .44815 .2416 .45445 .25167 .45104 .24492 .44472 Mtetra
.24492 .44472 .25167 .45104 .26178 .44763 .25505 .44128 Mtetra
.25505 .44128 .26178 .44763 .27193 .4442 .26523 .43783 Mtetra
.26523 .43783 .27193 .4442 .28212 .44075 .27544 .43436 Mtetra
.27544 .43436 .28212 .44075 .29235 .43729 .28569 .43087 Mtetra
.28569 .43087 .29235 .43729 .30262 .43382 .29598 .42738 Mtetra
.29598 .42738 .30262 .43382 .31293 .43034 .30632 .42387 Mtetra
.30632 .42387 .31293 .43034 .32328 .42684 .31669 .42034 Mtetra
.31669 .42034 .32328 .42684 .33367 .42333 .32711 .41681 Mtetra
.32711 .41681 .33367 .42333 .3441 .4198 .33756 .41326 Mtetra
.33756 .41326 .3441 .4198 .35457 .41626 .34806 .40969 Mtetra
.34806 .40969 .35457 .41626 .36508 .41271 .3586 .40611 Mtetra
.3586 .40611 .36508 .41271 .37564 .40914 .36918 .40252 Mtetra
.36918 .40252 .37564 .40914 .38623 .40556 .3798 .39891 Mtetra
.3798 .39891 .38623 .40556 .39687 .40196 .39047 .39529 Mtetra
.39047 .39529 .39687 .40196 .40756 .39835 .40118 .39165 Mtetra
.40118 .39165 .40756 .39835 .41828 .39473 .41193 .388 Mtetra
.41193 .388 .41828 .39473 .42905 .39109 .42272 .38433 Mtetra
.42272 .38433 .42905 .39109 .43986 .38743 .43356 .38065 Mtetra
.43356 .38065 .43986 .38743 .45071 .38376 .44444 .37695 Mtetra
.44444 .37695 .45071 .38376 .4616 .38008 .45536 .37324 Mtetra
.45536 .37324 .4616 .38008 .47255 .37638 .46633 .36952 Mtetra
.46633 .36952 .47255 .37638 .48353 .37267 .47735 .36578 Mtetra
.47735 .36578 .48353 .37267 .49456 .36894 .4884 .36202 Mtetra
.4884 .36202 .49456 .36894 .50563 .3652 .49951 .35825 Mtetra
.49951 .35825 .50563 .3652 .51675 .36144 .51065 .35446 Mtetra
.51065 .35446 .51675 .36144 .52791 .35767 .52185 .35066 Mtetra
.52185 .35066 .52791 .35767 .53912 .35388 .53309 .34684 Mtetra
.53309 .34684 .53912 .35388 .55038 .35007 .54437 .34301 Mtetra
.54437 .34301 .55038 .35007 .56168 .34625 .5557 .33916 Mtetra
.5557 .33916 .56168 .34625 .57303 .34242 .56708 .3353 Mtetra
.56708 .3353 .57303 .34242 .58442 .33857 .57851 .33142 Mtetra
.57851 .33142 .58442 .33857 .59586 .3347 .58998 .32752 Mtetra
.58998 .32752 .59586 .3347 .60735 .33082 .6015 .32361 Mtetra
.6015 .32361 .60735 .33082 .61889 .32692 .61307 .31968 Mtetra
.61307 .31968 .61889 .32692 .63047 .323 .62468 .31573 Mtetra
.62468 .31573 .63047 .323 .6421 .31907 .63635 .31177 Mtetra
.63635 .31177 .6421 .31907 .65378 .31512 .64806 .30779 Mtetra
.64806 .30779 .65378 .31512 .66551 .31116 .65982 .3038 Mtetra
.65982 .3038 .66551 .31116 .67729 .30718 .67163 .29978 Mtetra
.67163 .29978 .67729 .30718 .68911 .30318 .68349 .29576 Mtetra
.68349 .29576 .68911 .30318 .70099 .29917 .6954 .29171 Mtetra
.6954 .29171 .70099 .29917 .71292 .29513 .70736 .28765 Mtetra
.70736 .28765 .71292 .29513 .72489 .29109 .71938 .28357 Mtetra
.71938 .28357 .72489 .29109 .73692 .28702 .73144 .27947 Mtetra
.73144 .27947 .73692 .28702 .749 .28294 .74355 .27536 Mtetra
.74355 .27536 .749 .28294 .76113 .27884 .75572 .27122 Mtetra
.75572 .27122 .76113 .27884 .77331 .27472 .76793 .26707 Mtetra
.76793 .26707 .77331 .27472 .78554 .27059 .7802 .26291 Mtetra
.7802 .26291 .78554 .27059 .79782 .26643 .79252 .25872 Mtetra
.13868 .4723 .14569 .47843 .15545 .47511 .14845 .46897 Mtetra
.14845 .46897 .15545 .47511 .16524 .47179 .15826 .46562 Mtetra
.15826 .46562 .16524 .47179 .17506 .46845 .16811 .46226 Mtetra
.16811 .46226 .17506 .46845 .18493 .4651 .17799 .45888 Mtetra
.17799 .45888 .18493 .4651 .19483 .46174 .18792 .45549 Mtetra
.18792 .45549 .19483 .46174 .20477 .45836 .19788 .45209 Mtetra
.19788 .45209 .20477 .45836 .21475 .45497 .20788 .44868 Mtetra
.20788 .44868 .21475 .45497 .22477 .45157 .21792 .44525 Mtetra
.21792 .44525 .22477 .45157 .23482 .44815 .228 .44181 Mtetra
.228 .44181 .23482 .44815 .24492 .44472 .23812 .43836 Mtetra
.23812 .43836 .24492 .44472 .25505 .44128 .24828 .43489 Mtetra
.24828 .43489 .25505 .44128 .26523 .43783 .25847 .43141 Mtetra
.25847 .43141 .26523 .43783 .27544 .43436 .26871 .42792 Mtetra
.26871 .42792 .27544 .43436 .28569 .43087 .27899 .42441 Mtetra
.27899 .42441 .28569 .43087 .29598 .42738 .2893 .42089 Mtetra
.2893 .42089 .29598 .42738 .30632 .42387 .29966 .41735 Mtetra
.29966 .41735 .30632 .42387 .31669 .42034 .31006 .4138 Mtetra
.31006 .4138 .31669 .42034 .32711 .41681 .3205 .41024 Mtetra
.3205 .41024 .32711 .41681 .33756 .41326 .33098 .40666 Mtetra
.33098 .40666 .33756 .41326 .34806 .40969 .34151 .40307 Mtetra
.34151 .40307 .34806 .40969 .3586 .40611 .35207 .39946 Mtetra
.35207 .39946 .3586 .40611 .36918 .40252 .36268 .39584 Mtetra
.36268 .39584 .36918 .40252 .3798 .39891 .37333 .39221 Mtetra
.37333 .39221 .3798 .39891 .39047 .39529 .38402 .38856 Mtetra
.38402 .38856 .39047 .39529 .40118 .39165 .39475 .3849 Mtetra
.39475 .3849 .40118 .39165 .41193 .388 .40553 .38122 Mtetra
.40553 .38122 .41193 .388 .42272 .38433 .41635 .37752 Mtetra
.41635 .37752 .42272 .38433 .43356 .38065 .42722 .37381 Mtetra
.42722 .37381 .43356 .38065 .44444 .37695 .43812 .37009 Mtetra
.43812 .37009 .44444 .37695 .45536 .37324 .44908 .36635 Mtetra
.44908 .36635 .45536 .37324 .46633 .36952 .46007 .3626 Mtetra
.46007 .3626 .46633 .36952 .47735 .36578 .47112 .35883 Mtetra
.47112 .35883 .47735 .36578 .4884 .36202 .4822 .35505 Mtetra
.4822 .35505 .4884 .36202 .49951 .35825 .49333 .35125 Mtetra
.49333 .35125 .49951 .35825 .51065 .35446 .50451 .34743 Mtetra
.50451 .34743 .51065 .35446 .52185 .35066 .51573 .3436 Mtetra
.51573 .3436 .52185 .35066 .53309 .34684 .527 .33975 Mtetra
.527 .33975 .53309 .34684 .54437 .34301 .53832 .33589 Mtetra
.53832 .33589 .54437 .34301 .5557 .33916 .54968 .33201 Mtetra
.54968 .33201 .5557 .33916 .56708 .3353 .56109 .32812 Mtetra
.56109 .32812 .56708 .3353 .57851 .33142 .57255 .32421 Mtetra
.57255 .32421 .57851 .33142 .58998 .32752 .58405 .32028 Mtetra
.58405 .32028 .58998 .32752 .6015 .32361 .5956 .31634 Mtetra
.5956 .31634 .6015 .32361 .61307 .31968 .6072 .31238 Mtetra
.6072 .31238 .61307 .31968 .62468 .31573 .61885 .3084 Mtetra
.61885 .3084 .62468 .31573 .63635 .31177 .63055 .30441 Mtetra
.63055 .30441 .63635 .31177 .64806 .30779 .64229 .3004 Mtetra
.64229 .3004 .64806 .30779 .65982 .3038 .65409 .29638 Mtetra
.65409 .29638 .65982 .3038 .67163 .29978 .66593 .29233 Mtetra
.66593 .29233 .67163 .29978 .68349 .29576 .67783 .28827 Mtetra
.67783 .28827 .68349 .29576 .6954 .29171 .68977 .2842 Mtetra
.68977 .2842 .6954 .29171 .70736 .28765 .70177 .2801 Mtetra
.70177 .2801 .70736 .28765 .71938 .28357 .71382 .27599 Mtetra
.71382 .27599 .71938 .28357 .73144 .27947 .72591 .27186 Mtetra
.72591 .27186 .73144 .27947 .74355 .27536 .73806 .26771 Mtetra
.73806 .26771 .74355 .27536 .75572 .27122 .75026 .26355 Mtetra
.75026 .26355 .75572 .27122 .76793 .26707 .76252 .25937 Mtetra
.76252 .25937 .76793 .26707 .7802 .26291 .77482 .25517 Mtetra
.77482 .25517 .7802 .26291 .79252 .25872 .78718 .25095 Mtetra
.13161 .46613 .13868 .4723 .14845 .46897 .1414 .46277 Mtetra
.1414 .46277 .14845 .46897 .15826 .46562 .15123 .4594 Mtetra
.15123 .4594 .15826 .46562 .16811 .46226 .1611 .45602 Mtetra
.1611 .45602 .16811 .46226 .17799 .45888 .17101 .45262 Mtetra
.17101 .45262 .17799 .45888 .18792 .45549 .18096 .44921 Mtetra
.18096 .44921 .18792 .45549 .19788 .45209 .19094 .44578 Mtetra
.19094 .44578 .19788 .45209 .20788 .44868 .20097 .44234 Mtetra
.20097 .44234 .20788 .44868 .21792 .44525 .21103 .43889 Mtetra
.21103 .43889 .21792 .44525 .228 .44181 .22113 .43543 Mtetra
.22113 .43543 .228 .44181 .23812 .43836 .23127 .43195 Mtetra
.23127 .43195 .23812 .43836 .24828 .43489 .24145 .42846 Mtetra
.24145 .42846 .24828 .43489 .25847 .43141 .25167 .42495 Mtetra
.25167 .42495 .25847 .43141 .26871 .42792 .26193 .42143 Mtetra
.26193 .42143 .26871 .42792 .27899 .42441 .27223 .4179 Mtetra
.27223 .4179 .27899 .42441 .2893 .42089 .28258 .41435 Mtetra
.28258 .41435 .2893 .42089 .29966 .41735 .29296 .41079 Mtetra
.29296 .41079 .29966 .41735 .31006 .4138 .30338 .40721 Mtetra
.30338 .40721 .31006 .4138 .3205 .41024 .31385 .40362 Mtetra
.31385 .40362 .3205 .41024 .33098 .40666 .32435 .40002 Mtetra
.32435 .40002 .33098 .40666 .34151 .40307 .3349 .3964 Mtetra
.3349 .3964 .34151 .40307 .35207 .39946 .34549 .39277 Mtetra
.34549 .39277 .35207 .39946 .36268 .39584 .35613 .38912 Mtetra
.35613 .38912 .36268 .39584 .37333 .39221 .3668 .38546 Mtetra
.3668 .38546 .37333 .39221 .38402 .38856 .37752 .38178 Mtetra
.37752 .38178 .38402 .38856 .39475 .3849 .38828 .37809 Mtetra
.38828 .37809 .39475 .3849 .40553 .38122 .39908 .37439 Mtetra
.39908 .37439 .40553 .38122 .41635 .37752 .40993 .37067 Mtetra
.40993 .37067 .41635 .37752 .42722 .37381 .42083 .36693 Mtetra
.42083 .36693 .42722 .37381 .43812 .37009 .43176 .36318 Mtetra
.43176 .36318 .43812 .37009 .44908 .36635 .44274 .35941 Mtetra
.44274 .35941 .44908 .36635 .46007 .3626 .45377 .35563 Mtetra
.45377 .35563 .46007 .3626 .47112 .35883 .46484 .35183 Mtetra
.46484 .35183 .47112 .35883 .4822 .35505 .47595 .34802 Mtetra
.47595 .34802 .4822 .35505 .49333 .35125 .48711 .34419 Mtetra
.48711 .34419 .49333 .35125 .50451 .34743 .49832 .34035 Mtetra
.49832 .34035 .50451 .34743 .51573 .3436 .50957 .33649 Mtetra
.50957 .33649 .51573 .3436 .527 .33975 .52087 .33261 Mtetra
.52087 .33261 .527 .33975 .53832 .33589 .53222 .32872 Mtetra
.53222 .32872 .53832 .33589 .54968 .33201 .54361 .32481 Mtetra
.54361 .32481 .54968 .33201 .56109 .32812 .55505 .32089 Mtetra
.55505 .32089 .56109 .32812 .57255 .32421 .56654 .31695 Mtetra
.56654 .31695 .57255 .32421 .58405 .32028 .57808 .31299 Mtetra
.57808 .31299 .58405 .32028 .5956 .31634 .58966 .30902 Mtetra
.58966 .30902 .5956 .31634 .6072 .31238 .60129 .30503 Mtetra
.60129 .30503 .6072 .31238 .61885 .3084 .61297 .30102 Mtetra
.61297 .30102 .61885 .3084 .63055 .30441 .6247 .297 Mtetra
.6247 .297 .63055 .30441 .64229 .3004 .63648 .29296 Mtetra
.63648 .29296 .64229 .3004 .65409 .29638 .64831 .2889 Mtetra
.64831 .2889 .65409 .29638 .66593 .29233 .66019 .28482 Mtetra
.66019 .28482 .66593 .29233 .67783 .28827 .67212 .28073 Mtetra
.67212 .28073 .67783 .28827 .68977 .2842 .6841 .27662 Mtetra
.6841 .27662 .68977 .2842 .70177 .2801 .69613 .2725 Mtetra
.69613 .2725 .70177 .2801 .71382 .27599 .70821 .26835 Mtetra
.70821 .26835 .71382 .27599 .72591 .27186 .72035 .26419 Mtetra
.72035 .26419 .72591 .27186 .73806 .26771 .73253 .26001 Mtetra
.73253 .26001 .73806 .26771 .75026 .26355 .74477 .25581 Mtetra
.74477 .25581 .75026 .26355 .76252 .25937 .75706 .2516 Mtetra
.75706 .2516 .76252 .25937 .77482 .25517 .7694 .24736 Mtetra
.7694 .24736 .77482 .25517 .78718 .25095 .7818 .24311 Mtetra
.12449 .45992 .13161 .46613 .1414 .46277 .13431 .45654 Mtetra
.13431 .45654 .1414 .46277 .15123 .4594 .14416 .45314 Mtetra
.14416 .45314 .15123 .4594 .1611 .45602 .15405 .44973 Mtetra
.15405 .44973 .1611 .45602 .17101 .45262 .16398 .44631 Mtetra
.16398 .44631 .17101 .45262 .18096 .44921 .17395 .44287 Mtetra
.17395 .44287 .18096 .44921 .19094 .44578 .18396 .43942 Mtetra
.18396 .43942 .19094 .44578 .20097 .44234 .194 .43596 Mtetra
.194 .43596 .20097 .44234 .21103 .43889 .20409 .43248 Mtetra
.20409 .43248 .21103 .43889 .22113 .43543 .21421 .42899 Mtetra
.21421 .42899 .22113 .43543 .23127 .43195 .22437 .42549 Mtetra
.22437 .42549 .23127 .43195 .24145 .42846 .23458 .42197 Mtetra
.23458 .42197 .24145 .42846 .25167 .42495 .24482 .41844 Mtetra
.24482 .41844 .25167 .42495 .26193 .42143 .25511 .4149 Mtetra
.25511 .4149 .26193 .42143 .27223 .4179 .26543 .41134 Mtetra
.26543 .41134 .27223 .4179 .28258 .41435 .2758 .40776 Mtetra
.2758 .40776 .28258 .41435 .29296 .41079 .28621 .40418 Mtetra
.28621 .40418 .29296 .41079 .30338 .40721 .29665 .40057 Mtetra
.29665 .40057 .30338 .40721 .31385 .40362 .30714 .39696 Mtetra
.30714 .39696 .31385 .40362 .32435 .40002 .31768 .39333 Mtetra
.31768 .39333 .32435 .40002 .3349 .3964 .32825 .38968 Mtetra
.32825 .38968 .3349 .3964 .34549 .39277 .33887 .38602 Mtetra
.33887 .38602 .34549 .39277 .35613 .38912 .34952 .38235 Mtetra
.34952 .38235 .35613 .38912 .3668 .38546 .36023 .37866 Mtetra
.36023 .37866 .3668 .38546 .37752 .38178 .37097 .37496 Mtetra
.37097 .37496 .37752 .38178 .38828 .37809 .38176 .37124 Mtetra
.38176 .37124 .38828 .37809 .39908 .37439 .39259 .3675 Mtetra
.39259 .3675 .39908 .37439 .40993 .37067 .40347 .36376 Mtetra
.40347 .36376 .40993 .37067 .42083 .36693 .41439 .35999 Mtetra
.41439 .35999 .42083 .36693 .43176 .36318 .42535 .35621 Mtetra
.42535 .35621 .43176 .36318 .44274 .35941 .43636 .35242 Mtetra
.43636 .35242 .44274 .35941 .45377 .35563 .44741 .34861 Mtetra
.44741 .34861 .45377 .35563 .46484 .35183 .45851 .34478 Mtetra
.45851 .34478 .46484 .35183 .47595 .34802 .46966 .34094 Mtetra
.46966 .34094 .47595 .34802 .48711 .34419 .48085 .33708 Mtetra
.48085 .33708 .48711 .34419 .49832 .34035 .49208 .33321 Mtetra
.49208 .33321 .49832 .34035 .50957 .33649 .50337 .32932 Mtetra
.50337 .32932 .50957 .33649 .52087 .33261 .5147 .32541 Mtetra
.5147 .32541 .52087 .33261 .53222 .32872 .52607 .32149 Mtetra
.52607 .32149 .53222 .32872 .54361 .32481 .5375 .31755 Mtetra
.5375 .31755 .54361 .32481 .55505 .32089 .54897 .3136 Mtetra
.54897 .3136 .55505 .32089 .56654 .31695 .56049 .30963 Mtetra
.56049 .30963 .56654 .31695 .57808 .31299 .57206 .30564 Mtetra
.57206 .30564 .57808 .31299 .58966 .30902 .58367 .30164 Mtetra
.58367 .30164 .58966 .30902 .60129 .30503 .59534 .29762 Mtetra
.59534 .29762 .60129 .30503 .61297 .30102 .60705 .29358 Mtetra
.60705 .29358 .61297 .30102 .6247 .297 .61881 .28952 Mtetra
.61881 .28952 .6247 .297 .63648 .29296 .63063 .28545 Mtetra
.63063 .28545 .63648 .29296 .64831 .2889 .64249 .28136 Mtetra
.64249 .28136 .64831 .2889 .66019 .28482 .6544 .27726 Mtetra
.6544 .27726 .66019 .28482 .67212 .28073 .66637 .27313 Mtetra
.66637 .27313 .67212 .28073 .6841 .27662 .67838 .26899 Mtetra
.67838 .26899 .6841 .27662 .69613 .2725 .69045 .26483 Mtetra
.69045 .26483 .69613 .2725 .70821 .26835 .70256 .26066 Mtetra
.70256 .26066 .70821 .26835 .72035 .26419 .71473 .25646 Mtetra
.71473 .25646 .72035 .26419 .73253 .26001 .72695 .25225 Mtetra
.72695 .25225 .73253 .26001 .74477 .25581 .73923 .24802 Mtetra
.73923 .24802 .74477 .25581 .75706 .2516 .75156 .24377 Mtetra
.75156 .24377 .75706 .2516 .7694 .24736 .76394 .2395 Mtetra
.76394 .2395 .7694 .24736 .7818 .24311 .77637 .23521 Mtetra
.11732 .45366 .12449 .45992 .13431 .45654 .12716 .45025 Mtetra
.12716 .45025 .13431 .45654 .14416 .45314 .13703 .44683 Mtetra
.13703 .44683 .14416 .45314 .15405 .44973 .14695 .4434 Mtetra
.14695 .4434 .15405 .44973 .16398 .44631 .1569 .43995 Mtetra
.1569 .43995 .16398 .44631 .17395 .44287 .16689 .43649 Mtetra
.16689 .43649 .17395 .44287 .18396 .43942 .17692 .43301 Mtetra
.17692 .43301 .18396 .43942 .194 .43596 .18699 .42952 Mtetra
.18699 .42952 .194 .43596 .20409 .43248 .19709 .42602 Mtetra
.19709 .42602 .20409 .43248 .21421 .42899 .20724 .42251 Mtetra
.20724 .42251 .21421 .42899 .22437 .42549 .21743 .41898 Mtetra
.21743 .41898 .22437 .42549 .23458 .42197 .22766 .41543 Mtetra
.22766 .41543 .23458 .42197 .24482 .41844 .23792 .41188 Mtetra
.23792 .41188 .24482 .41844 .25511 .4149 .24823 .40831 Mtetra
.24823 .40831 .25511 .4149 .26543 .41134 .25858 .40472 Mtetra
.25858 .40472 .26543 .41134 .2758 .40776 .26897 .40112 Mtetra
.26897 .40112 .2758 .40776 .28621 .40418 .2794 .39751 Mtetra
.2794 .39751 .28621 .40418 .29665 .40057 .28988 .39388 Mtetra
.28988 .39388 .29665 .40057 .30714 .39696 .30039 .39024 Mtetra
.30039 .39024 .30714 .39696 .31768 .39333 .31095 .38658 Mtetra
.31095 .38658 .31768 .39333 .32825 .38968 .32155 .38291 Mtetra
.32155 .38291 .32825 .38968 .33887 .38602 .33219 .37922 Mtetra
.33219 .37922 .33887 .38602 .34952 .38235 .34288 .37552 Mtetra
.34288 .37552 .34952 .38235 .36023 .37866 .3536 .3718 Mtetra
.3536 .3718 .36023 .37866 .37097 .37496 .36438 .36807 Mtetra
.36438 .36807 .37097 .37496 .38176 .37124 .37519 .36433 Mtetra
.37519 .36433 .38176 .37124 .39259 .3675 .38605 .36056 Mtetra
.38605 .36056 .39259 .3675 .40347 .36376 .39695 .35679 Mtetra
.39695 .35679 .40347 .36376 .41439 .35999 .4079 .353 Mtetra
.4079 .353 .41439 .35999 .42535 .35621 .41889 .34919 Mtetra
.41889 .34919 .42535 .35621 .43636 .35242 .42993 .34536 Mtetra
.42993 .34536 .43636 .35242 .44741 .34861 .44101 .34152 Mtetra
.44101 .34152 .44741 .34861 .45851 .34478 .45214 .33767 Mtetra
.45214 .33767 .45851 .34478 .46966 .34094 .46331 .3338 Mtetra
.46331 .3338 .46966 .34094 .48085 .33708 .47453 .32991 Mtetra
.47453 .32991 .48085 .33708 .49208 .33321 .4858 .32601 Mtetra
.4858 .32601 .49208 .33321 .50337 .32932 .49711 .32209 Mtetra
.49711 .32209 .50337 .32932 .5147 .32541 .50847 .31815 Mtetra
.50847 .31815 .5147 .32541 .52607 .32149 .51988 .3142 Mtetra
.51988 .3142 .52607 .32149 .5375 .31755 .53134 .31023 Mtetra
.53134 .31023 .5375 .31755 .54897 .3136 .54284 .30625 Mtetra
.54284 .30625 .54897 .3136 .56049 .30963 .55439 .30225 Mtetra
.55439 .30225 .56049 .30963 .57206 .30564 .56599 .29823 Mtetra
.56599 .29823 .57206 .30564 .58367 .30164 .57764 .29419 Mtetra
.57764 .29419 .58367 .30164 .59534 .29762 .58933 .29014 Mtetra
.58933 .29014 .59534 .29762 .60705 .29358 .60108 .28607 Mtetra
.60108 .28607 .60705 .29358 .61881 .28952 .61288 .28199 Mtetra
.61288 .28199 .61881 .28952 .63063 .28545 .62472 .27788 Mtetra
.62472 .27788 .63063 .28545 .64249 .28136 .63662 .27376 Mtetra
.63662 .27376 .64249 .28136 .6544 .27726 .64857 .26962 Mtetra
.64857 .26962 .6544 .27726 .66637 .27313 .66057 .26547 Mtetra
.66057 .26547 .66637 .27313 .67838 .26899 .67262 .26129 Mtetra
.67262 .26129 .67838 .26899 .69045 .26483 .68472 .2571 Mtetra
.68472 .2571 .69045 .26483 .70256 .26066 .69687 .25289 Mtetra
.69687 .25289 .70256 .26066 .71473 .25646 .70908 .24866 Mtetra
.70908 .24866 .71473 .25646 .72695 .25225 .72133 .24442 Mtetra
.72133 .24442 .72695 .25225 .73923 .24802 .73365 .24015 Mtetra
.73365 .24015 .73923 .24802 .75156 .24377 .74601 .23587 Mtetra
.74601 .23587 .75156 .24377 .76394 .2395 .75843 .23157 Mtetra
.75843 .23157 .76394 .2395 .77637 .23521 .7709 .22725 Mtetra
.1101 .44736 .11732 .45366 .12716 .45025 .11996 .44393 Mtetra
.11996 .44393 .12716 .45025 .13703 .44683 .12986 .44049 Mtetra
.656 .752 .92 r
.12986 .44049 .13703 .44683 .14695 .4434 .13979 .43703 Mtetra
.13979 .43703 .14695 .4434 .1569 .43995 .14976 .43356 Mtetra
.14976 .43356 .1569 .43995 .16689 .43649 .15978 .43007 Mtetra
.15978 .43007 .16689 .43649 .17692 .43301 .16983 .42657 Mtetra
.16983 .42657 .17692 .43301 .18699 .42952 .17992 .42306 Mtetra
.17992 .42306 .18699 .42952 .19709 .42602 .19005 .41953 Mtetra
.19005 .41953 .19709 .42602 .20724 .42251 .20022 .41599 Mtetra
.20022 .41599 .20724 .42251 .21743 .41898 .21043 .41243 Mtetra
.21043 .41243 .21743 .41898 .22766 .41543 .22068 .40887 Mtetra
.22068 .40887 .22766 .41543 .23792 .41188 .23097 .40528 Mtetra
.23097 .40528 .23792 .41188 .24823 .40831 .24131 .40168 Mtetra
.24131 .40168 .24823 .40831 .25858 .40472 .25168 .39807 Mtetra
.25168 .39807 .25858 .40472 .26897 .40112 .26209 .39445 Mtetra
.26209 .39445 .26897 .40112 .2794 .39751 .27255 .39081 Mtetra
.27255 .39081 .2794 .39751 .28988 .39388 .28305 .38715 Mtetra
.28305 .38715 .28988 .39388 .30039 .39024 .29359 .38348 Mtetra
.29359 .38348 .30039 .39024 .31095 .38658 .30417 .3798 Mtetra
.30417 .3798 .31095 .38658 .32155 .38291 .3148 .3761 Mtetra
.3148 .3761 .32155 .38291 .33219 .37922 .32546 .37238 Mtetra
.32546 .37238 .33219 .37922 .34288 .37552 .33618 .36865 Mtetra
.33618 .36865 .34288 .37552 .3536 .3718 .34693 .36491 Mtetra
.34693 .36491 .3536 .3718 .36438 .36807 .35773 .36115 Mtetra
.35773 .36115 .36438 .36807 .37519 .36433 .36857 .35738 Mtetra
.36857 .35738 .37519 .36433 .38605 .36056 .37946 .35359 Mtetra
.37946 .35359 .38605 .36056 .39695 .35679 .39039 .34978 Mtetra
.39039 .34978 .39695 .35679 .4079 .353 .40136 .34596 Mtetra
.40136 .34596 .4079 .353 .41889 .34919 .41238 .34212 Mtetra
.41238 .34212 .41889 .34919 .42993 .34536 .42345 .33827 Mtetra
.42345 .33827 .42993 .34536 .44101 .34152 .43456 .3344 Mtetra
.43456 .3344 .44101 .34152 .45214 .33767 .44572 .33052 Mtetra
.44572 .33052 .45214 .33767 .46331 .3338 .45692 .32662 Mtetra
.45692 .32662 .46331 .3338 .47453 .32991 .46817 .3227 Mtetra
.46817 .3227 .47453 .32991 .4858 .32601 .47947 .31877 Mtetra
.47947 .31877 .4858 .32601 .49711 .32209 .49081 .31482 Mtetra
.49081 .31482 .49711 .32209 .50847 .31815 .5022 .31085 Mtetra
.5022 .31085 .50847 .31815 .51988 .3142 .51364 .30687 Mtetra
.51364 .30687 .51988 .3142 .53134 .31023 .52513 .30287 Mtetra
.52513 .30287 .53134 .31023 .54284 .30625 .53666 .29886 Mtetra
.53666 .29886 .54284 .30625 .55439 .30225 .54824 .29482 Mtetra
.54824 .29482 .55439 .30225 .56599 .29823 .55988 .29077 Mtetra
.55988 .29077 .56599 .29823 .57764 .29419 .57156 .28671 Mtetra
.57156 .28671 .57764 .29419 .58933 .29014 .58329 .28262 Mtetra
.58329 .28262 .58933 .29014 .60108 .28607 .59507 .27852 Mtetra
.59507 .27852 .60108 .28607 .61288 .28199 .6069 .2744 Mtetra
.6069 .2744 .61288 .28199 .62472 .27788 .61878 .27027 Mtetra
.61878 .27027 .62472 .27788 .63662 .27376 .63071 .26611 Mtetra
.63071 .26611 .63662 .27376 .64857 .26962 .64269 .26194 Mtetra
.64269 .26194 .64857 .26962 .66057 .26547 .65472 .25775 Mtetra
.65472 .25775 .66057 .26547 .67262 .26129 .66681 .25355 Mtetra
.66681 .25355 .67262 .26129 .68472 .2571 .67894 .24932 Mtetra
.67894 .24932 .68472 .2571 .69687 .25289 .69113 .24508 Mtetra
.69113 .24508 .69687 .25289 .70908 .24866 .70337 .24082 Mtetra
.70337 .24082 .70908 .24866 .72133 .24442 .71567 .23654 Mtetra
.71567 .23654 .72133 .24442 .73365 .24015 .72802 .23224 Mtetra
.72802 .23224 .73365 .24015 .74601 .23587 .74042 .22792 Mtetra
.74042 .22792 .74601 .23587 .75843 .23157 .75288 .22358 Mtetra
.656 .751 .92 r
.75288 .22358 .75843 .23157 .7709 .22725 .76539 .21923 Mtetra
.10283 .44102 .1101 .44736 .11996 .44393 .11271 .43756 Mtetra
.11271 .43756 .11996 .44393 .12986 .44049 .12263 .43408 Mtetra
.12263 .43408 .12986 .44049 .13979 .43703 .13259 .43059 Mtetra
.13259 .43059 .13979 .43703 .14976 .43356 .14258 .42709 Mtetra
.14258 .42709 .14976 .43356 .15978 .43007 .15262 .42358 Mtetra
.15262 .42358 .15978 .43007 .16983 .42657 .16269 .42005 Mtetra
.16269 .42005 .16983 .42657 .17992 .42306 .1728 .4165 Mtetra
.656 .75 .919 r
.1728 .4165 .17992 .42306 .19005 .41953 .18296 .41294 Mtetra
.18296 .41294 .19005 .41953 .20022 .41599 .19315 .40937 Mtetra
.19315 .40937 .20022 .41599 .21043 .41243 .20339 .40579 Mtetra
.20339 .40579 .21043 .41243 .22068 .40887 .21366 .40219 Mtetra
.21366 .40219 .22068 .40887 .23097 .40528 .22398 .39857 Mtetra
.22398 .39857 .23097 .40528 .24131 .40168 .23433 .39495 Mtetra
.23433 .39495 .24131 .40168 .25168 .39807 .24473 .39131 Mtetra
.656 .749 .919 r
.24473 .39131 .25168 .39807 .26209 .39445 .25517 .38765 Mtetra
.25517 .38765 .26209 .39445 .27255 .39081 .26565 .38398 Mtetra
.26565 .38398 .27255 .39081 .28305 .38715 .27617 .3803 Mtetra
.27617 .3803 .28305 .38715 .29359 .38348 .28674 .3766 Mtetra
.28674 .3766 .29359 .38348 .30417 .3798 .29735 .37289 Mtetra
.29735 .37289 .30417 .3798 .3148 .3761 .308 .36916 Mtetra
.308 .36916 .3148 .3761 .32546 .37238 .31869 .36541 Mtetra
.31869 .36541 .32546 .37238 .33618 .36865 .32943 .36166 Mtetra
.32943 .36166 .33618 .36865 .34693 .36491 .34021 .35788 Mtetra
.34021 .35788 .34693 .36491 .35773 .36115 .35104 .3541 Mtetra
.35104 .3541 .35773 .36115 .36857 .35738 .36191 .35029 Mtetra
.36191 .35029 .36857 .35738 .37946 .35359 .37282 .34647 Mtetra
.37282 .34647 .37946 .35359 .39039 .34978 .38378 .34264 Mtetra
.38378 .34264 .39039 .34978 .40136 .34596 .39478 .33879 Mtetra
.39478 .33879 .40136 .34596 .41238 .34212 .40583 .33492 Mtetra
.40583 .33492 .41238 .34212 .42345 .33827 .41692 .33104 Mtetra
.41692 .33104 .42345 .33827 .43456 .3344 .42806 .32714 Mtetra
.42806 .32714 .43456 .3344 .44572 .33052 .43925 .32323 Mtetra
.43925 .32323 .44572 .33052 .45692 .32662 .45048 .3193 Mtetra
.45048 .3193 .45692 .32662 .46817 .3227 .46176 .31535 Mtetra
.46176 .31535 .46817 .3227 .47947 .31877 .47309 .31139 Mtetra
.47309 .31139 .47947 .31877 .49081 .31482 .48446 .30741 Mtetra
.48446 .30741 .49081 .31482 .5022 .31085 .49588 .30341 Mtetra
.49588 .30341 .5022 .31085 .51364 .30687 .50735 .2994 Mtetra
.50735 .2994 .51364 .30687 .52513 .30287 .51887 .29537 Mtetra
.51887 .29537 .52513 .30287 .53666 .29886 .53043 .29133 Mtetra
.53043 .29133 .53666 .29886 .54824 .29482 .54205 .28726 Mtetra
.54205 .28726 .54824 .29482 .55988 .29077 .55371 .28318 Mtetra
.55371 .28318 .55988 .29077 .57156 .28671 .56543 .27909 Mtetra
.56543 .27909 .57156 .28671 .58329 .28262 .57719 .27497 Mtetra
.57719 .27497 .58329 .28262 .59507 .27852 .589 .27084 Mtetra
.589 .27084 .59507 .27852 .6069 .2744 .60087 .26669 Mtetra
.60087 .26669 .6069 .2744 .61878 .27027 .61278 .26253 Mtetra
.656 .75 .919 r
.61278 .26253 .61878 .27027 .63071 .26611 .62474 .25835 Mtetra
.62474 .25835 .63071 .26611 .64269 .26194 .63676 .25415 Mtetra
.63676 .25415 .64269 .26194 .65472 .25775 .64883 .24993 Mtetra
.64883 .24993 .65472 .25775 .66681 .25355 .66095 .24569 Mtetra
.66095 .24569 .66681 .25355 .67894 .24932 .67312 .24144 Mtetra
.656 .75 .92 r
.67312 .24144 .67894 .24932 .69113 .24508 .68535 .23717 Mtetra
.68535 .23717 .69113 .24508 .70337 .24082 .69763 .23288 Mtetra
.656 .751 .92 r
.69763 .23288 .70337 .24082 .71567 .23654 .70996 .22857 Mtetra
.70996 .22857 .71567 .23654 .72802 .23224 .72234 .22424 Mtetra
.72234 .22424 .72802 .23224 .74042 .22792 .73478 .21989 Mtetra
.73478 .21989 .74042 .22792 .75288 .22358 .74728 .21552 Mtetra
.74728 .21552 .75288 .22358 .76539 .21923 .75983 .21113 Mtetra
.655 .751 .921 r
.09551 .43462 .10283 .44102 .11271 .43756 .1054 .43117 Mtetra
.655 .752 .921 r
.1054 .43117 .11271 .43756 .12263 .43408 .11534 .4277 Mtetra
.655 .753 .922 r
.11534 .4277 .12263 .43408 .13259 .43059 .12531 .42422 Mtetra
.655 .754 .923 r
.12531 .42422 .13259 .43059 .14258 .42709 .13533 .42071 Mtetra
.655 .755 .923 r
.13533 .42071 .14258 .42709 .15262 .42358 .14539 .41719 Mtetra
.14539 .41719 .15262 .42358 .16269 .42005 .15548 .41365 Mtetra
.656 .756 .924 r
.15548 .41365 .16269 .42005 .1728 .4165 .16562 .41009 Mtetra
.16562 .41009 .1728 .4165 .18296 .41294 .17579 .40651 Mtetra
.656 .757 .924 r
.17579 .40651 .18296 .41294 .19315 .40937 .18601 .40292 Mtetra
.18601 .40292 .19315 .40937 .20339 .40579 .19627 .39932 Mtetra
.19627 .39932 .20339 .40579 .21366 .40219 .20657 .39569 Mtetra
.20657 .39569 .21366 .40219 .22398 .39857 .21691 .39206 Mtetra
.21691 .39206 .22398 .39857 .23433 .39495 .22729 .3884 Mtetra
.22729 .3884 .23433 .39495 .24473 .39131 .23771 .38473 Mtetra
.23771 .38473 .24473 .39131 .25517 .38765 .24817 .38105 Mtetra
.24817 .38105 .25517 .38765 .26565 .38398 .25868 .37735 Mtetra
.25868 .37735 .26565 .38398 .27617 .3803 .26923 .37364 Mtetra
.26923 .37364 .27617 .3803 .28674 .3766 .27982 .36991 Mtetra
.27982 .36991 .28674 .3766 .29735 .37289 .29046 .36617 Mtetra
.29046 .36617 .29735 .37289 .308 .36916 .30113 .36241 Mtetra
.30113 .36241 .308 .36916 .31869 .36541 .31186 .35864 Mtetra
.31186 .35864 .31869 .36541 .32943 .36166 .32262 .35485 Mtetra
.32262 .35485 .32943 .36166 .34021 .35788 .33343 .35105 Mtetra
.33343 .35105 .34021 .35788 .35104 .3541 .34428 .34723 Mtetra
.34428 .34723 .35104 .3541 .36191 .35029 .35518 .3434 Mtetra
.35518 .3434 .36191 .35029 .37282 .34647 .36612 .33955 Mtetra
.36612 .33955 .37282 .34647 .38378 .34264 .37711 .33568 Mtetra
.37711 .33568 .38378 .34264 .39478 .33879 .38814 .3318 Mtetra
.38814 .3318 .39478 .33879 .40583 .33492 .39922 .32791 Mtetra
.39922 .32791 .40583 .33492 .41692 .33104 .41034 .32399 Mtetra
.41034 .32399 .41692 .33104 .42806 .32714 .42151 .32007 Mtetra
.42151 .32007 .42806 .32714 .43925 .32323 .43273 .31612 Mtetra
.43273 .31612 .43925 .32323 .45048 .3193 .44399 .31216 Mtetra
.44399 .31216 .45048 .3193 .46176 .31535 .4553 .30819 Mtetra
.4553 .30819 .46176 .31535 .47309 .31139 .46665 .3042 Mtetra
.46665 .3042 .47309 .31139 .48446 .30741 .47806 .30019 Mtetra
.47806 .30019 .48446 .30741 .49588 .30341 .48951 .29616 Mtetra
.48951 .29616 .49588 .30341 .50735 .2994 .50101 .29212 Mtetra
.50101 .29212 .50735 .2994 .51887 .29537 .51256 .28806 Mtetra
.51256 .28806 .51887 .29537 .53043 .29133 .52416 .28399 Mtetra
.52416 .28399 .53043 .29133 .54205 .28726 .53581 .2799 Mtetra
.53581 .2799 .54205 .28726 .55371 .28318 .5475 .27579 Mtetra
.5475 .27579 .55371 .28318 .56543 .27909 .55925 .27166 Mtetra
.55925 .27166 .56543 .27909 .57719 .27497 .57105 .26752 Mtetra
.656 .757 .925 r
.57105 .26752 .57719 .27497 .589 .27084 .58289 .26335 Mtetra
.58289 .26335 .589 .27084 .60087 .26669 .59479 .25917 Mtetra
.59479 .25917 .60087 .26669 .61278 .26253 .60674 .25497 Mtetra
.60674 .25497 .61278 .26253 .62474 .25835 .61874 .25076 Mtetra
.656 .757 .924 r
.61874 .25076 .62474 .25835 .63676 .25415 .63079 .24652 Mtetra
.63079 .24652 .63676 .25415 .64883 .24993 .6429 .24226 Mtetra
.6429 .24226 .64883 .24993 .66095 .24569 .65505 .23799 Mtetra
.65505 .23799 .66095 .24569 .67312 .24144 .66726 .23369 Mtetra
.656 .756 .924 r
.66726 .23369 .67312 .24144 .68535 .23717 .67952 .22937 Mtetra
.67952 .22937 .68535 .23717 .69763 .23288 .69184 .22503 Mtetra
.656 .756 .923 r
.69184 .22503 .69763 .23288 .70996 .22857 .70421 .22067 Mtetra
.656 .755 .923 r
.70421 .22067 .70996 .22857 .72234 .22424 .71663 .21628 Mtetra
.657 .755 .922 r
.71663 .21628 .72234 .22424 .73478 .21989 .72911 .21187 Mtetra
.657 .754 .921 r
.72911 .21187 .73478 .21989 .74728 .21552 .74164 .20744 Mtetra
.657 .753 .921 r
.74164 .20744 .74728 .21552 .75983 .21113 .75422 .20298 Mtetra
.651 .75 .922 r
.08813 .42819 .09551 .43462 .1054 .43117 .09804 .4248 Mtetra
.651 .753 .924 r
.09804 .4248 .1054 .43117 .11534 .4277 .10798 .42138 Mtetra
.652 .756 .926 r
.10798 .42138 .11534 .4277 .12531 .42422 .11797 .41793 Mtetra
.653 .758 .927 r
.11797 .41793 .12531 .42422 .13533 .42071 .128 .41446 Mtetra
.653 .76 .928 r
.128 .41446 .13533 .42071 .14539 .41719 .13808 .41095 Mtetra
.654 .762 .929 r
.13808 .41095 .14539 .41719 .15548 .41365 .14819 .40741 Mtetra
.655 .763 .929 r
.14819 .40741 .15548 .41365 .16562 .41009 .15835 .40385 Mtetra
.15835 .40385 .16562 .41009 .17579 .40651 .16855 .40026 Mtetra
.655 .764 .929 r
.16855 .40026 .17579 .40651 .18601 .40292 .17879 .39665 Mtetra
.656 .764 .929 r
.17879 .39665 .18601 .40292 .19627 .39932 .18907 .39302 Mtetra
.18907 .39302 .19627 .39932 .20657 .39569 .1994 .38936 Mtetra
.1994 .38936 .20657 .39569 .21691 .39206 .20976 .38569 Mtetra
.20976 .38569 .21691 .39206 .22729 .3884 .22017 .382 Mtetra
.22017 .382 .22729 .3884 .23771 .38473 .23062 .37829 Mtetra
.656 .763 .928 r
.23062 .37829 .23771 .38473 .24817 .38105 .24111 .37457 Mtetra
.24111 .37457 .24817 .38105 .25868 .37735 .25165 .37083 Mtetra
.656 .762 .928 r
.25165 .37083 .25868 .37735 .26923 .37364 .26222 .36707 Mtetra
.657 .762 .927 r
.26222 .36707 .26923 .37364 .27982 .36991 .27284 .3633 Mtetra
.656 .761 .927 r
.27284 .3633 .27982 .36991 .29046 .36617 .2835 .35951 Mtetra
.2835 .35951 .29046 .36617 .30113 .36241 .29421 .35571 Mtetra
.656 .76 .926 r
.29421 .35571 .30113 .36241 .31186 .35864 .30496 .35189 Mtetra
.30496 .35189 .31186 .35864 .32262 .35485 .31575 .34807 Mtetra
.656 .759 .926 r
.31575 .34807 .32262 .35485 .33343 .35105 .32659 .34422 Mtetra
.656 .759 .925 r
.32659 .34422 .33343 .35105 .34428 .34723 .33747 .34036 Mtetra
.33747 .34036 .34428 .34723 .35518 .3434 .3484 .33649 Mtetra
.656 .758 .925 r
.3484 .33649 .35518 .3434 .36612 .33955 .35937 .33261 Mtetra
.35937 .33261 .36612 .33955 .37711 .33568 .37038 .32871 Mtetra
.37038 .32871 .37711 .33568 .38814 .3318 .38144 .3248 Mtetra
.38144 .3248 .38814 .3318 .39922 .32791 .39255 .32087 Mtetra
.39255 .32087 .39922 .32791 .41034 .32399 .4037 .31693 Mtetra
.4037 .31693 .41034 .32399 .42151 .32007 .4149 .31297 Mtetra
.4149 .31297 .42151 .32007 .43273 .31612 .42615 .309 Mtetra
.42615 .309 .43273 .31612 .44399 .31216 .43744 .30502 Mtetra
.655 .758 .925 r
.43744 .30502 .44399 .31216 .4553 .30819 .44878 .30102 Mtetra
.44878 .30102 .4553 .30819 .46665 .3042 .46017 .297 Mtetra
.655 .758 .926 r
.46017 .297 .46665 .3042 .47806 .30019 .47161 .29297 Mtetra
.655 .759 .926 r
.47161 .29297 .47806 .30019 .48951 .29616 .48309 .28893 Mtetra
.48309 .28893 .48951 .29616 .50101 .29212 .49462 .28487 Mtetra
.49462 .28487 .50101 .29212 .51256 .28806 .5062 .2808 Mtetra
.655 .76 .927 r
.5062 .2808 .51256 .28806 .52416 .28399 .51784 .2767 Mtetra
.51784 .2767 .52416 .28399 .53581 .2799 .52952 .2726 Mtetra
.655 .761 .927 r
.52952 .2726 .53581 .2799 .5475 .27579 .54125 .26847 Mtetra
.655 .761 .928 r
.54125 .26847 .5475 .27579 .55925 .27166 .55303 .26433 Mtetra
.655 .762 .928 r
.55303 .26433 .55925 .27166 .57105 .26752 .56486 .26017 Mtetra
.655 .762 .929 r
.56486 .26017 .57105 .26752 .58289 .26335 .57674 .25599 Mtetra
.655 .763 .929 r
.57674 .25599 .58289 .26335 .59479 .25917 .58868 .25179 Mtetra
.58868 .25179 .59479 .25917 .60674 .25497 .60066 .24757 Mtetra
.655 .764 .929 r
.60066 .24757 .60674 .25497 .61874 .25076 .6127 .24332 Mtetra
.6127 .24332 .61874 .25076 .63079 .24652 .62479 .23906 Mtetra
.656 .764 .929 r
.62479 .23906 .63079 .24652 .6429 .24226 .63693 .23477 Mtetra
.63693 .23477 .6429 .24226 .65505 .23799 .64912 .23045 Mtetra
.64912 .23045 .65505 .23799 .66726 .23369 .66137 .22611 Mtetra
.657 .764 .929 r
.66137 .22611 .66726 .23369 .67952 .22937 .67367 .22173 Mtetra
.657 .764 .928 r
.67367 .22173 .67952 .22937 .69184 .22503 .68602 .21733 Mtetra
.658 .763 .927 r
.68602 .21733 .69184 .22503 .70421 .22067 .69842 .21289 Mtetra
.658 .762 .926 r
.69842 .21289 .70421 .22067 .71663 .21628 .71088 .20841 Mtetra
.659 .76 .925 r
.71088 .20841 .71663 .21628 .72911 .21187 .72339 .20389 Mtetra
.66 .758 .923 r
.72339 .20389 .72911 .21187 .74164 .20744 .73595 .19934 Mtetra
.66 .756 .921 r
.73595 .19934 .74164 .20744 .75422 .20298 .74857 .19475 Mtetra
.64 .747 .927 r
.0807 .4217 .08813 .42819 .09804 .4248 .09059 .41854 Mtetra
.641 .756 .932 r
.09059 .41854 .09804 .4248 .10798 .42138 .10053 .41533 Mtetra
.642 .764 .937 r
.10053 .41533 .10798 .42138 .11797 .41793 .11052 .41207 Mtetra
.643 .771 .941 r
.11052 .41207 .11797 .41793 .128 .41446 .12055 .40877 Mtetra
.644 .778 .945 r
.12055 .40877 .128 .41446 .13808 .41095 .13063 .40541 Mtetra
.645 .784 .948 r
.13063 .40541 .13808 .41095 .14819 .40741 .14075 .402 Mtetra
.646 .79 .951 r
.14075 .402 .14819 .40741 .15835 .40385 .15092 .39854 Mtetra
.647 .795 .953 r
.15092 .39854 .15835 .40385 .16855 .40026 .16113 .39504 Mtetra
.648 .799 .955 r
.16113 .39504 .16855 .40026 .17879 .39665 .17139 .3915 Mtetra
.648 .802 .957 r
.17139 .3915 .17879 .39665 .18907 .39302 .18169 .38792 Mtetra
.649 .805 .958 r
.18169 .38792 .18907 .39302 .1994 .38936 .19204 .38431 Mtetra
.649 .807 .959 r
.19204 .38431 .1994 .38936 .20976 .38569 .20243 .38066 Mtetra
.649 .809 .96 r
.20243 .38066 .20976 .38569 .22017 .382 .21286 .37699 Mtetra
.65 .811 .961 r
.21286 .37699 .22017 .382 .23062 .37829 .22333 .37329 Mtetra
.65 .812 .961 r
.22333 .37329 .23062 .37829 .24111 .37457 .23385 .36957 Mtetra
.65 .813 .962 r
.23385 .36957 .24111 .37457 .25165 .37083 .24442 .36582 Mtetra
.65 .814 .962 r
.24442 .36582 .25165 .37083 .26222 .36707 .25502 .36205 Mtetra
.65 .815 .962 r
.25502 .36205 .26222 .36707 .27284 .3633 .26568 .35827 Mtetra
.26568 .35827 .27284 .3633 .2835 .35951 .27637 .35446 Mtetra
.65 .815 .963 r
.27637 .35446 .2835 .35951 .29421 .35571 .28711 .35063 Mtetra
.651 .816 .963 r
.28711 .35063 .29421 .35571 .30496 .35189 .29789 .34679 Mtetra
.29789 .34679 .30496 .35189 .31575 .34807 .30871 .34294 Mtetra
.65 .816 .963 r
.30871 .34294 .31575 .34807 .32659 .34422 .31958 .33907 Mtetra
.31958 .33907 .32659 .34422 .33747 .34036 .3305 .33518 Mtetra
.65 .815 .963 r
.3305 .33518 .33747 .34036 .3484 .33649 .34146 .33128 Mtetra
.34146 .33128 .3484 .33649 .35937 .33261 .35246 .32736 Mtetra
.35246 .32736 .35937 .33261 .37038 .32871 .36352 .32343 Mtetra
.36352 .32343 .37038 .32871 .38144 .3248 .37461 .31949 Mtetra
.37461 .31949 .38144 .3248 .39255 .32087 .38575 .31553 Mtetra
.38575 .31553 .39255 .32087 .4037 .31693 .39694 .31156 Mtetra
.39694 .31156 .4037 .31693 .4149 .31297 .40818 .30758 Mtetra
.40818 .30758 .4149 .31297 .42615 .309 .41946 .30358 Mtetra
.649 .815 .963 r
.41946 .30358 .42615 .309 .43744 .30502 .43079 .29957 Mtetra
.43079 .29957 .43744 .30502 .44878 .30102 .44217 .29554 Mtetra
.44217 .29554 .44878 .30102 .46017 .297 .45359 .2915 Mtetra
.45359 .2915 .46017 .297 .47161 .29297 .46507 .28744 Mtetra
.46507 .28744 .47161 .29297 .48309 .28893 .47659 .28337 Mtetra
.47659 .28337 .48309 .28893 .49462 .28487 .48816 .27928 Mtetra
.48816 .27928 .49462 .28487 .5062 .2808 .49978 .27517 Mtetra
.49978 .27517 .5062 .2808 .51784 .2767 .51145 .27105 Mtetra
.51145 .27105 .51784 .2767 .52952 .2726 .52317 .2669 Mtetra
.52317 .2669 .52952 .2726 .54125 .26847 .53494 .26273 Mtetra
.65 .815 .963 r
.53494 .26273 .54125 .26847 .55303 .26433 .54677 .25854 Mtetra
.65 .814 .962 r
.54677 .25854 .55303 .26433 .56486 .26017 .55864 .25433 Mtetra
.651 .814 .962 r
.55864 .25433 .56486 .26017 .57674 .25599 .57056 .25009 Mtetra
.651 .813 .961 r
.57056 .25009 .57674 .25599 .58868 .25179 .58254 .24582 Mtetra
.652 .812 .96 r
.58254 .24582 .58868 .25179 .60066 .24757 .59456 .24152 Mtetra
.653 .811 .959 r
.59456 .24152 .60066 .24757 .6127 .24332 .60664 .23719 Mtetra
.654 .809 .958 r
.60664 .23719 .6127 .24332 .62479 .23906 .61877 .23282 Mtetra
.655 .807 .956 r
.61877 .23282 .62479 .23906 .63693 .23477 .63095 .22842 Mtetra
.657 .805 .954 r
.63095 .22842 .63693 .23477 .64912 .23045 .64318 .22397 Mtetra
.658 .802 .952 r
.64318 .22397 .64912 .23045 .66137 .22611 .65546 .21947 Mtetra
.66 .798 .949 r
.65546 .21947 .66137 .22611 .67367 .22173 .6678 .21493 Mtetra
.662 .795 .946 r
.6678 .21493 .67367 .22173 .68602 .21733 .68019 .21033 Mtetra
.663 .79 .942 r
.68019 .21033 .68602 .21733 .69842 .21289 .69262 .20568 Mtetra
.665 .785 .938 r
.69262 .20568 .69842 .21289 .71088 .20841 .70511 .20096 Mtetra
.667 .779 .933 r
.70511 .20096 .71088 .20841 .72339 .20389 .71765 .19618 Mtetra
.668 .772 .928 r
.71765 .19618 .72339 .20389 .73595 .19934 .73024 .19135 Mtetra
.669 .765 .922 r
.73024 .19135 .73595 .19934 .74857 .19475 .74288 .18646 Mtetra
.611 .739 .937 r
.07322 .41517 .0807 .4217 .09059 .41854 .08305 .41259 Mtetra
.611 .76 .95 r
.08305 .41259 .09059 .41854 .10053 .41533 .09293 .40995 Mtetra
.609 .78 .963 r
.09293 .40995 .10053 .41533 .11052 .41207 .10287 .40723 Mtetra
.607 .799 .973 r
.10287 .40723 .11052 .41207 .12055 .40877 .11286 .40442 Mtetra
.606 .818 .981 r
.11286 .40442 .12055 .40877 .13063 .40541 .1229 .40152 Mtetra
.603 .834 .988 r
.1229 .40152 .13063 .40541 .14075 .402 .133 .39852 Mtetra
.599 .848 .991 r
.133 .39852 .14075 .402 .15092 .39854 .14316 .39542 Mtetra
.595 .86 .994 r
.14316 .39542 .15092 .39854 .16113 .39504 .15336 .39224 Mtetra
.59 .87 .994 r
.15336 .39224 .16113 .39504 .17139 .3915 .16362 .38898 Mtetra
.585 .878 .993 r
.16362 .38898 .17139 .3915 .18169 .38792 .17393 .38564 Mtetra
.58 .884 .992 r
.17393 .38564 .18169 .38792 .19204 .38431 .18429 .38224 Mtetra
.575 .889 .989 r
.18429 .38224 .19204 .38431 .20243 .38066 .1947 .37877 Mtetra
.571 .893 .987 r
.1947 .37877 .20243 .38066 .21286 .37699 .20515 .37525 Mtetra
.567 .896 .984 r
.20515 .37525 .21286 .37699 .22333 .37329 .21566 .37167 Mtetra
.563 .899 .981 r
.21566 .37167 .22333 .37329 .23385 .36957 .22621 .36804 Mtetra
.56 .9 .979 r
.22621 .36804 .23385 .36957 .24442 .36582 .2368 .36437 Mtetra
.558 .902 .977 r
.2368 .36437 .24442 .36582 .25502 .36205 .24744 .36066 Mtetra
.556 .903 .975 r
.24744 .36066 .25502 .36205 .26568 .35827 .25813 .35691 Mtetra
.554 .904 .973 r
.25813 .35691 .26568 .35827 .27637 .35446 .26887 .35313 Mtetra
.552 .904 .972 r
.26887 .35313 .27637 .35446 .28711 .35063 .27965 .34932 Mtetra
.551 .905 .971 r
.27965 .34932 .28711 .35063 .29789 .34679 .29047 .34548 Mtetra
.551 .905 .97 r
.29047 .34548 .29789 .34679 .30871 .34294 .30134 .34163 Mtetra
.55 .905 .969 r
.30134 .34163 .30871 .34294 .31958 .33907 .31226 .33774 Mtetra
.549 .905 .969 r
.31226 .33774 .31958 .33907 .3305 .33518 .32322 .33384 Mtetra
.549 .905 .968 r
.32322 .33384 .3305 .33518 .34146 .33128 .33423 .32992 Mtetra
.33423 .32992 .34146 .33128 .35246 .32736 .34528 .32599 Mtetra
.34528 .32599 .35246 .32736 .36352 .32343 .35638 .32204 Mtetra
.548 .905 .968 r
.35638 .32204 .36352 .32343 .37461 .31949 .36752 .31807 Mtetra
.36752 .31807 .37461 .31949 .38575 .31553 .37871 .31409 Mtetra
.37871 .31409 .38575 .31553 .39694 .31156 .38995 .31009 Mtetra
.38995 .31009 .39694 .31156 .40818 .30758 .40124 .30608 Mtetra
.40124 .30608 .40818 .30758 .41946 .30358 .41257 .30206 Mtetra
.547 .905 .968 r
.41257 .30206 .41946 .30358 .43079 .29957 .42395 .29801 Mtetra
.548 .905 .968 r
.42395 .29801 .43079 .29957 .44217 .29554 .43538 .29396 Mtetra
.43538 .29396 .44217 .29554 .45359 .2915 .44686 .28988 Mtetra
.44686 .28988 .45359 .2915 .46507 .28744 .45839 .28579 Mtetra
.549 .905 .969 r
.45839 .28579 .46507 .28744 .47659 .28337 .46996 .28167 Mtetra
.55 .905 .969 r
.46996 .28167 .47659 .28337 .48816 .27928 .48159 .27753 Mtetra
.552 .905 .97 r
.48159 .27753 .48816 .27928 .49978 .27517 .49326 .27336 Mtetra
.555 .906 .971 r
.49326 .27336 .49978 .27517 .51145 .27105 .50499 .26917 Mtetra
.557 .906 .972 r
.50499 .26917 .51145 .27105 .52317 .2669 .51676 .26494 Mtetra
.561 .906 .973 r
.51676 .26494 .52317 .2669 .53494 .26273 .52859 .26068 Mtetra
.566 .907 .975 r
.52859 .26068 .53494 .26273 .54677 .25854 .54046 .25638 Mtetra
.571 .907 .976 r
.54046 .25638 .54677 .25854 .55864 .25433 .55239 .25204 Mtetra
.578 .907 .978 r
.55239 .25204 .55864 .25433 .57056 .25009 .56437 .24765 Mtetra
.585 .907 .98 r
.56437 .24765 .57056 .25009 .58254 .24582 .5764 .2432 Mtetra
.594 .906 .983 r
.5764 .2432 .58254 .24582 .59456 .24152 .58847 .2387 Mtetra
.603 .904 .984 r
.58847 .2387 .59456 .24152 .60664 .23719 .6006 .23413 Mtetra
.613 .902 .986 r
.6006 .23413 .60664 .23719 .61877 .23282 .61278 .22949 Mtetra
.624 .899 .986 r
.61278 .22949 .61877 .23282 .63095 .22842 .62501 .22478 Mtetra
.634 .894 .986 r
.62501 .22478 .63095 .22842 .64318 .22397 .63728 .21998 Mtetra
.645 .887 .984 r
.63728 .21998 .64318 .22397 .65546 .21947 .6496 .2151 Mtetra
.656 .878 .981 r
.6496 .2151 .65546 .21947 .6678 .21493 .66197 .21012 Mtetra
.666 .868 .976 r
.66197 .21012 .6678 .21493 .68019 .21033 .67439 .20504 Mtetra
.674 .855 .969 r
.67439 .20504 .68019 .21033 .69262 .20568 .68685 .19985 Mtetra
.682 .84 .959 r
.68685 .19985 .69262 .20568 .70511 .20096 .69935 .19455 Mtetra
.687 .823 .948 r
.69935 .19455 .70511 .20096 .71765 .19618 .7119 .18915 Mtetra
.69 .804 .936 r
.7119 .18915 .71765 .19618 .73024 .19135 .7245 .18366 Mtetra
.691 .785 .923 r
.7245 .18366 .73024 .19135 .74288 .18646 .73713 .1781 Mtetra
.568 .726 .948 r
.06568 .40859 .07322 .41517 .08305 .41259 .07542 .40679 Mtetra
.562 .752 .966 r
.07542 .40679 .08305 .41259 .09293 .40995 .08521 .40491 Mtetra
.555 .778 .982 r
.08521 .40491 .09293 .40995 .10287 .40723 .09507 .40294 Mtetra
.546 .802 .993 r
.09507 .40294 .10287 .40723 .11286 .40442 .10499 .40086 Mtetra
.536 .825 .999 r
.10499 .40086 .11286 .40442 .1229 .40152 .11498 .39862 Mtetra
.522 .843 .999 r
.11498 .39862 .1229 .40152 .133 .39852 .12503 .39625 Mtetra
.506 .857 .992 r
.12503 .39625 .133 .39852 .14316 .39542 .13514 .39374 Mtetra
.488 .865 .98 r
.13514 .39374 .14316 .39542 .15336 .39224 .14532 .39109 Mtetra
.467 .868 .963 r
.14532 .39109 .15336 .39224 .16362 .38898 .15556 .38832 Mtetra
.445 .867 .942 r
.15556 .38832 .16362 .38898 .17393 .38564 .16586 .38543 Mtetra
.423 .861 .919 r
.16586 .38543 .17393 .38564 .18429 .38224 .17621 .38242 Mtetra
.402 .854 .894 r
.17621 .38242 .18429 .38224 .1947 .37877 .18663 .37932 Mtetra
.381 .844 .868 r
.18663 .37932 .1947 .37877 .20515 .37525 .19709 .37612 Mtetra
.361 .833 .843 r
.19709 .37612 .20515 .37525 .21566 .37167 .20761 .37283 Mtetra
.343 .822 .82 r
.20761 .37283 .21566 .37167 .22621 .36804 .21819 .36946 Mtetra
.327 .811 .797 r
.21819 .36946 .22621 .36804 .2368 .36437 .22881 .36601 Mtetra
.312 .8 .777 r
.22881 .36601 .2368 .36437 .24744 .36066 .23949 .36249 Mtetra
.299 .79 .758 r
.23949 .36249 .24744 .36066 .25813 .35691 .25022 .35891 Mtetra
.287 .781 .741 r
.25022 .35891 .25813 .35691 .26887 .35313 .26099 .35528 Mtetra
.276 .773 .727 r
.26099 .35528 .26887 .35313 .27965 .34932 .27182 .35159 Mtetra
.267 .765 .714 r
.27182 .35159 .27965 .34932 .29047 .34548 .28269 .34786 Mtetra
.26 .758 .702 r
.28269 .34786 .29047 .34548 .30134 .34163 .29361 .34408 Mtetra
.253 .753 .693 r
.29361 .34408 .30134 .34163 .31226 .33774 .30458 .34027 Mtetra
.248 .748 .685 r
.30458 .34027 .31226 .33774 .32322 .33384 .31559 .33642 Mtetra
.243 .744 .678 r
.31559 .33642 .32322 .33384 .33423 .32992 .32666 .33254 Mtetra
.24 .74 .673 r
.32666 .33254 .33423 .32992 .34528 .32599 .33777 .32862 Mtetra
.237 .738 .668 r
.33777 .32862 .34528 .32599 .35638 .32204 .34893 .32468 Mtetra
0 0 0 r
.34893 .32468 .35638 .32204 .36752 .31807 .36014 .32072 Mtetra
.36014 .32072 .36752 .31807 .37871 .31409 .37139 .31672 Mtetra
.37139 .31672 .37871 .31409 .38995 .31009 .38269 .3127 Mtetra
.38269 .3127 .38995 .31009 .40124 .30608 .39404 .30866 Mtetra
.39404 .30866 .40124 .30608 .41257 .30206 .40544 .30459 Mtetra
.24 .74 .668 r
.40544 .30459 .41257 .30206 .42395 .29801 .41689 .30049 Mtetra
.244 .743 .672 r
.41689 .30049 .42395 .29801 .43538 .29396 .42839 .29636 Mtetra
.249 .747 .677 r
.42839 .29636 .43538 .29396 .44686 .28988 .43994 .2922 Mtetra
.256 .753 .684 r
.43994 .2922 .44686 .28988 .45839 .28579 .45153 .28801 Mtetra
.265 .759 .692 r
.45153 .28801 .45839 .28579 .46996 .28167 .46318 .28378 Mtetra
.275 .767 .702 r
.46318 .28378 .46996 .28167 .48159 .27753 .47487 .27951 Mtetra
.287 .776 .714 r
.47487 .27951 .48159 .27753 .49326 .27336 .48662 .27519 Mtetra
.3 .787 .727 r
.48662 .27519 .49326 .27336 .50499 .26917 .49841 .27083 Mtetra
.317 .799 .743 r
.49841 .27083 .50499 .26917 .51676 .26494 .51026 .26641 Mtetra
.335 .812 .76 r
.51026 .26641 .51676 .26494 .52859 .26068 .52215 .26192 Mtetra
.356 .827 .78 r
.52215 .26192 .52859 .26068 .54046 .25638 .5341 .25738 Mtetra
.38 .842 .801 r
.5341 .25738 .54046 .25638 .55239 .25204 .54609 .25275 Mtetra
.406 .859 .824 r
.54609 .25275 .55239 .25204 .56437 .24765 .55814 .24805 Mtetra
.435 .875 .848 r
.55814 .24805 .56437 .24765 .5764 .2432 .57023 .24326 Mtetra
.466 .891 .872 r
.57023 .24326 .5764 .2432 .58847 .2387 .58236 .23837 Mtetra
.498 .906 .896 r
.58236 .23837 .58847 .2387 .6006 .23413 .59455 .23338 Mtetra
.531 .918 .919 r
.59455 .23338 .6006 .23413 .61278 .22949 .60678 .22827 Mtetra
.564 .927 .939 r
.60678 .22827 .61278 .22949 .62501 .22478 .61906 .22305 Mtetra
.596 .932 .956 r
.61906 .22305 .62501 .22478 .63728 .21998 .63138 .21769 Mtetra
.626 .931 .968 r
.63138 .21769 .63728 .21998 .6496 .2151 .64374 .2122 Mtetra
.653 .926 .974 r
.64374 .2122 .6496 .2151 .66197 .21012 .65614 .20656 Mtetra
.675 .914 .975 r
.65614 .20656 .66197 .21012 .67439 .20504 .66859 .20077 Mtetra
.693 .898 .97 r
.66859 .20077 .67439 .20504 .68685 .19985 .68107 .19482 Mtetra
.707 .877 .961 r
.68107 .19482 .68685 .19985 .69935 .19455 .69358 .18871 Mtetra
.715 .853 .948 r
.69358 .18871 .69935 .19455 .7119 .18915 .70613 .18246 Mtetra
.718 .828 .933 r
.70613 .18246 .7119 .18915 .7245 .18366 .71872 .17611 Mtetra
.718 .801 .916 r
.71872 .17611 .7245 .18366 .73713 .1781 .73134 .16968 Mtetra
.503 .702 .959 r
.05808 .40196 .06568 .40859 .07542 .40679 .0677 .40111 Mtetra
.485 .73 .979 r
.0677 .40111 .07542 .40679 .08521 .40491 .07738 .40022 Mtetra
.461 .757 .994 r
.07738 .40022 .08521 .40491 .09507 .40294 .08712 .39925 Mtetra
.43 .78 .997 r
.08712 .39925 .09507 .40294 .10499 .40086 .09693 .39817 Mtetra
.392 .794 .984 r
.09693 .39817 .10499 .40086 .11498 .39862 .10681 .39693 Mtetra
.342 .794 .95 r
.10681 .39693 .11498 .39862 .12503 .39625 .11677 .39555 Mtetra
.286 .778 .895 r
.11677 .39555 .12503 .39625 .13514 .39374 .1268 .39399 Mtetra
.223 .745 .821 r
.1268 .39399 .13514 .39374 .14532 .39109 .13691 .39228 Mtetra
.161 .7 .736 r
.13691 .39228 .14532 .39109 .15556 .38832 .14708 .3904 Mtetra
0 0 0 r
.14708 .3904 .15556 .38832 .16586 .38543 .15733 .38837 Mtetra
.15733 .38837 .16586 .38543 .17621 .38242 .16764 .38619 Mtetra
.16764 .38619 .17621 .38242 .18663 .37932 .17803 .38386 Mtetra
.036 0 0 r
.17803 .38386 .18663 .37932 .19709 .37612 .18847 .3814 Mtetra
.069 0 0 r
.18847 .3814 .19709 .37612 .20761 .37283 .19898 .3788 Mtetra
.097 0 0 r
.19898 .3788 .20761 .37283 .21819 .36946 .20956 .37607 Mtetra
.12 0 0 r
.20956 .37607 .21819 .36946 .22881 .36601 .22019 .37323 Mtetra
.139 0 0 r
.22019 .37323 .22881 .36601 .23949 .36249 .23088 .37027 Mtetra
.155 0 0 r
.23088 .37027 .23949 .36249 .25022 .35891 .24164 .3672 Mtetra
.169 0 0 r
.24164 .3672 .25022 .35891 .26099 .35528 .25245 .36403 Mtetra
.18 0 0 r
.25245 .36403 .26099 .35528 .27182 .35159 .26331 .36077 Mtetra
.189 0 0 r
.26331 .36077 .27182 .35159 .28269 .34786 .27423 .35741 Mtetra
.197 0 0 r
.27423 .35741 .28269 .34786 .29361 .34408 .28521 .35396 Mtetra
.203 0 0 r
.28521 .35396 .29361 .34408 .30458 .34027 .29624 .35043 Mtetra
.208 0 0 r
.29624 .35043 .30458 .34027 .31559 .33642 .30733 .34682 Mtetra
.212 0 0 r
.30733 .34682 .31559 .33642 .32666 .33254 .31847 .34313 Mtetra
.214 0 0 r
.31847 .34313 .32666 .33254 .33777 .32862 .32966 .33937 Mtetra
.216 0 0 r
.32966 .33937 .33777 .32862 .34893 .32468 .3409 .33554 Mtetra
.3409 .33554 .34893 .32468 .36014 .32072 .35219 .33164 Mtetra
.215 0 0 r
.35219 .33164 .36014 .32072 .37139 .31672 .36354 .32767 Mtetra
.214 0 0 r
.36354 .32767 .37139 .31672 .38269 .3127 .37494 .32364 Mtetra
.211 0 0 r
.37494 .32364 .38269 .3127 .39404 .30866 .38638 .31954 Mtetra
.207 0 0 r
.38638 .31954 .39404 .30866 .40544 .30459 .39788 .31536 Mtetra
.202 0 0 r
.39788 .31536 .40544 .30459 .41689 .30049 .40943 .31112 Mtetra
.196 0 0 r
.40943 .31112 .41689 .30049 .42839 .29636 .42103 .30681 Mtetra
.188 0 0 r
.42103 .30681 .42839 .29636 .43994 .2922 .43268 .30242 Mtetra
.178 0 0 r
.43268 .30242 .43994 .2922 .45153 .28801 .44438 .29795 Mtetra
.167 0 0 r
.44438 .29795 .45153 .28801 .46318 .28378 .45613 .2934 Mtetra
.153 0 0 r
.45613 .2934 .46318 .28378 .47487 .27951 .46793 .28876 Mtetra
.137 0 0 r
.46793 .28876 .47487 .27951 .48662 .27519 .47978 .28403 Mtetra
.117 0 0 r
.47978 .28403 .48662 .27519 .49841 .27083 .49168 .2792 Mtetra
.094 0 0 r
.49168 .2792 .49841 .27083 .51026 .26641 .50362 .27427 Mtetra
.067 0 0 r
.50362 .27427 .51026 .26641 .52215 .26192 .51561 .26923 Mtetra
.035 0 0 r
.51561 .26923 .52215 .26192 .5341 .25738 .52765 .26407 Mtetra
0 0 0 r
.52765 .26407 .5341 .25738 .54609 .25275 .53973 .25879 Mtetra
.53973 .25879 .54609 .25275 .55814 .24805 .55186 .25338 Mtetra
.55186 .25338 .55814 .24805 .57023 .24326 .56403 .24783 Mtetra
.56403 .24783 .57023 .24326 .58236 .23837 .57624 .24214 Mtetra
.57624 .24214 .58236 .23837 .59455 .23338 .5885 .2363 Mtetra
.313 .774 .638 r
.5885 .2363 .59455 .23338 .60678 .22827 .60079 .2303 Mtetra
.397 .839 .722 r
.60079 .2303 .60678 .22827 .61906 .22305 .61312 .22414 Mtetra
.482 .895 .801 r
.61312 .22414 .61906 .22305 .63138 .21769 .62549 .21781 Mtetra
.561 .936 .868 r
.62549 .21781 .63138 .21769 .64374 .2122 .63789 .2113 Mtetra
.629 .957 .917 r
.63789 .2113 .64374 .2122 .65614 .20656 .65032 .20461 Mtetra
.681 .959 .945 r
.65032 .20461 .65614 .20656 .66859 .20077 .66278 .19773 Mtetra
.717 .944 .956 r
.66278 .19773 .66859 .20077 .68107 .19482 .67527 .19068 Mtetra
.739 .917 .953 r
.67527 .19068 .68107 .19482 .69358 .18871 .68778 .18347 Mtetra
.75 .885 .941 r
.68778 .18347 .69358 .18871 .70613 .18246 .70033 .17612 Mtetra
.752 .851 .924 r
.70033 .17612 .70613 .18246 .71872 .17611 .7129 .16868 Mtetra
.749 .817 .906 r
.7129 .16868 .71872 .17611 .73134 .16968 .7255 .16118 Mtetra
.45 .68 .963 r
.05043 .39529 .05808 .40196 .0677 .40111 .05996 .39511 Mtetra
.431 .697 .976 r
.05996 .39511 .0677 .40111 .07738 .40022 .06955 .39492 Mtetra
.41 .714 .986 r
.06955 .39492 .07738 .40022 .08712 .39925 .07921 .39468 Mtetra
.386 .73 .99 r
.07921 .39468 .08712 .39925 .09693 .39817 .08893 .39436 Mtetra
.361 .745 .988 r
.08893 .39436 .09693 .39817 .10681 .39693 .09874 .39392 Mtetra
.329 .754 .974 r
.09874 .39392 .10681 .39693 .11677 .39555 .10861 .39333 Mtetra
.294 .756 .948 r
.10861 .39333 .11677 .39555 .1268 .39399 .11857 .39257 Mtetra
.254 .748 .909 r
.11857 .39257 .1268 .39399 .13691 .39228 .12861 .39165 Mtetra
.21 .73 .857 r
.12861 .39165 .13691 .39228 .14708 .3904 .13873 .39056 Mtetra
.164 .703 .796 r
.13873 .39056 .14708 .3904 .15733 .38837 .14893 .38929 Mtetra
.119 .669 .728 r
.14893 .38929 .15733 .38837 .16764 .38619 .1592 .38786 Mtetra
0 0 0 r
.1592 .38786 .16764 .38619 .17803 .38386 .16954 .38626 Mtetra
.16954 .38626 .17803 .38386 .18847 .3814 .17996 .3845 Mtetra
.17996 .3845 .18847 .3814 .19898 .3788 .19045 .38257 Mtetra
.027 0 0 r
.19045 .38257 .19898 .3788 .20956 .37607 .20102 .38048 Mtetra
.053 0 0 r
.20102 .38048 .20956 .37607 .22019 .37323 .21165 .37824 Mtetra
.075 0 0 r
.21165 .37824 .22019 .37323 .23088 .37027 .22235 .37585 Mtetra
.093 0 0 r
.22235 .37585 .23088 .37027 .24164 .3672 .23312 .37331 Mtetra
.109 0 0 r
.23312 .37331 .24164 .3672 .25245 .36403 .24395 .37063 Mtetra
.122 0 0 r
.24395 .37063 .25245 .36403 .26331 .36077 .25485 .3678 Mtetra
.132 0 0 r
.25485 .3678 .26331 .36077 .27423 .35741 .26581 .36484 Mtetra
.141 0 0 r
.26581 .36484 .27423 .35741 .28521 .35396 .27683 .36175 Mtetra
.147 0 0 r
.27683 .36175 .28521 .35396 .29624 .35043 .28792 .35853 Mtetra
.152 0 0 r
.28792 .35853 .29624 .35043 .30733 .34682 .29906 .35519 Mtetra
.155 0 0 r
.29906 .35519 .30733 .34682 .31847 .34313 .31026 .35172 Mtetra
.156 0 0 r
.31026 .35172 .31847 .34313 .32966 .33937 .32153 .34813 Mtetra
.32153 .34813 .32966 .33937 .3409 .33554 .33284 .34443 Mtetra
.155 0 0 r
.33284 .34443 .3409 .33554 .35219 .33164 .34422 .34061 Mtetra
.152 0 0 r
.34422 .34061 .35219 .33164 .36354 .32767 .35565 .33667 Mtetra
.147 0 0 r
.35565 .33667 .36354 .32767 .37494 .32364 .36713 .33262 Mtetra
.141 0 0 r
.36713 .33262 .37494 .32364 .38638 .31954 .37867 .32845 Mtetra
.133 0 0 r
.37867 .32845 .38638 .31954 .39788 .31536 .39027 .32416 Mtetra
.123 0 0 r
.39027 .32416 .39788 .31536 .40943 .31112 .40191 .31976 Mtetra
.11 0 0 r
.40191 .31976 .40943 .31112 .42103 .30681 .41361 .31523 Mtetra
.096 0 0 r
.41361 .31523 .42103 .30681 .43268 .30242 .42536 .31059 Mtetra
.079 0 0 r
.42536 .31059 .43268 .30242 .44438 .29795 .43716 .30581 Mtetra
.058 0 0 r
.43716 .30581 .44438 .29795 .45613 .2934 .44901 .30091 Mtetra
.034 0 0 r
.44901 .30091 .45613 .2934 .46793 .28876 .46091 .29587 Mtetra
.006 0 0 r
.46091 .29587 .46793 .28876 .47978 .28403 .47285 .29069 Mtetra
0 0 0 r
.47285 .29069 .47978 .28403 .49168 .2792 .48484 .28537 Mtetra
.48484 .28537 .49168 .2792 .50362 .27427 .49688 .2799 Mtetra
.49688 .2799 .50362 .27427 .51561 .26923 .50896 .27428 Mtetra
.50896 .27428 .51561 .26923 .52765 .26407 .52109 .2685 Mtetra
.52109 .2685 .52765 .26407 .53973 .25879 .53326 .26255 Mtetra
.53326 .26255 .53973 .25879 .55186 .25338 .54546 .25644 Mtetra
.341 .793 .65 r
.54546 .25644 .55186 .25338 .56403 .24783 .55771 .25016 Mtetra
.411 .846 .717 r
.55771 .25016 .56403 .24783 .57624 .24214 .56999 .2437 Mtetra
.482 .893 .781 r
.56999 .2437 .57624 .24214 .5885 .2363 .58231 .23706 Mtetra
.55 .93 .837 r
.58231 .23706 .5885 .2363 .60079 .2303 .59466 .23023 Mtetra
.611 .955 .883 r
.59466 .23023 .60079 .2303 .61312 .22414 .60704 .22322 Mtetra
.662 .967 .917 r
.60704 .22322 .61312 .22414 .62549 .21781 .61945 .21603 Mtetra
.703 .966 .937 r
.61945 .21603 .62549 .21781 .63789 .2113 .63189 .20864 Mtetra
.733 .955 .946 r
.63189 .20864 .63789 .2113 .65032 .20461 .64435 .20106 Mtetra
.754 .936 .945 r
.64435 .20106 .65032 .20461 .66278 .19773 .65684 .1933 Mtetra
.766 .913 .939 r
.65684 .1933 .66278 .19773 .67527 .19068 .66935 .18537 Mtetra
.772 .888 .928 r
.66935 .18537 .67527 .19068 .68778 .18347 .68188 .1773 Mtetra
.773 .862 .916 r
.68188 .1773 .68778 .18347 .70033 .17612 .69443 .16912 Mtetra
.77 .836 .903 r
.69443 .16912 .70033 .17612 .7129 .16868 .70701 .16088 Mtetra
.766 .813 .89 r
.70701 .16088 .7129 .16868 .7255 .16118 .71961 .15261 Mtetra
.471 .689 .962 r
.04273 .38856 .05043 .39529 .05996 .39511 .05231 .38809 Mtetra
.476 .682 .956 r
.05231 .38809 .05996 .39511 .06955 .39492 .06194 .38763 Mtetra
.482 .676 .95 r
.06194 .38763 .06955 .39492 .07921 .39468 .07164 .38714 Mtetra
.49 .672 .945 r
.07164 .38714 .07921 .39468 .08893 .39436 .0814 .38661 Mtetra
.497 .669 .94 r
.0814 .38661 .08893 .39436 .09874 .39392 .09124 .386 Mtetra
.505 .668 .936 r
.09124 .386 .09874 .39392 .10861 .39333 .10114 .38529 Mtetra
.514 .668 .932 r
.10114 .38529 .10861 .39333 .11857 .39257 .11112 .38446 Mtetra
.521 .67 .93 r
.11112 .38446 .11857 .39257 .12861 .39165 .12117 .38351 Mtetra
.529 .673 .929 r
.12117 .38351 .12861 .39165 .13873 .39056 .13129 .38242 Mtetra
.536 .677 .929 r
.13129 .38242 .13873 .39056 .14893 .38929 .1415 .3812 Mtetra
.543 .682 .929 r
.1415 .3812 .14893 .38929 .1592 .38786 .15177 .37984 Mtetra
.549 .687 .93 r
.15177 .37984 .1592 .38786 .16954 .38626 .16212 .37835 Mtetra
.555 .694 .932 r
.16212 .37835 .16954 .38626 .17996 .3845 .17254 .37671 Mtetra
.561 .701 .934 r
.17254 .37671 .17996 .3845 .19045 .38257 .18303 .37493 Mtetra
.566 .708 .937 r
.18303 .37493 .19045 .38257 .20102 .38048 .19359 .37301 Mtetra
.572 .716 .94 r
.19359 .37301 .20102 .38048 .21165 .37824 .20422 .37094 Mtetra
.577 .725 .943 r
.20422 .37094 .21165 .37824 .22235 .37585 .21492 .36873 Mtetra
.583 .733 .947 r
.21492 .36873 .22235 .37585 .23312 .37331 .22569 .36638 Mtetra
.588 .742 .95 r
.22569 .36638 .23312 .37331 .24395 .37063 .23653 .36388 Mtetra
.593 .751 .953 r
.23653 .36388 .24395 .37063 .25485 .3678 .24744 .36123 Mtetra
.598 .759 .956 r
.24744 .36123 .25485 .3678 .26581 .36484 .25841 .35845 Mtetra
.603 .768 .958 r
.25841 .35845 .26581 .36484 .27683 .36175 .26945 .35551 Mtetra
.608 .776 .961 r
.26945 .35551 .27683 .36175 .28792 .35853 .28055 .35244 Mtetra
.613 .783 .963 r
.28055 .35244 .28792 .35853 .29906 .35519 .29171 .34922 Mtetra
.619 .79 .964 r
.29171 .34922 .29906 .35519 .31026 .35172 .30294 .34585 Mtetra
.624 .796 .965 r
.30294 .34585 .31026 .35172 .32153 .34813 .31423 .34234 Mtetra
.629 .801 .965 r
.31423 .34234 .32153 .34813 .33284 .34443 .32557 .33869 Mtetra
.635 .806 .965 r
.32557 .33869 .33284 .34443 .34422 .34061 .33698 .3349 Mtetra
.64 .809 .964 r
.33698 .3349 .34422 .34061 .35565 .33667 .34844 .33096 Mtetra
.646 .812 .963 r
.34844 .33096 .35565 .33667 .36713 .33262 .35997 .32687 Mtetra
.652 .814 .961 r
.35997 .32687 .36713 .33262 .37867 .32845 .37155 .32265 Mtetra
.658 .815 .959 r
.37155 .32265 .37867 .32845 .39027 .32416 .38318 .31827 Mtetra
.663 .814 .956 r
.38318 .31827 .39027 .32416 .40191 .31976 .39487 .31375 Mtetra
.669 .813 .952 r
.39487 .31375 .40191 .31976 .41361 .31523 .40661 .30909 Mtetra
.674 .811 .948 r
.40661 .30909 .41361 .31523 .42536 .31059 .4184 .30427 Mtetra
.68 .808 .944 r
.4184 .30427 .42536 .31059 .43716 .30581 .43024 .29931 Mtetra
.685 .805 .939 r
.43024 .29931 .43716 .30581 .44901 .30091 .44213 .29419 Mtetra
.69 .801 .934 r
.44213 .29419 .44901 .30091 .46091 .29587 .45408 .28893 Mtetra
.694 .796 .928 r
.45408 .28893 .46091 .29587 .47285 .29069 .46606 .28352 Mtetra
.698 .791 .922 r
.46606 .28352 .47285 .29069 .48484 .28537 .4781 .27795 Mtetra
.702 .786 .916 r
.4781 .27795 .48484 .28537 .49688 .2799 .49018 .27222 Mtetra
.705 .78 .91 r
.49018 .27222 .49688 .2799 .50896 .27428 .5023 .26635 Mtetra
.708 .775 .904 r
.5023 .26635 .50896 .27428 .52109 .2685 .51446 .26031 Mtetra
.711 .77 .898 r
.51446 .26031 .52109 .2685 .53326 .26255 .52667 .25413 Mtetra
.714 .765 .892 r
.52667 .25413 .53326 .26255 .54546 .25644 .53891 .24778 Mtetra
.717 .761 .887 r
.53891 .24778 .54546 .25644 .55771 .25016 .55119 .24128 Mtetra
.719 .757 .882 r
.55119 .24128 .55771 .25016 .56999 .2437 .56351 .23462 Mtetra
.722 .753 .878 r
.56351 .23462 .56999 .2437 .58231 .23706 .57587 .22781 Mtetra
.724 .751 .873 r
.57587 .22781 .58231 .23706 .59466 .23023 .58825 .22084 Mtetra
.727 .749 .87 r
.58825 .22084 .59466 .23023 .60704 .22322 .60067 .21372 Mtetra
.729 .748 .867 r
.60067 .21372 .60704 .22322 .61945 .21603 .61312 .20645 Mtetra
.732 .748 .865 r
.61312 .20645 .61945 .21603 .63189 .20864 .62559 .19902 Mtetra
.735 .749 .864 r
.62559 .19902 .63189 .20864 .64435 .20106 .6381 .19145 Mtetra
.738 .752 .863 r
.6381 .19145 .64435 .20106 .65684 .1933 .65063 .18375 Mtetra
.741 .755 .864 r
.65063 .18375 .65684 .1933 .66935 .18537 .66318 .17592 Mtetra
.744 .76 .865 r
.66318 .17592 .66935 .18537 .68188 .1773 .67577 .16801 Mtetra
.747 .766 .868 r
.67577 .16801 .68188 .1773 .69443 .16912 .68837 .16002 Mtetra
.749 .773 .872 r
.68837 .16002 .69443 .16912 .70701 .16088 .70101 .152 Mtetra
.751 .78 .877 r
.70101 .152 .70701 .16088 .71961 .15261 .71368 .14397 Mtetra
.532 .713 .955 r
.03496 .38178 .04273 .38856 .05231 .38809 .04468 .38045 Mtetra
.541 .689 .935 r
.04468 .38045 .05231 .38809 .06194 .38763 .05445 .37913 Mtetra
.547 .666 .915 r
.05445 .37913 .06194 .38763 .07164 .38714 .06428 .3778 Mtetra
.552 .645 .895 r
.06428 .3778 .07164 .38714 .0814 .38661 .07415 .37646 Mtetra
.556 .627 .877 r
.07415 .37646 .0814 .38661 .09124 .386 .08409 .37508 Mtetra
.559 .611 .861 r
.08409 .37508 .09124 .386 .10114 .38529 .09409 .37367 Mtetra
.562 .597 .847 r
.09409 .37367 .10114 .38529 .11112 .38446 .10415 .37218 Mtetra
.564 .586 .834 r
.10415 .37218 .11112 .38446 .12117 .38351 .11428 .37063 Mtetra
.567 .577 .823 r
.11428 .37063 .12117 .38351 .13129 .38242 .12446 .369 Mtetra
.569 .569 .814 r
.12446 .369 .13129 .38242 .1415 .3812 .13472 .36729 Mtetra
.571 .563 .806 r
.13472 .36729 .1415 .3812 .15177 .37984 .14504 .36549 Mtetra
.573 .558 .799 r
.14504 .36549 .15177 .37984 .16212 .37835 .15542 .3636 Mtetra
.575 .554 .793 r
.15542 .3636 .16212 .37835 .17254 .37671 .16587 .36161 Mtetra
.577 .55 .788 r
.16587 .36161 .17254 .37671 .18303 .37493 .17639 .35953 Mtetra
.579 .548 .784 r
.17639 .35953 .18303 .37493 .19359 .37301 .18697 .35734 Mtetra
.581 .546 .78 r
.18697 .35734 .19359 .37301 .20422 .37094 .19762 .35505 Mtetra
.583 .545 .777 r
.19762 .35505 .20422 .37094 .21492 .36873 .20833 .35264 Mtetra
.586 .544 .775 r
.20833 .35264 .21492 .36873 .22569 .36638 .21911 .35012 Mtetra
.588 .544 .773 r
.21911 .35012 .22569 .36638 .23653 .36388 .22995 .34748 Mtetra
.59 .544 .771 r
.22995 .34748 .23653 .36388 .24744 .36123 .24086 .34472 Mtetra
.593 .544 .77 r
.24086 .34472 .24744 .36123 .25841 .35845 .25183 .34183 Mtetra
.596 .545 .768 r
.25183 .34183 .25841 .35845 .26945 .35551 .26286 .33882 Mtetra
.598 .546 .767 r
.26286 .33882 .26945 .35551 .28055 .35244 .27396 .33567 Mtetra
.601 .547 .767 r
.27396 .33567 .28055 .35244 .29171 .34922 .28512 .33239 Mtetra
.604 .549 .766 r
.28512 .33239 .29171 .34922 .30294 .34585 .29634 .32897 Mtetra
.606 .55 .765 r
.29634 .32897 .30294 .34585 .31423 .34234 .30762 .32542 Mtetra
.609 .551 .765 r
.30762 .32542 .31423 .34234 .32557 .33869 .31897 .32172 Mtetra
.612 .553 .764 r
.31897 .32172 .32557 .33869 .33698 .3349 .33037 .31788 Mtetra
.615 .554 .764 r
.33037 .31788 .33698 .3349 .34844 .33096 .34183 .3139 Mtetra
.617 .556 .763 r
.34183 .3139 .34844 .33096 .35997 .32687 .35335 .30978 Mtetra
.62 .557 .762 r
.35335 .30978 .35997 .32687 .37155 .32265 .36493 .30551 Mtetra
.623 .559 .762 r
.36493 .30551 .37155 .32265 .38318 .31827 .37656 .3011 Mtetra
.625 .56 .761 r
.37656 .3011 .38318 .31827 .39487 .31375 .38824 .29654 Mtetra
.628 .562 .761 r
.38824 .29654 .39487 .31375 .40661 .30909 .39998 .29184 Mtetra
.63 .563 .76 r
.39998 .29184 .40661 .30909 .4184 .30427 .41177 .287 Mtetra
.633 .565 .76 r
.41177 .287 .4184 .30427 .43024 .29931 .42361 .28201 Mtetra
.635 .566 .76 r
.42361 .28201 .43024 .29931 .44213 .29419 .43551 .27689 Mtetra
.638 .568 .76 r
.43551 .27689 .44213 .29419 .45408 .28893 .44745 .27163 Mtetra
.64 .569 .759 r
.44745 .27163 .45408 .28893 .46606 .28352 .45943 .26623 Mtetra
.642 .571 .76 r
.45943 .26623 .46606 .28352 .4781 .27795 .47147 .2607 Mtetra
.645 .574 .76 r
.47147 .2607 .4781 .27795 .49018 .27222 .48355 .25504 Mtetra
.647 .576 .761 r
.48355 .25504 .49018 .27222 .5023 .26635 .49567 .24925 Mtetra
.65 .579 .762 r
.49567 .24925 .5023 .26635 .51446 .26031 .50783 .24334 Mtetra
.653 .582 .763 r
.50783 .24334 .51446 .26031 .52667 .25413 .52004 .2373 Mtetra
.656 .586 .765 r
.52004 .2373 .52667 .25413 .53891 .24778 .53229 .23115 Mtetra
.659 .59 .767 r
.53229 .23115 .53891 .24778 .55119 .24128 .54458 .22488 Mtetra
.662 .595 .77 r
.54458 .22488 .55119 .24128 .56351 .23462 .55691 .2185 Mtetra
.665 .601 .773 r
.55691 .2185 .56351 .23462 .57587 .22781 .56928 .21202 Mtetra
.669 .607 .777 r
.56928 .21202 .57587 .22781 .58825 .22084 .58168 .20543 Mtetra
.673 .615 .782 r
.58168 .20543 .58825 .22084 .60067 .21372 .59412 .19874 Mtetra
.678 .624 .787 r
.59412 .19874 .60067 .21372 .61312 .20645 .6066 .19195 Mtetra
.683 .634 .794 r
.6066 .19195 .61312 .20645 .62559 .19902 .61911 .18507 Mtetra
.688 .645 .801 r
.61911 .18507 .62559 .19902 .6381 .19145 .63166 .1781 Mtetra
.694 .658 .81 r
.63166 .1781 .6381 .19145 .65063 .18375 .64424 .17106 Mtetra
.7 .673 .821 r
.64424 .17106 .65063 .18375 .66318 .17592 .65686 .16396 Mtetra
.706 .69 .832 r
.65686 .16396 .66318 .17592 .67577 .16801 .66951 .15682 Mtetra
.713 .71 .846 r
.66951 .15682 .67577 .16801 .68837 .16002 .6822 .14965 Mtetra
.719 .732 .861 r
.6822 .14965 .68837 .16002 .70101 .152 .69493 .14245 Mtetra
.725 .755 .876 r
.69493 .14245 .70101 .152 .71368 .14397 .70769 .13525 Mtetra
.603 .737 .939 r
.02714 .37496 .03496 .38178 .04468 .38045 .03706 .3724 Mtetra
.605 .701 .911 r
.03706 .3724 .04468 .38045 .05445 .37913 .04702 .36984 Mtetra
.605 .668 .884 r
.04702 .36984 .05445 .37913 .06428 .3778 .05703 .36728 Mtetra
.603 .638 .859 r
.05703 .36728 .06428 .3778 .07415 .37646 .06708 .36473 Mtetra
.6 .612 .836 r
.06708 .36473 .07415 .37646 .08409 .37508 .07719 .36217 Mtetra
.597 .59 .815 r
.07719 .36217 .08409 .37508 .09409 .37367 .08734 .3596 Mtetra
.594 .571 .797 r
.08734 .3596 .09409 .37367 .10415 .37218 .09754 .35702 Mtetra
.592 .554 .781 r
.09754 .35702 .10415 .37218 .11428 .37063 .10779 .35442 Mtetra
.589 .54 .767 r
.10779 .35442 .11428 .37063 .12446 .369 .11809 .35178 Mtetra
.587 .527 .755 r
.11809 .35178 .12446 .369 .13472 .36729 .12845 .34911 Mtetra
.585 .517 .744 r
.12845 .34911 .13472 .36729 .14504 .36549 .13886 .3464 Mtetra
.583 .507 .735 r
.13886 .3464 .14504 .36549 .15542 .3636 .14932 .34364 Mtetra
.582 .499 .727 r
.14932 .34364 .15542 .3636 .16587 .36161 .15984 .34085 Mtetra
.581 .492 .719 r
.15984 .34085 .16587 .36161 .17639 .35953 .17042 .338 Mtetra
.58 .486 .713 r
.17042 .338 .17639 .35953 .18697 .35734 .18105 .3351 Mtetra
.579 .481 .707 r
.18105 .3351 .18697 .35734 .19762 .35505 .19173 .33213 Mtetra
.578 .476 .702 r
.19173 .33213 .19762 .35505 .20833 .35264 .20248 .32911 Mtetra
.578 .473 .698 r
.20248 .32911 .20833 .35264 .21911 .35012 .21328 .32602 Mtetra
.578 .469 .694 r
.21328 .32602 .21911 .35012 .22995 .34748 .22413 .32286 Mtetra
.578 .466 .69 r
.22413 .32286 .22995 .34748 .24086 .34472 .23505 .31962 Mtetra
.578 .464 .687 r
.23505 .31962 .24086 .34472 .25183 .34183 .24602 .3163 Mtetra
.578 .462 .685 r
.24602 .3163 .25183 .34183 .26286 .33882 .25705 .31289 Mtetra
.579 .461 .682 r
.25705 .31289 .26286 .33882 .27396 .33567 .26813 .3094 Mtetra
.579 .459 .68 r
.26813 .3094 .27396 .33567 .28512 .33239 .27928 .30582 Mtetra
.58 .459 .679 r
.27928 .30582 .28512 .33239 .29634 .32897 .29048 .30214 Mtetra
.581 .458 .677 r
.29048 .30214 .29634 .32897 .30762 .32542 .30173 .29837 Mtetra
.582 .458 .676 r
.30173 .29837 .30762 .32542 .31897 .32172 .31305 .2945 Mtetra
.583 .458 .676 r
.31305 .2945 .31897 .32172 .33037 .31788 .32441 .29053 Mtetra
.584 .458 .675 r
.32441 .29053 .33037 .31788 .34183 .3139 .33584 .28646 Mtetra
.585 .459 .675 r
.33584 .28646 .34183 .3139 .35335 .30978 .34732 .28228 Mtetra
.586 .459 .675 r
.34732 .28228 .35335 .30978 .36493 .30551 .35885 .278 Mtetra
.587 .46 .675 r
.35885 .278 .36493 .30551 .37656 .3011 .37044 .27363 Mtetra
.589 .462 .675 r
.37044 .27363 .37656 .3011 .38824 .29654 .38208 .26914 Mtetra
.59 .463 .676 r
.38208 .26914 .38824 .29654 .39998 .29184 .39377 .26456 Mtetra
.592 .465 .677 r
.39377 .26456 .39998 .29184 .41177 .287 .40551 .25988 Mtetra
.593 .467 .678 r
.40551 .25988 .41177 .287 .42361 .28201 .41731 .25511 Mtetra
.595 .47 .679 r
.41731 .25511 .42361 .28201 .43551 .27689 .42915 .25023 Mtetra
.597 .472 .681 r
.42915 .25023 .43551 .27689 .44745 .27163 .44105 .24527 Mtetra
.599 .475 .683 r
.44105 .24527 .44745 .27163 .45943 .26623 .45299 .24021 Mtetra
.601 .479 .685 r
.45299 .24021 .45943 .26623 .47147 .2607 .46498 .23507 Mtetra
.603 .483 .688 r
.46498 .23507 .47147 .2607 .48355 .25504 .47702 .22985 Mtetra
.606 .487 .691 r
.47702 .22985 .48355 .25504 .49567 .24925 .48911 .22455 Mtetra
.608 .491 .695 r
.48911 .22455 .49567 .24925 .50783 .24334 .50124 .21918 Mtetra
.611 .497 .699 r
.50124 .21918 .50783 .24334 .52004 .2373 .51343 .21373 Mtetra
.614 .502 .703 r
.51343 .21373 .52004 .2373 .53229 .23115 .52565 .20822 Mtetra
.617 .509 .708 r
.52565 .20822 .53229 .23115 .54458 .22488 .53793 .20265 Mtetra
.62 .516 .714 r
.53793 .20265 .54458 .22488 .55691 .2185 .55024 .19702 Mtetra
.624 .524 .721 r
.55024 .19702 .55691 .2185 .56928 .21202 .56261 .19133 Mtetra
.628 .534 .728 r
.56261 .19133 .56928 .21202 .58168 .20543 .57502 .18559 Mtetra
.632 .544 .737 r
.57502 .18559 .58168 .20543 .59412 .19874 .58747 .17981 Mtetra
.637 .556 .746 r
.58747 .17981 .59412 .19874 .6066 .19195 .59997 .17398 Mtetra
.642 .569 .757 r
.59997 .17398 .6066 .19195 .61911 .18507 .61252 .16811 Mtetra
.648 .584 .769 r
.61252 .16811 .61911 .18507 .63166 .1781 .62511 .16221 Mtetra
.654 .601 .783 r
.62511 .16221 .63166 .1781 .64424 .17106 .63775 .15629 Mtetra
.661 .621 .799 r
.63775 .15629 .64424 .17106 .65686 .16396 .65043 .15034 Mtetra
.668 .644 .817 r
.65043 .15034 .65686 .16396 .66951 .15682 .66317 .14438 Mtetra
.675 .669 .837 r
.66317 .14438 .66951 .15682 .6822 .14965 .67595 .13842 Mtetra
.682 .699 .859 r
.67595 .13842 .6822 .14965 .69493 .14245 .68878 .13245 Mtetra
.689 .731 .883 r
.68878 .13245 .69493 .14245 .70769 .13525 .70165 .12647 Mtetra
.665 .754 .916 r
.01926 .36808 .02714 .37496 .03706 .3724 .02941 .36411 Mtetra
.66 .713 .887 r
.02941 .36411 .03706 .3724 .04702 .36984 .0396 .36012 Mtetra
.654 .676 .859 r
.0396 .36012 .04702 .36984 .05703 .36728 .04983 .35613 Mtetra
.647 .644 .833 r
.04983 .35613 .05703 .36728 .06708 .36473 .0601 .35214 Mtetra
.639 .615 .81 r
.0601 .35214 .06708 .36473 .07719 .36217 .07041 .34813 Mtetra
.632 .59 .788 r
.07041 .34813 .07719 .36217 .08734 .3596 .08076 .34412 Mtetra
.625 .567 .769 r
.08076 .34412 .08734 .3596 .09754 .35702 .09114 .34009 Mtetra
.619 .548 .752 r
.09114 .34009 .09754 .35702 .10779 .35442 .10157 .33606 Mtetra
.613 .53 .737 r
.10157 .33606 .10779 .35442 .11809 .35178 .11204 .33203 Mtetra
.608 .515 .724 r
.11204 .33203 .11809 .35178 .12845 .34911 .12255 .32798 Mtetra
.603 .502 .712 r
.12255 .32798 .12845 .34911 .13886 .3464 .1331 .32392 Mtetra
.598 .49 .701 r
.1331 .32392 .13886 .3464 .14932 .34364 .14369 .31986 Mtetra
.594 .479 .692 r
.14369 .31986 .14932 .34364 .15984 .34085 .15433 .31579 Mtetra
.591 .47 .684 r
.15433 .31579 .15984 .34085 .17042 .338 .165 .31171 Mtetra
.587 .462 .676 r
.165 .31171 .17042 .338 .18105 .3351 .17572 .30762 Mtetra
.585 .454 .669 r
.17572 .30762 .18105 .3351 .19173 .33213 .18649 .30352 Mtetra
.582 .448 .663 r
.18649 .30352 .19173 .33213 .20248 .32911 .19729 .29941 Mtetra
.579 .442 .658 r
.19729 .29941 .20248 .32911 .21328 .32602 .20814 .2953 Mtetra
.577 .436 .653 r
.20814 .2953 .21328 .32602 .22413 .32286 .21904 .29117 Mtetra
.575 .432 .649 r
.21904 .29117 .22413 .32286 .23505 .31962 .22998 .28704 Mtetra
.574 .428 .645 r
.22998 .28704 .23505 .31962 .24602 .3163 .24096 .2829 Mtetra
.572 .424 .642 r
.24096 .2829 .24602 .3163 .25705 .31289 .25199 .27874 Mtetra
.571 .421 .639 r
.25199 .27874 .25705 .31289 .26813 .3094 .26306 .27458 Mtetra
.569 .418 .636 r
.26306 .27458 .26813 .3094 .27928 .30582 .27418 .27041 Mtetra
.568 .416 .634 r
.27418 .27041 .27928 .30582 .29048 .30214 .28535 .26623 Mtetra
.568 .414 .633 r
.28535 .26623 .29048 .30214 .30173 .29837 .29656 .26204 Mtetra
.567 .412 .631 r
.29656 .26204 .30173 .29837 .31305 .2945 .30782 .25783 Mtetra
.566 .411 .63 r
.30782 .25783 .31305 .2945 .32441 .29053 .31913 .25362 Mtetra
.31913 .25362 .32441 .29053 .33584 .28646 .33049 .2494 Mtetra
.566 .41 .629 r
.33049 .2494 .33584 .28646 .34732 .28228 .34189 .24517 Mtetra
.34189 .24517 .34732 .28228 .35885 .278 .35335 .24093 Mtetra
.566 .41 .63 r
.35335 .24093 .35885 .278 .37044 .27363 .36485 .23668 Mtetra
.566 .411 .63 r
.36485 .23668 .37044 .27363 .38208 .26914 .3764 .23242 Mtetra
.566 .412 .631 r
.3764 .23242 .38208 .26914 .39377 .26456 .388 .22815 Mtetra
.567 .413 .633 r
.388 .22815 .39377 .26456 .40551 .25988 .39965 .22386 Mtetra
.567 .415 .634 r
.39965 .22386 .40551 .25988 .41731 .25511 .41135 .21957 Mtetra
.568 .417 .636 r
.41135 .21957 .41731 .25511 .42915 .25023 .42311 .21526 Mtetra
.569 .42 .639 r
.42311 .21526 .42915 .25023 .44105 .24527 .43491 .21095 Mtetra
.57 .423 .642 r
.43491 .21095 .44105 .24527 .45299 .24021 .44677 .20662 Mtetra
.572 .426 .645 r
.44677 .20662 .45299 .24021 .46498 .23507 .45868 .20229 Mtetra
.573 .43 .649 r
.45868 .20229 .46498 .23507 .47702 .22985 .47064 .19794 Mtetra
.575 .435 .653 r
.47064 .19794 .47702 .22985 .48911 .22455 .48266 .19358 Mtetra
.577 .44 .658 r
.48266 .19358 .48911 .22455 .50124 .21918 .49473 .18921 Mtetra
.579 .445 .663 r
.49473 .18921 .50124 .21918 .51343 .21373 .50685 .18482 Mtetra
.581 .452 .669 r
.50685 .18482 .51343 .21373 .52565 .20822 .51903 .18043 Mtetra
.584 .459 .676 r
.51903 .18043 .52565 .20822 .53793 .20265 .53127 .17602 Mtetra
.587 .467 .684 r
.53127 .17602 .53793 .20265 .55024 .19702 .54356 .1716 Mtetra
.59 .477 .692 r
.54356 .1716 .55024 .19702 .56261 .19133 .5559 .16717 Mtetra
.593 .487 .702 r
.5559 .16717 .56261 .19133 .57502 .18559 .5683 .16273 Mtetra
.597 .498 .713 r
.5683 .16273 .57502 .18559 .58747 .17981 .58077 .15827 Mtetra
.602 .512 .725 r
.58077 .15827 .58747 .17981 .59997 .17398 .59328 .15381 Mtetra
.606 .527 .738 r
.59328 .15381 .59997 .17398 .61252 .16811 .60586 .14933 Mtetra
.611 .544 .754 r
.60586 .14933 .61252 .16811 .62511 .16221 .61849 .14483 Mtetra
.617 .563 .771 r
.61849 .14483 .62511 .16221 .63775 .15629 .63119 .14033 Mtetra
.623 .585 .791 r
.63119 .14033 .63775 .15629 .65043 .15034 .64394 .13581 Mtetra
.629 .61 .812 r
.64394 .13581 .65043 .15034 .66317 .14438 .65676 .13128 Mtetra
.635 .639 .837 r
.65676 .13128 .66317 .14438 .67595 .13842 .66963 .12674 Mtetra
.641 .671 .863 r
.66963 .12674 .67595 .13842 .68878 .13245 .68257 .12218 Mtetra
.645 .707 .892 r
.68257 .12218 .68878 .13245 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Rooooo`;oYKCT00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`1Aooooo`00H?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B47ooooo`03o`000?oooooooooo01gooooo0ol00002ooooo`03o`000?oooooooooo05cooooo0_nT
Zm`4ojFdi003o`000?nU]>Cooooo01Gooooo00?o0000ooooooooool0D?ooool0063ooooo00Go410@
oooooooooooooooooa0@400;ooooo`Go00007?ooool2o`00067ooooo00?oXZ?FojB[g?nTZm`00onT
Zm`3ojFdi003o`000?n`^n;ooooo01Cooooo00?o0000ooooool00000DOooool0063ooooo00Go0000
ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001[ooooo0ol0001Qooooo`CoXZ?F
1OnTZm`00onU]>Co/;_Ro`000002ok2khQKooooo00?o0000ooooooooool0Coooool0063ooooo00Go
0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0001Sooooo0_l0001Qooooo`;o
XIc?1OnRXmH4ojB[g004ojjbfon`^n;o/;_Ro`0000?o/;_R5_ooool00ol0003oooooooooo`1>oooo
o`00H?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000005Oooool3o`00
00;ooooo00?o0000ooooooooool0F_ooool00onOUL[oXIc?oj6Lc`04oj6Lc`GoXZ?F00?oY:_Lojjb
fon^/]/00_n^/]/01On`^n;o0000ok2kh_n`^n;o^L7P01Kooooo00?o0000ooooooooool0C_ooool0
063ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000001?ooooo0_l0001P
ooooo`CoWiG:1OnQW<l4oj:SeP03ojb[e_n^/]_o[[;K00Co[[;K00?o0000okW1h?ni`N000_ni`N0F
ooooo`03o`000?oooooooooo04gooooo001Pooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`0?ooooo`?o0000Goooool2oif@a@KoWiG:1OnQW<l00onRXmKo[:_Fojb[eP02
ojb[ePCo[[;K00?o^;_Lo`000?ni`N001?ni`N0Fooooo`03o`000?oooooooooo04cooooo0022oooo
o`;o0000Goooool00onLRl7oWI35oif@a@03oif@a@GoWiG:1?nQW<l00on[Y=7o[:_Fojb[eP03ojb[
eP?o[[;K0_nh^m`00ol0003o^L7PokW1h002okW1h003ol37h?oooooooooo01Cooooo00?o0000oooo
ooooool0C?ooool007oooooo0ol00002ooooo`03o`000?oooooooooo05[ooooo1?nLRl45oif@a@Go
WiG:00?oXIc?oj^TdOn[Y=400_n[Y=45ojb[eP07ojjbfonh^mco^;_LokRkg?l0003o^;_LokW1h004
ol37h1Cooooo0ol0001=ooooo`00O?ooool3o`0005oooooo0_nKQ[`5oib;`@GoWI351?nOULX00onY
W/coZjCAoj^Td@03oj^Td@Co[:_F00?o][GHokRkg?nh^m`00_nh^m`00ol0003o_lGOol37h004ol37
h1Oooooo00?o0000ooooooooool0B_ooool007[ooooo0_l0001Nooooo`;oVX>i1OnKQ[`5oib;`@Go
WI3500?oWiG:ojVNc?nYW/`00_nYW/`5oj^Td@03ojb[e_nf]MSo][GH00;o][GH0onh^m`00onoaMoo
0000oko5g`03ol37h0;oa=3S5_ooool00ol0003oooooooooo`1:ooooo`00Moooool3o`0005gooooo
00?oV7nfoiZ3^OnJPkT00onJPkT4oi^6_0GoW8_11?nMT<D00onWVLSoZIk<ojVNc003ojVNc0CoZjCA
00?o];3DokJef?nf]MP01?nf]MP01_nh^mco_lGOoko5gol0003o_lGOol37h0Goa=3S5_ooool00ol0
003oooooooooo`19ooooo`00MOooool2o`0000;ooooo00?o0000ooooooooool0FOooool4oiQo]PCo
VX>i1OnKQ[`5oib;`@03oif@aOnWVLSoYiW800;oYiW81OnYW/`00on[Y=7o];3DokB`e002okB`e0Co
][GH00Ko_lCNoko5gonoaMoo_lGOo`000?o5e^L5olC@h`03okoAiooooooooooo01Gooooo00?o0000
ooooooooool0B?ooool007;ooooo0ol00005ooooo`03o`000?oooooooooo05Kooooo00?oUgbcoiQo
]_nHOkH00onHOkH5oiZ3^@CoVhJl1?nLRl400onUULCoYiW8ojNIb003ojNIb0CoZIk<00?o/jcBokB`
e?nd/=@00ond/=@3okJef0?o_lCN0_noaMl00ol0003oaMKWolGFi`03olC@h`?o_m7W5_ooool00ol0
003oooooooooo`18ooooo`00L?ooool2o`0005kooooo00?oUgZaoiMl/onGO;<00_nGO;<5oiQo]PCo
VX>i1OnKQ[`00onLRl7oYIG4ojFEa002ojFEa0CoYiW80onYW/`3ok>/dPGo];3D00?o][GHoko4g_no
a=h00_noa=h00onoaMooaMKWo`000003olGFi`03olC@honodNOo_m7W00?o_m7W5_ooool00ol0003o
ooooooooo`17ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go
00008?ooool3o`0005kooooo0onGN[44oiMl/`GoV7nf1OnJPkT2oi^6_0;oY9711OnUUL@5ojNIb003
ojVNc?nc[=;o/jcB00;o/jcB1?nd/=@00onn`]go_lCNoko4gP03oko4gP03olGLj_o5e^Oo000000;o
aMKW0_o0fN`4okoAi`03okO=j_oooooooooo01?ooooo0ol00018ooooo`00>?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@07_ooool2o`00
00?ooooo00?o0000ooooooooool0F?ooool2oiIg[`GoUgZa1?nGO;<4oiQo]PCoVX>i00?oXhjnojBA
`OnTTL400onTTL44ojFEa0CoYiW800?o/JS?ok>/d_nc[=801?nc[=800ond/=Co_/;Mokk2g@02okk2
g@?o_lCN0oo5g>X00ol0003o`=W/ol3Ik003ol3Ik003okoAiongcN[o]lgZ00;o]lgZ5_ooool00ol0
003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l00000
0ol@413oooooooooo`0Yooooo`00>?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RH
ob4Q8Oo^k^h07?ooool3o`0005gooooo00?oUGF]oiIg[onFMjl00_nFMjl5oiMj/@CoUgbc1OnHOkH0
0onJPkWoXhjnoj>>_P02oj>>_PCoY9711OnUUL@00onWVLSo/JS?ok6Xc`02ok6Xc`Co/jcB00?o_L7M
okk2gOnn`]d01?nn`]d01_noa=koaMcZolGLj_o5g>[o_n;`o`0000Co`=W/00?o]m?^okO=j_ngcNX0
1?ngcNXFooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1oooool00ol0003oooooooooo`0Zooooo`00>?ooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h06?ooool3o`0005kooooo0onEMJd5oiIg[`CoUgZa1?nGO;<4oiQo]P03
oj6;_?nSS[koXhjn00?oXhjn1?nTTL44ojFEa003ok2UcOnaZ<oo/JS?00?o/JS?0onc[=83okg1g@Co
_/;M0_o5hnd01oo5g>[o_n;`okoRl?noh_3o0000okoRl?o0fN`01?ngdnh4okO=jP;o/<S/5_ooool0
0ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0002_ooooo000h
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Eooooo`?o0000GOoo
ool2oiAcZ`GoUGF]1?nFMjl4oiMj/@GoUgbc00?oV7nfoj6;_?nQRk`00_nQRk`4oj>>_PGoY97100?o
YIG4ok2UcOn`YLd00_n`YLd5ok6Xc`03ok>/d_nm`Mgo_L7M00?o_L7M00Co_/;MolGSkOo5hngoaN?]
0_nmj_<3okoRl003o`000?ngf_;o]m[b00Go]m?^00?o]lgZok38k?n`b>`00on`b>`Eooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`00
02cooooo000hooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Aoooo
o`?o00000oooool00ol0003oooooooooo`1Fooooo`;oU76Y1?nDLj/5oiEe[@CoUWN_1OnGN[43oiMl
/`03oj28^_nQRkcoXH^l00?oXH^l1OnSS[h3ojBA`@03ojjRbon`YLgo/:G=00?o/:G=1?naZ<l00onl
`=co_L7Mokg1g@03okg1g@04olCYl?o5hngoaN?]olGSk@Co_N[c00?o_n;`okOJl_l000000ongf_82
okOCkP?o/<g_1?n`b>`00on[`ncoooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002cooooo000hooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@017ooooo0_l0001Looooo`03
oi=`Z?nDLJWoU76Y00;oU76Y1OnDLj/4oiEe[@CoUWN_1OnGN[400onGO;?oX8Rjoj28^P02oj28^PCo
XH^l1OnSS[h00onTTL7o[Z;;ojjRb`02ojjRb`Go/:G=00?o/JS?okc0g?nl`=`00_nl`=`3okg1g@?o
a>W`00?oaN?]okgZlonmj_<00_nmj_<2okCPmP05okOJl_l0003o]m[bokOJl_n_d_801_n`cNl00on`
b>coZl?/oj_3k002oj_3k1Kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oMgMgolc<c?l00000;?ooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03_ooool3o`0005cooooo0onCL:P5oiAaZ@CoU7>[1?nE
MJd5oiIg[`?oUgZa00?oWhJhoj28^_nPR;X00onPR;X5oj6;_0?oXhjn00?o[Io9ojjRbon^X//00on^
X//4ok2Uc@03okbogOnl`=co_<3L00Co_<3L00Co_L7MolCYl?o4jO3oa>W`0onglO@00onmj_?o]>3f
okCPmP03okCPmP03o`000?n_d_;o[m;b00;o[m;b1?n`cNl00on[aNgoZl?/oj_3k004oj_3k1Cooooo
0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000/ooooo`00
FOooool3o`0005cooooo00?oTfnWoi=`Z?nCL:P00onCL:P4oiAaZ@CoU7>[1?nEMJd5oiIg[`04oiMj
/OnOQ[SoWhJhoin6^0GoX8Rj1OnQRk`00onSS[ko[Io9ojfOb@02ojfOb@Go[Z;;00?o/:G=okbogOnl
_md00_nl_md4okc0g0;o`Noa00?oa>W`okOam?nglO@00_nglO@2ok7Un0Co]>3f00?o[]Oeo`000?n_
d_801?n_d_800on`cNooZlG]oj_5k@02oj_5k@CoZl?/00?oZ<7[ooooooooool04Oooool01?l0003o
ooooooooool00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0[
ooooo`00E_ooool3o`0000?ooooo00?o0000ooooooooool0EOooool2oi9^YP?oTfnW1OnCL:P4oiAa
Z@CoU7>[1OnEMJd3oiIg[`03oij4]_nOQ[SoWhJh00?oWhJh1OnPR;X3oj6;_003ojbMb?n]WlWo[Io9
00?o[Io91?n^X//00onk_mgo_;oMokbog@04okbog@04okc0g?o1ko7o`Noaol7_l@?o[_Ga00?o]o7d
ok7Un?naiOP00onaiOP01_ndh?Ko[]OeojkGmOn^eoGo0000ojkGm@;o[m;b0onZanh5oj_5k@03oj_3
k?nX`N_oZ<7[00;oZ<7[5_ooool00ol0003oooooooooo`10ooooo`00E?ooool2o`0005_ooooo00?o
TVfUoi9^Y_nBKZH00_nBKZH4oi=_Y`CoTg2X1?nDLJT5oiAcZ`CoUGF]00CoUWN_oij4]_nNQ;KoWXBf
1OnOQ[P5oj28^P03oj6;_?n/WLSo[9g800;o[9g81?n]WlT3ojjRb`?o^koM1?nl_md2ok_dlP03ol7_
lOn^mO7o[_Ga00;o[_Ga0on/jOT2ok7Un0?o[=[h0on^eoD00ol0003oZ/S`oj[8l005oj[7kP;oZlG]
0_nX`^`5ojS1jaKooooo00?o0000ooooooooool0@?ooool0057ooooo0ol0001Kooooo`?oTVfU1OnB
KZH3oi=_Y`CoTg2X1?nDLJT5oiAcZ`;oUGF]0_nMP[D5oij4]PCoWhJh1?nPR;X00on[VlKo[9g8ojbM
b003ojbMb0Go[Io900?o[Z;;ok^ogOnk_md00onk_md01?nl_mgo^oCbok_dl_nkm?83oj7djP03ojke
lOn/jOWo[>Wi00;o[>Wi0_nZg_T5ojcJn003ojkGmOnZb?3o000000?oZ/S`0_nZanh7ojS2k0;oZ<7[
0onX`>/Fooooo`03o`000?oooooooooo03oooooo001>ooooo`Go0000FOooool2oi5/Y0CoTVfU1OnB
KZH3oi=_Y`CoTg2X1OnDLJT3oiAcZ`03oif0/onMP[GoWH:e00;oWH:e1OnNQ;H5oin6^0;oX8Rj0on[
VlH4ojbMb0Co[Io900?o^[oMok^ogOnk_md00onk_md3ok?gk`04ok_dl_nQm>[oXOCZoj7djP?oYngi
00?o[>Wioj[NnOnZg_T00onZg_T2ojcJn0?oZL[a00GoZ/S`o`000?nZb?3oZ/S`ojS3k@07ojS2k0;o
Z<7[1_nX`>/Fooooo`03o`000?oooooooooo03kooooo001<ooooo`;o00001Oooool00ol0003ooooo
ooooo`1Cooooo`03oi5[XonAK:CoTFbT00;oTFbT1OnBKJD4oi9^YP?oTfnW1OnCL:P4oiAaZ@04oiAc
ZonMP;?oWH2coif0/`GoWH:e1?nNQ;H5oin6^003oj28^_n[VlKoZi_600;oZi_61On/WLP00on]WlWo
^[oMokZog@02okZog@?o^koM0oncmnl2oho_gP03oj7dj_nWkOWoYngi00;oYngi0onWh?/2oj[Nn@?o
ZL_b1OnYb_400ol0003oZ<?]ojS3k@02ojS3k@?oZ<;/00?oZ<7/ojS1jonX`N/00onX`N/4ojS0j`03
ojO0jooooooooooo01Cooooo00?o0000ooooooooool0?_ooool004Wooooo0ol0001Kooooo`?oTF^S
1OnAK:@4oi9]Y@CoTVjV0onCKjL5oi=`Z0?oU76Y00?oW7nboif0/onMP;<00onMP;<4oif2]@GoWXBf
0onOQ[P00onZVLGoZi_6oj^KaP03oj^KaPCo[9g800?o^[oNokZogOnj_md01?nj_md00onk_mgo/oO_
ok?gk`02oho_gPCoX>kg00?oYngiojOPnonWh?/00_nWh?/00onXc?;oZL_bojW;lP04ojW;lP;oZL[a
0onX`nd00ol0003oZ<?]ojS3k@02ojS3k@04ojS2k?nX`NcoZ<7/ojS1k0GoZ<7[00?oZ<3[ojO0jonW
`>/00_nW`>/Dooooo`?o0000?oooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Pooooo`;o
0000G?ooool00onAJZ;oTF^Soi5[X`02oi5[X`GoTFbT1?nBKJD4oi9^YPCoTfnW1?nCL:P01?nDLJWo
W7nboiao/_nLOk85oif0/`CoWH:e1OnNQ;H00onOQ[SoZYW5ojZIa@02ojZIa@GoZi_600?o[9g8okZo
g_nj_mh00_nj_mh4okZog@;oZOOZ00CoNnG=oiS^m?nHk_CoV>kd0_nPk_L4ojGSn`03ojOPnonXc?;o
Z<cb00;oZ<cb1?nYbo86ojS3k@03o`000?nX`ngoZ<?]00;oYl7/1OnX`N`2ojS1j`SoYl3[5Oooool0
0ol0003oooooooooo`0mooooo`008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo0ol00002
ooooo`03o`000?oooooooooo05Gooooo1OnAJZ85oi5[X`CoTFbT1?nBKJD5oi9^YP?oTfnW0onCL:P0
0onKOK7oW7nboiao/P03oiao/PCoWH2c1OnMP[D3oij4]P03ojVHaOnZVLGoZYW500?oZYW51?n[VlH0
0oni`=oo^[oNokZogP04okZogP03okZogOnYmn[oZOOZ00;oNnG=0onHk_@3oj;To0;oYN?k0onXcO<5
ojS<lP03ojW;l_nX`ngoZ<?]00KoZ<?]00?o0000ojO1k?nW`N`00onW`N`2ojS1k0goYl3[5Oooool0
0ol0003oooooooooo`0looooo`008_ooool01Ol@413ooooooooooooooooo410@01_ooooo0_l0001J
ooooo`03oi5YX_nAJZ;oTFZR00GoTFZR1OnAJj<4oi5/Y0CoTVfU1OnBKZH3oi=_Y`04oi=`Z?nKOK7o
Vgfaoi]m/@GoW7nb1?nMP;<5oif2]@03oij4]_nYV<GoZIS500;oZIS51?nZVLD3oj^KaP?o^L3O1?nj
_mh2oicdhP;oIMJh0_n@kO000onHk_CoX^Cloj;To002oj;To0;oZ<kd1OnXcO<2ojS<lPWoZ<?]0_nW
`N`00ol0003oYl7/ojO1k002ojO1k17oYl3[5Oooool00ol0003oooooooooo`0kooooo`008_ooool0
1Ol0003ooooooooooooooooo000001Sooooo0ol0001Jooooo`?oTFVR2?nAJZ84oi5[X`CoTFbT1OnB
KJD4oi9^YP;oTfnW00?oVgb`oi]m/OnKOK400onKOK44oiao/PGoWH2c0onMP[D00onXUlCoZIS5ojVH
a@03ojVHa@GoZYW500?oZi_6okW0goni`=l00oni`=l00onj_mkoW?CRoicdhP02ofGF^0?oT>g`0onO
i_`00onRi?coZ<kdojS>m003ojS>m0;oZ<gc0onW`nd7ojS3k@GoYl7/00?o0000ojO1k?nW`N`04onW
`>/Eooooo`03o`000?oooooooooo03_ooooo000Rooooo`05o`000?ooooooooooooooool000005_oo
ool3o`0005[ooooo00?oT6VQoi5YX_nAJJ800_nAJJ88oi5ZXPCoTF^S1OnAK:@4oi9]Y@?oTVjV00Co
VW^`oi]l/?nKO;3oVgb`1OnKOK44oiao/PGoWH2c00?oWH:eojRGa?nXUl@00_nXUl@4ojVHa@CoZYW5
0_nh`>04okW0g`;oS>kF00CoD<JSohO[jon7jn_oQn_[0_nLi_`2oioVo0?oYlkd1?nXc_@7ojO3k@;o
Z<?]2OnW`N`00ol0003oYl3[ojO0j`0DojO0jaGooooo00?o0000ooooooooool0>_ooool002;ooooo
00Go410@oooooooooooooooooa0@400Cooooo`?o00000_ooool00ol0003oooooooooo`1Dooooo`Go
T6VQ1OnAJJ87oi5ZXPCoTF^S1OnAK:@4oi9]Y@04oi9^Y_nJNk3oVW^`oiYk/0CoVgb`1?nKOK45oiao
/P?oWH2c00?oYiK3ojRGa?nXUl@00onXUl@5ojVHa@03ojZIaOnh`>3o^<3P00?o^<3P00?o^L3Oohc^
e_n<k]H00omoinD01?n7jn_oW>KloicVo?nLi_`2ojO?m@GoYlkd00?oZ<kdojO3kOnW`nd01_nW`nd9
ojO1k004ojNojonW`>_oYl3[o`0001KoYl3[5_ooool00ol0003oooooooooo`0iooooo`008_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg013ooooo0ol0001Iooooo`03oi1XXOn@JJ7oT6VQ00GoT6VQ1OnA
JJ87oi5ZXPGoTF^S1?nAK:@2oi9]Y@;oVGZ_1OnJNk03oi]l/0GoVgfa1?nLOk800onMP;?oYiK3ojNF
``02ojNF``CoZ9O41?nYV<D00onh`N7o^<3PokS0h003okS0h0;oNnC70omoinD4oi[Wn`03oicVo?nW
coGoYloe00;oYloe0_nWc_@9ojO3k@[oYl7/0onW_n/00onW`>_o0000ojO0j`0FojO0jaCooooo0_l0
000kooooo`008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo0_l0001Jooooo`?oT6RQ2?n@
JJ44oi5YXPOoTFZR1OnAJj<3oi5/Y003oiUi[_nINZooVGZ_00;oVGZ_1OnJNk03oi]l/0GoVgfa0_nL
Ok82ojND``GoYiK31OnXUl@00onYV<Go^<7QokS1h@02okS1h@?o^<3P00?oNnC7ogOTgonHio/00onH
io/2oi[Wn`KoYloe2OnW`nd:ojO1k0OoYko[00?o0000ojO0jonW`>/05_nW`>/Eooooo`03o`000?oo
oooooooo03Sooooo000booooo`Go0000F?ooool5oi1XX@SoT6VQ1?nAJJ88oi5ZXPCoTF^S00CoTFbT
oiUi[_nINJkoVGV^1OnINZl4oiYk/0CoVgb`0onKOK400onVU<?oYiC3ojND``03ojND``CoYiK31?nX
Ul@00ong`^?o^<7QokS1h@04okS1h@04okS0h?nEj?[oUNSjoiGXnP;oV>Ok0onVcoD4ojO?m@SoYl?]
2_nW`N`9ojNoj`03ojO0jol0003o000001SoYl3[5_ooool00ol0003oooooooooo`0gooooo`00<?oo
ool2o`0005Wooooo2_n@J:47oi1YX@CoTFVR2?nAJZ83oi5[X`03oiQh[_nINJkoVGV^00?oVGV^1?nI
NZl4oiYk/0CoVgb`00?oVgfaojJD`onVU<<00_nVU<<4ojND``GoYiK300?oZ9O4okO2hong`^<00_ng
`^<4okS1h@CoUNSj0_nVd?H5ojK?m@03ojO?mOnW`ngoYl?]00GoYl?]2_nW`N`9ojNoj`06ojO0jol0
003o0000o`000?nW`>_o00006OnW`>/Eooooo`03o`000?oooooooooo03Oooooo000]ooooo`?o0000
F?ooool00on@JJ7oT6RQoi1XX@0:oi1XX@OoT6VQ1?nAJJ88oi5ZXP04oi5[XonHN:koV7R^oiQh[PGo
VGV^1?nINZl5oiYk/0;oVgb`00?oYI?2ojJD`onVU<<00onVU<<4ojND``CoYiK300?o]/?TokO2hong
`^<01?ng`^<01Onh`N7oTnSjoi?Xn_nCj?[oUNSj00GoY]3f0_nVcoD8ojO3k@[oYl7/2?nW_n/01?nW
`>_o0000o`000?l00005ojO0j`03o`000?nW`>_oYl3[01OoYl3[5Oooool00ol0003oooooooooo`0f
ooooo`00;?ooool2o`0005Sooooo0on@JJ4<oi1XX@OoT6VQ1OnAJJ86oi5ZXP03oiQh[OnHN:koV7R^
00?oV7R^1?nINJh4oiUj[`GoVW^`00CoVgb`ojFC`_nUTl;oYI?21?nVU<<5ojND``03ojNF`onf`nCo
]/?T00;o]/?T1?ng`^<00onBj?WoTnSjoi?XnP06ojK@mP[oYl?]2OnW`N`9ojNoj`?o00002OnW`>/0
0ol0003oYl3[ojO0j`0GojO0jaGooooo00?o0000ooooooooool0=Oooool002cooooo0ol0001Eoooo
o`GoT6VQ3?n@J:48oi1YX@CoTFVR0onAJZ801?nGMjgoV7R]oiQh[OnHN:d5oiQh[PCoVGV^1OnINZl3
oiYk/003ojFB`_nUTl;oYI?200;oYI?21OnVU<<3ojND``03okK5iOnf`nCo]/?T00Co]/?T00?o]l;S
oi;XnOnBj?T01_nVd?H9ojO3k@WoYl7/2_nW_n/3o`0000goYl3[00?o0000ojO0jonW`>/05onW`>/D
ooooo`03o`000?oooooooooo03Gooooo000/ooooo`04o`000?oooooo0000o`00053ooooo0_nAJJ48
oi1YX@_oT6RQ2?n@JJ44oi5YXP04oi5ZX_nGMjgoUgN]oiMg[@CoV7R]1?nHN:h4oiUi[PGoVGZ_00?o
VW^`ojFB`_nUT/800_nUT/84ojFC`PCoYYC300?oYiC3okK5iOnfaND00_nfaND4okK3i003oi3XnOnV
d?KoY]3f00GoY]3f2?nW`nd9ojO1k0WoYko[00CoYl3[o`000?l0003o00004?nW`>/00ol0003oYl3[
ojO0j`0GojO0ja?ooooo00?o0000ooooool000002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`06Oooool002cooooo0_l00002ooooo`03
o`000?oooooooooo04[ooooo00?oTFVRoi5YXOnAJJ400_nAJJ48oi1YX@_oT6RQ2?n@JJ42oi5YXPOo
UgN]0onHN:d4oiQh[PGoVGV^0onINZl00onTT/;oYI;2ojFB`P03ojFB`PCoYI?20onVU<<3okG6i`Co
]/GU00?o]/?Toi3XnOnVd?H01_nVd?H8ojO3k@[oYl7/1onW_n/01?nW`>_o0000o`000?l0000DojO0
j`03o`000?nW`>_oYl3[01OoYl3[5Oooool00ol0003oooooooooo`05ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0Iooooo`00:oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Sooooo0_nAJJ84oi5YX@SoT6VQ3?n@J:46
oi1YX@03oiMf[OnGMjgoUgN]00OoUgN]0onHN:d5oiQh[PCoVGV^00?oVGZ_ojBB`_nTT/800_nTT/84
ojFB`PGoYI?200?oYYC3okG6ionea^L00onea^L2okK5i@KoY]3f0onW`^d6ojO3k@[oYl7/2?nW_n/0
0onW`>_o0000o`00000HojO0j`03o`000?nW`>_oYl3[01KoYl3[5Oooool00ol0003oooooooooo`05
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001Wooooo
000[ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0A?ooool2oi5ZXP?oTFVR1OnA
JJ47oi1YX@coT6RQ1?n@JJ43oiMf[@WoUgN]0onHN:d5oiQh[P;oVGV^0_nSTL85ojBB`PGoYI;20onU
Tl82okC7j0Co]LKW1_nVd?H7ojO2k@;oYl?]2OnW`N`9ojNoj`04ojO0jol0003o0000o`0001[oYl3[
00?o0000ojO0jonW`>/05onW`>/Eooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B406Oooool002_ooooo0ol00005ooooo`03
o`000?oooooooooo043ooooo00?oTF^Roi5ZX_nAJZ800_nAJZ84oi5YXPCoTFVQ1on@JJ4<oi1XX@;o
T6VQ00?oUWJ/oiMf[OnGMZd00onGMZd8oiMg[@CoV7R]0onHN:h6oj>A`PCoY9;21OnUT/800onUTl;o
]<OXokC7j003okC7j003okG6ionVd?KoY]3f00CoY]3f2?nW`^d8ojO1k0[oYko[00CoYl3[o`000?l0
003o00007_nW`>/00ol0003oYl3[ojO0j`0GojO0jaGooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Iooooo`00:oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo03cooooo00CoTV^Soi5[X_nAJj;oTF^R1?nA
JZ84oi5YXPCoTFVQ1on@JJ4:oi1XX@;oUWF/0onFMZ`5oiMf[@SoUgN]1?nHN:d00onHN:koXi72oj>A
`P06oj>A`PGoY9;20_nUT/83ok?9jPCo]<OX1OnVd?H9ojO2k@OoYl7/2_nW_n/01?nW`>_o0000o`00
0?l0000RojO0j`03o`000?nW`>_oYl3[01KoYl3[5Oooool00ol0003oooooooooo`03ooooo`05oa0@
4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Kooooo`00:oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo03Wooooo0onBJj<3oi5[XPCoTFZR1?nAJJ84oi5YX@SoT6VQ
1_n@J:45oiIe[0CoUWJ/1?nGMZd9oiMg[@;oV7R]00?oXY32oj>A`_nSTL801onSTL84ojBB`P03ok;:
k?ncbN[o/lWZ00Co/lWZ00?o]<OXojK@m_nVd?H00_nVd?H9ojO2k@WoYl7/2OnW_n/3o`0002KoYl3[
00?o0000ojO0jonW`>/05_nW`>/Cooooo`?o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00?ogMgMoa0@4?nHV9P06oooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0fooooo`03oi9/Y?nBJj?oTV^S00;oTV^S1?nAJj83oi5ZXPCoTFVR1?nAJJ48oi1YX@Co
T6RQ2?nFMJ`3oiIf[0CoUgJ]2OnGMjd01?nHN:goXY32oj:@`_nRT<89oj>A`P03ojBB`_nbb^co//[/
00;o//[/1?ncbNX3ojK@mPSoYl;]2_nW`N`9ojNoj`?o0000:OnW`>/00ol0003oYl3[ojO0j`0GojO0
jaGooooo00Wo0000ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4
o`000?l@410Iooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03
o`000?oooooooooo00Cooooo0ol0000:ooooo`03o`000?oooooooooo037ooooo0_nBKJD3oi9/Y0Co
TV^S1?nAJj84oi5ZXP?oTFVR1?nAJJ48oi1YX@;oT6RQ00?oUGF/oiIe[?nFMJ`01onFMJ`3oiIf[0Co
UgJ]1onGMjd6oj:@`PSoXi720_nabnd5ok;:k004ok?9j_nVd?KoY]3fojK@mPOoYl;]2OnW`N`:ojNo
j`?o0000;OnW`>/00ol0003oYl3[ojO0j`0FojO0jaGooooo00?o0000ooooooooool0;oooool000So
oooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0]ooooo`03oi=^Y_nBKJGoTVfU00;oTVfU0onBK:@4oi9[
X`CoTF^R1?nAJZ83oi5YXPGoTFVQ1On@JJ45oiEe[0WoUWF/0onFMZ`5oiMf[@?oUgN]00?oXI32oj:@
`_nRT<801_nRT<86oj>A`PGo/L_]0_nbb^`3ojK@mPWoYl;]1onW`N`:ojNoj`03ojO0jol0003o0000
037oYl3[00?o0000ojO0jonW`>/05_nW`>/Eooooo`03o`000?oooooooooo02kooooo000@ooooo`05
o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00006ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0:oooool2oi=^YPCoTVfU1?nBK:@4oi9[X`?oTF^R1?nAJZ84
oi5YXPCoTFVQ0_n@JJ400onEMJgoUGF/oiEe[006oiEe[0SoUWF/1?nFMZ`4oiMf[@03oiMg[OnQT<;o
XI3200;oXI322?nRT<83oj>A`P;o/<g_1?nabnd3ojK@mPWoYl;]2?nW`N`:ojNoj`?o0000<onW`>/0
0ol0003oYl3[ojO0j`0GojO0jaGooooo00?o0000ooooooooool0;Oooool0013ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Wooooo`;oTfnW0onCKZH4oi9]Y@CoTVbT1?nBJj<3oi5[XPCoTFZR1?nA
JJ84oi5YX@03oi1YXOnEMJgoUGF]00SoUGF/2?nFMJ`4oiIf[0;oUgJ]0_nPSl85oj6@`PSoXY3200?o
Xi72ok3=kon`cNl00on`cNl00onabngoY]3fojO2k@08ojO2k@[oYl7/2OnW_n/3o`0003OoYl3[00?o
0000ojO0jonW`>/05onW`>/Dooooo`03o`000?oooooooooo02gooooo000@ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`;o00003oooool2o`0002Cooooo00?o
U76Xoi=_YonCKjL00_nCKjL4oi=^YP?oTVfU1?nBK:@4oi9[X`CoTF^R0onAJZ84oi5YXP;oTFVQ0_nD
MJd4oiEe[@OoUGF/2OnFMJ`2oiIf[003oin?`_nPSl;oX8o200?oX8o21?nQT<87oj:@`P?o[lk`0on`
cNl00onW`^coYl;]ojO2k@06ojO2k@WoYl7/2OnW_n/01?nW`>_o0000o`000?l0000kojO0j`03o`00
0?nW`>_oYl3[01KoYl3[5Oooool00ol0003oooooooooo`0/ooooo`004?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo01kooooo00CoU7:YoiAaZ?nDLJSoU76X1?nCKjL4oi=^YPCoTVfU0onBK:@4oi9[X`Co
TF^R0onAJZ82oi5YXPKoU7F]1?nEMJd7oiEe[0WoUWF/00CoUWJ/oin?`_nOSl;oWho21?nPSl85oj6@
`P?oXY320_n^c_45ojo>l004ok3=konW`^coYl;/ojO2k0CoYl;]2OnW`N`9ojNoj`04ojO0jol0003o
0000o`0003ooYl3[00?o0000ojO0jonW`>/05_nW`>/Cooooo`;o0000;_ooool0013ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Kooooo`?oU7:Y1?nDLJP3oi=_Y`CoTfjV1?nBKJD3oi9/Y0CoTV^S1?nA
Jj82oi5ZXPWoU7F]1?nEMJd7oiEe[0OoUWF/0_nOSl<4oin?`PCoX8o21OnQT<800onRT<;o[/kaojk>
l@03ojk>l@;o[lk`1onW`^`00onW`^goYl7/ojO1k008ojO1k0OoYko[00CoYl3[o`000?l0003o0000
@_nW`>/00ol0003oYl3[ojO0j`0FojO0jaGooooo00?o0000ooooooooool0:oooool002Wooooo0_l0
000Dooooo`03o`000?oooooooooo01Sooooo00?oUGB[oiAbZOnDLZT00_nDLZT4oiAaZ0?oTfnW1?nC
KZH4oi9]Y@CoTVbT0onBJj<2oi5[XP;oU7F^2onDMJd4oiEe[@SoUGF/0onFMJ`00onNS/?oWho3oin?
``03oin?``?oWho21OnPSl82oj6@`P?o[<ob1?n^c_49ojO2k0WoYl7/2?nW_n/3o`0004KoYl3[00?o
0000ojO0jonW`>/05_nW`>/Eooooo`03o`000?oooooooooo02[ooooo000Yooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool05?ooool01?nFMZgoUGB[oiEdZonEM:/4oiAbZ@CoU76X1?nC
KjL3oi=^YPCoTVfU1?nBK:@2oi9[X`03oiAf[_nDMJkoU7F^00;oU7F^3?nDMJd3oiEe[@SoUGF/00?o
UWF/oij>`onNS/<00_nNS/<4oin?``CoWho20onPSl82oj_@l`Go[<ob00?o[/kaojO2k?nW`^`01OnW
`^`9ojO1k0[oYko[0_l0001:ojO0j`03o`000?nW`>_oYl3[01KoYl3[5?ooool00ol0003ooooooooo
o`0Zooooo`00:Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00oooooo0_nGN:l3
oiIf[@CoUGB[0onDLZT4oiAaZ0CoTfnW1?nCKZH3oi9]Y@CoTVbT00?oTV^SoiAf[_nDMZh01OnDMJh;
oiAe[@CoUGF]1_nEMJ`00onMS/?oWXk3oij>``03oij>``CoWho31?nOSl800onPSl;oZm3coj_@l`03
oj_@l`;o[<ob1onW`^`9ojO1k0WoYko[00CoYl3[o`000?l0003o0000COnW`>/00ol0003oYl3[ojO0
j`0FojO0jaCooooo00?o0000ooooooooool0:Oooool002Wooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0;ooooo`03oiQj/OnGN:ooUgR_00;oUgR_1?nFMZd3oiEdZ`CoU7:Y0onDLJP4
oi=_Y`CoTfjV0onBKJD2oi9/Y0;oTgJ_1?nDMZh4oiAe[P_oU7F]1?nEMJd2oiEe[0;oWHg31?nMS/<4
oij>``GoWho30_nOSl83ojW@m0?oZm3c2?nW`^`8ojO1k0SoYko[0_nW`>/3o`00053oYl3[00?o0000
ojO0jonW`>/05onW`>/Dooooo`03o`000?oooooooooo02Sooooo000Yooooo`?o00005oooool00ol0
003oooooooooo`09ooooo`;oV7Za1?nGN:l4oiIf[@?oUGB[1?nDLZT4oiAaZ0?oTfnW1?nCKZH2oi9]
Y@GoTgJ_1?nDMZh4oiAe[P_oU7F]0_nEMJd2oib=``GoWHg30onMS/<5oij>``?oWho30_nXd?D5ojW@
m003oj_@lonW`^coYl;/00GoYl;/2?nW`N`7ojNoj`;oYl3[0ol0001DojO0j`03o`000?nW`>_oYl3[
01KoYl3[4oooool2o`0002[ooooo000Yooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool01Oooool2oiUm/`CoV7Za0onGN:l4oiIf[@?oUGB[1?nDLZT4oiAaZ0?oTfnW0_nCKZH2oi=g/0So
TgJ_0onDMZh4oiAe[P[oU7F]00?oVhg3oib=`onLSL<00onLSL<4oif=``?oWHk31OnNS/<00onOSl?o
Z=3eojS@m@03ojS@m@;oZM3d1_nW`^`:ojO1k0SoYko[0ol0001HojO0j`03o`000?nW`>_oYl3[01Ko
Yl3[5?ooool00ol0003oooooooooo`0Wooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go00001Oooool00ol0003oooooooooo`0Jooooo`05o`000?oooooooooooooo
oonJP;H01?nIOK<4oiQj/@CoUgR_0onFMZd3oiEdZ`CoU7:Y1?nDLJP2oi=_Y`03oi=h/OnCMk3oTgN`
00;oTgN`2?nCMZl3oiAf[PCoU7F^1onDMJd00onKS<?oVhg3oi^=``02oi^=``CoW8g31?nMSL<4oif>
``;oWXk31?nVd?H2ojS@m@OoYl;/2OnW`N`9ojNoj`?o0000FonW`>/00ol0003oYl3[ojO0j`0FojO0
jaGooooo00?o0000ooooooooool09_ooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000ooooooooool06oooool0
1?nKPkWoVX2foiZ0]_nJP;H5oiUm/`?oV7Za1?nGN:l3oiIf[@CoUGB[0onDLZT2oiAaZ0;oTgVb0onC
N;45oi=g/0OoTgJ_0onDMZh5oiAe[PCoU7F]1?nKS<<3oi^=``CoW8g31OnMSL<2oif>``?oYLof0onV
d?H7ojO2k0SoYl7/2_nW_n/3o`0005ooYl3[00?o0000ojO0jonW`>/05_nW`>/Dooooo`03o`000?oo
oooooooo02Kooooo0006ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h01_ooool2o`0001_ooooo0_nKPkT4oiZ0]PCoVGfc0onHN[44oiMh[`CoUWJ]0onE
M:/2oiAbZ@03oi=i/onCNK;oTgVb00;oTgVb1?nCN;44oi=g/0OoTgJ_1?nDMZh4oiAe[P;oU7F]00?o
VXc4oi^<`onKS<<00onKS<<4oi^=``CoW8g30onMSL<2oj??mPGoYLof00?oY]3fojO2k?nW`^`01?nW
`^`7ojO1k0WoYko[0_nW`>/2o`0006?oYl3[00?o0000ojO0jonW`>/05_nW`>/Dooooo`03o`000?oo
oooooooo02Gooooo000>ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP05ooooo`03o`000?oooooooooo01Oooooo0_nLQk`4oi^3^@?oVX2f1?nIOK<4oiQj/@?oUgR_1?nF
MZd2oiEdZ`04oiAk]?nCNK?oTgVcoi=i/`GoTgVb0onCN;44oi=g/0SoTgJ_0onDMZh2oiAe[P;oVHc4
1?nJS<@4oi^<``CoVhg31?nLSL<00onMSL?oXlofoj??mP03oj??mP;oYLof1onW`^`8ojO1k0OoYko[
0_nW`>/3o`0006KoYl3[00?o0000ojO0jonW`>/05OnW`>/Eooooo`03o`000?oooooooooo02Cooooo
000>ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`04ooooo`03o`00
0?oooooooooo01Cooooo00?oWXc0oib7_?nLQk`00onLQk`3oi^3^@?oVX2f1OnIOK<3oiQj/@;oUgR_
00?oU7fhoiAl]_nDO;H00_nDO;H3oiAk]0CoTgVc1?nCNK83oi=h/@CoTgN`2?nCMZl2oiAf[P03oiV;
a?nIS<CoVHc400?oVHc40onJS<@5oi^<``CoVhg30_nLSL<3oj;>m`;oXlof1onW`^`9ojO1k0WoYko[
0ol0001YojO0j`03o`000?nW`>_oYl3[01KoYl3[4oooool2o`0000Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Wooooo000>ooooo`05
oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`;o00004_ooool00onO
TLCoWXc0oij<`002oij<`0CoW8Nl0onKPkT4oiZ0]PCoVGfc0_nHN[401?nDOk[oU7fhoiAm^?nDOKP4
oiAl]PCoU7^d0onCNK<4oi=i/PCoTgRa1?nCMk05oi=f[`;oV8_41?nIRl@4oiV<a0?oVXc41OnKS<<2
oi^=``?oXLgg0onRc_L7ojO2k0WoYl7/2OnW_n/3o`0006goYl3[00?o0000ojO0jonW`>/05_nW`>/D
ooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OlQ8B7oV9RHoooooonHV9So8B4Q00Wooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo0_l0000@ooooo`03oj6GbOnOTLCoWi7400;o
Wi740onNS<04oib7_0CoVh>i0onJP;H2oiUm/`;oUH6l0onDOkX4oiAm^0CoU7bf0onDNk@3oi=i/`Go
TgVb0onCN;44oi=g/0;oTgJ_00?oUh_5oiR;a?nHRl@00onHRl@3oiV;a0CoVHc41?nJS<@2oi^<``?o
Wl_g1OnQcOL00onRc_OoYl;/ojO2k002ojO2k0WoYl7/2_nW_n/3o`00077oYl3[00?o0000ojO0jonW
`>/05_nW`>/Dooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000002Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool00ol0003oooooooooo`0>ooooo`?oXIO90onO
TL@3oij<`0GoW8Nl0onKPkT2oiZ0]P03oiF4__nEPKcoUH6l00;oUH6l1?nDOkX3oiAm^0CoU7bf0onD
Nk@4oi=i/`CoTgVb0_nCN;400onFRlGoUh_5oiN;a@06oiN;a@CoV8_40onIRl@5oiV<a0;oVXc40onN
b_H4oio;m`;oXLgg00CoYl;]ojO2k?nW`^coYl;/2OnW`N`9ojNoj`04ojO0jol0003o0000o`0007Go
Yl3[00?o0000ojO0jonW`>/05OnW`>/Dooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S802Oooool002Oooooo00?o0000oooo
ooooool02oooool2oj>Mc`CoXIO90onOTL@4oij<`0CoW8Nl0_nKPkT00onFQ/7oUHBnoiF4_P02oiF4
_PCoUH6l0onDOkX3oiAm^0CoU7bf1?nDNk@3oi=i/`;oTgVb0_nFRlH4oiJ;a@OoUh_51?nHRl@4oiV;
a0;oVHc40onLb?H5oik:mP;oWl_g1OnW`^d00onW`^coYl7/ojO1k005ojO1k0WoYko[00CoYl3[o`00
0?l0003o0000N?nW`>/00ol0003oYl3[ojO0j`0FojO0jaCooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c009ooooo`009ooo
ool2o`0000Wooooo00?oYJCEoj>MconSWLl00onSWLl3oj6Gb@CoWi740onNS<02oib7_0;oUX[41?nF
Q/43oiF4_PCoUH6l0onDOkX4oiAm^0CoU7bf0onDNk@2oi=i/`03oiF;a_nFRlKoUX_600?oUX_60onF
RlD7oiN;a@GoV8_40_nIRl@3oi_6mPCoW<Sf0_nNb_H8ojO2k@SoYl7/1onW_n/2ojO0j`;o0000O?nW
`>/00ol0003oYl3[ojO0j`0EojO0jaGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4009ooooo`009oooool00ol0003ooooo
ooooo`05ooooo`03ojN]fonUY=GoYJCE00;oYJCE1?nSWLl4oj6Gb@?oWi740_nNS<000onGSLOoUX[4
oiJ:a003oiJ:a0?oUXK10onEQ;h4oiF1_0CoU7nj0onDOKP4oiAl]P;oU7^d00?oU8_7oiF;a_nERlH0
0_nERlH4oiJ;aP?oUX_52?nGRlD2oiR;a0?oV/Ce1OnKa_H2oic8mPOoYl;]2OnW`N`8ojNoj`04ojO0
jol0003o0000o`0007ooYl3[00?o0000ojO0jonW`>/05OnW`>/Booooo`?o00001?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000009ooooo`009oooool00ol0
003oooooooooo`02ooooo`03ojRfhonW[M_oYjgK00;oYjgK1?nUY=D4oj>Mc`;oXIO900CoV9O@oiRB
c?nHT/coV9;<1?nGSLL4oiJ:a0?oUXK11?nEQ;h4oiF1_0?oU7nj0_nDOKP00onCS<WoU8c8oiB<b002
oiB<b0CoU8_70onERlH4oiJ;aPCoUX_51_nGRlD3oiW2m0CoV/Ce0_nKa_H8ojO2k@WoYl7/2OnW_n/3
o`0008;oYl3[00?o0000ojO0jonW`>/05_nW`>/Dooooo`09o`000?ooooooooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@09ooooo`009_ooool3o`0000;o
oooo0onX]^<3ojN]f`GoYJCE0_nSWLl00onIW=KoV9O@oiRGd002oiRGd0?oV9;<1?nGSLL3oiJ:a0Co
UXK10onEQ;h4oiF1_0;oU7nj00?oThg;oi><bOnCS<T00_nCS<T4oiB<b0?oU8_70onERlH5oiJ;aP?o
UX_50_nGRlD3oiO0l`GoVL;d0_nJa?D00onVd?KoYl;]ojO2k@04ojO2k@WoYl7/2OnW_n/01?nW`>_o
0000o`000?l00026ojO0j`03o`000?nW`>_oYl3[01GoYl3[5Oooool00ol0003oooooooooo`0Noooo
o`009_ooool00ol0003ooooooj[1jP02oj[1jP?oZ;KS1?nW[M/2ojFTe@;oVZ?K1?nIW=H3oiRGd0?o
V9;<1?nGSLL4oiJ:a0?oUXK10_nEQ;h00onBT<koTXk<oi:>c002oi:>c0CoThg;0onCS<T4oiB<b0?o
U8_71?nERlH2oiJ;aP;oUK_b1OnF_O<4oiO0l`;oVL;d0_nVd?H3ojS3k@?oYl;]2OnW`N`9ojNoj`04
ojO0jol0003o0000o`0008[oYl3[00?o0000ojO0jonW`>/05OnW`>/Dooooo`03o`000?oooooooooo
01kooooo000Kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooooj[1jP03oj[1
jP?oZ;KS0_nW[M/2oiZ[hPCoVZ?K0onIW=H3oiRGd0CoV9;<1?nGSLL2oiJ:a004oi6Cd_nATM3oTI7@
oi6Ad0CoTY3>1?nBS/`3oi>=b`?oThc91?nDS<P4oiB;a`;oUH_60onC^O43oiFklPGoU[gc0_nG`?<2
ojK@mP?oYl?]1?nX`nd00onW`^goYl7/ojO1k005ojO1k0SoYko[0_nW`>/3o`0008koYl3[00?o0000
ojO0jonW`>/05OnW`>/Dooooo`03o`000?oooooooooo01gooooo000Kooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01_ooool00ol0003oooooooooo`02oj[1jP03oiZll?nJ/nWoV[?Y00;oV[?Y1?nJZn83
oiZSf`CoVIcF0onHUm02oiRBc003ohnHf?n@U]GoT9KE00;oT9KE1?nATm83oi6Ad0?oTY3>1?nBS/`3
oi>=b`CoThc91?nDS<P2oiB;a`;oT[O`1OnC^O43oiFklP;oU[gc00?oY/ofojK@m_nVd?H01onW`nd2
ojS3k@SoYl7/1_nW_n/2ojO0j`?o0000TOnW`>/00ol0003oYl3[ojO0j`0FojO0ja?ooooo0_l0000N
ooooo`006oooool01Ol@413ooooooooooooooooo410@00Kooooo0_l00002ooooo`?oV[c`1?nJ/nT4
oiZ[hP?oVZ?K0_nIW=H01?n>X>3oSicLohnLg?n?W=`4ohnHf0CoT9KE0onATm83oi6Ad0?oTY3>1OnB
S/`3oi>=b`;oThc90_n?/nl4oi2ek`CoT[O`0_nC^O400onAiO_oY/ofojK?mP03ojK?mPWoYl?]2OnW
`N`8ojNoj`?o0000UOnW`>/00ol0003oYl3[ojO0j`0EojO0ja;ooooo00?o0000ooooool000007_oo
ool001_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo0onJ
_?04oiZcj@;oVZ_R00CoS:[ZohfUiOn=YNGoSJGU1?n>X>03ohnLg0?oSiSH1?n@U]D3oi6CdPCoTI7@
0onBT<h2oi:>c0;oS:o^1?n>/Nh4ohnck`CoT;G_0_nB]o04ojK?m@;oY/of2OnW`nd9ojO1k0WoYko[
0_l0002IojO0j`03o`000?nW`>_oYl3[01GoYl3[5?ooool00ol0003oooooooooo`0Kooooo`006ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool4ohRfm0?oR[3_
0on<Z^X3ohfUi@?oSZ3P1?n?W=`3ohnHf0CoT9KE0onATm82oi6Ad003ohV]kOn;[^goRjk]00?oRjk]
0on<[nh4ohjakPCoSk?_0_n@]Nl3ojK>m@?oY/oe2OnW`nd9ojO1k0SoYko[00CoYl3[o`000?l0003o
0000VonW`>/00ol0003oYl3[ojO0j`0EojO0jaGooooo00?o0000ooooooooool06_ooool001_ooooo
00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo00Gooooo1?n8]_@3ohZ`k`?o
S:[Z0on=YND3ohjPh0;oSicL0_n1Znl3oh>[kPCoQJ_^0on7[>d3ohV]k@GoRjk]0on<[nh2ohjakP04
ofcLjonDh_goU>;moiCRo@OoY/ke00?oY/oeojO3kOnW`nd01?nW`nd9ojO1k0WoYko[00CoYl3[o`00
0?l0003o0000WonW`>/00ol0003oYl3[ojO0j`0EojO0jaCooooo00?o0000ooooooooool06_ooool0
01_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00001oooool2ohRfm004ogR`m_mi[_Co
NJkdogV^m0CoNjgc0omm[?44ogn[l0?oPJ__0on3Znh4ohF[kP?oQjc]0on9[Nd2oh^^k@?oMmkf0_ma
gO43oiGPoP;oYLgd1_nVc_D6ojO3k@WoYl7/2OnW_n/01?nW`>_o0000o`000?l0002SojO0j`03o`00
0?nW`>_oYl3[01GoYl3[5?ooool00ol0003oooooooooo`0Iooooo`006oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo00?o0000ooooooooool01oooool3ogR`mP?oNJkd1?mk[O<3ogf/l@CoOj_`
0on1Znl3oh>[kP;oQJ_^1?m1_nP2ocFjf`?oO=gj0_mgg_H3oiONoP;oYLcd1?nUcO@2ojK>m@SoYl?]
1onW`N`8ojNoj`;oYl3[0ol0002WojO0j`03o`000?nW`>_oYl3[01CoYl3[5?ooool00ol0003ooooo
ooooo`0Iooooo`009Oooool00ol0003oooooooooo`08ooooo`?oN;3f0omi[_@2og^]l`?oJ;Kl0omR
^_d4oebno0?oE<7i0_m;`O83odW7i@CoPM_m0_mlgOX3oiSLoP03oiONo_nUc?CoYLcd00?oYLcd0_nU
cO@9ojO3k@SoYl7/1_nW_n/2ojO0j`?o0000Z_nW`>/00ol0003oYl3[ojO0j`0EojO0ja;ooooo00?o
0000ooooool000006_ooool002Gooooo00?o0000ooooooooool02_ooool4og>^mP?oK[;i0omX]_`3
of:jo@;oG;kl1?mTbo/2oeO;l`?oQMOo0_n1fod4oiWIo@;oV=cn1?nUbo<2ojG<m0WoYl?]2?nW`N`8
ojNoj`?o0000[_nW`>/00ol0003oYl3[ojO0j`0EojO0jaCooooo00?o0000ooooooooool05oooool0
02Gooooo0_l0000<ooooo`;oLjkf0_n0/oD3ogbjnPCoM/7n0_m^aol3oh_=oPCoRM?o0_n5eol4oi[E
o0;oVMWm0onUb_<2ojG;l`WoYl?]2OnW`N`9ojNoj`;o0000/_nW`>/00ol0003oYl3[ojO0j`0EojO0
ja?ooooo00?o0000ooooooooool05oooool002Cooooo00?o0000ooooooooool03Oooool4oh2cm@?o
O;[j0_mf`Oh4ohk7n`?oRlgn0_n9dol4oi_An`;oV]Gl0onUb?82ojG:l`WoYl?]2OnW`N`9ojNoj`?o
0000]OnW`>/00ol0003oYl3[ojO0j`0DojO0jaCooooo00?o0000ooooooooool05_ooool002Cooooo
00?o0000ooooooooool03_ooool2oh2cm@?oTKWb1?n?`?L2ohk7n`;oVlOf1?nKc?T2oi_An`?oY<Oa
0onUb?89ojO3k@WoYl7/2?nW_n/01?nW`>_o0000o`000?l0002hojO0j`03o`000?nW`>_oYl3[01Go
Yl3[5?ooool00ol0003oooooooooo`0Eooooo`009?ooool3o`0000oooooo1OnA^O82oho0m`;oW<;c
1?nKaoH2oi_<n@?oY<G`1?nTao400onUb?;oYl?]ojO3k@05ojO3k@SoYl7/2OnW_n/01?nW`>_o0000
o`000?l0002lojO0j`03o`000?nW`>_oYl3[01GoYl3[4_ooool2o`0000Wooooo1?l000000ol@413o
ooooooooo`07ooooo`009?ooool00ol0003oooooooooo`0@ooooo`;oTKWb0onL_Nl4oic2l`;oVlOf
0onT`nl4ojC5l0;oY<Oa0_nW`^d4ojO3k@SoYl7/2OnW_n/01?nW`>_o0000o`000?l00030ojO0j`03
o`000?nW`>_oYl3[01GoYl3[4oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wo
oooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03
o`000?oooooooooo01;ooooo1?nL_Nl2oic2l`?oY<7^1?nT`nl2ojC5l0KoYl;]00?oYl?]ojO1k?nW
`N`01OnW`N`2ojO0j`OoYko[00CoYl3[o`000?l0003o0000`onW`>/00ol0003oYl3[ojO0j`0EojO0
jaCooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`002Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool0
0ol0003oooooooooo`0Cooooo`;oW;g_0_nS_nd5ojC1kP;oY<?_0_nV`Nd6ojO2k@SoYl7/1?nW`>/2
ojNoj`;oYl3[0ol00037ojO0j`03o`000?nW`>_oYl3[01GoYl3[4oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo01Gooooo1?nS_nd2ojC1kP?oY/3/1?nV`Nd2
ojO2k@WoYl7/2?nW`>/2o`000<_oYl3[00?o0000ojO0jonW`>/05OnW`>/Cooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02Oooool000Wooooo00Go0000ooooooooooooooooo`00000=
ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0ol0000Fooooo`;oXko]0onV_n`4ojK0k0;oY/7]0_nW`>`6
ojO1k0WoYl3[0ol0003>ojO0j`03o`000?nW`>_oYl3[01GoYl3[4Oooool3o`0000Oooooo00?o0000
ooooooooool02Oooool000Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKo
oooo00Cooooo00?o0000ooooooooool06?ooool4ojJok0;oY/3/0_nW`>/4ojO0k0;oYl7/2OnW`>/3
o`000=7oYl3[00?o0000ojO0jonW`>/05OnW`>/>ooooo`Co000000?oooooo`000?ooool01_ooool0
0ol0003oooooooooo`09ooooo`002Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Iooooo`;oY[o/1_nW`>/2ojO0k0WoYl3[0ol0003E
ojO0j`03o`000?nW`>_oYl3[01GoYl3[2_ooool3o`0000Gooooo00?o0000ooooooooool00oooool0
0omEEEGoIVIVo`00000;ooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4005ooooo`;o00006oooool?ojO0j`?o0000fOnW`>/00ol0003oYl3[ojO0
j`0DojO0j`Kooooo1?l00008ooooo`03o`000?oooooooooo017ooooo0009ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0
6oooool;ojO0j`?o0000g?nW`>/00ol0003oYl3[ojO0j`0EojO0j`;ooooo0ol0000<ooooo`03o`00
0?oooooooooo017ooooo000Rooooo`03o`000?oooooooooo01gooooo1onW`>/3o`000>3oYl3[00?o
0000ojO0jonW`>/05OnW`>/00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo013ooooo000R
ooooo`03o`000?oooooooooo01kooooo1?nW`>/2o`000>CoYl3[00?o0000ojO0jonW`>/05OnW`>/@
ooooo`03o`000?oooooooooo013ooooo000Rooooo`;o00008?ooool3o`000>OoYl3[00?o0000ojO0
jonW`>/05?nW`>/@ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo01co
oooo0ol000000oooooooYl3[ojO0j`3WojO0j`03o`000?nW`>_oYl3[01GoYl3[3oooool00ol0003o
ooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0Iooooo`?o00001_oooooXojO0j`03o`00
0?nW`>_oYl3[01CoYl3[3oooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0003ooooooooo
o`0Fooooo`?o00002_oooooXojO0j`03o`000?nW`>_oYl3[01CoYl3[3_ooool00ol0003ooooooooo
o`0@ooooo`008_ooool2o`0001Cooooo0ol0000>ooooonSoYl3[00?o0000ojO0jonW`>/05?nW`>/=
ooooo`03o`000?oooooooooo013ooooo000Qooooo`;o00004_ooool3o`0001;oooooionW`>/00ol0
003oYl3[ojO0j`0EojO0j`cooooo00?o0000ooooooooool04?ooool000Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool03oooool2o`0001KoooooionW`>/00ol0003oYl3[ojO0j`0DojO0j`gooooo00?o0000oooo
ooooool03oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo0ol0000IooooonOoYl3[00?o0000ojO0
jonW`>/05?nW`>/<ooooo`03o`000?oooooooooo00oooooo0007ooooo`05oa0@4?oooooooooooooo
ool@41002oooool5o`0000Gooooo0_l0000:ooooo`?o00007OoooooVojO0j`03o`000?nW`>_oYl3[
01GoYl3[2oooool00ol0003oooooooooo`0?ooooo`001oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CoA4A4omgMgOoooooo00001_ooool00ol0003oooooooooo`06ooooo`?o00008OoooooV
ojO0j`03o`000?nW`>_oYl3[01GoYl3[2_ooool00ol0003oooooooooo`0?ooooo`001oooool01Ol0
003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003ooooooooo
o`03ooooo`?o00009_oooooUojO0j`03o`000?nW`>_oYl3[01CoYl3[2_ooool00ol0003ooooooooo
o`0?ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001Ooo
ool01?l0003oooooooooooooool3o`0002[oooooiOnW`>/00ol0003oYl3[ojO0j`0DojO0j`Wooooo
00?o0000ooooooooool03oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^
k_m4A4Co000000Gooooo1?l0000^ooooonCoYl3[00?o0000ojO0jonW`>/05?nW`>/9ooooo`03o`00
0?oooooooooo00oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000
ooooo`04ooooo`;o0000<OoooooTojO0j`03o`000?nW`>_oYl3[01CoYl3[2?ooool00ol0003ooooo
ooooo`0?ooooo`008_ooool00ol0003oooooooooo`0_ooooonCoYl3[00?o0000ojO0jonW`>/04onW
`>/9ooooo`03o`000?oooooooooo00kooooo000Sooooo`03o`000?oooooooooo02oooooohonW`>/0
0ol0003oYl3[ojO0j`0DojO0j`Sooooo00?o0000ooooooooool03_ooool002Cooooo00?o0000oooo
ooooool0;ooooooSojO0j`03o`000?nW`>_oYl3[01CoYl3[1oooool00ol0003oooooooooo`0>oooo
o`009Oooool2o`00033ooooohonW`>/00ol0003oYl3[ojO0j`0DojO0j`Kooooo00?o0000oooooooo
ool03_ooool002Oooooo00?o0000ooooooooool0;_oooooSojO0j`03o`000?nW`>_oYl3[01?oYl3[
1_ooool00ol0003oooooooooo`0>ooooo`00:?ooool00ol0003oooooooooo`0^ooooon;oYl3[00?o
0000ojO0jonW`>/05?nW`>/5ooooo`03o`000?oooooooooo00kooooo000Yooooo`03o`000?oooooo
oooo02oooooohOnW`>/00ol0003oYl3[ojO0j`0DojO0j`Cooooo00?o0000ooooooooool03_ooool0
02[ooooo0_l0000aooooon3oYl3[00?o0000ojO0jonW`>/05?nW`>/3ooooo`03o`000?oooooooooo
00kooooo000/ooooo`03o`000?oooooooooo02ooooooh?nW`>/00ol0003oYl3[ojO0j`0DojO0j`?o
oooo00?o0000ooooooooool03Oooool002gooooo00?o0000ooooooooool0;ooooooOojO0j`03o`00
0?nW`>_oYl3[01CoYl3[0oooool00ol0003oooooooooo`0=ooooo`00;_ooool00ol0003ooooooooo
o`0_ooooomooYl3[00?o0000ojO0jonW`>/05?nW`>/2ooooo`03o`000?oooooooooo00gooooo000_
ooooo`03o`000?oooooooooo02oooooogonW`>/00ol0003oYl3[ojO0j`0CojO0j`;ooooo00?o0000
ooooooooool03Oooool0033ooooo0_l0000`ooooomkoYl3[00?o0000ojO0jonW`>/05?nW`>/00ooo
oooo0000ooooo`0>ooooo`00<_ooool00ol0003oooooooooo`0^ooooomkoYl3[00?o0000ojO0jonW
`>/04onW`>/00ooooooo0000ooooo`0>ooooo`00<oooool00ol0003oooooooooo`0^ooooomkoYl3[
00?o0000ojO0jonW`>/04onW`>/00ol0003oooooooooo`0=ooooo`00=?ooool00ol0003ooooooooo
o`0^ooooomkoYl3[00?o0000ojO0jonW`>/04OnW`>/00ooooooo0000ooooo`0>ooooo`00=Oooool2
o`0002oooooogOnW`>/00ol0003oYl3[ojO0j`0=ojO0j`Kooooo00?o0000ooooooooool03?ooool0
03Oooooo00?o0000ooooooooool0;_oooooLojO0j`03o`000?nW`>_oYl3[00WoYl3[2Oooool00ol0
003oooooooooo`0<ooooo`00>?ooool00ol0003oooooooooo`0^ooooomcoYl3[00?o0000ojO0jonW
`>/01OnW`>/<ooooo`03o`000?oooooooooo00cooooo000iooooo`03o`000?oooooooooo02kooooo
g?nW`>/00ol0003oYl3[ojO0j`0@ooooo`03o`000?oooooooooo00cooooo000jooooo`;o0000;ooo
oooKojO0j`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool003cooooo00?o0000
ooooooooool0;OoooooFojO0j`Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<
ooooo`00?Oooool00ol0003oooooooooo`0]ooooom;oYl3[2Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00cooooo000nooooo`03o`000?oooooooooo02gooooob_nW`>/@ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool003oooooo0_l0000_ooooolGoYl3[
5?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo0011ooooo`03o`000?oo
oooooooo02gooooo`OnW`>/Hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02ooo
ool004;ooooo00?o0000ooooooooool0;OoooonlojO0jagooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`00@oooool00ol0003oooooooooo`0]oooookSoYl3[8?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0014ooooo`03o`000?oooooooooo02go
oooo]?nW`>/Tooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool004Gooooo
0_l0000_ooooojkoYl3[:Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
0017ooooo`03o`000?oooooooooo02goooooZ_nW`>//ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02oooool004Sooooo00?o0000ooooooooool0;OoooonVojO0jc3ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`00BOooool00ol0003oooooooooo`0]oooo
oj;oYl3[=?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo001:ooooo`;o
0000;_oooonMojO0jcWooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00
C?ooool00ol0003oooooooooo`0/oooooiWoYl3[??ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00[ooooo001=ooooo`03o`000?oooooooooo02coooooT_nW`>]3ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02_ooool004kooooo00?o0000ooooooooool0;Ooooon=
ojO0jdOooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`00Coooool2o`00
02koooooR?nW`>]<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool0057o
oooo00?o0000ooooooooool0;?oooon4ojO0jdoooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0:ooooo`00D_ooool00ol0003oooooooooo`0[oooooh7oYl3[Doooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00[ooooo001Cooooo`03o`000?oooooooooo02_oooooOOnW
`>]Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool005Cooooo0_l0000]
ooooogSoYl3[F_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo001Foooo
o`03o`000?oooooooooo02_oooooM?nW`>]Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02Oooool005Oooooo00?o0000ooooooooool0:ooooom/ojO0jfKooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`09ooooo`00F?ooool00ol0003oooooooooo`0/ooooofOoYl3[
J_ooool01Ol0003ooooooooooooooooo000000_ooooo001Iooooo`03o`000?oooooooooo02cooooo
HonW`>]]ooooo`05o`000?ooooooooooooooool000002oooool005[ooooo0_l0000]oooooeooYl3[
LOooool01?l0003oooooooooool0000;ooooo`00G?ooool00ol0003oooooooooo`0[oooooe_oYl3[
MOooool00ol0003oooooo`00000;ooooo`00GOooool00ol0003oooooooooo`0[oooooeOoYl3[N?oo
ool01?l0003oooooooooool0000:ooooo`00G_ooool00ol0003oooooooooo`0[oooooe?oYl3[O?oo
ool00ol0003oooooo`00000:ooooo`00Goooool2o`0002coooooC?nW`>^3ooooo`;o00002_ooool0
067ooooo00?o0000ooooooooool0:_oooom8ojO0jhGooooo0ol0000:ooooo`00H_ooool00ol0003o
ooooooooo`0[oooood?oYl3[Q?ooool4o`0000gooooo001Sooooo`03o`000?oooooooooo02_ooooo
?onW`>^3ooooo`Co00004Oooool006Cooooo0_l0000/oooooc_oYl3[Poooool3o`0001Gooooo001V
ooooo`03o`000?oooooooooo02_ooooo<onW`>^5ooooo`Co00006?ooool006Oooooo00?o0000oooo
ooooool0:_ooool`ojO0jhCooooo1?l0000Looooo`00J?ooool00ol0003oooooooooo`0Zooooobco
Yl3[Poooool4o`00023ooooo001Yooooo`;o0000;?oooolWojO0jh;ooooo1?l0000Tooooo`00Jooo
ool00ol0003oooooooooo`0Zooooob?oYl3[P_ooool3o`0002Sooooo001/ooooo`03o`000?oooooo
oooo02[ooooo7OnW`>^3ooooo`Co0000:oooool006gooooo00?o0000ooooooooool0:ooooolHojO0
jh;ooooo1?l0000_ooooo`00K_ooool00ol0003oooooooooo`0ZoooooaGoYl3[POooool4o`0003?o
oooo001_ooooo`;o0000:ooooolAojO0jh3ooooo1?l0000gooooo`00LOooool00ol0003ooooooooo
o`0Zooooo`WoYl3[P_ooool4o`0003_ooooo001booooo`03o`000?oooooooooo02[ooooo1OnW`>^2
ooooo`?o0000?oooool007?ooooo00?o0000ooooooooool0:_ooool00onW`>_oooooooooo`1ooooo
o`Co0000@_ooool007Cooooo0_l0000Zooooo`03o`000?oooooooooo07_ooooo1?l00016ooooo`00
M_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07Sooooo1?l0001:ooooo`00Mooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07Cooooo1?l0001>ooooo`00N?ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo077ooooo0ol0001Booooo`00NOooool2o`00
02Cooooo00?o0000ooooooooool0KOooool4o`0005Gooooo001kooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0JOooool4o`0005Wooooo001looooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool0IOooool4o`0005gooooo001mooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool0HOooool4o`00067ooooo001nooooo`;o00007oooool00ol0003oooooooooo`1M
ooooo`Co0000IOooool0083ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Joooo
o`?o0000JOooool0087ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Fooooo`Co
0000K?ooool008;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Booooo`Co0000
L?ooool008?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1>ooooo`Co0000M?oo
ool008Cooooo0_l0000Iooooo`03o`000?oooooooooo04[ooooo1?l0001hooooo`00Q_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo04Kooooo1?l0001looooo`00Qoooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo04?ooooo0ol00020ooooo`00R?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo03oooooo1?l00023ooooo`00ROooool2o`0001Cooooo00?o
0000ooooooooool0>oooool4o`0008Oooooo002;ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0=oooool4o`0008_ooooo002<ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0<oooool4o`0008oooooo002=ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0<?ooool3o`0009?ooooo002>ooooo`;o00003oooool00ol0003oooooooooo`0/ooooo`Co0000
U_ooool0093ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Xooooo`Co0000V_oo
ool0097ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Tooooo`Co0000W_ooool0
09;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`Co0000X_ooool009?o
oooo0_l00009ooooo`03o`000?oooooooooo01gooooo1?l0002Vooooo`00UOooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01[ooooo0ol0002Zooooo`00U_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Kooooo1?l0002]ooooo`00Uoooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01;ooooo1?l0002aooooo`00V?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00kooooo1?l0002eooooo`00VOooool2o`0000?ooooo00?o0000oooooooo
ool02_ooool4o`000;Wooooo002Kooooo`04o`000?ooooooooooo`0000Wooooo0ol0002mooooo`00
W?ooool00ol0003oooooo`000005ooooo`Co0000`?ooool009gooooo0_l000000ooooooo0000o`00
0002o`000<Cooooo002Nooooo`;o0000b?ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:kooooo
00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Co
oooo00Gok^k^oc8b<_l0003o410@olc<c02Gooooo`00[_ooool01Ol@413o^[Zjonk^k_mgMgOo410@
00;ooooo1_l00004ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B40Uoooool00:kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:oooo
o`05o`000?ooooooooooooooool00000Uoooool00:kooooo00?o0000ooooooooool01?ooool6o`00
00Cooooo00?o0000ooooooooool02_ooool01Ol0003oV9RHoooooonHV9So8B4Q09Oooooo002^oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool01Ol0003oEEEEo`000?l@413o
c<c<09Oooooo002/ooooo`03oa0@4?l0003o000000?o00003Oooool00ol0003oooooooooo`0:oooo
o`03oeEEEOn7QhOooooo09Wooooo002^ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool02_ooool00ooMgMgo410@oiRHV02Iooooo`00[_ooool00ol0003oooooooooo`0<ooooo`03oeEE
EOmVIVKo000000gooooo00Coc<c<odA4A?l0003o410@Uoooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -17 0 ]
[.5 .82364 17 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69467 Mtetra
.4053 .69467 .41061 .69934 .41957 .69681 .41427 .69213 Mtetra
.41427 .69213 .41957 .69681 .42855 .69428 .42327 .68958 Mtetra
.42327 .68958 .42855 .69428 .43756 .69174 .43231 .68703 Mtetra
.43231 .68703 .43756 .69174 .4466 .68919 .44137 .68446 Mtetra
.44137 .68446 .4466 .68919 .45567 .68663 .45046 .68189 Mtetra
.45046 .68189 .45567 .68663 .46478 .68407 .45958 .67931 Mtetra
.45958 .67931 .46478 .68407 .47391 .68149 .46873 .67671 Mtetra
.46873 .67671 .47391 .68149 .48307 .67891 .47792 .67412 Mtetra
.47792 .67412 .48307 .67891 .49227 .67632 .48713 .67151 Mtetra
.48713 .67151 .49227 .67632 .50149 .67371 .49638 .66889 Mtetra
.49638 .66889 .50149 .67371 .51075 .6711 .50565 .66626 Mtetra
.50565 .66626 .51075 .6711 .52004 .66849 .51496 .66363 Mtetra
.51496 .66363 .52004 .66849 .52936 .66586 .5243 .66098 Mtetra
.5243 .66098 .52936 .66586 .53871 .66322 .53367 .65833 Mtetra
.53367 .65833 .53871 .66322 .54809 .66058 .54308 .65567 Mtetra
.54308 .65567 .54809 .66058 .55751 .65792 .55251 .653 Mtetra
.55251 .653 .55751 .65792 .56695 .65526 .56198 .65032 Mtetra
.56198 .65032 .56695 .65526 .57643 .65259 .57148 .64763 Mtetra
.57148 .64763 .57643 .65259 .58595 .6499 .58102 .64493 Mtetra
.58102 .64493 .58595 .6499 .59549 .64721 .59058 .64222 Mtetra
.59058 .64222 .59549 .64721 .60507 .64451 .60018 .6395 Mtetra
.60018 .6395 .60507 .64451 .61468 .6418 .60982 .63678 Mtetra
.60982 .63678 .61468 .6418 .62432 .63908 .61948 .63404 Mtetra
.61948 .63404 .62432 .63908 .634 .63636 .62918 .63129 Mtetra
.62918 .63129 .634 .63636 .64371 .63362 .63892 .62854 Mtetra
.63892 .62854 .64371 .63362 .65345 .63087 .64868 .62577 Mtetra
.64868 .62577 .65345 .63087 .66323 .62811 .65848 .623 Mtetra
.65848 .623 .66323 .62811 .67304 .62535 .66832 .62021 Mtetra
.66832 .62021 .67304 .62535 .68289 .62257 .67819 .61742 Mtetra
.67819 .61742 .68289 .62257 .69277 .61979 .68809 .61462 Mtetra
.68809 .61462 .69277 .61979 .70269 .61699 .69803 .6118 Mtetra
.69803 .6118 .70269 .61699 .71264 .61418 .70801 .60898 Mtetra
.70801 .60898 .71264 .61418 .72262 .61137 .71802 .60615 Mtetra
.71802 .60615 .72262 .61137 .73264 .60854 .72806 .6033 Mtetra
.72806 .6033 .73264 .60854 .7427 .60571 .73814 .60045 Mtetra
.73814 .60045 .7427 .60571 .75279 .60286 .74826 .59759 Mtetra
.74826 .59759 .75279 .60286 .76291 .60001 .75841 .59471 Mtetra
.75841 .59471 .76291 .60001 .77308 .59714 .7686 .59183 Mtetra
.7686 .59183 .77308 .59714 .78328 .59427 .77882 .58893 Mtetra
.77882 .58893 .78328 .59427 .79351 .59138 .78908 .58603 Mtetra
.78908 .58603 .79351 .59138 .80378 .58849 .79938 .58311 Mtetra
.79938 .58311 .80378 .58849 .81409 .58558 .80971 .58019 Mtetra
.80971 .58019 .81409 .58558 .82443 .58267 .82008 .57725 Mtetra
.82008 .57725 .82443 .58267 .83482 .57974 .83049 .57431 Mtetra
.83049 .57431 .83482 .57974 .84523 .5768 .84094 .57135 Mtetra
.84094 .57135 .84523 .5768 .85569 .57385 .85142 .56838 Mtetra
.85142 .56838 .85569 .57385 .86618 .57089 .86194 .5654 Mtetra
.86194 .5654 .86618 .57089 .87672 .56792 .8725 .56241 Mtetra
.8725 .56241 .87672 .56792 .88729 .56494 .8831 .55941 Mtetra
.8831 .55941 .88729 .56494 .89789 .56195 .89374 .5564 Mtetra
.89374 .5564 .89789 .56195 .90854 .55895 .90441 .55338 Mtetra
.90441 .55338 .90854 .55895 .91923 .55594 .91512 .55035 Mtetra
.91512 .55035 .91923 .55594 .92995 .55292 .92588 .5473 Mtetra
.92588 .5473 .92995 .55292 .94071 .54988 .93667 .54425 Mtetra
.93667 .54425 .94071 .54988 .95152 .54684 .9475 .54118 Mtetra
.9475 .54118 .95152 .54684 .96236 .54378 .95837 .53811 Mtetra
.95837 .53811 .96236 .54378 .97324 .54071 .96928 .53502 Mtetra
.96928 .53502 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.391 .69252 .39636 .6972 .4053 .69467 .39996 .68998 Mtetra
.39996 .68998 .4053 .69467 .41427 .69213 .40895 .68742 Mtetra
.40895 .68742 .41427 .69213 .42327 .68958 .41797 .68486 Mtetra
.41797 .68486 .42327 .68958 .43231 .68703 .42702 .68228 Mtetra
.42702 .68228 .43231 .68703 .44137 .68446 .4361 .6797 Mtetra
.4361 .6797 .44137 .68446 .45046 .68189 .44521 .67711 Mtetra
.44521 .67711 .45046 .68189 .45958 .67931 .45435 .67452 Mtetra
.45435 .67452 .45958 .67931 .46873 .67671 .46352 .67191 Mtetra
.46352 .67191 .46873 .67671 .47792 .67412 .47273 .66929 Mtetra
.47273 .66929 .47792 .67412 .48713 .67151 .48196 .66667 Mtetra
.48196 .66667 .48713 .67151 .49638 .66889 .49123 .66403 Mtetra
.49123 .66403 .49638 .66889 .50565 .66626 .50053 .66139 Mtetra
.50053 .66139 .50565 .66626 .51496 .66363 .50985 .65874 Mtetra
.50985 .65874 .51496 .66363 .5243 .66098 .51922 .65608 Mtetra
.51922 .65608 .5243 .66098 .53367 .65833 .52861 .65341 Mtetra
.52861 .65341 .53367 .65833 .54308 .65567 .53803 .65073 Mtetra
.53803 .65073 .54308 .65567 .55251 .653 .54749 .64804 Mtetra
.54749 .64804 .55251 .653 .56198 .65032 .55698 .64534 Mtetra
.55698 .64534 .56198 .65032 .57148 .64763 .5665 .64264 Mtetra
.5665 .64264 .57148 .64763 .58102 .64493 .57606 .63992 Mtetra
.57606 .63992 .58102 .64493 .59058 .64222 .58565 .6372 Mtetra
.58565 .6372 .59058 .64222 .60018 .6395 .59527 .63446 Mtetra
.59527 .63446 .60018 .6395 .60982 .63678 .60493 .63172 Mtetra
.60493 .63172 .60982 .63678 .61948 .63404 .61461 .62896 Mtetra
.61461 .62896 .61948 .63404 .62918 .63129 .62434 .6262 Mtetra
.62434 .6262 .62918 .63129 .63892 .62854 .63409 .62343 Mtetra
.63409 .62343 .63892 .62854 .64868 .62577 .64388 .62064 Mtetra
.64388 .62064 .64868 .62577 .65848 .623 .65371 .61785 Mtetra
.65371 .61785 .65848 .623 .66832 .62021 .66357 .61505 Mtetra
.66357 .61505 .66832 .62021 .67819 .61742 .67346 .61224 Mtetra
.67346 .61224 .67819 .61742 .68809 .61462 .68339 .60942 Mtetra
.68339 .60942 .68809 .61462 .69803 .6118 .69335 .60658 Mtetra
.69335 .60658 .69803 .6118 .70801 .60898 .70335 .60374 Mtetra
.70335 .60374 .70801 .60898 .71802 .60615 .71338 .60089 Mtetra
.71338 .60089 .71802 .60615 .72806 .6033 .72345 .59803 Mtetra
.72345 .59803 .72806 .6033 .73814 .60045 .73356 .59516 Mtetra
.73356 .59516 .73814 .60045 .74826 .59759 .7437 .59227 Mtetra
.7437 .59227 .74826 .59759 .75841 .59471 .75387 .58938 Mtetra
.75387 .58938 .75841 .59471 .7686 .59183 .76409 .58648 Mtetra
.76409 .58648 .7686 .59183 .77882 .58893 .77434 .58356 Mtetra
.77434 .58356 .77882 .58893 .78908 .58603 .78462 .58064 Mtetra
.78462 .58064 .78908 .58603 .79938 .58311 .79495 .57771 Mtetra
.79495 .57771 .79938 .58311 .80971 .58019 .80531 .57476 Mtetra
.80531 .57476 .80971 .58019 .82008 .57725 .81571 .57181 Mtetra
.81571 .57181 .82008 .57725 .83049 .57431 .82614 .56884 Mtetra
.82614 .56884 .83049 .57431 .84094 .57135 .83661 .56586 Mtetra
.83661 .56586 .84094 .57135 .85142 .56838 .84712 .56288 Mtetra
.84712 .56288 .85142 .56838 .86194 .5654 .85767 .55988 Mtetra
.85767 .55988 .86194 .5654 .8725 .56241 .86826 .55687 Mtetra
.86826 .55687 .8725 .56241 .8831 .55941 .87889 .55385 Mtetra
.87889 .55385 .8831 .55941 .89374 .5564 .88955 .55082 Mtetra
.88955 .55082 .89374 .5564 .90441 .55338 .90025 .54777 Mtetra
.90025 .54777 .90441 .55338 .91512 .55035 .911 .54472 Mtetra
.911 .54472 .91512 .55035 .92588 .5473 .92178 .54166 Mtetra
.92178 .54166 .92588 .5473 .93667 .54425 .9326 .53858 Mtetra
.9326 .53858 .93667 .54425 .9475 .54118 .94346 .53549 Mtetra
.94346 .53549 .9475 .54118 .95837 .53811 .95436 .53239 Mtetra
.95436 .53239 .95837 .53811 .96928 .53502 .9653 .52928 Mtetra
.9653 .52928 .96928 .53502 .98024 .53192 .97628 .52616 Mtetra
.38561 .68781 .391 .69252 .39996 .68998 .39459 .68525 Mtetra
.39459 .68525 .39996 .68998 .40895 .68742 .40359 .68268 Mtetra
.40359 .68268 .40895 .68742 .41797 .68486 .41263 .6801 Mtetra
.41263 .6801 .41797 .68486 .42702 .68228 .4217 .67751 Mtetra
.4217 .67751 .42702 .68228 .4361 .6797 .4308 .67492 Mtetra
.4308 .67492 .4361 .6797 .44521 .67711 .43993 .67231 Mtetra
.43993 .67231 .44521 .67711 .45435 .67452 .44909 .6697 Mtetra
.44909 .6697 .45435 .67452 .46352 .67191 .45828 .66707 Mtetra
.45828 .66707 .46352 .67191 .47273 .66929 .46751 .66444 Mtetra
.46751 .66444 .47273 .66929 .48196 .66667 .47676 .6618 Mtetra
.47676 .6618 .48196 .66667 .49123 .66403 .48605 .65915 Mtetra
.48605 .65915 .49123 .66403 .50053 .66139 .49537 .65649 Mtetra
.49537 .65649 .50053 .66139 .50985 .65874 .50472 .65382 Mtetra
.50472 .65382 .50985 .65874 .51922 .65608 .5141 .65114 Mtetra
.5141 .65114 .51922 .65608 .52861 .65341 .52351 .64846 Mtetra
.52351 .64846 .52861 .65341 .53803 .65073 .53296 .64576 Mtetra
.53296 .64576 .53803 .65073 .54749 .64804 .54244 .64305 Mtetra
.54244 .64305 .54749 .64804 .55698 .64534 .55195 .64034 Mtetra
.55195 .64034 .55698 .64534 .5665 .64264 .56149 .63762 Mtetra
.56149 .63762 .5665 .64264 .57606 .63992 .57107 .63488 Mtetra
.57107 .63488 .57606 .63992 .58565 .6372 .58068 .63214 Mtetra
.58068 .63214 .58565 .6372 .59527 .63446 .59032 .62939 Mtetra
.59032 .62939 .59527 .63446 .60493 .63172 .6 .62663 Mtetra
.6 .62663 .60493 .63172 .61461 .62896 .60971 .62385 Mtetra
.60971 .62385 .61461 .62896 .62434 .6262 .61946 .62107 Mtetra
.61946 .62107 .62434 .6262 .63409 .62343 .62924 .61828 Mtetra
.62924 .61828 .63409 .62343 .64388 .62064 .63905 .61548 Mtetra
.63905 .61548 .64388 .62064 .65371 .61785 .6489 .61267 Mtetra
.6489 .61267 .65371 .61785 .66357 .61505 .65878 .60985 Mtetra
.65878 .60985 .66357 .61505 .67346 .61224 .6687 .60702 Mtetra
.6687 .60702 .67346 .61224 .68339 .60942 .67865 .60418 Mtetra
.67865 .60418 .68339 .60942 .69335 .60658 .68864 .60133 Mtetra
.68864 .60133 .69335 .60658 .70335 .60374 .69866 .59847 Mtetra
.69866 .59847 .70335 .60374 .71338 .60089 .70872 .5956 Mtetra
.70872 .5956 .71338 .60089 .72345 .59803 .71881 .59272 Mtetra
.71881 .59272 .72345 .59803 .73356 .59516 .72894 .58983 Mtetra
.72894 .58983 .73356 .59516 .7437 .59227 .73911 .58692 Mtetra
.73911 .58692 .7437 .59227 .75387 .58938 .74931 .58401 Mtetra
.74931 .58401 .75387 .58938 .76409 .58648 .75955 .58109 Mtetra
.75955 .58109 .76409 .58648 .77434 .58356 .76982 .57816 Mtetra
.76982 .57816 .77434 .58356 .78462 .58064 .78014 .57521 Mtetra
.78014 .57521 .78462 .58064 .79495 .57771 .79049 .57226 Mtetra
.79049 .57226 .79495 .57771 .80531 .57476 .80087 .5693 Mtetra
.80087 .5693 .80531 .57476 .81571 .57181 .8113 .56632 Mtetra
.8113 .56632 .81571 .57181 .82614 .56884 .82176 .56334 Mtetra
.82176 .56334 .82614 .56884 .83661 .56586 .83226 .56034 Mtetra
.83226 .56034 .83661 .56586 .84712 .56288 .8428 .55733 Mtetra
.8428 .55733 .84712 .56288 .85767 .55988 .85337 .55431 Mtetra
.85337 .55431 .85767 .55988 .86826 .55687 .86399 .55128 Mtetra
.86399 .55128 .86826 .55687 .87889 .55385 .87464 .54824 Mtetra
.87464 .54824 .87889 .55385 .88955 .55082 .88533 .54519 Mtetra
.88533 .54519 .88955 .55082 .90025 .54777 .89607 .54213 Mtetra
.89607 .54213 .90025 .54777 .911 .54472 .90684 .53905 Mtetra
.90684 .53905 .911 .54472 .92178 .54166 .91765 .53597 Mtetra
.91765 .53597 .92178 .54166 .9326 .53858 .9285 .53287 Mtetra
.9285 .53287 .9326 .53858 .94346 .53549 .93939 .52976 Mtetra
.93939 .52976 .94346 .53549 .95436 .53239 .95032 .52664 Mtetra
.95032 .52664 .95436 .53239 .9653 .52928 .96129 .52351 Mtetra
.96129 .52351 .9653 .52928 .97628 .52616 .9723 .52037 Mtetra
.38018 .68308 .38561 .68781 .39459 .68525 .38918 .6805 Mtetra
.38918 .6805 .39459 .68525 .40359 .68268 .3982 .67791 Mtetra
.3982 .67791 .40359 .68268 .41263 .6801 .40726 .67532 Mtetra
.40726 .67532 .41263 .6801 .4217 .67751 .41635 .67271 Mtetra
.41635 .67271 .4217 .67751 .4308 .67492 .42547 .6701 Mtetra
.42547 .6701 .4308 .67492 .43993 .67231 .43462 .66748 Mtetra
.43462 .66748 .43993 .67231 .44909 .6697 .4438 .66485 Mtetra
.4438 .66485 .44909 .6697 .45828 .66707 .45301 .66221 Mtetra
.45301 .66221 .45828 .66707 .46751 .66444 .46225 .65956 Mtetra
.46225 .65956 .46751 .66444 .47676 .6618 .47153 .6569 Mtetra
.47153 .6569 .47676 .6618 .48605 .65915 .48083 .65423 Mtetra
.48083 .65423 .48605 .65915 .49537 .65649 .49017 .65156 Mtetra
.49017 .65156 .49537 .65649 .50472 .65382 .49954 .64887 Mtetra
.49954 .64887 .50472 .65382 .5141 .65114 .50895 .64618 Mtetra
.50895 .64618 .5141 .65114 .52351 .64846 .51838 .64347 Mtetra
.51838 .64347 .52351 .64846 .53296 .64576 .52785 .64076 Mtetra
.52785 .64076 .53296 .64576 .54244 .64305 .53735 .63804 Mtetra
.53735 .63804 .54244 .64305 .55195 .64034 .54688 .6353 Mtetra
.54688 .6353 .55195 .64034 .56149 .63762 .55645 .63256 Mtetra
.55645 .63256 .56149 .63762 .57107 .63488 .56605 .62981 Mtetra
.56605 .62981 .57107 .63488 .58068 .63214 .57568 .62705 Mtetra
.57568 .62705 .58068 .63214 .59032 .62939 .58535 .62428 Mtetra
.58535 .62428 .59032 .62939 .6 .62663 .59505 .6215 Mtetra
.59505 .6215 .6 .62663 .60971 .62385 .60478 .61871 Mtetra
.60478 .61871 .60971 .62385 .61946 .62107 .61455 .61591 Mtetra
.61455 .61591 .61946 .62107 .62924 .61828 .62435 .6131 Mtetra
.62435 .6131 .62924 .61828 .63905 .61548 .63419 .61028 Mtetra
.63419 .61028 .63905 .61548 .6489 .61267 .64406 .60746 Mtetra
.64406 .60746 .6489 .61267 .65878 .60985 .65396 .60462 Mtetra
.65396 .60462 .65878 .60985 .6687 .60702 .66391 .60177 Mtetra
.66391 .60177 .6687 .60702 .67865 .60418 .67388 .59891 Mtetra
.67388 .59891 .67865 .60418 .68864 .60133 .68389 .59604 Mtetra
.68389 .59604 .68864 .60133 .69866 .59847 .69394 .59316 Mtetra
.69394 .59316 .69866 .59847 .70872 .5956 .70402 .59027 Mtetra
.70402 .59027 .70872 .5956 .71881 .59272 .71414 .58737 Mtetra
.71414 .58737 .71881 .59272 .72894 .58983 .7243 .58446 Mtetra
.7243 .58446 .72894 .58983 .73911 .58692 .73449 .58154 Mtetra
.73449 .58154 .73911 .58692 .74931 .58401 .74472 .57861 Mtetra
.74472 .57861 .74931 .58401 .75955 .58109 .75498 .57567 Mtetra
.75498 .57567 .75955 .58109 .76982 .57816 .76528 .57272 Mtetra
.76528 .57272 .76982 .57816 .78014 .57521 .77562 .56975 Mtetra
.77562 .56975 .78014 .57521 .79049 .57226 .786 .56678 Mtetra
.786 .56678 .79049 .57226 .80087 .5693 .79641 .5638 Mtetra
.79641 .5638 .80087 .5693 .8113 .56632 .80686 .5608 Mtetra
.80686 .5608 .8113 .56632 .82176 .56334 .81735 .55779 Mtetra
.81735 .55779 .82176 .56334 .83226 .56034 .82788 .55478 Mtetra
.82788 .55478 .83226 .56034 .8428 .55733 .83844 .55175 Mtetra
.83844 .55175 .8428 .55733 .85337 .55431 .84905 .54871 Mtetra
.84905 .54871 .85337 .55431 .86399 .55128 .85969 .54566 Mtetra
.85969 .54566 .86399 .55128 .87464 .54824 .87037 .5426 Mtetra
.87037 .5426 .87464 .54824 .88533 .54519 .88109 .53953 Mtetra
.88109 .53953 .88533 .54519 .89607 .54213 .89185 .53644 Mtetra
.89185 .53644 .89607 .54213 .90684 .53905 .90265 .53335 Mtetra
.90265 .53335 .90684 .53905 .91765 .53597 .91349 .53024 Mtetra
.91349 .53024 .91765 .53597 .9285 .53287 .92437 .52712 Mtetra
.92437 .52712 .9285 .53287 .93939 .52976 .93529 .524 Mtetra
.93529 .524 .93939 .52976 .95032 .52664 .94625 .52085 Mtetra
.94625 .52085 .95032 .52664 .96129 .52351 .95725 .5177 Mtetra
.95725 .5177 .96129 .52351 .9723 .52037 .96829 .51454 Mtetra
.37472 .67831 .38018 .68308 .38918 .6805 .38373 .67572 Mtetra
.38373 .67572 .38918 .6805 .3982 .67791 .39278 .67311 Mtetra
.39278 .67311 .3982 .67791 .40726 .67532 .40186 .6705 Mtetra
.40186 .6705 .40726 .67532 .41635 .67271 .41096 .66788 Mtetra
.41096 .66788 .41635 .67271 .42547 .6701 .4201 .66525 Mtetra
.4201 .66525 .42547 .6701 .43462 .66748 .42927 .66261 Mtetra
.42927 .66261 .43462 .66748 .4438 .66485 .43847 .65996 Mtetra
.43847 .65996 .4438 .66485 .45301 .66221 .4477 .65731 Mtetra
.4477 .65731 .45301 .66221 .46225 .65956 .45697 .65464 Mtetra
.45697 .65464 .46225 .65956 .47153 .6569 .46626 .65197 Mtetra
.46626 .65197 .47153 .6569 .48083 .65423 .47559 .64928 Mtetra
.47559 .64928 .48083 .65423 .49017 .65156 .48495 .64659 Mtetra
.48495 .64659 .49017 .65156 .49954 .64887 .49434 .64389 Mtetra
.49434 .64389 .49954 .64887 .50895 .64618 .50376 .64118 Mtetra
.50376 .64118 .50895 .64618 .51838 .64347 .51322 .63846 Mtetra
.51322 .63846 .51838 .64347 .52785 .64076 .52271 .63572 Mtetra
.52271 .63572 .52785 .64076 .53735 .63804 .53223 .63298 Mtetra
.53223 .63298 .53735 .63804 .54688 .6353 .54178 .63024 Mtetra
.54178 .63024 .54688 .6353 .55645 .63256 .55137 .62748 Mtetra
.55137 .62748 .55645 .63256 .56605 .62981 .56099 .62471 Mtetra
.56099 .62471 .56605 .62981 .57568 .62705 .57065 .62193 Mtetra
.57065 .62193 .57568 .62705 .58535 .62428 .58034 .61914 Mtetra
.58034 .61914 .58535 .62428 .59505 .6215 .59006 .61634 Mtetra
.59006 .61634 .59505 .6215 .60478 .61871 .59982 .61354 Mtetra
.59982 .61354 .60478 .61871 .61455 .61591 .60961 .61072 Mtetra
.60961 .61072 .61455 .61591 .62435 .6131 .61943 .60789 Mtetra
.61943 .60789 .62435 .6131 .63419 .61028 .62929 .60505 Mtetra
.62929 .60505 .63419 .61028 .64406 .60746 .63919 .60221 Mtetra
.63919 .60221 .64406 .60746 .65396 .60462 .64912 .59935 Mtetra
.64912 .59935 .65396 .60462 .66391 .60177 .65908 .59648 Mtetra
.65908 .59648 .66391 .60177 .67388 .59891 .66908 .5936 Mtetra
.66908 .5936 .67388 .59891 .68389 .59604 .67912 .59072 Mtetra
.67912 .59072 .68389 .59604 .69394 .59316 .68919 .58782 Mtetra
.68919 .58782 .69394 .59316 .70402 .59027 .6993 .58491 Mtetra
.6993 .58491 .70402 .59027 .71414 .58737 .70944 .58199 Mtetra
.70944 .58199 .71414 .58737 .7243 .58446 .71962 .57906 Mtetra
.71962 .57906 .7243 .58446 .73449 .58154 .72984 .57612 Mtetra
.72984 .57612 .73449 .58154 .74472 .57861 .74009 .57317 Mtetra
.74009 .57317 .74472 .57861 .75498 .57567 .75038 .57021 Mtetra
.75038 .57021 .75498 .57567 .76528 .57272 .76071 .56724 Mtetra
.76071 .56724 .76528 .57272 .77562 .56975 .77107 .56426 Mtetra
.77107 .56426 .77562 .56975 .786 .56678 .78148 .56126 Mtetra
.78148 .56126 .786 .56678 .79641 .5638 .79192 .55826 Mtetra
.79192 .55826 .79641 .5638 .80686 .5608 .80239 .55524 Mtetra
.80239 .55524 .80686 .5608 .81735 .55779 .81291 .55222 Mtetra
.81291 .55222 .81735 .55779 .82788 .55478 .82346 .54918 Mtetra
.82346 .54918 .82788 .55478 .83844 .55175 .83406 .54613 Mtetra
.83406 .54613 .83844 .55175 .84905 .54871 .84469 .54307 Mtetra
.84469 .54307 .84905 .54871 .85969 .54566 .85536 .54 Mtetra
.85536 .54 .85969 .54566 .87037 .5426 .86607 .53692 Mtetra
.86607 .53692 .87037 .5426 .88109 .53953 .87682 .53383 Mtetra
.87682 .53383 .88109 .53953 .89185 .53644 .88761 .53072 Mtetra
.88761 .53072 .89185 .53644 .90265 .53335 .89844 .52761 Mtetra
.89844 .52761 .90265 .53335 .91349 .53024 .90931 .52448 Mtetra
.90931 .52448 .91349 .53024 .92437 .52712 .92022 .52134 Mtetra
.92022 .52134 .92437 .52712 .93529 .524 .93116 .51819 Mtetra
.93116 .51819 .93529 .524 .94625 .52085 .94216 .51503 Mtetra
.94216 .51503 .94625 .52085 .95725 .5177 .95319 .51185 Mtetra
.95319 .51185 .95725 .5177 .96829 .51454 .96426 .50866 Mtetra
.36922 .67351 .37472 .67831 .38373 .67572 .37826 .6709 Mtetra
.37826 .6709 .38373 .67572 .39278 .67311 .38732 .66828 Mtetra
.38732 .66828 .39278 .67311 .40186 .6705 .39642 .66566 Mtetra
.39642 .66566 .40186 .6705 .41096 .66788 .40554 .66302 Mtetra
.40554 .66302 .41096 .66788 .4201 .66525 .4147 .66037 Mtetra
.4147 .66037 .4201 .66525 .42927 .66261 .42389 .65772 Mtetra
.42389 .65772 .42927 .66261 .43847 .65996 .43311 .65505 Mtetra
.43311 .65505 .43847 .65996 .4477 .65731 .44236 .65238 Mtetra
.44236 .65238 .4477 .65731 .45697 .65464 .45165 .6497 Mtetra
.45165 .6497 .45697 .65464 .46626 .65197 .46096 .64701 Mtetra
.46096 .64701 .46626 .65197 .47559 .64928 .47031 .6443 Mtetra
.47031 .6443 .47559 .64928 .48495 .64659 .47969 .64159 Mtetra
.47969 .64159 .48495 .64659 .49434 .64389 .4891 .63887 Mtetra
.4891 .63887 .49434 .64389 .50376 .64118 .49855 .63615 Mtetra
.49855 .63615 .50376 .64118 .51322 .63846 .50802 .63341 Mtetra
.50802 .63341 .51322 .63846 .52271 .63572 .51753 .63066 Mtetra
.51753 .63066 .52271 .63572 .53223 .63298 .52708 .6279 Mtetra
.52708 .6279 .53223 .63298 .54178 .63024 .53665 .62513 Mtetra
.53665 .62513 .54178 .63024 .55137 .62748 .54626 .62236 Mtetra
.54626 .62236 .55137 .62748 .56099 .62471 .55591 .61957 Mtetra
.55591 .61957 .56099 .62471 .57065 .62193 .56558 .61677 Mtetra
.56558 .61677 .57065 .62193 .58034 .61914 .57529 .61397 Mtetra
.57529 .61397 .58034 .61914 .59006 .61634 .58504 .61115 Mtetra
.58504 .61115 .59006 .61634 .59982 .61354 .59482 .60833 Mtetra
.59482 .60833 .59982 .61354 .60961 .61072 .60463 .60549 Mtetra
.60463 .60549 .60961 .61072 .61943 .60789 .61448 .60265 Mtetra
.61448 .60265 .61943 .60789 .62929 .60505 .62437 .59979 Mtetra
.62437 .59979 .62929 .60505 .63919 .60221 .63428 .59692 Mtetra
.63428 .59692 .63919 .60221 .64912 .59935 .64424 .59405 Mtetra
.64424 .59405 .64912 .59935 .65908 .59648 .65423 .59116 Mtetra
.65423 .59116 .65908 .59648 .66908 .5936 .66425 .58826 Mtetra
.66425 .58826 .66908 .5936 .67912 .59072 .67431 .58536 Mtetra
.67431 .58536 .67912 .59072 .68919 .58782 .68441 .58244 Mtetra
.68441 .58244 .68919 .58782 .6993 .58491 .69454 .57951 Mtetra
.69454 .57951 .6993 .58491 .70944 .58199 .70471 .57657 Mtetra
.70471 .57657 .70944 .58199 .71962 .57906 .71491 .57363 Mtetra
.71491 .57363 .71962 .57906 .72984 .57612 .72516 .57067 Mtetra
.72516 .57067 .72984 .57612 .74009 .57317 .73544 .5677 Mtetra
.73544 .5677 .74009 .57317 .75038 .57021 .74575 .56471 Mtetra
.74575 .56471 .75038 .57021 .76071 .56724 .75611 .56172 Mtetra
.75611 .56172 .76071 .56724 .77107 .56426 .7665 .55872 Mtetra
.7665 .55872 .77107 .56426 .78148 .56126 .77693 .55571 Mtetra
.77693 .55571 .78148 .56126 .79192 .55826 .78739 .55268 Mtetra
.78739 .55268 .79192 .55826 .80239 .55524 .7979 .54965 Mtetra
.7979 .54965 .80239 .55524 .81291 .55222 .80844 .5466 Mtetra
.80844 .5466 .81291 .55222 .82346 .54918 .81902 .54354 Mtetra
.81902 .54354 .82346 .54918 .83406 .54613 .82964 .54047 Mtetra
.82964 .54047 .83406 .54613 .84469 .54307 .8403 .53739 Mtetra
.8403 .53739 .84469 .54307 .85536 .54 .851 .5343 Mtetra
.851 .5343 .85536 .54 .86607 .53692 .86174 .5312 Mtetra
.86174 .5312 .86607 .53692 .87682 .53383 .87252 .52809 Mtetra
.87252 .52809 .87682 .53383 .88761 .53072 .88334 .52496 Mtetra
.88334 .52496 .88761 .53072 .89844 .52761 .89419 .52182 Mtetra
.89419 .52182 .89844 .52761 .90931 .52448 .90509 .51867 Mtetra
.90509 .51867 .90931 .52448 .92022 .52134 .91603 .51551 Mtetra
.91603 .51551 .92022 .52134 .93116 .51819 .92701 .51234 Mtetra
.92701 .51234 .93116 .51819 .94216 .51503 .93803 .50916 Mtetra
.93803 .50916 .94216 .51503 .95319 .51185 .94909 .50596 Mtetra
.94909 .50596 .95319 .51185 .96426 .50866 .9602 .50275 Mtetra
.36369 .66869 .36922 .67351 .37826 .6709 .37275 .66606 Mtetra
.37275 .66606 .37826 .6709 .38732 .66828 .38183 .66342 Mtetra
.38183 .66342 .38732 .66828 .39642 .66566 .39094 .66078 Mtetra
.39094 .66078 .39642 .66566 .40554 .66302 .40009 .65813 Mtetra
.40009 .65813 .40554 .66302 .4147 .66037 .40927 .65546 Mtetra
.40927 .65546 .4147 .66037 .42389 .65772 .41848 .65279 Mtetra
.41848 .65279 .42389 .65772 .43311 .65505 .42772 .65011 Mtetra
.42772 .65011 .43311 .65505 .44236 .65238 .43699 .64742 Mtetra
.43699 .64742 .44236 .65238 .45165 .6497 .44629 .64472 Mtetra
.44629 .64472 .45165 .6497 .46096 .64701 .45563 .64201 Mtetra
.45563 .64201 .46096 .64701 .47031 .6443 .465 .63929 Mtetra
.465 .63929 .47031 .6443 .47969 .64159 .4744 .63657 Mtetra
.4744 .63657 .47969 .64159 .4891 .63887 .48383 .63383 Mtetra
.48383 .63383 .4891 .63887 .49855 .63615 .4933 .63108 Mtetra
.4933 .63108 .49855 .63615 .50802 .63341 .50279 .62833 Mtetra
.50279 .62833 .50802 .63341 .51753 .63066 .51233 .62556 Mtetra
.51233 .62556 .51753 .63066 .52708 .6279 .52189 .62279 Mtetra
.52189 .62279 .52708 .6279 .53665 .62513 .53149 .62 Mtetra
.53149 .62 .53665 .62513 .54626 .62236 .54112 .61721 Mtetra
.54112 .61721 .54626 .62236 .55591 .61957 .55079 .6144 Mtetra
.55079 .6144 .55591 .61957 .56558 .61677 .56049 .61159 Mtetra
.56049 .61159 .56558 .61677 .57529 .61397 .57022 .60876 Mtetra
.57022 .60876 .57529 .61397 .58504 .61115 .57999 .60593 Mtetra
.57999 .60593 .58504 .61115 .59482 .60833 .58979 .60308 Mtetra
.58979 .60308 .59482 .60833 .60463 .60549 .59963 .60023 Mtetra
.59963 .60023 .60463 .60549 .61448 .60265 .6095 .59737 Mtetra
.6095 .59737 .61448 .60265 .62437 .59979 .61941 .59449 Mtetra
.61941 .59449 .62437 .59979 .63428 .59692 .62935 .59161 Mtetra
.62935 .59161 .63428 .59692 .64424 .59405 .63933 .58871 Mtetra
.63933 .58871 .64424 .59405 .65423 .59116 .64934 .58581 Mtetra
.64934 .58581 .65423 .59116 .66425 .58826 .65939 .58289 Mtetra
.65939 .58289 .66425 .58826 .67431 .58536 .66947 .57996 Mtetra
.66947 .57996 .67431 .58536 .68441 .58244 .67959 .57703 Mtetra
.67959 .57703 .68441 .58244 .69454 .57951 .68975 .57408 Mtetra
.68975 .57408 .69454 .57951 .70471 .57657 .69995 .57112 Mtetra
.69995 .57112 .70471 .57657 .71491 .57363 .71018 .56815 Mtetra
.71018 .56815 .71491 .57363 .72516 .57067 .72044 .56517 Mtetra
.72044 .56517 .72516 .57067 .73544 .5677 .73075 .56218 Mtetra
.73075 .56218 .73544 .5677 .74575 .56471 .74109 .55918 Mtetra
.74109 .55918 .74575 .56471 .75611 .56172 .75147 .55617 Mtetra
.75147 .55617 .75611 .56172 .7665 .55872 .76189 .55315 Mtetra
.76189 .55315 .7665 .55872 .77693 .55571 .77234 .55012 Mtetra
.77234 .55012 .77693 .55571 .78739 .55268 .78284 .54707 Mtetra
.78284 .54707 .78739 .55268 .7979 .54965 .79337 .54401 Mtetra
.79337 .54401 .7979 .54965 .80844 .5466 .80394 .54095 Mtetra
.80394 .54095 .80844 .5466 .81902 .54354 .81455 .53787 Mtetra
.81455 .53787 .81902 .54354 .82964 .54047 .8252 .53478 Mtetra
.8252 .53478 .82964 .54047 .8403 .53739 .83589 .53168 Mtetra
.83589 .53168 .8403 .53739 .851 .5343 .84661 .52857 Mtetra
.84661 .52857 .851 .5343 .86174 .5312 .85738 .52544 Mtetra
.85738 .52544 .86174 .5312 .87252 .52809 .86819 .52231 Mtetra
.86819 .52231 .87252 .52809 .88334 .52496 .87903 .51916 Mtetra
.87903 .51916 .88334 .52496 .89419 .52182 .88992 .516 Mtetra
.88992 .516 .89419 .52182 .90509 .51867 .90085 .51283 Mtetra
.90085 .51283 .90509 .51867 .91603 .51551 .91182 .50965 Mtetra
.91182 .50965 .91603 .51551 .92701 .51234 .92283 .50645 Mtetra
.92283 .50645 .92701 .51234 .93803 .50916 .93388 .50324 Mtetra
.93388 .50324 .93803 .50916 .94909 .50596 .94497 .50003 Mtetra
.94497 .50003 .94909 .50596 .9602 .50275 .9561 .4968 Mtetra
.35813 .66383 .36369 .66869 .37275 .66606 .3672 .66119 Mtetra
.3672 .66119 .37275 .66606 .38183 .66342 .3763 .65854 Mtetra
.3763 .65854 .38183 .66342 .39094 .66078 .38544 .65587 Mtetra
.38544 .65587 .39094 .66078 .40009 .65813 .3946 .6532 Mtetra
.3946 .6532 .40009 .65813 .40927 .65546 .4038 .65052 Mtetra
.4038 .65052 .40927 .65546 .41848 .65279 .41303 .64783 Mtetra
.41303 .64783 .41848 .65279 .42772 .65011 .42229 .64514 Mtetra
.42229 .64514 .42772 .65011 .43699 .64742 .43158 .64243 Mtetra
.43158 .64243 .43699 .64742 .44629 .64472 .4409 .63971 Mtetra
.4409 .63971 .44629 .64472 .45563 .64201 .45026 .63699 Mtetra
.45026 .63699 .45563 .64201 .465 .63929 .45965 .63425 Mtetra
.45965 .63425 .465 .63929 .4744 .63657 .46907 .63151 Mtetra
.46907 .63151 .4744 .63657 .48383 .63383 .47853 .62875 Mtetra
.47853 .62875 .48383 .63383 .4933 .63108 .48801 .62599 Mtetra
.48801 .62599 .4933 .63108 .50279 .62833 .49753 .62321 Mtetra
.49753 .62321 .50279 .62833 .51233 .62556 .50709 .62043 Mtetra
.50709 .62043 .51233 .62556 .52189 .62279 .51667 .61764 Mtetra
.51667 .61764 .52189 .62279 .53149 .62 .52629 .61483 Mtetra
.52629 .61483 .53149 .62 .54112 .61721 .53595 .61202 Mtetra
.53595 .61202 .54112 .61721 .55079 .6144 .54563 .6092 Mtetra
.54563 .6092 .55079 .6144 .56049 .61159 .55536 .60636 Mtetra
.55536 .60636 .56049 .61159 .57022 .60876 .56511 .60352 Mtetra
.56511 .60352 .57022 .60876 .57999 .60593 .5749 .60067 Mtetra
.5749 .60067 .57999 .60593 .58979 .60308 .58473 .59781 Mtetra
.58473 .59781 .58979 .60308 .59963 .60023 .59459 .59493 Mtetra
.59459 .59493 .59963 .60023 .6095 .59737 .60448 .59205 Mtetra
.60448 .59205 .6095 .59737 .61941 .59449 .61441 .58916 Mtetra
.61441 .58916 .61941 .59449 .62935 .59161 .62438 .58625 Mtetra
.62438 .58625 .62935 .59161 .63933 .58871 .63438 .58334 Mtetra
.63438 .58334 .63933 .58871 .64934 .58581 .64442 .58041 Mtetra
.64442 .58041 .64934 .58581 .65939 .58289 .65449 .57748 Mtetra
.65449 .57748 .65939 .58289 .66947 .57996 .6646 .57453 Mtetra
.6646 .57453 .66947 .57996 .67959 .57703 .67475 .57158 Mtetra
.67475 .57158 .67959 .57703 .68975 .57408 .68493 .56861 Mtetra
.68493 .56861 .68975 .57408 .69995 .57112 .69515 .56563 Mtetra
.69515 .56563 .69995 .57112 .71018 .56815 .70541 .56264 Mtetra
.70541 .56264 .71018 .56815 .72044 .56517 .7157 .55965 Mtetra
.7157 .55965 .72044 .56517 .73075 .56218 .72603 .55664 Mtetra
.72603 .55664 .73075 .56218 .74109 .55918 .7364 .55361 Mtetra
.7364 .55361 .74109 .55918 .75147 .55617 .7468 .55058 Mtetra
.7468 .55058 .75147 .55617 .76189 .55315 .75725 .54754 Mtetra
.75725 .54754 .76189 .55315 .77234 .55012 .76773 .54449 Mtetra
.76773 .54449 .77234 .55012 .78284 .54707 .77825 .54142 Mtetra
.77825 .54142 .78284 .54707 .79337 .54401 .78881 .53834 Mtetra
.78881 .53834 .79337 .54401 .80394 .54095 .79941 .53526 Mtetra
.79941 .53526 .80394 .54095 .81455 .53787 .81005 .53216 Mtetra
.81005 .53216 .81455 .53787 .8252 .53478 .82072 .52905 Mtetra
.82072 .52905 .8252 .53478 .83589 .53168 .83144 .52592 Mtetra
.83144 .52592 .83589 .53168 .84661 .52857 .84219 .52279 Mtetra
.84219 .52279 .84661 .52857 .85738 .52544 .85299 .51964 Mtetra
.85299 .51964 .85738 .52544 .86819 .52231 .86383 .51649 Mtetra
.86383 .51649 .86819 .52231 .87903 .51916 .8747 .51332 Mtetra
.8747 .51332 .87903 .51916 .88992 .516 .88562 .51014 Mtetra
.88562 .51014 .88992 .516 .90085 .51283 .89658 .50694 Mtetra
.89658 .50694 .90085 .51283 .91182 .50965 .90758 .50374 Mtetra
.90758 .50374 .91182 .50965 .92283 .50645 .91862 .50052 Mtetra
.91862 .50052 .92283 .50645 .93388 .50324 .9297 .49729 Mtetra
.9297 .49729 .93388 .50324 .94497 .50003 .94082 .49405 Mtetra
.94082 .49405 .94497 .50003 .9561 .4968 .95198 .4908 Mtetra
.35253 .65894 .35813 .66383 .3672 .66119 .36162 .65628 Mtetra
.36162 .65628 .3672 .66119 .3763 .65854 .37074 .65361 Mtetra
.37074 .65361 .3763 .65854 .38544 .65587 .3799 .65094 Mtetra
.3799 .65094 .38544 .65587 .3946 .6532 .38908 .64825 Mtetra
.38908 .64825 .3946 .6532 .4038 .65052 .3983 .64555 Mtetra
.3983 .64555 .4038 .65052 .41303 .64783 .40755 .64285 Mtetra
.40755 .64285 .41303 .64783 .42229 .64514 .41683 .64013 Mtetra
.41683 .64013 .42229 .64514 .43158 .64243 .42614 .63741 Mtetra
.42614 .63741 .43158 .64243 .4409 .63971 .43548 .63467 Mtetra
.43548 .63467 .4409 .63971 .45026 .63699 .44486 .63193 Mtetra
.44486 .63193 .45026 .63699 .45965 .63425 .45427 .62918 Mtetra
.45427 .62918 .45965 .63425 .46907 .63151 .46371 .62641 Mtetra
.46371 .62641 .46907 .63151 .47853 .62875 .47319 .62364 Mtetra
.47319 .62364 .47853 .62875 .48801 .62599 .48269 .62086 Mtetra
.48269 .62086 .48801 .62599 .49753 .62321 .49224 .61807 Mtetra
.49224 .61807 .49753 .62321 .50709 .62043 .50181 .61527 Mtetra
.50181 .61527 .50709 .62043 .51667 .61764 .51142 .61245 Mtetra
.51142 .61245 .51667 .61764 .52629 .61483 .52106 .60963 Mtetra
.52106 .60963 .52629 .61483 .53595 .61202 .53074 .6068 Mtetra
.53074 .6068 .53595 .61202 .54563 .6092 .54045 .60396 Mtetra
.54045 .60396 .54563 .6092 .55536 .60636 .55019 .60111 Mtetra
.55019 .60111 .55536 .60636 .56511 .60352 .55997 .59825 Mtetra
.55997 .59825 .56511 .60352 .5749 .60067 .56978 .59538 Mtetra
.56978 .59538 .5749 .60067 .58473 .59781 .57963 .59249 Mtetra
.57963 .59249 .58473 .59781 .59459 .59493 .58952 .5896 Mtetra
.58952 .5896 .59459 .59493 .60448 .59205 .59944 .5867 Mtetra
.59944 .5867 .60448 .59205 .61441 .58916 .60939 .58379 Mtetra
.60939 .58379 .61441 .58916 .62438 .58625 .61938 .58087 Mtetra
.61938 .58087 .62438 .58625 .63438 .58334 .62941 .57793 Mtetra
.62941 .57793 .63438 .58334 .64442 .58041 .63947 .57499 Mtetra
.63947 .57499 .64442 .58041 .65449 .57748 .64957 .57203 Mtetra
.64957 .57203 .65449 .57748 .6646 .57453 .6597 .56907 Mtetra
.6597 .56907 .6646 .57453 .67475 .57158 .66987 .56609 Mtetra
.66987 .56609 .67475 .57158 .68493 .56861 .68008 .56311 Mtetra
.68008 .56311 .68493 .56861 .69515 .56563 .69032 .56011 Mtetra
.69032 .56011 .69515 .56563 .70541 .56264 .7006 .5571 Mtetra
.7006 .5571 .70541 .56264 .7157 .55965 .71092 .55408 Mtetra
.71092 .55408 .7157 .55965 .72603 .55664 .72128 .55105 Mtetra
.72128 .55105 .72603 .55664 .7364 .55361 .73168 .54801 Mtetra
.73168 .54801 .7364 .55361 .7468 .55058 .74211 .54496 Mtetra
.74211 .54496 .7468 .55058 .75725 .54754 .75258 .54189 Mtetra
.75258 .54189 .75725 .54754 .76773 .54449 .76309 .53882 Mtetra
.76309 .53882 .76773 .54449 .77825 .54142 .77364 .53573 Mtetra
.77364 .53573 .77825 .54142 .78881 .53834 .78422 .53263 Mtetra
.78422 .53263 .78881 .53834 .79941 .53526 .79485 .52952 Mtetra
.79485 .52952 .79941 .53526 .81005 .53216 .80551 .5264 Mtetra
.80551 .5264 .81005 .53216 .82072 .52905 .81622 .52327 Mtetra
.81622 .52327 .82072 .52905 .83144 .52592 .82696 .52013 Mtetra
.82696 .52013 .83144 .52592 .84219 .52279 .83775 .51697 Mtetra
.83775 .51697 .84219 .52279 .85299 .51964 .84857 .51381 Mtetra
.84857 .51381 .85299 .51964 .86383 .51649 .85944 .51063 Mtetra
.85944 .51063 .86383 .51649 .8747 .51332 .87034 .50744 Mtetra
.87034 .50744 .8747 .51332 .88562 .51014 .88129 .50423 Mtetra
.88129 .50423 .88562 .51014 .89658 .50694 .89227 .50102 Mtetra
.89227 .50102 .89658 .50694 .90758 .50374 .9033 .49779 Mtetra
.9033 .49779 .90758 .50374 .91862 .50052 .91437 .49455 Mtetra
.91437 .49455 .91862 .50052 .9297 .49729 .92549 .4913 Mtetra
.92549 .4913 .9297 .49729 .94082 .49405 .93664 .48804 Mtetra
.93664 .48804 .94082 .49405 .95198 .4908 .94784 .48476 Mtetra
.34689 .65403 .35253 .65894 .36162 .65628 .356 .65135 Mtetra
.356 .65135 .36162 .65628 .37074 .65361 .36515 .64866 Mtetra
.36515 .64866 .37074 .65361 .3799 .65094 .37432 .64597 Mtetra
.37432 .64597 .3799 .65094 .38908 .64825 .38352 .64326 Mtetra
.38352 .64326 .38908 .64825 .3983 .64555 .39276 .64055 Mtetra
.39276 .64055 .3983 .64555 .40755 .64285 .40203 .63783 Mtetra
.40203 .63783 .40755 .64285 .41683 .64013 .41133 .63509 Mtetra
.41133 .63509 .41683 .64013 .42614 .63741 .42066 .63235 Mtetra
.42066 .63235 .42614 .63741 .43548 .63467 .43003 .6296 Mtetra
.43003 .6296 .43548 .63467 .44486 .63193 .43942 .62684 Mtetra
.43942 .62684 .44486 .63193 .45427 .62918 .44885 .62407 Mtetra
.44885 .62407 .45427 .62918 .46371 .62641 .45832 .62129 Mtetra
.45832 .62129 .46371 .62641 .47319 .62364 .46781 .6185 Mtetra
.46781 .6185 .47319 .62364 .48269 .62086 .47734 .6157 Mtetra
.47734 .6157 .48269 .62086 .49224 .61807 .4869 .61289 Mtetra
.4869 .61289 .49224 .61807 .50181 .61527 .4965 .61007 Mtetra
.4965 .61007 .50181 .61527 .51142 .61245 .50613 .60724 Mtetra
.50613 .60724 .51142 .61245 .52106 .60963 .5158 .6044 Mtetra
.5158 .6044 .52106 .60963 .53074 .6068 .52549 .60155 Mtetra
.52549 .60155 .53074 .6068 .54045 .60396 .53523 .59869 Mtetra
.53523 .59869 .54045 .60396 .55019 .60111 .54499 .59582 Mtetra
.54499 .59582 .55019 .60111 .55997 .59825 .5548 .59294 Mtetra
.5548 .59294 .55997 .59825 .56978 .59538 .56463 .59005 Mtetra
.56463 .59005 .56978 .59538 .57963 .59249 .5745 .58715 Mtetra
.5745 .58715 .57963 .59249 .58952 .5896 .58441 .58424 Mtetra
.58441 .58424 .58952 .5896 .59944 .5867 .59435 .58132 Mtetra
.59435 .58132 .59944 .5867 .60939 .58379 .60433 .57838 Mtetra
.60433 .57838 .60939 .58379 .61938 .58087 .61435 .57544 Mtetra
.61435 .57544 .61938 .58087 .62941 .57793 .6244 .57249 Mtetra
.6244 .57249 .62941 .57793 .63947 .57499 .63448 .56952 Mtetra
.63448 .56952 .63947 .57499 .64957 .57203 .6446 .56655 Mtetra
.6446 .56655 .64957 .57203 .6597 .56907 .65476 .56357 Mtetra
.65476 .56357 .6597 .56907 .66987 .56609 .66496 .56057 Mtetra
.66496 .56057 .66987 .56609 .68008 .56311 .67519 .55756 Mtetra
.67519 .55756 .68008 .56311 .69032 .56011 .68546 .55455 Mtetra
.68546 .55455 .69032 .56011 .7006 .5571 .69577 .55152 Mtetra
.69577 .55152 .7006 .5571 .71092 .55408 .70612 .54848 Mtetra
.70612 .54848 .71092 .55408 .72128 .55105 .7165 .54543 Mtetra
.7165 .54543 .72128 .55105 .73168 .54801 .72692 .54236 Mtetra
.72692 .54236 .73168 .54801 .74211 .54496 .73738 .53929 Mtetra
.73738 .53929 .74211 .54496 .75258 .54189 .74788 .53621 Mtetra
.74788 .53621 .75258 .54189 .76309 .53882 .75841 .53311 Mtetra
.75841 .53311 .76309 .53882 .77364 .53573 .76899 .53 Mtetra
.76899 .53 .77364 .53573 .78422 .53263 .7796 .52688 Mtetra
.7796 .52688 .78422 .53263 .79485 .52952 .79026 .52375 Mtetra
.79026 .52375 .79485 .52952 .80551 .5264 .80095 .52061 Mtetra
.80095 .52061 .80551 .5264 .81622 .52327 .81168 .51746 Mtetra
.81168 .51746 .81622 .52327 .82696 .52013 .82245 .51429 Mtetra
.82245 .51429 .82696 .52013 .83775 .51697 .83327 .51112 Mtetra
.83327 .51112 .83775 .51697 .84857 .51381 .84412 .50793 Mtetra
.84412 .50793 .84857 .51381 .85944 .51063 .85501 .50473 Mtetra
.85501 .50473 .85944 .51063 .87034 .50744 .86595 .50151 Mtetra
.86595 .50151 .87034 .50744 .88129 .50423 .87693 .49829 Mtetra
.87693 .49829 .88129 .50423 .89227 .50102 .88794 .49505 Mtetra
.88794 .49505 .89227 .50102 .9033 .49779 .899 .4918 Mtetra
.899 .4918 .9033 .49779 .91437 .49455 .9101 .48854 Mtetra
.9101 .48854 .91437 .49455 .92549 .4913 .92125 .48527 Mtetra
.92125 .48527 .92549 .4913 .93664 .48804 .93243 .48198 Mtetra
.93243 .48198 .93664 .48804 .94784 .48476 .94366 .47868 Mtetra
.34122 .64908 .34689 .65403 .356 .65135 .35035 .64638 Mtetra
.35035 .64638 .356 .65135 .36515 .64866 .35951 .64368 Mtetra
.35951 .64368 .36515 .64866 .37432 .64597 .36871 .64097 Mtetra
.36871 .64097 .37432 .64597 .38352 .64326 .37793 .63825 Mtetra
.37793 .63825 .38352 .64326 .39276 .64055 .38719 .63551 Mtetra
.38719 .63551 .39276 .64055 .40203 .63783 .39647 .63277 Mtetra
.39647 .63277 .40203 .63783 .41133 .63509 .40579 .63002 Mtetra
.40579 .63002 .41133 .63509 .42066 .63235 .41515 .62726 Mtetra
.41515 .62726 .42066 .63235 .43003 .6296 .42453 .62449 Mtetra
.42453 .62449 .43003 .6296 .43942 .62684 .43395 .62172 Mtetra
.43395 .62172 .43942 .62684 .44885 .62407 .4434 .61893 Mtetra
.4434 .61893 .44885 .62407 .45832 .62129 .45289 .61613 Mtetra
.45289 .61613 .45832 .62129 .46781 .6185 .4624 .61332 Mtetra
.4624 .61332 .46781 .6185 .47734 .6157 .47195 .6105 Mtetra
.47195 .6105 .47734 .6157 .4869 .61289 .48154 .60767 Mtetra
.48154 .60767 .4869 .61289 .4965 .61007 .49116 .60484 Mtetra
.49116 .60484 .4965 .61007 .50613 .60724 .50081 .60199 Mtetra
.50081 .60199 .50613 .60724 .5158 .6044 .5105 .59913 Mtetra
.5105 .59913 .5158 .6044 .52549 .60155 .52022 .59626 Mtetra
.52022 .59626 .52549 .60155 .53523 .59869 .52997 .59338 Mtetra
.52997 .59338 .53523 .59869 .54499 .59582 .53976 .59049 Mtetra
.53976 .59049 .54499 .59582 .5548 .59294 .54959 .58759 Mtetra
.54959 .58759 .5548 .59294 .56463 .59005 .55945 .58469 Mtetra
.55945 .58469 .56463 .59005 .5745 .58715 .56934 .58177 Mtetra
.56934 .58177 .5745 .58715 .58441 .58424 .57927 .57884 Mtetra
.57927 .57884 .58441 .58424 .59435 .58132 .58924 .57589 Mtetra
.58924 .57589 .59435 .58132 .60433 .57838 .59924 .57294 Mtetra
.59924 .57294 .60433 .57838 .61435 .57544 .60928 .56998 Mtetra
.60928 .56998 .61435 .57544 .6244 .57249 .61935 .56701 Mtetra
.61935 .56701 .6244 .57249 .63448 .56952 .62946 .56403 Mtetra
.62946 .56403 .63448 .56952 .6446 .56655 .63961 .56103 Mtetra
.63961 .56103 .6446 .56655 .65476 .56357 .64979 .55803 Mtetra
.64979 .55803 .65476 .56357 .66496 .56057 .66002 .55501 Mtetra
.66002 .55501 .66496 .56057 .67519 .55756 .67027 .55198 Mtetra
.67027 .55198 .67519 .55756 .68546 .55455 .68057 .54895 Mtetra
.68057 .54895 .68546 .55455 .69577 .55152 .6909 .5459 Mtetra
.6909 .5459 .69577 .55152 .70612 .54848 .70127 .54284 Mtetra
.70127 .54284 .70612 .54848 .7165 .54543 .71168 .53976 Mtetra
.71168 .53976 .7165 .54543 .72692 .54236 .72213 .53668 Mtetra
.72213 .53668 .72692 .54236 .73738 .53929 .73262 .53359 Mtetra
.73262 .53359 .73738 .53929 .74788 .53621 .74314 .53048 Mtetra
.74314 .53048 .74788 .53621 .75841 .53311 .75371 .52737 Mtetra
.75371 .52737 .75841 .53311 .76899 .53 .76431 .52424 Mtetra
.76431 .52424 .76899 .53 .7796 .52688 .77495 .5211 Mtetra
.77495 .5211 .7796 .52688 .79026 .52375 .78563 .51794 Mtetra
.78563 .51794 .79026 .52375 .80095 .52061 .79635 .51478 Mtetra
.79635 .51478 .80095 .52061 .81168 .51746 .80711 .51161 Mtetra
.80711 .51161 .81168 .51746 .82245 .51429 .81792 .50842 Mtetra
.81792 .50842 .82245 .51429 .83327 .51112 .82876 .50522 Mtetra
.82876 .50522 .83327 .51112 .84412 .50793 .83964 .50201 Mtetra
.83964 .50201 .84412 .50793 .85501 .50473 .85056 .49879 Mtetra
.85056 .49879 .85501 .50473 .86595 .50151 .86153 .49555 Mtetra
.86153 .49555 .86595 .50151 .87693 .49829 .87253 .4923 Mtetra
.87253 .4923 .87693 .49829 .88794 .49505 .88358 .48904 Mtetra
.88358 .48904 .88794 .49505 .899 .4918 .89467 .48577 Mtetra
.89467 .48577 .899 .4918 .9101 .48854 .9058 .48249 Mtetra
.9058 .48249 .9101 .48854 .92125 .48527 .91698 .47919 Mtetra
.91698 .47919 .92125 .48527 .93243 .48198 .92819 .47588 Mtetra
.92819 .47588 .93243 .48198 .94366 .47868 .93945 .47256 Mtetra
.33552 .6441 .34122 .64908 .35035 .64638 .34467 .64139 Mtetra
.34467 .64139 .35035 .64638 .35951 .64368 .35385 .63866 Mtetra
.35385 .63866 .35951 .64368 .36871 .64097 .36306 .63594 Mtetra
.36306 .63594 .36871 .64097 .37793 .63825 .3723 .6332 Mtetra
.3723 .6332 .37793 .63825 .38719 .63551 .38158 .63045 Mtetra
.38158 .63045 .38719 .63551 .39647 .63277 .39089 .62769 Mtetra
.39089 .62769 .39647 .63277 .40579 .63002 .40023 .62492 Mtetra
.40023 .62492 .40579 .63002 .41515 .62726 .4096 .62214 Mtetra
.4096 .62214 .41515 .62726 .42453 .62449 .41901 .61936 Mtetra
.41901 .61936 .42453 .62449 .43395 .62172 .42844 .61656 Mtetra
.42844 .61656 .43395 .62172 .4434 .61893 .43792 .61375 Mtetra
.43792 .61375 .4434 .61893 .45289 .61613 .44742 .61094 Mtetra
.44742 .61094 .45289 .61613 .4624 .61332 .45696 .60811 Mtetra
.45696 .60811 .4624 .61332 .47195 .6105 .46653 .60527 Mtetra
.46653 .60527 .47195 .6105 .48154 .60767 .47614 .60243 Mtetra
.47614 .60243 .48154 .60767 .49116 .60484 .48578 .59957 Mtetra
.48578 .59957 .49116 .60484 .50081 .60199 .49545 .5967 Mtetra
.49545 .5967 .50081 .60199 .5105 .59913 .50516 .59383 Mtetra
.50516 .59383 .5105 .59913 .52022 .59626 .5149 .59094 Mtetra
.5149 .59094 .52022 .59626 .52997 .59338 .52468 .58804 Mtetra
.52468 .58804 .52997 .59338 .53976 .59049 .5345 .58513 Mtetra
.5345 .58513 .53976 .59049 .54959 .58759 .54434 .58222 Mtetra
.54434 .58222 .54959 .58759 .55945 .58469 .55423 .57929 Mtetra
.55423 .57929 .55945 .58469 .56934 .58177 .56414 .57635 Mtetra
.56414 .57635 .56934 .58177 .57927 .57884 .5741 .5734 Mtetra
.5741 .5734 .57927 .57884 .58924 .57589 .58409 .57044 Mtetra
.58409 .57044 .58924 .57589 .59924 .57294 .59412 .56747 Mtetra
.59412 .56747 .59924 .57294 .60928 .56998 .60418 .56449 Mtetra
.60418 .56449 .60928 .56998 .61935 .56701 .61428 .56149 Mtetra
.61428 .56149 .61935 .56701 .62946 .56403 .62441 .55849 Mtetra
.62441 .55849 .62946 .56403 .63961 .56103 .63458 .55547 Mtetra
.63458 .55547 .63961 .56103 .64979 .55803 .64479 .55245 Mtetra
.64479 .55245 .64979 .55803 .66002 .55501 .65504 .54941 Mtetra
.65504 .54941 .66002 .55501 .67027 .55198 .66532 .54637 Mtetra
.66532 .54637 .67027 .55198 .68057 .54895 .67564 .54331 Mtetra
.67564 .54331 .68057 .54895 .6909 .5459 .686 .54024 Mtetra
.686 .54024 .6909 .5459 .70127 .54284 .6964 .53716 Mtetra
.6964 .53716 .70127 .54284 .71168 .53976 .70684 .53406 Mtetra
.70684 .53406 .71168 .53976 .72213 .53668 .71731 .53096 Mtetra
.71731 .53096 .72213 .53668 .73262 .53359 .72782 .52785 Mtetra
.72782 .52785 .73262 .53359 .74314 .53048 .73838 .52472 Mtetra
.73838 .52472 .74314 .53048 .75371 .52737 .74897 .52158 Mtetra
.74897 .52158 .75371 .52737 .76431 .52424 .7596 .51843 Mtetra
.7596 .51843 .76431 .52424 .77495 .5211 .77027 .51527 Mtetra
.77027 .51527 .77495 .5211 .78563 .51794 .78098 .5121 Mtetra
.78098 .5121 .78563 .51794 .79635 .51478 .79173 .50891 Mtetra
.79173 .50891 .79635 .51478 .80711 .51161 .80251 .50571 Mtetra
.80251 .50571 .80711 .51161 .81792 .50842 .81335 .5025 Mtetra
.81335 .5025 .81792 .50842 .82876 .50522 .82422 .49928 Mtetra
.82422 .49928 .82876 .50522 .83964 .50201 .83513 .49605 Mtetra
.83513 .49605 .83964 .50201 .85056 .49879 .84608 .4928 Mtetra
.84608 .4928 .85056 .49879 .86153 .49555 .85707 .48955 Mtetra
.85707 .48955 .86153 .49555 .87253 .4923 .86811 .48627 Mtetra
.86811 .48627 .87253 .4923 .88358 .48904 .87919 .48299 Mtetra
.87919 .48299 .88358 .48904 .89467 .48577 .89031 .4797 Mtetra
.89031 .4797 .89467 .48577 .9058 .48249 .90147 .47639 Mtetra
.90147 .47639 .9058 .48249 .91698 .47919 .91268 .47307 Mtetra
.91268 .47307 .91698 .47919 .92819 .47588 .92392 .46974 Mtetra
.92392 .46974 .92819 .47588 .93945 .47256 .93521 .46639 Mtetra
.32977 .63908 .33552 .6441 .34467 .64139 .33894 .63636 Mtetra
.33894 .63636 .34467 .64139 .35385 .63866 .34814 .63362 Mtetra
.34814 .63362 .35385 .63866 .36306 .63594 .35737 .63087 Mtetra
.35737 .63087 .36306 .63594 .3723 .6332 .36664 .62811 Mtetra
.36664 .62811 .3723 .6332 .38158 .63045 .37593 .62535 Mtetra
.37593 .62535 .38158 .63045 .39089 .62769 .38526 .62257 Mtetra
.38526 .62257 .39089 .62769 .40023 .62492 .39462 .61979 Mtetra
.39462 .61979 .40023 .62492 .4096 .62214 .40402 .61699 Mtetra
.40402 .61699 .4096 .62214 .41901 .61936 .41344 .61418 Mtetra
.41344 .61418 .41901 .61936 .42844 .61656 .4229 .61137 Mtetra
.4229 .61137 .42844 .61656 .43792 .61375 .43239 .60854 Mtetra
.43239 .60854 .43792 .61375 .44742 .61094 .44192 .60571 Mtetra
.44192 .60571 .44742 .61094 .45696 .60811 .45148 .60286 Mtetra
.45148 .60286 .45696 .60811 .46653 .60527 .46108 .60001 Mtetra
.46108 .60001 .46653 .60527 .47614 .60243 .4707 .59714 Mtetra
.4707 .59714 .47614 .60243 .48578 .59957 .48037 .59427 Mtetra
.48037 .59427 .48578 .59957 .49545 .5967 .49006 .59138 Mtetra
.49006 .59138 .49545 .5967 .50516 .59383 .49979 .58849 Mtetra
.49979 .58849 .50516 .59383 .5149 .59094 .50956 .58558 Mtetra
.50956 .58558 .5149 .59094 .52468 .58804 .51936 .58267 Mtetra
.51936 .58267 .52468 .58804 .5345 .58513 .52919 .57974 Mtetra
.52919 .57974 .5345 .58513 .54434 .58222 .53907 .5768 Mtetra
.53907 .5768 .54434 .58222 .55423 .57929 .54897 .57385 Mtetra
.54897 .57385 .55423 .57929 .56414 .57635 .55891 .57089 Mtetra
.55891 .57089 .56414 .57635 .5741 .5734 .56889 .56792 Mtetra
.56889 .56792 .5741 .5734 .58409 .57044 .57891 .56494 Mtetra
.57891 .56494 .58409 .57044 .59412 .56747 .58896 .56195 Mtetra
.58896 .56195 .59412 .56747 .60418 .56449 .59904 .55895 Mtetra
.59904 .55895 .60418 .56449 .61428 .56149 .60917 .55594 Mtetra
.60917 .55594 .61428 .56149 .62441 .55849 .61933 .55292 Mtetra
.61933 .55292 .62441 .55849 .63458 .55547 .62952 .54988 Mtetra
.62952 .54988 .63458 .55547 .64479 .55245 .63976 .54684 Mtetra
.63976 .54684 .64479 .55245 .65504 .54941 .65003 .54378 Mtetra
.65003 .54378 .65504 .54941 .66532 .54637 .66034 .54071 Mtetra
.66034 .54071 .66532 .54637 .67564 .54331 .67069 .53763 Mtetra
.67069 .53763 .67564 .54331 .686 .54024 .68107 .53454 Mtetra
.68107 .53454 .686 .54024 .6964 .53716 .69149 .53144 Mtetra
.69149 .53144 .6964 .53716 .70684 .53406 .70196 .52833 Mtetra
.70196 .52833 .70684 .53406 .71731 .53096 .71246 .5252 Mtetra
.71246 .5252 .71731 .53096 .72782 .52785 .723 .52206 Mtetra
.723 .52206 .72782 .52785 .73838 .52472 .73358 .51892 Mtetra
.73358 .51892 .73838 .52472 .74897 .52158 .74419 .51576 Mtetra
.74419 .51576 .74897 .52158 .7596 .51843 .75485 .51258 Mtetra
.75485 .51258 .7596 .51843 .77027 .51527 .76555 .5094 Mtetra
.76555 .5094 .77027 .51527 .78098 .5121 .77629 .50621 Mtetra
.77629 .50621 .78098 .5121 .79173 .50891 .78707 .503 Mtetra
.78707 .503 .79173 .50891 .80251 .50571 .79788 .49978 Mtetra
.79788 .49978 .80251 .50571 .81335 .5025 .80874 .49655 Mtetra
.80874 .49655 .81335 .5025 .82422 .49928 .81964 .4933 Mtetra
.81964 .4933 .82422 .49928 .83513 .49605 .83058 .49005 Mtetra
.83058 .49005 .83513 .49605 .84608 .4928 .84157 .48678 Mtetra
.84157 .48678 .84608 .4928 .85707 .48955 .85259 .4835 Mtetra
.85259 .4835 .85707 .48955 .86811 .48627 .86366 .4802 Mtetra
.86366 .4802 .86811 .48627 .87919 .48299 .87477 .4769 Mtetra
.87477 .4769 .87919 .48299 .89031 .4797 .88592 .47358 Mtetra
.88592 .47358 .89031 .4797 .90147 .47639 .89711 .47025 Mtetra
.89711 .47025 .90147 .47639 .91268 .47307 .90834 .46691 Mtetra
.90834 .46691 .91268 .47307 .92392 .46974 .91962 .46355 Mtetra
.91962 .46355 .92392 .46974 .93521 .46639 .93095 .46018 Mtetra
.32399 .63404 .32977 .63908 .33894 .63636 .33318 .63129 Mtetra
.33318 .63129 .33894 .63636 .34814 .63362 .3424 .62854 Mtetra
.3424 .62854 .34814 .63362 .35737 .63087 .35165 .62577 Mtetra
.35165 .62577 .35737 .63087 .36664 .62811 .36094 .623 Mtetra
.36094 .623 .36664 .62811 .37593 .62535 .37025 .62021 Mtetra
.37025 .62021 .37593 .62535 .38526 .62257 .3796 .61742 Mtetra
.3796 .61742 .38526 .62257 .39462 .61979 .38898 .61462 Mtetra
.38898 .61462 .39462 .61979 .40402 .61699 .3984 .6118 Mtetra
.3984 .6118 .40402 .61699 .41344 .61418 .40784 .60898 Mtetra
.40784 .60898 .41344 .61418 .4229 .61137 .41732 .60615 Mtetra
.41732 .60615 .4229 .61137 .43239 .60854 .42684 .6033 Mtetra
.42684 .6033 .43239 .60854 .44192 .60571 .43639 .60045 Mtetra
.43639 .60045 .44192 .60571 .45148 .60286 .44597 .59759 Mtetra
.44597 .59759 .45148 .60286 .46108 .60001 .45558 .59471 Mtetra
.45558 .59471 .46108 .60001 .4707 .59714 .46523 .59183 Mtetra
.46523 .59183 .4707 .59714 .48037 .59427 .47492 .58893 Mtetra
.47492 .58893 .48037 .59427 .49006 .59138 .48463 .58603 Mtetra
.48463 .58603 .49006 .59138 .49979 .58849 .49439 .58311 Mtetra
.49439 .58311 .49979 .58849 .50956 .58558 .50418 .58019 Mtetra
.50418 .58019 .50956 .58558 .51936 .58267 .514 .57725 Mtetra
.514 .57725 .51936 .58267 .52919 .57974 .52386 .57431 Mtetra
.52386 .57431 .52919 .57974 .53907 .5768 .53375 .57135 Mtetra
.53375 .57135 .53907 .5768 .54897 .57385 .54368 .56838 Mtetra
.54368 .56838 .54897 .57385 .55891 .57089 .55365 .5654 Mtetra
.55365 .5654 .55891 .57089 .56889 .56792 .56365 .56241 Mtetra
.56365 .56241 .56889 .56792 .57891 .56494 .57369 .55941 Mtetra
.57369 .55941 .57891 .56494 .58896 .56195 .58376 .5564 Mtetra
.58376 .5564 .58896 .56195 .59904 .55895 .59387 .55338 Mtetra
.59387 .55338 .59904 .55895 .60917 .55594 .60402 .55035 Mtetra
.60402 .55035 .60917 .55594 .61933 .55292 .61421 .5473 Mtetra
.61421 .5473 .61933 .55292 .62952 .54988 .62443 .54425 Mtetra
.62443 .54425 .62952 .54988 .63976 .54684 .63469 .54118 Mtetra
.63469 .54118 .63976 .54684 .65003 .54378 .64498 .53811 Mtetra
.64498 .53811 .65003 .54378 .66034 .54071 .65532 .53502 Mtetra
.65532 .53502 .66034 .54071 .67069 .53763 .66569 .53192 Mtetra
.66569 .53192 .67069 .53763 .68107 .53454 .6761 .52881 Mtetra
.6761 .52881 .68107 .53454 .69149 .53144 .68655 .52568 Mtetra
.68655 .52568 .69149 .53144 .70196 .52833 .69704 .52255 Mtetra
.69704 .52255 .70196 .52833 .71246 .5252 .70757 .5194 Mtetra
.70757 .5194 .71246 .5252 .723 .52206 .71814 .51624 Mtetra
.71814 .51624 .723 .52206 .73358 .51892 .72874 .51307 Mtetra
.72874 .51307 .73358 .51892 .74419 .51576 .73939 .50989 Mtetra
.73939 .50989 .74419 .51576 .75485 .51258 .75008 .5067 Mtetra
.75008 .5067 .75485 .51258 .76555 .5094 .7608 .50349 Mtetra
.7608 .50349 .76555 .5094 .77629 .50621 .77157 .50027 Mtetra
.77157 .50027 .77629 .50621 .78707 .503 .78237 .49704 Mtetra
.78237 .49704 .78707 .503 .79788 .49978 .79322 .4938 Mtetra
.79322 .4938 .79788 .49978 .80874 .49655 .80411 .49055 Mtetra
.80411 .49055 .80874 .49655 .81964 .4933 .81504 .48728 Mtetra
.81504 .48728 .81964 .4933 .83058 .49005 .82601 .484 Mtetra
.82601 .484 .83058 .49005 .84157 .48678 .83702 .48071 Mtetra
.83702 .48071 .84157 .48678 .85259 .4835 .84808 .47741 Mtetra
.84808 .47741 .85259 .4835 .86366 .4802 .85917 .47409 Mtetra
.85917 .47409 .86366 .4802 .87477 .4769 .87031 .47076 Mtetra
.87031 .47076 .87477 .4769 .88592 .47358 .88149 .46742 Mtetra
.88149 .46742 .88592 .47358 .89711 .47025 .89272 .46407 Mtetra
.89272 .46407 .89711 .47025 .90834 .46691 .90398 .4607 Mtetra
.90398 .4607 .90834 .46691 .91962 .46355 .91529 .45732 Mtetra
.91529 .45732 .91962 .46355 .93095 .46018 .92665 .45393 Mtetra
.31818 .62896 .32399 .63404 .33318 .63129 .32738 .6262 Mtetra
.32738 .6262 .33318 .63129 .3424 .62854 .33662 .62343 Mtetra
.33662 .62343 .3424 .62854 .35165 .62577 .34589 .62064 Mtetra
.34589 .62064 .35165 .62577 .36094 .623 .3552 .61785 Mtetra
.3552 .61785 .36094 .623 .37025 .62021 .36453 .61505 Mtetra
.36453 .61505 .37025 .62021 .3796 .61742 .3739 .61224 Mtetra
.3739 .61224 .3796 .61742 .38898 .61462 .3833 .60942 Mtetra
.3833 .60942 .38898 .61462 .3984 .6118 .39274 .60658 Mtetra
.39274 .60658 .3984 .6118 .40784 .60898 .40221 .60374 Mtetra
.40221 .60374 .40784 .60898 .41732 .60615 .41171 .60089 Mtetra
.41171 .60089 .41732 .60615 .42684 .6033 .42124 .59803 Mtetra
.42124 .59803 .42684 .6033 .43639 .60045 .43081 .59516 Mtetra
.43081 .59516 .43639 .60045 .44597 .59759 .44042 .59227 Mtetra
.44042 .59227 .44597 .59759 .45558 .59471 .45005 .58938 Mtetra
.45005 .58938 .45558 .59471 .46523 .59183 .45972 .58648 Mtetra
.45972 .58648 .46523 .59183 .47492 .58893 .46943 .58356 Mtetra
.46943 .58356 .47492 .58893 .48463 .58603 .47917 .58064 Mtetra
.47917 .58064 .48463 .58603 .49439 .58311 .48895 .57771 Mtetra
.48895 .57771 .49439 .58311 .50418 .58019 .49876 .57476 Mtetra
.49876 .57476 .50418 .58019 .514 .57725 .5086 .57181 Mtetra
.5086 .57181 .514 .57725 .52386 .57431 .51849 .56884 Mtetra
.51849 .56884 .52386 .57431 .53375 .57135 .5284 .56586 Mtetra
.5284 .56586 .53375 .57135 .54368 .56838 .53836 .56288 Mtetra
.53836 .56288 .54368 .56838 .55365 .5654 .54835 .55988 Mtetra
.54835 .55988 .55365 .5654 .56365 .56241 .55837 .55687 Mtetra
.55837 .55687 .56365 .56241 .57369 .55941 .56843 .55385 Mtetra
.56843 .55385 .57369 .55941 .58376 .5564 .57853 .55082 Mtetra
.57853 .55082 .58376 .5564 .59387 .55338 .58867 .54777 Mtetra
.58867 .54777 .59387 .55338 .60402 .55035 .59884 .54472 Mtetra
.59884 .54472 .60402 .55035 .61421 .5473 .60905 .54166 Mtetra
.60905 .54166 .61421 .5473 .62443 .54425 .6193 .53858 Mtetra
.6193 .53858 .62443 .54425 .63469 .54118 .62958 .53549 Mtetra
.62958 .53549 .63469 .54118 .64498 .53811 .63991 .53239 Mtetra
.63991 .53239 .64498 .53811 .65532 .53502 .65027 .52928 Mtetra
.65027 .52928 .65532 .53502 .66569 .53192 .66067 .52616 Mtetra
.66067 .52616 .66569 .53192 .6761 .52881 .6711 .52303 Mtetra
.6711 .52303 .6761 .52881 .68655 .52568 .68158 .51989 Mtetra
.68158 .51989 .68655 .52568 .69704 .52255 .6921 .51673 Mtetra
.6921 .51673 .69704 .52255 .70757 .5194 .70265 .51356 Mtetra
.70265 .51356 .70757 .5194 .71814 .51624 .71324 .51038 Mtetra
.71324 .51038 .71814 .51624 .72874 .51307 .72388 .50719 Mtetra
.72388 .50719 .72874 .51307 .73939 .50989 .73455 .50399 Mtetra
.73455 .50399 .73939 .50989 .75008 .5067 .74527 .50077 Mtetra
.74527 .50077 .75008 .5067 .7608 .50349 .75602 .49754 Mtetra
.75602 .49754 .7608 .50349 .77157 .50027 .76681 .4943 Mtetra
.76681 .4943 .77157 .50027 .78237 .49704 .77765 .49105 Mtetra
.77765 .49105 .78237 .49704 .79322 .4938 .78852 .48779 Mtetra
.78852 .48779 .79322 .4938 .80411 .49055 .79944 .48451 Mtetra
.79944 .48451 .80411 .49055 .81504 .48728 .8104 .48122 Mtetra
.8104 .48122 .81504 .48728 .82601 .484 .8214 .47792 Mtetra
.8214 .47792 .82601 .484 .83702 .48071 .83244 .4746 Mtetra
.83244 .4746 .83702 .48071 .84808 .47741 .84353 .47128 Mtetra
.84353 .47128 .84808 .47741 .85917 .47409 .85465 .46794 Mtetra
.85465 .46794 .85917 .47409 .87031 .47076 .86582 .46458 Mtetra
.86582 .46458 .87031 .47076 .88149 .46742 .87704 .46122 Mtetra
.87704 .46122 .88149 .46742 .89272 .46407 .88829 .45784 Mtetra
.88829 .45784 .89272 .46407 .90398 .4607 .89959 .45445 Mtetra
.89959 .45445 .90398 .4607 .91529 .45732 .91093 .45104 Mtetra
.91093 .45104 .91529 .45732 .92665 .45393 .92232 .44763 Mtetra
.31232 .62385 .31818 .62896 .32738 .6262 .32155 .62107 Mtetra
.32155 .62107 .32738 .6262 .33662 .62343 .33081 .61828 Mtetra
.33081 .61828 .33662 .62343 .34589 .62064 .3401 .61548 Mtetra
.3401 .61548 .34589 .62064 .3552 .61785 .34942 .61267 Mtetra
.34942 .61267 .3552 .61785 .36453 .61505 .35878 .60985 Mtetra
.35878 .60985 .36453 .61505 .3739 .61224 .36817 .60702 Mtetra
.36817 .60702 .3739 .61224 .3833 .60942 .37759 .60418 Mtetra
.37759 .60418 .3833 .60942 .39274 .60658 .38704 .60133 Mtetra
.38704 .60133 .39274 .60658 .40221 .60374 .39653 .59847 Mtetra
.39653 .59847 .40221 .60374 .41171 .60089 .40606 .5956 Mtetra
.40606 .5956 .41171 .60089 .42124 .59803 .41561 .59272 Mtetra
.41561 .59272 .42124 .59803 .43081 .59516 .4252 .58983 Mtetra
.4252 .58983 .43081 .59516 .44042 .59227 .43483 .58692 Mtetra
.43483 .58692 .44042 .59227 .45005 .58938 .44449 .58401 Mtetra
.44449 .58401 .45005 .58938 .45972 .58648 .45418 .58109 Mtetra
.45418 .58109 .45972 .58648 .46943 .58356 .46391 .57816 Mtetra
.46391 .57816 .46943 .58356 .47917 .58064 .47367 .57521 Mtetra
.47367 .57521 .47917 .58064 .48895 .57771 .48347 .57226 Mtetra
.48347 .57226 .48895 .57771 .49876 .57476 .4933 .5693 Mtetra
.4933 .5693 .49876 .57476 .5086 .57181 .50317 .56632 Mtetra
.50317 .56632 .5086 .57181 .51849 .56884 .51308 .56334 Mtetra
.51308 .56334 .51849 .56884 .5284 .56586 .52302 .56034 Mtetra
.52302 .56034 .5284 .56586 .53836 .56288 .533 .55733 Mtetra
.533 .55733 .53836 .56288 .54835 .55988 .54301 .55431 Mtetra
.54301 .55431 .54835 .55988 .55837 .55687 .55306 .55128 Mtetra
.55306 .55128 .55837 .55687 .56843 .55385 .56314 .54824 Mtetra
.56314 .54824 .56843 .55385 .57853 .55082 .57327 .54519 Mtetra
.57327 .54519 .57853 .55082 .58867 .54777 .58343 .54213 Mtetra
.58343 .54213 .58867 .54777 .59884 .54472 .59363 .53905 Mtetra
.59363 .53905 .59884 .54472 .60905 .54166 .60386 .53597 Mtetra
.60386 .53597 .60905 .54166 .6193 .53858 .61413 .53287 Mtetra
.61413 .53287 .6193 .53858 .62958 .53549 .62444 .52976 Mtetra
.62444 .52976 .62958 .53549 .63991 .53239 .63479 .52664 Mtetra
.63479 .52664 .63991 .53239 .65027 .52928 .64518 .52351 Mtetra
.64518 .52351 .65027 .52928 .66067 .52616 .6556 .52037 Mtetra
.6556 .52037 .66067 .52616 .6711 .52303 .66607 .51722 Mtetra
.66607 .51722 .6711 .52303 .68158 .51989 .67657 .51405 Mtetra
.67657 .51405 .68158 .51989 .6921 .51673 .68711 .51087 Mtetra
.68711 .51087 .6921 .51673 .70265 .51356 .6977 .50768 Mtetra
.6977 .50768 .70265 .51356 .71324 .51038 .70832 .50448 Mtetra
.70832 .50448 .71324 .51038 .72388 .50719 .71898 .50127 Mtetra
.71898 .50127 .72388 .50719 .73455 .50399 .72968 .49804 Mtetra
.72968 .49804 .73455 .50399 .74527 .50077 .74042 .4948 Mtetra
.74042 .4948 .74527 .50077 .75602 .49754 .7512 .49155 Mtetra
.7512 .49155 .75602 .49754 .76681 .4943 .76203 .48829 Mtetra
.76203 .48829 .76681 .4943 .77765 .49105 .77289 .48501 Mtetra
.77289 .48501 .77765 .49105 .78852 .48779 .7838 .48173 Mtetra
.7838 .48173 .78852 .48779 .79944 .48451 .79474 .47843 Mtetra
.79474 .47843 .79944 .48451 .8104 .48122 .80573 .47511 Mtetra
.80573 .47511 .8104 .48122 .8214 .47792 .81676 .47179 Mtetra
.81676 .47179 .8214 .47792 .83244 .4746 .82783 .46845 Mtetra
.82783 .46845 .83244 .4746 .84353 .47128 .83895 .4651 Mtetra
.83895 .4651 .84353 .47128 .85465 .46794 .85011 .46174 Mtetra
.85011 .46174 .85465 .46794 .86582 .46458 .86131 .45836 Mtetra
.86131 .45836 .86582 .46458 .87704 .46122 .87255 .45497 Mtetra
.87255 .45497 .87704 .46122 .88829 .45784 .88384 .45157 Mtetra
.88384 .45157 .88829 .45784 .89959 .45445 .89517 .44815 Mtetra
.89517 .44815 .89959 .45445 .91093 .45104 .90654 .44472 Mtetra
.90654 .44472 .91093 .45104 .92232 .44763 .91796 .44128 Mtetra
.30643 .61871 .31232 .62385 .32155 .62107 .31568 .61591 Mtetra
.31568 .61591 .32155 .62107 .33081 .61828 .32495 .6131 Mtetra
.32495 .6131 .33081 .61828 .3401 .61548 .33427 .61028 Mtetra
.33427 .61028 .3401 .61548 .34942 .61267 .34361 .60746 Mtetra
.34361 .60746 .34942 .61267 .35878 .60985 .35299 .60462 Mtetra
.35299 .60462 .35878 .60985 .36817 .60702 .36239 .60177 Mtetra
.36239 .60177 .36817 .60702 .37759 .60418 .37184 .59891 Mtetra
.37184 .59891 .37759 .60418 .38704 .60133 .38131 .59604 Mtetra
.38131 .59604 .38704 .60133 .39653 .59847 .39082 .59316 Mtetra
.39082 .59316 .39653 .59847 .40606 .5956 .40037 .59027 Mtetra
.40037 .59027 .40606 .5956 .41561 .59272 .40995 .58737 Mtetra
.40995 .58737 .41561 .59272 .4252 .58983 .41956 .58446 Mtetra
.41956 .58446 .4252 .58983 .43483 .58692 .4292 .58154 Mtetra
.4292 .58154 .43483 .58692 .44449 .58401 .43888 .57861 Mtetra
.43888 .57861 .44449 .58401 .45418 .58109 .4486 .57567 Mtetra
.4486 .57567 .45418 .58109 .46391 .57816 .45835 .57272 Mtetra
.45835 .57272 .46391 .57816 .47367 .57521 .46814 .56975 Mtetra
.46814 .56975 .47367 .57521 .48347 .57226 .47796 .56678 Mtetra
.47796 .56678 .48347 .57226 .4933 .5693 .48781 .5638 Mtetra
.48781 .5638 .4933 .5693 .50317 .56632 .49771 .5608 Mtetra
.49771 .5608 .50317 .56632 .51308 .56334 .50763 .55779 Mtetra
.50763 .55779 .51308 .56334 .52302 .56034 .5176 .55478 Mtetra
.5176 .55478 .52302 .56034 .533 .55733 .5276 .55175 Mtetra
.5276 .55175 .533 .55733 .54301 .55431 .53764 .54871 Mtetra
.53764 .54871 .54301 .55431 .55306 .55128 .54771 .54566 Mtetra
.54771 .54566 .55306 .55128 .56314 .54824 .55782 .5426 Mtetra
.55782 .5426 .56314 .54824 .57327 .54519 .56797 .53953 Mtetra
.56797 .53953 .57327 .54519 .58343 .54213 .57815 .53644 Mtetra
.57815 .53644 .58343 .54213 .59363 .53905 .58837 .53335 Mtetra
.58837 .53335 .59363 .53905 .60386 .53597 .59864 .53024 Mtetra
.59864 .53024 .60386 .53597 .61413 .53287 .60893 .52712 Mtetra
.60893 .52712 .61413 .53287 .62444 .52976 .61927 .524 Mtetra
.61927 .524 .62444 .52976 .63479 .52664 .62964 .52085 Mtetra
.62964 .52085 .63479 .52664 .64518 .52351 .64006 .5177 Mtetra
.64006 .5177 .64518 .52351 .6556 .52037 .65051 .51454 Mtetra
.65051 .51454 .6556 .52037 .66607 .51722 .661 .51136 Mtetra
.661 .51136 .66607 .51722 .67657 .51405 .67153 .50817 Mtetra
.67153 .50817 .67657 .51405 .68711 .51087 .6821 .50497 Mtetra
.6821 .50497 .68711 .51087 .6977 .50768 .69271 .50176 Mtetra
.69271 .50176 .6977 .50768 .70832 .50448 .70336 .49854 Mtetra
.70336 .49854 .70832 .50448 .71898 .50127 .71405 .4953 Mtetra
.71405 .4953 .71898 .50127 .72968 .49804 .72477 .49205 Mtetra
.72477 .49205 .72968 .49804 .74042 .4948 .73554 .48879 Mtetra
.73554 .48879 .74042 .4948 .7512 .49155 .74636 .48552 Mtetra
.74636 .48552 .7512 .49155 .76203 .48829 .75721 .48223 Mtetra
.75721 .48223 .76203 .48829 .77289 .48501 .7681 .47893 Mtetra
.7681 .47893 .77289 .48501 .7838 .48173 .77903 .47562 Mtetra
.77903 .47562 .7838 .48173 .79474 .47843 .79001 .4723 Mtetra
.79001 .4723 .79474 .47843 .80573 .47511 .80103 .46897 Mtetra
.80103 .46897 .80573 .47511 .81676 .47179 .81209 .46562 Mtetra
.81209 .46562 .81676 .47179 .82783 .46845 .82319 .46226 Mtetra
.82319 .46226 .82783 .46845 .83895 .4651 .83434 .45888 Mtetra
.83434 .45888 .83895 .4651 .85011 .46174 .84552 .45549 Mtetra
.84552 .45549 .85011 .46174 .86131 .45836 .85676 .45209 Mtetra
.85676 .45209 .86131 .45836 .87255 .45497 .86803 .44868 Mtetra
.86803 .44868 .87255 .45497 .88384 .45157 .87935 .44525 Mtetra
.87935 .44525 .88384 .45157 .89517 .44815 .89071 .44181 Mtetra
.89071 .44181 .89517 .44815 .90654 .44472 .90212 .43836 Mtetra
.90212 .43836 .90654 .44472 .91796 .44128 .91357 .43489 Mtetra
.3005 .61354 .30643 .61871 .31568 .61591 .30977 .61072 Mtetra
.30977 .61072 .31568 .61591 .32495 .6131 .31906 .60789 Mtetra
.31906 .60789 .32495 .6131 .33427 .61028 .32839 .60505 Mtetra
.32839 .60505 .33427 .61028 .34361 .60746 .33776 .60221 Mtetra
.33776 .60221 .34361 .60746 .35299 .60462 .34715 .59935 Mtetra
.34715 .59935 .35299 .60462 .36239 .60177 .35658 .59648 Mtetra
.35658 .59648 .36239 .60177 .37184 .59891 .36605 .5936 Mtetra
.36605 .5936 .37184 .59891 .38131 .59604 .37555 .59072 Mtetra
.37555 .59072 .38131 .59604 .39082 .59316 .38508 .58782 Mtetra
.38508 .58782 .39082 .59316 .40037 .59027 .39464 .58491 Mtetra
.39464 .58491 .40037 .59027 .40995 .58737 .40424 .58199 Mtetra
.40424 .58199 .40995 .58737 .41956 .58446 .41387 .57906 Mtetra
.41387 .57906 .41956 .58446 .4292 .58154 .42354 .57612 Mtetra
.42354 .57612 .4292 .58154 .43888 .57861 .43324 .57317 Mtetra
.43324 .57317 .43888 .57861 .4486 .57567 .44298 .57021 Mtetra
.44298 .57021 .4486 .57567 .45835 .57272 .45276 .56724 Mtetra
.45276 .56724 .45835 .57272 .46814 .56975 .46256 .56426 Mtetra
.46256 .56426 .46814 .56975 .47796 .56678 .47241 .56126 Mtetra
.47241 .56126 .47796 .56678 .48781 .5638 .48229 .55826 Mtetra
.48229 .55826 .48781 .5638 .49771 .5608 .4922 .55524 Mtetra
.4922 .55524 .49771 .5608 .50763 .55779 .50215 .55222 Mtetra
.50215 .55222 .50763 .55779 .5176 .55478 .51214 .54918 Mtetra
.51214 .54918 .5176 .55478 .5276 .55175 .52217 .54613 Mtetra
.52217 .54613 .5276 .55175 .53764 .54871 .53223 .54307 Mtetra
.53223 .54307 .53764 .54871 .54771 .54566 .54232 .54 Mtetra
.54232 .54 .54771 .54566 .55782 .5426 .55246 .53692 Mtetra
.55246 .53692 .55782 .5426 .56797 .53953 .56263 .53383 Mtetra
.56263 .53383 .56797 .53953 .57815 .53644 .57284 .53072 Mtetra
.57284 .53072 .57815 .53644 .58837 .53335 .58309 .52761 Mtetra
.58309 .52761 .58837 .53335 .59864 .53024 .59337 .52448 Mtetra
.59337 .52448 .59864 .53024 .60893 .52712 .6037 .52134 Mtetra
.6037 .52134 .60893 .52712 .61927 .524 .61406 .51819 Mtetra
.61406 .51819 .61927 .524 .62964 .52085 .62446 .51503 Mtetra
.62446 .51503 .62964 .52085 .64006 .5177 .6349 .51185 Mtetra
.6349 .51185 .64006 .5177 .65051 .51454 .64538 .50866 Mtetra
.64538 .50866 .65051 .51454 .661 .51136 .65589 .50547 Mtetra
.65589 .50547 .661 .51136 .67153 .50817 .66645 .50226 Mtetra
.66645 .50226 .67153 .50817 .6821 .50497 .67705 .49903 Mtetra
.67705 .49903 .6821 .50497 .69271 .50176 .68768 .4958 Mtetra
.68768 .4958 .69271 .50176 .70336 .49854 .69836 .49255 Mtetra
.69836 .49255 .70336 .49854 .71405 .4953 .70908 .48929 Mtetra
.70908 .48929 .71405 .4953 .72477 .49205 .71984 .48602 Mtetra
.71984 .48602 .72477 .49205 .73554 .48879 .73063 .48274 Mtetra
.73063 .48274 .73554 .48879 .74636 .48552 .74147 .47944 Mtetra
.74147 .47944 .74636 .48552 .75721 .48223 .75235 .47613 Mtetra
.75235 .47613 .75721 .48223 .7681 .47893 .76328 .47281 Mtetra
.76328 .47281 .7681 .47893 .77903 .47562 .77424 .46948 Mtetra
.77424 .46948 .77903 .47562 .79001 .4723 .78524 .46613 Mtetra
.78524 .46613 .79001 .4723 .80103 .46897 .79629 .46277 Mtetra
.79629 .46277 .80103 .46897 .81209 .46562 .80738 .4594 Mtetra
.80738 .4594 .81209 .46562 .82319 .46226 .81852 .45602 Mtetra
.81852 .45602 .82319 .46226 .83434 .45888 .82969 .45262 Mtetra
.82969 .45262 .83434 .45888 .84552 .45549 .84091 .44921 Mtetra
.84091 .44921 .84552 .45549 .85676 .45209 .85217 .44578 Mtetra
.85217 .44578 .85676 .45209 .86803 .44868 .86348 .44234 Mtetra
.86348 .44234 .86803 .44868 .87935 .44525 .87483 .43889 Mtetra
.87483 .43889 .87935 .44525 .89071 .44181 .88623 .43543 Mtetra
.88623 .43543 .89071 .44181 .90212 .43836 .89766 .43195 Mtetra
.89766 .43195 .90212 .43836 .91357 .43489 .90915 .42846 Mtetra
.29453 .60833 .3005 .61354 .30977 .61072 .30382 .60549 Mtetra
.30382 .60549 .30977 .61072 .31906 .60789 .31314 .60265 Mtetra
.31314 .60265 .31906 .60789 .32839 .60505 .32249 .59979 Mtetra
.32249 .59979 .32839 .60505 .33776 .60221 .33187 .59692 Mtetra
.33187 .59692 .33776 .60221 .34715 .59935 .34129 .59405 Mtetra
.34129 .59405 .34715 .59935 .35658 .59648 .35074 .59116 Mtetra
.35074 .59116 .35658 .59648 .36605 .5936 .36022 .58826 Mtetra
.36022 .58826 .36605 .5936 .37555 .59072 .36974 .58536 Mtetra
.36974 .58536 .37555 .59072 .38508 .58782 .37929 .58244 Mtetra
.37929 .58244 .38508 .58782 .39464 .58491 .38888 .57951 Mtetra
.38888 .57951 .39464 .58491 .40424 .58199 .3985 .57657 Mtetra
.3985 .57657 .40424 .58199 .41387 .57906 .40815 .57363 Mtetra
.40815 .57363 .41387 .57906 .42354 .57612 .41784 .57067 Mtetra
.41784 .57067 .42354 .57612 .43324 .57317 .42757 .5677 Mtetra
.42757 .5677 .43324 .57317 .44298 .57021 .43733 .56471 Mtetra
.43733 .56471 .44298 .57021 .45276 .56724 .44712 .56172 Mtetra
.44712 .56172 .45276 .56724 .46256 .56426 .45695 .55872 Mtetra
.45695 .55872 .46256 .56426 .47241 .56126 .46682 .55571 Mtetra
.46682 .55571 .47241 .56126 .48229 .55826 .47672 .55268 Mtetra
.47672 .55268 .48229 .55826 .4922 .55524 .48666 .54965 Mtetra
.48666 .54965 .4922 .55524 .50215 .55222 .49664 .5466 Mtetra
.49664 .5466 .50215 .55222 .51214 .54918 .50665 .54354 Mtetra
.50665 .54354 .51214 .54918 .52217 .54613 .5167 .54047 Mtetra
.5167 .54047 .52217 .54613 .53223 .54307 .52678 .53739 Mtetra
.52678 .53739 .53223 .54307 .54232 .54 .5369 .5343 Mtetra
.5369 .5343 .54232 .54 .55246 .53692 .54706 .5312 Mtetra
.54706 .5312 .55246 .53692 .56263 .53383 .55726 .52809 Mtetra
.55726 .52809 .56263 .53383 .57284 .53072 .56749 .52496 Mtetra
.56749 .52496 .57284 .53072 .58309 .52761 .57777 .52182 Mtetra
.57777 .52182 .58309 .52761 .59337 .52448 .58808 .51867 Mtetra
.58808 .51867 .59337 .52448 .6037 .52134 .59843 .51551 Mtetra
.59843 .51551 .6037 .52134 .61406 .51819 .60881 .51234 Mtetra
.60881 .51234 .61406 .51819 .62446 .51503 .61924 .50916 Mtetra
.61924 .50916 .62446 .51503 .6349 .51185 .62971 .50596 Mtetra
.62971 .50596 .6349 .51185 .64538 .50866 .64021 .50275 Mtetra
.64021 .50275 .64538 .50866 .65589 .50547 .65075 .49953 Mtetra
.65075 .49953 .65589 .50547 .66645 .50226 .66134 .4963 Mtetra
.66134 .4963 .66645 .50226 .67705 .49903 .67196 .49305 Mtetra
.67196 .49305 .67705 .49903 .68768 .4958 .68263 .4898 Mtetra
.68263 .4898 .68768 .4958 .69836 .49255 .69333 .48653 Mtetra
.69333 .48653 .69836 .49255 .70908 .48929 .70408 .48325 Mtetra
.70408 .48325 .70908 .48929 .71984 .48602 .71486 .47995 Mtetra
.71486 .47995 .71984 .48602 .73063 .48274 .72569 .47664 Mtetra
.72569 .47664 .73063 .48274 .74147 .47944 .73656 .47333 Mtetra
.73656 .47333 .74147 .47944 .75235 .47613 .74746 .46999 Mtetra
.74746 .46999 .75235 .47613 .76328 .47281 .75842 .46665 Mtetra
.75842 .46665 .76328 .47281 .77424 .46948 .76941 .46329 Mtetra
.76941 .46329 .77424 .46948 .78524 .46613 .78044 .45992 Mtetra
.78044 .45992 .78524 .46613 .79629 .46277 .79152 .45654 Mtetra
.79152 .45654 .79629 .46277 .80738 .4594 .80264 .45314 Mtetra
.80264 .45314 .80738 .4594 .81852 .45602 .81381 .44973 Mtetra
.81381 .44973 .81852 .45602 .82969 .45262 .82501 .44631 Mtetra
.82501 .44631 .82969 .45262 .84091 .44921 .83626 .44287 Mtetra
.83626 .44287 .84091 .44921 .85217 .44578 .84756 .43942 Mtetra
.84756 .43942 .85217 .44578 .86348 .44234 .8589 .43596 Mtetra
.8589 .43596 .86348 .44234 .87483 .43889 .87028 .43248 Mtetra
.87028 .43248 .87483 .43889 .88623 .43543 .88171 .42899 Mtetra
.88171 .42899 .88623 .43543 .89766 .43195 .89318 .42549 Mtetra
.89318 .42549 .89766 .43195 .90915 .42846 .90469 .42197 Mtetra
.28853 .60308 .29453 .60833 .30382 .60549 .29783 .60023 Mtetra
.29783 .60023 .30382 .60549 .31314 .60265 .30717 .59737 Mtetra
.30717 .59737 .31314 .60265 .32249 .59979 .31654 .59449 Mtetra
.31654 .59449 .32249 .59979 .33187 .59692 .32594 .59161 Mtetra
.32594 .59161 .33187 .59692 .34129 .59405 .33538 .58871 Mtetra
.33538 .58871 .34129 .59405 .35074 .59116 .34485 .58581 Mtetra
.34485 .58581 .35074 .59116 .36022 .58826 .35435 .58289 Mtetra
.35435 .58289 .36022 .58826 .36974 .58536 .36389 .57996 Mtetra
.36389 .57996 .36974 .58536 .37929 .58244 .37347 .57703 Mtetra
.37347 .57703 .37929 .58244 .38888 .57951 .38307 .57408 Mtetra
.38307 .57408 .38888 .57951 .3985 .57657 .39272 .57112 Mtetra
.39272 .57112 .3985 .57657 .40815 .57363 .40239 .56815 Mtetra
.40239 .56815 .40815 .57363 .41784 .57067 .41211 .56517 Mtetra
.41211 .56517 .41784 .57067 .42757 .5677 .42185 .56218 Mtetra
.42185 .56218 .42757 .5677 .43733 .56471 .43163 .55918 Mtetra
.43163 .55918 .43733 .56471 .44712 .56172 .44145 .55617 Mtetra
.44145 .55617 .44712 .56172 .45695 .55872 .45131 .55315 Mtetra
.45131 .55315 .45695 .55872 .46682 .55571 .4612 .55012 Mtetra
.4612 .55012 .46682 .55571 .47672 .55268 .47112 .54707 Mtetra
.47112 .54707 .47672 .55268 .48666 .54965 .48108 .54401 Mtetra
.48108 .54401 .48666 .54965 .49664 .5466 .49108 .54095 Mtetra
.49108 .54095 .49664 .5466 .50665 .54354 .50112 .53787 Mtetra
.50112 .53787 .50665 .54354 .5167 .54047 .51119 .53478 Mtetra
.51119 .53478 .5167 .54047 .52678 .53739 .5213 .53168 Mtetra
.5213 .53168 .52678 .53739 .5369 .5343 .53144 .52857 Mtetra
.53144 .52857 .5369 .5343 .54706 .5312 .54163 .52544 Mtetra
.54163 .52544 .54706 .5312 .55726 .52809 .55185 .52231 Mtetra
.55185 .52231 .55726 .52809 .56749 .52496 .56211 .51916 Mtetra
.56211 .51916 .56749 .52496 .57777 .52182 .57241 .516 Mtetra
.57241 .516 .57777 .52182 .58808 .51867 .58274 .51283 Mtetra
.58274 .51283 .58808 .51867 .59843 .51551 .59312 .50965 Mtetra
.59312 .50965 .59843 .51551 .60881 .51234 .60353 .50645 Mtetra
.60353 .50645 .60881 .51234 .61924 .50916 .61398 .50324 Mtetra
.61398 .50324 .61924 .50916 .62971 .50596 .62448 .50003 Mtetra
.62448 .50003 .62971 .50596 .64021 .50275 .63501 .4968 Mtetra
.63501 .4968 .64021 .50275 .65075 .49953 .64558 .49355 Mtetra
.64558 .49355 .65075 .49953 .66134 .4963 .65619 .4903 Mtetra
.65619 .4903 .66134 .4963 .67196 .49305 .66684 .48703 Mtetra
.66684 .48703 .67196 .49305 .68263 .4898 .67753 .48375 Mtetra
.67753 .48375 .68263 .4898 .69333 .48653 .68826 .48046 Mtetra
.68826 .48046 .69333 .48653 .70408 .48325 .69904 .47715 Mtetra
.69904 .47715 .70408 .48325 .71486 .47995 .70985 .47384 Mtetra
.70985 .47384 .71486 .47995 .72569 .47664 .72071 .47051 Mtetra
.72071 .47051 .72569 .47664 .73656 .47333 .7316 .46716 Mtetra
.7316 .46716 .73656 .47333 .74746 .46999 .74254 .46381 Mtetra
.74254 .46381 .74746 .46999 .75842 .46665 .75352 .46044 Mtetra
.75352 .46044 .75842 .46665 .76941 .46329 .76455 .45706 Mtetra
.76455 .45706 .76941 .46329 .78044 .45992 .77561 .45366 Mtetra
.77561 .45366 .78044 .45992 .79152 .45654 .78672 .45026 Mtetra
.78672 .45026 .79152 .45654 .80264 .45314 .79787 .44684 Mtetra
.79787 .44684 .80264 .45314 .81381 .44973 .80906 .4434 Mtetra
.80906 .4434 .81381 .44973 .82501 .44631 .8203 .43995 Mtetra
.8203 .43995 .82501 .44631 .83626 .44287 .83158 .43649 Mtetra
.83158 .43649 .83626 .44287 .84756 .43942 .84291 .43302 Mtetra
.84291 .43302 .84756 .43942 .8589 .43596 .85428 .42953 Mtetra
.85428 .42953 .8589 .43596 .87028 .43248 .86569 .42603 Mtetra
.86569 .42603 .87028 .43248 .88171 .42899 .87715 .42251 Mtetra
.87715 .42251 .88171 .42899 .89318 .42549 .88866 .41899 Mtetra
.88866 .41899 .89318 .42549 .90469 .42197 .90021 .41544 Mtetra
.28248 .59781 .28853 .60308 .29783 .60023 .2918 .59493 Mtetra
.2918 .59493 .29783 .60023 .30717 .59737 .30116 .59205 Mtetra
.30116 .59205 .30717 .59737 .31654 .59449 .31055 .58916 Mtetra
.31055 .58916 .31654 .59449 .32594 .59161 .31998 .58625 Mtetra
.31998 .58625 .32594 .59161 .33538 .58871 .32943 .58334 Mtetra
.32943 .58334 .33538 .58871 .34485 .58581 .33892 .58041 Mtetra
.33892 .58041 .34485 .58581 .35435 .58289 .34845 .57748 Mtetra
.34845 .57748 .35435 .58289 .36389 .57996 .35801 .57453 Mtetra
.35801 .57453 .36389 .57996 .37347 .57703 .3676 .57158 Mtetra
.3676 .57158 .37347 .57703 .38307 .57408 .37723 .56861 Mtetra
.37723 .56861 .38307 .57408 .39272 .57112 .3869 .56563 Mtetra
.3869 .56563 .39272 .57112 .40239 .56815 .3966 .56264 Mtetra
.3966 .56264 .40239 .56815 .41211 .56517 .40633 .55965 Mtetra
.40633 .55965 .41211 .56517 .42185 .56218 .4161 .55664 Mtetra
.4161 .55664 .42185 .56218 .43163 .55918 .4259 .55361 Mtetra
.4259 .55361 .43163 .55918 .44145 .55617 .43574 .55058 Mtetra
.43574 .55058 .44145 .55617 .45131 .55315 .44562 .54754 Mtetra
.44562 .54754 .45131 .55315 .4612 .55012 .45553 .54449 Mtetra
.45553 .54449 .4612 .55012 .47112 .54707 .46548 .54142 Mtetra
.46548 .54142 .47112 .54707 .48108 .54401 .47547 .53834 Mtetra
.47547 .53834 .48108 .54401 .49108 .54095 .48549 .53526 Mtetra
.48549 .53526 .49108 .54095 .50112 .53787 .49555 .53216 Mtetra
.49555 .53216 .50112 .53787 .51119 .53478 .50564 .52905 Mtetra
.50564 .52905 .51119 .53478 .5213 .53168 .51578 .52592 Mtetra
.51578 .52592 .5213 .53168 .53144 .52857 .52595 .52279 Mtetra
.52595 .52279 .53144 .52857 .54163 .52544 .53616 .51964 Mtetra
.53616 .51964 .54163 .52544 .55185 .52231 .5464 .51649 Mtetra
.5464 .51649 .55185 .52231 .56211 .51916 .55669 .51332 Mtetra
.55669 .51332 .56211 .51916 .57241 .516 .56701 .51014 Mtetra
.56701 .51014 .57241 .516 .58274 .51283 .57737 .50694 Mtetra
.57737 .50694 .58274 .51283 .59312 .50965 .58777 .50374 Mtetra
.58777 .50374 .59312 .50965 .60353 .50645 .59821 .50052 Mtetra
.59821 .50052 .60353 .50645 .61398 .50324 .60869 .49729 Mtetra
.60869 .49729 .61398 .50324 .62448 .50003 .61921 .49405 Mtetra
.61921 .49405 .62448 .50003 .63501 .4968 .62977 .4908 Mtetra
.62977 .4908 .63501 .4968 .64558 .49355 .64037 .48753 Mtetra
.64037 .48753 .64558 .49355 .65619 .4903 .65101 .48426 Mtetra
.65101 .48426 .65619 .4903 .66684 .48703 .66168 .48097 Mtetra
.66168 .48097 .66684 .48703 .67753 .48375 .6724 .47766 Mtetra
.6724 .47766 .67753 .48375 .68826 .48046 .68316 .47435 Mtetra
.68316 .47435 .68826 .48046 .69904 .47715 .69396 .47102 Mtetra
.69396 .47102 .69904 .47715 .70985 .47384 .70481 .46768 Mtetra
.70481 .46768 .70985 .47384 .72071 .47051 .71569 .46433 Mtetra
.71569 .46433 .72071 .47051 .7316 .46716 .72662 .46096 Mtetra
.72662 .46096 .7316 .46716 .74254 .46381 .73758 .45758 Mtetra
.73758 .45758 .74254 .46381 .75352 .46044 .74859 .45419 Mtetra
.74859 .45419 .75352 .46044 .76455 .45706 .75965 .45078 Mtetra
.75965 .45078 .76455 .45706 .77561 .45366 .77074 .44736 Mtetra
.77074 .44736 .77561 .45366 .78672 .45026 .78188 .44393 Mtetra
.78188 .44393 .78672 .45026 .79787 .44684 .79306 .44049 Mtetra
.79306 .44049 .79787 .44684 .80906 .4434 .80429 .43703 Mtetra
.80429 .43703 .80906 .4434 .8203 .43995 .81556 .43355 Mtetra
.81556 .43355 .8203 .43995 .83158 .43649 .82687 .43007 Mtetra
.82687 .43007 .83158 .43649 .84291 .43302 .83823 .42657 Mtetra
.83823 .42657 .84291 .43302 .85428 .42953 .84963 .42306 Mtetra
.84963 .42306 .85428 .42953 .86569 .42603 .86108 .41953 Mtetra
.86108 .41953 .86569 .42603 .87715 .42251 .87257 .41599 Mtetra
.87257 .41599 .87715 .42251 .88866 .41899 .8841 .41243 Mtetra
.8841 .41243 .88866 .41899 .90021 .41544 .89569 .40886 Mtetra
.27639 .59249 .28248 .59781 .2918 .59493 .28574 .5896 Mtetra
.28574 .5896 .2918 .59493 .30116 .59205 .29511 .5867 Mtetra
.29511 .5867 .30116 .59205 .31055 .58916 .30452 .58379 Mtetra
.30452 .58379 .31055 .58916 .31998 .58625 .31397 .58087 Mtetra
.31397 .58087 .31998 .58625 .32943 .58334 .32345 .57793 Mtetra
.32345 .57793 .32943 .58334 .33892 .58041 .33296 .57499 Mtetra
.33296 .57499 .33892 .58041 .34845 .57748 .34251 .57203 Mtetra
.34251 .57203 .34845 .57748 .35801 .57453 .35209 .56907 Mtetra
.35209 .56907 .35801 .57453 .3676 .57158 .3617 .56609 Mtetra
.3617 .56609 .3676 .57158 .37723 .56861 .37135 .56311 Mtetra
.37135 .56311 .37723 .56861 .3869 .56563 .38104 .56011 Mtetra
.38104 .56011 .3869 .56563 .3966 .56264 .39076 .5571 Mtetra
.39076 .5571 .3966 .56264 .40633 .55965 .40052 .55408 Mtetra
.40052 .55408 .40633 .55965 .4161 .55664 .41031 .55105 Mtetra
.41031 .55105 .4161 .55664 .4259 .55361 .42013 .54801 Mtetra
.42013 .54801 .4259 .55361 .43574 .55058 .43 .54496 Mtetra
.43 .54496 .43574 .55058 .44562 .54754 .4399 .54189 Mtetra
.4399 .54189 .44562 .54754 .45553 .54449 .44983 .53882 Mtetra
.44983 .53882 .45553 .54449 .46548 .54142 .4598 .53573 Mtetra
.4598 .53573 .46548 .54142 .47547 .53834 .46981 .53263 Mtetra
.46981 .53263 .47547 .53834 .48549 .53526 .47986 .52952 Mtetra
.47986 .52952 .48549 .53526 .49555 .53216 .48994 .5264 Mtetra
.48994 .5264 .49555 .53216 .50564 .52905 .50006 .52327 Mtetra
.50006 .52327 .50564 .52905 .51578 .52592 .51022 .52013 Mtetra
.51022 .52013 .51578 .52592 .52595 .52279 .52041 .51697 Mtetra
.52041 .51697 .52595 .52279 .53616 .51964 .53065 .51381 Mtetra
.53065 .51381 .53616 .51964 .5464 .51649 .54092 .51063 Mtetra
.54092 .51063 .5464 .51649 .55669 .51332 .55123 .50744 Mtetra
.55123 .50744 .55669 .51332 .56701 .51014 .56158 .50423 Mtetra
.56158 .50423 .56701 .51014 .57737 .50694 .57197 .50102 Mtetra
.57197 .50102 .57737 .50694 .58777 .50374 .58239 .49779 Mtetra
.58239 .49779 .58777 .50374 .59821 .50052 .59286 .49455 Mtetra
.59286 .49455 .59821 .50052 .60869 .49729 .60336 .4913 Mtetra
.60336 .4913 .60869 .49729 .61921 .49405 .61391 .48804 Mtetra
.61391 .48804 .61921 .49405 .62977 .4908 .62449 .48476 Mtetra
.62449 .48476 .62977 .4908 .64037 .48753 .63512 .48147 Mtetra
.63512 .48147 .64037 .48753 .65101 .48426 .64578 .47817 Mtetra
.64578 .47817 .65101 .48426 .66168 .48097 .65649 .47486 Mtetra
.65649 .47486 .66168 .48097 .6724 .47766 .66724 .47153 Mtetra
.66724 .47153 .6724 .47766 .68316 .47435 .67803 .46819 Mtetra
.67803 .46819 .68316 .47435 .69396 .47102 .68886 .46484 Mtetra
.68886 .46484 .69396 .47102 .70481 .46768 .69973 .46148 Mtetra
.69973 .46148 .70481 .46768 .71569 .46433 .71064 .4581 Mtetra
.71064 .4581 .71569 .46433 .72662 .46096 .72159 .45471 Mtetra
.72159 .45471 .72662 .46096 .73758 .45758 .73259 .45131 Mtetra
.73259 .45131 .73758 .45758 .74859 .45419 .74363 .44789 Mtetra
.74363 .44789 .74859 .45419 .75965 .45078 .75471 .44446 Mtetra
.75471 .44446 .75965 .45078 .77074 .44736 .76584 .44102 Mtetra
.76584 .44102 .77074 .44736 .78188 .44393 .77701 .43756 Mtetra
.77701 .43756 .78188 .44393 .79306 .44049 .78822 .43409 Mtetra
.78822 .43409 .79306 .44049 .80429 .43703 .79948 .43061 Mtetra
.79948 .43061 .80429 .43703 .81556 .43355 .81078 .42711 Mtetra
.81078 .42711 .81556 .43355 .82687 .43007 .82212 .4236 Mtetra
.82212 .4236 .82687 .43007 .83823 .42657 .83351 .42007 Mtetra
.83351 .42007 .83823 .42657 .84963 .42306 .84494 .41653 Mtetra
.84494 .41653 .84963 .42306 .86108 .41953 .85642 .41298 Mtetra
.85642 .41298 .86108 .41953 .87257 .41599 .86795 .40941 Mtetra
.86795 .40941 .87257 .41599 .8841 .41243 .87952 .40583 Mtetra
.87952 .40583 .8841 .41243 .89569 .40886 .89113 .40224 Mtetra
.27027 .58715 .27639 .59249 .28574 .5896 .27963 .58424 Mtetra
.27963 .58424 .28574 .5896 .29511 .5867 .28903 .58132 Mtetra
.28903 .58132 .29511 .5867 .30452 .58379 .29846 .57838 Mtetra
.29846 .57838 .30452 .58379 .31397 .58087 .30792 .57544 Mtetra
.30792 .57544 .31397 .58087 .32345 .57793 .31742 .57249 Mtetra
.31742 .57249 .32345 .57793 .33296 .57499 .32696 .56952 Mtetra
.32696 .56952 .33296 .57499 .34251 .57203 .33652 .56655 Mtetra
.33652 .56655 .34251 .57203 .35209 .56907 .34613 .56357 Mtetra
.34613 .56357 .35209 .56907 .3617 .56609 .35576 .56057 Mtetra
.35576 .56057 .3617 .56609 .37135 .56311 .36543 .55756 Mtetra
.36543 .55756 .37135 .56311 .38104 .56011 .37514 .55455 Mtetra
.37514 .55455 .38104 .56011 .39076 .5571 .38488 .55152 Mtetra
.38488 .55152 .39076 .5571 .40052 .55408 .39466 .54848 Mtetra
.39466 .54848 .40052 .55408 .41031 .55105 .40448 .54543 Mtetra
.40448 .54543 .41031 .55105 .42013 .54801 .41432 .54236 Mtetra
.41432 .54236 .42013 .54801 .43 .54496 .42421 .53929 Mtetra
.42421 .53929 .43 .54496 .4399 .54189 .43413 .53621 Mtetra
.43413 .53621 .4399 .54189 .44983 .53882 .44409 .53311 Mtetra
.44409 .53311 .44983 .53882 .4598 .53573 .45409 .53 Mtetra
.45409 .53 .4598 .53573 .46981 .53263 .46412 .52688 Mtetra
.46412 .52688 .46981 .53263 .47986 .52952 .47419 .52375 Mtetra
.47419 .52375 .47986 .52952 .48994 .5264 .4843 .52061 Mtetra
.4843 .52061 .48994 .5264 .50006 .52327 .49444 .51746 Mtetra
.49444 .51746 .50006 .52327 .51022 .52013 .50462 .51429 Mtetra
.50462 .51429 .51022 .52013 .52041 .51697 .51484 .51112 Mtetra
.51484 .51112 .52041 .51697 .53065 .51381 .5251 .50793 Mtetra
.5251 .50793 .53065 .51381 .54092 .51063 .5354 .50473 Mtetra
.5354 .50473 .54092 .51063 .55123 .50744 .54573 .50151 Mtetra
.54573 .50151 .55123 .50744 .56158 .50423 .55611 .49829 Mtetra
.55611 .49829 .56158 .50423 .57197 .50102 .56652 .49505 Mtetra
.56652 .49505 .57197 .50102 .58239 .49779 .57697 .4918 Mtetra
.57697 .4918 .58239 .49779 .59286 .49455 .58747 .48854 Mtetra
.58747 .48854 .59286 .49455 .60336 .4913 .598 .48527 Mtetra
.598 .48527 .60336 .4913 .61391 .48804 .60857 .48198 Mtetra
.60857 .48198 .61391 .48804 .62449 .48476 .61918 .47868 Mtetra
.61918 .47868 .62449 .48476 .63512 .48147 .62983 .47537 Mtetra
.62983 .47537 .63512 .48147 .64578 .47817 .64053 .47205 Mtetra
.64053 .47205 .64578 .47817 .65649 .47486 .65126 .46871 Mtetra
.65126 .46871 .65649 .47486 .66724 .47153 .66204 .46536 Mtetra
.66204 .46536 .66724 .47153 .67803 .46819 .67285 .462 Mtetra
.67285 .462 .67803 .46819 .68886 .46484 .68371 .45862 Mtetra
.68371 .45862 .68886 .46484 .69973 .46148 .69461 .45523 Mtetra
.69461 .45523 .69973 .46148 .71064 .4581 .70555 .45183 Mtetra
.70555 .45183 .71064 .4581 .72159 .45471 .71654 .44842 Mtetra
.71654 .44842 .72159 .45471 .73259 .45131 .72756 .44499 Mtetra
.72756 .44499 .73259 .45131 .74363 .44789 .73863 .44155 Mtetra
.73863 .44155 .74363 .44789 .75471 .44446 .74974 .43809 Mtetra
.74974 .43809 .75471 .44446 .76584 .44102 .7609 .43462 Mtetra
.7609 .43462 .76584 .44102 .77701 .43756 .7721 .43114 Mtetra
.7721 .43114 .77701 .43756 .78822 .43409 .78334 .42765 Mtetra
.78334 .42765 .78822 .43409 .79948 .43061 .79463 .42414 Mtetra
.79463 .42414 .79948 .43061 .81078 .42711 .80596 .42062 Mtetra
.80596 .42062 .81078 .42711 .82212 .4236 .81734 .41708 Mtetra
.81734 .41708 .82212 .4236 .83351 .42007 .82876 .41353 Mtetra
.82876 .41353 .83351 .42007 .84494 .41653 .84023 .40996 Mtetra
.84023 .40996 .84494 .41653 .85642 .41298 .85174 .40639 Mtetra
.85174 .40639 .85642 .41298 .86795 .40941 .8633 .40279 Mtetra
.8633 .40279 .86795 .40941 .87952 .40583 .8749 .39919 Mtetra
.8749 .39919 .87952 .40583 .89113 .40224 .88655 .39556 Mtetra
.2641 .58177 .27027 .58715 .27963 .58424 .27348 .57884 Mtetra
.27348 .57884 .27963 .58424 .28903 .58132 .2829 .57589 Mtetra
.2829 .57589 .28903 .58132 .29846 .57838 .29235 .57294 Mtetra
.29235 .57294 .29846 .57838 .30792 .57544 .30184 .56998 Mtetra
.30184 .56998 .30792 .57544 .31742 .57249 .31136 .56701 Mtetra
.31136 .56701 .31742 .57249 .32696 .56952 .32091 .56403 Mtetra
.32091 .56403 .32696 .56952 .33652 .56655 .3305 .56103 Mtetra
.3305 .56103 .33652 .56655 .34613 .56357 .34012 .55803 Mtetra
.34012 .55803 .34613 .56357 .35576 .56057 .34978 .55501 Mtetra
.34978 .55501 .35576 .56057 .36543 .55756 .35947 .55198 Mtetra
.35947 .55198 .36543 .55756 .37514 .55455 .3692 .54895 Mtetra
.3692 .54895 .37514 .55455 .38488 .55152 .37897 .5459 Mtetra
.37897 .5459 .38488 .55152 .39466 .54848 .38877 .54284 Mtetra
.38877 .54284 .39466 .54848 .40448 .54543 .3986 .53976 Mtetra
.3986 .53976 .40448 .54543 .41432 .54236 .40848 .53668 Mtetra
.40848 .53668 .41432 .54236 .42421 .53929 .41839 .53359 Mtetra
.41839 .53359 .42421 .53929 .43413 .53621 .42833 .53048 Mtetra
.42833 .53048 .43413 .53621 .44409 .53311 .43831 .52737 Mtetra
.43831 .52737 .44409 .53311 .45409 .53 .44833 .52424 Mtetra
.44833 .52424 .45409 .53 .46412 .52688 .45839 .5211 Mtetra
.45839 .5211 .46412 .52688 .47419 .52375 .46848 .51794 Mtetra
.46848 .51794 .47419 .52375 .4843 .52061 .47861 .51478 Mtetra
.47861 .51478 .4843 .52061 .49444 .51746 .48878 .51161 Mtetra
.48878 .51161 .49444 .51746 .50462 .51429 .49899 .50842 Mtetra
.49899 .50842 .50462 .51429 .51484 .51112 .50923 .50522 Mtetra
.50923 .50522 .51484 .51112 .5251 .50793 .51952 .50201 Mtetra
.51952 .50201 .5251 .50793 .5354 .50473 .52984 .49879 Mtetra
.52984 .49879 .5354 .50473 .54573 .50151 .5402 .49555 Mtetra
.5402 .49555 .54573 .50151 .55611 .49829 .5506 .4923 Mtetra
.5506 .4923 .55611 .49829 .56652 .49505 .56104 .48904 Mtetra
.56104 .48904 .56652 .49505 .57697 .4918 .57152 .48577 Mtetra
.57152 .48577 .57697 .4918 .58747 .48854 .58203 .48249 Mtetra
.58203 .48249 .58747 .48854 .598 .48527 .59259 .47919 Mtetra
.59259 .47919 .598 .48527 .60857 .48198 .60319 .47588 Mtetra
.60319 .47588 .60857 .48198 .61918 .47868 .61383 .47256 Mtetra
.61383 .47256 .61918 .47868 .62983 .47537 .62451 .46922 Mtetra
.62451 .46922 .62983 .47537 .64053 .47205 .63523 .46587 Mtetra
.63523 .46587 .64053 .47205 .65126 .46871 .64599 .46251 Mtetra
.64599 .46251 .65126 .46871 .66204 .46536 .6568 .45914 Mtetra
.6568 .45914 .66204 .46536 .67285 .462 .66764 .45575 Mtetra
.66764 .45575 .67285 .462 .68371 .45862 .67853 .45235 Mtetra
.67853 .45235 .68371 .45862 .69461 .45523 .68946 .44894 Mtetra
.68946 .44894 .69461 .45523 .70555 .45183 .70043 .44552 Mtetra
.70043 .44552 .70555 .45183 .71654 .44842 .71144 .44208 Mtetra
.71144 .44208 .71654 .44842 .72756 .44499 .7225 .43862 Mtetra
.7225 .43862 .72756 .44499 .73863 .44155 .7336 .43516 Mtetra
.7336 .43516 .73863 .44155 .74974 .43809 .74474 .43168 Mtetra
.74474 .43168 .74974 .43809 .7609 .43462 .75593 .42819 Mtetra
.75593 .42819 .7609 .43462 .7721 .43114 .76716 .42468 Mtetra
.76716 .42468 .7721 .43114 .78334 .42765 .77843 .42116 Mtetra
.77843 .42116 .78334 .42765 .79463 .42414 .78975 .41762 Mtetra
.78975 .41762 .79463 .42414 .80596 .42062 .80111 .41408 Mtetra
.80111 .41408 .80596 .42062 .81734 .41708 .81252 .41051 Mtetra
.81252 .41051 .81734 .41708 .82876 .41353 .82397 .40694 Mtetra
.82397 .40694 .82876 .41353 .84023 .40996 .83547 .40335 Mtetra
.83547 .40335 .84023 .40996 .85174 .40639 .84702 .39974 Mtetra
.84702 .39974 .85174 .40639 .8633 .40279 .85861 .39612 Mtetra
.85861 .39612 .8633 .40279 .8749 .39919 .87025 .39249 Mtetra
.87025 .39249 .8749 .39919 .88655 .39556 .88193 .38884 Mtetra
.25789 .57635 .2641 .58177 .27348 .57884 .2673 .5734 Mtetra
.2673 .5734 .27348 .57884 .2829 .57589 .27673 .57044 Mtetra
.27673 .57044 .2829 .57589 .29235 .57294 .2862 .56747 Mtetra
.2862 .56747 .29235 .57294 .30184 .56998 .29571 .56449 Mtetra
.29571 .56449 .30184 .56998 .31136 .56701 .30525 .56149 Mtetra
.30525 .56149 .31136 .56701 .32091 .56403 .31483 .55849 Mtetra
.31483 .55849 .32091 .56403 .3305 .56103 .32444 .55547 Mtetra
.32444 .55547 .3305 .56103 .34012 .55803 .33408 .55245 Mtetra
.33408 .55245 .34012 .55803 .34978 .55501 .34376 .54941 Mtetra
.34376 .54941 .34978 .55501 .35947 .55198 .35348 .54637 Mtetra
.35348 .54637 .35947 .55198 .3692 .54895 .36323 .54331 Mtetra
.36323 .54331 .3692 .54895 .37897 .5459 .37301 .54024 Mtetra
.37301 .54024 .37897 .5459 .38877 .54284 .38284 .53716 Mtetra
.38284 .53716 .38877 .54284 .3986 .53976 .39269 .53406 Mtetra
.39269 .53406 .3986 .53976 .40848 .53668 .40259 .53096 Mtetra
.40259 .53096 .40848 .53668 .41839 .53359 .41252 .52785 Mtetra
.41252 .52785 .41839 .53359 .42833 .53048 .42249 .52472 Mtetra
.42249 .52472 .42833 .53048 .43831 .52737 .43249 .52158 Mtetra
.43249 .52158 .43831 .52737 .44833 .52424 .44254 .51843 Mtetra
.44254 .51843 .44833 .52424 .45839 .5211 .45262 .51527 Mtetra
.45262 .51527 .45839 .5211 .46848 .51794 .46273 .5121 Mtetra
.46273 .5121 .46848 .51794 .47861 .51478 .47289 .50891 Mtetra
.47289 .50891 .47861 .51478 .48878 .51161 .48308 .50571 Mtetra
.48308 .50571 .48878 .51161 .49899 .50842 .49331 .5025 Mtetra
.49331 .5025 .49899 .50842 .50923 .50522 .50358 .49928 Mtetra
.50358 .49928 .50923 .50522 .51952 .50201 .51389 .49605 Mtetra
.51389 .49605 .51952 .50201 .52984 .49879 .52424 .4928 Mtetra
.52424 .4928 .52984 .49879 .5402 .49555 .53463 .48955 Mtetra
.53463 .48955 .5402 .49555 .5506 .4923 .54505 .48627 Mtetra
.54505 .48627 .5506 .4923 .56104 .48904 .55552 .48299 Mtetra
.55552 .48299 .56104 .48904 .57152 .48577 .56602 .4797 Mtetra
.56602 .4797 .57152 .48577 .58203 .48249 .57657 .47639 Mtetra
.57657 .47639 .58203 .48249 .59259 .47919 .58715 .47307 Mtetra
.58715 .47307 .59259 .47919 .60319 .47588 .59778 .46974 Mtetra
.59778 .46974 .60319 .47588 .61383 .47256 .60844 .46639 Mtetra
.60844 .46639 .61383 .47256 .62451 .46922 .61915 .46303 Mtetra
.61915 .46303 .62451 .46922 .63523 .46587 .6299 .45966 Mtetra
.6299 .45966 .63523 .46587 .64599 .46251 .64069 .45628 Mtetra
.64069 .45628 .64599 .46251 .6568 .45914 .65152 .45288 Mtetra
.65152 .45288 .6568 .45914 .66764 .45575 .66239 .44947 Mtetra
.66239 .44947 .66764 .45575 .67853 .45235 .67331 .44604 Mtetra
.67331 .44604 .67853 .45235 .68946 .44894 .68427 .44261 Mtetra
.68427 .44261 .68946 .44894 .70043 .44552 .69527 .43916 Mtetra
.69527 .43916 .70043 .44552 .71144 .44208 .70631 .43569 Mtetra
.70631 .43569 .71144 .44208 .7225 .43862 .7174 .43222 Mtetra
.7174 .43222 .7225 .43862 .7336 .43516 .72853 .42872 Mtetra
.72853 .42872 .7336 .43516 .74474 .43168 .7397 .42522 Mtetra
.7397 .42522 .74474 .43168 .75593 .42819 .75092 .4217 Mtetra
.75092 .4217 .75593 .42819 .76716 .42468 .76218 .41817 Mtetra
.76218 .41817 .76716 .42468 .77843 .42116 .77348 .41462 Mtetra
.77348 .41462 .77843 .42116 .78975 .41762 .78483 .41106 Mtetra
.78483 .41106 .78975 .41762 .80111 .41408 .79623 .40749 Mtetra
.79623 .40749 .80111 .41408 .81252 .41051 .80767 .4039 Mtetra
.80767 .4039 .81252 .41051 .82397 .40694 .81915 .4003 Mtetra
.81915 .4003 .82397 .40694 .83547 .40335 .83069 .39668 Mtetra
.83069 .39668 .83547 .40335 .84702 .39974 .84226 .39305 Mtetra
.84226 .39305 .84702 .39974 .85861 .39612 .85389 .3894 Mtetra
.85389 .3894 .85861 .39612 .87025 .39249 .86556 .38574 Mtetra
.86556 .38574 .87025 .39249 .88193 .38884 .87727 .38207 Mtetra
.25164 .57089 .25789 .57635 .2673 .5734 .26107 .56792 Mtetra
.26107 .56792 .2673 .5734 .27673 .57044 .27052 .56494 Mtetra
.27052 .56494 .27673 .57044 .2862 .56747 .28002 .56195 Mtetra
.28002 .56195 .2862 .56747 .29571 .56449 .28954 .55895 Mtetra
.28954 .55895 .29571 .56449 .30525 .56149 .2991 .55594 Mtetra
.2991 .55594 .30525 .56149 .31483 .55849 .3087 .55292 Mtetra
.3087 .55292 .31483 .55849 .32444 .55547 .31833 .54988 Mtetra
.31833 .54988 .32444 .55547 .33408 .55245 .328 .54684 Mtetra
.328 .54684 .33408 .55245 .34376 .54941 .3377 .54378 Mtetra
.3377 .54378 .34376 .54941 .35348 .54637 .34744 .54071 Mtetra
.34744 .54071 .35348 .54637 .36323 .54331 .35721 .53763 Mtetra
.35721 .53763 .36323 .54331 .37301 .54024 .36702 .53454 Mtetra
.36702 .53454 .37301 .54024 .38284 .53716 .37686 .53144 Mtetra
.37686 .53144 .38284 .53716 .39269 .53406 .38674 .52833 Mtetra
.38674 .52833 .39269 .53406 .40259 .53096 .39666 .5252 Mtetra
.39666 .5252 .40259 .53096 .41252 .52785 .40662 .52206 Mtetra
.40662 .52206 .41252 .52785 .42249 .52472 .41661 .51892 Mtetra
.41661 .51892 .42249 .52472 .43249 .52158 .42664 .51576 Mtetra
.42664 .51576 .43249 .52158 .44254 .51843 .4367 .51258 Mtetra
.4367 .51258 .44254 .51843 .45262 .51527 .44681 .5094 Mtetra
.44681 .5094 .45262 .51527 .46273 .5121 .45695 .50621 Mtetra
.45695 .50621 .46273 .5121 .47289 .50891 .46713 .503 Mtetra
.46713 .503 .47289 .50891 .48308 .50571 .47734 .49978 Mtetra
.47734 .49978 .48308 .50571 .49331 .5025 .4876 .49655 Mtetra
.4876 .49655 .49331 .5025 .50358 .49928 .49789 .4933 Mtetra
.49789 .4933 .50358 .49928 .51389 .49605 .50823 .49005 Mtetra
.50823 .49005 .51389 .49605 .52424 .4928 .5186 .48678 Mtetra
.5186 .48678 .52424 .4928 .53463 .48955 .52901 .4835 Mtetra
.52901 .4835 .53463 .48955 .54505 .48627 .53946 .4802 Mtetra
.53946 .4802 .54505 .48627 .55552 .48299 .54996 .4769 Mtetra
.54996 .4769 .55552 .48299 .56602 .4797 .56049 .47358 Mtetra
.56049 .47358 .56602 .4797 .57657 .47639 .57106 .47025 Mtetra
.57106 .47025 .57657 .47639 .58715 .47307 .58167 .46691 Mtetra
.58167 .46691 .58715 .47307 .59778 .46974 .59232 .46355 Mtetra
.59232 .46355 .59778 .46974 .60844 .46639 .60302 .46018 Mtetra
.60302 .46018 .60844 .46639 .61915 .46303 .61375 .4568 Mtetra
.61375 .4568 .61915 .46303 .6299 .45966 .62453 .4534 Mtetra
.62453 .4534 .6299 .45966 .64069 .45628 .63535 .44999 Mtetra
.63535 .44999 .64069 .45628 .65152 .45288 .64621 .44657 Mtetra
.64621 .44657 .65152 .45288 .66239 .44947 .65711 .44314 Mtetra
.65711 .44314 .66239 .44947 .67331 .44604 .66805 .43969 Mtetra
.66805 .43969 .67331 .44604 .68427 .44261 .67904 .43623 Mtetra
.67904 .43623 .68427 .44261 .69527 .43916 .69007 .43275 Mtetra
.69007 .43275 .69527 .43916 .70631 .43569 .70114 .42926 Mtetra
.70114 .42926 .70631 .43569 .7174 .43222 .71226 .42576 Mtetra
.71226 .42576 .7174 .43222 .72853 .42872 .72342 .42224 Mtetra
.72342 .42224 .72853 .42872 .7397 .42522 .73462 .41871 Mtetra
.73462 .41871 .7397 .42522 .75092 .4217 .74587 .41517 Mtetra
.74587 .41517 .75092 .4217 .76218 .41817 .75716 .41161 Mtetra
.75716 .41161 .76218 .41817 .77348 .41462 .7685 .40804 Mtetra
.7685 .40804 .77348 .41462 .78483 .41106 .77988 .40445 Mtetra
.77988 .40445 .78483 .41106 .79623 .40749 .79131 .40085 Mtetra
.79131 .40085 .79623 .40749 .80767 .4039 .80278 .39724 Mtetra
.80278 .39724 .80767 .4039 .81915 .4003 .8143 .39361 Mtetra
.8143 .39361 .81915 .4003 .83069 .39668 .82586 .38996 Mtetra
.82586 .38996 .83069 .39668 .84226 .39305 .83747 .38631 Mtetra
.83747 .38631 .84226 .39305 .85389 .3894 .84913 .38263 Mtetra
.84913 .38263 .85389 .3894 .86556 .38574 .86083 .37895 Mtetra
.86083 .37895 .86556 .38574 .87727 .38207 .87259 .37524 Mtetra
.24535 .5654 .25164 .57089 .26107 .56792 .2548 .56241 Mtetra
.2548 .56241 .26107 .56792 .27052 .56494 .26427 .55941 Mtetra
.26427 .55941 .27052 .56494 .28002 .56195 .27379 .5564 Mtetra
.27379 .5564 .28002 .56195 .28954 .55895 .28333 .55338 Mtetra
.28333 .55338 .28954 .55895 .2991 .55594 .29292 .55035 Mtetra
.29292 .55035 .2991 .55594 .3087 .55292 .30253 .5473 Mtetra
.30253 .5473 .3087 .55292 .31833 .54988 .31218 .54425 Mtetra
.31218 .54425 .31833 .54988 .328 .54684 .32187 .54118 Mtetra
.32187 .54118 .328 .54684 .3377 .54378 .3316 .53811 Mtetra
.3316 .53811 .3377 .54378 .34744 .54071 .34135 .53502 Mtetra
.34135 .53502 .34744 .54071 .35721 .53763 .35115 .53192 Mtetra
.35115 .53192 .35721 .53763 .36702 .53454 .36098 .52881 Mtetra
.36098 .52881 .36702 .53454 .37686 .53144 .37085 .52568 Mtetra
.37085 .52568 .37686 .53144 .38674 .52833 .38075 .52255 Mtetra
.38075 .52255 .38674 .52833 .39666 .5252 .39069 .5194 Mtetra
.39069 .5194 .39666 .5252 .40662 .52206 .40067 .51624 Mtetra
.40067 .51624 .40662 .52206 .41661 .51892 .41068 .51307 Mtetra
.41068 .51307 .41661 .51892 .42664 .51576 .42074 .50989 Mtetra
.42074 .50989 .42664 .51576 .4367 .51258 .43083 .5067 Mtetra
.43083 .5067 .4367 .51258 .44681 .5094 .44095 .50349 Mtetra
.44095 .50349 .44681 .5094 .45695 .50621 .45112 .50027 Mtetra
.45112 .50027 .45695 .50621 .46713 .503 .46132 .49704 Mtetra
.46132 .49704 .46713 .503 .47734 .49978 .47157 .4938 Mtetra
.47157 .4938 .47734 .49978 .4876 .49655 .48185 .49055 Mtetra
.48185 .49055 .4876 .49655 .49789 .4933 .49217 .48728 Mtetra
.49217 .48728 .49789 .4933 .50823 .49005 .50253 .484 Mtetra
.50253 .484 .50823 .49005 .5186 .48678 .51292 .48071 Mtetra
.51292 .48071 .5186 .48678 .52901 .4835 .52336 .47741 Mtetra
.52336 .47741 .52901 .4835 .53946 .4802 .53384 .47409 Mtetra
.53384 .47409 .53946 .4802 .54996 .4769 .54436 .47076 Mtetra
.54436 .47076 .54996 .4769 .56049 .47358 .55491 .46742 Mtetra
.55491 .46742 .56049 .47358 .57106 .47025 .56551 .46407 Mtetra
.56551 .46407 .57106 .47025 .58167 .46691 .57615 .4607 Mtetra
.57615 .4607 .58167 .46691 .59232 .46355 .58683 .45732 Mtetra
.58683 .45732 .59232 .46355 .60302 .46018 .59755 .45393 Mtetra
.59755 .45393 .60302 .46018 .61375 .4568 .60832 .45052 Mtetra
.60832 .45052 .61375 .4568 .62453 .4534 .61912 .4471 Mtetra
.61912 .4471 .62453 .4534 .63535 .44999 .62997 .44367 Mtetra
.62997 .44367 .63535 .44999 .64621 .44657 .64085 .44022 Mtetra
.64085 .44022 .64621 .44657 .65711 .44314 .65178 .43676 Mtetra
.65178 .43676 .65711 .44314 .66805 .43969 .66276 .43329 Mtetra
.66276 .43329 .66805 .43969 .67904 .43623 .67377 .4298 Mtetra
.67377 .4298 .67904 .43623 .69007 .43275 .68483 .4263 Mtetra
.68483 .4263 .69007 .43275 .70114 .42926 .69594 .42279 Mtetra
.69594 .42279 .70114 .42926 .71226 .42576 .70708 .41926 Mtetra
.70708 .41926 .71226 .42576 .72342 .42224 .71827 .41572 Mtetra
.71827 .41572 .72342 .42224 .73462 .41871 .72951 .41216 Mtetra
.72951 .41216 .73462 .41871 .74587 .41517 .74079 .40859 Mtetra
.74079 .40859 .74587 .41517 .75716 .41161 .75211 .40501 Mtetra
.75211 .40501 .75716 .41161 .7685 .40804 .76348 .40141 Mtetra
.76348 .40141 .7685 .40804 .77988 .40445 .77489 .39779 Mtetra
.77489 .39779 .77988 .40445 .79131 .40085 .78635 .39417 Mtetra
.78635 .39417 .79131 .40085 .80278 .39724 .79786 .39053 Mtetra
.79786 .39053 .80278 .39724 .8143 .39361 .80941 .38687 Mtetra
.80941 .38687 .8143 .39361 .82586 .38996 .821 .3832 Mtetra
.821 .3832 .82586 .38996 .83747 .38631 .83265 .37951 Mtetra
.83265 .37951 .83747 .38631 .84913 .38263 .84434 .37581 Mtetra
.84434 .37581 .84913 .38263 .86083 .37895 .85608 .3721 Mtetra
.85608 .3721 .86083 .37895 .87259 .37524 .86786 .36837 Mtetra
.23902 .55988 .24535 .5654 .2548 .56241 .24848 .55687 Mtetra
.24848 .55687 .2548 .56241 .26427 .55941 .25798 .55385 Mtetra
.25798 .55385 .26427 .55941 .27379 .5564 .26751 .55082 Mtetra
.26751 .55082 .27379 .5564 .28333 .55338 .27708 .54777 Mtetra
.27708 .54777 .28333 .55338 .29292 .55035 .28669 .54472 Mtetra
.28669 .54472 .29292 .55035 .30253 .5473 .29632 .54166 Mtetra
.29632 .54166 .30253 .5473 .31218 .54425 .306 .53858 Mtetra
.306 .53858 .31218 .54425 .32187 .54118 .31571 .53549 Mtetra
.31571 .53549 .32187 .54118 .3316 .53811 .32545 .53239 Mtetra
.32545 .53239 .3316 .53811 .34135 .53502 .33523 .52928 Mtetra
.33523 .52928 .34135 .53502 .35115 .53192 .34505 .52616 Mtetra
.34505 .52616 .35115 .53192 .36098 .52881 .3549 .52303 Mtetra
.3549 .52303 .36098 .52881 .37085 .52568 .36479 .51989 Mtetra
.36479 .51989 .37085 .52568 .38075 .52255 .37472 .51673 Mtetra
.37472 .51673 .38075 .52255 .39069 .5194 .38468 .51356 Mtetra
.38468 .51356 .39069 .5194 .40067 .51624 .39468 .51038 Mtetra
.39468 .51038 .40067 .51624 .41068 .51307 .40472 .50719 Mtetra
.40472 .50719 .41068 .51307 .42074 .50989 .4148 .50399 Mtetra
.4148 .50399 .42074 .50989 .43083 .5067 .42491 .50077 Mtetra
.42491 .50077 .43083 .5067 .44095 .50349 .43506 .49754 Mtetra
.43506 .49754 .44095 .50349 .45112 .50027 .44525 .4943 Mtetra
.44525 .4943 .45112 .50027 .46132 .49704 .45548 .49105 Mtetra
.45548 .49105 .46132 .49704 .47157 .4938 .46575 .48779 Mtetra
.46575 .48779 .47157 .4938 .48185 .49055 .47605 .48451 Mtetra
.47605 .48451 .48185 .49055 .49217 .48728 .4864 .48122 Mtetra
.4864 .48122 .49217 .48728 .50253 .484 .49678 .47792 Mtetra
.49678 .47792 .50253 .484 .51292 .48071 .50721 .4746 Mtetra
.50721 .4746 .51292 .48071 .52336 .47741 .51767 .47128 Mtetra
.51767 .47128 .52336 .47741 .53384 .47409 .52817 .46794 Mtetra
.52817 .46794 .53384 .47409 .54436 .47076 .53872 .46458 Mtetra
.53872 .46458 .54436 .47076 .55491 .46742 .5493 .46122 Mtetra
.5493 .46122 .55491 .46742 .56551 .46407 .55993 .45784 Mtetra
.55993 .45784 .56551 .46407 .57615 .4607 .57059 .45445 Mtetra
.57059 .45445 .57615 .4607 .58683 .45732 .5813 .45104 Mtetra
.5813 .45104 .58683 .45732 .59755 .45393 .59205 .44763 Mtetra
.59205 .44763 .59755 .45393 .60832 .45052 .60284 .4442 Mtetra
.60284 .4442 .60832 .45052 .61912 .4471 .61367 .44075 Mtetra
.61367 .44075 .61912 .4471 .62997 .44367 .62455 .43729 Mtetra
.62455 .43729 .62997 .44367 .64085 .44022 .63546 .43382 Mtetra
.63546 .43382 .64085 .44022 .65178 .43676 .64642 .43034 Mtetra
.64642 .43034 .65178 .43676 .66276 .43329 .65743 .42684 Mtetra
.65743 .42684 .66276 .43329 .67377 .4298 .66847 .42333 Mtetra
.66847 .42333 .67377 .4298 .68483 .4263 .67956 .4198 Mtetra
.67956 .4198 .68483 .4263 .69594 .42279 .69069 .41626 Mtetra
.69069 .41626 .69594 .42279 .70708 .41926 .70187 .41271 Mtetra
.70187 .41271 .70708 .41926 .71827 .41572 .71309 .40914 Mtetra
.71309 .40914 .71827 .41572 .72951 .41216 .72436 .40556 Mtetra
.72436 .40556 .72951 .41216 .74079 .40859 .73566 .40196 Mtetra
.73566 .40196 .74079 .40859 .75211 .40501 .74702 .39835 Mtetra
.74702 .39835 .75211 .40501 .76348 .40141 .75842 .39473 Mtetra
.75842 .39473 .76348 .40141 .77489 .39779 .76987 .39109 Mtetra
.76987 .39109 .77489 .39779 .78635 .39417 .78136 .38743 Mtetra
.78136 .38743 .78635 .39417 .79786 .39053 .79289 .38376 Mtetra
.79289 .38376 .79786 .39053 .80941 .38687 .80448 .38008 Mtetra
.80448 .38008 .80941 .38687 .821 .3832 .81611 .37638 Mtetra
.81611 .37638 .821 .3832 .83265 .37951 .82779 .37267 Mtetra
.82779 .37267 .83265 .37951 .84434 .37581 .83951 .36894 Mtetra
.83951 .36894 .84434 .37581 .85608 .3721 .85128 .3652 Mtetra
.85128 .3652 .85608 .3721 .86786 .36837 .8631 .36144 Mtetra
.23264 .55431 .23902 .55988 .24848 .55687 .24213 .55128 Mtetra
.24213 .55128 .24848 .55687 .25798 .55385 .25165 .54824 Mtetra
.25165 .54824 .25798 .55385 .26751 .55082 .2612 .54519 Mtetra
.2612 .54519 .26751 .55082 .27708 .54777 .27079 .54213 Mtetra
.27079 .54213 .27708 .54777 .28669 .54472 .28041 .53905 Mtetra
.28041 .53905 .28669 .54472 .29632 .54166 .29007 .53597 Mtetra
.29007 .53597 .29632 .54166 .306 .53858 .29977 .53287 Mtetra
.29977 .53287 .306 .53858 .31571 .53549 .3095 .52976 Mtetra
.3095 .52976 .31571 .53549 .32545 .53239 .31926 .52664 Mtetra
.31926 .52664 .32545 .53239 .33523 .52928 .32907 .52351 Mtetra
.32907 .52351 .33523 .52928 .34505 .52616 .33891 .52037 Mtetra
.33891 .52037 .34505 .52616 .3549 .52303 .34878 .51722 Mtetra
.34878 .51722 .3549 .52303 .36479 .51989 .35869 .51405 Mtetra
.35869 .51405 .36479 .51989 .37472 .51673 .36864 .51087 Mtetra
.36864 .51087 .37472 .51673 .38468 .51356 .37863 .50768 Mtetra
.37863 .50768 .38468 .51356 .39468 .51038 .38865 .50448 Mtetra
.38865 .50448 .39468 .51038 .40472 .50719 .39872 .50127 Mtetra
.39872 .50127 .40472 .50719 .4148 .50399 .40882 .49804 Mtetra
.40882 .49804 .4148 .50399 .42491 .50077 .41895 .4948 Mtetra
.41895 .4948 .42491 .50077 .43506 .49754 .42913 .49155 Mtetra
.42913 .49155 .43506 .49754 .44525 .4943 .43934 .48829 Mtetra
.43934 .48829 .44525 .4943 .45548 .49105 .4496 .48501 Mtetra
.4496 .48501 .45548 .49105 .46575 .48779 .45989 .48173 Mtetra
.45989 .48173 .46575 .48779 .47605 .48451 .47022 .47843 Mtetra
.47022 .47843 .47605 .48451 .4864 .48122 .48059 .47511 Mtetra
.48059 .47511 .4864 .48122 .49678 .47792 .491 .47179 Mtetra
.491 .47179 .49678 .47792 .50721 .4746 .50145 .46845 Mtetra
.50145 .46845 .50721 .4746 .51767 .47128 .51194 .4651 Mtetra
.51194 .4651 .51767 .47128 .52817 .46794 .52247 .46174 Mtetra
.52247 .46174 .52817 .46794 .53872 .46458 .53304 .45836 Mtetra
.53304 .45836 .53872 .46458 .5493 .46122 .54365 .45497 Mtetra
.54365 .45497 .5493 .46122 .55993 .45784 .5543 .45157 Mtetra
.5543 .45157 .55993 .45784 .57059 .45445 .565 .44815 Mtetra
.565 .44815 .57059 .45445 .5813 .45104 .57573 .44472 Mtetra
.57573 .44472 .5813 .45104 .59205 .44763 .58651 .44128 Mtetra
.58651 .44128 .59205 .44763 .60284 .4442 .59732 .43783 Mtetra
.59732 .43783 .60284 .4442 .61367 .44075 .60819 .43436 Mtetra
.60819 .43436 .61367 .44075 .62455 .43729 .61909 .43087 Mtetra
.61909 .43087 .62455 .43729 .63546 .43382 .63003 .42738 Mtetra
.63003 .42738 .63546 .43382 .64642 .43034 .64102 .42387 Mtetra
.64102 .42387 .64642 .43034 .65743 .42684 .65205 .42034 Mtetra
.65205 .42034 .65743 .42684 .66847 .42333 .66313 .41681 Mtetra
.66313 .41681 .66847 .42333 .67956 .4198 .67425 .41326 Mtetra
.67425 .41326 .67956 .4198 .69069 .41626 .68541 .40969 Mtetra
.68541 .40969 .69069 .41626 .70187 .41271 .69662 .40611 Mtetra
.69662 .40611 .70187 .41271 .71309 .40914 .70787 .40252 Mtetra
.70787 .40252 .71309 .40914 .72436 .40556 .71917 .39891 Mtetra
.71917 .39891 .72436 .40556 .73566 .40196 .73051 .39529 Mtetra
.73051 .39529 .73566 .40196 .74702 .39835 .74189 .39165 Mtetra
.74189 .39165 .74702 .39835 .75842 .39473 .75332 .388 Mtetra
.75332 .388 .75842 .39473 .76987 .39109 .7648 .38433 Mtetra
.7648 .38433 .76987 .39109 .78136 .38743 .77633 .38065 Mtetra
.77633 .38065 .78136 .38743 .79289 .38376 .7879 .37695 Mtetra
.7879 .37695 .79289 .38376 .80448 .38008 .79951 .37324 Mtetra
.79951 .37324 .80448 .38008 .81611 .37638 .81118 .36952 Mtetra
.81118 .36952 .81611 .37638 .82779 .37267 .82289 .36578 Mtetra
.82289 .36578 .82779 .37267 .83951 .36894 .83465 .36202 Mtetra
.83465 .36202 .83951 .36894 .85128 .3652 .84645 .35825 Mtetra
.84645 .35825 .85128 .3652 .8631 .36144 .85831 .35446 Mtetra
.22623 .54871 .23264 .55431 .24213 .55128 .23573 .54566 Mtetra
.23573 .54566 .24213 .55128 .25165 .54824 .24527 .5426 Mtetra
.24527 .5426 .25165 .54824 .2612 .54519 .25484 .53953 Mtetra
.25484 .53953 .2612 .54519 .27079 .54213 .26445 .53644 Mtetra
.26445 .53644 .27079 .54213 .28041 .53905 .2741 .53335 Mtetra
.2741 .53335 .28041 .53905 .29007 .53597 .28378 .53024 Mtetra
.28378 .53024 .29007 .53597 .29977 .53287 .2935 .52712 Mtetra
.2935 .52712 .29977 .53287 .3095 .52976 .30325 .524 Mtetra
.30325 .524 .3095 .52976 .31926 .52664 .31304 .52085 Mtetra
.31304 .52085 .31926 .52664 .32907 .52351 .32286 .5177 Mtetra
.32286 .5177 .32907 .52351 .33891 .52037 .33272 .51454 Mtetra
.33272 .51454 .33891 .52037 .34878 .51722 .34262 .51136 Mtetra
.34262 .51136 .34878 .51722 .35869 .51405 .35256 .50817 Mtetra
.35256 .50817 .35869 .51405 .36864 .51087 .36253 .50497 Mtetra
.36253 .50497 .36864 .51087 .37863 .50768 .37254 .50176 Mtetra
.37254 .50176 .37863 .50768 .38865 .50448 .38258 .49854 Mtetra
.38258 .49854 .38865 .50448 .39872 .50127 .39267 .4953 Mtetra
.39267 .4953 .39872 .50127 .40882 .49804 .40279 .49205 Mtetra
.40279 .49205 .40882 .49804 .41895 .4948 .41295 .48879 Mtetra
.41295 .48879 .41895 .4948 .42913 .49155 .42315 .48552 Mtetra
.42315 .48552 .42913 .49155 .43934 .48829 .43339 .48223 Mtetra
.43339 .48223 .43934 .48829 .4496 .48501 .44367 .47893 Mtetra
.44367 .47893 .4496 .48501 .45989 .48173 .45399 .47562 Mtetra
.45399 .47562 .45989 .48173 .47022 .47843 .46434 .4723 Mtetra
.46434 .4723 .47022 .47843 .48059 .47511 .47474 .46897 Mtetra
.47474 .46897 .48059 .47511 .491 .47179 .48517 .46562 Mtetra
.48517 .46562 .491 .47179 .50145 .46845 .49565 .46226 Mtetra
.49565 .46226 .50145 .46845 .51194 .4651 .50617 .45888 Mtetra
.50617 .45888 .51194 .4651 .52247 .46174 .51672 .45549 Mtetra
.51672 .45549 .52247 .46174 .53304 .45836 .52732 .45209 Mtetra
.52732 .45209 .53304 .45836 .54365 .45497 .53796 .44868 Mtetra
.53796 .44868 .54365 .45497 .5543 .45157 .54864 .44525 Mtetra
.54864 .44525 .5543 .45157 .565 .44815 .55936 .44181 Mtetra
.55936 .44181 .565 .44815 .57573 .44472 .57012 .43836 Mtetra
.57012 .43836 .57573 .44472 .58651 .44128 .58092 .43489 Mtetra
.58092 .43489 .58651 .44128 .59732 .43783 .59177 .43141 Mtetra
.59177 .43141 .59732 .43783 .60819 .43436 .60266 .42792 Mtetra
.60266 .42792 .60819 .43436 .61909 .43087 .61359 .42441 Mtetra
.61359 .42441 .61909 .43087 .63003 .42738 .62456 .42089 Mtetra
.62456 .42089 .63003 .42738 .64102 .42387 .63558 .41735 Mtetra
.63558 .41735 .64102 .42387 .65205 .42034 .64664 .4138 Mtetra
.64664 .4138 .65205 .42034 .66313 .41681 .65775 .41024 Mtetra
.65775 .41024 .66313 .41681 .67425 .41326 .6689 .40666 Mtetra
.6689 .40666 .67425 .41326 .68541 .40969 .68009 .40307 Mtetra
.68009 .40307 .68541 .40969 .69662 .40611 .69133 .39946 Mtetra
.69133 .39946 .69662 .40611 .70787 .40252 .70261 .39584 Mtetra
.70261 .39584 .70787 .40252 .71917 .39891 .71394 .39221 Mtetra
.71394 .39221 .71917 .39891 .73051 .39529 .72531 .38856 Mtetra
.72531 .38856 .73051 .39529 .74189 .39165 .73673 .3849 Mtetra
.73673 .3849 .74189 .39165 .75332 .388 .74819 .38122 Mtetra
.74819 .38122 .75332 .388 .7648 .38433 .7597 .37752 Mtetra
.7597 .37752 .7648 .38433 .77633 .38065 .77126 .37381 Mtetra
.77126 .37381 .77633 .38065 .7879 .37695 .78286 .37009 Mtetra
.78286 .37009 .7879 .37695 .79951 .37324 .79451 .36635 Mtetra
.79451 .36635 .79951 .37324 .81118 .36952 .80621 .3626 Mtetra
.80621 .3626 .81118 .36952 .82289 .36578 .81795 .35883 Mtetra
.81795 .35883 .82289 .36578 .83465 .36202 .82975 .35505 Mtetra
.82975 .35505 .83465 .36202 .84645 .35825 .84159 .35125 Mtetra
.84159 .35125 .84645 .35825 .85831 .35446 .85348 .34743 Mtetra
.21976 .54307 .22623 .54871 .23573 .54566 .22929 .54 Mtetra
.22929 .54 .23573 .54566 .24527 .5426 .23885 .53692 Mtetra
.23885 .53692 .24527 .5426 .25484 .53953 .24844 .53383 Mtetra
.24844 .53383 .25484 .53953 .26445 .53644 .25807 .53072 Mtetra
.25807 .53072 .26445 .53644 .2741 .53335 .26774 .52761 Mtetra
.26774 .52761 .2741 .53335 .28378 .53024 .27744 .52448 Mtetra
.27744 .52448 .28378 .53024 .2935 .52712 .28718 .52134 Mtetra
.28718 .52134 .2935 .52712 .30325 .524 .29695 .51819 Mtetra
.29695 .51819 .30325 .524 .31304 .52085 .30676 .51503 Mtetra
.30676 .51503 .31304 .52085 .32286 .5177 .31661 .51185 Mtetra
.31661 .51185 .32286 .5177 .33272 .51454 .3265 .50866 Mtetra
.3265 .50866 .33272 .51454 .34262 .51136 .33642 .50547 Mtetra
.33642 .50547 .34262 .51136 .35256 .50817 .34637 .50226 Mtetra
.34637 .50226 .35256 .50817 .36253 .50497 .35637 .49903 Mtetra
.35637 .49903 .36253 .50497 .37254 .50176 .3664 .4958 Mtetra
.3664 .4958 .37254 .50176 .38258 .49854 .37647 .49255 Mtetra
.37647 .49255 .38258 .49854 .39267 .4953 .38658 .48929 Mtetra
.38658 .48929 .39267 .4953 .40279 .49205 .39673 .48602 Mtetra
.39673 .48602 .40279 .49205 .41295 .48879 .40691 .48274 Mtetra
.40691 .48274 .41295 .48879 .42315 .48552 .41714 .47944 Mtetra
.41714 .47944 .42315 .48552 .43339 .48223 .4274 .47613 Mtetra
.4274 .47613 .43339 .48223 .44367 .47893 .4377 .47281 Mtetra
.4377 .47281 .44367 .47893 .45399 .47562 .44805 .46948 Mtetra
.44805 .46948 .45399 .47562 .46434 .4723 .45843 .46613 Mtetra
.45843 .46613 .46434 .4723 .47474 .46897 .46885 .46277 Mtetra
.46885 .46277 .47474 .46897 .48517 .46562 .47931 .4594 Mtetra
.47931 .4594 .48517 .46562 .49565 .46226 .48981 .45602 Mtetra
.48981 .45602 .49565 .46226 .50617 .45888 .50035 .45262 Mtetra
.50035 .45262 .50617 .45888 .51672 .45549 .51093 .44921 Mtetra
.51093 .44921 .51672 .45549 .52732 .45209 .52156 .44578 Mtetra
.52156 .44578 .52732 .45209 .53796 .44868 .53222 .44234 Mtetra
.53222 .44234 .53796 .44868 .54864 .44525 .54293 .43889 Mtetra
.54293 .43889 .54864 .44525 .55936 .44181 .55368 .43543 Mtetra
.55368 .43543 .55936 .44181 .57012 .43836 .56447 .43195 Mtetra
.56447 .43195 .57012 .43836 .58092 .43489 .5753 .42846 Mtetra
.5753 .42846 .58092 .43489 .59177 .43141 .58617 .42495 Mtetra
.58617 .42495 .59177 .43141 .60266 .42792 .59709 .42143 Mtetra
.59709 .42143 .60266 .42792 .61359 .42441 .60805 .4179 Mtetra
.60805 .4179 .61359 .42441 .62456 .42089 .61906 .41435 Mtetra
.61906 .41435 .62456 .42089 .63558 .41735 .6301 .41079 Mtetra
.6301 .41079 .63558 .41735 .64664 .4138 .64119 .40721 Mtetra
.64119 .40721 .64664 .4138 .65775 .41024 .65233 .40362 Mtetra
.65233 .40362 .65775 .41024 .6689 .40666 .66351 .40002 Mtetra
.66351 .40002 .6689 .40666 .68009 .40307 .67473 .3964 Mtetra
.67473 .3964 .68009 .40307 .69133 .39946 .686 .39277 Mtetra
.686 .39277 .69133 .39946 .70261 .39584 .69731 .38912 Mtetra
.69731 .38912 .70261 .39584 .71394 .39221 .70867 .38546 Mtetra
.70867 .38546 .71394 .39221 .72531 .38856 .72007 .38178 Mtetra
.72007 .38178 .72531 .38856 .73673 .3849 .73152 .37809 Mtetra
.73152 .37809 .73673 .3849 .74819 .38122 .74302 .37439 Mtetra
.74302 .37439 .74819 .38122 .7597 .37752 .75456 .37067 Mtetra
.75456 .37067 .7597 .37752 .77126 .37381 .76615 .36693 Mtetra
.76615 .36693 .77126 .37381 .78286 .37009 .77779 .36318 Mtetra
.77779 .36318 .78286 .37009 .79451 .36635 .78947 .35941 Mtetra
.78947 .35941 .79451 .36635 .80621 .3626 .8012 .35563 Mtetra
.8012 .35563 .80621 .3626 .81795 .35883 .81298 .35183 Mtetra
.81298 .35183 .81795 .35883 .82975 .35505 .82481 .34802 Mtetra
.82481 .34802 .82975 .35505 .84159 .35125 .83668 .34419 Mtetra
.83668 .34419 .84159 .35125 .85348 .34743 .84861 .34035 Mtetra
.21326 .53739 .21976 .54307 .22929 .54 .2228 .5343 Mtetra
.2228 .5343 .22929 .54 .23885 .53692 .23238 .5312 Mtetra
.23238 .5312 .23885 .53692 .24844 .53383 .242 .52809 Mtetra
.242 .52809 .24844 .53383 .25807 .53072 .25165 .52496 Mtetra
.25165 .52496 .25807 .53072 .26774 .52761 .26134 .52182 Mtetra
.26134 .52182 .26774 .52761 .27744 .52448 .27106 .51867 Mtetra
.27106 .51867 .27744 .52448 .28718 .52134 .28082 .51551 Mtetra
.28082 .51551 .28718 .52134 .29695 .51819 .29062 .51234 Mtetra
.29062 .51234 .29695 .51819 .30676 .51503 .30045 .50916 Mtetra
.30045 .50916 .30676 .51503 .31661 .51185 .31032 .50596 Mtetra
.31032 .50596 .31661 .51185 .3265 .50866 .32022 .50275 Mtetra
.32022 .50275 .3265 .50866 .33642 .50547 .33017 .49953 Mtetra
.33017 .49953 .33642 .50547 .34637 .50226 .34015 .4963 Mtetra
.34015 .4963 .34637 .50226 .35637 .49903 .35017 .49305 Mtetra
.35017 .49305 .35637 .49903 .3664 .4958 .36022 .4898 Mtetra
.36022 .4898 .3664 .4958 .37647 .49255 .37032 .48653 Mtetra
.37032 .48653 .37647 .49255 .38658 .48929 .38045 .48325 Mtetra
.38045 .48325 .38658 .48929 .39673 .48602 .39062 .47995 Mtetra
.39062 .47995 .39673 .48602 .40691 .48274 .40083 .47664 Mtetra
.40083 .47664 .40691 .48274 .41714 .47944 .41108 .47333 Mtetra
.41108 .47333 .41714 .47944 .4274 .47613 .42137 .46999 Mtetra
.42137 .46999 .4274 .47613 .4377 .47281 .43169 .46665 Mtetra
.43169 .46665 .4377 .47281 .44805 .46948 .44206 .46329 Mtetra
.44206 .46329 .44805 .46948 .45843 .46613 .45247 .45992 Mtetra
.45247 .45992 .45843 .46613 .46885 .46277 .46291 .45654 Mtetra
.46291 .45654 .46885 .46277 .47931 .4594 .4734 .45314 Mtetra
.4734 .45314 .47931 .4594 .48981 .45602 .48393 .44973 Mtetra
.48393 .44973 .48981 .45602 .50035 .45262 .4945 .44631 Mtetra
.4945 .44631 .50035 .45262 .51093 .44921 .50511 .44287 Mtetra
.50511 .44287 .51093 .44921 .52156 .44578 .51576 .43942 Mtetra
.51576 .43942 .52156 .44578 .53222 .44234 .52645 .43596 Mtetra
.52645 .43596 .53222 .44234 .54293 .43889 .53718 .43248 Mtetra
.53718 .43248 .54293 .43889 .55368 .43543 .54796 .42899 Mtetra
.54796 .42899 .55368 .43543 .56447 .43195 .55878 .42549 Mtetra
.55878 .42549 .56447 .43195 .5753 .42846 .56964 .42197 Mtetra
.56964 .42197 .5753 .42846 .58617 .42495 .58054 .41844 Mtetra
.58054 .41844 .58617 .42495 .59709 .42143 .59149 .4149 Mtetra
.59149 .4149 .59709 .42143 .60805 .4179 .60247 .41134 Mtetra
.60247 .41134 .60805 .4179 .61906 .41435 .61351 .40776 Mtetra
.61351 .40776 .61906 .41435 .6301 .41079 .62458 .40418 Mtetra
.62458 .40418 .6301 .41079 .64119 .40721 .6357 .40057 Mtetra
.6357 .40057 .64119 .40721 .65233 .40362 .64687 .39696 Mtetra
.64687 .39696 .65233 .40362 .66351 .40002 .65808 .39333 Mtetra
.65808 .39333 .66351 .40002 .67473 .3964 .66933 .38968 Mtetra
.66933 .38968 .67473 .3964 .686 .39277 .68063 .38602 Mtetra
.68063 .38602 .686 .39277 .69731 .38912 .69198 .38235 Mtetra
.69198 .38235 .69731 .38912 .70867 .38546 .70336 .37866 Mtetra
.70336 .37866 .70867 .38546 .72007 .38178 .7148 .37496 Mtetra
.7148 .37496 .72007 .38178 .73152 .37809 .72628 .37124 Mtetra
.72628 .37124 .73152 .37809 .74302 .37439 .73781 .3675 Mtetra
.73781 .3675 .74302 .37439 .75456 .37067 .74939 .36376 Mtetra
.74939 .36376 .75456 .37067 .76615 .36693 .76101 .35999 Mtetra
.76101 .35999 .76615 .36693 .77779 .36318 .77268 .35621 Mtetra
.77268 .35621 .77779 .36318 .78947 .35941 .78439 .35242 Mtetra
.78439 .35242 .78947 .35941 .8012 .35563 .79616 .34861 Mtetra
.79616 .34861 .8012 .35563 .81298 .35183 .80797 .34478 Mtetra
.80797 .34478 .81298 .35183 .82481 .34802 .81983 .34094 Mtetra
.81983 .34094 .82481 .34802 .83668 .34419 .83174 .33708 Mtetra
.83174 .33708 .83668 .34419 .84861 .34035 .8437 .33321 Mtetra
.20671 .53168 .21326 .53739 .2228 .5343 .21628 .52857 Mtetra
.21628 .52857 .2228 .5343 .23238 .5312 .22588 .52544 Mtetra
.22588 .52544 .23238 .5312 .242 .52809 .23551 .52231 Mtetra
.23551 .52231 .242 .52809 .25165 .52496 .24519 .51916 Mtetra
.24519 .51916 .25165 .52496 .26134 .52182 .25489 .516 Mtetra
.25489 .516 .26134 .52182 .27106 .51867 .26464 .51283 Mtetra
.26464 .51283 .27106 .51867 .28082 .51551 .27442 .50965 Mtetra
.27442 .50965 .28082 .51551 .29062 .51234 .28424 .50645 Mtetra
.28424 .50645 .29062 .51234 .30045 .50916 .29409 .50324 Mtetra
.29409 .50324 .30045 .50916 .31032 .50596 .30398 .50003 Mtetra
.30398 .50003 .31032 .50596 .32022 .50275 .31391 .4968 Mtetra
.31391 .4968 .32022 .50275 .33017 .49953 .32388 .49355 Mtetra
.32388 .49355 .33017 .49953 .34015 .4963 .33388 .4903 Mtetra
.33388 .4903 .34015 .4963 .35017 .49305 .34392 .48703 Mtetra
.34392 .48703 .35017 .49305 .36022 .4898 .354 .48375 Mtetra
.354 .48375 .36022 .4898 .37032 .48653 .36412 .48046 Mtetra
.36412 .48046 .37032 .48653 .38045 .48325 .37428 .47715 Mtetra
.37428 .47715 .38045 .48325 .39062 .47995 .38447 .47384 Mtetra
.38447 .47384 .39062 .47995 .40083 .47664 .3947 .47051 Mtetra
.3947 .47051 .40083 .47664 .41108 .47333 .40498 .46716 Mtetra
.40498 .46716 .41108 .47333 .42137 .46999 .41529 .46381 Mtetra
.41529 .46381 .42137 .46999 .43169 .46665 .42564 .46044 Mtetra
.42564 .46044 .43169 .46665 .44206 .46329 .43603 .45706 Mtetra
.43603 .45706 .44206 .46329 .45247 .45992 .44647 .45366 Mtetra
.44647 .45366 .45247 .45992 .46291 .45654 .45694 .45026 Mtetra
.45694 .45026 .46291 .45654 .4734 .45314 .46745 .44684 Mtetra
.46745 .44684 .4734 .45314 .48393 .44973 .47801 .4434 Mtetra
.47801 .4434 .48393 .44973 .4945 .44631 .4886 .43995 Mtetra
.4886 .43995 .4945 .44631 .50511 .44287 .49924 .43649 Mtetra
.49924 .43649 .50511 .44287 .51576 .43942 .50991 .43302 Mtetra
.50991 .43302 .51576 .43942 .52645 .43596 .52063 .42953 Mtetra
.52063 .42953 .52645 .43596 .53718 .43248 .53139 .42603 Mtetra
.53139 .42603 .53718 .43248 .54796 .42899 .5422 .42251 Mtetra
.5422 .42251 .54796 .42899 .55878 .42549 .55304 .41899 Mtetra
.55304 .41899 .55878 .42549 .56964 .42197 .56393 .41544 Mtetra
.56393 .41544 .56964 .42197 .58054 .41844 .57486 .41189 Mtetra
.57486 .41189 .58054 .41844 .59149 .4149 .58584 .40831 Mtetra
.58584 .40831 .59149 .4149 .60247 .41134 .59686 .40473 Mtetra
.59686 .40473 .60247 .41134 .61351 .40776 .60792 .40113 Mtetra
.60792 .40113 .61351 .40776 .62458 .40418 .61902 .39752 Mtetra
.61902 .39752 .62458 .40418 .6357 .40057 .63017 .39389 Mtetra
.63017 .39389 .6357 .40057 .64687 .39696 .64137 .39025 Mtetra
.64137 .39025 .64687 .39696 .65808 .39333 .65261 .38659 Mtetra
.65261 .38659 .65808 .39333 .66933 .38968 .66389 .38292 Mtetra
.66389 .38292 .66933 .38968 .68063 .38602 .67522 .37923 Mtetra
.67522 .37923 .68063 .38602 .69198 .38235 .6866 .37553 Mtetra
.6866 .37553 .69198 .38235 .70336 .37866 .69802 .37181 Mtetra
.69802 .37181 .70336 .37866 .7148 .37496 .70949 .36808 Mtetra
.70949 .36808 .7148 .37496 .72628 .37124 .721 .36433 Mtetra
.721 .36433 .72628 .37124 .73781 .3675 .73256 .36057 Mtetra
.73256 .36057 .73781 .3675 .74939 .36376 .74417 .35679 Mtetra
.74417 .35679 .74939 .36376 .76101 .35999 .75583 .353 Mtetra
.75583 .353 .76101 .35999 .77268 .35621 .76753 .34919 Mtetra
.76753 .34919 .77268 .35621 .78439 .35242 .77928 .34537 Mtetra
.77928 .34537 .78439 .35242 .79616 .34861 .79108 .34153 Mtetra
.79108 .34153 .79616 .34861 .80797 .34478 .80293 .33768 Mtetra
.80293 .33768 .80797 .34478 .81983 .34094 .81482 .33381 Mtetra
.81482 .33381 .81983 .34094 .83174 .33708 .82677 .32992 Mtetra
.82677 .32992 .83174 .33708 .8437 .33321 .83876 .32602 Mtetra
.20012 .52592 .20671 .53168 .21628 .52857 .2097 .52279 Mtetra
.2097 .52279 .21628 .52857 .22588 .52544 .21932 .51964 Mtetra
.21932 .51964 .22588 .52544 .23551 .52231 .22898 .51649 Mtetra
.22898 .51649 .23551 .52231 .24519 .51916 .23867 .51332 Mtetra
.23867 .51332 .24519 .51916 .25489 .516 .2484 .51014 Mtetra
.2484 .51014 .25489 .516 .26464 .51283 .25817 .50694 Mtetra
.25817 .50694 .26464 .51283 .27442 .50965 .26797 .50374 Mtetra
.26797 .50374 .27442 .50965 .28424 .50645 .27781 .50052 Mtetra
.27781 .50052 .28424 .50645 .29409 .50324 .28769 .49729 Mtetra
.28769 .49729 .29409 .50324 .30398 .50003 .2976 .49405 Mtetra
.2976 .49405 .30398 .50003 .31391 .4968 .30755 .4908 Mtetra
.30755 .4908 .31391 .4968 .32388 .49355 .31754 .48753 Mtetra
.31754 .48753 .32388 .49355 .33388 .4903 .32757 .48426 Mtetra
.32757 .48426 .33388 .4903 .34392 .48703 .33763 .48097 Mtetra
.33763 .48097 .34392 .48703 .354 .48375 .34774 .47766 Mtetra
.34774 .47766 .354 .48375 .36412 .48046 .35788 .47435 Mtetra
.35788 .47435 .36412 .48046 .37428 .47715 .36806 .47102 Mtetra
.36806 .47102 .37428 .47715 .38447 .47384 .37828 .46768 Mtetra
.37828 .46768 .38447 .47384 .3947 .47051 .38854 .46433 Mtetra
.38854 .46433 .3947 .47051 .40498 .46716 .39883 .46096 Mtetra
.39883 .46096 .40498 .46716 .41529 .46381 .40917 .45758 Mtetra
.40917 .45758 .41529 .46381 .42564 .46044 .41955 .45419 Mtetra
.41955 .45419 .42564 .46044 .43603 .45706 .42996 .45078 Mtetra
.42996 .45078 .43603 .45706 .44647 .45366 .44042 .44736 Mtetra
.44042 .44736 .44647 .45366 .45694 .45026 .45092 .44393 Mtetra
.45092 .44393 .45694 .45026 .46745 .44684 .46146 .44049 Mtetra
.46146 .44049 .46745 .44684 .47801 .4434 .47204 .43703 Mtetra
.47204 .43703 .47801 .4434 .4886 .43995 .48266 .43355 Mtetra
.48266 .43355 .4886 .43995 .49924 .43649 .49332 .43007 Mtetra
.49332 .43007 .49924 .43649 .50991 .43302 .50403 .42657 Mtetra
.50403 .42657 .50991 .43302 .52063 .42953 .51477 .42306 Mtetra
.51477 .42306 .52063 .42953 .53139 .42603 .52556 .41953 Mtetra
.52556 .41953 .53139 .42603 .5422 .42251 .53639 .41599 Mtetra
.53639 .41599 .5422 .42251 .55304 .41899 .54727 .41243 Mtetra
.54727 .41243 .55304 .41899 .56393 .41544 .55818 .40886 Mtetra
.55818 .40886 .56393 .41544 .57486 .41189 .56914 .40528 Mtetra
.56914 .40528 .57486 .41189 .58584 .40831 .58015 .40168 Mtetra
.58015 .40168 .58584 .40831 .59686 .40473 .5912 .39807 Mtetra
.5912 .39807 .59686 .40473 .60792 .40113 .60229 .39445 Mtetra
.60229 .39445 .60792 .40113 .61902 .39752 .61342 .39081 Mtetra
.61342 .39081 .61902 .39752 .63017 .39389 .6246 .38715 Mtetra
.6246 .38715 .63017 .39389 .64137 .39025 .63583 .38348 Mtetra
.63583 .38348 .64137 .39025 .65261 .38659 .6471 .3798 Mtetra
.6471 .3798 .65261 .38659 .66389 .38292 .65841 .3761 Mtetra
.65841 .3761 .66389 .38292 .67522 .37923 .66977 .37238 Mtetra
.66977 .37238 .67522 .37923 .6866 .37553 .68118 .36866 Mtetra
.68118 .36866 .6866 .37553 .69802 .37181 .69263 .36491 Mtetra
.69263 .36491 .69802 .37181 .70949 .36808 .70413 .36115 Mtetra
.70413 .36115 .70949 .36808 .721 .36433 .71568 .35738 Mtetra
.71568 .35738 .721 .36433 .73256 .36057 .72727 .35359 Mtetra
.72727 .35359 .73256 .36057 .74417 .35679 .73892 .34978 Mtetra
.73892 .34978 .74417 .35679 .75583 .353 .7506 .34596 Mtetra
.7506 .34596 .75583 .353 .76753 .34919 .76234 .34212 Mtetra
.76234 .34212 .76753 .34919 .77928 .34537 .77412 .33827 Mtetra
.77412 .33827 .77928 .34537 .79108 .34153 .78596 .3344 Mtetra
.78596 .3344 .79108 .34153 .80293 .33768 .79784 .33052 Mtetra
.79784 .33052 .80293 .33768 .81482 .33381 .80977 .32662 Mtetra
.80977 .32662 .81482 .33381 .82677 .32992 .82175 .3227 Mtetra
.82175 .3227 .82677 .32992 .83876 .32602 .83378 .31877 Mtetra
.19348 .52013 .20012 .52592 .2097 .52279 .20308 .51697 Mtetra
.20308 .51697 .2097 .52279 .21932 .51964 .21272 .51381 Mtetra
.21272 .51381 .21932 .51964 .22898 .51649 .2224 .51063 Mtetra
.2224 .51063 .22898 .51649 .23867 .51332 .23212 .50744 Mtetra
.23212 .50744 .23867 .51332 .2484 .51014 .24187 .50423 Mtetra
.24187 .50423 .2484 .51014 .25817 .50694 .25166 .50102 Mtetra
.25166 .50102 .25817 .50694 .26797 .50374 .26148 .49779 Mtetra
.26148 .49779 .26797 .50374 .27781 .50052 .27134 .49455 Mtetra
.27134 .49455 .27781 .50052 .28769 .49729 .28124 .4913 Mtetra
.28124 .4913 .28769 .49729 .2976 .49405 .29118 .48804 Mtetra
.29118 .48804 .2976 .49405 .30755 .4908 .30115 .48476 Mtetra
.30115 .48476 .30755 .4908 .31754 .48753 .31116 .48147 Mtetra
.31116 .48147 .31754 .48753 .32757 .48426 .32121 .47817 Mtetra
.32121 .47817 .32757 .48426 .33763 .48097 .3313 .47486 Mtetra
.3313 .47486 .33763 .48097 .34774 .47766 .34143 .47153 Mtetra
.34143 .47153 .34774 .47766 .35788 .47435 .35159 .46819 Mtetra
.35159 .46819 .35788 .47435 .36806 .47102 .3618 .46484 Mtetra
.3618 .46484 .36806 .47102 .37828 .46768 .37204 .46148 Mtetra
.37204 .46148 .37828 .46768 .38854 .46433 .38232 .4581 Mtetra
.38232 .4581 .38854 .46433 .39883 .46096 .39264 .45471 Mtetra
.39264 .45471 .39883 .46096 .40917 .45758 .40301 .45131 Mtetra
.40301 .45131 .40917 .45758 .41955 .45419 .41341 .44789 Mtetra
.41341 .44789 .41955 .45419 .42996 .45078 .42385 .44446 Mtetra
.42385 .44446 .42996 .45078 .44042 .44736 .43434 .44102 Mtetra
.43434 .44102 .44042 .44736 .45092 .44393 .44486 .43756 Mtetra
.44486 .43756 .45092 .44393 .46146 .44049 .45542 .43409 Mtetra
.45542 .43409 .46146 .44049 .47204 .43703 .46603 .43061 Mtetra
.46603 .43061 .47204 .43703 .48266 .43355 .47668 .42711 Mtetra
.47668 .42711 .48266 .43355 .49332 .43007 .48737 .4236 Mtetra
.48737 .4236 .49332 .43007 .50403 .42657 .4981 .42007 Mtetra
.4981 .42007 .50403 .42657 .51477 .42306 .50887 .41653 Mtetra
.50887 .41653 .51477 .42306 .52556 .41953 .51969 .41298 Mtetra
.51969 .41298 .52556 .41953 .53639 .41599 .53055 .40941 Mtetra
.53055 .40941 .53639 .41599 .54727 .41243 .54145 .40583 Mtetra
.54145 .40583 .54727 .41243 .55818 .40886 .5524 .40224 Mtetra
.5524 .40224 .55818 .40886 .56914 .40528 .56338 .39863 Mtetra
.56338 .39863 .56914 .40528 .58015 .40168 .57442 .39501 Mtetra
.57442 .39501 .58015 .40168 .5912 .39807 .58549 .39137 Mtetra
.58549 .39137 .5912 .39807 .60229 .39445 .59661 .38772 Mtetra
.59661 .38772 .60229 .39445 .61342 .39081 .60778 .38405 Mtetra
.60778 .38405 .61342 .39081 .6246 .38715 .61899 .38037 Mtetra
.61899 .38037 .6246 .38715 .63583 .38348 .63025 .37667 Mtetra
.63025 .37667 .63583 .38348 .6471 .3798 .64155 .37296 Mtetra
.64155 .37296 .6471 .3798 .65841 .3761 .65289 .36923 Mtetra
.65289 .36923 .65841 .3761 .66977 .37238 .66429 .36549 Mtetra
.66429 .36549 .66977 .37238 .68118 .36866 .67572 .36173 Mtetra
.67572 .36173 .68118 .36866 .69263 .36491 .68721 .35796 Mtetra
.68721 .35796 .69263 .36491 .70413 .36115 .69874 .35417 Mtetra
.69874 .35417 .70413 .36115 .71568 .35738 .71032 .35037 Mtetra
.71032 .35037 .71568 .35738 .72727 .35359 .72195 .34655 Mtetra
.72195 .34655 .72727 .35359 .73892 .34978 .73362 .34271 Mtetra
.73362 .34271 .73892 .34978 .7506 .34596 .74534 .33886 Mtetra
.74534 .33886 .7506 .34596 .76234 .34212 .75711 .335 Mtetra
.75711 .335 .76234 .34212 .77412 .33827 .76893 .33112 Mtetra
.76893 .33112 .77412 .33827 .78596 .3344 .7808 .32722 Mtetra
.7808 .32722 .78596 .3344 .79784 .33052 .79272 .3233 Mtetra
.79272 .3233 .79784 .33052 .80977 .32662 .80468 .31937 Mtetra
.80468 .31937 .80977 .32662 .82175 .3227 .8167 .31543 Mtetra
.8167 .31543 .82175 .3227 .83378 .31877 .82876 .31146 Mtetra
.18679 .51429 .19348 .52013 .20308 .51697 .19642 .51112 Mtetra
.19642 .51112 .20308 .51697 .21272 .51381 .20608 .50793 Mtetra
.20608 .50793 .21272 .51381 .2224 .51063 .21578 .50473 Mtetra
.21578 .50473 .2224 .51063 .23212 .50744 .22552 .50151 Mtetra
.22552 .50151 .23212 .50744 .24187 .50423 .23529 .49829 Mtetra
.23529 .49829 .24187 .50423 .25166 .50102 .2451 .49505 Mtetra
.2451 .49505 .25166 .50102 .26148 .49779 .25494 .4918 Mtetra
.25494 .4918 .26148 .49779 .27134 .49455 .26483 .48854 Mtetra
.26483 .48854 .27134 .49455 .28124 .4913 .27475 .48527 Mtetra
.27475 .48527 .28124 .4913 .29118 .48804 .28471 .48198 Mtetra
.28471 .48198 .29118 .48804 .30115 .48476 .2947 .47868 Mtetra
.2947 .47868 .30115 .48476 .31116 .48147 .30474 .47537 Mtetra
.30474 .47537 .31116 .48147 .32121 .47817 .31481 .47205 Mtetra
.31481 .47205 .32121 .47817 .3313 .47486 .32492 .46871 Mtetra
.32492 .46871 .3313 .47486 .34143 .47153 .33507 .46536 Mtetra
.33507 .46536 .34143 .47153 .35159 .46819 .34526 .462 Mtetra
.34526 .462 .35159 .46819 .3618 .46484 .35549 .45862 Mtetra
.35549 .45862 .3618 .46484 .37204 .46148 .36576 .45523 Mtetra
.36576 .45523 .37204 .46148 .38232 .4581 .37607 .45183 Mtetra
.37607 .45183 .38232 .4581 .39264 .45471 .38641 .44842 Mtetra
.38641 .44842 .39264 .45471 .40301 .45131 .3968 .44499 Mtetra
.3968 .44499 .40301 .45131 .41341 .44789 .40723 .44155 Mtetra
.40723 .44155 .41341 .44789 .42385 .44446 .41769 .43809 Mtetra
.41769 .43809 .42385 .44446 .43434 .44102 .4282 .43462 Mtetra
.4282 .43462 .43434 .44102 .44486 .43756 .43875 .43114 Mtetra
.43875 .43114 .44486 .43756 .45542 .43409 .44934 .42765 Mtetra
.44934 .42765 .45542 .43409 .46603 .43061 .45998 .42414 Mtetra
.45998 .42414 .46603 .43061 .47668 .42711 .47065 .42062 Mtetra
.47065 .42062 .47668 .42711 .48737 .4236 .48137 .41708 Mtetra
.48137 .41708 .48737 .4236 .4981 .42007 .49213 .41353 Mtetra
.49213 .41353 .4981 .42007 .50887 .41653 .50293 .40996 Mtetra
.50293 .40996 .50887 .41653 .51969 .41298 .51377 .40639 Mtetra
.51377 .40639 .51969 .41298 .53055 .40941 .52466 .40279 Mtetra
.52466 .40279 .53055 .40941 .54145 .40583 .53559 .39919 Mtetra
.53559 .39919 .54145 .40583 .5524 .40224 .54656 .39556 Mtetra
.54656 .39556 .5524 .40224 .56338 .39863 .55758 .39193 Mtetra
.55758 .39193 .56338 .39863 .57442 .39501 .56864 .38828 Mtetra
.56864 .38828 .57442 .39501 .58549 .39137 .57975 .38461 Mtetra
.57975 .38461 .58549 .39137 .59661 .38772 .5909 .38093 Mtetra
.5909 .38093 .59661 .38772 .60778 .38405 .6021 .37724 Mtetra
.6021 .37724 .60778 .38405 .61899 .38037 .61334 .37353 Mtetra
.61334 .37353 .61899 .38037 .63025 .37667 .62462 .3698 Mtetra
.62462 .3698 .63025 .37667 .64155 .37296 .63595 .36606 Mtetra
.63595 .36606 .64155 .37296 .65289 .36923 .64733 .36231 Mtetra
.64733 .36231 .65289 .36923 .66429 .36549 .65875 .35854 Mtetra
.65875 .35854 .66429 .36549 .67572 .36173 .67023 .35475 Mtetra
.67023 .35475 .67572 .36173 .68721 .35796 .68174 .35095 Mtetra
.68174 .35095 .68721 .35796 .69874 .35417 .69331 .34714 Mtetra
.69331 .34714 .69874 .35417 .71032 .35037 .70492 .34331 Mtetra
.70492 .34331 .71032 .35037 .72195 .34655 .71658 .33946 Mtetra
.71658 .33946 .72195 .34655 .73362 .34271 .72829 .33559 Mtetra
.72829 .33559 .73362 .34271 .74534 .33886 .74004 .33171 Mtetra
.74004 .33171 .74534 .33886 .75711 .335 .75184 .32782 Mtetra
.75184 .32782 .75711 .335 .76893 .33112 .7637 .32391 Mtetra
.7637 .32391 .76893 .33112 .7808 .32722 .7756 .31998 Mtetra
.7756 .31998 .7808 .32722 .79272 .3233 .78755 .31604 Mtetra
.78755 .31604 .79272 .3233 .80468 .31937 .79955 .31208 Mtetra
.79955 .31208 .80468 .31937 .8167 .31543 .8116 .3081 Mtetra
.8116 .3081 .8167 .31543 .82876 .31146 .82371 .3041 Mtetra
.18006 .50842 .18679 .51429 .19642 .51112 .18971 .50522 Mtetra
.18971 .50522 .19642 .51112 .20608 .50793 .19939 .50201 Mtetra
.19939 .50201 .20608 .50793 .21578 .50473 .20911 .49879 Mtetra
.20911 .49879 .21578 .50473 .22552 .50151 .21887 .49555 Mtetra
.21887 .49555 .22552 .50151 .23529 .49829 .22866 .4923 Mtetra
.22866 .4923 .23529 .49829 .2451 .49505 .23849 .48904 Mtetra
.23849 .48904 .2451 .49505 .25494 .4918 .24836 .48577 Mtetra
.24836 .48577 .25494 .4918 .26483 .48854 .25827 .48249 Mtetra
.25827 .48249 .26483 .48854 .27475 .48527 .26821 .47919 Mtetra
.26821 .47919 .27475 .48527 .28471 .48198 .27819 .47588 Mtetra
.27819 .47588 .28471 .48198 .2947 .47868 .28821 .47256 Mtetra
.28821 .47256 .2947 .47868 .30474 .47537 .29827 .46922 Mtetra
.29827 .46922 .30474 .47537 .31481 .47205 .30837 .46587 Mtetra
.30837 .46587 .31481 .47205 .32492 .46871 .3185 .46251 Mtetra
.3185 .46251 .32492 .46871 .33507 .46536 .32867 .45914 Mtetra
.32867 .45914 .33507 .46536 .34526 .462 .33889 .45575 Mtetra
.33889 .45575 .34526 .462 .35549 .45862 .34914 .45235 Mtetra
.34914 .45235 .35549 .45862 .36576 .45523 .35943 .44894 Mtetra
.35943 .44894 .36576 .45523 .37607 .45183 .36976 .44552 Mtetra
.36976 .44552 .37607 .45183 .38641 .44842 .38013 .44208 Mtetra
.38013 .44208 .38641 .44842 .3968 .44499 .39055 .43862 Mtetra
.39055 .43862 .3968 .44499 .40723 .44155 .401 .43516 Mtetra
.401 .43516 .40723 .44155 .41769 .43809 .41149 .43168 Mtetra
.41149 .43168 .41769 .43809 .4282 .43462 .42203 .42819 Mtetra
.42203 .42819 .4282 .43462 .43875 .43114 .4326 .42468 Mtetra
.4326 .42468 .43875 .43114 .44934 .42765 .44322 .42116 Mtetra
.44322 .42116 .44934 .42765 .45998 .42414 .45388 .41762 Mtetra
.45388 .41762 .45998 .42414 .47065 .42062 .46458 .41408 Mtetra
.46458 .41408 .47065 .42062 .48137 .41708 .47533 .41051 Mtetra
.47533 .41051 .48137 .41708 .49213 .41353 .48611 .40694 Mtetra
.48611 .40694 .49213 .41353 .50293 .40996 .49694 .40335 Mtetra
.49694 .40335 .50293 .40996 .51377 .40639 .50781 .39974 Mtetra
.50781 .39974 .51377 .40639 .52466 .40279 .51873 .39612 Mtetra
.51873 .39612 .52466 .40279 .53559 .39919 .52969 .39249 Mtetra
.52969 .39249 .53559 .39919 .54656 .39556 .54069 .38884 Mtetra
.54069 .38884 .54656 .39556 .55758 .39193 .55174 .38518 Mtetra
.55174 .38518 .55758 .39193 .56864 .38828 .56283 .3815 Mtetra
.56283 .3815 .56864 .38828 .57975 .38461 .57396 .37781 Mtetra
.57396 .37781 .57975 .38461 .5909 .38093 .58514 .3741 Mtetra
.58514 .3741 .5909 .38093 .6021 .37724 .59637 .37038 Mtetra
.59637 .37038 .6021 .37724 .61334 .37353 .60764 .36664 Mtetra
.60764 .36664 .61334 .37353 .62462 .3698 .61896 .36289 Mtetra
.61896 .36289 .62462 .3698 .63595 .36606 .63032 .35912 Mtetra
.63032 .35912 .63595 .36606 .64733 .36231 .64173 .35534 Mtetra
.64173 .35534 .64733 .36231 .65875 .35854 .65318 .35154 Mtetra
.65318 .35154 .65875 .35854 .67023 .35475 .66469 .34773 Mtetra
.66469 .34773 .67023 .35475 .68174 .35095 .67623 .3439 Mtetra
.67623 .3439 .68174 .35095 .69331 .34714 .68783 .34005 Mtetra
.68783 .34005 .69331 .34714 .70492 .34331 .69948 .33619 Mtetra
.69948 .33619 .70492 .34331 .71658 .33946 .71117 .33231 Mtetra
.71117 .33231 .71658 .33946 .72829 .33559 .72291 .32842 Mtetra
.72291 .32842 .72829 .33559 .74004 .33171 .7347 .32451 Mtetra
.7347 .32451 .74004 .33171 .75184 .32782 .74654 .32059 Mtetra
.74654 .32059 .75184 .32782 .7637 .32391 .75842 .31664 Mtetra
.75842 .31664 .7637 .32391 .7756 .31998 .77036 .31269 Mtetra
.77036 .31269 .7756 .31998 .78755 .31604 .78235 .30871 Mtetra
.78235 .30871 .78755 .31604 .79955 .31208 .79438 .30472 Mtetra
.79438 .30472 .79955 .31208 .8116 .3081 .80647 .30071 Mtetra
.80647 .30071 .8116 .3081 .82371 .3041 .81861 .29669 Mtetra
.17328 .5025 .18006 .50842 .18971 .50522 .18295 .49928 Mtetra
.18295 .49928 .18971 .50522 .19939 .50201 .19266 .49605 Mtetra
.19266 .49605 .19939 .50201 .20911 .49879 .2024 .4928 Mtetra
.2024 .4928 .20911 .49879 .21887 .49555 .21218 .48955 Mtetra
.21218 .48955 .21887 .49555 .22866 .4923 .22199 .48627 Mtetra
.22199 .48627 .22866 .4923 .23849 .48904 .23184 .48299 Mtetra
.23184 .48299 .23849 .48904 .24836 .48577 .24173 .4797 Mtetra
.24173 .4797 .24836 .48577 .25827 .48249 .25166 .47639 Mtetra
.25166 .47639 .25827 .48249 .26821 .47919 .26163 .47307 Mtetra
.26163 .47307 .26821 .47919 .27819 .47588 .27163 .46974 Mtetra
.27163 .46974 .27819 .47588 .28821 .47256 .28167 .46639 Mtetra
.28167 .46639 .28821 .47256 .29827 .46922 .29175 .46303 Mtetra
.29175 .46303 .29827 .46922 .30837 .46587 .30187 .45966 Mtetra
.30187 .45966 .30837 .46587 .3185 .46251 .31203 .45628 Mtetra
.31203 .45628 .3185 .46251 .32867 .45914 .32223 .45288 Mtetra
.32223 .45288 .32867 .45914 .33889 .45575 .33247 .44947 Mtetra
.33247 .44947 .33889 .45575 .34914 .45235 .34274 .44604 Mtetra
.34274 .44604 .34914 .45235 .35943 .44894 .35306 .44261 Mtetra
.35306 .44261 .35943 .44894 .36976 .44552 .36342 .43916 Mtetra
.36342 .43916 .36976 .44552 .38013 .44208 .37381 .43569 Mtetra
.37381 .43569 .38013 .44208 .39055 .43862 .38425 .43222 Mtetra
.38425 .43222 .39055 .43862 .401 .43516 .39473 .42872 Mtetra
.39473 .42872 .401 .43516 .41149 .43168 .40525 .42522 Mtetra
.40525 .42522 .41149 .43168 .42203 .42819 .41581 .4217 Mtetra
.41581 .4217 .42203 .42819 .4326 .42468 .42641 .41817 Mtetra
.42641 .41817 .4326 .42468 .44322 .42116 .43705 .41462 Mtetra
.43705 .41462 .44322 .42116 .45388 .41762 .44774 .41106 Mtetra
.44774 .41106 .45388 .41762 .46458 .41408 .45847 .40749 Mtetra
.45847 .40749 .46458 .41408 .47533 .41051 .46924 .4039 Mtetra
.46924 .4039 .47533 .41051 .48611 .40694 .48005 .4003 Mtetra
.48005 .4003 .48611 .40694 .49694 .40335 .49091 .39668 Mtetra
.49091 .39668 .49694 .40335 .50781 .39974 .50181 .39305 Mtetra
.50181 .39305 .50781 .39974 .51873 .39612 .51275 .3894 Mtetra
.51275 .3894 .51873 .39612 .52969 .39249 .52374 .38574 Mtetra
.52374 .38574 .52969 .39249 .54069 .38884 .53477 .38207 Mtetra
.53477 .38207 .54069 .38884 .55174 .38518 .54585 .37838 Mtetra
.54585 .37838 .55174 .38518 .56283 .3815 .55697 .37467 Mtetra
.55697 .37467 .56283 .3815 .57396 .37781 .56813 .37095 Mtetra
.56813 .37095 .57396 .37781 .58514 .3741 .57934 .36722 Mtetra
.57934 .36722 .58514 .3741 .59637 .37038 .5906 .36347 Mtetra
.5906 .36347 .59637 .37038 .60764 .36664 .6019 .3597 Mtetra
.6019 .3597 .60764 .36664 .61896 .36289 .61325 .35592 Mtetra
.61325 .35592 .61896 .36289 .63032 .35912 .62464 .35213 Mtetra
.62464 .35213 .63032 .35912 .64173 .35534 .63608 .34831 Mtetra
.63608 .34831 .64173 .35534 .65318 .35154 .64757 .34449 Mtetra
.64757 .34449 .65318 .35154 .66469 .34773 .6591 .34064 Mtetra
.6591 .34064 .66469 .34773 .67623 .3439 .67069 .33678 Mtetra
.67069 .33678 .67623 .3439 .68783 .34005 .68231 .33291 Mtetra
.68231 .33291 .68783 .34005 .69948 .33619 .69399 .32902 Mtetra
.69399 .32902 .69948 .33619 .71117 .33231 .70572 .32511 Mtetra
.70572 .32511 .71117 .33231 .72291 .32842 .71749 .32119 Mtetra
.71749 .32119 .72291 .32842 .7347 .32451 .72932 .31725 Mtetra
.72932 .31725 .7347 .32451 .74654 .32059 .74119 .3133 Mtetra
.74119 .3133 .74654 .32059 .75842 .31664 .75311 .30932 Mtetra
.75311 .30932 .75842 .31664 .77036 .31269 .76508 .30533 Mtetra
.76508 .30533 .77036 .31269 .78235 .30871 .7771 .30133 Mtetra
.7771 .30133 .78235 .30871 .79438 .30472 .78918 .29731 Mtetra
.78918 .29731 .79438 .30472 .80647 .30071 .8013 .29327 Mtetra
.8013 .29327 .80647 .30071 .81861 .29669 .81347 .28921 Mtetra
.16646 .49655 .17328 .5025 .18295 .49928 .17615 .4933 Mtetra
.17615 .4933 .18295 .49928 .19266 .49605 .18587 .49005 Mtetra
.18587 .49005 .19266 .49605 .2024 .4928 .19564 .48678 Mtetra
.19564 .48678 .2024 .4928 .21218 .48955 .20544 .4835 Mtetra
.20544 .4835 .21218 .48955 .22199 .48627 .21527 .4802 Mtetra
.21527 .4802 .22199 .48627 .23184 .48299 .22515 .4769 Mtetra
.22515 .4769 .23184 .48299 .24173 .4797 .23506 .47358 Mtetra
.23506 .47358 .24173 .4797 .25166 .47639 .24501 .47025 Mtetra
.24501 .47025 .25166 .47639 .26163 .47307 .255 .46691 Mtetra
.255 .46691 .26163 .47307 .27163 .46974 .26502 .46355 Mtetra
.26502 .46355 .27163 .46974 .28167 .46639 .27509 .46018 Mtetra
.27509 .46018 .28167 .46639 .29175 .46303 .28519 .4568 Mtetra
.28519 .4568 .29175 .46303 .30187 .45966 .29534 .4534 Mtetra
.29534 .4534 .30187 .45966 .31203 .45628 .30552 .44999 Mtetra
.30552 .44999 .31203 .45628 .32223 .45288 .31574 .44657 Mtetra
.31574 .44657 .32223 .45288 .33247 .44947 .326 .44314 Mtetra
.326 .44314 .33247 .44947 .34274 .44604 .3363 .43969 Mtetra
.3363 .43969 .34274 .44604 .35306 .44261 .34664 .43623 Mtetra
.34664 .43623 .35306 .44261 .36342 .43916 .35702 .43275 Mtetra
.35702 .43275 .36342 .43916 .37381 .43569 .36744 .42926 Mtetra
.36744 .42926 .37381 .43569 .38425 .43222 .37791 .42576 Mtetra
.37791 .42576 .38425 .43222 .39473 .42872 .38841 .42224 Mtetra
.38841 .42224 .39473 .42872 .40525 .42522 .39896 .41871 Mtetra
.39896 .41871 .40525 .42522 .41581 .4217 .40954 .41517 Mtetra
.40954 .41517 .41581 .4217 .42641 .41817 .42017 .41161 Mtetra
.42017 .41161 .42641 .41817 .43705 .41462 .43084 .40804 Mtetra
.43084 .40804 .43705 .41462 .44774 .41106 .44155 .40445 Mtetra
.44155 .40445 .44774 .41106 .45847 .40749 .45231 .40085 Mtetra
.45231 .40085 .45847 .40749 .46924 .4039 .46311 .39724 Mtetra
.46311 .39724 .46924 .4039 .48005 .4003 .47395 .39361 Mtetra
.47395 .39361 .48005 .4003 .49091 .39668 .48483 .38996 Mtetra
.48483 .38996 .49091 .39668 .50181 .39305 .49576 .38631 Mtetra
.49576 .38631 .50181 .39305 .51275 .3894 .50673 .38263 Mtetra
.50673 .38263 .51275 .3894 .52374 .38574 .51775 .37895 Mtetra
.51775 .37895 .52374 .38574 .53477 .38207 .52881 .37524 Mtetra
.52881 .37524 .53477 .38207 .54585 .37838 .53991 .37153 Mtetra
.53991 .37153 .54585 .37838 .55697 .37467 .55106 .36779 Mtetra
.55106 .36779 .55697 .37467 .56813 .37095 .56226 .36404 Mtetra
.56226 .36404 .56813 .37095 .57934 .36722 .5735 .36028 Mtetra
.5735 .36028 .57934 .36722 .5906 .36347 .58479 .3565 Mtetra
.58479 .3565 .5906 .36347 .6019 .3597 .59612 .35271 Mtetra
.59612 .35271 .6019 .3597 .61325 .35592 .6075 .3489 Mtetra
.6075 .3489 .61325 .35592 .62464 .35213 .61892 .34508 Mtetra
.61892 .34508 .62464 .35213 .63608 .34831 .63039 .34124 Mtetra
.63039 .34124 .63608 .34831 .64757 .34449 .64191 .33738 Mtetra
.64191 .33738 .64757 .34449 .6591 .34064 .65348 .33351 Mtetra
.65348 .33351 .6591 .34064 .67069 .33678 .66509 .32962 Mtetra
.66509 .32962 .67069 .33678 .68231 .33291 .67676 .32572 Mtetra
.67676 .32572 .68231 .33291 .69399 .32902 .68847 .32179 Mtetra
.68847 .32179 .69399 .32902 .70572 .32511 .70023 .31786 Mtetra
.70023 .31786 .70572 .32511 .71749 .32119 .71203 .31391 Mtetra
.71203 .31391 .71749 .32119 .72932 .31725 .72389 .30994 Mtetra
.72389 .30994 .72932 .31725 .74119 .3133 .7358 .30595 Mtetra
.7358 .30595 .74119 .3133 .75311 .30932 .74775 .30195 Mtetra
.74775 .30195 .75311 .30932 .76508 .30533 .75976 .29793 Mtetra
.75976 .29793 .76508 .30533 .7771 .30133 .77182 .29389 Mtetra
.77182 .29389 .7771 .30133 .78918 .29731 .78393 .28984 Mtetra
.78393 .28984 .78918 .29731 .8013 .29327 .79609 .28577 Mtetra
.79609 .28577 .8013 .29327 .81347 .28921 .8083 .28168 Mtetra
.15958 .49055 .16646 .49655 .17615 .4933 .16929 .48728 Mtetra
.16929 .48728 .17615 .4933 .18587 .49005 .17904 .484 Mtetra
.17904 .484 .18587 .49005 .19564 .48678 .18883 .48071 Mtetra
.18883 .48071 .19564 .48678 .20544 .4835 .19865 .47741 Mtetra
.19865 .47741 .20544 .4835 .21527 .4802 .20851 .47409 Mtetra
.20851 .47409 .21527 .4802 .22515 .4769 .2184 .47076 Mtetra
.2184 .47076 .22515 .4769 .23506 .47358 .22834 .46742 Mtetra
.22834 .46742 .23506 .47358 .24501 .47025 .23831 .46407 Mtetra
.23831 .46407 .24501 .47025 .255 .46691 .24832 .4607 Mtetra
.24832 .4607 .255 .46691 .26502 .46355 .25837 .45732 Mtetra
.25837 .45732 .26502 .46355 .27509 .46018 .26846 .45393 Mtetra
.26846 .45393 .27509 .46018 .28519 .4568 .27858 .45052 Mtetra
.27858 .45052 .28519 .4568 .29534 .4534 .28875 .4471 Mtetra
.28875 .4471 .29534 .4534 .30552 .44999 .29896 .44367 Mtetra
.29896 .44367 .30552 .44999 .31574 .44657 .3092 .44022 Mtetra
.3092 .44022 .31574 .44657 .326 .44314 .31949 .43676 Mtetra
.31949 .43676 .326 .44314 .3363 .43969 .32981 .43329 Mtetra
.32981 .43329 .3363 .43969 .34664 .43623 .34018 .4298 Mtetra
.34018 .4298 .34664 .43623 .35702 .43275 .35058 .4263 Mtetra
.35058 .4263 .35702 .43275 .36744 .42926 .36103 .42279 Mtetra
.36103 .42279 .36744 .42926 .37791 .42576 .37152 .41926 Mtetra
.37152 .41926 .37791 .42576 .38841 .42224 .38205 .41572 Mtetra
.38205 .41572 .38841 .42224 .39896 .41871 .39262 .41216 Mtetra
.39262 .41216 .39896 .41871 .40954 .41517 .40323 .40859 Mtetra
.40323 .40859 .40954 .41517 .42017 .41161 .41389 .40501 Mtetra
.41389 .40501 .42017 .41161 .43084 .40804 .42458 .40141 Mtetra
.42458 .40141 .43084 .40804 .44155 .40445 .43532 .39779 Mtetra
.43532 .39779 .44155 .40445 .45231 .40085 .44611 .39417 Mtetra
.44611 .39417 .45231 .40085 .46311 .39724 .45693 .39053 Mtetra
.45693 .39053 .46311 .39724 .47395 .39361 .4678 .38687 Mtetra
.4678 .38687 .47395 .39361 .48483 .38996 .47871 .3832 Mtetra
.47871 .3832 .48483 .38996 .49576 .38631 .48967 .37951 Mtetra
.48967 .37951 .49576 .38631 .50673 .38263 .50067 .37581 Mtetra
.50067 .37581 .50673 .38263 .51775 .37895 .51171 .3721 Mtetra
.51171 .3721 .51775 .37895 .52881 .37524 .5228 .36837 Mtetra
.5228 .36837 .52881 .37524 .53991 .37153 .53394 .36462 Mtetra
.53394 .36462 .53991 .37153 .55106 .36779 .54512 .36086 Mtetra
.54512 .36086 .55106 .36779 .56226 .36404 .55634 .35709 Mtetra
.55634 .35709 .56226 .36404 .5735 .36028 .56761 .35329 Mtetra
.56761 .35329 .5735 .36028 .58479 .3565 .57893 .34949 Mtetra
.57893 .34949 .58479 .3565 .59612 .35271 .59029 .34567 Mtetra
.59029 .34567 .59612 .35271 .6075 .3489 .6017 .34183 Mtetra
.6017 .34183 .6075 .3489 .61892 .34508 .61316 .33797 Mtetra
.61316 .33797 .61892 .34508 .63039 .34124 .62466 .3341 Mtetra
.62466 .3341 .63039 .34124 .64191 .33738 .63621 .33022 Mtetra
.63621 .33022 .64191 .33738 .65348 .33351 .64781 .32632 Mtetra
.64781 .32632 .65348 .33351 .66509 .32962 .65946 .3224 Mtetra
.65946 .3224 .66509 .32962 .67676 .32572 .67115 .31846 Mtetra
.67115 .31846 .67676 .32572 .68847 .32179 .6829 .31451 Mtetra
.6829 .31451 .68847 .32179 .70023 .31786 .69469 .31055 Mtetra
.69469 .31055 .70023 .31786 .71203 .31391 .70653 .30656 Mtetra
.70653 .30656 .71203 .31391 .72389 .30994 .71842 .30256 Mtetra
.71842 .30256 .72389 .30994 .7358 .30595 .73037 .29855 Mtetra
.73037 .29855 .7358 .30595 .74775 .30195 .74236 .29451 Mtetra
.74236 .29451 .74775 .30195 .75976 .29793 .7544 .29046 Mtetra
.7544 .29046 .75976 .29793 .77182 .29389 .76649 .28639 Mtetra
.76649 .28639 .77182 .29389 .78393 .28984 .77864 .28231 Mtetra
.77864 .28231 .78393 .28984 .79609 .28577 .79083 .27821 Mtetra
.79083 .27821 .79609 .28577 .8083 .28168 .80308 .27409 Mtetra
.15266 .48451 .15958 .49055 .16929 .48728 .16239 .48122 Mtetra
.16239 .48122 .16929 .48728 .17904 .484 .17216 .47792 Mtetra
.17216 .47792 .17904 .484 .18883 .48071 .18197 .4746 Mtetra
.18197 .4746 .18883 .48071 .19865 .47741 .19181 .47128 Mtetra
.19181 .47128 .19865 .47741 .20851 .47409 .20169 .46794 Mtetra
.20169 .46794 .20851 .47409 .2184 .47076 .21161 .46458 Mtetra
.21161 .46458 .2184 .47076 .22834 .46742 .22157 .46122 Mtetra
.22157 .46122 .22834 .46742 .23831 .46407 .23156 .45784 Mtetra
.23156 .45784 .23831 .46407 .24832 .4607 .2416 .45445 Mtetra
.2416 .45445 .24832 .4607 .25837 .45732 .25167 .45104 Mtetra
.25167 .45104 .25837 .45732 .26846 .45393 .26178 .44763 Mtetra
.26178 .44763 .26846 .45393 .27858 .45052 .27193 .4442 Mtetra
.27193 .4442 .27858 .45052 .28875 .4471 .28212 .44075 Mtetra
.28212 .44075 .28875 .4471 .29896 .44367 .29235 .43729 Mtetra
.29235 .43729 .29896 .44367 .3092 .44022 .30262 .43382 Mtetra
.30262 .43382 .3092 .44022 .31949 .43676 .31293 .43034 Mtetra
.31293 .43034 .31949 .43676 .32981 .43329 .32328 .42684 Mtetra
.32328 .42684 .32981 .43329 .34018 .4298 .33367 .42333 Mtetra
.33367 .42333 .34018 .4298 .35058 .4263 .3441 .4198 Mtetra
.3441 .4198 .35058 .4263 .36103 .42279 .35457 .41626 Mtetra
.35457 .41626 .36103 .42279 .37152 .41926 .36508 .41271 Mtetra
.36508 .41271 .37152 .41926 .38205 .41572 .37564 .40914 Mtetra
.37564 .40914 .38205 .41572 .39262 .41216 .38623 .40556 Mtetra
.38623 .40556 .39262 .41216 .40323 .40859 .39687 .40196 Mtetra
.39687 .40196 .40323 .40859 .41389 .40501 .40756 .39835 Mtetra
.40756 .39835 .41389 .40501 .42458 .40141 .41828 .39473 Mtetra
.41828 .39473 .42458 .40141 .43532 .39779 .42905 .39109 Mtetra
.42905 .39109 .43532 .39779 .44611 .39417 .43986 .38743 Mtetra
.43986 .38743 .44611 .39417 .45693 .39053 .45071 .38376 Mtetra
.45071 .38376 .45693 .39053 .4678 .38687 .4616 .38008 Mtetra
.4616 .38008 .4678 .38687 .47871 .3832 .47255 .37638 Mtetra
.47255 .37638 .47871 .3832 .48967 .37951 .48353 .37267 Mtetra
.48353 .37267 .48967 .37951 .50067 .37581 .49456 .36894 Mtetra
.49456 .36894 .50067 .37581 .51171 .3721 .50563 .3652 Mtetra
.50563 .3652 .51171 .3721 .5228 .36837 .51675 .36144 Mtetra
.51675 .36144 .5228 .36837 .53394 .36462 .52791 .35767 Mtetra
.52791 .35767 .53394 .36462 .54512 .36086 .53912 .35388 Mtetra
.53912 .35388 .54512 .36086 .55634 .35709 .55038 .35007 Mtetra
.55038 .35007 .55634 .35709 .56761 .35329 .56168 .34625 Mtetra
.56168 .34625 .56761 .35329 .57893 .34949 .57303 .34242 Mtetra
.57303 .34242 .57893 .34949 .59029 .34567 .58442 .33857 Mtetra
.58442 .33857 .59029 .34567 .6017 .34183 .59586 .3347 Mtetra
.59586 .3347 .6017 .34183 .61316 .33797 .60735 .33082 Mtetra
.60735 .33082 .61316 .33797 .62466 .3341 .61889 .32692 Mtetra
.61889 .32692 .62466 .3341 .63621 .33022 .63047 .323 Mtetra
.63047 .323 .63621 .33022 .64781 .32632 .6421 .31907 Mtetra
.6421 .31907 .64781 .32632 .65946 .3224 .65378 .31512 Mtetra
.65378 .31512 .65946 .3224 .67115 .31846 .66551 .31116 Mtetra
.66551 .31116 .67115 .31846 .6829 .31451 .67729 .30718 Mtetra
.67729 .30718 .6829 .31451 .69469 .31055 .68911 .30318 Mtetra
.68911 .30318 .69469 .31055 .70653 .30656 .70099 .29917 Mtetra
.70099 .29917 .70653 .30656 .71842 .30256 .71292 .29513 Mtetra
.71292 .29513 .71842 .30256 .73037 .29855 .72489 .29109 Mtetra
.72489 .29109 .73037 .29855 .74236 .29451 .73692 .28702 Mtetra
.73692 .28702 .74236 .29451 .7544 .29046 .749 .28294 Mtetra
.749 .28294 .7544 .29046 .76649 .28639 .76113 .27884 Mtetra
.76113 .27884 .76649 .28639 .77864 .28231 .77331 .27472 Mtetra
.77331 .27472 .77864 .28231 .79083 .27821 .78554 .27059 Mtetra
.78554 .27059 .79083 .27821 .80308 .27409 .79782 .26643 Mtetra
.14569 .47843 .15266 .48451 .16239 .48122 .15545 .47511 Mtetra
.15545 .47511 .16239 .48122 .17216 .47792 .16524 .47179 Mtetra
.16524 .47179 .17216 .47792 .18197 .4746 .17506 .46845 Mtetra
.17506 .46845 .18197 .4746 .19181 .47128 .18493 .4651 Mtetra
.18493 .4651 .19181 .47128 .20169 .46794 .19483 .46173 Mtetra
.19483 .46173 .20169 .46794 .21161 .46458 .20477 .45836 Mtetra
.20477 .45836 .21161 .46458 .22157 .46122 .21475 .45497 Mtetra
.21475 .45497 .22157 .46122 .23156 .45784 .22477 .45156 Mtetra
.22477 .45156 .23156 .45784 .2416 .45445 .23482 .44815 Mtetra
.23482 .44815 .2416 .45445 .25167 .45104 .24492 .44472 Mtetra
.24492 .44472 .25167 .45104 .26178 .44763 .25505 .44128 Mtetra
.25505 .44128 .26178 .44763 .27193 .4442 .26523 .43782 Mtetra
.26523 .43782 .27193 .4442 .28212 .44075 .27544 .43435 Mtetra
.27544 .43435 .28212 .44075 .29235 .43729 .28569 .43087 Mtetra
.28569 .43087 .29235 .43729 .30262 .43382 .29599 .42737 Mtetra
.29599 .42737 .30262 .43382 .31293 .43034 .30632 .42386 Mtetra
.30632 .42386 .31293 .43034 .32328 .42684 .31669 .42034 Mtetra
.31669 .42034 .32328 .42684 .33367 .42333 .32711 .4168 Mtetra
.32711 .4168 .33367 .42333 .3441 .4198 .33756 .41325 Mtetra
.33756 .41325 .3441 .4198 .35457 .41626 .34806 .40969 Mtetra
.34806 .40969 .35457 .41626 .36508 .41271 .3586 .40611 Mtetra
.3586 .40611 .36508 .41271 .37564 .40914 .36918 .40251 Mtetra
.36918 .40251 .37564 .40914 .38623 .40556 .3798 .39891 Mtetra
.3798 .39891 .38623 .40556 .39687 .40196 .39047 .39528 Mtetra
.39047 .39528 .39687 .40196 .40756 .39835 .40118 .39165 Mtetra
.40118 .39165 .40756 .39835 .41828 .39473 .41193 .38799 Mtetra
.41193 .38799 .41828 .39473 .42905 .39109 .42272 .38433 Mtetra
.42272 .38433 .42905 .39109 .43986 .38743 .43356 .38065 Mtetra
.43356 .38065 .43986 .38743 .45071 .38376 .44444 .37695 Mtetra
.44444 .37695 .45071 .38376 .4616 .38008 .45536 .37324 Mtetra
.45536 .37324 .4616 .38008 .47255 .37638 .46633 .36951 Mtetra
.46633 .36951 .47255 .37638 .48353 .37267 .47735 .36577 Mtetra
.47735 .36577 .48353 .37267 .49456 .36894 .4884 .36202 Mtetra
.4884 .36202 .49456 .36894 .50563 .3652 .49951 .35825 Mtetra
.49951 .35825 .50563 .3652 .51675 .36144 .51065 .35446 Mtetra
.51065 .35446 .51675 .36144 .52791 .35767 .52185 .35066 Mtetra
.52185 .35066 .52791 .35767 .53912 .35388 .53309 .34684 Mtetra
.53309 .34684 .53912 .35388 .55038 .35007 .54437 .34301 Mtetra
.54437 .34301 .55038 .35007 .56168 .34625 .5557 .33916 Mtetra
.5557 .33916 .56168 .34625 .57303 .34242 .56708 .33529 Mtetra
.56708 .33529 .57303 .34242 .58442 .33857 .57851 .33141 Mtetra
.57851 .33141 .58442 .33857 .59586 .3347 .58998 .32752 Mtetra
.58998 .32752 .59586 .3347 .60735 .33082 .6015 .3236 Mtetra
.6015 .3236 .60735 .33082 .61889 .32692 .61307 .31967 Mtetra
.61307 .31967 .61889 .32692 .63047 .323 .62468 .31573 Mtetra
.62468 .31573 .63047 .323 .6421 .31907 .63635 .31177 Mtetra
.63635 .31177 .6421 .31907 .65378 .31512 .64806 .30779 Mtetra
.64806 .30779 .65378 .31512 .66551 .31116 .65982 .30379 Mtetra
.65982 .30379 .66551 .31116 .67729 .30718 .67163 .29978 Mtetra
.67163 .29978 .67729 .30718 .68911 .30318 .68349 .29575 Mtetra
.68349 .29575 .68911 .30318 .70099 .29917 .6954 .29171 Mtetra
.6954 .29171 .70099 .29917 .71292 .29513 .70736 .28764 Mtetra
.70736 .28764 .71292 .29513 .72489 .29109 .71938 .28356 Mtetra
.71938 .28356 .72489 .29109 .73692 .28702 .73144 .27947 Mtetra
.73144 .27947 .73692 .28702 .749 .28294 .74355 .27535 Mtetra
.74355 .27535 .749 .28294 .76113 .27884 .75572 .27122 Mtetra
.75572 .27122 .76113 .27884 .77331 .27472 .76793 .26707 Mtetra
.76793 .26707 .77331 .27472 .78554 .27059 .7802 .26291 Mtetra
.7802 .26291 .78554 .27059 .79782 .26643 .79252 .25872 Mtetra
.13868 .4723 .14569 .47843 .15545 .47511 .14845 .46897 Mtetra
.14845 .46897 .15545 .47511 .16524 .47179 .15826 .46562 Mtetra
.15826 .46562 .16524 .47179 .17506 .46845 .16811 .46226 Mtetra
.656 .752 .92 r
.16811 .46226 .17506 .46845 .18493 .4651 .17799 .45888 Mtetra
.17799 .45888 .18493 .4651 .19483 .46173 .18792 .4555 Mtetra
.18792 .4555 .19483 .46173 .20477 .45836 .19788 .45209 Mtetra
.19788 .45209 .20477 .45836 .21475 .45497 .20788 .44868 Mtetra
.20788 .44868 .21475 .45497 .22477 .45156 .21792 .44525 Mtetra
.21792 .44525 .22477 .45156 .23482 .44815 .228 .44181 Mtetra
.228 .44181 .23482 .44815 .24492 .44472 .23812 .43836 Mtetra
.23812 .43836 .24492 .44472 .25505 .44128 .24828 .43489 Mtetra
.24828 .43489 .25505 .44128 .26523 .43782 .25847 .43141 Mtetra
.25847 .43141 .26523 .43782 .27544 .43435 .26871 .42792 Mtetra
.26871 .42792 .27544 .43435 .28569 .43087 .27899 .42441 Mtetra
.27899 .42441 .28569 .43087 .29599 .42737 .2893 .42089 Mtetra
.2893 .42089 .29599 .42737 .30632 .42386 .29966 .41735 Mtetra
.656 .751 .92 r
.29966 .41735 .30632 .42386 .31669 .42034 .31006 .4138 Mtetra
.31006 .4138 .31669 .42034 .32711 .4168 .3205 .41024 Mtetra
.3205 .41024 .32711 .4168 .33756 .41325 .33098 .40666 Mtetra
.33098 .40666 .33756 .41325 .34806 .40969 .34151 .40307 Mtetra
.34151 .40307 .34806 .40969 .3586 .40611 .35207 .39946 Mtetra
.35207 .39946 .3586 .40611 .36918 .40251 .36268 .39584 Mtetra
.36268 .39584 .36918 .40251 .3798 .39891 .37333 .39221 Mtetra
.37333 .39221 .3798 .39891 .39047 .39528 .38402 .38856 Mtetra
.38402 .38856 .39047 .39528 .40118 .39165 .39475 .38489 Mtetra
.39475 .38489 .40118 .39165 .41193 .38799 .40553 .38122 Mtetra
.40553 .38122 .41193 .38799 .42272 .38433 .41635 .37752 Mtetra
.41635 .37752 .42272 .38433 .43356 .38065 .42722 .37381 Mtetra
.42722 .37381 .43356 .38065 .44444 .37695 .43812 .37009 Mtetra
.43812 .37009 .44444 .37695 .45536 .37324 .44908 .36635 Mtetra
.44908 .36635 .45536 .37324 .46633 .36951 .46007 .3626 Mtetra
.46007 .3626 .46633 .36951 .47735 .36577 .47112 .35883 Mtetra
.47112 .35883 .47735 .36577 .4884 .36202 .4822 .35505 Mtetra
.4822 .35505 .4884 .36202 .49951 .35825 .49333 .35125 Mtetra
.49333 .35125 .49951 .35825 .51065 .35446 .50451 .34743 Mtetra
.50451 .34743 .51065 .35446 .52185 .35066 .51573 .3436 Mtetra
.51573 .3436 .52185 .35066 .53309 .34684 .527 .33975 Mtetra
.527 .33975 .53309 .34684 .54437 .34301 .53832 .33589 Mtetra
.53832 .33589 .54437 .34301 .5557 .33916 .54968 .33201 Mtetra
.54968 .33201 .5557 .33916 .56708 .33529 .56109 .32812 Mtetra
.56109 .32812 .56708 .33529 .57851 .33141 .57255 .32421 Mtetra
.57255 .32421 .57851 .33141 .58998 .32752 .58405 .32028 Mtetra
.58405 .32028 .58998 .32752 .6015 .3236 .5956 .31634 Mtetra
.5956 .31634 .6015 .3236 .61307 .31967 .6072 .31238 Mtetra
.656 .752 .92 r
.6072 .31238 .61307 .31967 .62468 .31573 .61885 .3084 Mtetra
.61885 .3084 .62468 .31573 .63635 .31177 .63055 .30441 Mtetra
.63055 .30441 .63635 .31177 .64806 .30779 .64229 .3004 Mtetra
.64229 .3004 .64806 .30779 .65982 .30379 .65409 .29638 Mtetra
.65409 .29638 .65982 .30379 .67163 .29978 .66593 .29233 Mtetra
.66593 .29233 .67163 .29978 .68349 .29575 .67783 .28827 Mtetra
.67783 .28827 .68349 .29575 .6954 .29171 .68977 .2842 Mtetra
.68977 .2842 .6954 .29171 .70736 .28764 .70177 .2801 Mtetra
.70177 .2801 .70736 .28764 .71938 .28356 .71382 .27599 Mtetra
.71382 .27599 .71938 .28356 .73144 .27947 .72591 .27186 Mtetra
.72591 .27186 .73144 .27947 .74355 .27535 .73806 .26772 Mtetra
.73806 .26772 .74355 .27535 .75572 .27122 .75026 .26355 Mtetra
.75026 .26355 .75572 .27122 .76793 .26707 .76252 .25937 Mtetra
.76252 .25937 .76793 .26707 .7802 .26291 .77482 .25517 Mtetra
.656 .751 .92 r
.77482 .25517 .7802 .26291 .79252 .25872 .78718 .25095 Mtetra
.13161 .46613 .13868 .4723 .14845 .46897 .1414 .46277 Mtetra
.1414 .46277 .14845 .46897 .15826 .46562 .15123 .4594 Mtetra
.15123 .4594 .15826 .46562 .16811 .46226 .1611 .45601 Mtetra
.1611 .45601 .16811 .46226 .17799 .45888 .17101 .45261 Mtetra
.17101 .45261 .17799 .45888 .18792 .4555 .18096 .4492 Mtetra
.18096 .4492 .18792 .4555 .19788 .45209 .19094 .44577 Mtetra
.19094 .44577 .19788 .45209 .20788 .44868 .20097 .44233 Mtetra
.20097 .44233 .20788 .44868 .21792 .44525 .21103 .43888 Mtetra
.21103 .43888 .21792 .44525 .228 .44181 .22113 .43541 Mtetra
.22113 .43541 .228 .44181 .23812 .43836 .23127 .43193 Mtetra
.23127 .43193 .23812 .43836 .24828 .43489 .24145 .42843 Mtetra
.24145 .42843 .24828 .43489 .25847 .43141 .25167 .42493 Mtetra
.25167 .42493 .25847 .43141 .26871 .42792 .26194 .42141 Mtetra
.26194 .42141 .26871 .42792 .27899 .42441 .27224 .41787 Mtetra
.27224 .41787 .27899 .42441 .2893 .42089 .28258 .41432 Mtetra
.28258 .41432 .2893 .42089 .29966 .41735 .29296 .41076 Mtetra
.29296 .41076 .29966 .41735 .31006 .4138 .30338 .40718 Mtetra
.656 .75 .92 r
.30338 .40718 .31006 .4138 .3205 .41024 .31385 .4036 Mtetra
.31385 .4036 .3205 .41024 .33098 .40666 .32436 .39999 Mtetra
.32436 .39999 .33098 .40666 .34151 .40307 .3349 .39637 Mtetra
.3349 .39637 .34151 .40307 .35207 .39946 .34549 .39274 Mtetra
.34549 .39274 .35207 .39946 .36268 .39584 .35613 .38909 Mtetra
.35613 .38909 .36268 .39584 .37333 .39221 .3668 .38543 Mtetra
.3668 .38543 .37333 .39221 .38402 .38856 .37752 .38176 Mtetra
.656 .751 .92 r
.37752 .38176 .38402 .38856 .39475 .38489 .38828 .37806 Mtetra
.38828 .37806 .39475 .38489 .40553 .38122 .39909 .37436 Mtetra
.39909 .37436 .40553 .38122 .41635 .37752 .40993 .37064 Mtetra
.40993 .37064 .41635 .37752 .42722 .37381 .42083 .3669 Mtetra
.42083 .3669 .42722 .37381 .43812 .37009 .43176 .36315 Mtetra
.43176 .36315 .43812 .37009 .44908 .36635 .44274 .35938 Mtetra
.44274 .35938 .44908 .36635 .46007 .3626 .45377 .3556 Mtetra
.45377 .3556 .46007 .3626 .47112 .35883 .46484 .3518 Mtetra
.46484 .3518 .47112 .35883 .4822 .35505 .47595 .34799 Mtetra
.47595 .34799 .4822 .35505 .49333 .35125 .48711 .34416 Mtetra
.48711 .34416 .49333 .35125 .50451 .34743 .49832 .34032 Mtetra
.49832 .34032 .50451 .34743 .51573 .3436 .50957 .33646 Mtetra
.50957 .33646 .51573 .3436 .527 .33975 .52087 .33258 Mtetra
.656 .75 .92 r
.52087 .33258 .527 .33975 .53832 .33589 .53222 .32869 Mtetra
.53222 .32869 .53832 .33589 .54968 .33201 .54361 .32478 Mtetra
.54361 .32478 .54968 .33201 .56109 .32812 .55505 .32086 Mtetra
.55505 .32086 .56109 .32812 .57255 .32421 .56654 .31692 Mtetra
.56654 .31692 .57255 .32421 .58405 .32028 .57808 .31296 Mtetra
.57808 .31296 .58405 .32028 .5956 .31634 .58966 .30899 Mtetra
.58966 .30899 .5956 .31634 .6072 .31238 .60129 .305 Mtetra
.656 .751 .92 r
.60129 .305 .6072 .31238 .61885 .3084 .61297 .30099 Mtetra
.61297 .30099 .61885 .3084 .63055 .30441 .6247 .29697 Mtetra
.6247 .29697 .63055 .30441 .64229 .3004 .63648 .29293 Mtetra
.63648 .29293 .64229 .3004 .65409 .29638 .64831 .28888 Mtetra
.64831 .28888 .65409 .29638 .66593 .29233 .66019 .2848 Mtetra
.66019 .2848 .66593 .29233 .67783 .28827 .67212 .28071 Mtetra
.67212 .28071 .67783 .28827 .68977 .2842 .6841 .27661 Mtetra
.6841 .27661 .68977 .2842 .70177 .2801 .69613 .27248 Mtetra
.69613 .27248 .70177 .2801 .71382 .27599 .70821 .26834 Mtetra
.70821 .26834 .71382 .27599 .72591 .27186 .72034 .26418 Mtetra
.72034 .26418 .72591 .27186 .73806 .26772 .73253 .26001 Mtetra
.73253 .26001 .73806 .26772 .75026 .26355 .74477 .25581 Mtetra
.74477 .25581 .75026 .26355 .76252 .25937 .75706 .2516 Mtetra
.75706 .2516 .76252 .25937 .77482 .25517 .7694 .24737 Mtetra
.7694 .24737 .77482 .25517 .78718 .25095 .7818 .24311 Mtetra
.655 .751 .921 r
.12449 .45992 .13161 .46613 .1414 .46277 .1343 .45656 Mtetra
.655 .752 .921 r
.1343 .45656 .1414 .46277 .15123 .4594 .14415 .45318 Mtetra
.655 .753 .922 r
.14415 .45318 .15123 .4594 .1611 .45601 .15404 .44979 Mtetra
.15404 .44979 .1611 .45601 .17101 .45261 .16397 .44637 Mtetra
.656 .754 .922 r
.16397 .44637 .17101 .45261 .18096 .4492 .17394 .44294 Mtetra
.17394 .44294 .18096 .4492 .19094 .44577 .18395 .4395 Mtetra
.18395 .4395 .19094 .44577 .20097 .44233 .19399 .43604 Mtetra
.19399 .43604 .20097 .44233 .21103 .43888 .20408 .43256 Mtetra
.20408 .43256 .21103 .43888 .22113 .43541 .2142 .42906 Mtetra
.2142 .42906 .22113 .43541 .23127 .43193 .22437 .42556 Mtetra
.22437 .42556 .23127 .43193 .24145 .42843 .23457 .42204 Mtetra
.23457 .42204 .24145 .42843 .25167 .42493 .24482 .4185 Mtetra
.24482 .4185 .25167 .42493 .26194 .42141 .2551 .41495 Mtetra
.2551 .41495 .26194 .42141 .27224 .41787 .26543 .41139 Mtetra
.26543 .41139 .27224 .41787 .28258 .41432 .27579 .40781 Mtetra
.27579 .40781 .28258 .41432 .29296 .41076 .2862 .40422 Mtetra
.2862 .40422 .29296 .41076 .30338 .40718 .29665 .40061 Mtetra
.29665 .40061 .30338 .40718 .31385 .4036 .30714 .397 Mtetra
.30714 .397 .31385 .4036 .32436 .39999 .31767 .39336 Mtetra
.656 .753 .922 r
.31767 .39336 .32436 .39999 .3349 .39637 .32825 .38972 Mtetra
.32825 .38972 .3349 .39637 .34549 .39274 .33886 .38605 Mtetra
.33886 .38605 .34549 .39274 .35613 .38909 .34952 .38238 Mtetra
.34952 .38238 .35613 .38909 .3668 .38543 .36023 .37869 Mtetra
.36023 .37869 .3668 .38543 .37752 .38176 .37097 .37498 Mtetra
.656 .753 .921 r
.37097 .37498 .37752 .38176 .38828 .37806 .38176 .37126 Mtetra
.38176 .37126 .38828 .37806 .39909 .37436 .39259 .36753 Mtetra
.39259 .36753 .39909 .37436 .40993 .37064 .40347 .36378 Mtetra
.40347 .36378 .40993 .37064 .42083 .3669 .41439 .36001 Mtetra
.41439 .36001 .42083 .3669 .43176 .36315 .42535 .35623 Mtetra
.42535 .35623 .43176 .36315 .44274 .35938 .43636 .35244 Mtetra
.43636 .35244 .44274 .35938 .45377 .3556 .44741 .34863 Mtetra
.44741 .34863 .45377 .3556 .46484 .3518 .45851 .3448 Mtetra
.45851 .3448 .46484 .3518 .47595 .34799 .46966 .34096 Mtetra
.46966 .34096 .47595 .34799 .48711 .34416 .48085 .33711 Mtetra
.48085 .33711 .48711 .34416 .49832 .34032 .49208 .33323 Mtetra
.656 .753 .922 r
.49208 .33323 .49832 .34032 .50957 .33646 .50337 .32935 Mtetra
.50337 .32935 .50957 .33646 .52087 .33258 .5147 .32544 Mtetra
.5147 .32544 .52087 .33258 .53222 .32869 .52607 .32152 Mtetra
.52607 .32152 .53222 .32869 .54361 .32478 .5375 .31759 Mtetra
.5375 .31759 .54361 .32478 .55505 .32086 .54897 .31363 Mtetra
.54897 .31363 .55505 .32086 .56654 .31692 .56049 .30967 Mtetra
.56049 .30967 .56654 .31692 .57808 .31296 .57206 .30568 Mtetra
.656 .754 .922 r
.57206 .30568 .57808 .31296 .58966 .30899 .58367 .30168 Mtetra
.58367 .30168 .58966 .30899 .60129 .305 .59534 .29767 Mtetra
.59534 .29767 .60129 .305 .61297 .30099 .60705 .29363 Mtetra
.60705 .29363 .61297 .30099 .6247 .29697 .61882 .28958 Mtetra
.61882 .28958 .6247 .29697 .63648 .29293 .63063 .28551 Mtetra
.63063 .28551 .63648 .29293 .64831 .28888 .64249 .28143 Mtetra
.64249 .28143 .64831 .28888 .66019 .2848 .6544 .27733 Mtetra
.6544 .27733 .66019 .2848 .67212 .28071 .66637 .27321 Mtetra
.66637 .27321 .67212 .28071 .6841 .27661 .67838 .26907 Mtetra
.67838 .26907 .6841 .27661 .69613 .27248 .69045 .26491 Mtetra
.69045 .26491 .69613 .27248 .70821 .26834 .70257 .26073 Mtetra
.70257 .26073 .70821 .26834 .72034 .26418 .71474 .25654 Mtetra
.71474 .25654 .72034 .26418 .73253 .26001 .72696 .25232 Mtetra
.72696 .25232 .73253 .26001 .74477 .25581 .73923 .24808 Mtetra
.656 .753 .921 r
.73923 .24808 .74477 .25581 .75706 .2516 .75156 .24381 Mtetra
.75156 .24381 .75706 .2516 .7694 .24737 .76394 .23952 Mtetra
.657 .752 .921 r
.76394 .23952 .7694 .24737 .7818 .24311 .77637 .23521 Mtetra
.653 .751 .922 r
.11732 .45366 .12449 .45992 .1343 .45656 .12715 .45033 Mtetra
.653 .753 .923 r
.12715 .45033 .1343 .45656 .14415 .45318 .13702 .44698 Mtetra
.654 .754 .924 r
.13702 .44698 .14415 .45318 .15404 .44979 .14692 .4436 Mtetra
.654 .756 .924 r
.14692 .4436 .15404 .44979 .16397 .44637 .15687 .44019 Mtetra
.655 .757 .925 r
.15687 .44019 .16397 .44637 .17394 .44294 .16686 .43675 Mtetra
.16686 .43675 .17394 .44294 .18395 .4395 .17689 .43328 Mtetra
.656 .758 .925 r
.17689 .43328 .18395 .4395 .19399 .43604 .18696 .4298 Mtetra
.18696 .4298 .19399 .43604 .20408 .43256 .19707 .42629 Mtetra
.656 .758 .924 r
.19707 .42629 .20408 .43256 .2142 .42906 .20722 .42276 Mtetra
.656 .757 .924 r
.20722 .42276 .2142 .42906 .22437 .42556 .21741 .41922 Mtetra
.21741 .41922 .22437 .42556 .23457 .42204 .22764 .41566 Mtetra
.657 .757 .924 r
.22764 .41566 .23457 .42204 .24482 .4185 .23791 .41208 Mtetra
.657 .756 .923 r
.23791 .41208 .24482 .4185 .2551 .41495 .24822 .40849 Mtetra
.24822 .40849 .2551 .41495 .26543 .41139 .25857 .40489 Mtetra
.657 .755 .922 r
.25857 .40489 .26543 .41139 .27579 .40781 .26896 .40127 Mtetra
.656 .754 .922 r
.26896 .40127 .27579 .40781 .2862 .40422 .27939 .39763 Mtetra
.27939 .39763 .2862 .40422 .29665 .40061 .28987 .39399 Mtetra
.656 .754 .921 r
.28987 .39399 .29665 .40061 .30714 .397 .30039 .39033 Mtetra
.656 .753 .921 r
.30039 .39033 .30714 .397 .31767 .39336 .31094 .38666 Mtetra
.31094 .38666 .31767 .39336 .32825 .38972 .32154 .38297 Mtetra
.656 .752 .921 r
.32154 .38297 .32825 .38972 .33886 .38605 .33219 .37928 Mtetra
.33219 .37928 .33886 .38605 .34952 .38238 .34287 .37556 Mtetra
.656 .752 .92 r
.34287 .37556 .34952 .38238 .36023 .37869 .3536 .37184 Mtetra
.3536 .37184 .36023 .37869 .37097 .37498 .36437 .3681 Mtetra
.656 .751 .92 r
.36437 .3681 .37097 .37498 .38176 .37126 .37519 .36435 Mtetra
.37519 .36435 .38176 .37126 .39259 .36753 .38605 .36058 Mtetra
.38605 .36058 .39259 .36753 .40347 .36378 .39695 .3568 Mtetra
.39695 .3568 .40347 .36378 .41439 .36001 .4079 .35301 Mtetra
.4079 .35301 .41439 .36001 .42535 .35623 .41889 .3492 Mtetra
.41889 .3492 .42535 .35623 .43636 .35244 .42993 .34537 Mtetra
.42993 .34537 .43636 .35244 .44741 .34863 .44101 .34153 Mtetra
.44101 .34153 .44741 .34863 .45851 .3448 .45214 .33768 Mtetra
.45214 .33768 .45851 .3448 .46966 .34096 .46331 .33381 Mtetra
.46331 .33381 .46966 .34096 .48085 .33711 .47453 .32993 Mtetra
.47453 .32993 .48085 .33711 .49208 .33323 .4858 .32604 Mtetra
.4858 .32604 .49208 .33323 .50337 .32935 .49711 .32212 Mtetra
.655 .751 .92 r
.49711 .32212 .50337 .32935 .5147 .32544 .50847 .3182 Mtetra
.655 .752 .921 r
.50847 .3182 .5147 .32544 .52607 .32152 .51988 .31426 Mtetra
.51988 .31426 .52607 .32152 .5375 .31759 .53134 .3103 Mtetra
.53134 .3103 .5375 .31759 .54897 .31363 .54284 .30633 Mtetra
.54284 .30633 .54897 .31363 .56049 .30967 .55439 .30234 Mtetra
.655 .753 .922 r
.55439 .30234 .56049 .30967 .57206 .30568 .56599 .29834 Mtetra
.56599 .29834 .57206 .30568 .58367 .30168 .57764 .29432 Mtetra
.655 .754 .922 r
.57764 .29432 .58367 .30168 .59534 .29767 .58934 .29029 Mtetra
.655 .754 .923 r
.58934 .29029 .59534 .29767 .60705 .29363 .60109 .28624 Mtetra
.60109 .28624 .60705 .29363 .61882 .28958 .61288 .28217 Mtetra
.655 .755 .923 r
.61288 .28217 .61882 .28958 .63063 .28551 .62473 .27809 Mtetra
.655 .756 .924 r
.62473 .27809 .63063 .28551 .64249 .28143 .63663 .27399 Mtetra
.63663 .27399 .64249 .28143 .6544 .27733 .64858 .26987 Mtetra
.655 .757 .924 r
.64858 .26987 .6544 .27733 .66637 .27321 .66058 .26573 Mtetra
.655 .757 .925 r
.66058 .26573 .66637 .27321 .67838 .26907 .67263 .26157 Mtetra
.67263 .26157 .67838 .26907 .69045 .26491 .68473 .25738 Mtetra
.656 .758 .925 r
.68473 .25738 .69045 .26491 .70257 .26073 .69689 .25317 Mtetra
.69689 .25317 .70257 .26073 .71474 .25654 .70909 .24893 Mtetra
.657 .758 .924 r
.70909 .24893 .71474 .25654 .72696 .25232 .72135 .24466 Mtetra
.657 .757 .924 r
.72135 .24466 .72696 .25232 .73923 .24808 .73366 .24036 Mtetra
.658 .757 .923 r
.73366 .24036 .73923 .24808 .75156 .24381 .74602 .23602 Mtetra
.658 .756 .922 r
.74602 .23602 .75156 .24381 .76394 .23952 .75843 .23165 Mtetra
.659 .754 .921 r
.75843 .23165 .76394 .23952 .77637 .23521 .7709 .22725 Mtetra
.646 .749 .924 r
.1101 .44736 .11732 .45366 .12715 .45033 .11993 .44417 Mtetra
.647 .754 .928 r
.11993 .44417 .12715 .45033 .13702 .44698 .1298 .44093 Mtetra
.648 .759 .931 r
.1298 .44093 .13702 .44698 .14692 .4436 .13972 .43765 Mtetra
.649 .764 .933 r
.13972 .43765 .14692 .4436 .15687 .44019 .14967 .43433 Mtetra
.65 .768 .935 r
.14967 .43433 .15687 .44019 .16686 .43675 .15968 .43096 Mtetra
.651 .772 .937 r
.15968 .43096 .16686 .43675 .17689 .43328 .16972 .42754 Mtetra
.652 .774 .938 r
.16972 .42754 .17689 .43328 .18696 .4298 .17981 .42409 Mtetra
.653 .776 .939 r
.17981 .42409 .18696 .4298 .19707 .42629 .18994 .42059 Mtetra
.654 .778 .94 r
.18994 .42059 .19707 .42629 .20722 .42276 .20011 .41707 Mtetra
.655 .779 .94 r
.20011 .41707 .20722 .42276 .21741 .41922 .21032 .41352 Mtetra
.655 .78 .94 r
.21032 .41352 .21741 .41922 .22764 .41566 .22058 .40994 Mtetra
.22058 .40994 .22764 .41566 .23791 .41208 .23088 .40634 Mtetra
.656 .78 .94 r
.23088 .40634 .23791 .41208 .24822 .40849 .24121 .40272 Mtetra
.24121 .40272 .24822 .40849 .25857 .40489 .25159 .39908 Mtetra
.25159 .39908 .25857 .40489 .26896 .40127 .26201 .39542 Mtetra
.656 .779 .939 r
.26201 .39542 .26896 .40127 .27939 .39763 .27248 .39175 Mtetra
.27248 .39175 .27939 .39763 .28987 .39399 .28298 .38806 Mtetra
.656 .778 .939 r
.28298 .38806 .28987 .39399 .30039 .39033 .29352 .38436 Mtetra
.656 .778 .938 r
.29352 .38436 .30039 .39033 .31094 .38666 .30411 .38065 Mtetra
.656 .777 .938 r
.30411 .38065 .31094 .38666 .32154 .38297 .31474 .37692 Mtetra
.31474 .37692 .32154 .38297 .33219 .37928 .32541 .37318 Mtetra
.656 .776 .937 r
.32541 .37318 .33219 .37928 .34287 .37556 .33613 .36943 Mtetra
.33613 .36943 .34287 .37556 .3536 .37184 .34689 .36566 Mtetra
.656 .775 .937 r
.34689 .36566 .3536 .37184 .36437 .3681 .35769 .36189 Mtetra
.35769 .36189 .36437 .3681 .37519 .36435 .36854 .3581 Mtetra
.656 .775 .936 r
.36854 .3581 .37519 .36435 .38605 .36058 .37942 .35429 Mtetra
.655 .774 .936 r
.37942 .35429 .38605 .36058 .39695 .3568 .39036 .35048 Mtetra
.39036 .35048 .39695 .3568 .4079 .35301 .40134 .34665 Mtetra
.40134 .34665 .4079 .35301 .41889 .3492 .41236 .34281 Mtetra
.41236 .34281 .41889 .3492 .42993 .34537 .42343 .33896 Mtetra
.42343 .33896 .42993 .34537 .44101 .34153 .43454 .3351 Mtetra
.43454 .3351 .44101 .34153 .45214 .33768 .4457 .33122 Mtetra
.4457 .33122 .45214 .33768 .46331 .33381 .45691 .32733 Mtetra
.655 .774 .937 r
.45691 .32733 .46331 .33381 .47453 .32993 .46816 .32343 Mtetra
.654 .774 .937 r
.46816 .32343 .47453 .32993 .4858 .32604 .47946 .31951 Mtetra
.47946 .31951 .4858 .32604 .49711 .32212 .4908 .31558 Mtetra
.654 .775 .937 r
.4908 .31558 .49711 .32212 .50847 .3182 .5022 .31164 Mtetra
.654 .775 .938 r
.5022 .31164 .50847 .3182 .51988 .31426 .51364 .30768 Mtetra
.654 .776 .938 r
.51364 .30768 .51988 .31426 .53134 .3103 .52513 .30371 Mtetra
.52513 .30371 .53134 .3103 .54284 .30633 .53666 .29972 Mtetra
.654 .777 .939 r
.53666 .29972 .54284 .30633 .55439 .30234 .54825 .29572 Mtetra
.653 .777 .939 r
.54825 .29572 .55439 .30234 .56599 .29834 .55989 .29171 Mtetra
.653 .778 .94 r
.55989 .29171 .56599 .29834 .57764 .29432 .57157 .28767 Mtetra
.57157 .28767 .57764 .29432 .58934 .29029 .5833 .28362 Mtetra
.653 .779 .94 r
.5833 .28362 .58934 .29029 .60109 .28624 .59509 .27956 Mtetra
.653 .779 .941 r
.59509 .27956 .60109 .28624 .61288 .28217 .60692 .27547 Mtetra
.654 .779 .941 r
.60692 .27547 .61288 .28217 .62473 .27809 .61881 .27136 Mtetra
.654 .78 .941 r
.61881 .27136 .62473 .27809 .63663 .27399 .63074 .26722 Mtetra
.63074 .26722 .63663 .27399 .64858 .26987 .64273 .26306 Mtetra
.655 .78 .94 r
.64273 .26306 .64858 .26987 .66058 .26573 .65477 .25887 Mtetra
.655 .779 .94 r
.65477 .25887 .66058 .26573 .67263 .26157 .66686 .25465 Mtetra
.656 .779 .939 r
.66686 .25465 .67263 .26157 .68473 .25738 .679 .25039 Mtetra
.657 .778 .938 r
.679 .25039 .68473 .25738 .69689 .25317 .69119 .24609 Mtetra
.658 .776 .936 r
.69119 .24609 .69689 .25317 .70909 .24893 .70343 .24174 Mtetra
.66 .774 .934 r
.70343 .24174 .70909 .24893 .72135 .24466 .71572 .23734 Mtetra
.661 .772 .931 r
.71572 .23734 .72135 .24466 .73366 .24036 .72806 .23289 Mtetra
.662 .768 .928 r
.72806 .23289 .73366 .24036 .74602 .23602 .74045 .22838 Mtetra
.663 .764 .925 r
.74045 .22838 .74602 .23602 .75843 .23165 .75289 .22383 Mtetra
.664 .76 .921 r
.75289 .22383 .75843 .23165 .7709 .22725 .76539 .21923 Mtetra
.629 .744 .931 r
.10283 .44102 .1101 .44736 .11993 .44417 .11263 .43817 Mtetra
.63 .757 .939 r
.11263 .43817 .11993 .44417 .1298 .44093 .12248 .43526 Mtetra
.631 .77 .947 r
.12248 .43526 .1298 .44093 .13972 .43765 .13238 .43229 Mtetra
.632 .782 .953 r
.13238 .43229 .13972 .43765 .14967 .43433 .14233 .42924 Mtetra
.634 .793 .958 r
.14233 .42924 .14967 .43433 .15968 .43096 .15233 .4261 Mtetra
.636 .802 .963 r
.15233 .4261 .15968 .43096 .16972 .42754 .16237 .42287 Mtetra
.638 .81 .966 r
.16237 .42287 .16972 .42754 .17981 .42409 .17247 .41956 Mtetra
.639 .817 .968 r
.17247 .41956 .17981 .42409 .18994 .42059 .18262 .41618 Mtetra
.641 .822 .97 r
.18262 .41618 .18994 .42059 .20011 .41707 .19281 .41273 Mtetra
.642 .826 .971 r
.19281 .41273 .20011 .41707 .21032 .41352 .20304 .40922 Mtetra
.643 .829 .972 r
.20304 .40922 .21032 .41352 .22058 .40994 .21333 .40566 Mtetra
.645 .83 .972 r
.21333 .40566 .22058 .40994 .23088 .40634 .22365 .40206 Mtetra
.646 .831 .972 r
.22365 .40206 .23088 .40634 .24121 .40272 .23402 .39842 Mtetra
.647 .832 .972 r
.23402 .39842 .24121 .40272 .25159 .39908 .24443 .39474 Mtetra
.647 .832 .971 r
.24443 .39474 .25159 .39908 .26201 .39542 .25489 .39104 Mtetra
.648 .831 .971 r
.25489 .39104 .26201 .39542 .27248 .39175 .26538 .38731 Mtetra
.649 .83 .97 r
.26538 .38731 .27248 .39175 .28298 .38806 .27592 .38356 Mtetra
.649 .829 .969 r
.27592 .38356 .28298 .38806 .29352 .38436 .2865 .37979 Mtetra
.65 .827 .968 r
.2865 .37979 .29352 .38436 .30411 .38065 .29713 .37601 Mtetra
.65 .826 .968 r
.29713 .37601 .30411 .38065 .31474 .37692 .30779 .37221 Mtetra
.65 .824 .967 r
.30779 .37221 .31474 .37692 .32541 .37318 .3185 .3684 Mtetra
.651 .823 .966 r
.3185 .3684 .32541 .37318 .33613 .36943 .32925 .36458 Mtetra
.651 .821 .965 r
.32925 .36458 .33613 .36943 .34689 .36566 .34005 .36075 Mtetra
.651 .82 .965 r
.34005 .36075 .34689 .36566 .35769 .36189 .35088 .35692 Mtetra
.651 .819 .964 r
.35088 .35692 .35769 .36189 .36854 .3581 .36176 .35307 Mtetra
.65 .818 .964 r
.36176 .35307 .36854 .3581 .37942 .35429 .37269 .34922 Mtetra
.65 .817 .963 r
.37269 .34922 .37942 .35429 .39036 .35048 .38366 .34536 Mtetra
.65 .816 .963 r
.38366 .34536 .39036 .35048 .40134 .34665 .39467 .34149 Mtetra
.39467 .34149 .40134 .34665 .41236 .34281 .40573 .33762 Mtetra
.649 .815 .963 r
.40573 .33762 .41236 .34281 .42343 .33896 .41683 .33374 Mtetra
.41683 .33374 .42343 .33896 .43454 .3351 .42798 .32985 Mtetra
.648 .815 .964 r
.42798 .32985 .43454 .3351 .4457 .33122 .43918 .32596 Mtetra
.648 .816 .964 r
.43918 .32596 .4457 .33122 .45691 .32733 .45042 .32206 Mtetra
.647 .816 .964 r
.45042 .32206 .45691 .32733 .46816 .32343 .46171 .31815 Mtetra
.647 .817 .965 r
.46171 .31815 .46816 .32343 .47946 .31951 .47304 .31424 Mtetra
.646 .818 .966 r
.47304 .31424 .47946 .31951 .4908 .31558 .48442 .31031 Mtetra
.645 .819 .966 r
.48442 .31031 .4908 .31558 .5022 .31164 .49586 .30638 Mtetra
.645 .82 .967 r
.49586 .30638 .5022 .31164 .51364 .30768 .50733 .30243 Mtetra
.644 .821 .968 r
.50733 .30243 .51364 .30768 .52513 .30371 .51886 .29847 Mtetra
.643 .822 .969 r
.51886 .29847 .52513 .30371 .53666 .29972 .53044 .2945 Mtetra
.643 .824 .97 r
.53044 .2945 .53666 .29972 .54825 .29572 .54207 .29052 Mtetra
.643 .825 .971 r
.54207 .29052 .54825 .29572 .55989 .29171 .55374 .28651 Mtetra
.642 .827 .971 r
.55374 .28651 .55989 .29171 .57157 .28767 .56547 .28249 Mtetra
.642 .828 .972 r
.56547 .28249 .57157 .28767 .5833 .28362 .57725 .27844 Mtetra
.642 .829 .972 r
.57725 .27844 .5833 .28362 .59509 .27956 .58907 .27437 Mtetra
.643 .83 .973 r
.58907 .27437 .59509 .27956 .60692 .27547 .60095 .27026 Mtetra
.643 .831 .972 r
.60095 .27026 .60692 .27547 .61881 .27136 .61288 .26612 Mtetra
.645 .831 .972 r
.61288 .26612 .61881 .27136 .63074 .26722 .62486 .26193 Mtetra
.646 .831 .971 r
.62486 .26193 .63074 .26722 .64273 .26306 .63689 .25769 Mtetra
.649 .83 .97 r
.63689 .25769 .64273 .26306 .65477 .25887 .64897 .2534 Mtetra
.651 .829 .968 r
.64897 .2534 .65477 .25887 .66686 .25465 .6611 .24905 Mtetra
.655 .826 .966 r
.6611 .24905 .66686 .25465 .679 .25039 .67328 .24462 Mtetra
.658 .823 .962 r
.67328 .24462 .679 .25039 .69119 .24609 .6855 .24011 Mtetra
.663 .818 .958 r
.6855 .24011 .69119 .24609 .70343 .24174 .69777 .23551 Mtetra
.667 .812 .953 r
.69777 .23551 .70343 .24174 .71572 .23734 .71009 .23081 Mtetra
.671 .804 .946 r
.71009 .23081 .71572 .23734 .72806 .23289 .72246 .22601 Mtetra
.674 .795 .939 r
.72246 .22601 .72806 .23289 .74045 .22838 .73487 .22113 Mtetra
.677 .784 .931 r
.73487 .22113 .74045 .22838 .75289 .22383 .74732 .21616 Mtetra
.678 .773 .922 r
.74732 .21616 .75289 .22383 .76539 .21923 .75983 .21113 Mtetra
.602 .737 .94 r
.09551 .43462 .10283 .44102 .11263 .43817 .10526 .43231 Mtetra
.6 .755 .952 r
.10526 .43231 .11263 .43817 .12248 .43526 .11506 .42992 Mtetra
.6 .774 .964 r
.11506 .42992 .12248 .43526 .13238 .43229 .12492 .42745 Mtetra
.599 .793 .973 r
.12492 .42745 .13238 .43229 .14233 .42924 .13483 .42487 Mtetra
.599 .811 .981 r
.13483 .42487 .14233 .42924 .15233 .4261 .1448 .42215 Mtetra
.599 .827 .987 r
.1448 .42215 .15233 .4261 .16237 .42287 .15484 .41931 Mtetra
.599 .842 .99 r
.15484 .41931 .16237 .42287 .17247 .41956 .16492 .41632 Mtetra
.598 .854 .992 r
.16492 .41632 .17247 .41956 .18262 .41618 .17507 .41322 Mtetra
.597 .864 .993 r
.17507 .41322 .18262 .41618 .19281 .41273 .18527 .41 Mtetra
.596 .872 .993 r
.18527 .41 .19281 .41273 .20304 .40922 .19552 .40669 Mtetra
.595 .879 .992 r
.19552 .40669 .20304 .40922 .21333 .40566 .20582 .40328 Mtetra
.594 .884 .992 r
.20582 .40328 .21333 .40566 .22365 .40206 .21616 .3998 Mtetra
.593 .888 .99 r
.21616 .3998 .22365 .40206 .23402 .39842 .22656 .39625 Mtetra
.593 .891 .989 r
.22656 .39625 .23402 .39842 .24443 .39474 .237 .39263 Mtetra
.592 .894 .989 r
.237 .39263 .24443 .39474 .25489 .39104 .24749 .38897 Mtetra
.592 .896 .988 r
.24749 .38897 .25489 .39104 .26538 .38731 .25802 .38526 Mtetra
.592 .897 .987 r
.25802 .38526 .26538 .38731 .27592 .38356 .2686 .38152 Mtetra
.593 .898 .987 r
.2686 .38152 .27592 .38356 .2865 .37979 .27922 .37774 Mtetra
.27922 .37774 .2865 .37979 .29713 .37601 .28989 .37394 Mtetra
.28989 .37394 .29713 .37601 .30779 .37221 .30059 .37011 Mtetra
.30059 .37011 .30779 .37221 .3185 .3684 .31134 .36627 Mtetra
.594 .898 .987 r
.31134 .36627 .3185 .3684 .32925 .36458 .32214 .36241 Mtetra
.32214 .36241 .32925 .36458 .34005 .36075 .33298 .35855 Mtetra
.33298 .35855 .34005 .36075 .35088 .35692 .34386 .35467 Mtetra
.594 .897 .987 r
.34386 .35467 .35088 .35692 .36176 .35307 .35478 .35079 Mtetra
.35478 .35079 .36176 .35307 .37269 .34922 .36575 .3469 Mtetra
.593 .896 .988 r
.36575 .3469 .37269 .34922 .38366 .34536 .37676 .343 Mtetra
.37676 .343 .38366 .34536 .39467 .34149 .38782 .3391 Mtetra
.592 .895 .988 r
.38782 .3391 .39467 .34149 .40573 .33762 .39893 .3352 Mtetra
.591 .895 .988 r
.39893 .3352 .40573 .33762 .41683 .33374 .41007 .33129 Mtetra
.59 .895 .988 r
.41007 .33129 .41683 .33374 .42798 .32985 .42127 .32739 Mtetra
.589 .894 .988 r
.42127 .32739 .42798 .32985 .43918 .32596 .43251 .32347 Mtetra
.588 .894 .988 r
.43251 .32347 .43918 .32596 .45042 .32206 .4438 .31956 Mtetra
.587 .894 .988 r
.4438 .31956 .45042 .32206 .46171 .31815 .45513 .31563 Mtetra
.586 .894 .988 r
.45513 .31563 .46171 .31815 .47304 .31424 .46652 .31171 Mtetra
.585 .894 .988 r
.46652 .31171 .47304 .31424 .48442 .31031 .47795 .30777 Mtetra
.584 .894 .988 r
.47795 .30777 .48442 .31031 .49586 .30638 .48943 .30382 Mtetra
.583 .894 .988 r
.48943 .30382 .49586 .30638 .50733 .30243 .50095 .29986 Mtetra
.582 .894 .988 r
.50095 .29986 .50733 .30243 .51886 .29847 .51253 .29589 Mtetra
.582 .895 .987 r
.51253 .29589 .51886 .29847 .53044 .2945 .52416 .29189 Mtetra
.52416 .29189 .53044 .2945 .54207 .29052 .53584 .28787 Mtetra
.583 .895 .987 r
.53584 .28787 .54207 .29052 .55374 .28651 .54756 .28383 Mtetra
.585 .895 .987 r
.54756 .28383 .55374 .28651 .56547 .28249 .55934 .27975 Mtetra
.588 .895 .988 r
.55934 .27975 .56547 .28249 .57725 .27844 .57117 .27563 Mtetra
.591 .895 .988 r
.57117 .27563 .57725 .27844 .58907 .27437 .58305 .27146 Mtetra
.596 .895 .988 r
.58305 .27146 .58907 .27437 .60095 .27026 .59498 .26723 Mtetra
.602 .895 .988 r
.59498 .26723 .60095 .27026 .61288 .26612 .60695 .26294 Mtetra
.609 .894 .989 r
.60695 .26294 .61288 .26612 .62486 .26193 .61898 .25858 Mtetra
.618 .892 .988 r
.61898 .25858 .62486 .26193 .63689 .25769 .63106 .25413 Mtetra
.627 .889 .988 r
.63106 .25413 .63689 .25769 .64897 .2534 .64318 .24959 Mtetra
.638 .885 .986 r
.64318 .24959 .64897 .2534 .6611 .24905 .65535 .24493 Mtetra
.649 .88 .983 r
.65535 .24493 .6611 .24905 .67328 .24462 .66756 .24016 Mtetra
.66 .873 .979 r
.66756 .24016 .67328 .24462 .6855 .24011 .67982 .23525 Mtetra
.67 .863 .973 r
.67982 .23525 .6855 .24011 .69777 .23551 .69212 .2302 Mtetra
.68 .851 .965 r
.69212 .2302 .69777 .23551 .71009 .23081 .70446 .22501 Mtetra
.688 .837 .955 r
.70446 .22501 .71009 .23081 .72246 .22601 .71684 .21966 Mtetra
.693 .821 .944 r
.71684 .21966 .72246 .22601 .73487 .22113 .72926 .21419 Mtetra
.696 .804 .932 r
.72926 .21419 .73487 .22113 .74732 .21616 .74172 .20862 Mtetra
.697 .786 .919 r
.74172 .20862 .74732 .21616 .75983 .21113 .75422 .20298 Mtetra
.554 .721 .951 r
.08813 .42819 .09551 .43462 .10526 .43231 .09779 .42667 Mtetra
.544 .747 .97 r
.09779 .42667 .10526 .43231 .11506 .42992 .1075 .42512 Mtetra
.532 .774 .987 r
.1075 .42512 .11506 .42992 .12492 .42745 .11728 .42348 Mtetra
.516 .8 .997 r
.11728 .42348 .12492 .42745 .13483 .42487 .12711 .42173 Mtetra
.498 .823 1 r
.12711 .42173 .13483 .42487 .1448 .42215 .13702 .41983 Mtetra
.473 .839 .992 r
.13702 .41983 .1448 .42215 .15484 .41931 .14699 .41776 Mtetra
.445 .848 .972 r
.14699 .41776 .15484 .41931 .16492 .41632 .15703 .41551 Mtetra
.412 .847 .941 r
.15703 .41551 .16492 .41632 .17507 .41322 .16713 .41309 Mtetra
.377 .837 .902 r
.16713 .41309 .17507 .41322 .18527 .41 .1773 .4105 Mtetra
.341 .82 .858 r
.1773 .4105 .18527 .41 .19552 .40669 .18753 .40775 Mtetra
.306 .799 .811 r
.18753 .40775 .19552 .40669 .20582 .40328 .19783 .40485 Mtetra
.273 .776 .766 r
.19783 .40485 .20582 .40328 .21616 .3998 .20818 .40181 Mtetra
.244 .752 .723 r
.20818 .40181 .21616 .3998 .22656 .39625 .21859 .39866 Mtetra
.218 .73 .684 r
.21859 .39866 .22656 .39625 .237 .39263 .22905 .39539 Mtetra
0 0 0 r
.22905 .39539 .237 .39263 .24749 .38897 .23956 .39202 Mtetra
.23956 .39202 .24749 .38897 .25802 .38526 .25013 .38856 Mtetra
.25013 .38856 .25802 .38526 .2686 .38152 .26074 .38503 Mtetra
.26074 .38503 .2686 .38152 .27922 .37774 .27141 .38143 Mtetra
.27141 .38143 .27922 .37774 .28989 .37394 .28212 .37777 Mtetra
.28212 .37777 .28989 .37394 .30059 .37011 .29288 .37406 Mtetra
.29288 .37406 .30059 .37011 .31134 .36627 .30368 .3703 Mtetra
.30368 .3703 .31134 .36627 .32214 .36241 .31454 .36651 Mtetra
.31454 .36651 .32214 .36241 .33298 .35855 .32543 .36269 Mtetra
.32543 .36269 .33298 .35855 .34386 .35467 .33638 .35885 Mtetra
.33638 .35885 .34386 .35467 .35478 .35079 .34736 .35498 Mtetra
.34736 .35498 .35478 .35079 .36575 .3469 .3584 .3511 Mtetra
.3584 .3511 .36575 .3469 .37676 .343 .36948 .34721 Mtetra
.36948 .34721 .37676 .343 .38782 .3391 .3806 .3433 Mtetra
.3806 .3433 .38782 .3391 .39893 .3352 .39177 .33938 Mtetra
.39177 .33938 .39893 .3352 .41007 .33129 .40299 .33546 Mtetra
.40299 .33546 .41007 .33129 .42127 .32739 .41425 .33152 Mtetra
.41425 .33152 .42127 .32739 .43251 .32347 .42556 .32758 Mtetra
.42556 .32758 .43251 .32347 .4438 .31956 .43692 .32362 Mtetra
.43692 .32362 .4438 .31956 .45513 .31563 .44833 .31965 Mtetra
.44833 .31965 .45513 .31563 .46652 .31171 .45978 .31566 Mtetra
.45978 .31566 .46652 .31171 .47795 .30777 .47129 .31165 Mtetra
.47129 .31165 .47795 .30777 .48943 .30382 .48284 .30761 Mtetra
.48284 .30761 .48943 .30382 .50095 .29986 .49444 .30354 Mtetra
.49444 .30354 .50095 .29986 .51253 .29589 .50609 .29943 Mtetra
.50609 .29943 .51253 .29589 .52416 .29189 .51779 .29528 Mtetra
.51779 .29528 .52416 .29189 .53584 .28787 .52954 .29108 Mtetra
.52954 .29108 .53584 .28787 .54756 .28383 .54134 .28681 Mtetra
.54134 .28681 .54756 .28383 .55934 .27975 .55319 .28247 Mtetra
.55319 .28247 .55934 .27975 .57117 .27563 .56509 .27805 Mtetra
.56509 .27805 .57117 .27563 .58305 .27146 .57704 .27353 Mtetra
.276 .765 .685 r
.57704 .27353 .58305 .27146 .59498 .26723 .58903 .26891 Mtetra
.319 .798 .727 r
.58903 .26891 .59498 .26723 .60695 .26294 .60107 .26416 Mtetra
.367 .832 .771 r
.60107 .26416 .60695 .26294 .61898 .25858 .61315 .25929 Mtetra
.42 .865 .818 r
.61315 .25929 .61898 .25858 .63106 .25413 .62528 .25427 Mtetra
.475 .896 .863 r
.62528 .25427 .63106 .25413 .64318 .24959 .63745 .24909 Mtetra
.531 .92 .903 r
.63745 .24909 .64318 .24959 .65535 .24493 .64966 .24375 Mtetra
.584 .936 .936 r
.64966 .24375 .65535 .24493 .66756 .24016 .66191 .23821 Mtetra
.63 .94 .958 r
.66191 .23821 .66756 .24016 .67982 .23525 .67419 .23249 Mtetra
.668 .933 .969 r
.67419 .23249 .67982 .23525 .69212 .2302 .68651 .22657 Mtetra
.696 .916 .969 r
.68651 .22657 .69212 .2302 .70446 .22501 .69886 .22047 Mtetra
.714 .892 .961 r
.69886 .22047 .70446 .22501 .71684 .21966 .71123 .2142 Mtetra
.723 .864 .948 r
.71123 .2142 .71684 .21966 .72926 .21419 .72365 .2078 Mtetra
.727 .834 .931 r
.72365 .2078 .72926 .21419 .74172 .20862 .73609 .20131 Mtetra
.725 .805 .914 r
.73609 .20131 .74172 .20862 .75422 .20298 .74857 .19475 Mtetra
.505 .703 .959 r
.0807 .4217 .08813 .42819 .09779 .42667 .09028 .42089 Mtetra
.49 .723 .975 r
.09028 .42089 .09779 .42667 .1075 .42512 .09991 .42007 Mtetra
.473 .744 .988 r
.09991 .42007 .1075 .42512 .11728 .42348 .1096 .4192 Mtetra
.452 .765 .996 r
.1096 .4192 .11728 .42348 .12711 .42173 .11936 .41824 Mtetra
.428 .783 .996 r
.11936 .41824 .12711 .42173 .13702 .41983 .12919 .41716 Mtetra
.399 .797 .986 r
.12919 .41716 .13702 .41983 .14699 .41776 .13909 .41591 Mtetra
.367 .803 .962 r
.13909 .41591 .14699 .41776 .15703 .41551 .14907 .41447 Mtetra
.328 .798 .925 r
.14907 .41447 .15703 .41551 .16713 .41309 .15912 .41283 Mtetra
.288 .784 .876 r
.15912 .41283 .16713 .41309 .1773 .4105 .16924 .41098 Mtetra
.246 .76 .818 r
.16924 .41098 .1773 .4105 .18753 .40775 .17944 .40893 Mtetra
.205 .731 .756 r
.17944 .40893 .18753 .40775 .19783 .40485 .18971 .4067 Mtetra
.166 .698 .695 r
.18971 .4067 .19783 .40485 .20818 .40181 .20005 .40427 Mtetra
0 0 0 r
.20005 .40427 .20818 .40181 .21859 .39866 .21045 .40168 Mtetra
.21045 .40168 .21859 .39866 .22905 .39539 .22092 .39893 Mtetra
.22092 .39893 .22905 .39539 .23956 .39202 .23144 .39603 Mtetra
.23144 .39603 .23956 .39202 .25013 .38856 .24203 .393 Mtetra
.24203 .393 .25013 .38856 .26074 .38503 .25267 .38984 Mtetra
.25267 .38984 .26074 .38503 .27141 .38143 .26337 .38658 Mtetra
.005 0 0 r
.26337 .38658 .27141 .38143 .28212 .37777 .27412 .38321 Mtetra
.018 0 0 r
.27412 .38321 .28212 .37777 .29288 .37406 .28492 .37975 Mtetra
.029 0 0 r
.28492 .37975 .29288 .37406 .30368 .3703 .29578 .37622 Mtetra
.038 0 0 r
.29578 .37622 .30368 .3703 .31454 .36651 .30669 .37261 Mtetra
.046 0 0 r
.30669 .37261 .31454 .36651 .32543 .36269 .31764 .36895 Mtetra
.052 0 0 r
.31764 .36895 .32543 .36269 .33638 .35885 .32865 .36523 Mtetra
.057 0 0 r
.32865 .36523 .33638 .35885 .34736 .35498 .3397 .36146 Mtetra
.061 0 0 r
.3397 .36146 .34736 .35498 .3584 .3511 .35081 .35765 Mtetra
.064 0 0 r
.35081 .35765 .3584 .3511 .36948 .34721 .36196 .3538 Mtetra
.067 0 0 r
.36196 .3538 .36948 .34721 .3806 .3433 .37316 .34992 Mtetra
.068 0 0 r
.37316 .34992 .3806 .3433 .39177 .33938 .3844 .34601 Mtetra
.3844 .34601 .39177 .33938 .40299 .33546 .3957 .34206 Mtetra
.066 0 0 r
.3957 .34206 .40299 .33546 .41425 .33152 .40704 .33809 Mtetra
.064 0 0 r
.40704 .33809 .41425 .33152 .42556 .32758 .41843 .33408 Mtetra
.06 0 0 r
.41843 .33408 .42556 .32758 .43692 .32362 .42987 .33003 Mtetra
.055 0 0 r
.42987 .33003 .43692 .32362 .44833 .31965 .44136 .32595 Mtetra
.048 0 0 r
.44136 .32595 .44833 .31965 .45978 .31566 .4529 .32183 Mtetra
.039 0 0 r
.4529 .32183 .45978 .31566 .47129 .31165 .46449 .31765 Mtetra
.028 0 0 r
.46449 .31765 .47129 .31165 .48284 .30761 .47612 .31342 Mtetra
.014 0 0 r
.47612 .31342 .48284 .30761 .49444 .30354 .48781 .30913 Mtetra
0 0 0 r
.48781 .30913 .49444 .30354 .50609 .29943 .49954 .30476 Mtetra
.49954 .30476 .50609 .29943 .51779 .29528 .51133 .30031 Mtetra
.51133 .30031 .51779 .29528 .52954 .29108 .52316 .29576 Mtetra
.52316 .29576 .52954 .29108 .54134 .28681 .53504 .29111 Mtetra
.53504 .29111 .54134 .28681 .55319 .28247 .54696 .28634 Mtetra
.54696 .28634 .55319 .28247 .56509 .27805 .55894 .28145 Mtetra
.55894 .28145 .56509 .27805 .57704 .27353 .57095 .2764 Mtetra
.57095 .2764 .57704 .27353 .58903 .26891 .58301 .2712 Mtetra
.32 .789 .684 r
.58301 .2712 .58903 .26891 .60107 .26416 .59511 .26583 Mtetra
.386 .838 .746 r
.59511 .26583 .60107 .26416 .61315 .25929 .60726 .26028 Mtetra
.456 .883 .807 r
.60726 .26028 .61315 .25929 .62528 .25427 .61943 .25453 Mtetra
.524 .92 .861 r
.61943 .25453 .62528 .25427 .63745 .24909 .63165 .24858 Mtetra
.588 .944 .906 r
.63165 .24858 .63745 .24909 .64966 .24375 .6439 .2424 Mtetra
.643 .955 .937 r
.6439 .2424 .64966 .24375 .66191 .23821 .65617 .23601 Mtetra
.686 .952 .954 r
.65617 .23601 .66191 .23821 .67419 .23249 .66848 .22939 Mtetra
.717 .938 .958 r
.66848 .22939 .67419 .23249 .68651 .22657 .68081 .22256 Mtetra
.737 .916 .954 r
.68081 .22256 .68651 .22657 .69886 .22047 .69317 .21556 Mtetra
.747 .889 .943 r
.69317 .21556 .69886 .22047 .71123 .2142 .70555 .2084 Mtetra
.751 .862 .93 r
.70555 .2084 .71123 .2142 .72365 .2078 .71796 .20114 Mtetra
.75 .834 .916 r
.71796 .20114 .72365 .2078 .73609 .20131 .7304 .19381 Mtetra
.746 .808 .901 r
.7304 .19381 .73609 .20131 .74857 .19475 .74288 .18646 Mtetra
.497 .699 .96 r
.07322 .41517 .0807 .4217 .09028 .42089 .08279 .41446 Mtetra
.491 .702 .963 r
.08279 .41446 .09028 .42089 .09991 .42007 .09242 .41378 Mtetra
.487 .705 .966 r
.09242 .41378 .09991 .42007 .1096 .4192 .1021 .41311 Mtetra
.482 .712 .971 r
.1021 .41311 .1096 .4192 .11936 .41824 .11183 .41243 Mtetra
.477 .72 .977 r
.11183 .41243 .11936 .41824 .12919 .41716 .12163 .41172 Mtetra
.471 .733 .984 r
.12163 .41172 .12919 .41716 .13909 .41591 .13149 .41094 Mtetra
.465 .748 .991 r
.13149 .41094 .13909 .41591 .14907 .41447 .14142 .41004 Mtetra
.457 .765 .996 r
.14142 .41004 .14907 .41447 .15912 .41283 .15142 .40902 Mtetra
.445 .783 .998 r
.15142 .40902 .15912 .41283 .16924 .41098 .1615 .40783 Mtetra
.428 .798 .994 r
.1615 .40783 .16924 .41098 .17944 .40893 .17165 .40648 Mtetra
.406 .809 .982 r
.17165 .40648 .17944 .40893 .18971 .4067 .18187 .40496 Mtetra
.376 .812 .959 r
.18187 .40496 .18971 .4067 .20005 .40427 .19217 .40327 Mtetra
.34 .806 .924 r
.19217 .40327 .20005 .40427 .21045 .40168 .20254 .40142 Mtetra
.298 .79 .877 r
.20254 .40142 .21045 .40168 .22092 .39893 .21297 .39939 Mtetra
.253 .765 .819 r
.21297 .39939 .22092 .39893 .23144 .39603 .22347 .39721 Mtetra
.206 .732 .755 r
.22347 .39721 .23144 .39603 .24203 .393 .23404 .39487 Mtetra
0 0 0 r
.23404 .39487 .24203 .393 .25267 .38984 .24468 .39238 Mtetra
.24468 .39238 .25267 .38984 .26337 .38658 .25538 .38975 Mtetra
.25538 .38975 .26337 .38658 .27412 .38321 .26614 .38698 Mtetra
.26614 .38698 .27412 .38321 .28492 .37975 .27696 .38407 Mtetra
.27696 .38407 .28492 .37975 .29578 .37622 .28784 .38104 Mtetra
.008 0 0 r
.28784 .38104 .29578 .37622 .30669 .37261 .29878 .37788 Mtetra
.028 0 0 r
.29878 .37788 .30669 .37261 .31764 .36895 .30978 .37461 Mtetra
.044 0 0 r
.30978 .37461 .31764 .36895 .32865 .36523 .32083 .37123 Mtetra
.057 0 0 r
.32083 .37123 .32865 .36523 .3397 .36146 .33194 .36775 Mtetra
.066 0 0 r
.33194 .36775 .3397 .36146 .35081 .35765 .3431 .36416 Mtetra
.072 0 0 r
.3431 .36416 .35081 .35765 .36196 .3538 .35432 .36048 Mtetra
.075 0 0 r
.35432 .36048 .36196 .3538 .37316 .34992 .36559 .3567 Mtetra
.36559 .3567 .37316 .34992 .3844 .34601 .37691 .35283 Mtetra
.072 0 0 r
.37691 .35283 .3844 .34601 .3957 .34206 .38828 .34887 Mtetra
.066 0 0 r
.38828 .34887 .3957 .34206 .40704 .33809 .39971 .34481 Mtetra
.057 0 0 r
.39971 .34481 .40704 .33809 .41843 .33408 .41118 .34066 Mtetra
.044 0 0 r
.41118 .34066 .41843 .33408 .42987 .33003 .42271 .33642 Mtetra
.028 0 0 r
.42271 .33642 .42987 .33003 .44136 .32595 .43429 .33207 Mtetra
.007 0 0 r
.43429 .33207 .44136 .32595 .4529 .32183 .44591 .32762 Mtetra
0 0 0 r
.44591 .32762 .4529 .32183 .46449 .31765 .45759 .32306 Mtetra
.45759 .32306 .46449 .31765 .47612 .31342 .46931 .31839 Mtetra
.46931 .31839 .47612 .31342 .48781 .30913 .48108 .3136 Mtetra
.48108 .3136 .48781 .30913 .49954 .30476 .4929 .30868 Mtetra
.4929 .30868 .49954 .30476 .51133 .30031 .50476 .30362 Mtetra
.50476 .30362 .51133 .30031 .52316 .29576 .51667 .29843 Mtetra
.309 .78 .669 r
.51667 .29843 .52316 .29576 .53504 .29111 .52863 .29309 Mtetra
.378 .832 .737 r
.52863 .29309 .53504 .29111 .54696 .28634 .54062 .28759 Mtetra
.449 .879 .802 r
.54062 .28759 .54696 .28634 .55894 .28145 .55266 .28193 Mtetra
.517 .916 .859 r
.55266 .28193 .55894 .28145 .57095 .2764 .56473 .2761 Mtetra
.579 .941 .904 r
.56473 .2761 .57095 .2764 .58301 .2712 .57685 .2701 Mtetra
.631 .952 .936 r
.57685 .2701 .58301 .2712 .59511 .26583 .589 .26392 Mtetra
.672 .951 .954 r
.589 .26392 .59511 .26583 .60726 .26028 .60118 .25756 Mtetra
.703 .94 .961 r
.60118 .25756 .60726 .26028 .61943 .25453 .6134 .25102 Mtetra
.724 .923 .959 r
.6134 .25102 .61943 .25453 .63165 .24858 .62565 .24428 Mtetra
.738 .902 .952 r
.62565 .24428 .63165 .24858 .6439 .2424 .63792 .23737 Mtetra
.747 .881 .941 r
.63792 .23737 .6439 .2424 .65617 .23601 .65023 .23028 Mtetra
.751 .86 .929 r
.65023 .23028 .65617 .23601 .66848 .22939 .66256 .22303 Mtetra
.753 .841 .918 r
.66256 .22303 .66848 .22939 .68081 .22256 .67491 .21566 Mtetra
.753 .825 .908 r
.67491 .21566 .68081 .22256 .69317 .21556 .6873 .2082 Mtetra
.752 .812 .9 r
.6873 .2082 .69317 .21556 .70555 .2084 .69971 .20069 Mtetra
.75 .802 .895 r
.69971 .20069 .70555 .2084 .71796 .20114 .71215 .19315 Mtetra
.748 .795 .891 r
.71215 .19315 .71796 .20114 .7304 .19381 .72462 .18562 Mtetra
.746 .789 .888 r
.72462 .18562 .7304 .19381 .74288 .18646 .73713 .1781 Mtetra
.53 .712 .956 r
.06568 .40859 .07322 .41517 .08279 .41446 .07533 .40738 Mtetra
.531 .697 .945 r
.07533 .40738 .08279 .41446 .09242 .41378 .08503 .40624 Mtetra
.532 .683 .935 r
.08503 .40624 .09242 .41378 .1021 .41311 .09477 .40517 Mtetra
.531 .671 .926 r
.09477 .40517 .1021 .41311 .11183 .41243 .10456 .40417 Mtetra
.529 .661 .92 r
.10456 .40417 .11183 .41243 .12163 .41172 .11439 .40325 Mtetra
.529 .655 .916 r
.11439 .40325 .12163 .41172 .13149 .41094 .12427 .40237 Mtetra
.529 .653 .914 r
.12427 .40237 .13149 .41094 .14142 .41004 .1342 .40149 Mtetra
.53 .654 .914 r
.1342 .40149 .14142 .41004 .15142 .40902 .1442 .40057 Mtetra
.533 .66 .917 r
.1442 .40057 .15142 .40902 .1615 .40783 .15426 .39959 Mtetra
.535 .667 .922 r
.15426 .39959 .1615 .40783 .17165 .40648 .16439 .39851 Mtetra
.538 .678 .929 r
.16439 .39851 .17165 .40648 .18187 .40496 .17459 .39733 Mtetra
.541 .69 .936 r
.17459 .39733 .18187 .40496 .19217 .40327 .18486 .39603 Mtetra
.543 .705 .945 r
.18486 .39603 .19217 .40327 .20254 .40142 .1952 .3946 Mtetra
.545 .72 .955 r
.1952 .3946 .20254 .40142 .21297 .39939 .20561 .39303 Mtetra
.547 .738 .964 r
.20561 .39303 .21297 .39939 .22347 .39721 .21609 .39133 Mtetra
.547 .755 .974 r
.21609 .39133 .22347 .39721 .23404 .39487 .22663 .38948 Mtetra
.547 .774 .982 r
.22663 .38948 .23404 .39487 .24468 .39238 .23725 .38748 Mtetra
.546 .792 .989 r
.23725 .38748 .24468 .39238 .25538 .38975 .24793 .38533 Mtetra
.544 .809 .995 r
.24793 .38533 .25538 .38975 .26614 .38698 .25869 .38302 Mtetra
.541 .825 .998 r
.25869 .38302 .26614 .38698 .27696 .38407 .26951 .38056 Mtetra
.537 .839 .999 r
.26951 .38056 .27696 .38407 .28784 .38104 .28039 .37795 Mtetra
.533 .852 .998 r
.28039 .37795 .28784 .38104 .29878 .37788 .29134 .37517 Mtetra
.528 .862 .994 r
.29134 .37517 .29878 .37788 .30978 .37461 .30235 .37224 Mtetra
.524 .871 .989 r
.30235 .37224 .30978 .37461 .32083 .37123 .31342 .36916 Mtetra
.52 .878 .984 r
.31342 .36916 .32083 .37123 .33194 .36775 .32456 .36593 Mtetra
.519 .884 .978 r
.32456 .36593 .33194 .36775 .3431 .36416 .33576 .36254 Mtetra
.519 .889 .972 r
.33576 .36254 .3431 .36416 .35432 .36048 .34701 .359 Mtetra
.521 .893 .968 r
.34701 .359 .35432 .36048 .36559 .3567 .35832 .35531 Mtetra
.527 .898 .965 r
.35832 .35531 .36559 .3567 .37691 .35283 .36969 .35148 Mtetra
.535 .902 .964 r
.36969 .35148 .37691 .35283 .38828 .34887 .38112 .34749 Mtetra
.546 .907 .964 r
.38112 .34749 .38828 .34887 .39971 .34481 .3926 .34335 Mtetra
.559 .911 .966 r
.3926 .34335 .39971 .34481 .41118 .34066 .40413 .33905 Mtetra
.575 .915 .97 r
.40413 .33905 .41118 .34066 .42271 .33642 .41571 .33461 Mtetra
.592 .917 .973 r
.41571 .33461 .42271 .33642 .43429 .33207 .42735 .33001 Mtetra
.61 .918 .976 r
.42735 .33001 .43429 .33207 .44591 .32762 .43904 .32526 Mtetra
.629 .917 .979 r
.43904 .32526 .44591 .32762 .45759 .32306 .45077 .32034 Mtetra
.647 .914 .98 r
.45077 .32034 .45759 .32306 .46931 .31839 .46255 .31527 Mtetra
.664 .907 .979 r
.46255 .31527 .46931 .31839 .48108 .3136 .47438 .31003 Mtetra
.679 .899 .975 r
.47438 .31003 .48108 .3136 .4929 .30868 .48626 .30463 Mtetra
.692 .887 .97 r
.48626 .30463 .4929 .30868 .50476 .30362 .49817 .29907 Mtetra
.703 .874 .962 r
.49817 .29907 .50476 .30362 .51667 .29843 .51013 .29334 Mtetra
.711 .859 .952 r
.51013 .29334 .51667 .29843 .52863 .29309 .52213 .28745 Mtetra
.718 .844 .942 r
.52213 .28745 .52863 .29309 .54062 .28759 .53417 .28139 Mtetra
.722 .827 .93 r
.53417 .28139 .54062 .28759 .55266 .28193 .54625 .27517 Mtetra
.725 .812 .918 r
.54625 .27517 .55266 .28193 .56473 .2761 .55836 .26879 Mtetra
.727 .796 .907 r
.55836 .26879 .56473 .2761 .57685 .2701 .57051 .26225 Mtetra
.728 .782 .895 r
.57051 .26225 .57685 .2701 .589 .26392 .58269 .25557 Mtetra
.729 .769 .885 r
.58269 .25557 .589 .26392 .60118 .25756 .5949 .24875 Mtetra
.729 .758 .876 r
.5949 .24875 .60118 .25756 .6134 .25102 .60715 .24179 Mtetra
.728 .748 .868 r
.60715 .24179 .6134 .25102 .62565 .24428 .61942 .2347 Mtetra
.728 .74 .861 r
.61942 .2347 .62565 .24428 .63792 .23737 .63172 .22752 Mtetra
.728 .735 .856 r
.63172 .22752 .63792 .23737 .65023 .23028 .64406 .22024 Mtetra
.727 .731 .853 r
.64406 .22024 .65023 .23028 .66256 .22303 .65642 .21292 Mtetra
.727 .73 .853 r
.65642 .21292 .66256 .22303 .67491 .21566 .66881 .20559 Mtetra
.726 .731 .855 r
.66881 .20559 .67491 .21566 .6873 .2082 .68124 .19828 Mtetra
.726 .736 .859 r
.68124 .19828 .6873 .2082 .69971 .20069 .69371 .19104 Mtetra
.726 .743 .865 r
.69371 .19104 .69971 .20069 .71215 .19315 .70621 .18386 Mtetra
.727 .754 .873 r
.70621 .18386 .71215 .19315 .72462 .18562 .71876 .17674 Mtetra
.729 .766 .883 r
.71876 .17674 .72462 .18562 .73713 .1781 .73134 .16968 Mtetra
.606 .738 .938 r
.05808 .40196 .06568 .40859 .07533 .40738 .06794 .39945 Mtetra
.606 .698 .909 r
.06794 .39945 .07533 .40738 .08503 .40624 .07782 .39699 Mtetra
.603 .662 .88 r
.07782 .39699 .08503 .40624 .09477 .40517 .08775 .3946 Mtetra
.598 .629 .853 r
.08775 .3946 .09477 .40517 .10456 .40417 .09771 .39231 Mtetra
.592 .601 .83 r
.09771 .39231 .10456 .40417 .11439 .40325 .1077 .39012 Mtetra
.587 .576 .809 r
.1077 .39012 .11439 .40325 .12427 .40237 .11772 .38802 Mtetra
.582 .556 .79 r
.11772 .38802 .12427 .40237 .1342 .40149 .12779 .38599 Mtetra
.578 .539 .774 r
.12779 .38599 .1342 .40149 .1442 .40057 .13791 .38401 Mtetra
.576 .525 .761 r
.13791 .38401 .1442 .40057 .15426 .39959 .14807 .38204 Mtetra
.574 .513 .749 r
.14807 .38204 .15426 .39959 .16439 .39851 .15828 .38006 Mtetra
.573 .504 .74 r
.15828 .38006 .16439 .39851 .17459 .39733 .16855 .37805 Mtetra
.572 .496 .731 r
.16855 .37805 .17459 .39733 .18486 .39603 .17888 .37601 Mtetra
.571 .49 .725 r
.17888 .37601 .18486 .39603 .1952 .3946 .18926 .37391 Mtetra
.571 .485 .719 r
.18926 .37391 .1952 .3946 .20561 .39303 .1997 .37175 Mtetra
.571 .481 .714 r
.1997 .37175 .20561 .39303 .21609 .39133 .2102 .36952 Mtetra
.572 .478 .71 r
.2102 .36952 .21609 .39133 .22663 .38948 .22076 .36721 Mtetra
.572 .476 .706 r
.22076 .36721 .22663 .38948 .23725 .38748 .23139 .36482 Mtetra
.573 .474 .703 r
.23139 .36482 .23725 .38748 .24793 .38533 .24207 .36232 Mtetra
.574 .473 .701 r
.24207 .36232 .24793 .38533 .25869 .38302 .25281 .35973 Mtetra
.576 .472 .699 r
.25281 .35973 .25869 .38302 .26951 .38056 .26362 .35702 Mtetra
.577 .472 .697 r
.26362 .35702 .26951 .38056 .28039 .37795 .27449 .3542 Mtetra
.579 .472 .696 r
.27449 .3542 .28039 .37795 .29134 .37517 .28542 .35126 Mtetra
.58 .472 .695 r
.28542 .35126 .29134 .37517 .30235 .37224 .2964 .34819 Mtetra
.582 .473 .694 r
.2964 .34819 .30235 .37224 .31342 .36916 .30745 .34499 Mtetra
.584 .474 .694 r
.30745 .34499 .31342 .36916 .32456 .36593 .31856 .34166 Mtetra
.586 .474 .693 r
.31856 .34166 .32456 .36593 .33576 .36254 .32973 .33819 Mtetra
.588 .476 .693 r
.32973 .33819 .33576 .36254 .34701 .359 .34095 .33458 Mtetra
.59 .477 .693 r
.34095 .33458 .34701 .359 .35832 .35531 .35224 .33083 Mtetra
.592 .478 .692 r
.35224 .33083 .35832 .35531 .36969 .35148 .36358 .32694 Mtetra
.594 .479 .692 r
.36358 .32694 .36969 .35148 .38112 .34749 .37497 .32291 Mtetra
.596 .48 .692 r
.37497 .32291 .38112 .34749 .3926 .34335 .38642 .31873 Mtetra
.598 .482 .692 r
.38642 .31873 .3926 .34335 .40413 .33905 .39792 .3144 Mtetra
.6 .483 .692 r
.39792 .3144 .40413 .33905 .41571 .33461 .40948 .30994 Mtetra
.602 .484 .692 r
.40948 .30994 .41571 .33461 .42735 .33001 .42108 .30533 Mtetra
.603 .486 .692 r
.42108 .30533 .42735 .33001 .43904 .32526 .43274 .30058 Mtetra
.605 .487 .692 r
.43274 .30058 .43904 .32526 .45077 .32034 .44444 .29569 Mtetra
.607 .489 .692 r
.44444 .29569 .45077 .32034 .46255 .31527 .45619 .29066 Mtetra
.609 .49 .692 r
.45619 .29066 .46255 .31527 .47438 .31003 .46799 .28551 Mtetra
.611 .492 .693 r
.46799 .28551 .47438 .31003 .48626 .30463 .47984 .28022 Mtetra
.613 .494 .694 r
.47984 .28022 .48626 .30463 .49817 .29907 .49172 .27482 Mtetra
.615 .497 .695 r
.49172 .27482 .49817 .29907 .51013 .29334 .50365 .26929 Mtetra
.617 .5 .696 r
.50365 .26929 .51013 .29334 .52213 .28745 .51563 .26365 Mtetra
.62 .503 .698 r
.51563 .26365 .52213 .28745 .53417 .28139 .52764 .25791 Mtetra
.622 .506 .701 r
.52764 .25791 .53417 .28139 .54625 .27517 .5397 .25207 Mtetra
.625 .511 .703 r
.5397 .25207 .54625 .27517 .55836 .26879 .5518 .24614 Mtetra
.627 .515 .707 r
.5518 .24614 .55836 .26879 .57051 .26225 .56393 .24013 Mtetra
.63 .521 .711 r
.56393 .24013 .57051 .26225 .58269 .25557 .57611 .23405 Mtetra
.634 .528 .716 r
.57611 .23405 .58269 .25557 .5949 .24875 .58832 .22791 Mtetra
.637 .535 .722 r
.58832 .22791 .5949 .24875 .60715 .24179 .60058 .22172 Mtetra
.641 .544 .729 r
.60058 .22172 .60715 .24179 .61942 .2347 .61287 .21549 Mtetra
.645 .554 .737 r
.61287 .21549 .61942 .2347 .63172 .22752 .6252 .20924 Mtetra
.65 .566 .747 r
.6252 .20924 .63172 .22752 .64406 .22024 .63758 .203 Mtetra
.654 .58 .759 r
.63758 .203 .64406 .22024 .65642 .21292 .64999 .19679 Mtetra
.659 .596 .773 r
.64999 .19679 .65642 .21292 .66881 .20559 .66245 .19064 Mtetra
.664 .615 .789 r
.66245 .19064 .66881 .20559 .68124 .19828 .67496 .18458 Mtetra
.67 .637 .809 r
.67496 .18458 .68124 .19828 .69371 .19104 .68752 .17862 Mtetra
.675 .663 .83 r
.68752 .17862 .69371 .19104 .70621 .18386 .70013 .17275 Mtetra
.682 .693 .855 r
.70013 .17275 .70621 .18386 .71876 .17674 .71279 .16694 Mtetra
.687 .728 .881 r
.71279 .16694 .71876 .17674 .73134 .16968 .7255 .16118 Mtetra
.675 .756 .912 r
.05043 .39529 .05808 .40196 .06794 .39945 .06053 .39116 Mtetra
.667 .709 .879 r
.06053 .39116 .06794 .39945 .07782 .39699 .07066 .38708 Mtetra
.657 .667 .848 r
.07066 .38708 .07782 .39699 .08775 .3946 .08082 .38306 Mtetra
.646 .631 .821 r
.08082 .38306 .08775 .3946 .09771 .39231 .091 .37911 Mtetra
.635 .599 .796 r
.091 .37911 .09771 .39231 .1077 .39012 .1012 .37528 Mtetra
.624 .571 .774 r
.1012 .37528 .1077 .39012 .11772 .38802 .11143 .37156 Mtetra
.615 .547 .755 r
.11143 .37156 .11772 .38802 .12779 .38599 .12169 .36796 Mtetra
.607 .527 .738 r
.12169 .36796 .12779 .38599 .13791 .38401 .13197 .36445 Mtetra
.6 .509 .724 r
.13197 .36445 .13791 .38401 .14807 .38204 .14228 .36102 Mtetra
.594 .495 .711 r
.14228 .36102 .14807 .38204 .15828 .38006 .15263 .35765 Mtetra
.589 .483 .701 r
.15263 .35765 .15828 .38006 .16855 .37805 .16302 .35433 Mtetra
.585 .472 .691 r
.16302 .35433 .16855 .37805 .17888 .37601 .17344 .35105 Mtetra
.581 .463 .683 r
.17344 .35105 .17888 .37601 .18926 .37391 .18391 .3478 Mtetra
.579 .456 .676 r
.18391 .3478 .18926 .37391 .1997 .37175 .19442 .34456 Mtetra
.576 .449 .67 r
.19442 .34456 .1997 .37175 .2102 .36952 .20497 .34134 Mtetra
.574 .444 .665 r
.20497 .34134 .2102 .36952 .22076 .36721 .21558 .33811 Mtetra
.572 .439 .661 r
.21558 .33811 .22076 .36721 .23139 .36482 .22623 .33488 Mtetra
.571 .435 .657 r
.22623 .33488 .23139 .36482 .24207 .36232 .23692 .33163 Mtetra
.57 .432 .653 r
.23692 .33163 .24207 .36232 .25281 .35973 .24767 .32834 Mtetra
.569 .429 .65 r
.24767 .32834 .25281 .35973 .26362 .35702 .25847 .32503 Mtetra
.569 .427 .648 r
.25847 .32503 .26362 .35702 .27449 .3542 .26932 .32166 Mtetra
.569 .425 .646 r
.26932 .32166 .27449 .3542 .28542 .35126 .28022 .31824 Mtetra
.569 .423 .644 r
.28022 .31824 .28542 .35126 .2964 .34819 .29118 .31475 Mtetra
.569 .422 .643 r
.29118 .31475 .2964 .34819 .30745 .34499 .30219 .3112 Mtetra
.569 .422 .641 r
.30219 .3112 .30745 .34499 .31856 .34166 .31325 .30756 Mtetra
.569 .421 .641 r
.31325 .30756 .31856 .34166 .32973 .33819 .32437 .30384 Mtetra
.57 .421 .64 r
.32437 .30384 .32973 .33819 .34095 .33458 .33554 .30003 Mtetra
.571 .421 .639 r
.33554 .30003 .34095 .33458 .35224 .33083 .34676 .29614 Mtetra
.34676 .29614 .35224 .33083 .36358 .32694 .35803 .29214 Mtetra
.572 .422 .639 r
.35803 .29214 .36358 .32694 .37497 .32291 .36936 .28805 Mtetra
.573 .423 .639 r
.36936 .28805 .37497 .32291 .38642 .31873 .38074 .28386 Mtetra
.574 .423 .639 r
.38074 .28386 .38642 .31873 .39792 .3144 .39217 .27958 Mtetra
.575 .424 .639 r
.39217 .27958 .39792 .3144 .40948 .30994 .40366 .27521 Mtetra
.576 .425 .64 r
.40366 .27521 .40948 .30994 .42108 .30533 .41519 .27074 Mtetra
.578 .427 .64 r
.41519 .27074 .42108 .30533 .43274 .30058 .42677 .26619 Mtetra
.579 .428 .641 r
.42677 .26619 .43274 .30058 .44444 .29569 .4384 .26155 Mtetra
.58 .43 .642 r
.4384 .26155 .44444 .29569 .45619 .29066 .45008 .25684 Mtetra
.581 .432 .644 r
.45008 .25684 .45619 .29066 .46799 .28551 .4618 .25207 Mtetra
.582 .434 .646 r
.4618 .25207 .46799 .28551 .47984 .28022 .47358 .24723 Mtetra
.584 .437 .648 r
.47358 .24723 .47984 .28022 .49172 .27482 .4854 .24234 Mtetra
.585 .44 .65 r
.4854 .24234 .49172 .27482 .50365 .26929 .49726 .23741 Mtetra
.587 .443 .653 r
.49726 .23741 .50365 .26929 .51563 .26365 .50918 .23245 Mtetra
.588 .446 .656 r
.50918 .23245 .51563 .26365 .52764 .25791 .52114 .22746 Mtetra
.59 .451 .66 r
.52114 .22746 .52764 .25791 .5397 .25207 .53315 .22246 Mtetra
.592 .455 .664 r
.53315 .22246 .5397 .25207 .5518 .24614 .5452 .21745 Mtetra
.594 .461 .669 r
.5452 .21745 .5518 .24614 .56393 .24013 .55731 .21245 Mtetra
.596 .467 .675 r
.55731 .21245 .56393 .24013 .57611 .23405 .56946 .20747 Mtetra
.598 .474 .682 r
.56946 .20747 .57611 .23405 .58832 .22791 .58166 .2025 Mtetra
.601 .482 .69 r
.58166 .2025 .58832 .22791 .60058 .22172 .59391 .19757 Mtetra
.604 .492 .699 r
.59391 .19757 .60058 .22172 .61287 .21549 .60622 .19268 Mtetra
.607 .503 .71 r
.60622 .19268 .61287 .21549 .6252 .20924 .61858 .18786 Mtetra
.61 .516 .722 r
.61858 .18786 .6252 .20924 .63758 .203 .63099 .18311 Mtetra
.614 .531 .737 r
.63099 .18311 .63758 .203 .64999 .19679 .64346 .17845 Mtetra
.617 .548 .754 r
.64346 .17845 .64999 .19679 .66245 .19064 .65599 .17392 Mtetra
.621 .569 .775 r
.65599 .17392 .66245 .19064 .67496 .18458 .66859 .16949 Mtetra
.625 .594 .798 r
.66859 .16949 .67496 .18458 .68752 .17862 .68125 .16517 Mtetra
.629 .623 .825 r
.68125 .16517 .68752 .17862 .70013 .17275 .69397 .16093 Mtetra
.634 .657 .856 r
.69397 .16093 .70013 .17275 .71279 .16694 .70676 .15675 Mtetra
.637 .697 .889 r
.70676 .15675 .71279 .16694 .7255 .16118 .71961 .15261 Mtetra
.718 .764 .889 r
.04273 .38856 .05043 .39529 .06053 .39116 .05304 .38309 Mtetra
.707 .726 .865 r
.05304 .38309 .06053 .39116 .07066 .38708 .06338 .37766 Mtetra
.696 .692 .842 r
.06338 .37766 .07066 .38708 .08082 .38306 .07374 .37229 Mtetra
.684 .661 .821 r
.07374 .37229 .08082 .38306 .091 .37911 .08411 .36701 Mtetra
.672 .633 .802 r
.08411 .36701 .091 .37911 .1012 .37528 .0945 .36185 Mtetra
.661 .609 .785 r
.0945 .36185 .1012 .37528 .11143 .37156 .1049 .3568 Mtetra
.651 .586 .769 r
.1049 .3568 .11143 .37156 .12169 .36796 .11532 .35187 Mtetra
.641 .566 .754 r
.11532 .35187 .12169 .36796 .13197 .36445 .12576 .34705 Mtetra
.633 .548 .741 r
.12576 .34705 .13197 .36445 .14228 .36102 .13622 .34234 Mtetra
.625 .532 .729 r
.13622 .34234 .14228 .36102 .15263 .35765 .1467 .33771 Mtetra
.619 .518 .718 r
.1467 .33771 .15263 .35765 .16302 .35433 .15721 .33316 Mtetra
.613 .506 .708 r
.15721 .33316 .16302 .35433 .17344 .35105 .16775 .32868 Mtetra
.607 .495 .699 r
.16775 .32868 .17344 .35105 .18391 .3478 .17831 .32426 Mtetra
.602 .485 .691 r
.17831 .32426 .18391 .3478 .19442 .34456 .18891 .3199 Mtetra
.598 .476 .684 r
.18891 .3199 .19442 .34456 .20497 .34134 .19954 .31559 Mtetra
.594 .468 .678 r
.19954 .31559 .20497 .34134 .21558 .33811 .21021 .31133 Mtetra
.591 .461 .672 r
.21021 .31133 .21558 .33811 .22623 .33488 .22091 .30711 Mtetra
.588 .454 .667 r
.22091 .30711 .22623 .33488 .23692 .33163 .23165 .30292 Mtetra
.585 .449 .662 r
.23165 .30292 .23692 .33163 .24767 .32834 .24243 .29877 Mtetra
.583 .444 .658 r
.24243 .29877 .24767 .32834 .25847 .32503 .25324 .29463 Mtetra
.581 .44 .654 r
.25324 .29463 .25847 .32503 .26932 .32166 .2641 .29052 Mtetra
.579 .436 .651 r
.2641 .29052 .26932 .32166 .28022 .31824 .275 .28641 Mtetra
.577 .433 .648 r
.275 .28641 .28022 .31824 .29118 .31475 .28594 .28231 Mtetra
.576 .43 .646 r
.28594 .28231 .29118 .31475 .30219 .3112 .29693 .27822 Mtetra
.575 .427 .644 r
.29693 .27822 .30219 .3112 .31325 .30756 .30796 .27412 Mtetra
.574 .426 .642 r
.30796 .27412 .31325 .30756 .32437 .30384 .31904 .27002 Mtetra
.573 .424 .641 r
.31904 .27002 .32437 .30384 .33554 .30003 .33016 .26591 Mtetra
.573 .423 .64 r
.33016 .26591 .33554 .30003 .34676 .29614 .34133 .26179 Mtetra
.573 .422 .639 r
.34133 .26179 .34676 .29614 .35803 .29214 .35255 .25766 Mtetra
.572 .422 .639 r
.35255 .25766 .35803 .29214 .36936 .28805 .36381 .25352 Mtetra
.36381 .25352 .36936 .28805 .38074 .28386 .37512 .24936 Mtetra
.37512 .24936 .38074 .28386 .39217 .27958 .38648 .2452 Mtetra
.573 .423 .64 r
.38648 .2452 .39217 .27958 .40366 .27521 .39788 .24102 Mtetra
.573 .424 .641 r
.39788 .24102 .40366 .27521 .41519 .27074 .40934 .23683 Mtetra
.573 .425 .642 r
.40934 .23683 .41519 .27074 .42677 .26619 .42084 .23263 Mtetra
.574 .427 .644 r
.42084 .23263 .42677 .26619 .4384 .26155 .43239 .22844 Mtetra
.574 .429 .646 r
.43239 .22844 .4384 .26155 .45008 .25684 .44399 .22424 Mtetra
.575 .431 .648 r
.44399 .22424 .45008 .25684 .4618 .25207 .45564 .22006 Mtetra
.576 .434 .651 r
.45564 .22006 .4618 .25207 .47358 .24723 .46735 .21588 Mtetra
.577 .437 .654 r
.46735 .21588 .47358 .24723 .4854 .24234 .4791 .21172 Mtetra
.578 .441 .658 r
.4791 .21172 .4854 .24234 .49726 .23741 .4909 .20758 Mtetra
.579 .445 .662 r
.4909 .20758 .49726 .23741 .50918 .23245 .50276 .20347 Mtetra
.58 .449 .667 r
.50276 .20347 .50918 .23245 .52114 .22746 .51467 .19939 Mtetra
.581 .455 .672 r
.51467 .19939 .52114 .22746 .53315 .22246 .52664 .19535 Mtetra
.583 .46 .679 r
.52664 .19535 .53315 .22246 .5452 .21745 .53866 .19136 Mtetra
.584 .467 .685 r
.53866 .19136 .5452 .21745 .55731 .21245 .55073 .18742 Mtetra
.586 .474 .693 r
.55073 .18742 .55731 .21245 .56946 .20747 .56287 .18354 Mtetra
.587 .482 .702 r
.56287 .18354 .56946 .20747 .58166 .2025 .57506 .17972 Mtetra
.589 .491 .711 r
.57506 .17972 .58166 .2025 .59391 .19757 .58732 .17597 Mtetra
.59 .501 .722 r
.58732 .17597 .59391 .19757 .60622 .19268 .59963 .1723 Mtetra
.592 .513 .734 r
.59963 .1723 .60622 .19268 .61858 .18786 .61202 .16872 Mtetra
.593 .526 .748 r
.61202 .16872 .61858 .18786 .63099 .18311 .62447 .16524 Mtetra
.594 .54 .764 r
.62447 .16524 .63099 .18311 .64346 .17845 .63699 .16188 Mtetra
.595 .556 .781 r
.63699 .16188 .64346 .17845 .65599 .17392 .64958 .15864 Mtetra
.595 .575 .801 r
.64958 .15864 .65599 .17392 .66859 .16949 .66224 .15552 Mtetra
.595 .596 .823 r
.66224 .15552 .66859 .16949 .68125 .16517 .67498 .15252 Mtetra
.594 .621 .848 r
.67498 .15252 .68125 .16517 .69397 .16093 .6878 .14961 Mtetra
.593 .65 .875 r
.6878 .14961 .69397 .16093 .70676 .15675 .7007 .14677 Mtetra
.589 .682 .905 r
.7007 .14677 .70676 .15675 .71961 .15261 .71368 .14397 Mtetra
.745 .767 .871 r
.03496 .38178 .04273 .38856 .05304 .38309 .04547 .37522 Mtetra
.735 .738 .854 r
.04547 .37522 .05304 .38309 .06338 .37766 .05598 .36871 Mtetra
.724 .711 .838 r
.05598 .36871 .06338 .37766 .07374 .37229 .06651 .36227 Mtetra
.713 .686 .823 r
.06651 .36227 .07374 .37229 .08411 .36701 .07705 .35593 Mtetra
.702 .663 .809 r
.07705 .35593 .08411 .36701 .0945 .36185 .08759 .34971 Mtetra
.692 .642 .795 r
.08759 .34971 .0945 .36185 .1049 .3568 .09814 .3436 Mtetra
.682 .622 .783 r
.09814 .3436 .1049 .3568 .11532 .35187 .1087 .33761 Mtetra
.673 .604 .77 r
.1087 .33761 .11532 .35187 .12576 .34705 .11928 .33173 Mtetra
.664 .587 .759 r
.11928 .33173 .12576 .34705 .13622 .34234 .12987 .32595 Mtetra
.656 .571 .748 r
.12987 .32595 .13622 .34234 .1467 .33771 .14047 .32026 Mtetra
.648 .557 .738 r
.14047 .32026 .1467 .33771 .15721 .33316 .15109 .31467 Mtetra
.641 .544 .729 r
.15109 .31467 .15721 .33316 .16775 .32868 .16174 .30916 Mtetra
.635 .532 .72 r
.16174 .30916 .16775 .32868 .17831 .32426 .1724 .30373 Mtetra
.629 .521 .712 r
.1724 .30373 .17831 .32426 .18891 .3199 .18309 .29838 Mtetra
.623 .511 .704 r
.18309 .29838 .18891 .3199 .19954 .31559 .1938 .2931 Mtetra
.618 .501 .698 r
.1938 .2931 .19954 .31559 .21021 .31133 .20453 .28791 Mtetra
.614 .493 .691 r
.20453 .28791 .21021 .31133 .22091 .30711 .21529 .28279 Mtetra
.609 .485 .686 r
.21529 .28279 .22091 .30711 .23165 .30292 .22608 .27775 Mtetra
.605 .478 .681 r
.22608 .27775 .23165 .30292 .24243 .29877 .2369 .27278 Mtetra
.602 .472 .676 r
.2369 .27278 .24243 .29877 .25324 .29463 .24775 .26788 Mtetra
.598 .466 .672 r
.24775 .26788 .25324 .29463 .2641 .29052 .25862 .26306 Mtetra
.595 .461 .668 r
.25862 .26306 .2641 .29052 .275 .28641 .26953 .2583 Mtetra
.592 .456 .665 r
.26953 .2583 .275 .28641 .28594 .28231 .28048 .25362 Mtetra
.59 .452 .662 r
.28048 .25362 .28594 .28231 .29693 .27822 .29146 .24901 Mtetra
.587 .449 .66 r
.29146 .24901 .29693 .27822 .30796 .27412 .30247 .24447 Mtetra
.585 .446 .658 r
.30247 .24447 .30796 .27412 .31904 .27002 .31352 .24 Mtetra
.583 .443 .656 r
.31352 .24 .31904 .27002 .33016 .26591 .32461 .2356 Mtetra
.582 .441 .655 r
.32461 .2356 .33016 .26591 .34133 .26179 .33574 .23127 Mtetra
.58 .439 .654 r
.33574 .23127 .34133 .26179 .35255 .25766 .3469 .22701 Mtetra
.579 .438 .654 r
.3469 .22701 .35255 .25766 .36381 .25352 .35811 .22282 Mtetra
.578 .437 .654 r
.35811 .22282 .36381 .25352 .37512 .24936 .36937 .21869 Mtetra
.577 .437 .654 r
.36937 .21869 .37512 .24936 .38648 .2452 .38066 .21464 Mtetra
.576 .437 .655 r
.38066 .21464 .38648 .2452 .39788 .24102 .39201 .21065 Mtetra
.575 .438 .657 r
.39201 .21065 .39788 .24102 .40934 .23683 .4034 .20674 Mtetra
.575 .439 .658 r
.4034 .20674 .40934 .23683 .42084 .23263 .41483 .20289 Mtetra
.574 .44 .66 r
.41483 .20289 .42084 .23263 .43239 .22844 .42632 .19912 Mtetra
.574 .442 .663 r
.42632 .19912 .43239 .22844 .44399 .22424 .43785 .19542 Mtetra
.574 .444 .666 r
.43785 .19542 .44399 .22424 .45564 .22006 .44944 .19179 Mtetra
.574 .447 .669 r
.44944 .19179 .45564 .22006 .46735 .21588 .46109 .18823 Mtetra
.574 .45 .673 r
.46109 .18823 .46735 .21588 .4791 .21172 .47278 .18475 Mtetra
.574 .454 .678 r
.47278 .18475 .4791 .21172 .4909 .20758 .48454 .18134 Mtetra
.574 .458 .683 r
.48454 .18134 .4909 .20758 .50276 .20347 .49635 .17801 Mtetra
.574 .463 .689 r
.49635 .17801 .50276 .20347 .51467 .19939 .50822 .17476 Mtetra
.574 .468 .695 r
.50822 .17476 .51467 .19939 .52664 .19535 .52015 .17159 Mtetra
.575 .474 .702 r
.52015 .17159 .52664 .19535 .53866 .19136 .53214 .16849 Mtetra
.575 .481 .71 r
.53214 .16849 .53866 .19136 .55073 .18742 .5442 .16548 Mtetra
.576 .488 .719 r
.5442 .16548 .55073 .18742 .56287 .18354 .55632 .16254 Mtetra
.576 .497 .728 r
.55632 .16254 .56287 .18354 .57506 .17972 .56851 .1597 Mtetra
.576 .506 .739 r
.56851 .1597 .57506 .17972 .58732 .17597 .58077 .15694 Mtetra
.576 .516 .751 r
.58077 .15694 .58732 .17597 .59963 .1723 .59311 .15428 Mtetra
.576 .527 .763 r
.59311 .15428 .59963 .1723 .61202 .16872 .60551 .15171 Mtetra
.575 .539 .778 r
.60551 .15171 .61202 .16872 .62447 .16524 .61799 .14926 Mtetra
.574 .553 .793 r
.61799 .14926 .62447 .16524 .63699 .16188 .63055 .14692 Mtetra
.572 .567 .81 r
.63055 .14692 .63699 .16188 .64958 .15864 .64319 .1447 Mtetra
.569 .583 .828 r
.64319 .1447 .64958 .15864 .66224 .15552 .65592 .14261 Mtetra
.564 .601 .848 r
.65592 .14261 .66224 .15552 .67498 .15252 .66873 .14063 Mtetra
.559 .62 .87 r
.66873 .14063 .67498 .15252 .6878 .14961 .68163 .13877 Mtetra
.553 .642 .893 r
.68163 .13877 .6878 .14961 .7007 .14677 .69461 .13698 Mtetra
.545 .667 .917 r
.69461 .13698 .7007 .14677 .71368 .14397 .70769 .13525 Mtetra
.761 .768 .859 r
.02714 .37496 .03496 .38178 .04547 .37522 .03779 .36764 Mtetra
.752 .749 .849 r
.03779 .36764 .04547 .37522 .05598 .36871 .04843 .3604 Mtetra
.744 .731 .84 r
.04843 .3604 .05598 .36871 .06651 .36227 .05909 .35326 Mtetra
.736 .714 .831 r
.05909 .35326 .06651 .36227 .07705 .35593 .06974 .34622 Mtetra
.727 .698 .823 r
.06974 .34622 .07705 .35593 .08759 .34971 .0804 .33931 Mtetra
.719 .683 .814 r
.0804 .33931 .08759 .34971 .09814 .3436 .09106 .3325 Mtetra
.711 .668 .806 r
.09106 .3325 .09814 .3436 .1087 .33761 .10173 .32581 Mtetra
.704 .654 .798 r
.10173 .32581 .1087 .33761 .11928 .33173 .11241 .31922 Mtetra
.696 .64 .79 r
.11241 .31922 .11928 .33173 .12987 .32595 .1231 .31273 Mtetra
.689 .627 .782 r
.1231 .31273 .12987 .32595 .14047 .32026 .13379 .30635 Mtetra
.682 .615 .774 r
.13379 .30635 .14047 .32026 .15109 .31467 .1445 .30006 Mtetra
.675 .603 .767 r
.1445 .30006 .15109 .31467 .16174 .30916 .15523 .29387 Mtetra
.669 .592 .76 r
.15523 .29387 .16174 .30916 .1724 .30373 .16597 .28778 Mtetra
.663 .582 .753 r
.16597 .28778 .1724 .30373 .18309 .29838 .17672 .28178 Mtetra
.657 .572 .747 r
.17672 .28178 .18309 .29838 .1938 .2931 .1875 .27588 Mtetra
.652 .563 .742 r
.1875 .27588 .1938 .2931 .20453 .28791 .19829 .27008 Mtetra
.647 .554 .736 r
.19829 .27008 .20453 .28791 .21529 .28279 .2091 .26437 Mtetra
.642 .546 .731 r
.2091 .26437 .21529 .28279 .22608 .27775 .21993 .25877 Mtetra
.637 .539 .727 r
.21993 .25877 .22608 .27775 .2369 .27278 .23079 .25328 Mtetra
.633 .532 .723 r
.23079 .25328 .2369 .27278 .24775 .26788 .24166 .24789 Mtetra
.628 .526 .719 r
.24166 .24789 .24775 .26788 .25862 .26306 .25257 .2426 Mtetra
.624 .52 .716 r
.25257 .2426 .25862 .26306 .26953 .2583 .26349 .23743 Mtetra
.621 .515 .713 r
.26349 .23743 .26953 .2583 .28048 .25362 .27445 .23237 Mtetra
.617 .51 .71 r
.27445 .23237 .28048 .25362 .29146 .24901 .28543 .22743 Mtetra
.613 .506 .708 r
.28543 .22743 .29146 .24901 .30247 .24447 .29644 .22259 Mtetra
.61 .502 .706 r
.29644 .22259 .30247 .24447 .31352 .24 .30749 .21788 Mtetra
.607 .499 .705 r
.30749 .21788 .31352 .24 .32461 .2356 .31857 .21328 Mtetra
.604 .496 .704 r
.31857 .21328 .32461 .2356 .33574 .23127 .32968 .20881 Mtetra
.602 .494 .703 r
.32968 .20881 .33574 .23127 .3469 .22701 .34082 .20445 Mtetra
.599 .492 .703 r
.34082 .20445 .3469 .22701 .35811 .22282 .35201 .20021 Mtetra
.597 .49 .703 r
.35201 .20021 .35811 .22282 .36937 .21869 .36324 .1961 Mtetra
.595 .489 .704 r
.36324 .1961 .36937 .21869 .38066 .21464 .3745 .1921 Mtetra
.592 .489 .705 r
.3745 .1921 .38066 .21464 .39201 .21065 .38581 .18823 Mtetra
.59 .489 .707 r
.38581 .18823 .39201 .21065 .4034 .20674 .39717 .18447 Mtetra
.589 .489 .709 r
.39717 .18447 .4034 .20674 .41483 .20289 .40857 .18083 Mtetra
.587 .49 .711 r
.40857 .18083 .41483 .20289 .42632 .19912 .42003 .17731 Mtetra
.585 .491 .714 r
.42003 .17731 .42632 .19912 .43785 .19542 .43153 .17391 Mtetra
.584 .493 .717 r
.43153 .17391 .43785 .19542 .44944 .19179 .44309 .17062 Mtetra
.582 .495 .721 r
.44309 .17062 .44944 .19179 .46109 .18823 .4547 .16744 Mtetra
.581 .498 .726 r
.4547 .16744 .46109 .18823 .47278 .18475 .46637 .16438 Mtetra
.58 .501 .73 r
.46637 .16438 .47278 .18475 .48454 .18134 .4781 .16142 Mtetra
.578 .505 .736 r
.4781 .16142 .48454 .18134 .49635 .17801 .48988 .15857 Mtetra
.577 .509 .742 r
.48988 .15857 .49635 .17801 .50822 .17476 .50174 .15583 Mtetra
.576 .514 .748 r
.50174 .15583 .50822 .17476 .52015 .17159 .51365 .1532 Mtetra
.574 .519 .756 r
.51365 .1532 .52015 .17159 .53214 .16849 .52564 .15066 Mtetra
.573 .525 .763 r
.52564 .15066 .53214 .16849 .5442 .16548 .53769 .14823 Mtetra
.572 .532 .772 r
.53769 .14823 .5442 .16548 .55632 .16254 .54981 .1459 Mtetra
.57 .539 .781 r
.54981 .1459 .55632 .16254 .56851 .1597 .56201 .14367 Mtetra
.568 .547 .791 r
.56201 .14367 .56851 .1597 .58077 .15694 .57428 .14155 Mtetra
.566 .555 .801 r
.57428 .14155 .58077 .15694 .59311 .15428 .58663 .13952 Mtetra
.563 .564 .813 r
.58663 .13952 .59311 .15428 .60551 .15171 .59906 .13761 Mtetra
.56 .574 .825 r
.59906 .13761 .60551 .15171 .61799 .14926 .61157 .13581 Mtetra
.556 .584 .838 r
.61157 .13581 .61799 .14926 .63055 .14692 .62417 .13412 Mtetra
.551 .595 .852 r
.62417 .13412 .63055 .14692 .64319 .1447 .63685 .13255 Mtetra
.545 .606 .866 r
.63685 .13255 .64319 .1447 .65592 .14261 .64962 .1311 Mtetra
.537 .618 .88 r
.64962 .1311 .65592 .14261 .66873 .14063 .66249 .12978 Mtetra
.529 .63 .895 r
.66249 .12978 .66873 .14063 .68163 .13877 .67544 .12857 Mtetra
.52 .644 .911 r
.67544 .12857 .68163 .13877 .69461 .13698 .6885 .12747 Mtetra
.509 .658 .927 r
.6885 .12747 .69461 .13698 .70769 .13525 .70165 .12647 Mtetra
.766 .768 .855 r
.01926 .36808 .02714 .37496 .03779 .36764 .02998 .36045 Mtetra
.761 .761 .852 r
.02998 .36045 .03779 .36764 .04843 .3604 .0407 .35294 Mtetra
.756 .754 .851 r
.0407 .35294 .04843 .3604 .05909 .35326 .05141 .34555 Mtetra
.752 .748 .849 r
.05141 .34555 .05909 .35326 .06974 .34622 .06213 .33828 Mtetra
.747 .743 .848 r
.06213 .33828 .06974 .34622 .0804 .33931 .07285 .33113 Mtetra
.743 .737 .847 r
.07285 .33113 .0804 .33931 .09106 .3325 .08356 .3241 Mtetra
.738 .732 .845 r
.08356 .3241 .09106 .3325 .10173 .32581 .09428 .31718 Mtetra
.734 .727 .844 r
.09428 .31718 .10173 .32581 .11241 .31922 .10501 .31039 Mtetra
.729 .722 .843 r
.10501 .31039 .11241 .31922 .1231 .31273 .11574 .30371 Mtetra
.725 .717 .842 r
.11574 .30371 .1231 .31273 .13379 .30635 .12649 .29715 Mtetra
.721 .713 .842 r
.12649 .29715 .13379 .30635 .1445 .30006 .13724 .29071 Mtetra
.717 .709 .841 r
.13724 .29071 .1445 .30006 .15523 .29387 .148 .28438 Mtetra
.713 .705 .841 r
.148 .28438 .15523 .29387 .16597 .28778 .15877 .27817 Mtetra
.709 .702 .841 r
.15877 .27817 .16597 .28778 .17672 .28178 .16956 .27207 Mtetra
.706 .7 .842 r
.16956 .27207 .17672 .28178 .1875 .27588 .18036 .26609 Mtetra
.702 .698 .842 r
.18036 .26609 .1875 .27588 .19829 .27008 .19117 .26022 Mtetra
.699 .696 .843 r
.19117 .26022 .19829 .27008 .2091 .26437 .20201 .25447 Mtetra
.695 .694 .845 r
.20201 .25447 .2091 .26437 .21993 .25877 .21286 .24883 Mtetra
.692 .693 .846 r
.21286 .24883 .21993 .25877 .23079 .25328 .22374 .24331 Mtetra
.689 .692 .848 r
.22374 .24331 .23079 .25328 .24166 .24789 .23464 .2379 Mtetra
.685 .691 .85 r
.23464 .2379 .24166 .24789 .25257 .2426 .24556 .2326 Mtetra
.682 .69 .851 r
.24556 .2326 .25257 .2426 .26349 .23743 .2565 .22742 Mtetra
.679 .69 .853 r
.2565 .22742 .26349 .23743 .27445 .23237 .26748 .22235 Mtetra
.675 .689 .855 r
.26748 .22235 .27445 .23237 .28543 .22743 .27848 .2174 Mtetra
.671 .688 .857 r
.27848 .2174 .28543 .22743 .29644 .22259 .28951 .21256 Mtetra
.668 .687 .859 r
.28951 .21256 .29644 .22259 .30749 .21788 .30058 .20783 Mtetra
.664 .687 .861 r
.30058 .20783 .30749 .21788 .31857 .21328 .31167 .20322 Mtetra
.66 .685 .863 r
.31167 .20322 .31857 .21328 .32968 .20881 .3228 .19872 Mtetra
.656 .684 .865 r
.3228 .19872 .32968 .20881 .34082 .20445 .33397 .19434 Mtetra
.652 .683 .866 r
.33397 .19434 .34082 .20445 .35201 .20021 .34518 .19007 Mtetra
.648 .681 .867 r
.34518 .19007 .35201 .20021 .36324 .1961 .35643 .18591 Mtetra
.644 .679 .869 r
.35643 .18591 .36324 .1961 .3745 .1921 .36771 .18187 Mtetra
.64 .677 .87 r
.36771 .18187 .3745 .1921 .38581 .18823 .37905 .17794 Mtetra
.635 .675 .871 r
.37905 .17794 .38581 .18823 .39717 .18447 .39042 .17412 Mtetra
.631 .673 .872 r
.39042 .17412 .39717 .18447 .40857 .18083 .40185 .17043 Mtetra
.627 .67 .872 r
.40185 .17043 .40857 .18083 .42003 .17731 .41332 .16684 Mtetra
.622 .668 .873 r
.41332 .16684 .42003 .17731 .43153 .17391 .42485 .16338 Mtetra
.618 .665 .874 r
.42485 .16338 .43153 .17391 .44309 .17062 .43642 .16003 Mtetra
.613 .662 .874 r
.43642 .16003 .44309 .17062 .4547 .16744 .44805 .15679 Mtetra
.608 .66 .875 r
.44805 .15679 .4547 .16744 .46637 .16438 .45974 .15368 Mtetra
.604 .657 .876 r
.45974 .15368 .46637 .16438 .4781 .16142 .47149 .15068 Mtetra
.599 .655 .876 r
.47149 .15068 .4781 .16142 .48988 .15857 .4833 .1478 Mtetra
.594 .653 .878 r
.4833 .1478 .48988 .15857 .50174 .15583 .49517 .14503 Mtetra
.589 .651 .879 r
.49517 .14503 .50174 .15583 .51365 .1532 .50711 .14239 Mtetra
.585 .65 .881 r
.50711 .14239 .51365 .1532 .52564 .15066 .51911 .13987 Mtetra
.58 .648 .882 r
.51911 .13987 .52564 .15066 .53769 .14823 .53118 .13746 Mtetra
.574 .648 .885 r
.53118 .13746 .53769 .14823 .54981 .1459 .54333 .13518 Mtetra
.569 .647 .888 r
.54333 .13518 .54981 .1459 .56201 .14367 .55555 .13302 Mtetra
.564 .647 .891 r
.55555 .13302 .56201 .14367 .57428 .14155 .56784 .13099 Mtetra
.558 .648 .894 r
.56784 .13099 .57428 .14155 .58663 .13952 .58022 .12908 Mtetra
.552 .648 .898 r
.58022 .12908 .58663 .13952 .59906 .13761 .59267 .12729 Mtetra
.546 .65 .902 r
.59267 .12729 .59906 .13761 .61157 .13581 .60521 .12563 Mtetra
.539 .651 .907 r
.60521 .12563 .61157 .13581 .62417 .13412 .61784 .12409 Mtetra
.532 .653 .912 r
.61784 .12409 .62417 .13412 .63685 .13255 .63055 .12269 Mtetra
.525 .654 .917 r
.63055 .12269 .63685 .13255 .64962 .1311 .64336 .12141 Mtetra
.517 .656 .922 r
.64336 .12141 .64962 .1311 .66249 .12978 .65626 .12026 Mtetra
.509 .658 .927 r
.65626 .12026 .66249 .12978 .67544 .12857 .66926 .11924 Mtetra
.5 .66 .932 r
.66926 .11924 .67544 .12857 .6885 .12747 .68236 .11836 Mtetra
.491 .662 .938 r
.68236 .11836 .6885 .12747 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Eooooo`;oQ:O/1On2Z>d4ognXkPCoOJW`00?o
0000ooooooooool05?ooool00ol0003oooooooooo`1Aooooo`00H?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo01gooooo0ol00002ooooo`03o`000?oo
oooooooo04_ooooo0_n8YnT4ohJWjPGoQ:O/1On2Z>d4ognXkP?oOJW`00?o0000ogfYl?ooool05Ooo
ool00ol0003oooooooooo`1@ooooo`00H?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Looooo`;o0000Boooool2oh^ViPCoRJKX1On8YnT4ohJWjPGoQ:O/1?n2Z>d5ognXkP;oOJW`00?o
0000oh:XkOooool05?ooool00ol0003oooooo`00001Aooooo`00H?ooool01Ol0003ooooooooooooo
oooo000000_ooooo00CoA4A4omgMgOoooooo00006_ooool3o`0004Gooooo0_n>YN@4ohfUi@GoRjKV
1?n9Y^P5ohRWj@CoQZOZ0_n4Yn`2ohVNh@CoQj7U1On5Y>T2oh:Xk@03o`000?n2Z>goPZS]01Kooooo
00?o0000ooooooooool0Coooool0063ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgM
gOmEEEGoooooo`0001Sooooo0_l00011ooooo`03oi6Uhon@YNCoT:GT00;oT:GT1On>YN@4ohfUi@Go
RjKV1?n9Y^P2ohRWj@;oSISJ1?n;Vmd5ohVNh@CoQj7U1On5Y>T00on2Z>go0000oh:Xk@02oh:XkAKo
oooo00?o0000ooooooooool0C_ooool0063ooooo00Go410@oooooooooooooooooa0@400<ooooo`03
ogMgMoo<c<co000001Gooooo0ol00002ooooo`03o`000?oooooooooo03[ooooo0_nBYN84oi6Uh`Co
T:GT1?n>YN@5ohfUi@;oRjKV0_n?T]<4ohjEePGoSISJ1?n;Vmd4ohVNh@GoQj7U1On5Y>T01?l0003o
PZS]oh^Zj_n;Z^XFooooo`03o`000?oooooooooo04kooooo001Pooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00oo^k^koA4A4o`00000Cooooo`;o0000?_ooool2oiBUh@GoTZGR0onAYN<5oi2U
i0CoSZGT0_n=YND2oi2@d0GoSi;C1?n>UMH4ohfHfPCoRi_M1On9W^42ohNQi@;oSikN1On=Y>@00ol0
003oRj[Zoh^ZjP02oh^ZjQKooooo00?o0000ooooooooool0COooool0063ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00oooooo0ol0000hooooo`;oUZKQ1?nEY^45oiBU
h@CoTZGR1?nAYN<2oi2Ui0;oTHc:1?n@S/d5oi2@d0CoSi;C1?n>UMH5ohfHfPCoRi_M0_n9W^42oi2I
f@GoSikN1?n=Y>@00ol0003oRj[Zoh^ZjP03oh^ZjQKooooo00?o0000ooooooooool0C?ooool008;o
oooo0_l0000hooooo`03oiRWh?nFY^7oUZKQ00?oUZKQ1?nEY^45oiBUh@CoTZGR0_nAYN<00onARLOo
THc:oi6<bP03oi6<bPCoT8k=1?n@T=04ohnBd`GoSYGF0_n=V=X2oi:Ac`CoTIGC1On@VMT4ohnNgPCo
SJCT00Co0000oh^Zj_n;Z^[oRj[Z0_nF[^LFooooo`03o`000?oooooooooo04cooooo001oooooo`?o
00000_ooool00ol0003oooooooooo`0aooooo`;oVJOP1?nHYn04oiJVh@GoUJKQ0_nDYN42oi:6``Co
TXS51?nARLL4oi6<bPCoT8k=1On@T=04ohnBd`;oSYGF0_nBSL/5oi:Ac`CoTIGC1?n@VMT5ohnNgP;o
SJCT00?oUjKOo`000?nF[^L01OnF[^LDooooo`?o0000COooool007cooooo0ol0000eooooo`;oVZSP
1OnIYn03oiRWh0GoUZKQ0_nEY^42oi:4`@GoTXK31?nBR<D4oi69a`?oTHc:1On@S/d2oi2@d0;oThK3
1?nCRLL5oi:=b`CoTY7?1?nAUM<5oi2If@;oSikN0_nHW]T3oiNVg`03o`000?nGY]ooUZkW00CoUZkW
5oooool00ol0003oooooooooo`1:ooooo`00N_ooool2o`0003Cooooo0_nKZ=l5oiZXh0CoVJOP1?nH
Yn02oiJVh@;oTh>o1OnBQ<44oi:6``CoTXS51?nARLL4oi6<bP;oT8k=0_nCQ<05oi>6``CoThW71?nB
SL/4oi:Ac`GoTIGC0_n@VMT2oiRHdPGoV9kI0onGY]l01?l0003oUjKOoiJ^ionF[^L3oj>bhaKooooo
00?o0000ooooooooool0B_ooool007Oooooo0ol0000cooooo`03oibYgonKZ=ooVjSO00?oVjSO1OnJ
Z>04oiVWh0;oV:OP00?oTh:moi>3_onCPkl00onCPkl4oi:4`@CoTXK31?nBR<D5oi69a`;oTHc:00?o
Th6moi>4`?nCQ<000onCQ<04oi>6``CoThW71?nBSL/5oi:Ac`;oTIGC0_nHTld5oiRHdPGoV9kI0_nG
Y]l00ol0003oXZSKoj>bh`05oj>bhaKooooo00?o0000ooooooooool0BOooool007Gooooo0_l00002
ooooo`03o`000?oooooooooo02gooooo0_nNZ]l4oibYg`GoVjSO0_nJZ>02oiB0^PCoTh6l1?nCP[d4
oi>3_`CoTXC11OnBQ/<4oi:8a@;oTHW70_nCOkX4oi>1_@CoThC01?nCQ/<4oi>9a`GoTXg;0_nBTLl2
oiR>a`GoV9?=1?nHV=84oiRNf@04oj6OdonRZ=_oXZSKo`0000;oXZSK1?nS/^<00on_^^7ooooooooo
o`0Eooooo`03o`000?oooooooooo04Sooooo001booooo`?o00001Oooool00ol0003oooooooooo`0X
ooooo`;oWj_O1OnNZ]l4oibYg`;oVjSO0_nDOkT4oiB0^PGoTh6l0onCP[d4oi>3_`GoTXC11?nBQ/<2
oi:8a@;oTgbh1OnCOkX3oi>1_@CoThC01OnCQ/<4oi>9a`;oTXg;0_nHR/<5oiR>a`CoV9?=1OnHV=80
0onHW]WoXIoCoj6Od`02oj6Od`03oj:Xfol0003oXZSK00;oXZSK00?oXk;SojnjhOn_^^400_n_^^4F
ooooo`03o`000?oooooooooo04Sooooo001`ooooo`;o0000<?ooool00onPZmooWj_Ooin[g`03oin[
g`GoWZ[O0_nLZMl00onDO[SoU7nioiAo^@02oiAo^@GoU82j1?nCPK`3oi>2_@GoTh>o1?nBQ<42oi:6
``;oTg^e1?nCO;P5oi=o^PCoTh6m1?nCQ<04oi>6``;oThW70_nGQ[l5oiR:``CoV8k71OnHTld2oiRH
dP;oWiS<1OnQWm<01OnRZ=_o0000oj:XfonRZ=_o[[7J00Ko[k[Q5_ooool00ol0003oooooooooo`17
ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00008?ooool3
o`0002oooooo00?oXJcOoj2[gonPZml00_nPZml5oin[g`;oWZ[O0_nEO[L3oiAn^0GoU7ni1?nDP;X4
oi>1_0CoTh:m1?nCPkl2oi:4`@;oTgVc1?nCNkD5oi=l^0CoTgnj1?nCPKd4oi>4`0;oThK30_nGPk/5
oiN6_`CoV8[31OnHS/L2oiRCc@;oWY761OnOV<`5oj6Od`03o`000?n^/M[o[[7J00;o[[7J1?n_^^40
0onja>;oooooooooo`0Cooooo`?o0000B?ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A401kooooo0_l00003ooooo`03o`000?oo
oooooooo02[ooooo1?nQ[=l3oj2[g`CoWj_O00?oUGffoiEn]onEO[L00_nEO[L4oiAn^0CoU7ni1?nD
P;X5oi>1_0?oTh:m0_nCPkl2oi9g/@CoTgVc1OnCNkD4oi=l^0GoTgnj1?nCPKd2oi>4`003oiN0^?nG
Pk_oUh>k00?oUh>k1?nGQ[l4oiR:``CoV8k700?oWHc1oijAa_nNTLH00onNTLH4oinHc0CoXIoC00?o
[:WDo`000?n^/MX01?n^/MX00on_^^7o^/CRok[4hP02ok[4hQKooooo00?o0000ooooooooool01_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0
:Oooool003Sooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^01cooooo
0ol0000_ooooo`;oXZcN1OnQ[=l4oj2[g`04oin[gonEOKKoUGffoiEm]PGoUGjg0onDO[P4oiAo^@Go
U82j1?nCPK`2oi>2_@03oi9f/?nBMk7oTWNa00;oTWNa1OnCNK<4oi=k]@CoTgbh1OnCOkX2oi>1_@;o
UWff1?nGP;P4oiN3^`CoUhJo1OnHR/<00onHS/OoWHc1oif<`@02oif<`@CoWY761OnOV<`01OnQWm?o
[:WDojbYe?n/ZMCo000000Co[[7J00?o^/7Ook[4h_nja>801?nja>8Fooooo`03o`000?oooooooooo
00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Z
ooooo`00>?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h06?ooool3
o`0002oooooo0_nS[Mh4oj:/gPGoXJcO0_nPZml00onFOKKoUGffoiEm]P03oiEm]PCoUGjg0onDO[P5
oiAo^@CoU82j0_nCPK`2oi9e[P?oTWJ`1OnBMk44oi=i/`CoTg^e1OnCO;P3oi=o^P03oiIk/onFOKKo
UWff00;oUWff1?nGP;P4oiN3^`GoUhJo0_nHR/<2oif7_0GoWHc11?nNTLH4oinHc003oj^Scon/ZMCo
[:WD00;o[:WD00Co0000ojjaf_n^/M[o[[7J0onj`Ml4ok[4hP;o_/WS5_ooool00ol0003ooooooooo
o`04ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0002_ooooo000hooooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Eooooo`?o0000;Oooool2ojB]gPGoXjgN
1?nR[=h2oj6/g`;oUWfe1?nFOKH4oiEm]PCoUGjg1?nDO[P4oiAo^@;oU82j0_nBM:d4oi9e[PCoTWJ`
1?nBMk44oi=i/`GoTg^e1?nCO;P01?nCOk[oUW^coiIk/onFNk<5oiIm]PCoUh2h1?nGPk/3oiN6_`03
oib4^?nMQkcoWHNl00?oWHNl1?nMS<45oijAaP03oinHc?n[XlooZj??00;oZj??0on/ZM@00ol0003o
[:WDojjafP05ok[1g`03ok[4h_nnbN?o_/WS00?o_/WS5Oooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0000/ooooo`00>?ooool01Ol@
413ooooooooooooooooo410@00oooooo00?o0000ooooooooool04Oooool3o`0000?ooooo00?o0000
ooooooooool09oooool00onU[]goY:gNojB]gP03ojB]gPGoXjgN0_nR[=h00onGOKCoUWfeoiIm]@02
oiIm]@CoUWff1?nEOKH5oiEn]`?oU7jh0_nDOkT2oi9c[0CoTWB]1OnBMJh3oi9f/0CoTWNa1OnCNK<4
oi=k]@;oTgbh0_nFNK45oiIk/`CoUWff1?nGP;P4oiN3^`04oiN6_onLQ;SoW8Bhoib4^0GoWHNl1OnM
S<43oijAaP03ojVMbOn[XlooZj??00?oZj??0on/ZM@00ol0003o^KkMok[1g`04ok[1g`03oko;i?nn
bN?o_/WS00?o_/WS00?o_/kVooooooooool05?ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000002oooool01?oMgMgoEEEEooooool0000/ooooo`00>?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Aooooo`;o0000;oooool3ojF^
g@GoY:gN0_nS[Mh5oiMm]0GoUWfe0onFOKH5oiEm]PCoUGjg0_nDO[P00onBLZ_oTW>/oi9c[002oi9c
[0GoTWB]1?nBMJh3oi9f/0GoTWNa1?nCNK<2oi=k]@;oUGN_1?nFNK45oiIk/`CoUWff1OnGP;P2oiN3
^`03oi^0]OnLQ;SoW8Bh00?oW8Bh1?nMQk`5oif<`@03oijAa_nYWLWoZIg900;oZIg91On[Xll00on/
ZMCo^KkMo`000002okVng@?o^/7O0onobn@3okk9h`?o_/kV5_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000/ooooo`00>?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00>ooooo`?o0000;_oo
ool2ojJ^g@GoYJkM0_nT[Mh2oiQm]0SoUgfd1?nFOKD4oiIm]PCoUGff0_nEO[L2oi9aZP?oTW:[1OnB
Lj`4oi9d[@CoTWF^0onBM[05oi9g/@;oTgVc0_nEMJd4oiEg[`GoUWVa1?nFNk<5oiIm]P?oUh2h00?o
VWfboi^0]OnKP;D00_nKP;D4oib4^0GoWHNl0onMS<400onXV<GoZIg9ojVMb@03ojVMb@CoZj??00Co
^KcKokVngOni_]go00000oni_]d00onj`Moo_l_Toko;i003oko;i003okk9honnc^Ko_/kV00?o_/kV
5?ooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002co
oooo001Iooooo`?o0000;Oooool00onW[mgoYZkMojJ^g@03ojJ^g@?oYJkM00?oV7fcoiQm]?nHOK@0
0_nHOK@8oiMm]0CoUWfe1?nFOKH2oiEm]P;oTW6Y1?nBLJX4oi9bZ`CoTW>/1?nBM:d4oi9e[PCoTWJ`
0onBMk400onDM:coUGF]oiEe[@02oiEe[@GoUGN_1?nFNK44oiIk/`GoUWff00CoUh2hoiYm/_nJOK;o
VWfb1?nKP;D4oib4^0GoWHNl00?oWHc1ojRHaOnXV<D00_nXV<D5ojVMb@03oj^Sconi_=_o^KcK00;o
^KcK00Co^KkMo`000?ni_]go^KkM0_nocND4oko;i0;o_mGZ1?nnc^H00onic^Woooooooooo`0Aoooo
o`04o`000?ooooooooooo`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0
003ooooo02_ooooo001Fooooo`?o00000oooool00ol0003oooooooooo`0Wooooo`03ojR_g?nW[mgo
YjoM00;oYjoM1OnV[]d00onU[]goV7fcoiQm/`05oiQm]0OoUgfd1OnFOKD2oiIm]P03oi9`Z?nBLJWo
TW6Y00;oTW6Y1OnBLJX3oi9bZ`CoTW>/1?nBM:d5oi9e[P?oTWJ`00CoTWNaoiAd[?nDM:coU7B/1OnE
MJd4oiEg[`CoUWVa1OnFNk<3oiIm]P03oiUk/?nJOK;oVWfb00?oVWfb1?nKP;D4oib4^0?oWHNl00?o
YiC2ojRHaOnXV<D00onXV<D4ojVMb@03okVkf_ni_=_o^KcK00Co^KcK00?o0000oko=iOnocND00ono
cND00onobnCo_mGZokoEjP03okoEjP03okk>i_nic^Wo^LkY00;o^LkY5_ooool00ol0003ooooooooo
o`10ooooo`00E?ooool2o`0002kooooo1?nX[m`4ojN_g@;oYZkM0_nIOK<4oiQm/`CoV7fd2?nGOK@4
oiIm]@03oiIm]_nBL:SoTW2X00GoTW6Y1?nBLJX3oi9bZ`CoTW>/1OnBM:d4oi9e[P;oTWJ`00?oU7:Z
oiAd[?nDM:`00onDM:`4oiEe[@CoUGN_1OnFNK44oiIk/`04oiIm]_nINk3oVG^`oiUk/0GoVWfb1?nK
P;D4oib4^003oif7_?nWU<;oYiC200;oYiC21OnXV<D00onYWLWo^K_JokVkfP02okVkfPCo^KcK00?o
`<oVo`000?nocND00onocND2ol3LkPCo_mGZ00?o^]G^okW>jOnic^T00onic^TFooooo`03o`000?oo
oooooooo043ooooo001Aooooo`?o0000;_ooool00onY[mcoZ:oLojR_g003ojR_g0?oYjoM00?oVWjc
oiUm/onIOK<00_nIOK<4oiQm/`CoV7fd2?nGOK@2oiIm]@;oTg2X1?nBL:P4oi9aZ@CoTW6Z0onBLZ/5
oi9c[0CoTWB]0_nBMJh2oiAaZ@CoU7:Z1?nDM:`4oiEe[@CoUGN_1OnFNK42oiIk/`;oVGV^1OnINk04
oiYm/PCoVh2e0onLQ;P00onVT;ooYiC2ojND`P03ojND`PCoZ9S500?o^[[JokVkf_ni^mX01?ni^mX0
1oni_=_o`<oVol3?i_o0cnKo0000ol3?i_nocND01Oo0g>h00onoeN[o^]G^ok[EkP02ok[EkP;o^LkY
0onbbN/Fooooo`03o`000?oooooooooo03oooooo001>ooooo`Go0000;?ooool00on[[m_oZJoLojV_
g002ojV_g0GoZ:oL00?oYjoMoiYn/onJO[<01OnIOK<3oiQm/`GoV7fd1_nGOK@5oi=`Z0CoTW2X1?nB
LJT4oi9aZP?oTW:[1OnBLj`2oi9d[@;oTg2X1?nDLJT4oiAbZPCoU7B/1?nEMJd5oiEg[`?oUWVa00?o
V7N/oiUi[_nINJh00_nINJh5oiUk/0CoVWfb1OnKP;D01?nLQ;SoYY2oojJ@_onVT;l4ojND`P?oZ9S5
0onj^]X4okVkfP03ol3Cj?o0cnKo`<oV00;o`<oV00?o0000okoSlOnoho401?o0g>h2okWMlP?o^]G^
00?o//g^ok;9jonbbN/01?nbbN/Fooooo`03o`000?oooooooooo03kooooo001<ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Wooooo`CoZjoK1?nY[m`2ojR_g0;oVWjd1?nJO[<4oiUm/`?oV7fc1OnH
OK@2oiMm]0;oTfnW2?nCL:P3oi9`Z0CoTW6Y1?nBLJX4oi9bZ`?oTW>/00?oTfnWoi=`Z?nCL:P00_nC
L:P5oiAaZ@?oU7:Z1?nDM:`5oiEe[@CoUGN_00CoUWVaoiQg[?nHMjcoV7N/1OnINJh4oiUk/0GoVWfb
0onKP;D00onUSKcoYY2oojJ@_`03ojJ@_`CoYiC200?oZ9S5okZjf_nj^]X00_nj^]X3okVkfP?o`=?X
0oo0cnH01Ol0003o_n?aokoSlOnoho7o`=c^00Go^Mgb00Co^]G^ok;=k_nbcNko//g^1?nbbN/00on]
aNcoooooooooo`0Dooooo`03o`000?oooooooooo03kooooo0019ooooo`?o0000;oooool00on[/=_o
ZjoKoj^_f`04oj^_f`;oZJoL00?oVgndoiYn]?nJO[@00_nJO[@4oiYn/`CoVGfc1?nHOK<3oiQm]0Go
TfnW2?nCL:P3oi9`Z0CoTW6Y1OnBLJX3oi9bZ`04oi9c[?nCKjOoTfnWoi=_Y`GoTg2X1?nDLJT4oiAb
ZP?oU7B/1OnEMJd2oiEg[`;oV7J[1OnHMj`4oiUi[PCoVG^`1OnJOK800onKP;GoYHflojF=_002ojF=
_0CoYY2o0onWU<800onj^m[o^[[JokZjfP04okZjfP03okVkf_o0dnSo`=?X00?o`=?X00Go`<oVokoS
lOnoho7o0000okoSl@02okKTmPCo^Mgb00?o/M;aok;=k_nbcNh00onbcNh00onbbN_o[LG/ojg5k002
ojg5k1Cooooo0ol0000oooooo`008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^023ooooo0_l0000_
ooooo`03ojb`f_n[/=_oZk3K00;oZk3K1?n[[m/01?nLP;CoVgndoi]o]?nKOk@5oiYn]0?oVWjc1OnI
OK<3oiQm/`03oiQm]?nCKjOoTfnW00GoTfnW2?nCL:P3oi9`Z0GoTW6Y1?nBLJX2oi9bZ`03oi=_Y_nC
KjOoTfnW00?oTfnW1?nCL:P4oiAaZ@CoU7:Z1?nDM:`3oiEe[@03oiMdZOnHMZ_oV7J[00;oV7J[1OnH
Mj`4oiUi[PGoVG^`0onJOK800onTRk[oYHflojF=_003ojF=_0GoYY2o00CoYiC2okZkf_nj^m[o^[_J
1?nj^]X2ol3Gj`Co`=?X0onlj_@00onoho7o0000okKTmP03okKTmP03okWMl_nad_7o/M;a00;o/M;a
0_nbcNh3ojg8kPGo[LG/5Oooool00ol0003oooooooooo`0mooooo`008_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01gooooo0ol00002ooooo`03o`000?oooooooooo02[ooooo1?n//=X4oj^`f`04oj^_
fonLP;CoW82doib0]0CoVgnd1?nJO[@4oiYn/`CoVGfc0_nHOK<9oi=_Y`SoTg2X1?nBL:P4oi9aZ@;o
TW6Z0_nCKZD3oi=_YPGoTfnW1?nCL:P4oiAaZ@CoU7:Z1?nDM:`01?nEMJgoUgBYoiMdZOnGM:T5oiQf
Z`CoV7N/1?nINJh5oiUk/003oiYm/_nTRk[oY8^j00;oY8^j1?nUSK`4ojJ@_`03okZlfonj^m[o^[_J
00?o^[_J00?o^[[Jol3Gjoo0en/00oo0en/00oo0dnSo_>[dokcZm002okcZm0;o/^[h00Go0000okKT
m_nfi?Ko]^Cfok3Fm004ok7Bl@03ojc;l?n]b>ko[LS^00Co[LS^0_n]aN`3ojW2jaGooooo00?o0000
ooooooooool0??ooool002;ooooo00Go410@oooooooooooooooooa0@400Kooooo`;o0000<?ooool0
0on]/=[o[;3Jojb`fP04ojb`fP;oZk3K00?oW86eoib0]?nLP;@00onLP;@3oi]o]0CoVWjd1?nJO[<2
oiUm/`;oU72W2onCKjL8oi=`Z0CoTW2X0onBLJT00onBKJGoTfjUoi=^Y@02oi=^Y@CoTfnV1?nCKjL4
oi=`Z0CoU76Y1OnDLZX2oiAd[003oiMcZ?nGM:WoUgBY00?oUgBY1?nHMZ/4oiQg[0GoVGV^0onINk00
0onSR;SoY8^jojB;^P03ojB;^PGoYHfl00?oYY2ookZlfonj_=/00_nj_=/3okZkfP;o`=c]1?o0en/3
okO`m@03okcZm?nbj_So/^[h00;o/^[h00?o0000okKTm_n`e_@00on`e_@00onad_7o[<_`ojc;l002
ojc;l0Co[LS^00?oZL?/ojW2jonY`^/01?nY`^/Eooooo`03o`000?oooooooooo03_ooooo000Roooo
o`05o`000?ooooooooooooooool000006?ooool3o`0002oooooo00?o[[3Iojf`f_n]/=X00_n]/=X4
ojb`fP04oif2]OnLPKGoW86eoib1]@GoW82d0onKOk@5oiYn]0;oVWjc1OnDL:L<oi=_Y`SoTg2X0onB
L:P01?nBLJWoTVfUoi9]YOnBKJD5oi=^Y@?oTfnV1?nCKjL4oi=`Z0GoU76Y0onDLZX01?nFLZOoUg>X
oiMcZ?nGLjP5oiMdZ@CoV7J[1?nHMj`5oiUi[P03oiUk/?nSR;SoXhRh00;oXhRh1?nTRkX4ojF=_003
okZmg?nj_=_o^[cK00?o^[cK00?o^[_Jol3LkOo0g>d00oo0g>d00oo0en_o]o3eokO`m@02okO`m@?o
Znkh0_nbj_P00on^fOOo0000ojkIm`02ok3Fm0?oZlgb1On/bo000on]b>koZL?/ojW3k002ojW3k0Co
ZL;[00?oZ<7[ooooooooool04oooool00ol0003oooooooooo`0kooooo`008_ooool01Ol0003ooooo
oooooooooooo000001Kooooo0ol0000_ooooo`Co[[3I1?n]/=X01?n//=[oWH:eoif2]OnMP[D4oib1
]@CoW82d1?nKOk@4oiYn]003oiYn/onDL:OoU72W00GoU72W2onCKjL8oi=`Z0;oTW2X00?oTVfToi9]
YOnBKJD00_nBKJD5oi=^Y@?oTfnV1?nCKjL5oi=`Z0CoU76Y00CoU7:ZoiIbYonFLZOoUW:W1?nGLjP4
oiMdZ@CoV7J[1OnHMj`3oiUi[P03oj:7]onSR;SoXhRh00?oXhRh1OnTRkX2ojF=_0?o^[gL1?nj_=/0
0onohO3o`=c]ol3Lk@02ol3Lk@?o[o?d00?o]o3eoj_^n?n[k_P00_n[k_P2oj_Ln@;o[]Wg00?o0000
oj[?lon[cO801On[cO82ojc;l0?oZLC]1OnY`n`00onY`^_oZ<7[ojS1j`02ojS1jaGooooo00?o0000
ooooooooool0>_ooool002;ooooo00Go410@oooooooooooooooooa0@400Cooooo`?o00000_ooool0
0ol0003oooooooooo`0[ooooo`03ojn`fOn^/=Wo[[3I00?o[[3I0on]/=X00onNPkKoWH:eoif2]@03
oif2]@?oW86e1OnLP;@3oi]o]0;oVWjd2_nDL:L;oi=_Y`KoTg2X0_nBK:@3oi9]Y0GoTVfU1?nCKZD3
oi=_YPGoTfnW1?nCL:P3oiAaZ@03oiIaYonFLZOoUW:W00?oUW:W0onGLjP4oiMdZ@GoV7J[1?nHMj`0
0onINJkoXXNgoj:7]`02oj:7]`CoXhRh1OnTRkX00onUSKco^[gLokZmg002okZmg0?o^[cK0onohO00
0oo0g>go[o?dojocm002ojocm0?oXO3e00?oZnkhoj_LnOn[g?T00on[g?T01?n^fOOo0000oj[?lonZ
co<4oj_=lP03ojW5k_nYa>goZLC]00CoZLC]0_nY`n`3ojS1k0CoZ<7[5_ooool00ol0003ooooooooo
o`0iooooo`008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg013ooooo0ol0000booooo`?o[k3I1On^
/=T00on]/=[oWX>foij3]P05oif2]@?oW86e1OnLP;@2oi]o]003oiEaYonDL:OoU72W00[oU72W2onC
KjL3oi=`Z0GoTVbT1?nBKJ@4oi9]Y@CoTfjU0onCKjH5oi=_Y`CoTg2X00CoU76YoiIaYonFLJOoUW6W
1OnFLZL3oiMcZ0CoUgBY1OnHMZ/2oiQg[0;oXHFf1OnRQkL5oj>8^0?oY8^j00?o^[oNokZmg?nj_M`0
1?nj_M`01?nj_=_o_n7`okoQl?nohO03ojCdk`04ojocm?nQl?GoXO3eoj7`m@CoZ=oj0_n[g?T2ojWA
m@03oj[?lol0003oZ/oc00;oZ/oc00?oZlgbojW5k_nYaNh00_nYaNh4ojW4k@OoZ<7/0_nX`N/2ojS0
jaCooooo0_l0000kooooo`008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo0_l0000boooo
o`;o/;7I1On_/=T2ojj`f@;oWhFg1?nNPkH4oif2]@CoW86e0onLP;@01?nELZSoUG6WoiEaYonELJL<
oiA`Y`_oTfnW00?oTg2Xoi9/Y?nBK:@01OnBK:@4oi9]Y0CoTVfU1?nCKZD4oi=_YPCoTfnW0_nCL:P2
oiE`YPGoUW6W1?nFLZL3oiMcZ0GoUgBY0onHMZ/00onPPkCoXHFfoj65]P03oj65]PCoXXNg1OnSR;P0
0onTRk[o^[oNokZogP02okZogPCo^[gL0_nli_<00onohO3oY?C_ojCdk`02ojCdk`;oUNo_0_nVhO/4
ojSOnP03ojSBm_nYdOGoZM7e00?oZM7e00?o0000oj[?lonXa^l00_nXa^l5ojW5kP03ojW4kOnX`Nco
Z<7/00KoZ<7/00?oYl3[ojS0jonX`>/00onX`>/Eooooo`03o`000?oooooooooo03Sooooo000boooo
o`Go0000;oooool00ona/MSo/;7Iok2af@03ok2af@?o[k3I00?oX8Jhoin5]onOQKL00onOQKL3oij3
]PGoWH:e0onLPKD01?nLP;CoUG:XoiEbZ?nELZP4oiEaY`_oU72W2_nCKjL00onBK:?oTVbToi9/Y007
oi9/Y0?oTVfT1?nBKJD5oi=^Y@?oTfnV0onCKjL00onEKjGoUG2VoiE`YP02oiE`YPGoUW6W1?nFLZL3
oiMcZ0GoUgBY00CoV7J[oj23]?nPPkCoX8>d1OnQQKH5oj:7]`?oXhRh00?o^/;PokZog_nj_mh01?nj
_mh01?nj_Mco_>KcokcVlonli_<3oiKai`03ojCdkonEknooUNo_00GoY^7k00?oZ=ojojSBm_nXd_H0
0_nXd_H2ojWAm@03ojS6kol0003o000000GoZ<K_0_nYaNh9ojS1k0CoYl3[0onX`>/00onW`>_ooooo
ooooo`0Dooooo`03o`000?oooooooooo03Oooooo000`ooooo`;o0000<oooool3ok6af0Go/;7I00?o
[k3Ioj26^?nPQ[P01OnOQKL3oij3]PGoWH:e0_nLPKD00onFLZSoUG:XoiEbZ002oiEbZ0CoUG6W3?nD
L:L5oi=_Y`GoTVbS2OnBK:@3oi9]Y0CoTVfU1OnCKZD3oi=_YP04oi=_YonEKjGoUFnUoiE_Y@GoUG2V
1?nFLJL4oiIbY`CoUg>X0onGM:T00onOP[?oX8>doj23]003oj23]0CoXHFf1OnRQkL00onSR;So^/;P
ok[2h002ok[2h0Co^[oN0onik?D00onli_?oU_7WoiKai`02ohO[i`CoXn;l0_nVhO/3ojOCm`?oZ=;f
00KoZ<O`o`000?l0003o0000ojS6kol00003ojS6k`?oZ<;/1onX`N`7ojO0j`03ojS0jonW`>_oYl3[
00;oYl3[5Oooool00ol0003oooooooooo`0gooooo`00;Oooool3o`0003?ooooo1Ona/MP4ok2af@03
oj:8^OnPQ[SoX8Jh00;oX8Jh1?nOQKL4oij3]P?oWH:e00CoUg>YoiIbZ?nFLZSoUW:X1?nELZP4oiEa
Y`coU72W0_nCKjL8oi9/X`WoTVbT0onBKJ@5oi9]Y@CoTfjU0_nCKjH00onDKjGoUFnUoiE_Y@03oiE_
Y@CoUG2V1?nFLJL5oiIbY`?oUg>X00CoUgBYoin2/onOP[?oWh:c1OnPPk@5oj65]P?oXXNg00?o^/CR
ok[2h?nj`^001?nj`^000onj_mko^NceokW/m@02okW/m@03ohK[g?miiMcoNNGL00;oX>?l1?nSh_`2
ojKDm`GoYm?g0ol000000onXao3oZ<K_ojS6k`02ojS6k`03o`000?nX`^coZ<;/00CoZ<;/0_nX`N`2
ojO1k0ooYl3[5Oooool00ol0003oooooooooo`0fooooo`00;?ooool2o`0003?ooooo2?na/MP00on`
/MWoXXRioj:8^@02oj:8^@?oX8Jh1OnOQKL3oij3]P04oif2]OnGLjWoUg>YoiMcZ@CoUW:X0onELZP4
oiEaY`coU72W00?oTfnWoi9/XonBK:<02?nBK:<8oi9/Y0CoTVfT1?nBKJD3oi=^Y@04oiA^Y?nDKjGo
U6nUoiA_Y@GoUFnU1?nEL:H4oiIaY`GoUW:W0_nGLjP00onOPK?oWh:coin2/`03oin2/`CoX8>d1OnQ
QKH00onRQkOo^/CRok[4hP02ok[4hPCo^/;P0oncl?H01?nik?GoQ^_LohK[g?miiM`5oj3So003oj?R
o?nVe?OoY]Cg00?oY]Cg00CoYm?go`000?l0003o00001OnXao001OnXa^ooYl;/ojO2k?nW`^co0000
00CoZ<;/1_nW`N`?ojO0jaGooooo00?o0000ooooooooool0=Oooool002cooooo0ol0000`ooooo`;o
/[;G1ona/MP00onSRK[oXXRioj:8^@03oj:8^@?oX8Jh1OnOQKL2oij3]P03oiMdZ_nGLjWoUg>Y00;o
Ug>Y1?nFLZP4oiEbZ0?oUG6W2_nDL:L=oi9/X`SoTVbT1?nBKJ@4oi9]Y@04oi=^YOnDKZCoU6jToiA^
Y0CoU6nU1?nEKjD4oiE`YPGoUW6W1?nFLZL00onGLjSoWh6coin1/`05oin2/`GoX8>d0onQQKH00onj
b>Go^/CRok[4hP04ok[4hP03ok[2h?ncl?Ko/o3f00;o/o3f0_mdh/h01?m[gM7oW^CloikTo?nNi?`2
oj3So0CoY]Ch0_nVe?L3o`0000CoYlO`0_nXao07ojO2k003o`000?nX`^coYl7/00KoYl7/4OnW`>/D
ooooo`03o`000?oooooooooo03Gooooo000/ooooo`04o`000?oooooo0000o`0002kooooo1?nb/]L3
ok6af003ojB;^onSRK[oXhVj00;oXhVj1?nRR;T4oj26^0?oWhFg00CoV7J[oiMdZ_nGM:[oUgBZ1?nG
LjT4oiIbZ0CoUG:X1?nELJL6oiA`Ya3oTVbS2OnBK:@3oi9]Y0;oTVfU1_nDKZ@4oiA_Y@CoUFnU1?nE
L:H5oiIaY`?oUW:W00?oWX2boin1/onOPK<00_nOPK<4oin2/`GoX8>d00?oXHFfok[8iOnjb>D00_nj
b>D4ok[4hP?o[??d00?o/o3fogCRc_mdh/h00_nKi?d2oikTo0?oYMCh1?nVe?P3o`0000KoYlO`0_nW
`N`7ojO2k003ojO1k?l0003oYl7/00KoYl7/4_nW`>/Cooooo`03o`000?oooooo000000Sooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<01Wo
oooo000/ooooo`;o00000_ooool00ol0003oooooooooo`0Yooooo`03ok>beonb/]Oo/[;G00Co/[;G
00Co/K7HojB;^onTRk_oY8^k0onSRKX5oj:8^@?oX8Jh00CoWhFgoiQfZonHMZ_oV7J[1?nGM:X3oiMc
Z@CoUW:X1?nELZP4oiEaY`?oU72W4onBK:<9oi9/Y0;oTVfT00?oU6fToiA^Y?nDKZ@01onDKZ@3oiA_
Y@CoUFnU1OnEL:H4oiIaY`04oiIbYonNP;;oWX2boij0/PCoWh6c1?nOP[<4oj23]003ok[;j?njb>Go
^/SU00Co^/SU00?o^/CRojccm?n/lo@00_n/lo@00omRe[koGMC5oi_To@02oi_To@OoYMCh0ol00006
ojO7l0KoYl7/0_nW`^`6ojO1k004o`000?nW`NcoYl7/ojO1k1KoYl3[5Oooool00ol0003ooooooooo
o`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooooooo
V9RHob4Q8@0Iooooo`00:oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Kooooo
1?nc/]L4ok:be`03ojF=_?nTRk_oY8^k00;oY8^k0onSRKX5oj:8^@;oX8Jh00?oVGN/oiQfZonHMZ/0
0_nHMZ/4oiMdZPCoUg>Y0onFLZP4oiEbZ0CoUG6W00?oU72Woi9/XonBK:<04onBK:<9oi9/Y003oi9]
Y?nDKJCoU6fT00WoU6jT0onDKjD5oiE_Y@CoUG2V0onFLJL00onMOk;oWX2boij0/P03oij0/P?oWh6c
1OnOP[<2oj23]0?o^/_X1?njb>D3oj7ck`03ojccm?mAc;[oV^Gl00?oV^Gl00?oVnCmojGDn?nUe?P0
1?nUe?P2o`0000OoYlO`4?nW`N`00onW`>_o0000ojO0j`0GojO0jaGooooo00?o0000ooooooooool0
1Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Ioooo
o`00:oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02?ooooo0_nd/mL5ok>be`03
ok:beonUSKcoYHfl00;oYHfl0onTRk/4oj>9^P?oXXRi00CoVWR]oiUg[?nIMjcoVGN/1?nHMZ/4oiMd
ZPCoUg>Y1?nFLZP3oiEbZ0;oUG6W0_nBK:@Goi9/X`KoTVbT0_nCKJ<3oiA]Y0WoU6jT0onDKjD5oiE_
Y@CoUG2V00CoUW6Woieo/_nMOk;oWGnb1OnNP;83oin1/`GoWh:c00?oX8>dok[;j?njbnP00onjbnP0
1Onjb>GoXO?_oj7ckonQlnooDLV_00?oV>Gl0_nJiO`4ojCDn0;oYMCh0ol00006ojO7l13oYl7/1?nW
`>/00ol0003oYl3[ojO0j`0GojO0jaGooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Iooooo`00:oooool3o`0000Gooooo
00?o0000ooooooooool08Oooool4okBce`?o/k;G00?oYY2mojF=_?nUSK`00onUSK`4ojB;^`?oXhVj
00CoXXRioiYh[OnJN:goVWR]1?nIMj`4oiQfZ`?oUgBZ1?nGLjT4oiIbZ0;oUG:X00?oTVfToi9/Y?nB
K:@00_nBK:@Goi9/X`?oTVbT00?oTfbSoi=]XonCKJ<00_nCKJ<4oiA]Y0SoU6jT1?nDKjD4oiE_Y@;o
UG2V0_nMOk45oieo/PCoWX2b1?nOPK<3oin2/`;o^Lo[1?njbnP2oiC`i`03o`000?nGiOcoUnGl00;o
V>Gl0onTe?T4ojCDn0?o00001OnWao0BojO1k0OoYl3[00?o0000ojO0jonW`>/05onW`>/Eooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000
oa0@4?o<c<`06Oooool002_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Noooo
o`03okFceond/mOo];?G00Co];?G00Co/k;GojJ@_OnVT;goYY2m1?nUSK`4ojB;^`;oXhVj00?oVWZ^
oiYh[OnJN:d00onJN:d3oiUg[0CoV7J[0onGM:X4oiMcZ@?oUW:X00CoTffToi9]Y?nBKJCoTVfT1OnB
K:@Foi9/X`04oi9/Y?nCK:?oTfbSoi=/X`CoTffS1?nDKJ@8oiA^Y0CoU6nU0onEKjD00onLO[7oWGna
oieo/@02oieo/@GoWGnb1?nNP;84oin1/`03oin2/onicn_o^Lo[00?o^Lo[00?o^/_XoiC`ionDl>L0
1?nGiO`2ojCDn0GoY=Ci0ol00004ojO7l1?oYl7/2onW`>/00ol0003oYl3[ojO0j`0FojO0jaGooooo
00?o0000ooooooooool00oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qooo
ool06oooool002_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`?o]K?G
1?nd/mL00onXT[ooYY2mojJ@_@02ojJ@_@GoYHfl0_nTRk/01?nKO:ooVWZ^oiYj[_nJNZh5oiYh[@?o
VGN/1?nHMZ/4oiMdZP?oUg>Y00CoUW:Xoi=]Y?nCKJCoTffT0onBKJ@5oi9/Y1GoTVbS1OnCK:<4oi=]
X`CoU6fT2OnDKZ@3oiA_Y@04oiE_YOnLO[7oW7jaoian/@GoWGna1?nMOk85oij0/P;oWh6c0onhdnh3
okW?j`;oQ>[K0onFiO`00onGiOcoY=ChojCDn003ojCDn004ojCDnOl0003o0000o`0000CoYlO`4_nW
`N`@ojO0j`03o`000?nW`>_oYl3[01KoYl3[4oooool3o`0000Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`03omgMgOl@413oV9RH01_ooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool06?ooool2okJde`Go]K?G00?o];?GojRB_onXT[l00_nXT[l3ojJ@_@GoYHfl
00?oY8^koi]l[onKO:l01?nJNZh4oiYh[@?oVGN/1?nHMZ/4oiMdZP;oUg>Y00?oTfjUoi=]Y?nCKJ@0
0_nCKJ@4oi9]Y0CoTVbT4onBK:<8oi=/X`?oTffS1?nDKJ@9oiA^Y0;oU6nU00?oW7faoian/OnLO[40
0onLO[44oieo/@GoWGnb1?nNP;800onOPK?o^=?^okSCkP03okSCkP04okW?jon4j]_oQ>[KoiGUo0;o
U^Gl0onTdoP2ojCDn0?o00001_nWao0@ojO1k1?oYl3[00?o0000ojO0jonW`>/05onW`>/Eooooo`09
o`000?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@
6Oooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooo
ooooo`04ooooo`?o00002_ooool00ol0003oooooooooo`0Dooooo`03okNeeonf]=Oo][CG00?o][CG
0one/mL00onYU<3oZ9:oojRB_`03ojRB_`CoYY2m0onUSK`00onMO[3oVgb_oi]l[`02oi]l[`?oVWZ^
1?nJN:d4oiUg[0?oV7J[0_nGM:X5oi=^Y@GoTffT0onBKJ@4oi9/Y1?oTVbS2?nCK:<4oi=]X`?oU6fT
2OnDKZ@00onDKjGoW7faoiam/@05oian/@CoWGna1OnMOk82oij0/PCo]mSa0_nhdnh2og;Qc@;oUNGl
1_nTdoP3o`0000KoYlO`4_nW`N`EojO0j`03o`000?nW`>_oYl3[01KoYl3[5Oooool00ol0003ooooo
ooooo`0_ooooo`002?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000
1Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo0ong]ML5okJde`04okFc
eonYU<3oZIC0ojVD`0CoZ9:o1?nVT;d01?nUSKcoWGj`oien/?nMO[04oi]l[`?oVWZ^1?nJN:d4oiUg
[0;oV7J[00?oU6nVoi=^YOnCKZD01_nCKZD4oi=]Y0?oTVfT1?nBK:@Coi9/X`SoTfbS1?nCKJ<4oiA]
Y0KoU6jT0_nKOK44oiam/@CoW7ja1OnMOk43oieo/P;o]]_c1?ngf?42of3D_003oiGUo?nTdoSoY=?h
00KoY=?h0_l00005ojO7l1?oYl7/6OnW`>/00ol0003oYl3[ojO0j`0FojO0jaGooooo00?o0000oooo
ooooool0;_ooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgooooo
o`0000Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`03okRfeong]MOo
]kGG00?o]kGG0_nf]=L2oj^G`PCoZIC01OnXT[l2ojJ@_@03oij0/_nMO[3oWGj`00;oWGj`1?nKO:l3
oiYj[PGoVWR]0_nIMj`01?nDL:OoU6nVoiA_Y_nDKjH8oi=^Y@CoTffT0onBKJ@5oi9/Y1;oTVbS2?nC
K:<4oi=]X`CoU6fT0onDKZ@5oi]m/@CoW7fa1?nLO[45oieo/@03oieo/_nffo?o]]_c00?o]]_c00?o
]mSaof3D_?mPe;`00_nTd_P6ojCCn0?o00001?nWao0BojO1k1goYl3[00?o0000ojO0jonW`>/05onW
`>/Eooooo`03o`000?oooooooooo02gooooo000@ooooo`05o`000?ooooooooooooooool000002ooo
ool01?oMgMgoEEEEooooool00006ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool3okRfe`?o]kGG00?o[9[4oj^G`_n[Ul800on[Ul83ojVD`0CoZ9:o00CoWh:doij0/_nNP;;o
WX2b1?nMO[04oi]l[`CoVWZ^1?nJN:d00onIMjcoU72WoiA`Y`04oiA_YPOoTfjU1?nCKJ@3oi9]Y0Go
TVbT1OnBK:<2oi9[X`_oTVbS2?nCK:<4oi=]X`CoU6fT00?oU6jToi]m/OnKOK401_nKOK43oiam/@Go
W7ja0onMOk42ok?OmPCo]]_c00?oClN[oiCUo?nTd_P01?nTd_P2ojCCn0?o00001OnWao0@ojO1k2;o
Yl3[00?o0000ojO0jonW`>/05onW`>/Dooooo`03o`000?oooooooooo02gooooo000@ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`;o00003oooool2o`0000co
oooo1Onh]]L01?ng]MOo[9[4ojbJa?n/V/@4oj^G`PCoZIC000CoZ9:ooin2]?nOP[CoWh:d1?nNP;84
oien/0CoVgb_0onJNZh2oiYh[@;oUG6X1?nDL:L3oiA_YPOoTfjU1?nCKJ@4oi9]Y0CoTVbT0_nBK:<5
oi9[X`coTVbS2?nCK:<3oi=]X`?oU6fT00?oVWbaoi]m/OnKOK401onKOK43oiam/@GoW7ja00?oWGna
ok?Om_ncgoH00oncgoH00onffo?oU>GloiCUo005ojCBn004ojO6l?l0003o0000o`0000CoYlK`0_nW
ao02ojO0k0goYl7/9_nW`>/00ol0003oYl3[ojO0j`0FojO0jaGooooo00?o0000ooooooooool0;?oo
ool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`?o^KOG0onh]]L00on^WLKo[9[4ojbJ
a003ojbJa0?oZiO20onYU<000onQQKKoWh:doin2]003oin2]0?oWX2b1?nMO[04oi]l[`;oVWZ^00?o
UG:YoiEaZ?nELJP00_nELJP4oiA`Y`?oU6nV1onCKZD5oi=]Y0?oTVfT0onBK:@00onAJj?oTV^Soi9[
X`05oi9[X`coTVbS2?nCK:<3oi=]X`04oiA]Y?nJO;7oVWbaoiYl/@WoVgfa1?nLOK43oian/@;o/N?h
1?ncgoH3ojCBm`?oY=;h00CoYlK`o`000?l0003o00001OnWa_07ojO0k0_oYl7/:?nW`>/00ol0003o
Yl3[ojO0j`0FojO0ja?ooooo0_l0000^ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00go
oooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Go
oooo1Oni]mL01?nh]]Oo[Yg6ojjMa_n^WLH4ojbJa0CoZiO200?oZIC0oj65]_nQQKH01OnOP[@3oij0
/PCoWGj`0onKO:l01?nFM:[oUG:YoiEbZOnELZT4oiEaZ0CoU72W0onDKjH8oi=^Y@CoTffT0onBKJ@0
1?nBK:CoTF^Soi5[XonAJj<8oi9[X`_oTVbS2?nCK:<2oi=]X`KoVWba2?nKOK44oiam/@03oian/Ona
hoSo/N?h00?o/N?h00?o/mofojGAmonTd_L01?nTd_L3o`0000CoYlK`0_nW`>/8ojO0k0WoYl7/:onW
`>/00ol0003oYl3[ojO0j`0FojO0jaGooooo00?o0000ooooooooool0:oooool002Wooooo0_l0000D
ooooo`03o`000?oooooooooo00;ooooo0_nj^=L4okVge`03ok2Pb?n^WLKo[Yg600;o[Yg61On/V/@2
oj^G`P03oj:8^?nQQKKoXHFf00;oXHFf1?nOP[@4oij0/P?oWGj`00CoVgb_oiIdZ_nFM:[oUWBZ1?nE
LZT3oiEaZ0CoU72W0onDKjH8oi=^Y@CoTffT0_nBKJ@00onAJjCoTF^Soi5[X`02oi5[X`SoTV^S2onB
K:<7oi=/X`03oiYk/OnJO;7oVWba00KoVWba2OnKOK42oiam/@Co[NKi0_nahoP4ojGAm`04ojCBmol0
003o0000o`0000CoYlK`1_nW`>/5ojO0k0OoYl7/0onW_n/]ojO0j`03o`000?nW`>_oYl3[01KoYl3[
5Oooool00ol0003oooooooooo`0Zooooo`00:Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00Co^[SG00?o^KOGok2Pb?n`X<P00_n`X<P3ojjMaPCo[9[400?oY8^joj:8^?nRR;P00_nR
R;P3oj65]PGoWh:d0onNP;82oien/003oiMf[?nFM:[oUWBZ00;oUWBZ1?nELZT4oiEaZ0?oU72W1?nD
KjH7oi=^Y@;oTffT0_nAK:@3oi5[Y0CoTF^S2?nBJj<;oi9/X`GoTfbS0onJNk48oiYl/@WoVgfa00?o
W7faojgVnOn]i_T00_n]i_T6ojGAm`;o00001_nWa_08ojO0j`GoYl3/0onW`N`7ojNojbgoYl3[00?o
0000ojO0jonW`>/05_nW`>/Dooooo`03o`000?oooooooooo02[ooooo000Yooooo`03o`000?oooooo
oooo01Gooooo00?o^k[HokZheonj^=L00onj^=L5ok2Pb0Co[Yg600Co[9[4ojB;^_nTRk[oY8^j1?nR
R;P3oj65]PGoWh:d0_nNP;801?nHMjgoUgJ/oiMf[?nGMZ`4oiIdZPCoUG:Y1?nELJP4oiA`Y`?oU6nV
1_nCKZD5oi5/Y0?oTF^T1?nAJj<8oi9[X`_oTVbS0_nCK:<2oiUk/@GoVW^a1onJO;47oi]m/@CoZNSj
00?o[NKiojGAmonUdOL00_nUdOL01?nWa^oo0000o`000?l00005ojO6l0WoYl3[2?nW`>`00onW`Nco
Yko[ojNoj`05ojNojbooYl3[00?o0000ojO0jonW`>/05_nW`>/Dooooo`03o`000?oooooooooo02Wo
oooo000Yooooo`03o`000?oooooooooo01?ooooo1?nk^]P3okZhe`;o/Z?:1?n`X<P3ojjMaP03ojF>
_?nTRk[oY8^j00;oY8^j1?nRR;P4oj65]P?oWh:d00CoVGV_oiQg[OnHMjgoV7N]1?nGMZ`4oiIdZP?o
UG:Y1?nELJP4oiA`Y`?oU6nV0_nCKZD9oi5/Y0CoTF^T1?nAJj<7oi9[X`[oTVbS1OnINk45oiYk/@So
VWba0onKOK43ojGYnP;oZNSj1?nUdOL01?nWa^oo0000o`000?l00003ojO6k`;oYlK`2OnW`>/9ojO0
k0SoYko[<OnW`>/00ol0003oYl3[ojO0j`0GojO0jaCooooo00?o0000ooooooooool0:?ooool002Wo
oooo0ol0000Aooooo`;o_;_H1Onk^]P01?nj^=Oo/Z?:ok:Sb_nbXlX5ok2Pb004ojjMa_nUS[coYHjl
ojF>_0CoY8^j1?nRR;P3oj65]P04oin2]?nINJooVGV_oiUi[`CoV7N]0onGMZ`4oiIdZP?oUG:Y1?nE
LJP4oiA`Y`;oU6nV00?oTFbUoi5/Y?nAK:@02OnAK:@4oi5[Y0CoTF^S2?nBJj<6oi9/X`03oiQj/OnI
Nk7oVG^a00KoVG^a1?nJNk48oiYl/@03oi]m/OnUjO[oYNWj00;oYNWj1OnUdOL3o`0000CoYlK_2OnW
`>/9ojO0k0WoYko[=OnW`>/00ol0003oYl3[ojO0j`0FojO0ja?ooooo0_l0000Zooooo`00:Oooool0
0ol0003oooooooooo`0@ooooo`Co_;_H0onk^]P00ondYlco/Z?:ok:SbP02ok:SbPCo/:3800?oYi:o
ojF>_?nUS[`00_nUS[`4ojB;^PCoXXRh0_nQQKH00onJO;3oVGV_oiUi[`02oiUi[`CoV7N]0onGMZ`4
oiIdZPCoUG:Y0onELJP2oiA`Y`;oTFfU0onAK:D;oi5/Y0CoTF^T1?nAJj<8oi9[X`CoTVbS0onHN[48
oiUk/@CoVW^a1_nJO;44oj7ZnP05ojGYn_nUd?KoYM3fojG@m_nUdOL00ol00004ojO6k`WoYl3[2OnW
`>`9ojNojcWoYl3[00?o0000ojO0jonW`>/05_nW`>/Dooooo`03o`000?oooooooooo02Oooooo000>
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00005ooooo`03o`000?oo
oooooooo00oooooo00?o_[cHokbkf?nl^mP01?nl^mP01?nk^]So]:O<okBWc?ndYl`4ok:SbP03ok2P
b?nWT[ooYi:o00;oYi:o0onUS[`4ojB;^P?oXXRh00CoVgjboiYl/?nJO;3oVWb`1?nINJl4oiQg[@?o
UgJ/1?nFM:X4oiEbZ@;oUG6X00?oTFfVoi5]YOnAKJD00_nAKJD3oi5/Y@coTFbT0onAJj@4oi5[X`So
TV^S0_nBK:<6oiQj/@OoVG^a1OnJNk42oiYl/@CoW>_i0_nQj_X3ojG@mP?o00001OnWa^l9ojO0j`So
Yl3/2?nW_n/mojO0j`03o`000?nW`>_oYl3[01KoYl3[5Oooool00ol0003oooooooooo`0Vooooo`00
3_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01Oooool00ol0003oooooooooo`0=ooooo`Co_[cH1?nl^mP00onfZlko]:O<okBWc003okBW
c0;o/Z?:00?oZIK2ojNB_onWT[l00onWT[l4ojF>_0?oY8^j00CoXXRhoi]n/_nKO[;oVgjb1?nJO;04
oiUi[`?oV7N]1?nGMZ`3oiIdZP;oUG:Y0_nAKZL3oi5]YPCoTFfU1?nAK:D;oi5/Y0?oTF^T1?nAJj<6
oi9[X`;oUgZa2?nHN[48oiUk/@CoVW^a00?oVWbaoic[nOnLjoT00_nLjoT3ojG@mP?o00001_nWa^l9
ojO0j`SoYl3/1onW_n]1ojO0j`03o`000?nW`>_oYl3[01KoYl3[5?ooool00ol0003oooooooooo`0V
ooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7o
k^k^00Kooooo0_l0000=ooooo`03oknnfOnn_=So_[cH00?o_[cH00?o_;_HokJ[c_nfZlh00_nfZlh3
okBWc003ojbJaOnYU/;oZIK200;oZIK21?nWT[l4ojF>_0;oY8^j00?oW86eoi]n/_nKO[800onKO[83
oiYl/0CoVGV_0onHMjd4oiMf[0;oUWBZ00?oTVnXoi5^YonAKZL00_nAKZL3oi5]YPCoTFfU1?nAK:D;
oi5/Y0CoTF^T0onAJj<2oi9[X`KoUgZa2?nHN[48oiUk/@;oVW^a1?nGj_T01?nLjoWoYM3fojG@m_nW
a^l2o`0000GoYlK_2OnW`>/9ojO0k0WoYko[@onW`>/00ol0003oYl3[ojO0j`0FojO0jaCooooo00?o
0000ooooooooool09Oooool000kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Gooooo00?o0000ooooooooool02oooool3oknnf@?o_[cH00?o^:k@okJ[c_nfZlh01?nf
Zlh01?ndYlco[9[5ojbJaOn/V/D3ojVF`PGoYi:o0_nUS[`01?nNQ;OoW86eoib1]OnLPKD5oi]n/P?o
VWb`1?nINJl4oiQg[@;oUgJ/00CoTW2Yoi9_Z?nBKjSoTVnX1?nAKZL4oi5]YP?oTFfU1?nAK:D;oi5/
Y0CoTF^T0_nAJj<00onFNK7oUgZaoiMj/@06oiMj/@SoV7Za1onINk43oi?Zn0;oUn[i0_nVd?H01?nU
d?Ko0000o`000?l00004ojO6k`_oYl3[1onW`>`2ojO0j`OoYko[AonW`>/00ol0003oYl3[ojO0j`0E
ojO0jaGooooo00?o0000ooooooooool09?ooool000kooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool02_ooool5oknnf@04okjlf?nh[]3o
^:k@okR^d0Co]Z_>00?o[Yo8ojbJaOn/V/D00_n/V/D3ojVF`PCoYi:o00CoWhRjoij4]onNQ;OoWXBg
1?nLPKD4oi]n/P?oVWb`1?nINJl4oiQg[@03oiMf[?nBL:WoTW2Y00CoTVnX0onAKZL4oi5]YPCoTFfU
0onAK:D;oi5/Y0CoTF^T00?oTF^SoiIi/OnFNK402?nGN[49oiQj/@CoVG^a1?nCj_P3ojK@mP?o0000
1?nWa^l?ojO0j`;oYl3/1onW`>/2ojNojd_oYl3[00?o0000ojO0jonW`>/05_nW`>/Cooooo`;o0000
2?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`02Oooool000kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo
00?ooooo0_l00009ooooo`;o`;oI1?no_]T00onj/];o^:k@okR^d003okR^d003okJ[c_n^WlSo[Yo8
00;o[Yo80on/V/D4ojVF`P04ojNB_onOR;[oWhRjoin8^PCoWXBg0onLPKD4oi]n/PCoVWb`0onINJl2
oiQg[@;oTW6Z1?nBL:T3oi9_Z0?oTFjW1?nAKJH4oi5]Y@?oTFbU2onAK:@2oi5[Y0KoUWVa2?nGN[48
oiQj/@;oVG^a0on?jOL3ojK@mP?o00001OnWa^mXojO0j`03o`000?nW`>_oYl3[01KoYl3[5?ooool0
0ol0003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
8B4QoiRHV?ooooooV9RHob4Q8@09ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`;o00002Oooool4ol2of@03oknnfOnj/];o^[;B00;o
^[;B0onh[]000onaY<_o[Yo8ojjOb003ojjOb0Co[9[50_nYU/800onRS;goWhRjoin8^P03oin8^P?o
WXBg0onLPKD5oi]n/P?oVWb`0_nINJl00onCLZ_oTW6Zoi9aZP02oi9aZPCoTW2Y0onBKjP4oi5^Y`?o
TFfV1?nAKJD4oi5/Y@WoTFbT00?oUGVaoiIi/OnFNK401_nFNK48oiMj/@KoV7Za1?n;j?H00on?jOOo
Y]3fojK@mP03o`0000KoYlK_JonW`>/00ol0003oYl3[ojO0j`0FojO0jaCooooo00?o0000oooooooo
ool01?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000009
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`03o`000?oooooooooo00Kooooo0_o1`MT3ol2of@;o_;KD1Onj/]801?nh[]3o/JC;ok6T
bonaY</4ojjOb0?o[9[500?oY931oj:<_OnRS;d00_nRS;d4oin8^P?oWXBg1?nLPKD4oi]n/P;oVWb`
00CoU7B]oi=bZonCLZ_oTg:[1?nBLJX4oi9`Z@?oTVnX1?nAKZL3oi5]YPCoTFfU1?nAK:D5oi5/Y0;o
U7Va0onENK48oiIi/@SoUgZa0onHN[43ohSVmP;oRnSf00?oY]3fojO6kol000000_l00005ojO6kg3o
Yl3[00?o0000ojO0jonW`>/05OnW`>/Dooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S802Oooool002Oooooo00?o0000oooo
ooooool01?ooool5ol71f@03ol2ofOnl]]Co_;KD00;o_;KD0onj/]800oncZLoo/JC;ok6Tb`03ok6T
b`Co[Yo800Co[9[5ojB@`OnTT<7oY9310onRS;d4oin8^PCoWXBg0onLPKD2oi]n/P;oU7J^0onDM:d4
oi=bZ`?oTW6Z1?nBL:T3oi9_Z0CoTFjW1?nAKJH3oi5]Y@CoTFbU0_nAK:@00onDN;7oU7VaoiAi/@02
oiAi/@CoUGVa1onFNK48oiMj/@03oiQj/On8i_KoR>Kf00;oR>Kf00?oY]7fojO6kol000000_l00005
ojO6kg?oYl3[00?o0000ojO0jonW`>/05_nW`>/Dooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`02Oooool002Oooooo0_l0
0004ooooo`03ol;2f_o1`MWo`L7I00?o`L7I1_nl]]@01?nj/];o/jW?ok>YconcZLl5ok6Tb`;o[Yo8
00?oYYK4ojB@`OnTT<400_nTT<43oj:<_@GoWhRj0onNQ;L2oib1]@03oiEh/?nDMZkoU7J^00;oU7J^
1?nDM:d3oi=bZ`CoTW6Z0onBL:T4oi9_Z0?oTFjW1?nAKJH3oi5]Y@;oTFbU0_nDN;83oiAh/@GoU7Va
0onENK48oiIi/@KoUgZa0_n6iOL4ojKAmP;o00001?nWa^mhojO0j`03o`000?nW`>_oYl3[01GoYl3[
5Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o
^[Zjoooooonj^[[o410@00Wooooo000Wooooo`03o`000?oooooooooo00;ooooo0oo2`]X3ol71f@;o
_[_G1?nl]]@00onf[m;o/jW?ok>Yc`02ok>Yc`Co/JC;00?oZI_8ojJFa?nVU/@00_nVU/@3ojB@`@Co
XXbm1?nOR;X2oij4]`04oiIk/onEN;3oUGR`oiEh/0CoU7J^1?nDM:d3oi=bZ`CoTW6Z1?nBL:T3oi9_
Z0?oTFjW1?nAKJH2oi5]Y@03oi=h/_nDN;;oU7Rb00;oU7Rb1?nDN;44oiAi/@?oUGVa2?nFNK42oiMj
/@?oQNCg1?nVdOH3o`0000?oYlK_O?nW`>/00ol0003oYl3[ojO0j`0EojO0ja;ooooo0ol00004oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Wooooo000W
ooooo`04o`000?ooooooooooooooo`Go`/;J00?o`L7Iokjkeonn^mL00_nn^mL00onl]]Co]ZoBokJ_
dP02okJ_dPCo/jW?00?o/JC;ojVKb?nYVlP00_nYVlP3ojJFa0CoY9310onRS;d2oin8^P;oV7jf0onF
Nk<4oiEh/0?oU7J^1?nDM:d3oi=bZ`CoTW6Z1?nBL:T3oi9_Z0;oTFjW00?oTWVcoi=h/_nCN;801OnC
N;85oiAh/P?oU7Ra1?nDNK44oiEi/@KoUWVa1?n4hoP00on5i?OoY]7fojKAmP03o`0000GoYlK_OOnW
`>/00ol0003oYl3[ojO0j`0FojO0jaCooooo00Wo0000ooooooooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Wooooo000Vooooo`?o00000_o4a=X4ol;2
fP;o`;oI0onn^mL2okVfePCo]ZoB0oncZLl00on/X/goZI_8ojVKb003ojVKb0?oYYK41?nTT<42oj:<
_@03oiV2^OnHO[KoV7jf00;oV7jf1?nFNk<3oiEh/0CoU7J^0onDM:d4oi=bZ`?oTW6Z1?nBL:T2oi9_
Z0CoTWVc2?nCN;84oiAh/P?oU7Ra1OnDNK43oiEi/@;oUWVa1?n4h_X2ohCSn003ojKAmonWa^oo0000
00;o00001OnWa^n1ojO0j`03o`000?nW`>_oYl3[01GoYl3[5Oooool00ol0003oooooooooo`0Noooo
o`009_ooool00ol0003oa<CJolC4fP03olC4fP03ol;2f_o0_mWo`;oI00?o`;oI00?o_[_GokVfe_ni
]]H00_ni]]H4okJ_dP04ok>Ycon/X/go[:;=ojbRc@CoZI_81?nVU/@2ojB@`@03oi^6_?nIP[WoVH:i
00;oVH:i0onHO[H4oiIk/`?oUGR`1?nDMZh4oiAd[@?oTg:[0onBLJX2oi9`Z@;oTWVd1onBNK<7oi=h
/PCoU7Rb1?nDN;44oiAi/@;oUGVa1?n5h?/2ohCRnP03ojKBmonWa^oo000000;o00001OnWa^n5ojO0
j`03o`000?nW`>_oYl3[01GoYl3[5?ooool00ol0003oooooooooo`0Nooooo`006oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooo4a=X00_o4a=X3ol;4f`?o`;oI00?o_;cJokVf
e_ni]]H01?ni]]H2okJ_dP03ojnYd_n/X/go[:;=00;o[:;=1OnYVlP2ojJFa003oif<`OnKQ[coVhJl
00;oVhJl0onIP[T4oiQn]P?oUW^c0onEN;04oiAf[PCoU7B]0_nCLZ/01?nBNkKoTWZeoi9j]OnBN[D4
oi9i]0OoTWVc1onCN;85oiAh/P?oU7Ra0_nDNK44ohKNo@;oQN3k0_nVd_L01?nWa^oo0000o`000?l0
0004ojO6kh[oYl3[00?o0000ojO0jonW`>/05OnW`>/Dooooo`03o`000?oooooooooo01gooooo000K
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool01?l0003oooooooooooo4a=X5ol;4f`04ol2o
fOnl_=[o_;cJokblfPCo^KKF00?o/[7GojnYd_n_ZM800_n_ZM84ojbRc@;oZI_80_nOT/H4oif<`@?o
VhJl0onIP[T4oiQn]PCoUW^c0onEN;03oiAf[P;oU7B]0_nBO;P3oi9k]P?oTWZe1?nBNK@7oi9i/`So
TgRb1?nDN;82oiAh/@?oQmcn0_n6g_d4ojKBm`?o00001?nWa^n=ojO0j`03o`000?nW`>_oYl3[01Ko
Yl3[4oooool2o`0001kooooo000Kooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0000;o
oooo1?o2a=/00onna=ko_;cJokblfP03okblfP03okVfe_nb/MOo/[7G00;o/[7G0on_ZM83ojbRc@03
oj:IbonOT/KoWi;600?oWi;60onMS<43oi^6_0CoVH:i0onHO[H4oiIk/`?oUGR`0_nDMZh00onBOKWo
TWbhoi9l^002oi9l^0CoTW^f0onBN[D4oi9i]0KoTWVc2?nCN;82oiAh/PCoR=[o0_n7g?h3ojKCm`05
ojKBmol0003o0000o`000?nWa_000onWa^l8ojO0j`?oYl3/Q_nW`>/00ol0003oYl3[ojO0j`0EojO0
ja;ooooo00?o0000ooooool000007_ooool001_ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo00;ooooo00?o`/CKokk4g_nna=h00_nna=h3okblfP;o];WM1?nb/ML4ojnY
dP04ojbRcOnRVL_oXYW;oj:Ib`CoWi;60onMS<44oi^6_0?oVH:i0onHO[H2oiIk/`;oTX6m0onBO[/4
oi9m^@?oTWbh1?nBNkH3oi9j]@CoTWVd1onBNK<6oi=h/PCoRMKo0_n8f_l5ojKCm`;o00001OnWa_00
0onWa^ooYl3[ojO0j`04ojO0j`OoYl3/Q_nW`>/00ol0003oYl3[ojO0j`0EojO0jaCooooo00?o0000
ooooooooool06oooool001_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo00?ooooo1Onna=h00onl_=[o];WMokBig@02okBig@Co/[7G0_n_ZM800onUXM;oXYW;oj:Ib`02
oj:Ib`CoWi;61?nMS<43oi^6_0;oVH:i00CoThK2oi:3_onBPkooTX>o1OnBPKd3oi9n^`?oTWfi1?nB
O;P3oi9k]P?oTWZe1?nBNK@7oi9i/`;oTgRb1?n:dol2ohWFo`?oY]Ch0_nVdoL01?nWao3o0000o`00
0?l00005ojO6l0SoYl3[1onW`>`00onW_n_oYl3[ojO0j`24ojO0j`03o`000?nW`>_oYl3[01GoYl3[
5Oooool00ol0003oooooooooo`0Jooooo`006oooool01Ol@413ooooooooooooooooo410@00Gooooo
00?o0000ooooooooool01Oooool3okk4gP;o]l?S1Ond^Md2ok:ae`03ojRZfOnUXM;oYJ7B00;oYJ7B
0onRVL/5oinBaP?oWHc10_nKQ[`00onCRLKoThK2oi>6`P02oi>6`P?oTX>o1?nBPKd3oi9n^`?oTWfi
1?nBO;P4oi9k]P?oTWZe0onBNK@2oi9i/`?oRl[m1On;coh2oh[Co`GoY]Ch00CoYlO`o`000?l0003o
00000onWao02ojO6l0WoYl3[2?nW`>`3ojNojhKoYl3[00?o0000ojO0jonW`>/05OnW`>/Dooooo`03
o`000?oooooooooo01[ooooo000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000Oo
oooo00?o_/CNokO3hong`n<00_ng`n<2okBig@;oZ[GQ1?nXZ]T3ojFQdPCoXYW;0_nOT/H2oiJCc`?o
U8k:1?nCRLH3oi>6`P?oTX>o1?nBPKd3oi9n^`CoTWfi0onBO;P4oi9k]P?oTWZe0_nBNK@3ohc6n`Co
Rl[m0_n;coh3ojGDn0?oY]Ch00CoYlO`o`000?l0003o00001OnWao08ojO0j`WoYl3/1onW_n^6ojO0
j`03o`000?nW`>_oYl3[01GoYl3[5?ooool00ol0003oooooooooo`0Iooooo`006oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool01oooool3okO3h`;o[<7Y1?nZ]N44ojRZ
f@?oYJ7B0_nRVL/00onGVMCoUY??oiJCc`03oiJCc`?oU8k:0onCRLH3oi>6`P?oTX>o1OnBPKd3oi9n
^`?oTWfi0onBO;P2oi9k]P?oS;cf0on<`OT5ohc6n`;oRl[m1onUe?P3o`0000CoYlO`0onW`N/6ojO0
j`WoYl3/2OnW_n^8ojO0j`03o`000?nW`>_oYl3[01CoYl3[5?ooool00ol0003oooooooooo`0Ioooo
o`009Oooool00ol0003oooooooooo`08ooooo`03okO3hon/`NWo[<7Y00;o[<7Y1?nZ]N42ojRZf@04
oiZYhOnIXM[oVJ7JoiVQfPCoUiWD1?nFTll3oiB>bP?oThW61?nCQ/83oi:3_`CoTX6m0onBO[/2oi9m
^@03oh^dlOn;^?CoRkSd00?oRkSd1?n<_?H3ohc1n@;oS<Kk00?oUnCmojGDn?nUe?P01OnUe?P3o`00
00CoYlO`0_nW`N`5ojO1j`;oYl3[0_nW`N`6ojO0k0WoYko[S?nW`>/00ol0003oYl3[ojO0j`0EojO0
ja;ooooo00?o0000ooooool000006_ooool002Gooooo00?o0000ooooooooool02_ooool4ojc1j@;o
Z[GQ00?oVk;XoiZYhOnJZN400_nJZN43oiVQfPCoUiWD0onFTll3oiB>bPCoThW60onCQ/83oi:3_`;o
TX6m0_n9[Nd4ohZ`k`?oRkCa1On;^?@2ohblmP;o@<?A0_nGhod00onGi?goYMChojGDn004ojGDn0?o
00001?nWao06ojO1k0;oYl7[1onW`N`2ojO0k0WoYko[T?nW`>/00ol0003oYl3[ojO0j`0EojO0jaCo
oooo00?o0000ooooooooool05oooool002Gooooo0_l0000<ooooo`;o[<7Y0_nK_?03oi^bj0?oVZWQ
1?nIXMX4oiNIe0?oUY??0onDS/X2oi>9aP04ohNWjOn8Z>[oR:SZohRXjPGoR:[/0on9[Nd4ohZ`k`?o
RkCa0_n;^?@3odc:h0;oV>;m0_nGhod6ojGDn0;o00001_nWao0?ojO1k0WoYko[U?nW`>/00ol0003o
Yl3[ojO0j`0EojO0ja?ooooo00?o0000ooooooooool05oooool002Cooooo00?o0000ooooooooool0
3Oooool4oi^ll0?oVk;X0onJZN42oiVQfP;oQj_]0on7ZN/3ohNWjPOoQjOY0on8Z>X5ohRZk0?oRJg]
0_n:/>l4of3?m@;oElk/0_nHhOd2oiSRo@GoYMCh00CoYlO`o`000?l0003o00001OnWao03ojS1k0_o
Yl7/2OnW_n^IojO0j`03o`000?nW`>_oYl3[01CoYl3[5?ooool00ol0003oooooooooo`0Fooooo`00
9?ooool00ol0003oooooooooo`0>ooooo`;oVkc`0_n7]_@3ohNbl@CoR:k_0on7Znd3ohNYj`?oQjOZ
1on7YnT3ohRXjP;oR:[/1?m]c?h2ofO?n`?o=;_10onHgoh2oiSQo@?oY=Ch0_nUe?P01?nWao3o0000
o`000?l00005ojO7l0OoZ<7/1onW`N`2ojO0j`OoYko[W?nW`>/00ol0003oYl3[ojO0j`0EojO0jaCo
oooo00?o0000ooooooooool05Oooool002Cooooo0ol0000?ooooo`CoQkKd0on7/_44ohR^k`?oQj_]
0on7ZN/3ohNWjP;oQjOY0omg_od4ogC3oP?oLLSo0_m]c?h2of3FiP?oV=gn0_nHgoh4ojCCn0;oY=Ch
00CoYlO`o`000?l0003o00001OnWao08ojS1k0SoYl7/1?nW`>/3ojNojj3oYl3[00?o0000ojO0jonW
`>/05OnW`>/Booooo`;o00002Oooool4o`000003oa0@4?oooooooooo00Oooooo000Tooooo`03o`00
0?oooooooooo013ooooo1?n7]_@3ohNbl@;oR:k_0_ml]?L3og^fn0?oN[Sj1?mh^o/4ogNoo@;oM<?n
0_mCc>`3ofWHl0?oVM[m0_nHgOh3ojCBn0?oY=?h00CoYlO`o`000?l0003o00001?nWao09ojS1k0Wo
Yl7/1onW`>/00onW_n_oYl3[ojO0j`2PojO0j`03o`000?nW`>_oYl3[01GoYl3[4oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo01;ooooo0omo/_D3ogfcmPCo
O;Cg0omk]_P3ogZhnP;oN;_k1?mVc?`2oeg=mP;oLMWh1?nIeod2oiWJo@;oXm7g1OnTd_P3o`0000Co
YlO`0onW`N`6ojS1k0WoYl7/[OnW`>/00ol0003oYl3[ojO0j`0EojO0jaCooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`09ooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0Coooo
o`?oOk;e0omm/oH2ogbdm`;oNKkl1Omc`oh2ofg8oP?oOm;o0_mie_d4oiWCo0;oVMOm0_nScoL4oj?A
m`04ojCBn?l0003o0000o`0000CoYlO`1onW`N`2ojS1k0SoYl7//_nW`>/00ol0003oYl3[ojO0j`0E
ojO0ja?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`002Oooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0E
ooooo`?oPK?e1?mm^OT3ogVno0;oLl?n1?n4c?l2ogoBo`CoVLok0_nIdo`2oj;=mPCoXlog0_nSdOL2
o`0000;oYlK`0_nWao02ojO2k0ooYl7/]_nW`>/00ol0003oYl3[ojO0j`0EojO0ja?ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`09ooooo`002Oooool01Ol0003ooooooooooooooooo
000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`0001Kooooo0on1/oD2ogfin@?oRkoh1?n8a_`2
ohC<o`?oVL_i0_nIco/3oj;;m@CoX/gf0_nScoL3o`0000?oYlK`1_nW`^`;ojO1k;[oYl3[00?o0000
ojO0jonW`>/05OnW`>/Aooooo`?o00001oooool00ol0003oooooooooo`09ooooo`002Oooool01Ol0
003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`0H
ooooo`CoSKSc0on;_oP2ohS6o0?oVLKf0_nIboT3oj78l`CoX/_e0_nRcOH3o`0000CoY/K`00?oYlK`
ojO2k?nW`^`01?nW`^`9ojO1k;goYl3[00?o0000ojO0jonW`>/05OnW`>/>ooooo`Co000000?ooooo
o`000?ooool01_ooool00ol0003oooooooooo`09ooooo`002Oooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`;oSKSc0_nJ_?04
oiW1l`;oVLKf0onQaO84oj78l`;oX/_e0ol00003ojK5k`;oY/K`1_nW`^`8ojO1k<;oYl3[00?o0000
ojO0jonW`>/05OnW`>/:ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`03oeEEEOmVIVKo
000000_ooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@00Gooooo0_l0000Kooooo`CoV[c`0_nI`O<2oj71l0GoXLGb0_nQb?<3o`0000?oY/C_0_nV
aNl3ojO1k0GoYl;/1_nW`Nc6ojO0j`03o`000?nW`>_oYl3[01CoYl3[1_ooool4o`0000Sooooo00?o
0000ooooooooool04Oooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`0Kooooo`;oV[c`0_nQ_^h4oj71l0;oXLGb
00CoYL;^o`000?l0003o00000onV`nh2ojK4k`OoYl7/0_nW`^`5ojO1k<WoYl3[00?o0000ojO0jonW
`>/05OnW`>/2ooooo`?o00003?ooool00ol0003oooooooooo`0Aooooo`008_ooool00ol0003ooooo
ooooo`0Mooooo`CoXKk^0_nQ`O001?nU`Ngo0000o`000?l00003ojG2kP;oY/?^4?nW`Nc;ojO0j`03
o`000?nW`>_oYl3[01GoYl3[00?o0000ooooooooool03_ooool00ol0003oooooooooo`0@ooooo`00
8_ooool00ol0003oooooooooo`0Nooooo`;oXKk^0_nU_n`2o`0000?oYL7]0_nU`^hAojO1k<koYl3[
00?o0000ojO0jonW`>/05OnW`>/@ooooo`03o`000?oooooooooo013ooooo000Rooooo`;o00008?oo
ool3o`0000;oYKo/0_nU`Nd2ojO0k0KoYl7/0_nW`>`7ojO1k=;oYl3[00?o0000ojO0jonW`>/05?nW
`>/@ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo01cooooo0ol00000
0oooooooYKo/ojFok007ojO0k0;oYl7/1_nW`>`2ojO1k=KoYl3[00?o0000ojO0jonW`>/05OnW`>/?
ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo01Wooooo0ol00006oooo
o`KoYl3/0_nW`>/6ojO0k=[oYl3[00?o0000ojO0jonW`>/05?nW`>/?ooooo`03o`000?oooooooooo
013ooooo000Rooooo`03o`000?oooooooooo01Kooooo0ol0000:ooooo`;oYl3/1_nW`>/2ojO0k=ko
Yl3[00?o0000ojO0jonW`>/05?nW`>/>ooooo`03o`000?oooooooooo013ooooo000Rooooo`;o0000
5?ooool3o`0000koooooj?nW`>/00ol0003oYl3[ojO0j`0DojO0j`gooooo00?o0000ooooooooool0
4?ooool0027ooooo0_l0000Booooo`?o00004_oooooWojO0j`03o`000?nW`>_oYl3[01GoYl3[3?oo
ool00ol0003oooooooooo`0@ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B46ooooo`;o000000?o410@ooooooooool00oooool00ol0003oooooooooo`0?ooooo`;o00005_oo
oooWojO0j`03o`000?nW`>_oYl3[01CoYl3[3Oooool00ol0003oooooooooo`0?ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool03?ooool3o`0001WoooooionW`>/00ol0003oYl3[ojO0j`0DojO0j`cooooo00?o
0000ooooooooool03oooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001Ooo
ool2o`0000[ooooo0ol0000MooooonKoYl3[00?o0000ojO0jonW`>/05OnW`>/;ooooo`03o`000?oo
oooooooo00oooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMoooo
ool00006ooooo`03o`000?oooooooooo00Kooooo0ol0000QooooonKoYl3[00?o0000ojO0jonW`>/0
5OnW`>/:ooooo`03o`000?oooooooooo00oooooo0007ooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool00006ooooo`03o`000?oooooooooo00?ooooo0ol0000VooooonGo
Yl3[00?o0000ojO0jonW`>/05?nW`>/:ooooo`03o`000?oooooooooo00oooooo0007ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000005ooooo`04o`000?oooooooooooooo
o`?o0000:_oooooUojO0j`03o`000?nW`>_oYl3[01CoYl3[2Oooool00ol0003oooooooooo`0?oooo
o`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001Oooool4o`00
02koooooi?nW`>/00ol0003oYl3[ojO0j`0DojO0j`Wooooo00?o0000ooooooooool03oooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Cooooo0_l0000aoooo
onCoYl3[00?o0000ojO0jonW`>/05?nW`>/8ooooo`03o`000?oooooooooo00oooooo000Rooooo`03
o`000?oooooooooo02ooooooi?nW`>/00ol0003oYl3[ojO0j`0CojO0j`Wooooo00?o0000oooooooo
ool03_ooool002?ooooo00?o0000ooooooooool0;ooooooSojO0j`03o`000?nW`>_oYl3[01CoYl3[
2?ooool00ol0003oooooooooo`0>ooooo`009?ooool00ol0003oooooooooo`0_ooooon?oYl3[00?o
0000ojO0jonW`>/05?nW`>/7ooooo`03o`000?oooooooooo00kooooo000Uooooo`;o0000<?oooooS
ojO0j`03o`000?nW`>_oYl3[01CoYl3[1_ooool00ol0003oooooooooo`0>ooooo`009oooool00ol0
003oooooooooo`0^ooooon?oYl3[00?o0000ojO0jonW`>/04onW`>/6ooooo`03o`000?oooooooooo
00kooooo000Xooooo`03o`000?oooooooooo02koooooh_nW`>/00ol0003oYl3[ojO0j`0DojO0j`Go
oooo00?o0000ooooooooool03_ooool002Wooooo00?o0000ooooooooool0;ooooooQojO0j`03o`00
0?nW`>_oYl3[01CoYl3[1?ooool00ol0003oooooooooo`0>ooooo`00:_ooool2o`00037oooooh?nW
`>/00ol0003oYl3[ojO0j`0DojO0j`?ooooo00?o0000ooooooooool03_ooool002cooooo00?o0000
ooooooooool0;ooooooPojO0j`03o`000?nW`>_oYl3[01CoYl3[0oooool00ol0003oooooooooo`0=
ooooo`00;Oooool00ol0003oooooooooo`0_ooooomooYl3[00?o0000ojO0jonW`>/05?nW`>/3oooo
o`03o`000?oooooooooo00gooooo000^ooooo`03o`000?oooooooooo02oooooogonW`>/00ol0003o
Yl3[ojO0j`0DojO0j`;ooooo00?o0000ooooooooool03Oooool002oooooo00?o0000ooooooooool0
;ooooooOojO0j`03o`000?nW`>_oYl3[01?oYl3[0_ooool00ol0003oooooooooo`0=ooooo`00<?oo
ool2o`00033ooooog_nW`>/00ol0003oYl3[ojO0j`0DojO0j`03ooooool0003ooooo00kooooo000b
ooooo`03o`000?oooooooooo02kooooog_nW`>/00ol0003oYl3[ojO0j`0CojO0j`03ooooool0003o
oooo00kooooo000cooooo`03o`000?oooooooooo02kooooog_nW`>/00ol0003oYl3[ojO0j`0CojO0
j`03o`000?oooooooooo00gooooo000dooooo`03o`000?oooooooooo02kooooog_nW`>/00ol0003o
Yl3[ojO0j`0AojO0j`03ooooool0003ooooo00kooooo000eooooo`;o0000;ooooooMojO0j`03o`00
0?nW`>_oYl3[00goYl3[1_ooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003ooooooooo
o`0^ooooomcoYl3[00?o0000ojO0jonW`>/02OnW`>/9ooooo`03o`000?oooooooooo00cooooo000h
ooooo`03o`000?oooooooooo02kooooog?nW`>/00ol0003oYl3[ojO0j`05ojO0j`cooooo00?o0000
ooooooooool03?ooool003Wooooo00?o0000ooooooooool0;_oooooLojO0j`03o`000?nW`>_oYl3[
013ooooo00?o0000ooooooooool03?ooool003[ooooo0_l0000_ooooom_oYl3[00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0<ooooo`00??ooool00ol0003oooooooooo`0]ooooomKoYl3[
1Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo000mooooo`03o`000?oo
oooooooo02goooood_nW`>/9ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?oo
ool003kooooo00?o0000ooooooooool0;Oooooo:ojO0ja3ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0<ooooo`00?oooool2o`0002ooooooaOnW`>/Dooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool02oooool0047ooooo00?o0000ooooooooool0;Oooooo1ojO0jaSo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`00@_ooool00ol0003ooooo
ooooo`0]oooookcoYl3[7Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
0013ooooo`03o`000?oooooooooo02gooooo^?nW`>/Pooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02oooool004Cooooo00?o0000ooooooooool0;OoooondojO0jbCooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0;ooooo`00AOooool2o`0002oooooo[_nW`>/Yoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool004Oooooo00?o0000oooooooo
ool0;OoooonZojO0jbcooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`00
B?ooool00ol0003oooooooooo`0]ooooojKoYl3[<?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00_ooooo0019ooooo`03o`000?oooooooooo02goooooX_nW`>/dooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool004[ooooo0_l0000^oooooigoYl3[>Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo001<ooooo`03o`000?oooooooooo
02coooooVOnW`>/looooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool004go
oooo00?o0000ooooooooool0;?oooonBojO0jd?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0:ooooo`00C_ooool00ol0003oooooooooo`0]ooooohgoYl3[Aoooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00[ooooo001?ooooo`;o0000;_oooon8ojO0jdcooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`00DOooool00ol0003oooooooooo`0/
ooooohCoYl3[Coooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo001Boooo
o`03o`000?oooooooooo02_oooooPOnW`>]Cooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02_ooool005?ooooo00?o0000ooooooooool0:ooooommojO0jeOooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`09ooooo`00E?ooool2o`0002goooooN?nW`>]Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02Oooool005Kooooo00?o0000ooooooooool0:ooo
oomdojO0jekooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`00Eoooool0
0ol0003oooooooooo`0[ooooofcoYl3[I_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Wooooo001Hooooo`03o`000?oooooooooo02coooooIonW`>]Zooooo`05o`000?oooooooooo
ooooool000002oooool005Wooooo00?o0000ooooooooool0;?oooomSojO0jfgooooo00Go0000oooo
ooooooooooooo`00000;ooooo`00F_ooool2o`0002goooooGonW`>]aooooo`04o`000?oooooooooo
o`0000_ooooo001Looooo`03o`000?oooooooooo02_oooooFonW`>]eooooo`03o`000?oooooo0000
00_ooooo001Mooooo`03o`000?oooooooooo02_oooooEonW`>]hooooo`04o`000?ooooooooooo`00
00[ooooo001Nooooo`03o`000?oooooooooo02_oooooDonW`>]looooo`03o`000?oooooo000000[o
oooo001Oooooo`;o0000;?oooom<ojO0jh?ooooo0_l0000:ooooo`00HOooool00ol0003ooooooooo
o`0ZooooodSoYl3[QOooool3o`0000[ooooo001Rooooo`03o`000?oooooooooo02_ooooo@onW`>^4
ooooo`Co00003Oooool006?ooooo00?o0000ooooooooool0:oooooloojO0jh?ooooo1?l0000Aoooo
o`00I?ooool2o`0002cooooo>onW`>^3ooooo`?o00005Oooool006Kooooo00?o0000ooooooooool0
:ooooolcojO0jhGooooo1?l0000Hooooo`00Ioooool00ol0003oooooooooo`0Zoooooc3oYl3[Q?oo
ool4o`0001cooooo001Xooooo`03o`000?oooooooooo02[ooooo;?nW`>^3ooooo`Co00008?ooool0
06Wooooo0_l0000/ooooobOoYl3[P_ooool4o`0002Cooooo001[ooooo`03o`000?oooooooooo02[o
oooo8onW`>^2ooooo`?o0000:?ooool006cooooo00?o0000ooooooooool0:_oooolMojO0jh?ooooo
1?l0000[ooooo`00KOooool00ol0003oooooooooo`0[oooooaSoYl3[P_ooool4o`0002oooooo001^
ooooo`03o`000?oooooooooo02[ooooo5OnW`>^1ooooo`Co0000<oooool006oooooo0_l0000[oooo
oa7oYl3[P?ooool4o`0003Oooooo001aooooo`03o`000?oooooooooo02[ooooo2OnW`>^2ooooo`Co
0000>oooool007;ooooo00?o0000ooooooooool0:_ooool5ojO0jh;ooooo0ol0000oooooo`00Looo
ool00ol0003oooooooooo`0Zooooo`03ojO0jooooooooooo07oooooo1?l00012ooooo`00M?ooool2
o`0002[ooooo00?o0000ooooooooool0Noooool4o`0004Kooooo001fooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0N?ooool4o`0004[ooooo001gooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0M?ooool4o`0004kooooo001hooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0LOooool3o`0005;ooooo001iooooo`;o00009?ooool00ol0003ooooooooo
o`1]ooooo`Co0000EOooool007_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Y
ooooo`Co0000FOooool007cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Uoooo
o`Co0000GOooool007gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Qooooo`Co
0000HOooool007kooooo0_l0000Oooooo`03o`000?oooooooooo05gooooo1?l0001Uooooo`00P?oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05[ooooo0ol0001Yooooo`00POooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Kooooo1?l0001/ooooo`00P_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo05;ooooo1?l0001`ooooo`00Poooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo04kooooo1?l0001dooooo`00Q?ooool2o`0001Wooooo
00?o0000ooooooooool0B_ooool4o`0007Sooooo0026ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0A_ooool4o`0007cooooo0027ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0@oooool3o`00083ooooo0028ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0?oooool4o`0008?ooooo0029ooooo`;o00005?ooool00ol0003oooooooooo`0kooooo`Co
0000Qoooool008_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0gooooo`Co0000
Roooool008cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0cooooo`Co0000Sooo
ool008gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0`ooooo`?o0000Toooool0
08kooooo0_l0000?ooooo`03o`000?oooooooooo02cooooo1?l0002Fooooo`00T?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo02Sooooo1?l0002Jooooo`00TOooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo02Cooooo1?l0002Nooooo`00T_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo027ooooo1?l0002Rooooo`00Toooool2o`0000Wooooo00?o0000
ooooooooool07Oooool4o`000:Kooooo002Eooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool06_ooool3o`000:[ooooo002Fooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool05_ooool4o`000:gooooo002Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
4_ooool4o`000;7ooooo002Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_oo
ool4o`000;Gooooo002Iooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000^Oooool0
09_ooooo00Co0000oooooooooooo00002Oooool3o`000;gooooo002Looooo`03o`000?oooooo0000
00Gooooo1?l00030ooooo`00WOooool2o`000003ooooool0003o000000;o0000a?ooool009kooooo
0_l00038ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00[_ooool01OnHV9So0000o`000?m4A4Co
^[Zj00Wooooo1Ol00005ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo09Gooooo002^oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool6o`000006oooooonHV9So8B4Qonk^k_ooooooA4A4
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool0U_ooool00:kooooo00?o0000ooooooooool03?oo
ool00onHV9So8B4Qonk^kP0<ooooo`Go0000Uoooool00:kooooo00?o0000ooooooooool01?ooool6
o`0000?ooooo00?oV9RHob4Q8Oo^k^h02oooool01?m4A4CogMgMooooool0002Hooooo`00[_ooool0
0ol0003oooooooooo`0>ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoeEEEOoooooo0000V?oo
ool00:cooooo00?o410@o`000?l000000ol0000>ooooo`03o`000?oooooooooo00[ooooo00?oMgMg
olc<c?l00000V?ooool00:kooooo00?o0000ooooooooool02oooool01Ol0003o^[ZjoooooonHV9So
410@00cooooo00?ok^k^odA4A?l00000V?ooool00:kooooo00?o0000ooooooooool02oooool01OnH
V9So410@o`000?lQ8B7oc<c<00gooooo00?oMgMgo`000?ooool0Uoooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -17 0 ]
[.5 .82364 17 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69467 Mtetra
.4053 .69467 .41061 .69934 .41957 .69681 .41427 .69213 Mtetra
.41427 .69213 .41957 .69681 .42855 .69428 .42327 .68958 Mtetra
.42327 .68958 .42855 .69428 .43756 .69174 .43231 .68703 Mtetra
.43231 .68703 .43756 .69174 .4466 .68919 .44137 .68446 Mtetra
.44137 .68446 .4466 .68919 .45567 .68663 .45046 .68189 Mtetra
.45046 .68189 .45567 .68663 .46478 .68407 .45958 .67931 Mtetra
.45958 .67931 .46478 .68407 .47391 .68149 .46873 .67671 Mtetra
.46873 .67671 .47391 .68149 .48307 .67891 .47792 .67412 Mtetra
.47792 .67412 .48307 .67891 .49227 .67632 .48713 .67151 Mtetra
.48713 .67151 .49227 .67632 .50149 .67371 .49638 .66889 Mtetra
.49638 .66889 .50149 .67371 .51075 .6711 .50565 .66626 Mtetra
.50565 .66626 .51075 .6711 .52004 .66849 .51496 .66363 Mtetra
.51496 .66363 .52004 .66849 .52936 .66586 .5243 .66098 Mtetra
.5243 .66098 .52936 .66586 .53871 .66322 .53367 .65833 Mtetra
.53367 .65833 .53871 .66322 .54809 .66058 .54308 .65567 Mtetra
.54308 .65567 .54809 .66058 .55751 .65792 .55251 .653 Mtetra
.55251 .653 .55751 .65792 .56695 .65526 .56198 .65032 Mtetra
.56198 .65032 .56695 .65526 .57643 .65259 .57148 .64763 Mtetra
.57148 .64763 .57643 .65259 .58595 .6499 .58102 .64493 Mtetra
.58102 .64493 .58595 .6499 .59549 .64721 .59058 .64222 Mtetra
.59058 .64222 .59549 .64721 .60507 .64451 .60018 .6395 Mtetra
.60018 .6395 .60507 .64451 .61468 .6418 .60982 .63678 Mtetra
.60982 .63678 .61468 .6418 .62432 .63908 .61948 .63404 Mtetra
.61948 .63404 .62432 .63908 .634 .63636 .62918 .63129 Mtetra
.62918 .63129 .634 .63636 .64371 .63362 .63892 .62854 Mtetra
.63892 .62854 .64371 .63362 .65345 .63087 .64868 .62577 Mtetra
.64868 .62577 .65345 .63087 .66323 .62811 .65848 .623 Mtetra
.65848 .623 .66323 .62811 .67304 .62535 .66832 .62021 Mtetra
.66832 .62021 .67304 .62535 .68289 .62257 .67819 .61742 Mtetra
.67819 .61742 .68289 .62257 .69277 .61979 .68809 .61462 Mtetra
.68809 .61462 .69277 .61979 .70269 .61699 .69803 .6118 Mtetra
.69803 .6118 .70269 .61699 .71264 .61418 .70801 .60898 Mtetra
.70801 .60898 .71264 .61418 .72262 .61137 .71802 .60615 Mtetra
.71802 .60615 .72262 .61137 .73264 .60854 .72806 .6033 Mtetra
.72806 .6033 .73264 .60854 .7427 .60571 .73814 .60045 Mtetra
.73814 .60045 .7427 .60571 .75279 .60286 .74826 .59759 Mtetra
.74826 .59759 .75279 .60286 .76291 .60001 .75841 .59471 Mtetra
.75841 .59471 .76291 .60001 .77308 .59714 .7686 .59183 Mtetra
.7686 .59183 .77308 .59714 .78328 .59427 .77882 .58893 Mtetra
.77882 .58893 .78328 .59427 .79351 .59138 .78908 .58603 Mtetra
.78908 .58603 .79351 .59138 .80378 .58849 .79938 .58311 Mtetra
.79938 .58311 .80378 .58849 .81409 .58558 .80971 .58019 Mtetra
.80971 .58019 .81409 .58558 .82443 .58267 .82008 .57725 Mtetra
.82008 .57725 .82443 .58267 .83482 .57974 .83049 .57431 Mtetra
.83049 .57431 .83482 .57974 .84523 .5768 .84094 .57135 Mtetra
.84094 .57135 .84523 .5768 .85569 .57385 .85142 .56838 Mtetra
.85142 .56838 .85569 .57385 .86618 .57089 .86194 .5654 Mtetra
.86194 .5654 .86618 .57089 .87672 .56792 .8725 .56241 Mtetra
.8725 .56241 .87672 .56792 .88729 .56494 .8831 .55941 Mtetra
.8831 .55941 .88729 .56494 .89789 .56195 .89374 .5564 Mtetra
.89374 .5564 .89789 .56195 .90854 .55895 .90441 .55338 Mtetra
.90441 .55338 .90854 .55895 .91923 .55594 .91512 .55035 Mtetra
.91512 .55035 .91923 .55594 .92995 .55292 .92588 .5473 Mtetra
.92588 .5473 .92995 .55292 .94071 .54988 .93667 .54425 Mtetra
.93667 .54425 .94071 .54988 .95152 .54684 .9475 .54118 Mtetra
.9475 .54118 .95152 .54684 .96236 .54378 .95837 .53811 Mtetra
.95837 .53811 .96236 .54378 .97324 .54071 .96928 .53502 Mtetra
.96928 .53502 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.391 .69252 .39636 .6972 .4053 .69467 .39996 .68998 Mtetra
.39996 .68998 .4053 .69467 .41427 .69213 .40895 .68742 Mtetra
.40895 .68742 .41427 .69213 .42327 .68958 .41797 .68486 Mtetra
.41797 .68486 .42327 .68958 .43231 .68703 .42702 .68228 Mtetra
.42702 .68228 .43231 .68703 .44137 .68446 .4361 .6797 Mtetra
.4361 .6797 .44137 .68446 .45046 .68189 .44521 .67711 Mtetra
.44521 .67711 .45046 .68189 .45958 .67931 .45435 .67452 Mtetra
.45435 .67452 .45958 .67931 .46873 .67671 .46352 .67191 Mtetra
.46352 .67191 .46873 .67671 .47792 .67412 .47273 .66929 Mtetra
.47273 .66929 .47792 .67412 .48713 .67151 .48196 .66667 Mtetra
.48196 .66667 .48713 .67151 .49638 .66889 .49123 .66403 Mtetra
.49123 .66403 .49638 .66889 .50565 .66626 .50053 .66139 Mtetra
.50053 .66139 .50565 .66626 .51496 .66363 .50985 .65874 Mtetra
.50985 .65874 .51496 .66363 .5243 .66098 .51922 .65608 Mtetra
.51922 .65608 .5243 .66098 .53367 .65833 .52861 .65341 Mtetra
.52861 .65341 .53367 .65833 .54308 .65567 .53803 .65073 Mtetra
.53803 .65073 .54308 .65567 .55251 .653 .54749 .64804 Mtetra
.54749 .64804 .55251 .653 .56198 .65032 .55698 .64534 Mtetra
.55698 .64534 .56198 .65032 .57148 .64763 .5665 .64264 Mtetra
.5665 .64264 .57148 .64763 .58102 .64493 .57606 .63992 Mtetra
.57606 .63992 .58102 .64493 .59058 .64222 .58565 .6372 Mtetra
.58565 .6372 .59058 .64222 .60018 .6395 .59527 .63446 Mtetra
.59527 .63446 .60018 .6395 .60982 .63678 .60493 .63172 Mtetra
.60493 .63172 .60982 .63678 .61948 .63404 .61461 .62896 Mtetra
.61461 .62896 .61948 .63404 .62918 .63129 .62434 .6262 Mtetra
.62434 .6262 .62918 .63129 .63892 .62854 .63409 .62343 Mtetra
.63409 .62343 .63892 .62854 .64868 .62577 .64388 .62064 Mtetra
.64388 .62064 .64868 .62577 .65848 .623 .65371 .61785 Mtetra
.65371 .61785 .65848 .623 .66832 .62021 .66357 .61505 Mtetra
.66357 .61505 .66832 .62021 .67819 .61742 .67346 .61224 Mtetra
.67346 .61224 .67819 .61742 .68809 .61462 .68339 .60942 Mtetra
.68339 .60942 .68809 .61462 .69803 .6118 .69335 .60658 Mtetra
.69335 .60658 .69803 .6118 .70801 .60898 .70335 .60374 Mtetra
.70335 .60374 .70801 .60898 .71802 .60615 .71338 .60089 Mtetra
.71338 .60089 .71802 .60615 .72806 .6033 .72345 .59803 Mtetra
.72345 .59803 .72806 .6033 .73814 .60045 .73356 .59516 Mtetra
.73356 .59516 .73814 .60045 .74826 .59759 .7437 .59227 Mtetra
.7437 .59227 .74826 .59759 .75841 .59471 .75387 .58938 Mtetra
.75387 .58938 .75841 .59471 .7686 .59183 .76409 .58648 Mtetra
.76409 .58648 .7686 .59183 .77882 .58893 .77434 .58356 Mtetra
.77434 .58356 .77882 .58893 .78908 .58603 .78462 .58064 Mtetra
.78462 .58064 .78908 .58603 .79938 .58311 .79495 .57771 Mtetra
.79495 .57771 .79938 .58311 .80971 .58019 .80531 .57476 Mtetra
.80531 .57476 .80971 .58019 .82008 .57725 .81571 .57181 Mtetra
.81571 .57181 .82008 .57725 .83049 .57431 .82614 .56884 Mtetra
.82614 .56884 .83049 .57431 .84094 .57135 .83661 .56586 Mtetra
.83661 .56586 .84094 .57135 .85142 .56838 .84712 .56288 Mtetra
.84712 .56288 .85142 .56838 .86194 .5654 .85767 .55988 Mtetra
.85767 .55988 .86194 .5654 .8725 .56241 .86826 .55687 Mtetra
.86826 .55687 .8725 .56241 .8831 .55941 .87889 .55385 Mtetra
.87889 .55385 .8831 .55941 .89374 .5564 .88955 .55082 Mtetra
.88955 .55082 .89374 .5564 .90441 .55338 .90025 .54777 Mtetra
.90025 .54777 .90441 .55338 .91512 .55035 .911 .54472 Mtetra
.911 .54472 .91512 .55035 .92588 .5473 .92178 .54166 Mtetra
.92178 .54166 .92588 .5473 .93667 .54425 .9326 .53858 Mtetra
.9326 .53858 .93667 .54425 .9475 .54118 .94346 .53549 Mtetra
.94346 .53549 .9475 .54118 .95837 .53811 .95436 .53239 Mtetra
.95436 .53239 .95837 .53811 .96928 .53502 .9653 .52928 Mtetra
.9653 .52928 .96928 .53502 .98024 .53192 .97628 .52616 Mtetra
.38561 .68781 .391 .69252 .39996 .68998 .39459 .68525 Mtetra
.39459 .68525 .39996 .68998 .40895 .68742 .40359 .68268 Mtetra
.40359 .68268 .40895 .68742 .41797 .68486 .41263 .6801 Mtetra
.41263 .6801 .41797 .68486 .42702 .68228 .4217 .67751 Mtetra
.4217 .67751 .42702 .68228 .4361 .6797 .4308 .67492 Mtetra
.4308 .67492 .4361 .6797 .44521 .67711 .43993 .67231 Mtetra
.43993 .67231 .44521 .67711 .45435 .67452 .44909 .6697 Mtetra
.44909 .6697 .45435 .67452 .46352 .67191 .45828 .66707 Mtetra
.45828 .66707 .46352 .67191 .47273 .66929 .46751 .66444 Mtetra
.46751 .66444 .47273 .66929 .48196 .66667 .47676 .6618 Mtetra
.47676 .6618 .48196 .66667 .49123 .66403 .48605 .65915 Mtetra
.48605 .65915 .49123 .66403 .50053 .66139 .49537 .65649 Mtetra
.49537 .65649 .50053 .66139 .50985 .65874 .50472 .65382 Mtetra
.50472 .65382 .50985 .65874 .51922 .65608 .5141 .65114 Mtetra
.5141 .65114 .51922 .65608 .52861 .65341 .52351 .64846 Mtetra
.52351 .64846 .52861 .65341 .53803 .65073 .53296 .64576 Mtetra
.53296 .64576 .53803 .65073 .54749 .64804 .54244 .64305 Mtetra
.54244 .64305 .54749 .64804 .55698 .64534 .55195 .64034 Mtetra
.55195 .64034 .55698 .64534 .5665 .64264 .56149 .63762 Mtetra
.56149 .63762 .5665 .64264 .57606 .63992 .57107 .63488 Mtetra
.57107 .63488 .57606 .63992 .58565 .6372 .58068 .63214 Mtetra
.58068 .63214 .58565 .6372 .59527 .63446 .59032 .62939 Mtetra
.59032 .62939 .59527 .63446 .60493 .63172 .6 .62663 Mtetra
.6 .62663 .60493 .63172 .61461 .62896 .60971 .62385 Mtetra
.60971 .62385 .61461 .62896 .62434 .6262 .61946 .62107 Mtetra
.61946 .62107 .62434 .6262 .63409 .62343 .62924 .61828 Mtetra
.62924 .61828 .63409 .62343 .64388 .62064 .63905 .61548 Mtetra
.63905 .61548 .64388 .62064 .65371 .61785 .6489 .61267 Mtetra
.6489 .61267 .65371 .61785 .66357 .61505 .65878 .60985 Mtetra
.65878 .60985 .66357 .61505 .67346 .61224 .6687 .60702 Mtetra
.6687 .60702 .67346 .61224 .68339 .60942 .67865 .60418 Mtetra
.67865 .60418 .68339 .60942 .69335 .60658 .68864 .60133 Mtetra
.68864 .60133 .69335 .60658 .70335 .60374 .69866 .59847 Mtetra
.69866 .59847 .70335 .60374 .71338 .60089 .70872 .5956 Mtetra
.70872 .5956 .71338 .60089 .72345 .59803 .71881 .59272 Mtetra
.71881 .59272 .72345 .59803 .73356 .59516 .72894 .58983 Mtetra
.72894 .58983 .73356 .59516 .7437 .59227 .73911 .58692 Mtetra
.73911 .58692 .7437 .59227 .75387 .58938 .74931 .58401 Mtetra
.74931 .58401 .75387 .58938 .76409 .58648 .75955 .58109 Mtetra
.75955 .58109 .76409 .58648 .77434 .58356 .76982 .57816 Mtetra
.76982 .57816 .77434 .58356 .78462 .58064 .78014 .57521 Mtetra
.78014 .57521 .78462 .58064 .79495 .57771 .79049 .57226 Mtetra
.79049 .57226 .79495 .57771 .80531 .57476 .80087 .5693 Mtetra
.80087 .5693 .80531 .57476 .81571 .57181 .8113 .56632 Mtetra
.8113 .56632 .81571 .57181 .82614 .56884 .82176 .56334 Mtetra
.82176 .56334 .82614 .56884 .83661 .56586 .83226 .56034 Mtetra
.83226 .56034 .83661 .56586 .84712 .56288 .8428 .55733 Mtetra
.8428 .55733 .84712 .56288 .85767 .55988 .85337 .55431 Mtetra
.85337 .55431 .85767 .55988 .86826 .55687 .86399 .55128 Mtetra
.86399 .55128 .86826 .55687 .87889 .55385 .87464 .54824 Mtetra
.87464 .54824 .87889 .55385 .88955 .55082 .88533 .54519 Mtetra
.88533 .54519 .88955 .55082 .90025 .54777 .89607 .54213 Mtetra
.89607 .54213 .90025 .54777 .911 .54472 .90684 .53905 Mtetra
.90684 .53905 .911 .54472 .92178 .54166 .91765 .53597 Mtetra
.91765 .53597 .92178 .54166 .9326 .53858 .9285 .53287 Mtetra
.9285 .53287 .9326 .53858 .94346 .53549 .93939 .52976 Mtetra
.93939 .52976 .94346 .53549 .95436 .53239 .95032 .52664 Mtetra
.95032 .52664 .95436 .53239 .9653 .52928 .96129 .52351 Mtetra
.96129 .52351 .9653 .52928 .97628 .52616 .9723 .52037 Mtetra
.38018 .68308 .38561 .68781 .39459 .68525 .38918 .6805 Mtetra
.38918 .6805 .39459 .68525 .40359 .68268 .3982 .67791 Mtetra
.3982 .67791 .40359 .68268 .41263 .6801 .40726 .67532 Mtetra
.40726 .67532 .41263 .6801 .4217 .67751 .41635 .67271 Mtetra
.41635 .67271 .4217 .67751 .4308 .67492 .42547 .6701 Mtetra
.42547 .6701 .4308 .67492 .43993 .67231 .43462 .66748 Mtetra
.43462 .66748 .43993 .67231 .44909 .6697 .4438 .66485 Mtetra
.4438 .66485 .44909 .6697 .45828 .66707 .45301 .66221 Mtetra
.45301 .66221 .45828 .66707 .46751 .66444 .46225 .65956 Mtetra
.46225 .65956 .46751 .66444 .47676 .6618 .47153 .6569 Mtetra
.47153 .6569 .47676 .6618 .48605 .65915 .48083 .65423 Mtetra
.48083 .65423 .48605 .65915 .49537 .65649 .49017 .65156 Mtetra
.49017 .65156 .49537 .65649 .50472 .65382 .49954 .64887 Mtetra
.49954 .64887 .50472 .65382 .5141 .65114 .50895 .64618 Mtetra
.50895 .64618 .5141 .65114 .52351 .64846 .51838 .64347 Mtetra
.51838 .64347 .52351 .64846 .53296 .64576 .52785 .64076 Mtetra
.52785 .64076 .53296 .64576 .54244 .64305 .53735 .63804 Mtetra
.53735 .63804 .54244 .64305 .55195 .64034 .54688 .6353 Mtetra
.54688 .6353 .55195 .64034 .56149 .63762 .55645 .63256 Mtetra
.55645 .63256 .56149 .63762 .57107 .63488 .56605 .62981 Mtetra
.56605 .62981 .57107 .63488 .58068 .63214 .57568 .62705 Mtetra
.57568 .62705 .58068 .63214 .59032 .62939 .58535 .62428 Mtetra
.58535 .62428 .59032 .62939 .6 .62663 .59505 .6215 Mtetra
.59505 .6215 .6 .62663 .60971 .62385 .60478 .61871 Mtetra
.60478 .61871 .60971 .62385 .61946 .62107 .61455 .61591 Mtetra
.61455 .61591 .61946 .62107 .62924 .61828 .62435 .6131 Mtetra
.62435 .6131 .62924 .61828 .63905 .61548 .63419 .61028 Mtetra
.63419 .61028 .63905 .61548 .6489 .61267 .64406 .60746 Mtetra
.64406 .60746 .6489 .61267 .65878 .60985 .65396 .60462 Mtetra
.65396 .60462 .65878 .60985 .6687 .60702 .66391 .60177 Mtetra
.66391 .60177 .6687 .60702 .67865 .60418 .67388 .59891 Mtetra
.67388 .59891 .67865 .60418 .68864 .60133 .68389 .59604 Mtetra
.68389 .59604 .68864 .60133 .69866 .59847 .69394 .59316 Mtetra
.69394 .59316 .69866 .59847 .70872 .5956 .70402 .59027 Mtetra
.70402 .59027 .70872 .5956 .71881 .59272 .71414 .58737 Mtetra
.71414 .58737 .71881 .59272 .72894 .58983 .7243 .58446 Mtetra
.7243 .58446 .72894 .58983 .73911 .58692 .73449 .58154 Mtetra
.73449 .58154 .73911 .58692 .74931 .58401 .74472 .57861 Mtetra
.74472 .57861 .74931 .58401 .75955 .58109 .75498 .57567 Mtetra
.75498 .57567 .75955 .58109 .76982 .57816 .76528 .57272 Mtetra
.76528 .57272 .76982 .57816 .78014 .57521 .77562 .56975 Mtetra
.77562 .56975 .78014 .57521 .79049 .57226 .786 .56678 Mtetra
.786 .56678 .79049 .57226 .80087 .5693 .79641 .5638 Mtetra
.79641 .5638 .80087 .5693 .8113 .56632 .80686 .5608 Mtetra
.80686 .5608 .8113 .56632 .82176 .56334 .81735 .55779 Mtetra
.81735 .55779 .82176 .56334 .83226 .56034 .82788 .55478 Mtetra
.82788 .55478 .83226 .56034 .8428 .55733 .83844 .55175 Mtetra
.83844 .55175 .8428 .55733 .85337 .55431 .84905 .54871 Mtetra
.84905 .54871 .85337 .55431 .86399 .55128 .85969 .54566 Mtetra
.85969 .54566 .86399 .55128 .87464 .54824 .87037 .5426 Mtetra
.87037 .5426 .87464 .54824 .88533 .54519 .88109 .53953 Mtetra
.88109 .53953 .88533 .54519 .89607 .54213 .89185 .53644 Mtetra
.89185 .53644 .89607 .54213 .90684 .53905 .90265 .53335 Mtetra
.90265 .53335 .90684 .53905 .91765 .53597 .91349 .53024 Mtetra
.91349 .53024 .91765 .53597 .9285 .53287 .92437 .52712 Mtetra
.92437 .52712 .9285 .53287 .93939 .52976 .93529 .524 Mtetra
.93529 .524 .93939 .52976 .95032 .52664 .94625 .52085 Mtetra
.94625 .52085 .95032 .52664 .96129 .52351 .95725 .5177 Mtetra
.95725 .5177 .96129 .52351 .9723 .52037 .96829 .51454 Mtetra
.37472 .67831 .38018 .68308 .38918 .6805 .38373 .67572 Mtetra
.38373 .67572 .38918 .6805 .3982 .67791 .39278 .67311 Mtetra
.39278 .67311 .3982 .67791 .40726 .67532 .40186 .6705 Mtetra
.40186 .6705 .40726 .67532 .41635 .67271 .41096 .66788 Mtetra
.41096 .66788 .41635 .67271 .42547 .6701 .4201 .66525 Mtetra
.4201 .66525 .42547 .6701 .43462 .66748 .42927 .66261 Mtetra
.42927 .66261 .43462 .66748 .4438 .66485 .43847 .65996 Mtetra
.43847 .65996 .4438 .66485 .45301 .66221 .4477 .65731 Mtetra
.4477 .65731 .45301 .66221 .46225 .65956 .45697 .65464 Mtetra
.45697 .65464 .46225 .65956 .47153 .6569 .46626 .65197 Mtetra
.46626 .65197 .47153 .6569 .48083 .65423 .47559 .64928 Mtetra
.47559 .64928 .48083 .65423 .49017 .65156 .48495 .64659 Mtetra
.48495 .64659 .49017 .65156 .49954 .64887 .49434 .64389 Mtetra
.49434 .64389 .49954 .64887 .50895 .64618 .50376 .64118 Mtetra
.50376 .64118 .50895 .64618 .51838 .64347 .51322 .63846 Mtetra
.51322 .63846 .51838 .64347 .52785 .64076 .52271 .63572 Mtetra
.52271 .63572 .52785 .64076 .53735 .63804 .53223 .63298 Mtetra
.53223 .63298 .53735 .63804 .54688 .6353 .54178 .63024 Mtetra
.54178 .63024 .54688 .6353 .55645 .63256 .55137 .62748 Mtetra
.55137 .62748 .55645 .63256 .56605 .62981 .56099 .62471 Mtetra
.56099 .62471 .56605 .62981 .57568 .62705 .57065 .62193 Mtetra
.57065 .62193 .57568 .62705 .58535 .62428 .58034 .61914 Mtetra
.58034 .61914 .58535 .62428 .59505 .6215 .59006 .61634 Mtetra
.59006 .61634 .59505 .6215 .60478 .61871 .59982 .61354 Mtetra
.59982 .61354 .60478 .61871 .61455 .61591 .60961 .61072 Mtetra
.60961 .61072 .61455 .61591 .62435 .6131 .61943 .60789 Mtetra
.61943 .60789 .62435 .6131 .63419 .61028 .62929 .60505 Mtetra
.62929 .60505 .63419 .61028 .64406 .60746 .63919 .60221 Mtetra
.63919 .60221 .64406 .60746 .65396 .60462 .64912 .59935 Mtetra
.64912 .59935 .65396 .60462 .66391 .60177 .65908 .59648 Mtetra
.65908 .59648 .66391 .60177 .67388 .59891 .66908 .5936 Mtetra
.66908 .5936 .67388 .59891 .68389 .59604 .67912 .59072 Mtetra
.67912 .59072 .68389 .59604 .69394 .59316 .68919 .58782 Mtetra
.68919 .58782 .69394 .59316 .70402 .59027 .6993 .58491 Mtetra
.6993 .58491 .70402 .59027 .71414 .58737 .70944 .58199 Mtetra
.70944 .58199 .71414 .58737 .7243 .58446 .71962 .57906 Mtetra
.71962 .57906 .7243 .58446 .73449 .58154 .72984 .57612 Mtetra
.72984 .57612 .73449 .58154 .74472 .57861 .74009 .57317 Mtetra
.74009 .57317 .74472 .57861 .75498 .57567 .75038 .57021 Mtetra
.75038 .57021 .75498 .57567 .76528 .57272 .76071 .56724 Mtetra
.76071 .56724 .76528 .57272 .77562 .56975 .77107 .56426 Mtetra
.77107 .56426 .77562 .56975 .786 .56678 .78148 .56126 Mtetra
.78148 .56126 .786 .56678 .79641 .5638 .79192 .55826 Mtetra
.79192 .55826 .79641 .5638 .80686 .5608 .80239 .55524 Mtetra
.80239 .55524 .80686 .5608 .81735 .55779 .81291 .55222 Mtetra
.81291 .55222 .81735 .55779 .82788 .55478 .82346 .54918 Mtetra
.82346 .54918 .82788 .55478 .83844 .55175 .83406 .54613 Mtetra
.83406 .54613 .83844 .55175 .84905 .54871 .84469 .54307 Mtetra
.84469 .54307 .84905 .54871 .85969 .54566 .85536 .54 Mtetra
.85536 .54 .85969 .54566 .87037 .5426 .86607 .53692 Mtetra
.86607 .53692 .87037 .5426 .88109 .53953 .87682 .53383 Mtetra
.87682 .53383 .88109 .53953 .89185 .53644 .88761 .53072 Mtetra
.88761 .53072 .89185 .53644 .90265 .53335 .89844 .52761 Mtetra
.89844 .52761 .90265 .53335 .91349 .53024 .90931 .52448 Mtetra
.90931 .52448 .91349 .53024 .92437 .52712 .92022 .52134 Mtetra
.92022 .52134 .92437 .52712 .93529 .524 .93116 .51819 Mtetra
.93116 .51819 .93529 .524 .94625 .52085 .94216 .51503 Mtetra
.94216 .51503 .94625 .52085 .95725 .5177 .95319 .51185 Mtetra
.95319 .51185 .95725 .5177 .96829 .51454 .96426 .50866 Mtetra
.36922 .67351 .37472 .67831 .38373 .67572 .37826 .6709 Mtetra
.37826 .6709 .38373 .67572 .39278 .67311 .38732 .66828 Mtetra
.38732 .66828 .39278 .67311 .40186 .6705 .39642 .66566 Mtetra
.39642 .66566 .40186 .6705 .41096 .66788 .40554 .66302 Mtetra
.40554 .66302 .41096 .66788 .4201 .66525 .4147 .66037 Mtetra
.4147 .66037 .4201 .66525 .42927 .66261 .42389 .65772 Mtetra
.42389 .65772 .42927 .66261 .43847 .65996 .43311 .65505 Mtetra
.43311 .65505 .43847 .65996 .4477 .65731 .44236 .65238 Mtetra
.44236 .65238 .4477 .65731 .45697 .65464 .45165 .6497 Mtetra
.45165 .6497 .45697 .65464 .46626 .65197 .46096 .64701 Mtetra
.46096 .64701 .46626 .65197 .47559 .64928 .47031 .6443 Mtetra
.47031 .6443 .47559 .64928 .48495 .64659 .47969 .64159 Mtetra
.47969 .64159 .48495 .64659 .49434 .64389 .4891 .63887 Mtetra
.4891 .63887 .49434 .64389 .50376 .64118 .49855 .63615 Mtetra
.49855 .63615 .50376 .64118 .51322 .63846 .50802 .63341 Mtetra
.50802 .63341 .51322 .63846 .52271 .63572 .51753 .63066 Mtetra
.51753 .63066 .52271 .63572 .53223 .63298 .52708 .6279 Mtetra
.52708 .6279 .53223 .63298 .54178 .63024 .53665 .62513 Mtetra
.53665 .62513 .54178 .63024 .55137 .62748 .54626 .62236 Mtetra
.54626 .62236 .55137 .62748 .56099 .62471 .55591 .61957 Mtetra
.55591 .61957 .56099 .62471 .57065 .62193 .56558 .61677 Mtetra
.56558 .61677 .57065 .62193 .58034 .61914 .57529 .61397 Mtetra
.57529 .61397 .58034 .61914 .59006 .61634 .58504 .61115 Mtetra
.58504 .61115 .59006 .61634 .59982 .61354 .59482 .60833 Mtetra
.59482 .60833 .59982 .61354 .60961 .61072 .60463 .60549 Mtetra
.60463 .60549 .60961 .61072 .61943 .60789 .61448 .60265 Mtetra
.61448 .60265 .61943 .60789 .62929 .60505 .62437 .59979 Mtetra
.62437 .59979 .62929 .60505 .63919 .60221 .63428 .59692 Mtetra
.63428 .59692 .63919 .60221 .64912 .59935 .64424 .59405 Mtetra
.64424 .59405 .64912 .59935 .65908 .59648 .65423 .59116 Mtetra
.65423 .59116 .65908 .59648 .66908 .5936 .66425 .58826 Mtetra
.66425 .58826 .66908 .5936 .67912 .59072 .67431 .58536 Mtetra
.67431 .58536 .67912 .59072 .68919 .58782 .68441 .58244 Mtetra
.68441 .58244 .68919 .58782 .6993 .58491 .69454 .57951 Mtetra
.69454 .57951 .6993 .58491 .70944 .58199 .70471 .57657 Mtetra
.70471 .57657 .70944 .58199 .71962 .57906 .71491 .57363 Mtetra
.71491 .57363 .71962 .57906 .72984 .57612 .72516 .57067 Mtetra
.72516 .57067 .72984 .57612 .74009 .57317 .73544 .5677 Mtetra
.73544 .5677 .74009 .57317 .75038 .57021 .74575 .56471 Mtetra
.74575 .56471 .75038 .57021 .76071 .56724 .75611 .56172 Mtetra
.75611 .56172 .76071 .56724 .77107 .56426 .7665 .55872 Mtetra
.7665 .55872 .77107 .56426 .78148 .56126 .77693 .55571 Mtetra
.77693 .55571 .78148 .56126 .79192 .55826 .78739 .55268 Mtetra
.78739 .55268 .79192 .55826 .80239 .55524 .7979 .54965 Mtetra
.7979 .54965 .80239 .55524 .81291 .55222 .80844 .5466 Mtetra
.80844 .5466 .81291 .55222 .82346 .54918 .81902 .54354 Mtetra
.81902 .54354 .82346 .54918 .83406 .54613 .82964 .54047 Mtetra
.82964 .54047 .83406 .54613 .84469 .54307 .8403 .53739 Mtetra
.8403 .53739 .84469 .54307 .85536 .54 .851 .5343 Mtetra
.851 .5343 .85536 .54 .86607 .53692 .86174 .5312 Mtetra
.86174 .5312 .86607 .53692 .87682 .53383 .87252 .52809 Mtetra
.87252 .52809 .87682 .53383 .88761 .53072 .88334 .52496 Mtetra
.88334 .52496 .88761 .53072 .89844 .52761 .89419 .52182 Mtetra
.89419 .52182 .89844 .52761 .90931 .52448 .90509 .51867 Mtetra
.90509 .51867 .90931 .52448 .92022 .52134 .91603 .51551 Mtetra
.91603 .51551 .92022 .52134 .93116 .51819 .92701 .51234 Mtetra
.92701 .51234 .93116 .51819 .94216 .51503 .93803 .50916 Mtetra
.93803 .50916 .94216 .51503 .95319 .51185 .94909 .50596 Mtetra
.94909 .50596 .95319 .51185 .96426 .50866 .9602 .50275 Mtetra
.36369 .66869 .36922 .67351 .37826 .6709 .37275 .66606 Mtetra
.37275 .66606 .37826 .6709 .38732 .66828 .38183 .66342 Mtetra
.38183 .66342 .38732 .66828 .39642 .66566 .39094 .66078 Mtetra
.39094 .66078 .39642 .66566 .40554 .66302 .40009 .65813 Mtetra
.40009 .65813 .40554 .66302 .4147 .66037 .40927 .65546 Mtetra
.40927 .65546 .4147 .66037 .42389 .65772 .41848 .65279 Mtetra
.41848 .65279 .42389 .65772 .43311 .65505 .42772 .65011 Mtetra
.42772 .65011 .43311 .65505 .44236 .65238 .43699 .64742 Mtetra
.43699 .64742 .44236 .65238 .45165 .6497 .44629 .64472 Mtetra
.44629 .64472 .45165 .6497 .46096 .64701 .45563 .64201 Mtetra
.45563 .64201 .46096 .64701 .47031 .6443 .465 .63929 Mtetra
.465 .63929 .47031 .6443 .47969 .64159 .4744 .63657 Mtetra
.4744 .63657 .47969 .64159 .4891 .63887 .48383 .63383 Mtetra
.48383 .63383 .4891 .63887 .49855 .63615 .4933 .63108 Mtetra
.4933 .63108 .49855 .63615 .50802 .63341 .50279 .62833 Mtetra
.50279 .62833 .50802 .63341 .51753 .63066 .51233 .62556 Mtetra
.51233 .62556 .51753 .63066 .52708 .6279 .52189 .62279 Mtetra
.52189 .62279 .52708 .6279 .53665 .62513 .53149 .62 Mtetra
.53149 .62 .53665 .62513 .54626 .62236 .54112 .61721 Mtetra
.54112 .61721 .54626 .62236 .55591 .61957 .55079 .6144 Mtetra
.55079 .6144 .55591 .61957 .56558 .61677 .56049 .61159 Mtetra
.56049 .61159 .56558 .61677 .57529 .61397 .57022 .60876 Mtetra
.57022 .60876 .57529 .61397 .58504 .61115 .57999 .60593 Mtetra
.57999 .60593 .58504 .61115 .59482 .60833 .58979 .60308 Mtetra
.58979 .60308 .59482 .60833 .60463 .60549 .59963 .60023 Mtetra
.59963 .60023 .60463 .60549 .61448 .60265 .6095 .59737 Mtetra
.6095 .59737 .61448 .60265 .62437 .59979 .61941 .59449 Mtetra
.61941 .59449 .62437 .59979 .63428 .59692 .62935 .59161 Mtetra
.62935 .59161 .63428 .59692 .64424 .59405 .63933 .58871 Mtetra
.63933 .58871 .64424 .59405 .65423 .59116 .64934 .58581 Mtetra
.64934 .58581 .65423 .59116 .66425 .58826 .65939 .58289 Mtetra
.65939 .58289 .66425 .58826 .67431 .58536 .66947 .57996 Mtetra
.66947 .57996 .67431 .58536 .68441 .58244 .67959 .57703 Mtetra
.67959 .57703 .68441 .58244 .69454 .57951 .68975 .57408 Mtetra
.68975 .57408 .69454 .57951 .70471 .57657 .69995 .57112 Mtetra
.69995 .57112 .70471 .57657 .71491 .57363 .71018 .56815 Mtetra
.71018 .56815 .71491 .57363 .72516 .57067 .72044 .56517 Mtetra
.72044 .56517 .72516 .57067 .73544 .5677 .73075 .56218 Mtetra
.73075 .56218 .73544 .5677 .74575 .56471 .74109 .55918 Mtetra
.74109 .55918 .74575 .56471 .75611 .56172 .75147 .55617 Mtetra
.75147 .55617 .75611 .56172 .7665 .55872 .76189 .55315 Mtetra
.76189 .55315 .7665 .55872 .77693 .55571 .77234 .55012 Mtetra
.77234 .55012 .77693 .55571 .78739 .55268 .78284 .54707 Mtetra
.78284 .54707 .78739 .55268 .7979 .54965 .79337 .54401 Mtetra
.79337 .54401 .7979 .54965 .80844 .5466 .80394 .54095 Mtetra
.80394 .54095 .80844 .5466 .81902 .54354 .81455 .53787 Mtetra
.81455 .53787 .81902 .54354 .82964 .54047 .8252 .53478 Mtetra
.8252 .53478 .82964 .54047 .8403 .53739 .83589 .53168 Mtetra
.83589 .53168 .8403 .53739 .851 .5343 .84661 .52857 Mtetra
.84661 .52857 .851 .5343 .86174 .5312 .85738 .52544 Mtetra
.85738 .52544 .86174 .5312 .87252 .52809 .86819 .52231 Mtetra
.86819 .52231 .87252 .52809 .88334 .52496 .87903 .51916 Mtetra
.87903 .51916 .88334 .52496 .89419 .52182 .88992 .516 Mtetra
.88992 .516 .89419 .52182 .90509 .51867 .90085 .51283 Mtetra
.90085 .51283 .90509 .51867 .91603 .51551 .91182 .50965 Mtetra
.91182 .50965 .91603 .51551 .92701 .51234 .92283 .50645 Mtetra
.92283 .50645 .92701 .51234 .93803 .50916 .93388 .50324 Mtetra
.93388 .50324 .93803 .50916 .94909 .50596 .94497 .50003 Mtetra
.94497 .50003 .94909 .50596 .9602 .50275 .9561 .4968 Mtetra
.35813 .66383 .36369 .66869 .37275 .66606 .3672 .66119 Mtetra
.3672 .66119 .37275 .66606 .38183 .66342 .3763 .65854 Mtetra
.3763 .65854 .38183 .66342 .39094 .66078 .38544 .65587 Mtetra
.38544 .65587 .39094 .66078 .40009 .65813 .3946 .6532 Mtetra
.3946 .6532 .40009 .65813 .40927 .65546 .4038 .65052 Mtetra
.4038 .65052 .40927 .65546 .41848 .65279 .41303 .64783 Mtetra
.41303 .64783 .41848 .65279 .42772 .65011 .42229 .64514 Mtetra
.42229 .64514 .42772 .65011 .43699 .64742 .43158 .64243 Mtetra
.43158 .64243 .43699 .64742 .44629 .64472 .4409 .63971 Mtetra
.4409 .63971 .44629 .64472 .45563 .64201 .45026 .63699 Mtetra
.45026 .63699 .45563 .64201 .465 .63929 .45965 .63425 Mtetra
.45965 .63425 .465 .63929 .4744 .63657 .46907 .63151 Mtetra
.46907 .63151 .4744 .63657 .48383 .63383 .47853 .62875 Mtetra
.47853 .62875 .48383 .63383 .4933 .63108 .48801 .62599 Mtetra
.48801 .62599 .4933 .63108 .50279 .62833 .49753 .62321 Mtetra
.49753 .62321 .50279 .62833 .51233 .62556 .50709 .62043 Mtetra
.50709 .62043 .51233 .62556 .52189 .62279 .51667 .61764 Mtetra
.51667 .61764 .52189 .62279 .53149 .62 .52629 .61483 Mtetra
.52629 .61483 .53149 .62 .54112 .61721 .53595 .61202 Mtetra
.53595 .61202 .54112 .61721 .55079 .6144 .54563 .6092 Mtetra
.54563 .6092 .55079 .6144 .56049 .61159 .55536 .60636 Mtetra
.55536 .60636 .56049 .61159 .57022 .60876 .56511 .60352 Mtetra
.56511 .60352 .57022 .60876 .57999 .60593 .5749 .60067 Mtetra
.5749 .60067 .57999 .60593 .58979 .60308 .58473 .59781 Mtetra
.58473 .59781 .58979 .60308 .59963 .60023 .59459 .59493 Mtetra
.59459 .59493 .59963 .60023 .6095 .59737 .60448 .59205 Mtetra
.60448 .59205 .6095 .59737 .61941 .59449 .61441 .58916 Mtetra
.61441 .58916 .61941 .59449 .62935 .59161 .62438 .58625 Mtetra
.62438 .58625 .62935 .59161 .63933 .58871 .63438 .58334 Mtetra
.63438 .58334 .63933 .58871 .64934 .58581 .64442 .58041 Mtetra
.64442 .58041 .64934 .58581 .65939 .58289 .65449 .57748 Mtetra
.65449 .57748 .65939 .58289 .66947 .57996 .6646 .57453 Mtetra
.6646 .57453 .66947 .57996 .67959 .57703 .67475 .57158 Mtetra
.67475 .57158 .67959 .57703 .68975 .57408 .68493 .56861 Mtetra
.68493 .56861 .68975 .57408 .69995 .57112 .69515 .56563 Mtetra
.69515 .56563 .69995 .57112 .71018 .56815 .70541 .56264 Mtetra
.70541 .56264 .71018 .56815 .72044 .56517 .7157 .55965 Mtetra
.7157 .55965 .72044 .56517 .73075 .56218 .72603 .55664 Mtetra
.72603 .55664 .73075 .56218 .74109 .55918 .7364 .55361 Mtetra
.7364 .55361 .74109 .55918 .75147 .55617 .7468 .55058 Mtetra
.7468 .55058 .75147 .55617 .76189 .55315 .75725 .54754 Mtetra
.75725 .54754 .76189 .55315 .77234 .55012 .76773 .54449 Mtetra
.76773 .54449 .77234 .55012 .78284 .54707 .77825 .54142 Mtetra
.77825 .54142 .78284 .54707 .79337 .54401 .78881 .53834 Mtetra
.78881 .53834 .79337 .54401 .80394 .54095 .79941 .53526 Mtetra
.79941 .53526 .80394 .54095 .81455 .53787 .81005 .53216 Mtetra
.81005 .53216 .81455 .53787 .8252 .53478 .82072 .52905 Mtetra
.82072 .52905 .8252 .53478 .83589 .53168 .83144 .52592 Mtetra
.83144 .52592 .83589 .53168 .84661 .52857 .84219 .52279 Mtetra
.84219 .52279 .84661 .52857 .85738 .52544 .85299 .51964 Mtetra
.85299 .51964 .85738 .52544 .86819 .52231 .86383 .51649 Mtetra
.86383 .51649 .86819 .52231 .87903 .51916 .8747 .51332 Mtetra
.8747 .51332 .87903 .51916 .88992 .516 .88562 .51014 Mtetra
.88562 .51014 .88992 .516 .90085 .51283 .89658 .50694 Mtetra
.89658 .50694 .90085 .51283 .91182 .50965 .90758 .50374 Mtetra
.90758 .50374 .91182 .50965 .92283 .50645 .91862 .50052 Mtetra
.91862 .50052 .92283 .50645 .93388 .50324 .9297 .49729 Mtetra
.9297 .49729 .93388 .50324 .94497 .50003 .94082 .49405 Mtetra
.94082 .49405 .94497 .50003 .9561 .4968 .95198 .4908 Mtetra
.35253 .65894 .35813 .66383 .3672 .66119 .36162 .65628 Mtetra
.36162 .65628 .3672 .66119 .3763 .65854 .37074 .65361 Mtetra
.37074 .65361 .3763 .65854 .38544 .65587 .3799 .65094 Mtetra
.3799 .65094 .38544 .65587 .3946 .6532 .38908 .64825 Mtetra
.38908 .64825 .3946 .6532 .4038 .65052 .3983 .64555 Mtetra
.3983 .64555 .4038 .65052 .41303 .64783 .40755 .64285 Mtetra
.40755 .64285 .41303 .64783 .42229 .64514 .41683 .64013 Mtetra
.41683 .64013 .42229 .64514 .43158 .64243 .42614 .63741 Mtetra
.42614 .63741 .43158 .64243 .4409 .63971 .43548 .63467 Mtetra
.43548 .63467 .4409 .63971 .45026 .63699 .44486 .63193 Mtetra
.44486 .63193 .45026 .63699 .45965 .63425 .45427 .62918 Mtetra
.45427 .62918 .45965 .63425 .46907 .63151 .46371 .62641 Mtetra
.46371 .62641 .46907 .63151 .47853 .62875 .47319 .62364 Mtetra
.47319 .62364 .47853 .62875 .48801 .62599 .48269 .62086 Mtetra
.48269 .62086 .48801 .62599 .49753 .62321 .49224 .61807 Mtetra
.49224 .61807 .49753 .62321 .50709 .62043 .50181 .61527 Mtetra
.50181 .61527 .50709 .62043 .51667 .61764 .51142 .61245 Mtetra
.51142 .61245 .51667 .61764 .52629 .61483 .52106 .60963 Mtetra
.52106 .60963 .52629 .61483 .53595 .61202 .53074 .6068 Mtetra
.53074 .6068 .53595 .61202 .54563 .6092 .54045 .60396 Mtetra
.54045 .60396 .54563 .6092 .55536 .60636 .55019 .60111 Mtetra
.55019 .60111 .55536 .60636 .56511 .60352 .55997 .59825 Mtetra
.55997 .59825 .56511 .60352 .5749 .60067 .56978 .59538 Mtetra
.56978 .59538 .5749 .60067 .58473 .59781 .57963 .59249 Mtetra
.57963 .59249 .58473 .59781 .59459 .59493 .58952 .5896 Mtetra
.58952 .5896 .59459 .59493 .60448 .59205 .59944 .5867 Mtetra
.59944 .5867 .60448 .59205 .61441 .58916 .60939 .58379 Mtetra
.60939 .58379 .61441 .58916 .62438 .58625 .61938 .58087 Mtetra
.61938 .58087 .62438 .58625 .63438 .58334 .62941 .57793 Mtetra
.62941 .57793 .63438 .58334 .64442 .58041 .63947 .57499 Mtetra
.63947 .57499 .64442 .58041 .65449 .57748 .64957 .57203 Mtetra
.64957 .57203 .65449 .57748 .6646 .57453 .6597 .56907 Mtetra
.6597 .56907 .6646 .57453 .67475 .57158 .66987 .56609 Mtetra
.66987 .56609 .67475 .57158 .68493 .56861 .68008 .56311 Mtetra
.68008 .56311 .68493 .56861 .69515 .56563 .69032 .56011 Mtetra
.69032 .56011 .69515 .56563 .70541 .56264 .7006 .5571 Mtetra
.7006 .5571 .70541 .56264 .7157 .55965 .71092 .55408 Mtetra
.71092 .55408 .7157 .55965 .72603 .55664 .72128 .55105 Mtetra
.72128 .55105 .72603 .55664 .7364 .55361 .73168 .54801 Mtetra
.73168 .54801 .7364 .55361 .7468 .55058 .74211 .54496 Mtetra
.74211 .54496 .7468 .55058 .75725 .54754 .75258 .54189 Mtetra
.75258 .54189 .75725 .54754 .76773 .54449 .76309 .53882 Mtetra
.76309 .53882 .76773 .54449 .77825 .54142 .77364 .53573 Mtetra
.77364 .53573 .77825 .54142 .78881 .53834 .78422 .53263 Mtetra
.78422 .53263 .78881 .53834 .79941 .53526 .79485 .52952 Mtetra
.79485 .52952 .79941 .53526 .81005 .53216 .80551 .5264 Mtetra
.80551 .5264 .81005 .53216 .82072 .52905 .81622 .52327 Mtetra
.81622 .52327 .82072 .52905 .83144 .52592 .82696 .52013 Mtetra
.82696 .52013 .83144 .52592 .84219 .52279 .83775 .51697 Mtetra
.83775 .51697 .84219 .52279 .85299 .51964 .84857 .51381 Mtetra
.84857 .51381 .85299 .51964 .86383 .51649 .85944 .51063 Mtetra
.85944 .51063 .86383 .51649 .8747 .51332 .87034 .50744 Mtetra
.87034 .50744 .8747 .51332 .88562 .51014 .88129 .50423 Mtetra
.88129 .50423 .88562 .51014 .89658 .50694 .89227 .50102 Mtetra
.89227 .50102 .89658 .50694 .90758 .50374 .9033 .49779 Mtetra
.9033 .49779 .90758 .50374 .91862 .50052 .91437 .49455 Mtetra
.91437 .49455 .91862 .50052 .9297 .49729 .92549 .4913 Mtetra
.92549 .4913 .9297 .49729 .94082 .49405 .93664 .48804 Mtetra
.93664 .48804 .94082 .49405 .95198 .4908 .94784 .48476 Mtetra
.34689 .65403 .35253 .65894 .36162 .65628 .356 .65135 Mtetra
.356 .65135 .36162 .65628 .37074 .65361 .36515 .64866 Mtetra
.36515 .64866 .37074 .65361 .3799 .65094 .37432 .64597 Mtetra
.37432 .64597 .3799 .65094 .38908 .64825 .38352 .64326 Mtetra
.38352 .64326 .38908 .64825 .3983 .64555 .39276 .64055 Mtetra
.39276 .64055 .3983 .64555 .40755 .64285 .40203 .63783 Mtetra
.40203 .63783 .40755 .64285 .41683 .64013 .41133 .63509 Mtetra
.41133 .63509 .41683 .64013 .42614 .63741 .42066 .63235 Mtetra
.42066 .63235 .42614 .63741 .43548 .63467 .43003 .6296 Mtetra
.43003 .6296 .43548 .63467 .44486 .63193 .43942 .62684 Mtetra
.43942 .62684 .44486 .63193 .45427 .62918 .44885 .62407 Mtetra
.44885 .62407 .45427 .62918 .46371 .62641 .45832 .62129 Mtetra
.45832 .62129 .46371 .62641 .47319 .62364 .46781 .6185 Mtetra
.46781 .6185 .47319 .62364 .48269 .62086 .47734 .6157 Mtetra
.47734 .6157 .48269 .62086 .49224 .61807 .4869 .61289 Mtetra
.4869 .61289 .49224 .61807 .50181 .61527 .4965 .61007 Mtetra
.4965 .61007 .50181 .61527 .51142 .61245 .50613 .60724 Mtetra
.50613 .60724 .51142 .61245 .52106 .60963 .5158 .6044 Mtetra
.5158 .6044 .52106 .60963 .53074 .6068 .52549 .60155 Mtetra
.52549 .60155 .53074 .6068 .54045 .60396 .53523 .59869 Mtetra
.53523 .59869 .54045 .60396 .55019 .60111 .54499 .59582 Mtetra
.54499 .59582 .55019 .60111 .55997 .59825 .5548 .59294 Mtetra
.5548 .59294 .55997 .59825 .56978 .59538 .56463 .59005 Mtetra
.56463 .59005 .56978 .59538 .57963 .59249 .5745 .58715 Mtetra
.5745 .58715 .57963 .59249 .58952 .5896 .58441 .58424 Mtetra
.58441 .58424 .58952 .5896 .59944 .5867 .59435 .58132 Mtetra
.59435 .58132 .59944 .5867 .60939 .58379 .60433 .57838 Mtetra
.60433 .57838 .60939 .58379 .61938 .58087 .61435 .57544 Mtetra
.61435 .57544 .61938 .58087 .62941 .57793 .6244 .57249 Mtetra
.6244 .57249 .62941 .57793 .63947 .57499 .63448 .56952 Mtetra
.63448 .56952 .63947 .57499 .64957 .57203 .6446 .56655 Mtetra
.6446 .56655 .64957 .57203 .6597 .56907 .65476 .56357 Mtetra
.65476 .56357 .6597 .56907 .66987 .56609 .66496 .56057 Mtetra
.66496 .56057 .66987 .56609 .68008 .56311 .67519 .55756 Mtetra
.67519 .55756 .68008 .56311 .69032 .56011 .68546 .55455 Mtetra
.68546 .55455 .69032 .56011 .7006 .5571 .69577 .55152 Mtetra
.69577 .55152 .7006 .5571 .71092 .55408 .70612 .54848 Mtetra
.70612 .54848 .71092 .55408 .72128 .55105 .7165 .54543 Mtetra
.7165 .54543 .72128 .55105 .73168 .54801 .72692 .54236 Mtetra
.72692 .54236 .73168 .54801 .74211 .54496 .73738 .53929 Mtetra
.73738 .53929 .74211 .54496 .75258 .54189 .74788 .53621 Mtetra
.74788 .53621 .75258 .54189 .76309 .53882 .75841 .53311 Mtetra
.75841 .53311 .76309 .53882 .77364 .53573 .76899 .53 Mtetra
.76899 .53 .77364 .53573 .78422 .53263 .7796 .52688 Mtetra
.7796 .52688 .78422 .53263 .79485 .52952 .79026 .52375 Mtetra
.79026 .52375 .79485 .52952 .80551 .5264 .80095 .52061 Mtetra
.80095 .52061 .80551 .5264 .81622 .52327 .81168 .51746 Mtetra
.81168 .51746 .81622 .52327 .82696 .52013 .82245 .51429 Mtetra
.82245 .51429 .82696 .52013 .83775 .51697 .83327 .51112 Mtetra
.83327 .51112 .83775 .51697 .84857 .51381 .84412 .50793 Mtetra
.84412 .50793 .84857 .51381 .85944 .51063 .85501 .50473 Mtetra
.85501 .50473 .85944 .51063 .87034 .50744 .86595 .50151 Mtetra
.86595 .50151 .87034 .50744 .88129 .50423 .87693 .49829 Mtetra
.87693 .49829 .88129 .50423 .89227 .50102 .88794 .49505 Mtetra
.88794 .49505 .89227 .50102 .9033 .49779 .899 .4918 Mtetra
.899 .4918 .9033 .49779 .91437 .49455 .9101 .48854 Mtetra
.9101 .48854 .91437 .49455 .92549 .4913 .92125 .48527 Mtetra
.92125 .48527 .92549 .4913 .93664 .48804 .93243 .48198 Mtetra
.93243 .48198 .93664 .48804 .94784 .48476 .94366 .47868 Mtetra
.34122 .64908 .34689 .65403 .356 .65135 .35035 .64638 Mtetra
.35035 .64638 .356 .65135 .36515 .64866 .35951 .64368 Mtetra
.35951 .64368 .36515 .64866 .37432 .64597 .36871 .64097 Mtetra
.36871 .64097 .37432 .64597 .38352 .64326 .37793 .63825 Mtetra
.37793 .63825 .38352 .64326 .39276 .64055 .38719 .63551 Mtetra
.38719 .63551 .39276 .64055 .40203 .63783 .39647 .63277 Mtetra
.39647 .63277 .40203 .63783 .41133 .63509 .40579 .63002 Mtetra
.40579 .63002 .41133 .63509 .42066 .63235 .41515 .62726 Mtetra
.41515 .62726 .42066 .63235 .43003 .6296 .42453 .62449 Mtetra
.42453 .62449 .43003 .6296 .43942 .62684 .43395 .62172 Mtetra
.43395 .62172 .43942 .62684 .44885 .62407 .4434 .61893 Mtetra
.4434 .61893 .44885 .62407 .45832 .62129 .45289 .61613 Mtetra
.45289 .61613 .45832 .62129 .46781 .6185 .4624 .61332 Mtetra
.4624 .61332 .46781 .6185 .47734 .6157 .47195 .6105 Mtetra
.47195 .6105 .47734 .6157 .4869 .61289 .48154 .60767 Mtetra
.48154 .60767 .4869 .61289 .4965 .61007 .49116 .60484 Mtetra
.49116 .60484 .4965 .61007 .50613 .60724 .50081 .60199 Mtetra
.50081 .60199 .50613 .60724 .5158 .6044 .5105 .59913 Mtetra
.5105 .59913 .5158 .6044 .52549 .60155 .52022 .59626 Mtetra
.52022 .59626 .52549 .60155 .53523 .59869 .52997 .59338 Mtetra
.52997 .59338 .53523 .59869 .54499 .59582 .53976 .59049 Mtetra
.53976 .59049 .54499 .59582 .5548 .59294 .54959 .58759 Mtetra
.54959 .58759 .5548 .59294 .56463 .59005 .55945 .58469 Mtetra
.55945 .58469 .56463 .59005 .5745 .58715 .56934 .58177 Mtetra
.56934 .58177 .5745 .58715 .58441 .58424 .57927 .57884 Mtetra
.57927 .57884 .58441 .58424 .59435 .58132 .58924 .57589 Mtetra
.58924 .57589 .59435 .58132 .60433 .57838 .59924 .57294 Mtetra
.59924 .57294 .60433 .57838 .61435 .57544 .60928 .56998 Mtetra
.60928 .56998 .61435 .57544 .6244 .57249 .61935 .56701 Mtetra
.61935 .56701 .6244 .57249 .63448 .56952 .62946 .56403 Mtetra
.62946 .56403 .63448 .56952 .6446 .56655 .63961 .56103 Mtetra
.63961 .56103 .6446 .56655 .65476 .56357 .64979 .55803 Mtetra
.64979 .55803 .65476 .56357 .66496 .56057 .66002 .55501 Mtetra
.66002 .55501 .66496 .56057 .67519 .55756 .67027 .55198 Mtetra
.67027 .55198 .67519 .55756 .68546 .55455 .68057 .54895 Mtetra
.68057 .54895 .68546 .55455 .69577 .55152 .6909 .5459 Mtetra
.6909 .5459 .69577 .55152 .70612 .54848 .70127 .54284 Mtetra
.70127 .54284 .70612 .54848 .7165 .54543 .71168 .53976 Mtetra
.71168 .53976 .7165 .54543 .72692 .54236 .72213 .53668 Mtetra
.72213 .53668 .72692 .54236 .73738 .53929 .73262 .53359 Mtetra
.73262 .53359 .73738 .53929 .74788 .53621 .74314 .53048 Mtetra
.74314 .53048 .74788 .53621 .75841 .53311 .75371 .52737 Mtetra
.75371 .52737 .75841 .53311 .76899 .53 .76431 .52424 Mtetra
.76431 .52424 .76899 .53 .7796 .52688 .77495 .5211 Mtetra
.77495 .5211 .7796 .52688 .79026 .52375 .78563 .51794 Mtetra
.78563 .51794 .79026 .52375 .80095 .52061 .79635 .51478 Mtetra
.79635 .51478 .80095 .52061 .81168 .51746 .80711 .51161 Mtetra
.80711 .51161 .81168 .51746 .82245 .51429 .81792 .50842 Mtetra
.81792 .50842 .82245 .51429 .83327 .51112 .82876 .50522 Mtetra
.82876 .50522 .83327 .51112 .84412 .50793 .83964 .50201 Mtetra
.83964 .50201 .84412 .50793 .85501 .50473 .85056 .49879 Mtetra
.85056 .49879 .85501 .50473 .86595 .50151 .86153 .49555 Mtetra
.86153 .49555 .86595 .50151 .87693 .49829 .87253 .4923 Mtetra
.87253 .4923 .87693 .49829 .88794 .49505 .88358 .48904 Mtetra
.88358 .48904 .88794 .49505 .899 .4918 .89467 .48577 Mtetra
.89467 .48577 .899 .4918 .9101 .48854 .9058 .48249 Mtetra
.9058 .48249 .9101 .48854 .92125 .48527 .91698 .47919 Mtetra
.91698 .47919 .92125 .48527 .93243 .48198 .92819 .47588 Mtetra
.92819 .47588 .93243 .48198 .94366 .47868 .93945 .47256 Mtetra
.33552 .6441 .34122 .64908 .35035 .64638 .34467 .64139 Mtetra
.34467 .64139 .35035 .64638 .35951 .64368 .35385 .63866 Mtetra
.35385 .63866 .35951 .64368 .36871 .64097 .36306 .63594 Mtetra
.36306 .63594 .36871 .64097 .37793 .63825 .3723 .6332 Mtetra
.3723 .6332 .37793 .63825 .38719 .63551 .38158 .63045 Mtetra
.38158 .63045 .38719 .63551 .39647 .63277 .39089 .62769 Mtetra
.39089 .62769 .39647 .63277 .40579 .63002 .40023 .62492 Mtetra
.40023 .62492 .40579 .63002 .41515 .62726 .4096 .62214 Mtetra
.4096 .62214 .41515 .62726 .42453 .62449 .41901 .61936 Mtetra
.41901 .61936 .42453 .62449 .43395 .62172 .42844 .61656 Mtetra
.42844 .61656 .43395 .62172 .4434 .61893 .43792 .61375 Mtetra
.43792 .61375 .4434 .61893 .45289 .61613 .44742 .61094 Mtetra
.44742 .61094 .45289 .61613 .4624 .61332 .45696 .60811 Mtetra
.45696 .60811 .4624 .61332 .47195 .6105 .46653 .60527 Mtetra
.46653 .60527 .47195 .6105 .48154 .60767 .47614 .60243 Mtetra
.47614 .60243 .48154 .60767 .49116 .60484 .48578 .59957 Mtetra
.48578 .59957 .49116 .60484 .50081 .60199 .49545 .5967 Mtetra
.49545 .5967 .50081 .60199 .5105 .59913 .50516 .59383 Mtetra
.50516 .59383 .5105 .59913 .52022 .59626 .5149 .59094 Mtetra
.5149 .59094 .52022 .59626 .52997 .59338 .52468 .58804 Mtetra
.52468 .58804 .52997 .59338 .53976 .59049 .5345 .58513 Mtetra
.5345 .58513 .53976 .59049 .54959 .58759 .54434 .58222 Mtetra
.54434 .58222 .54959 .58759 .55945 .58469 .55423 .57929 Mtetra
.55423 .57929 .55945 .58469 .56934 .58177 .56414 .57635 Mtetra
.56414 .57635 .56934 .58177 .57927 .57884 .5741 .5734 Mtetra
.5741 .5734 .57927 .57884 .58924 .57589 .58409 .57044 Mtetra
.58409 .57044 .58924 .57589 .59924 .57294 .59412 .56747 Mtetra
.59412 .56747 .59924 .57294 .60928 .56998 .60418 .56449 Mtetra
.60418 .56449 .60928 .56998 .61935 .56701 .61428 .56149 Mtetra
.61428 .56149 .61935 .56701 .62946 .56403 .62441 .55849 Mtetra
.62441 .55849 .62946 .56403 .63961 .56103 .63458 .55547 Mtetra
.63458 .55547 .63961 .56103 .64979 .55803 .64479 .55245 Mtetra
.64479 .55245 .64979 .55803 .66002 .55501 .65504 .54941 Mtetra
.65504 .54941 .66002 .55501 .67027 .55198 .66532 .54637 Mtetra
.66532 .54637 .67027 .55198 .68057 .54895 .67564 .54331 Mtetra
.67564 .54331 .68057 .54895 .6909 .5459 .686 .54024 Mtetra
.686 .54024 .6909 .5459 .70127 .54284 .6964 .53716 Mtetra
.6964 .53716 .70127 .54284 .71168 .53976 .70684 .53406 Mtetra
.70684 .53406 .71168 .53976 .72213 .53668 .71731 .53096 Mtetra
.71731 .53096 .72213 .53668 .73262 .53359 .72782 .52785 Mtetra
.72782 .52785 .73262 .53359 .74314 .53048 .73838 .52472 Mtetra
.73838 .52472 .74314 .53048 .75371 .52737 .74897 .52158 Mtetra
.74897 .52158 .75371 .52737 .76431 .52424 .7596 .51843 Mtetra
.7596 .51843 .76431 .52424 .77495 .5211 .77027 .51527 Mtetra
.77027 .51527 .77495 .5211 .78563 .51794 .78098 .5121 Mtetra
.78098 .5121 .78563 .51794 .79635 .51478 .79173 .50891 Mtetra
.79173 .50891 .79635 .51478 .80711 .51161 .80251 .50571 Mtetra
.80251 .50571 .80711 .51161 .81792 .50842 .81335 .5025 Mtetra
.81335 .5025 .81792 .50842 .82876 .50522 .82422 .49928 Mtetra
.82422 .49928 .82876 .50522 .83964 .50201 .83513 .49605 Mtetra
.83513 .49605 .83964 .50201 .85056 .49879 .84608 .4928 Mtetra
.84608 .4928 .85056 .49879 .86153 .49555 .85707 .48955 Mtetra
.85707 .48955 .86153 .49555 .87253 .4923 .86811 .48627 Mtetra
.86811 .48627 .87253 .4923 .88358 .48904 .87919 .48299 Mtetra
.87919 .48299 .88358 .48904 .89467 .48577 .89031 .4797 Mtetra
.89031 .4797 .89467 .48577 .9058 .48249 .90147 .47639 Mtetra
.90147 .47639 .9058 .48249 .91698 .47919 .91268 .47307 Mtetra
.91268 .47307 .91698 .47919 .92819 .47588 .92392 .46974 Mtetra
.92392 .46974 .92819 .47588 .93945 .47256 .93521 .46639 Mtetra
.32977 .63908 .33552 .6441 .34467 .64139 .33894 .63636 Mtetra
.33894 .63636 .34467 .64139 .35385 .63866 .34814 .63362 Mtetra
.34814 .63362 .35385 .63866 .36306 .63594 .35737 .63087 Mtetra
.35737 .63087 .36306 .63594 .3723 .6332 .36664 .62811 Mtetra
.36664 .62811 .3723 .6332 .38158 .63045 .37593 .62535 Mtetra
.37593 .62535 .38158 .63045 .39089 .62769 .38526 .62257 Mtetra
.38526 .62257 .39089 .62769 .40023 .62492 .39462 .61979 Mtetra
.39462 .61979 .40023 .62492 .4096 .62214 .40402 .61699 Mtetra
.40402 .61699 .4096 .62214 .41901 .61936 .41344 .61418 Mtetra
.41344 .61418 .41901 .61936 .42844 .61656 .4229 .61137 Mtetra
.4229 .61137 .42844 .61656 .43792 .61375 .43239 .60854 Mtetra
.43239 .60854 .43792 .61375 .44742 .61094 .44192 .60571 Mtetra
.44192 .60571 .44742 .61094 .45696 .60811 .45148 .60286 Mtetra
.45148 .60286 .45696 .60811 .46653 .60527 .46108 .60001 Mtetra
.46108 .60001 .46653 .60527 .47614 .60243 .4707 .59714 Mtetra
.4707 .59714 .47614 .60243 .48578 .59957 .48037 .59427 Mtetra
.48037 .59427 .48578 .59957 .49545 .5967 .49006 .59138 Mtetra
.49006 .59138 .49545 .5967 .50516 .59383 .49979 .58849 Mtetra
.49979 .58849 .50516 .59383 .5149 .59094 .50956 .58558 Mtetra
.50956 .58558 .5149 .59094 .52468 .58804 .51936 .58267 Mtetra
.51936 .58267 .52468 .58804 .5345 .58513 .52919 .57974 Mtetra
.52919 .57974 .5345 .58513 .54434 .58222 .53907 .5768 Mtetra
.53907 .5768 .54434 .58222 .55423 .57929 .54897 .57385 Mtetra
.54897 .57385 .55423 .57929 .56414 .57635 .55891 .57089 Mtetra
.55891 .57089 .56414 .57635 .5741 .5734 .56889 .56792 Mtetra
.56889 .56792 .5741 .5734 .58409 .57044 .57891 .56494 Mtetra
.57891 .56494 .58409 .57044 .59412 .56747 .58896 .56195 Mtetra
.58896 .56195 .59412 .56747 .60418 .56449 .59904 .55895 Mtetra
.59904 .55895 .60418 .56449 .61428 .56149 .60917 .55594 Mtetra
.60917 .55594 .61428 .56149 .62441 .55849 .61933 .55292 Mtetra
.61933 .55292 .62441 .55849 .63458 .55547 .62952 .54988 Mtetra
.62952 .54988 .63458 .55547 .64479 .55245 .63976 .54684 Mtetra
.63976 .54684 .64479 .55245 .65504 .54941 .65003 .54378 Mtetra
.65003 .54378 .65504 .54941 .66532 .54637 .66034 .54071 Mtetra
.66034 .54071 .66532 .54637 .67564 .54331 .67069 .53763 Mtetra
.67069 .53763 .67564 .54331 .686 .54024 .68107 .53454 Mtetra
.68107 .53454 .686 .54024 .6964 .53716 .69149 .53144 Mtetra
.69149 .53144 .6964 .53716 .70684 .53406 .70196 .52833 Mtetra
.70196 .52833 .70684 .53406 .71731 .53096 .71246 .5252 Mtetra
.71246 .5252 .71731 .53096 .72782 .52785 .723 .52206 Mtetra
.723 .52206 .72782 .52785 .73838 .52472 .73358 .51892 Mtetra
.73358 .51892 .73838 .52472 .74897 .52158 .74419 .51576 Mtetra
.74419 .51576 .74897 .52158 .7596 .51843 .75485 .51258 Mtetra
.75485 .51258 .7596 .51843 .77027 .51527 .76555 .5094 Mtetra
.76555 .5094 .77027 .51527 .78098 .5121 .77629 .50621 Mtetra
.77629 .50621 .78098 .5121 .79173 .50891 .78707 .503 Mtetra
.78707 .503 .79173 .50891 .80251 .50571 .79788 .49978 Mtetra
.79788 .49978 .80251 .50571 .81335 .5025 .80874 .49655 Mtetra
.80874 .49655 .81335 .5025 .82422 .49928 .81964 .4933 Mtetra
.81964 .4933 .82422 .49928 .83513 .49605 .83058 .49005 Mtetra
.83058 .49005 .83513 .49605 .84608 .4928 .84157 .48678 Mtetra
.84157 .48678 .84608 .4928 .85707 .48955 .85259 .4835 Mtetra
.85259 .4835 .85707 .48955 .86811 .48627 .86366 .4802 Mtetra
.86366 .4802 .86811 .48627 .87919 .48299 .87477 .4769 Mtetra
.87477 .4769 .87919 .48299 .89031 .4797 .88592 .47358 Mtetra
.88592 .47358 .89031 .4797 .90147 .47639 .89711 .47025 Mtetra
.89711 .47025 .90147 .47639 .91268 .47307 .90834 .46691 Mtetra
.90834 .46691 .91268 .47307 .92392 .46974 .91962 .46355 Mtetra
.91962 .46355 .92392 .46974 .93521 .46639 .93095 .46018 Mtetra
.32399 .63404 .32977 .63908 .33894 .63636 .33318 .63129 Mtetra
.33318 .63129 .33894 .63636 .34814 .63362 .3424 .62854 Mtetra
.3424 .62854 .34814 .63362 .35737 .63087 .35165 .62577 Mtetra
.35165 .62577 .35737 .63087 .36664 .62811 .36094 .623 Mtetra
.36094 .623 .36664 .62811 .37593 .62535 .37025 .62021 Mtetra
.37025 .62021 .37593 .62535 .38526 .62257 .3796 .61742 Mtetra
.3796 .61742 .38526 .62257 .39462 .61979 .38898 .61462 Mtetra
.38898 .61462 .39462 .61979 .40402 .61699 .3984 .6118 Mtetra
.3984 .6118 .40402 .61699 .41344 .61418 .40784 .60898 Mtetra
.40784 .60898 .41344 .61418 .4229 .61137 .41732 .60615 Mtetra
.41732 .60615 .4229 .61137 .43239 .60854 .42684 .6033 Mtetra
.42684 .6033 .43239 .60854 .44192 .60571 .43639 .60045 Mtetra
.43639 .60045 .44192 .60571 .45148 .60286 .44597 .59759 Mtetra
.44597 .59759 .45148 .60286 .46108 .60001 .45558 .59471 Mtetra
.45558 .59471 .46108 .60001 .4707 .59714 .46523 .59183 Mtetra
.46523 .59183 .4707 .59714 .48037 .59427 .47492 .58893 Mtetra
.47492 .58893 .48037 .59427 .49006 .59138 .48463 .58603 Mtetra
.48463 .58603 .49006 .59138 .49979 .58849 .49439 .58311 Mtetra
.49439 .58311 .49979 .58849 .50956 .58558 .50418 .58019 Mtetra
.50418 .58019 .50956 .58558 .51936 .58267 .514 .57725 Mtetra
.514 .57725 .51936 .58267 .52919 .57974 .52386 .57431 Mtetra
.52386 .57431 .52919 .57974 .53907 .5768 .53375 .57135 Mtetra
.53375 .57135 .53907 .5768 .54897 .57385 .54368 .56838 Mtetra
.54368 .56838 .54897 .57385 .55891 .57089 .55365 .5654 Mtetra
.55365 .5654 .55891 .57089 .56889 .56792 .56365 .56241 Mtetra
.56365 .56241 .56889 .56792 .57891 .56494 .57369 .55941 Mtetra
.57369 .55941 .57891 .56494 .58896 .56195 .58376 .5564 Mtetra
.58376 .5564 .58896 .56195 .59904 .55895 .59387 .55338 Mtetra
.59387 .55338 .59904 .55895 .60917 .55594 .60402 .55035 Mtetra
.60402 .55035 .60917 .55594 .61933 .55292 .61421 .5473 Mtetra
.61421 .5473 .61933 .55292 .62952 .54988 .62443 .54425 Mtetra
.62443 .54425 .62952 .54988 .63976 .54684 .63469 .54118 Mtetra
.63469 .54118 .63976 .54684 .65003 .54378 .64498 .53811 Mtetra
.64498 .53811 .65003 .54378 .66034 .54071 .65532 .53502 Mtetra
.65532 .53502 .66034 .54071 .67069 .53763 .66569 .53192 Mtetra
.66569 .53192 .67069 .53763 .68107 .53454 .6761 .52881 Mtetra
.6761 .52881 .68107 .53454 .69149 .53144 .68655 .52568 Mtetra
.68655 .52568 .69149 .53144 .70196 .52833 .69704 .52255 Mtetra
.69704 .52255 .70196 .52833 .71246 .5252 .70757 .5194 Mtetra
.70757 .5194 .71246 .5252 .723 .52206 .71814 .51624 Mtetra
.71814 .51624 .723 .52206 .73358 .51892 .72874 .51307 Mtetra
.72874 .51307 .73358 .51892 .74419 .51576 .73939 .50989 Mtetra
.73939 .50989 .74419 .51576 .75485 .51258 .75008 .5067 Mtetra
.75008 .5067 .75485 .51258 .76555 .5094 .7608 .50349 Mtetra
.7608 .50349 .76555 .5094 .77629 .50621 .77157 .50027 Mtetra
.77157 .50027 .77629 .50621 .78707 .503 .78237 .49704 Mtetra
.78237 .49704 .78707 .503 .79788 .49978 .79322 .4938 Mtetra
.79322 .4938 .79788 .49978 .80874 .49655 .80411 .49055 Mtetra
.80411 .49055 .80874 .49655 .81964 .4933 .81504 .48728 Mtetra
.81504 .48728 .81964 .4933 .83058 .49005 .82601 .484 Mtetra
.82601 .484 .83058 .49005 .84157 .48678 .83702 .48071 Mtetra
.83702 .48071 .84157 .48678 .85259 .4835 .84808 .47741 Mtetra
.84808 .47741 .85259 .4835 .86366 .4802 .85917 .47409 Mtetra
.85917 .47409 .86366 .4802 .87477 .4769 .87031 .47076 Mtetra
.87031 .47076 .87477 .4769 .88592 .47358 .88149 .46742 Mtetra
.88149 .46742 .88592 .47358 .89711 .47025 .89272 .46407 Mtetra
.89272 .46407 .89711 .47025 .90834 .46691 .90398 .4607 Mtetra
.90398 .4607 .90834 .46691 .91962 .46355 .91529 .45732 Mtetra
.91529 .45732 .91962 .46355 .93095 .46018 .92665 .45393 Mtetra
.31818 .62896 .32399 .63404 .33318 .63129 .32738 .6262 Mtetra
.32738 .6262 .33318 .63129 .3424 .62854 .33662 .62343 Mtetra
.33662 .62343 .3424 .62854 .35165 .62577 .34589 .62064 Mtetra
.34589 .62064 .35165 .62577 .36094 .623 .3552 .61785 Mtetra
.3552 .61785 .36094 .623 .37025 .62021 .36453 .61505 Mtetra
.36453 .61505 .37025 .62021 .3796 .61742 .3739 .61224 Mtetra
.3739 .61224 .3796 .61742 .38898 .61462 .3833 .60942 Mtetra
.3833 .60942 .38898 .61462 .3984 .6118 .39274 .60658 Mtetra
.39274 .60658 .3984 .6118 .40784 .60898 .40221 .60374 Mtetra
.40221 .60374 .40784 .60898 .41732 .60615 .41171 .60089 Mtetra
.41171 .60089 .41732 .60615 .42684 .6033 .42124 .59803 Mtetra
.42124 .59803 .42684 .6033 .43639 .60045 .43081 .59516 Mtetra
.43081 .59516 .43639 .60045 .44597 .59759 .44042 .59227 Mtetra
.44042 .59227 .44597 .59759 .45558 .59471 .45005 .58938 Mtetra
.45005 .58938 .45558 .59471 .46523 .59183 .45972 .58648 Mtetra
.45972 .58648 .46523 .59183 .47492 .58893 .46943 .58356 Mtetra
.46943 .58356 .47492 .58893 .48463 .58603 .47917 .58064 Mtetra
.47917 .58064 .48463 .58603 .49439 .58311 .48895 .57771 Mtetra
.48895 .57771 .49439 .58311 .50418 .58019 .49876 .57476 Mtetra
.49876 .57476 .50418 .58019 .514 .57725 .5086 .57181 Mtetra
.5086 .57181 .514 .57725 .52386 .57431 .51849 .56884 Mtetra
.51849 .56884 .52386 .57431 .53375 .57135 .5284 .56586 Mtetra
.5284 .56586 .53375 .57135 .54368 .56838 .53836 .56288 Mtetra
.53836 .56288 .54368 .56838 .55365 .5654 .54835 .55988 Mtetra
.54835 .55988 .55365 .5654 .56365 .56241 .55837 .55687 Mtetra
.55837 .55687 .56365 .56241 .57369 .55941 .56843 .55385 Mtetra
.56843 .55385 .57369 .55941 .58376 .5564 .57853 .55082 Mtetra
.57853 .55082 .58376 .5564 .59387 .55338 .58867 .54777 Mtetra
.58867 .54777 .59387 .55338 .60402 .55035 .59884 .54472 Mtetra
.59884 .54472 .60402 .55035 .61421 .5473 .60905 .54166 Mtetra
.60905 .54166 .61421 .5473 .62443 .54425 .6193 .53858 Mtetra
.6193 .53858 .62443 .54425 .63469 .54118 .62958 .53549 Mtetra
.62958 .53549 .63469 .54118 .64498 .53811 .63991 .53239 Mtetra
.63991 .53239 .64498 .53811 .65532 .53502 .65027 .52928 Mtetra
.65027 .52928 .65532 .53502 .66569 .53192 .66067 .52616 Mtetra
.66067 .52616 .66569 .53192 .6761 .52881 .6711 .52303 Mtetra
.6711 .52303 .6761 .52881 .68655 .52568 .68158 .51989 Mtetra
.68158 .51989 .68655 .52568 .69704 .52255 .6921 .51673 Mtetra
.6921 .51673 .69704 .52255 .70757 .5194 .70265 .51356 Mtetra
.70265 .51356 .70757 .5194 .71814 .51624 .71324 .51038 Mtetra
.71324 .51038 .71814 .51624 .72874 .51307 .72388 .50719 Mtetra
.72388 .50719 .72874 .51307 .73939 .50989 .73455 .50399 Mtetra
.73455 .50399 .73939 .50989 .75008 .5067 .74527 .50077 Mtetra
.74527 .50077 .75008 .5067 .7608 .50349 .75602 .49754 Mtetra
.75602 .49754 .7608 .50349 .77157 .50027 .76681 .4943 Mtetra
.76681 .4943 .77157 .50027 .78237 .49704 .77765 .49105 Mtetra
.77765 .49105 .78237 .49704 .79322 .4938 .78852 .48779 Mtetra
.78852 .48779 .79322 .4938 .80411 .49055 .79944 .48451 Mtetra
.79944 .48451 .80411 .49055 .81504 .48728 .8104 .48122 Mtetra
.8104 .48122 .81504 .48728 .82601 .484 .8214 .47792 Mtetra
.8214 .47792 .82601 .484 .83702 .48071 .83244 .4746 Mtetra
.83244 .4746 .83702 .48071 .84808 .47741 .84353 .47128 Mtetra
.84353 .47128 .84808 .47741 .85917 .47409 .85465 .46794 Mtetra
.85465 .46794 .85917 .47409 .87031 .47076 .86582 .46458 Mtetra
.86582 .46458 .87031 .47076 .88149 .46742 .87704 .46122 Mtetra
.87704 .46122 .88149 .46742 .89272 .46407 .88829 .45784 Mtetra
.88829 .45784 .89272 .46407 .90398 .4607 .89959 .45445 Mtetra
.89959 .45445 .90398 .4607 .91529 .45732 .91093 .45104 Mtetra
.91093 .45104 .91529 .45732 .92665 .45393 .92232 .44763 Mtetra
.31232 .62385 .31818 .62896 .32738 .6262 .32155 .62107 Mtetra
.32155 .62107 .32738 .6262 .33662 .62343 .33081 .61828 Mtetra
.33081 .61828 .33662 .62343 .34589 .62064 .3401 .61548 Mtetra
.3401 .61548 .34589 .62064 .3552 .61785 .34942 .61267 Mtetra
.34942 .61267 .3552 .61785 .36453 .61505 .35878 .60985 Mtetra
.35878 .60985 .36453 .61505 .3739 .61224 .36817 .60702 Mtetra
.36817 .60702 .3739 .61224 .3833 .60942 .37759 .60418 Mtetra
.37759 .60418 .3833 .60942 .39274 .60658 .38704 .60133 Mtetra
.38704 .60133 .39274 .60658 .40221 .60374 .39653 .59847 Mtetra
.39653 .59847 .40221 .60374 .41171 .60089 .40606 .5956 Mtetra
.40606 .5956 .41171 .60089 .42124 .59803 .41561 .59272 Mtetra
.41561 .59272 .42124 .59803 .43081 .59516 .4252 .58983 Mtetra
.4252 .58983 .43081 .59516 .44042 .59227 .43483 .58692 Mtetra
.43483 .58692 .44042 .59227 .45005 .58938 .44449 .58401 Mtetra
.44449 .58401 .45005 .58938 .45972 .58648 .45418 .58109 Mtetra
.45418 .58109 .45972 .58648 .46943 .58356 .46391 .57816 Mtetra
.46391 .57816 .46943 .58356 .47917 .58064 .47367 .57521 Mtetra
.47367 .57521 .47917 .58064 .48895 .57771 .48347 .57226 Mtetra
.48347 .57226 .48895 .57771 .49876 .57476 .4933 .5693 Mtetra
.4933 .5693 .49876 .57476 .5086 .57181 .50317 .56632 Mtetra
.50317 .56632 .5086 .57181 .51849 .56884 .51308 .56334 Mtetra
.51308 .56334 .51849 .56884 .5284 .56586 .52302 .56034 Mtetra
.52302 .56034 .5284 .56586 .53836 .56288 .533 .55733 Mtetra
.533 .55733 .53836 .56288 .54835 .55988 .54301 .55431 Mtetra
.54301 .55431 .54835 .55988 .55837 .55687 .55306 .55128 Mtetra
.55306 .55128 .55837 .55687 .56843 .55385 .56314 .54824 Mtetra
.56314 .54824 .56843 .55385 .57853 .55082 .57327 .54519 Mtetra
.57327 .54519 .57853 .55082 .58867 .54777 .58343 .54213 Mtetra
.58343 .54213 .58867 .54777 .59884 .54472 .59363 .53905 Mtetra
.59363 .53905 .59884 .54472 .60905 .54166 .60386 .53597 Mtetra
.60386 .53597 .60905 .54166 .6193 .53858 .61413 .53287 Mtetra
.61413 .53287 .6193 .53858 .62958 .53549 .62444 .52976 Mtetra
.62444 .52976 .62958 .53549 .63991 .53239 .63479 .52664 Mtetra
.63479 .52664 .63991 .53239 .65027 .52928 .64518 .52351 Mtetra
.64518 .52351 .65027 .52928 .66067 .52616 .6556 .52037 Mtetra
.6556 .52037 .66067 .52616 .6711 .52303 .66607 .51722 Mtetra
.66607 .51722 .6711 .52303 .68158 .51989 .67657 .51405 Mtetra
.67657 .51405 .68158 .51989 .6921 .51673 .68711 .51087 Mtetra
.68711 .51087 .6921 .51673 .70265 .51356 .6977 .50768 Mtetra
.6977 .50768 .70265 .51356 .71324 .51038 .70832 .50448 Mtetra
.70832 .50448 .71324 .51038 .72388 .50719 .71898 .50127 Mtetra
.71898 .50127 .72388 .50719 .73455 .50399 .72968 .49804 Mtetra
.72968 .49804 .73455 .50399 .74527 .50077 .74042 .4948 Mtetra
.74042 .4948 .74527 .50077 .75602 .49754 .7512 .49155 Mtetra
.7512 .49155 .75602 .49754 .76681 .4943 .76203 .48829 Mtetra
.76203 .48829 .76681 .4943 .77765 .49105 .77289 .48501 Mtetra
.77289 .48501 .77765 .49105 .78852 .48779 .7838 .48173 Mtetra
.7838 .48173 .78852 .48779 .79944 .48451 .79474 .47843 Mtetra
.79474 .47843 .79944 .48451 .8104 .48122 .80573 .47511 Mtetra
.80573 .47511 .8104 .48122 .8214 .47792 .81676 .47179 Mtetra
.81676 .47179 .8214 .47792 .83244 .4746 .82783 .46845 Mtetra
.82783 .46845 .83244 .4746 .84353 .47128 .83895 .4651 Mtetra
.83895 .4651 .84353 .47128 .85465 .46794 .85011 .46174 Mtetra
.85011 .46174 .85465 .46794 .86582 .46458 .86131 .45836 Mtetra
.86131 .45836 .86582 .46458 .87704 .46122 .87255 .45497 Mtetra
.87255 .45497 .87704 .46122 .88829 .45784 .88384 .45157 Mtetra
.88384 .45157 .88829 .45784 .89959 .45445 .89517 .44815 Mtetra
.89517 .44815 .89959 .45445 .91093 .45104 .90654 .44472 Mtetra
.90654 .44472 .91093 .45104 .92232 .44763 .91796 .44128 Mtetra
.30643 .61871 .31232 .62385 .32155 .62107 .31568 .61591 Mtetra
.31568 .61591 .32155 .62107 .33081 .61828 .32495 .6131 Mtetra
.32495 .6131 .33081 .61828 .3401 .61548 .33427 .61028 Mtetra
.33427 .61028 .3401 .61548 .34942 .61267 .34361 .60746 Mtetra
.34361 .60746 .34942 .61267 .35878 .60985 .35299 .60462 Mtetra
.35299 .60462 .35878 .60985 .36817 .60702 .36239 .60177 Mtetra
.36239 .60177 .36817 .60702 .37759 .60418 .37184 .59891 Mtetra
.37184 .59891 .37759 .60418 .38704 .60133 .38131 .59604 Mtetra
.38131 .59604 .38704 .60133 .39653 .59847 .39082 .59316 Mtetra
.39082 .59316 .39653 .59847 .40606 .5956 .40037 .59027 Mtetra
.40037 .59027 .40606 .5956 .41561 .59272 .40995 .58737 Mtetra
.40995 .58737 .41561 .59272 .4252 .58983 .41956 .58446 Mtetra
.41956 .58446 .4252 .58983 .43483 .58692 .4292 .58154 Mtetra
.4292 .58154 .43483 .58692 .44449 .58401 .43888 .57861 Mtetra
.43888 .57861 .44449 .58401 .45418 .58109 .4486 .57567 Mtetra
.4486 .57567 .45418 .58109 .46391 .57816 .45835 .57272 Mtetra
.45835 .57272 .46391 .57816 .47367 .57521 .46814 .56975 Mtetra
.46814 .56975 .47367 .57521 .48347 .57226 .47796 .56678 Mtetra
.47796 .56678 .48347 .57226 .4933 .5693 .48781 .5638 Mtetra
.48781 .5638 .4933 .5693 .50317 .56632 .49771 .5608 Mtetra
.49771 .5608 .50317 .56632 .51308 .56334 .50763 .55779 Mtetra
.50763 .55779 .51308 .56334 .52302 .56034 .5176 .55478 Mtetra
.5176 .55478 .52302 .56034 .533 .55733 .5276 .55175 Mtetra
.5276 .55175 .533 .55733 .54301 .55431 .53764 .54871 Mtetra
.53764 .54871 .54301 .55431 .55306 .55128 .54771 .54566 Mtetra
.54771 .54566 .55306 .55128 .56314 .54824 .55782 .5426 Mtetra
.55782 .5426 .56314 .54824 .57327 .54519 .56797 .53953 Mtetra
.56797 .53953 .57327 .54519 .58343 .54213 .57815 .53644 Mtetra
.57815 .53644 .58343 .54213 .59363 .53905 .58837 .53335 Mtetra
.58837 .53335 .59363 .53905 .60386 .53597 .59864 .53024 Mtetra
.59864 .53024 .60386 .53597 .61413 .53287 .60893 .52712 Mtetra
.60893 .52712 .61413 .53287 .62444 .52976 .61927 .524 Mtetra
.61927 .524 .62444 .52976 .63479 .52664 .62964 .52085 Mtetra
.62964 .52085 .63479 .52664 .64518 .52351 .64006 .5177 Mtetra
.64006 .5177 .64518 .52351 .6556 .52037 .65051 .51454 Mtetra
.65051 .51454 .6556 .52037 .66607 .51722 .661 .51136 Mtetra
.661 .51136 .66607 .51722 .67657 .51405 .67153 .50817 Mtetra
.67153 .50817 .67657 .51405 .68711 .51087 .6821 .50497 Mtetra
.6821 .50497 .68711 .51087 .6977 .50768 .69271 .50176 Mtetra
.69271 .50176 .6977 .50768 .70832 .50448 .70336 .49854 Mtetra
.70336 .49854 .70832 .50448 .71898 .50127 .71405 .4953 Mtetra
.71405 .4953 .71898 .50127 .72968 .49804 .72477 .49205 Mtetra
.72477 .49205 .72968 .49804 .74042 .4948 .73554 .48879 Mtetra
.73554 .48879 .74042 .4948 .7512 .49155 .74636 .48552 Mtetra
.74636 .48552 .7512 .49155 .76203 .48829 .75721 .48223 Mtetra
.75721 .48223 .76203 .48829 .77289 .48501 .7681 .47893 Mtetra
.7681 .47893 .77289 .48501 .7838 .48173 .77903 .47562 Mtetra
.77903 .47562 .7838 .48173 .79474 .47843 .79001 .4723 Mtetra
.79001 .4723 .79474 .47843 .80573 .47511 .80103 .46897 Mtetra
.80103 .46897 .80573 .47511 .81676 .47179 .81209 .46562 Mtetra
.81209 .46562 .81676 .47179 .82783 .46845 .82319 .46226 Mtetra
.82319 .46226 .82783 .46845 .83895 .4651 .83434 .45888 Mtetra
.83434 .45888 .83895 .4651 .85011 .46174 .84552 .45549 Mtetra
.84552 .45549 .85011 .46174 .86131 .45836 .85676 .45209 Mtetra
.85676 .45209 .86131 .45836 .87255 .45497 .86803 .44868 Mtetra
.86803 .44868 .87255 .45497 .88384 .45157 .87935 .44525 Mtetra
.87935 .44525 .88384 .45157 .89517 .44815 .89071 .44181 Mtetra
.89071 .44181 .89517 .44815 .90654 .44472 .90212 .43836 Mtetra
.90212 .43836 .90654 .44472 .91796 .44128 .91357 .43489 Mtetra
.3005 .61354 .30643 .61871 .31568 .61591 .30977 .61072 Mtetra
.30977 .61072 .31568 .61591 .32495 .6131 .31906 .60789 Mtetra
.31906 .60789 .32495 .6131 .33427 .61028 .32839 .60505 Mtetra
.32839 .60505 .33427 .61028 .34361 .60746 .33776 .60221 Mtetra
.33776 .60221 .34361 .60746 .35299 .60462 .34715 .59935 Mtetra
.34715 .59935 .35299 .60462 .36239 .60177 .35658 .59648 Mtetra
.35658 .59648 .36239 .60177 .37184 .59891 .36605 .5936 Mtetra
.36605 .5936 .37184 .59891 .38131 .59604 .37555 .59072 Mtetra
.37555 .59072 .38131 .59604 .39082 .59316 .38508 .58782 Mtetra
.38508 .58782 .39082 .59316 .40037 .59027 .39464 .58491 Mtetra
.39464 .58491 .40037 .59027 .40995 .58737 .40424 .58199 Mtetra
.40424 .58199 .40995 .58737 .41956 .58446 .41387 .57906 Mtetra
.41387 .57906 .41956 .58446 .4292 .58154 .42354 .57612 Mtetra
.42354 .57612 .4292 .58154 .43888 .57861 .43324 .57317 Mtetra
.43324 .57317 .43888 .57861 .4486 .57567 .44298 .57021 Mtetra
.44298 .57021 .4486 .57567 .45835 .57272 .45276 .56724 Mtetra
.45276 .56724 .45835 .57272 .46814 .56975 .46256 .56426 Mtetra
.46256 .56426 .46814 .56975 .47796 .56678 .47241 .56126 Mtetra
.47241 .56126 .47796 .56678 .48781 .5638 .48229 .55826 Mtetra
.48229 .55826 .48781 .5638 .49771 .5608 .4922 .55524 Mtetra
.4922 .55524 .49771 .5608 .50763 .55779 .50215 .55222 Mtetra
.50215 .55222 .50763 .55779 .5176 .55478 .51214 .54918 Mtetra
.51214 .54918 .5176 .55478 .5276 .55175 .52217 .54613 Mtetra
.52217 .54613 .5276 .55175 .53764 .54871 .53223 .54307 Mtetra
.53223 .54307 .53764 .54871 .54771 .54566 .54232 .54 Mtetra
.54232 .54 .54771 .54566 .55782 .5426 .55246 .53692 Mtetra
.55246 .53692 .55782 .5426 .56797 .53953 .56263 .53383 Mtetra
.56263 .53383 .56797 .53953 .57815 .53644 .57284 .53072 Mtetra
.57284 .53072 .57815 .53644 .58837 .53335 .58309 .52761 Mtetra
.58309 .52761 .58837 .53335 .59864 .53024 .59337 .52448 Mtetra
.59337 .52448 .59864 .53024 .60893 .52712 .6037 .52134 Mtetra
.6037 .52134 .60893 .52712 .61927 .524 .61406 .51819 Mtetra
.61406 .51819 .61927 .524 .62964 .52085 .62446 .51503 Mtetra
.62446 .51503 .62964 .52085 .64006 .5177 .6349 .51185 Mtetra
.6349 .51185 .64006 .5177 .65051 .51454 .64538 .50866 Mtetra
.64538 .50866 .65051 .51454 .661 .51136 .65589 .50547 Mtetra
.65589 .50547 .661 .51136 .67153 .50817 .66645 .50226 Mtetra
.66645 .50226 .67153 .50817 .6821 .50497 .67705 .49903 Mtetra
.67705 .49903 .6821 .50497 .69271 .50176 .68768 .4958 Mtetra
.68768 .4958 .69271 .50176 .70336 .49854 .69836 .49255 Mtetra
.69836 .49255 .70336 .49854 .71405 .4953 .70908 .48929 Mtetra
.70908 .48929 .71405 .4953 .72477 .49205 .71984 .48602 Mtetra
.71984 .48602 .72477 .49205 .73554 .48879 .73063 .48274 Mtetra
.73063 .48274 .73554 .48879 .74636 .48552 .74147 .47944 Mtetra
.74147 .47944 .74636 .48552 .75721 .48223 .75235 .47613 Mtetra
.75235 .47613 .75721 .48223 .7681 .47893 .76328 .47281 Mtetra
.76328 .47281 .7681 .47893 .77903 .47562 .77424 .46948 Mtetra
.77424 .46948 .77903 .47562 .79001 .4723 .78524 .46613 Mtetra
.78524 .46613 .79001 .4723 .80103 .46897 .79629 .46277 Mtetra
.79629 .46277 .80103 .46897 .81209 .46562 .80738 .4594 Mtetra
.80738 .4594 .81209 .46562 .82319 .46226 .81852 .45602 Mtetra
.81852 .45602 .82319 .46226 .83434 .45888 .82969 .45262 Mtetra
.82969 .45262 .83434 .45888 .84552 .45549 .84091 .44921 Mtetra
.84091 .44921 .84552 .45549 .85676 .45209 .85217 .44578 Mtetra
.85217 .44578 .85676 .45209 .86803 .44868 .86348 .44234 Mtetra
.86348 .44234 .86803 .44868 .87935 .44525 .87483 .43889 Mtetra
.87483 .43889 .87935 .44525 .89071 .44181 .88623 .43543 Mtetra
.88623 .43543 .89071 .44181 .90212 .43836 .89766 .43195 Mtetra
.89766 .43195 .90212 .43836 .91357 .43489 .90915 .42846 Mtetra
.29453 .60833 .3005 .61354 .30977 .61072 .30382 .60549 Mtetra
.30382 .60549 .30977 .61072 .31906 .60789 .31314 .60265 Mtetra
.31314 .60265 .31906 .60789 .32839 .60505 .32249 .59979 Mtetra
.32249 .59979 .32839 .60505 .33776 .60221 .33187 .59692 Mtetra
.33187 .59692 .33776 .60221 .34715 .59935 .34129 .59405 Mtetra
.34129 .59405 .34715 .59935 .35658 .59648 .35074 .59116 Mtetra
.35074 .59116 .35658 .59648 .36605 .5936 .36022 .58826 Mtetra
.36022 .58826 .36605 .5936 .37555 .59072 .36974 .58536 Mtetra
.36974 .58536 .37555 .59072 .38508 .58782 .37929 .58244 Mtetra
.37929 .58244 .38508 .58782 .39464 .58491 .38888 .57951 Mtetra
.38888 .57951 .39464 .58491 .40424 .58199 .3985 .57657 Mtetra
.3985 .57657 .40424 .58199 .41387 .57906 .40815 .57363 Mtetra
.40815 .57363 .41387 .57906 .42354 .57612 .41784 .57067 Mtetra
.41784 .57067 .42354 .57612 .43324 .57317 .42757 .5677 Mtetra
.42757 .5677 .43324 .57317 .44298 .57021 .43733 .56471 Mtetra
.43733 .56471 .44298 .57021 .45276 .56724 .44712 .56172 Mtetra
.44712 .56172 .45276 .56724 .46256 .56426 .45695 .55872 Mtetra
.45695 .55872 .46256 .56426 .47241 .56126 .46682 .55571 Mtetra
.46682 .55571 .47241 .56126 .48229 .55826 .47672 .55268 Mtetra
.47672 .55268 .48229 .55826 .4922 .55524 .48666 .54965 Mtetra
.48666 .54965 .4922 .55524 .50215 .55222 .49664 .5466 Mtetra
.49664 .5466 .50215 .55222 .51214 .54918 .50665 .54354 Mtetra
.50665 .54354 .51214 .54918 .52217 .54613 .5167 .54047 Mtetra
.5167 .54047 .52217 .54613 .53223 .54307 .52678 .53739 Mtetra
.52678 .53739 .53223 .54307 .54232 .54 .5369 .5343 Mtetra
.5369 .5343 .54232 .54 .55246 .53692 .54706 .5312 Mtetra
.54706 .5312 .55246 .53692 .56263 .53383 .55726 .52809 Mtetra
.55726 .52809 .56263 .53383 .57284 .53072 .56749 .52496 Mtetra
.56749 .52496 .57284 .53072 .58309 .52761 .57777 .52182 Mtetra
.57777 .52182 .58309 .52761 .59337 .52448 .58808 .51867 Mtetra
.58808 .51867 .59337 .52448 .6037 .52134 .59843 .51551 Mtetra
.59843 .51551 .6037 .52134 .61406 .51819 .60881 .51234 Mtetra
.60881 .51234 .61406 .51819 .62446 .51503 .61924 .50916 Mtetra
.61924 .50916 .62446 .51503 .6349 .51185 .62971 .50596 Mtetra
.62971 .50596 .6349 .51185 .64538 .50866 .64021 .50275 Mtetra
.64021 .50275 .64538 .50866 .65589 .50547 .65075 .49953 Mtetra
.65075 .49953 .65589 .50547 .66645 .50226 .66134 .4963 Mtetra
.66134 .4963 .66645 .50226 .67705 .49903 .67196 .49305 Mtetra
.67196 .49305 .67705 .49903 .68768 .4958 .68263 .4898 Mtetra
.68263 .4898 .68768 .4958 .69836 .49255 .69333 .48653 Mtetra
.69333 .48653 .69836 .49255 .70908 .48929 .70408 .48325 Mtetra
.70408 .48325 .70908 .48929 .71984 .48602 .71486 .47995 Mtetra
.71486 .47995 .71984 .48602 .73063 .48274 .72569 .47664 Mtetra
.72569 .47664 .73063 .48274 .74147 .47944 .73656 .47333 Mtetra
.73656 .47333 .74147 .47944 .75235 .47613 .74746 .46999 Mtetra
.74746 .46999 .75235 .47613 .76328 .47281 .75842 .46665 Mtetra
.75842 .46665 .76328 .47281 .77424 .46948 .76941 .46329 Mtetra
.76941 .46329 .77424 .46948 .78524 .46613 .78044 .45992 Mtetra
.78044 .45992 .78524 .46613 .79629 .46277 .79152 .45654 Mtetra
.79152 .45654 .79629 .46277 .80738 .4594 .80264 .45314 Mtetra
.80264 .45314 .80738 .4594 .81852 .45602 .81381 .44973 Mtetra
.81381 .44973 .81852 .45602 .82969 .45262 .82501 .44631 Mtetra
.82501 .44631 .82969 .45262 .84091 .44921 .83626 .44287 Mtetra
.83626 .44287 .84091 .44921 .85217 .44578 .84756 .43942 Mtetra
.84756 .43942 .85217 .44578 .86348 .44234 .8589 .43596 Mtetra
.8589 .43596 .86348 .44234 .87483 .43889 .87028 .43248 Mtetra
.87028 .43248 .87483 .43889 .88623 .43543 .88171 .42899 Mtetra
.88171 .42899 .88623 .43543 .89766 .43195 .89318 .42549 Mtetra
.89318 .42549 .89766 .43195 .90915 .42846 .90469 .42197 Mtetra
.28853 .60308 .29453 .60833 .30382 .60549 .29783 .60023 Mtetra
.29783 .60023 .30382 .60549 .31314 .60265 .30717 .59737 Mtetra
.30717 .59737 .31314 .60265 .32249 .59979 .31654 .59449 Mtetra
.31654 .59449 .32249 .59979 .33187 .59692 .32594 .59161 Mtetra
.32594 .59161 .33187 .59692 .34129 .59405 .33538 .58871 Mtetra
.33538 .58871 .34129 .59405 .35074 .59116 .34485 .58581 Mtetra
.34485 .58581 .35074 .59116 .36022 .58826 .35435 .58289 Mtetra
.35435 .58289 .36022 .58826 .36974 .58536 .36389 .57996 Mtetra
.36389 .57996 .36974 .58536 .37929 .58244 .37347 .57703 Mtetra
.37347 .57703 .37929 .58244 .38888 .57951 .38307 .57408 Mtetra
.38307 .57408 .38888 .57951 .3985 .57657 .39272 .57112 Mtetra
.39272 .57112 .3985 .57657 .40815 .57363 .40239 .56815 Mtetra
.40239 .56815 .40815 .57363 .41784 .57067 .41211 .56517 Mtetra
.41211 .56517 .41784 .57067 .42757 .5677 .42185 .56218 Mtetra
.42185 .56218 .42757 .5677 .43733 .56471 .43163 .55918 Mtetra
.43163 .55918 .43733 .56471 .44712 .56172 .44145 .55617 Mtetra
.44145 .55617 .44712 .56172 .45695 .55872 .45131 .55315 Mtetra
.45131 .55315 .45695 .55872 .46682 .55571 .4612 .55012 Mtetra
.4612 .55012 .46682 .55571 .47672 .55268 .47112 .54707 Mtetra
.47112 .54707 .47672 .55268 .48666 .54965 .48108 .54401 Mtetra
.48108 .54401 .48666 .54965 .49664 .5466 .49108 .54095 Mtetra
.49108 .54095 .49664 .5466 .50665 .54354 .50112 .53787 Mtetra
.50112 .53787 .50665 .54354 .5167 .54047 .51119 .53478 Mtetra
.51119 .53478 .5167 .54047 .52678 .53739 .5213 .53168 Mtetra
.5213 .53168 .52678 .53739 .5369 .5343 .53144 .52857 Mtetra
.53144 .52857 .5369 .5343 .54706 .5312 .54163 .52544 Mtetra
.54163 .52544 .54706 .5312 .55726 .52809 .55185 .52231 Mtetra
.55185 .52231 .55726 .52809 .56749 .52496 .56211 .51916 Mtetra
.56211 .51916 .56749 .52496 .57777 .52182 .57241 .516 Mtetra
.57241 .516 .57777 .52182 .58808 .51867 .58274 .51283 Mtetra
.58274 .51283 .58808 .51867 .59843 .51551 .59312 .50965 Mtetra
.59312 .50965 .59843 .51551 .60881 .51234 .60353 .50645 Mtetra
.60353 .50645 .60881 .51234 .61924 .50916 .61398 .50324 Mtetra
.61398 .50324 .61924 .50916 .62971 .50596 .62448 .50003 Mtetra
.62448 .50003 .62971 .50596 .64021 .50275 .63501 .4968 Mtetra
.63501 .4968 .64021 .50275 .65075 .49953 .64558 .49355 Mtetra
.64558 .49355 .65075 .49953 .66134 .4963 .65619 .4903 Mtetra
.65619 .4903 .66134 .4963 .67196 .49305 .66684 .48703 Mtetra
.66684 .48703 .67196 .49305 .68263 .4898 .67753 .48375 Mtetra
.67753 .48375 .68263 .4898 .69333 .48653 .68826 .48046 Mtetra
.68826 .48046 .69333 .48653 .70408 .48325 .69904 .47715 Mtetra
.69904 .47715 .70408 .48325 .71486 .47995 .70985 .47384 Mtetra
.70985 .47384 .71486 .47995 .72569 .47664 .72071 .47051 Mtetra
.72071 .47051 .72569 .47664 .73656 .47333 .7316 .46716 Mtetra
.7316 .46716 .73656 .47333 .74746 .46999 .74254 .46381 Mtetra
.74254 .46381 .74746 .46999 .75842 .46665 .75352 .46044 Mtetra
.75352 .46044 .75842 .46665 .76941 .46329 .76455 .45706 Mtetra
.76455 .45706 .76941 .46329 .78044 .45992 .77561 .45366 Mtetra
.77561 .45366 .78044 .45992 .79152 .45654 .78672 .45026 Mtetra
.78672 .45026 .79152 .45654 .80264 .45314 .79787 .44684 Mtetra
.79787 .44684 .80264 .45314 .81381 .44973 .80906 .4434 Mtetra
.80906 .4434 .81381 .44973 .82501 .44631 .8203 .43995 Mtetra
.8203 .43995 .82501 .44631 .83626 .44287 .83158 .43649 Mtetra
.83158 .43649 .83626 .44287 .84756 .43942 .84291 .43302 Mtetra
.84291 .43302 .84756 .43942 .8589 .43596 .85428 .42953 Mtetra
.85428 .42953 .8589 .43596 .87028 .43248 .86569 .42603 Mtetra
.86569 .42603 .87028 .43248 .88171 .42899 .87715 .42251 Mtetra
.87715 .42251 .88171 .42899 .89318 .42549 .88866 .41899 Mtetra
.88866 .41899 .89318 .42549 .90469 .42197 .90021 .41544 Mtetra
.28248 .59781 .28853 .60308 .29783 .60023 .2918 .59493 Mtetra
.2918 .59493 .29783 .60023 .30717 .59737 .30116 .59205 Mtetra
.30116 .59205 .30717 .59737 .31654 .59449 .31055 .58916 Mtetra
.31055 .58916 .31654 .59449 .32594 .59161 .31998 .58625 Mtetra
.31998 .58625 .32594 .59161 .33538 .58871 .32943 .58334 Mtetra
.32943 .58334 .33538 .58871 .34485 .58581 .33892 .58041 Mtetra
.33892 .58041 .34485 .58581 .35435 .58289 .34845 .57748 Mtetra
.34845 .57748 .35435 .58289 .36389 .57996 .35801 .57453 Mtetra
.35801 .57453 .36389 .57996 .37347 .57703 .3676 .57158 Mtetra
.3676 .57158 .37347 .57703 .38307 .57408 .37723 .56861 Mtetra
.37723 .56861 .38307 .57408 .39272 .57112 .3869 .56563 Mtetra
.3869 .56563 .39272 .57112 .40239 .56815 .3966 .56264 Mtetra
.3966 .56264 .40239 .56815 .41211 .56517 .40633 .55965 Mtetra
.40633 .55965 .41211 .56517 .42185 .56218 .4161 .55664 Mtetra
.4161 .55664 .42185 .56218 .43163 .55918 .4259 .55361 Mtetra
.4259 .55361 .43163 .55918 .44145 .55617 .43574 .55058 Mtetra
.43574 .55058 .44145 .55617 .45131 .55315 .44562 .54754 Mtetra
.44562 .54754 .45131 .55315 .4612 .55012 .45553 .54449 Mtetra
.45553 .54449 .4612 .55012 .47112 .54707 .46548 .54142 Mtetra
.46548 .54142 .47112 .54707 .48108 .54401 .47547 .53834 Mtetra
.47547 .53834 .48108 .54401 .49108 .54095 .48549 .53526 Mtetra
.48549 .53526 .49108 .54095 .50112 .53787 .49555 .53216 Mtetra
.49555 .53216 .50112 .53787 .51119 .53478 .50564 .52905 Mtetra
.50564 .52905 .51119 .53478 .5213 .53168 .51578 .52592 Mtetra
.51578 .52592 .5213 .53168 .53144 .52857 .52595 .52279 Mtetra
.52595 .52279 .53144 .52857 .54163 .52544 .53616 .51964 Mtetra
.53616 .51964 .54163 .52544 .55185 .52231 .5464 .51649 Mtetra
.5464 .51649 .55185 .52231 .56211 .51916 .55669 .51332 Mtetra
.55669 .51332 .56211 .51916 .57241 .516 .56701 .51014 Mtetra
.56701 .51014 .57241 .516 .58274 .51283 .57737 .50694 Mtetra
.57737 .50694 .58274 .51283 .59312 .50965 .58777 .50374 Mtetra
.58777 .50374 .59312 .50965 .60353 .50645 .59821 .50052 Mtetra
.59821 .50052 .60353 .50645 .61398 .50324 .60869 .49729 Mtetra
.60869 .49729 .61398 .50324 .62448 .50003 .61921 .49405 Mtetra
.61921 .49405 .62448 .50003 .63501 .4968 .62977 .4908 Mtetra
.62977 .4908 .63501 .4968 .64558 .49355 .64037 .48753 Mtetra
.64037 .48753 .64558 .49355 .65619 .4903 .65101 .48426 Mtetra
.65101 .48426 .65619 .4903 .66684 .48703 .66168 .48097 Mtetra
.66168 .48097 .66684 .48703 .67753 .48375 .6724 .47766 Mtetra
.6724 .47766 .67753 .48375 .68826 .48046 .68316 .47435 Mtetra
.68316 .47435 .68826 .48046 .69904 .47715 .69396 .47102 Mtetra
.69396 .47102 .69904 .47715 .70985 .47384 .70481 .46768 Mtetra
.70481 .46768 .70985 .47384 .72071 .47051 .71569 .46433 Mtetra
.71569 .46433 .72071 .47051 .7316 .46716 .72662 .46096 Mtetra
.72662 .46096 .7316 .46716 .74254 .46381 .73758 .45758 Mtetra
.73758 .45758 .74254 .46381 .75352 .46044 .74859 .45419 Mtetra
.74859 .45419 .75352 .46044 .76455 .45706 .75965 .45078 Mtetra
.75965 .45078 .76455 .45706 .77561 .45366 .77074 .44736 Mtetra
.77074 .44736 .77561 .45366 .78672 .45026 .78188 .44393 Mtetra
.78188 .44393 .78672 .45026 .79787 .44684 .79306 .44049 Mtetra
.79306 .44049 .79787 .44684 .80906 .4434 .80429 .43703 Mtetra
.80429 .43703 .80906 .4434 .8203 .43995 .81556 .43355 Mtetra
.81556 .43355 .8203 .43995 .83158 .43649 .82687 .43007 Mtetra
.82687 .43007 .83158 .43649 .84291 .43302 .83823 .42657 Mtetra
.83823 .42657 .84291 .43302 .85428 .42953 .84963 .42306 Mtetra
.84963 .42306 .85428 .42953 .86569 .42603 .86108 .41953 Mtetra
.86108 .41953 .86569 .42603 .87715 .42251 .87257 .41599 Mtetra
.87257 .41599 .87715 .42251 .88866 .41899 .8841 .41243 Mtetra
.8841 .41243 .88866 .41899 .90021 .41544 .89569 .40886 Mtetra
.27639 .59249 .28248 .59781 .2918 .59493 .28574 .5896 Mtetra
.28574 .5896 .2918 .59493 .30116 .59205 .29511 .5867 Mtetra
.29511 .5867 .30116 .59205 .31055 .58916 .30452 .58379 Mtetra
.30452 .58379 .31055 .58916 .31998 .58625 .31397 .58087 Mtetra
.31397 .58087 .31998 .58625 .32943 .58334 .32345 .57793 Mtetra
.32345 .57793 .32943 .58334 .33892 .58041 .33296 .57499 Mtetra
.33296 .57499 .33892 .58041 .34845 .57748 .34251 .57203 Mtetra
.34251 .57203 .34845 .57748 .35801 .57453 .35209 .56907 Mtetra
.35209 .56907 .35801 .57453 .3676 .57158 .3617 .56609 Mtetra
.3617 .56609 .3676 .57158 .37723 .56861 .37135 .56311 Mtetra
.37135 .56311 .37723 .56861 .3869 .56563 .38104 .56011 Mtetra
.38104 .56011 .3869 .56563 .3966 .56264 .39076 .5571 Mtetra
.39076 .5571 .3966 .56264 .40633 .55965 .40052 .55408 Mtetra
.40052 .55408 .40633 .55965 .4161 .55664 .41031 .55105 Mtetra
.41031 .55105 .4161 .55664 .4259 .55361 .42013 .54801 Mtetra
.42013 .54801 .4259 .55361 .43574 .55058 .43 .54496 Mtetra
.43 .54496 .43574 .55058 .44562 .54754 .4399 .54189 Mtetra
.4399 .54189 .44562 .54754 .45553 .54449 .44983 .53882 Mtetra
.44983 .53882 .45553 .54449 .46548 .54142 .4598 .53573 Mtetra
.4598 .53573 .46548 .54142 .47547 .53834 .46981 .53263 Mtetra
.46981 .53263 .47547 .53834 .48549 .53526 .47986 .52952 Mtetra
.47986 .52952 .48549 .53526 .49555 .53216 .48994 .5264 Mtetra
.48994 .5264 .49555 .53216 .50564 .52905 .50006 .52327 Mtetra
.50006 .52327 .50564 .52905 .51578 .52592 .51022 .52013 Mtetra
.51022 .52013 .51578 .52592 .52595 .52279 .52041 .51697 Mtetra
.52041 .51697 .52595 .52279 .53616 .51964 .53065 .51381 Mtetra
.53065 .51381 .53616 .51964 .5464 .51649 .54092 .51063 Mtetra
.54092 .51063 .5464 .51649 .55669 .51332 .55123 .50744 Mtetra
.55123 .50744 .55669 .51332 .56701 .51014 .56158 .50423 Mtetra
.56158 .50423 .56701 .51014 .57737 .50694 .57197 .50102 Mtetra
.57197 .50102 .57737 .50694 .58777 .50374 .58239 .49779 Mtetra
.58239 .49779 .58777 .50374 .59821 .50052 .59286 .49455 Mtetra
.59286 .49455 .59821 .50052 .60869 .49729 .60336 .4913 Mtetra
.60336 .4913 .60869 .49729 .61921 .49405 .61391 .48804 Mtetra
.61391 .48804 .61921 .49405 .62977 .4908 .62449 .48476 Mtetra
.62449 .48476 .62977 .4908 .64037 .48753 .63512 .48147 Mtetra
.63512 .48147 .64037 .48753 .65101 .48426 .64578 .47817 Mtetra
.64578 .47817 .65101 .48426 .66168 .48097 .65649 .47486 Mtetra
.65649 .47486 .66168 .48097 .6724 .47766 .66724 .47153 Mtetra
.66724 .47153 .6724 .47766 .68316 .47435 .67803 .46819 Mtetra
.67803 .46819 .68316 .47435 .69396 .47102 .68886 .46484 Mtetra
.68886 .46484 .69396 .47102 .70481 .46768 .69973 .46148 Mtetra
.69973 .46148 .70481 .46768 .71569 .46433 .71064 .4581 Mtetra
.71064 .4581 .71569 .46433 .72662 .46096 .72159 .45471 Mtetra
.72159 .45471 .72662 .46096 .73758 .45758 .73259 .45131 Mtetra
.73259 .45131 .73758 .45758 .74859 .45419 .74363 .44789 Mtetra
.74363 .44789 .74859 .45419 .75965 .45078 .75471 .44446 Mtetra
.75471 .44446 .75965 .45078 .77074 .44736 .76584 .44102 Mtetra
.76584 .44102 .77074 .44736 .78188 .44393 .77701 .43756 Mtetra
.77701 .43756 .78188 .44393 .79306 .44049 .78822 .43409 Mtetra
.78822 .43409 .79306 .44049 .80429 .43703 .79948 .43061 Mtetra
.79948 .43061 .80429 .43703 .81556 .43355 .81078 .42711 Mtetra
.81078 .42711 .81556 .43355 .82687 .43007 .82212 .4236 Mtetra
.82212 .4236 .82687 .43007 .83823 .42657 .83351 .42007 Mtetra
.83351 .42007 .83823 .42657 .84963 .42306 .84494 .41653 Mtetra
.84494 .41653 .84963 .42306 .86108 .41953 .85642 .41298 Mtetra
.85642 .41298 .86108 .41953 .87257 .41599 .86795 .40941 Mtetra
.86795 .40941 .87257 .41599 .8841 .41243 .87952 .40583 Mtetra
.87952 .40583 .8841 .41243 .89569 .40886 .89113 .40224 Mtetra
.27027 .58715 .27639 .59249 .28574 .5896 .27963 .58424 Mtetra
.27963 .58424 .28574 .5896 .29511 .5867 .28903 .58132 Mtetra
.28903 .58132 .29511 .5867 .30452 .58379 .29846 .57838 Mtetra
.29846 .57838 .30452 .58379 .31397 .58087 .30792 .57544 Mtetra
.30792 .57544 .31397 .58087 .32345 .57793 .31742 .57249 Mtetra
.31742 .57249 .32345 .57793 .33296 .57499 .32696 .56952 Mtetra
.32696 .56952 .33296 .57499 .34251 .57203 .33652 .56655 Mtetra
.33652 .56655 .34251 .57203 .35209 .56907 .34613 .56357 Mtetra
.34613 .56357 .35209 .56907 .3617 .56609 .35576 .56057 Mtetra
.35576 .56057 .3617 .56609 .37135 .56311 .36543 .55756 Mtetra
.36543 .55756 .37135 .56311 .38104 .56011 .37514 .55455 Mtetra
.37514 .55455 .38104 .56011 .39076 .5571 .38488 .55152 Mtetra
.38488 .55152 .39076 .5571 .40052 .55408 .39466 .54848 Mtetra
.39466 .54848 .40052 .55408 .41031 .55105 .40448 .54543 Mtetra
.40448 .54543 .41031 .55105 .42013 .54801 .41432 .54236 Mtetra
.41432 .54236 .42013 .54801 .43 .54496 .42421 .53929 Mtetra
.42421 .53929 .43 .54496 .4399 .54189 .43413 .53621 Mtetra
.43413 .53621 .4399 .54189 .44983 .53882 .44409 .53311 Mtetra
.44409 .53311 .44983 .53882 .4598 .53573 .45409 .53 Mtetra
.45409 .53 .4598 .53573 .46981 .53263 .46412 .52688 Mtetra
.46412 .52688 .46981 .53263 .47986 .52952 .47419 .52375 Mtetra
.47419 .52375 .47986 .52952 .48994 .5264 .4843 .52061 Mtetra
.4843 .52061 .48994 .5264 .50006 .52327 .49444 .51746 Mtetra
.49444 .51746 .50006 .52327 .51022 .52013 .50462 .51429 Mtetra
.50462 .51429 .51022 .52013 .52041 .51697 .51484 .51112 Mtetra
.51484 .51112 .52041 .51697 .53065 .51381 .5251 .50793 Mtetra
.5251 .50793 .53065 .51381 .54092 .51063 .5354 .50473 Mtetra
.5354 .50473 .54092 .51063 .55123 .50744 .54573 .50151 Mtetra
.54573 .50151 .55123 .50744 .56158 .50423 .55611 .49829 Mtetra
.55611 .49829 .56158 .50423 .57197 .50102 .56652 .49505 Mtetra
.56652 .49505 .57197 .50102 .58239 .49779 .57697 .4918 Mtetra
.57697 .4918 .58239 .49779 .59286 .49455 .58747 .48854 Mtetra
.58747 .48854 .59286 .49455 .60336 .4913 .598 .48527 Mtetra
.598 .48527 .60336 .4913 .61391 .48804 .60857 .48198 Mtetra
.60857 .48198 .61391 .48804 .62449 .48476 .61918 .47868 Mtetra
.61918 .47868 .62449 .48476 .63512 .48147 .62983 .47537 Mtetra
.62983 .47537 .63512 .48147 .64578 .47817 .64053 .47205 Mtetra
.64053 .47205 .64578 .47817 .65649 .47486 .65126 .46871 Mtetra
.65126 .46871 .65649 .47486 .66724 .47153 .66204 .46536 Mtetra
.66204 .46536 .66724 .47153 .67803 .46819 .67285 .462 Mtetra
.67285 .462 .67803 .46819 .68886 .46484 .68371 .45862 Mtetra
.68371 .45862 .68886 .46484 .69973 .46148 .69461 .45523 Mtetra
.69461 .45523 .69973 .46148 .71064 .4581 .70555 .45183 Mtetra
.70555 .45183 .71064 .4581 .72159 .45471 .71654 .44842 Mtetra
.71654 .44842 .72159 .45471 .73259 .45131 .72756 .44499 Mtetra
.72756 .44499 .73259 .45131 .74363 .44789 .73863 .44155 Mtetra
.73863 .44155 .74363 .44789 .75471 .44446 .74974 .43809 Mtetra
.74974 .43809 .75471 .44446 .76584 .44102 .7609 .43462 Mtetra
.7609 .43462 .76584 .44102 .77701 .43756 .7721 .43114 Mtetra
.7721 .43114 .77701 .43756 .78822 .43409 .78334 .42765 Mtetra
.78334 .42765 .78822 .43409 .79948 .43061 .79463 .42414 Mtetra
.79463 .42414 .79948 .43061 .81078 .42711 .80596 .42062 Mtetra
.80596 .42062 .81078 .42711 .82212 .4236 .81734 .41708 Mtetra
.81734 .41708 .82212 .4236 .83351 .42007 .82876 .41353 Mtetra
.82876 .41353 .83351 .42007 .84494 .41653 .84023 .40996 Mtetra
.84023 .40996 .84494 .41653 .85642 .41298 .85174 .40639 Mtetra
.85174 .40639 .85642 .41298 .86795 .40941 .8633 .40279 Mtetra
.8633 .40279 .86795 .40941 .87952 .40583 .8749 .39919 Mtetra
.8749 .39919 .87952 .40583 .89113 .40224 .88655 .39556 Mtetra
.2641 .58177 .27027 .58715 .27963 .58424 .27348 .57884 Mtetra
.27348 .57884 .27963 .58424 .28903 .58132 .2829 .57589 Mtetra
.2829 .57589 .28903 .58132 .29846 .57838 .29235 .57294 Mtetra
.29235 .57294 .29846 .57838 .30792 .57544 .30184 .56998 Mtetra
.30184 .56998 .30792 .57544 .31742 .57249 .31136 .56701 Mtetra
.31136 .56701 .31742 .57249 .32696 .56952 .32091 .56403 Mtetra
.32091 .56403 .32696 .56952 .33652 .56655 .3305 .56103 Mtetra
.3305 .56103 .33652 .56655 .34613 .56357 .34012 .55803 Mtetra
.34012 .55803 .34613 .56357 .35576 .56057 .34978 .55501 Mtetra
.34978 .55501 .35576 .56057 .36543 .55756 .35947 .55198 Mtetra
.35947 .55198 .36543 .55756 .37514 .55455 .3692 .54895 Mtetra
.3692 .54895 .37514 .55455 .38488 .55152 .37897 .5459 Mtetra
.37897 .5459 .38488 .55152 .39466 .54848 .38877 .54284 Mtetra
.38877 .54284 .39466 .54848 .40448 .54543 .3986 .53976 Mtetra
.3986 .53976 .40448 .54543 .41432 .54236 .40848 .53668 Mtetra
.40848 .53668 .41432 .54236 .42421 .53929 .41839 .53359 Mtetra
.41839 .53359 .42421 .53929 .43413 .53621 .42833 .53048 Mtetra
.42833 .53048 .43413 .53621 .44409 .53311 .43831 .52737 Mtetra
.43831 .52737 .44409 .53311 .45409 .53 .44833 .52424 Mtetra
.44833 .52424 .45409 .53 .46412 .52688 .45839 .5211 Mtetra
.45839 .5211 .46412 .52688 .47419 .52375 .46848 .51794 Mtetra
.46848 .51794 .47419 .52375 .4843 .52061 .47861 .51478 Mtetra
.47861 .51478 .4843 .52061 .49444 .51746 .48878 .51161 Mtetra
.48878 .51161 .49444 .51746 .50462 .51429 .49899 .50842 Mtetra
.49899 .50842 .50462 .51429 .51484 .51112 .50923 .50522 Mtetra
.50923 .50522 .51484 .51112 .5251 .50793 .51952 .50201 Mtetra
.51952 .50201 .5251 .50793 .5354 .50473 .52984 .49879 Mtetra
.52984 .49879 .5354 .50473 .54573 .50151 .5402 .49555 Mtetra
.5402 .49555 .54573 .50151 .55611 .49829 .5506 .4923 Mtetra
.5506 .4923 .55611 .49829 .56652 .49505 .56104 .48904 Mtetra
.56104 .48904 .56652 .49505 .57697 .4918 .57152 .48577 Mtetra
.57152 .48577 .57697 .4918 .58747 .48854 .58203 .48249 Mtetra
.58203 .48249 .58747 .48854 .598 .48527 .59259 .47919 Mtetra
.59259 .47919 .598 .48527 .60857 .48198 .60319 .47588 Mtetra
.60319 .47588 .60857 .48198 .61918 .47868 .61383 .47256 Mtetra
.61383 .47256 .61918 .47868 .62983 .47537 .62451 .46922 Mtetra
.62451 .46922 .62983 .47537 .64053 .47205 .63523 .46587 Mtetra
.63523 .46587 .64053 .47205 .65126 .46871 .64599 .46251 Mtetra
.64599 .46251 .65126 .46871 .66204 .46536 .6568 .45914 Mtetra
.6568 .45914 .66204 .46536 .67285 .462 .66764 .45575 Mtetra
.66764 .45575 .67285 .462 .68371 .45862 .67853 .45235 Mtetra
.67853 .45235 .68371 .45862 .69461 .45523 .68946 .44894 Mtetra
.68946 .44894 .69461 .45523 .70555 .45183 .70043 .44552 Mtetra
.70043 .44552 .70555 .45183 .71654 .44842 .71144 .44208 Mtetra
.71144 .44208 .71654 .44842 .72756 .44499 .7225 .43862 Mtetra
.7225 .43862 .72756 .44499 .73863 .44155 .7336 .43516 Mtetra
.7336 .43516 .73863 .44155 .74974 .43809 .74474 .43168 Mtetra
.74474 .43168 .74974 .43809 .7609 .43462 .75593 .42819 Mtetra
.75593 .42819 .7609 .43462 .7721 .43114 .76716 .42468 Mtetra
.76716 .42468 .7721 .43114 .78334 .42765 .77843 .42116 Mtetra
.77843 .42116 .78334 .42765 .79463 .42414 .78975 .41762 Mtetra
.78975 .41762 .79463 .42414 .80596 .42062 .80111 .41408 Mtetra
.80111 .41408 .80596 .42062 .81734 .41708 .81252 .41051 Mtetra
.81252 .41051 .81734 .41708 .82876 .41353 .82397 .40694 Mtetra
.82397 .40694 .82876 .41353 .84023 .40996 .83547 .40335 Mtetra
.83547 .40335 .84023 .40996 .85174 .40639 .84702 .39974 Mtetra
.84702 .39974 .85174 .40639 .8633 .40279 .85861 .39612 Mtetra
.85861 .39612 .8633 .40279 .8749 .39919 .87025 .39249 Mtetra
.87025 .39249 .8749 .39919 .88655 .39556 .88193 .38884 Mtetra
.25789 .57635 .2641 .58177 .27348 .57884 .2673 .5734 Mtetra
.2673 .5734 .27348 .57884 .2829 .57589 .27673 .57044 Mtetra
.27673 .57044 .2829 .57589 .29235 .57294 .2862 .56747 Mtetra
.2862 .56747 .29235 .57294 .30184 .56998 .29571 .56449 Mtetra
.29571 .56449 .30184 .56998 .31136 .56701 .30525 .56149 Mtetra
.30525 .56149 .31136 .56701 .32091 .56403 .31483 .55849 Mtetra
.31483 .55849 .32091 .56403 .3305 .56103 .32444 .55547 Mtetra
.32444 .55547 .3305 .56103 .34012 .55803 .33408 .55245 Mtetra
.33408 .55245 .34012 .55803 .34978 .55501 .34376 .54941 Mtetra
.34376 .54941 .34978 .55501 .35947 .55198 .35348 .54637 Mtetra
.35348 .54637 .35947 .55198 .3692 .54895 .36323 .54331 Mtetra
.36323 .54331 .3692 .54895 .37897 .5459 .37301 .54024 Mtetra
.37301 .54024 .37897 .5459 .38877 .54284 .38284 .53716 Mtetra
.38284 .53716 .38877 .54284 .3986 .53976 .39269 .53406 Mtetra
.39269 .53406 .3986 .53976 .40848 .53668 .40259 .53096 Mtetra
.40259 .53096 .40848 .53668 .41839 .53359 .41252 .52785 Mtetra
.41252 .52785 .41839 .53359 .42833 .53048 .42249 .52472 Mtetra
.42249 .52472 .42833 .53048 .43831 .52737 .43249 .52158 Mtetra
.43249 .52158 .43831 .52737 .44833 .52424 .44254 .51843 Mtetra
.44254 .51843 .44833 .52424 .45839 .5211 .45262 .51527 Mtetra
.45262 .51527 .45839 .5211 .46848 .51794 .46273 .5121 Mtetra
.46273 .5121 .46848 .51794 .47861 .51478 .47289 .50891 Mtetra
.47289 .50891 .47861 .51478 .48878 .51161 .48308 .50571 Mtetra
.48308 .50571 .48878 .51161 .49899 .50842 .49331 .5025 Mtetra
.49331 .5025 .49899 .50842 .50923 .50522 .50358 .49928 Mtetra
.50358 .49928 .50923 .50522 .51952 .50201 .51389 .49605 Mtetra
.51389 .49605 .51952 .50201 .52984 .49879 .52424 .4928 Mtetra
.52424 .4928 .52984 .49879 .5402 .49555 .53463 .48955 Mtetra
.53463 .48955 .5402 .49555 .5506 .4923 .54505 .48627 Mtetra
.54505 .48627 .5506 .4923 .56104 .48904 .55552 .48299 Mtetra
.55552 .48299 .56104 .48904 .57152 .48577 .56602 .4797 Mtetra
.56602 .4797 .57152 .48577 .58203 .48249 .57657 .47639 Mtetra
.57657 .47639 .58203 .48249 .59259 .47919 .58715 .47307 Mtetra
.58715 .47307 .59259 .47919 .60319 .47588 .59778 .46974 Mtetra
.59778 .46974 .60319 .47588 .61383 .47256 .60844 .46639 Mtetra
.60844 .46639 .61383 .47256 .62451 .46922 .61915 .46303 Mtetra
.61915 .46303 .62451 .46922 .63523 .46587 .6299 .45966 Mtetra
.6299 .45966 .63523 .46587 .64599 .46251 .64069 .45628 Mtetra
.64069 .45628 .64599 .46251 .6568 .45914 .65152 .45288 Mtetra
.65152 .45288 .6568 .45914 .66764 .45575 .66239 .44947 Mtetra
.66239 .44947 .66764 .45575 .67853 .45235 .67331 .44604 Mtetra
.67331 .44604 .67853 .45235 .68946 .44894 .68427 .44261 Mtetra
.68427 .44261 .68946 .44894 .70043 .44552 .69527 .43916 Mtetra
.69527 .43916 .70043 .44552 .71144 .44208 .70631 .43569 Mtetra
.70631 .43569 .71144 .44208 .7225 .43862 .7174 .43222 Mtetra
.7174 .43222 .7225 .43862 .7336 .43516 .72853 .42872 Mtetra
.72853 .42872 .7336 .43516 .74474 .43168 .7397 .42522 Mtetra
.7397 .42522 .74474 .43168 .75593 .42819 .75092 .4217 Mtetra
.75092 .4217 .75593 .42819 .76716 .42468 .76218 .41817 Mtetra
.76218 .41817 .76716 .42468 .77843 .42116 .77348 .41462 Mtetra
.77348 .41462 .77843 .42116 .78975 .41762 .78483 .41106 Mtetra
.78483 .41106 .78975 .41762 .80111 .41408 .79623 .40749 Mtetra
.79623 .40749 .80111 .41408 .81252 .41051 .80767 .4039 Mtetra
.80767 .4039 .81252 .41051 .82397 .40694 .81915 .4003 Mtetra
.81915 .4003 .82397 .40694 .83547 .40335 .83069 .39668 Mtetra
.83069 .39668 .83547 .40335 .84702 .39974 .84226 .39305 Mtetra
.84226 .39305 .84702 .39974 .85861 .39612 .85389 .3894 Mtetra
.85389 .3894 .85861 .39612 .87025 .39249 .86556 .38574 Mtetra
.86556 .38574 .87025 .39249 .88193 .38884 .87727 .38207 Mtetra
.25164 .57089 .25789 .57635 .2673 .5734 .26107 .56792 Mtetra
.26107 .56792 .2673 .5734 .27673 .57044 .27052 .56494 Mtetra
.27052 .56494 .27673 .57044 .2862 .56747 .28002 .56195 Mtetra
.28002 .56195 .2862 .56747 .29571 .56449 .28954 .55895 Mtetra
.28954 .55895 .29571 .56449 .30525 .56149 .2991 .55594 Mtetra
.2991 .55594 .30525 .56149 .31483 .55849 .3087 .55292 Mtetra
.3087 .55292 .31483 .55849 .32444 .55547 .31833 .54988 Mtetra
.31833 .54988 .32444 .55547 .33408 .55245 .328 .54684 Mtetra
.328 .54684 .33408 .55245 .34376 .54941 .3377 .54378 Mtetra
.3377 .54378 .34376 .54941 .35348 .54637 .34744 .54071 Mtetra
.34744 .54071 .35348 .54637 .36323 .54331 .35721 .53763 Mtetra
.35721 .53763 .36323 .54331 .37301 .54024 .36702 .53454 Mtetra
.36702 .53454 .37301 .54024 .38284 .53716 .37686 .53144 Mtetra
.37686 .53144 .38284 .53716 .39269 .53406 .38674 .52833 Mtetra
.38674 .52833 .39269 .53406 .40259 .53096 .39666 .5252 Mtetra
.39666 .5252 .40259 .53096 .41252 .52785 .40662 .52206 Mtetra
.40662 .52206 .41252 .52785 .42249 .52472 .41661 .51892 Mtetra
.41661 .51892 .42249 .52472 .43249 .52158 .42664 .51576 Mtetra
.42664 .51576 .43249 .52158 .44254 .51843 .4367 .51258 Mtetra
.4367 .51258 .44254 .51843 .45262 .51527 .44681 .5094 Mtetra
.44681 .5094 .45262 .51527 .46273 .5121 .45695 .50621 Mtetra
.45695 .50621 .46273 .5121 .47289 .50891 .46713 .503 Mtetra
.46713 .503 .47289 .50891 .48308 .50571 .47734 .49978 Mtetra
.47734 .49978 .48308 .50571 .49331 .5025 .4876 .49655 Mtetra
.4876 .49655 .49331 .5025 .50358 .49928 .49789 .4933 Mtetra
.49789 .4933 .50358 .49928 .51389 .49605 .50823 .49005 Mtetra
.50823 .49005 .51389 .49605 .52424 .4928 .5186 .48678 Mtetra
.5186 .48678 .52424 .4928 .53463 .48955 .52901 .4835 Mtetra
.52901 .4835 .53463 .48955 .54505 .48627 .53946 .4802 Mtetra
.53946 .4802 .54505 .48627 .55552 .48299 .54996 .4769 Mtetra
.54996 .4769 .55552 .48299 .56602 .4797 .56049 .47358 Mtetra
.56049 .47358 .56602 .4797 .57657 .47639 .57106 .47025 Mtetra
.57106 .47025 .57657 .47639 .58715 .47307 .58167 .46691 Mtetra
.58167 .46691 .58715 .47307 .59778 .46974 .59232 .46355 Mtetra
.59232 .46355 .59778 .46974 .60844 .46639 .60302 .46018 Mtetra
.60302 .46018 .60844 .46639 .61915 .46303 .61375 .4568 Mtetra
.61375 .4568 .61915 .46303 .6299 .45966 .62453 .4534 Mtetra
.62453 .4534 .6299 .45966 .64069 .45628 .63535 .44999 Mtetra
.63535 .44999 .64069 .45628 .65152 .45288 .64621 .44657 Mtetra
.64621 .44657 .65152 .45288 .66239 .44947 .65711 .44314 Mtetra
.65711 .44314 .66239 .44947 .67331 .44604 .66805 .43969 Mtetra
.66805 .43969 .67331 .44604 .68427 .44261 .67904 .43623 Mtetra
.67904 .43623 .68427 .44261 .69527 .43916 .69007 .43275 Mtetra
.69007 .43275 .69527 .43916 .70631 .43569 .70114 .42926 Mtetra
.70114 .42926 .70631 .43569 .7174 .43222 .71226 .42576 Mtetra
.71226 .42576 .7174 .43222 .72853 .42872 .72342 .42224 Mtetra
.72342 .42224 .72853 .42872 .7397 .42522 .73462 .41871 Mtetra
.73462 .41871 .7397 .42522 .75092 .4217 .74587 .41517 Mtetra
.74587 .41517 .75092 .4217 .76218 .41817 .75716 .41161 Mtetra
.75716 .41161 .76218 .41817 .77348 .41462 .7685 .40804 Mtetra
.7685 .40804 .77348 .41462 .78483 .41106 .77988 .40445 Mtetra
.77988 .40445 .78483 .41106 .79623 .40749 .79131 .40085 Mtetra
.79131 .40085 .79623 .40749 .80767 .4039 .80278 .39724 Mtetra
.80278 .39724 .80767 .4039 .81915 .4003 .8143 .39361 Mtetra
.8143 .39361 .81915 .4003 .83069 .39668 .82586 .38996 Mtetra
.82586 .38996 .83069 .39668 .84226 .39305 .83747 .38631 Mtetra
.83747 .38631 .84226 .39305 .85389 .3894 .84913 .38263 Mtetra
.84913 .38263 .85389 .3894 .86556 .38574 .86083 .37895 Mtetra
.86083 .37895 .86556 .38574 .87727 .38207 .87259 .37524 Mtetra
.24535 .5654 .25164 .57089 .26107 .56792 .2548 .56241 Mtetra
.2548 .56241 .26107 .56792 .27052 .56494 .26427 .55941 Mtetra
.26427 .55941 .27052 .56494 .28002 .56195 .27379 .5564 Mtetra
.27379 .5564 .28002 .56195 .28954 .55895 .28333 .55338 Mtetra
.28333 .55338 .28954 .55895 .2991 .55594 .29292 .55035 Mtetra
.29292 .55035 .2991 .55594 .3087 .55292 .30253 .5473 Mtetra
.30253 .5473 .3087 .55292 .31833 .54988 .31218 .54425 Mtetra
.31218 .54425 .31833 .54988 .328 .54684 .32187 .54118 Mtetra
.32187 .54118 .328 .54684 .3377 .54378 .3316 .53811 Mtetra
.3316 .53811 .3377 .54378 .34744 .54071 .34135 .53502 Mtetra
.34135 .53502 .34744 .54071 .35721 .53763 .35115 .53192 Mtetra
.35115 .53192 .35721 .53763 .36702 .53454 .36098 .52881 Mtetra
.36098 .52881 .36702 .53454 .37686 .53144 .37085 .52568 Mtetra
.37085 .52568 .37686 .53144 .38674 .52833 .38075 .52255 Mtetra
.38075 .52255 .38674 .52833 .39666 .5252 .39069 .5194 Mtetra
.39069 .5194 .39666 .5252 .40662 .52206 .40067 .51624 Mtetra
.40067 .51624 .40662 .52206 .41661 .51892 .41068 .51307 Mtetra
.41068 .51307 .41661 .51892 .42664 .51576 .42074 .50989 Mtetra
.42074 .50989 .42664 .51576 .4367 .51258 .43083 .5067 Mtetra
.43083 .5067 .4367 .51258 .44681 .5094 .44095 .50349 Mtetra
.44095 .50349 .44681 .5094 .45695 .50621 .45112 .50027 Mtetra
.45112 .50027 .45695 .50621 .46713 .503 .46132 .49704 Mtetra
.46132 .49704 .46713 .503 .47734 .49978 .47157 .4938 Mtetra
.47157 .4938 .47734 .49978 .4876 .49655 .48185 .49055 Mtetra
.48185 .49055 .4876 .49655 .49789 .4933 .49217 .48728 Mtetra
.49217 .48728 .49789 .4933 .50823 .49005 .50253 .484 Mtetra
.50253 .484 .50823 .49005 .5186 .48678 .51292 .48071 Mtetra
.51292 .48071 .5186 .48678 .52901 .4835 .52336 .47741 Mtetra
.52336 .47741 .52901 .4835 .53946 .4802 .53384 .47409 Mtetra
.53384 .47409 .53946 .4802 .54996 .4769 .54436 .47076 Mtetra
.54436 .47076 .54996 .4769 .56049 .47358 .55491 .46742 Mtetra
.55491 .46742 .56049 .47358 .57106 .47025 .56551 .46407 Mtetra
.56551 .46407 .57106 .47025 .58167 .46691 .57615 .4607 Mtetra
.57615 .4607 .58167 .46691 .59232 .46355 .58683 .45732 Mtetra
.58683 .45732 .59232 .46355 .60302 .46018 .59755 .45393 Mtetra
.59755 .45393 .60302 .46018 .61375 .4568 .60832 .45052 Mtetra
.60832 .45052 .61375 .4568 .62453 .4534 .61912 .4471 Mtetra
.61912 .4471 .62453 .4534 .63535 .44999 .62997 .44367 Mtetra
.62997 .44367 .63535 .44999 .64621 .44657 .64085 .44022 Mtetra
.64085 .44022 .64621 .44657 .65711 .44314 .65178 .43676 Mtetra
.65178 .43676 .65711 .44314 .66805 .43969 .66276 .43329 Mtetra
.66276 .43329 .66805 .43969 .67904 .43623 .67377 .4298 Mtetra
.67377 .4298 .67904 .43623 .69007 .43275 .68483 .4263 Mtetra
.68483 .4263 .69007 .43275 .70114 .42926 .69594 .42279 Mtetra
.69594 .42279 .70114 .42926 .71226 .42576 .70708 .41926 Mtetra
.70708 .41926 .71226 .42576 .72342 .42224 .71827 .41572 Mtetra
.71827 .41572 .72342 .42224 .73462 .41871 .72951 .41216 Mtetra
.72951 .41216 .73462 .41871 .74587 .41517 .74079 .40859 Mtetra
.74079 .40859 .74587 .41517 .75716 .41161 .75211 .40501 Mtetra
.75211 .40501 .75716 .41161 .7685 .40804 .76348 .40141 Mtetra
.76348 .40141 .7685 .40804 .77988 .40445 .77489 .39779 Mtetra
.77489 .39779 .77988 .40445 .79131 .40085 .78635 .39417 Mtetra
.78635 .39417 .79131 .40085 .80278 .39724 .79786 .39053 Mtetra
.79786 .39053 .80278 .39724 .8143 .39361 .80941 .38687 Mtetra
.80941 .38687 .8143 .39361 .82586 .38996 .821 .3832 Mtetra
.821 .3832 .82586 .38996 .83747 .38631 .83265 .37951 Mtetra
.83265 .37951 .83747 .38631 .84913 .38263 .84434 .37581 Mtetra
.84434 .37581 .84913 .38263 .86083 .37895 .85608 .3721 Mtetra
.85608 .3721 .86083 .37895 .87259 .37524 .86786 .36837 Mtetra
.23902 .55988 .24535 .5654 .2548 .56241 .24848 .55687 Mtetra
.24848 .55687 .2548 .56241 .26427 .55941 .25798 .55385 Mtetra
.25798 .55385 .26427 .55941 .27379 .5564 .26751 .55082 Mtetra
.26751 .55082 .27379 .5564 .28333 .55338 .27708 .54777 Mtetra
.27708 .54777 .28333 .55338 .29292 .55035 .28669 .54472 Mtetra
.28669 .54472 .29292 .55035 .30253 .5473 .29632 .54166 Mtetra
.29632 .54166 .30253 .5473 .31218 .54425 .306 .53858 Mtetra
.306 .53858 .31218 .54425 .32187 .54118 .31571 .53549 Mtetra
.31571 .53549 .32187 .54118 .3316 .53811 .32545 .53239 Mtetra
.32545 .53239 .3316 .53811 .34135 .53502 .33523 .52928 Mtetra
.33523 .52928 .34135 .53502 .35115 .53192 .34505 .52616 Mtetra
.34505 .52616 .35115 .53192 .36098 .52881 .3549 .52303 Mtetra
.3549 .52303 .36098 .52881 .37085 .52568 .36479 .51989 Mtetra
.36479 .51989 .37085 .52568 .38075 .52255 .37472 .51673 Mtetra
.37472 .51673 .38075 .52255 .39069 .5194 .38468 .51356 Mtetra
.38468 .51356 .39069 .5194 .40067 .51624 .39468 .51038 Mtetra
.39468 .51038 .40067 .51624 .41068 .51307 .40472 .50719 Mtetra
.40472 .50719 .41068 .51307 .42074 .50989 .4148 .50399 Mtetra
.4148 .50399 .42074 .50989 .43083 .5067 .42491 .50077 Mtetra
.42491 .50077 .43083 .5067 .44095 .50349 .43506 .49754 Mtetra
.43506 .49754 .44095 .50349 .45112 .50027 .44525 .4943 Mtetra
.44525 .4943 .45112 .50027 .46132 .49704 .45548 .49105 Mtetra
.45548 .49105 .46132 .49704 .47157 .4938 .46575 .48779 Mtetra
.46575 .48779 .47157 .4938 .48185 .49055 .47605 .48451 Mtetra
.47605 .48451 .48185 .49055 .49217 .48728 .4864 .48122 Mtetra
.4864 .48122 .49217 .48728 .50253 .484 .49678 .47792 Mtetra
.49678 .47792 .50253 .484 .51292 .48071 .50721 .4746 Mtetra
.50721 .4746 .51292 .48071 .52336 .47741 .51767 .47128 Mtetra
.51767 .47128 .52336 .47741 .53384 .47409 .52817 .46794 Mtetra
.52817 .46794 .53384 .47409 .54436 .47076 .53872 .46458 Mtetra
.53872 .46458 .54436 .47076 .55491 .46742 .5493 .46122 Mtetra
.5493 .46122 .55491 .46742 .56551 .46407 .55993 .45784 Mtetra
.55993 .45784 .56551 .46407 .57615 .4607 .57059 .45445 Mtetra
.57059 .45445 .57615 .4607 .58683 .45732 .5813 .45104 Mtetra
.5813 .45104 .58683 .45732 .59755 .45393 .59205 .44763 Mtetra
.59205 .44763 .59755 .45393 .60832 .45052 .60284 .4442 Mtetra
.60284 .4442 .60832 .45052 .61912 .4471 .61367 .44075 Mtetra
.61367 .44075 .61912 .4471 .62997 .44367 .62455 .43729 Mtetra
.62455 .43729 .62997 .44367 .64085 .44022 .63546 .43382 Mtetra
.63546 .43382 .64085 .44022 .65178 .43676 .64642 .43034 Mtetra
.64642 .43034 .65178 .43676 .66276 .43329 .65743 .42684 Mtetra
.65743 .42684 .66276 .43329 .67377 .4298 .66847 .42333 Mtetra
.66847 .42333 .67377 .4298 .68483 .4263 .67956 .4198 Mtetra
.67956 .4198 .68483 .4263 .69594 .42279 .69069 .41626 Mtetra
.69069 .41626 .69594 .42279 .70708 .41926 .70187 .41271 Mtetra
.70187 .41271 .70708 .41926 .71827 .41572 .71309 .40914 Mtetra
.71309 .40914 .71827 .41572 .72951 .41216 .72436 .40556 Mtetra
.72436 .40556 .72951 .41216 .74079 .40859 .73566 .40196 Mtetra
.73566 .40196 .74079 .40859 .75211 .40501 .74702 .39835 Mtetra
.74702 .39835 .75211 .40501 .76348 .40141 .75842 .39473 Mtetra
.75842 .39473 .76348 .40141 .77489 .39779 .76987 .39109 Mtetra
.76987 .39109 .77489 .39779 .78635 .39417 .78136 .38743 Mtetra
.78136 .38743 .78635 .39417 .79786 .39053 .79289 .38376 Mtetra
.79289 .38376 .79786 .39053 .80941 .38687 .80448 .38008 Mtetra
.80448 .38008 .80941 .38687 .821 .3832 .81611 .37638 Mtetra
.81611 .37638 .821 .3832 .83265 .37951 .82779 .37267 Mtetra
.82779 .37267 .83265 .37951 .84434 .37581 .83951 .36894 Mtetra
.83951 .36894 .84434 .37581 .85608 .3721 .85128 .3652 Mtetra
.85128 .3652 .85608 .3721 .86786 .36837 .8631 .36144 Mtetra
.23264 .55431 .23902 .55988 .24848 .55687 .24213 .55128 Mtetra
.24213 .55128 .24848 .55687 .25798 .55385 .25165 .54824 Mtetra
.25165 .54824 .25798 .55385 .26751 .55082 .2612 .54519 Mtetra
.2612 .54519 .26751 .55082 .27708 .54777 .27079 .54213 Mtetra
.27079 .54213 .27708 .54777 .28669 .54472 .28041 .53905 Mtetra
.28041 .53905 .28669 .54472 .29632 .54166 .29007 .53597 Mtetra
.29007 .53597 .29632 .54166 .306 .53858 .29977 .53287 Mtetra
.29977 .53287 .306 .53858 .31571 .53549 .3095 .52976 Mtetra
.3095 .52976 .31571 .53549 .32545 .53239 .31926 .52664 Mtetra
.31926 .52664 .32545 .53239 .33523 .52928 .32907 .52351 Mtetra
.32907 .52351 .33523 .52928 .34505 .52616 .33891 .52037 Mtetra
.33891 .52037 .34505 .52616 .3549 .52303 .34878 .51722 Mtetra
.34878 .51722 .3549 .52303 .36479 .51989 .35869 .51405 Mtetra
.35869 .51405 .36479 .51989 .37472 .51673 .36864 .51087 Mtetra
.36864 .51087 .37472 .51673 .38468 .51356 .37863 .50768 Mtetra
.37863 .50768 .38468 .51356 .39468 .51038 .38865 .50448 Mtetra
.38865 .50448 .39468 .51038 .40472 .50719 .39872 .50127 Mtetra
.39872 .50127 .40472 .50719 .4148 .50399 .40882 .49804 Mtetra
.40882 .49804 .4148 .50399 .42491 .50077 .41895 .4948 Mtetra
.41895 .4948 .42491 .50077 .43506 .49754 .42913 .49155 Mtetra
.42913 .49155 .43506 .49754 .44525 .4943 .43934 .48829 Mtetra
.43934 .48829 .44525 .4943 .45548 .49105 .4496 .48501 Mtetra
.4496 .48501 .45548 .49105 .46575 .48779 .45989 .48173 Mtetra
.45989 .48173 .46575 .48779 .47605 .48451 .47022 .47843 Mtetra
.47022 .47843 .47605 .48451 .4864 .48122 .48059 .47511 Mtetra
.48059 .47511 .4864 .48122 .49678 .47792 .491 .47179 Mtetra
.491 .47179 .49678 .47792 .50721 .4746 .50145 .46845 Mtetra
.50145 .46845 .50721 .4746 .51767 .47128 .51194 .4651 Mtetra
.51194 .4651 .51767 .47128 .52817 .46794 .52247 .46174 Mtetra
.52247 .46174 .52817 .46794 .53872 .46458 .53304 .45836 Mtetra
.53304 .45836 .53872 .46458 .5493 .46122 .54365 .45497 Mtetra
.54365 .45497 .5493 .46122 .55993 .45784 .5543 .45157 Mtetra
.5543 .45157 .55993 .45784 .57059 .45445 .565 .44815 Mtetra
.565 .44815 .57059 .45445 .5813 .45104 .57573 .44472 Mtetra
.57573 .44472 .5813 .45104 .59205 .44763 .58651 .44128 Mtetra
.58651 .44128 .59205 .44763 .60284 .4442 .59732 .43783 Mtetra
.59732 .43783 .60284 .4442 .61367 .44075 .60819 .43436 Mtetra
.60819 .43436 .61367 .44075 .62455 .43729 .61909 .43087 Mtetra
.61909 .43087 .62455 .43729 .63546 .43382 .63003 .42738 Mtetra
.63003 .42738 .63546 .43382 .64642 .43034 .64102 .42387 Mtetra
.64102 .42387 .64642 .43034 .65743 .42684 .65205 .42034 Mtetra
.65205 .42034 .65743 .42684 .66847 .42333 .66313 .41681 Mtetra
.66313 .41681 .66847 .42333 .67956 .4198 .67425 .41326 Mtetra
.67425 .41326 .67956 .4198 .69069 .41626 .68541 .40969 Mtetra
.68541 .40969 .69069 .41626 .70187 .41271 .69662 .40611 Mtetra
.69662 .40611 .70187 .41271 .71309 .40914 .70787 .40252 Mtetra
.70787 .40252 .71309 .40914 .72436 .40556 .71917 .39891 Mtetra
.71917 .39891 .72436 .40556 .73566 .40196 .73051 .39529 Mtetra
.73051 .39529 .73566 .40196 .74702 .39835 .74189 .39165 Mtetra
.74189 .39165 .74702 .39835 .75842 .39473 .75332 .388 Mtetra
.75332 .388 .75842 .39473 .76987 .39109 .7648 .38433 Mtetra
.7648 .38433 .76987 .39109 .78136 .38743 .77633 .38065 Mtetra
.77633 .38065 .78136 .38743 .79289 .38376 .7879 .37695 Mtetra
.7879 .37695 .79289 .38376 .80448 .38008 .79951 .37324 Mtetra
.79951 .37324 .80448 .38008 .81611 .37638 .81118 .36952 Mtetra
.81118 .36952 .81611 .37638 .82779 .37267 .82289 .36578 Mtetra
.82289 .36578 .82779 .37267 .83951 .36894 .83465 .36202 Mtetra
.83465 .36202 .83951 .36894 .85128 .3652 .84645 .35825 Mtetra
.84645 .35825 .85128 .3652 .8631 .36144 .85831 .35446 Mtetra
.22623 .54871 .23264 .55431 .24213 .55128 .23573 .54566 Mtetra
.23573 .54566 .24213 .55128 .25165 .54824 .24527 .5426 Mtetra
.24527 .5426 .25165 .54824 .2612 .54519 .25484 .53953 Mtetra
.25484 .53953 .2612 .54519 .27079 .54213 .26445 .53644 Mtetra
.26445 .53644 .27079 .54213 .28041 .53905 .2741 .53335 Mtetra
.2741 .53335 .28041 .53905 .29007 .53597 .28378 .53024 Mtetra
.28378 .53024 .29007 .53597 .29977 .53287 .2935 .52712 Mtetra
.2935 .52712 .29977 .53287 .3095 .52976 .30325 .524 Mtetra
.30325 .524 .3095 .52976 .31926 .52664 .31304 .52085 Mtetra
.31304 .52085 .31926 .52664 .32907 .52351 .32286 .5177 Mtetra
.32286 .5177 .32907 .52351 .33891 .52037 .33272 .51454 Mtetra
.33272 .51454 .33891 .52037 .34878 .51722 .34262 .51136 Mtetra
.34262 .51136 .34878 .51722 .35869 .51405 .35256 .50817 Mtetra
.35256 .50817 .35869 .51405 .36864 .51087 .36253 .50497 Mtetra
.36253 .50497 .36864 .51087 .37863 .50768 .37254 .50176 Mtetra
.37254 .50176 .37863 .50768 .38865 .50448 .38258 .49854 Mtetra
.38258 .49854 .38865 .50448 .39872 .50127 .39267 .4953 Mtetra
.39267 .4953 .39872 .50127 .40882 .49804 .40279 .49205 Mtetra
.40279 .49205 .40882 .49804 .41895 .4948 .41295 .48879 Mtetra
.41295 .48879 .41895 .4948 .42913 .49155 .42315 .48552 Mtetra
.42315 .48552 .42913 .49155 .43934 .48829 .43339 .48223 Mtetra
.43339 .48223 .43934 .48829 .4496 .48501 .44367 .47893 Mtetra
.44367 .47893 .4496 .48501 .45989 .48173 .45399 .47562 Mtetra
.45399 .47562 .45989 .48173 .47022 .47843 .46434 .4723 Mtetra
.46434 .4723 .47022 .47843 .48059 .47511 .47474 .46897 Mtetra
.47474 .46897 .48059 .47511 .491 .47179 .48517 .46562 Mtetra
.48517 .46562 .491 .47179 .50145 .46845 .49565 .46226 Mtetra
.49565 .46226 .50145 .46845 .51194 .4651 .50617 .45888 Mtetra
.50617 .45888 .51194 .4651 .52247 .46174 .51672 .45549 Mtetra
.51672 .45549 .52247 .46174 .53304 .45836 .52732 .45209 Mtetra
.52732 .45209 .53304 .45836 .54365 .45497 .53796 .44868 Mtetra
.53796 .44868 .54365 .45497 .5543 .45157 .54864 .44525 Mtetra
.54864 .44525 .5543 .45157 .565 .44815 .55936 .44181 Mtetra
.55936 .44181 .565 .44815 .57573 .44472 .57012 .43836 Mtetra
.57012 .43836 .57573 .44472 .58651 .44128 .58092 .43489 Mtetra
.58092 .43489 .58651 .44128 .59732 .43783 .59177 .43141 Mtetra
.59177 .43141 .59732 .43783 .60819 .43436 .60266 .42792 Mtetra
.60266 .42792 .60819 .43436 .61909 .43087 .61359 .42441 Mtetra
.61359 .42441 .61909 .43087 .63003 .42738 .62456 .42089 Mtetra
.62456 .42089 .63003 .42738 .64102 .42387 .63558 .41735 Mtetra
.63558 .41735 .64102 .42387 .65205 .42034 .64664 .4138 Mtetra
.64664 .4138 .65205 .42034 .66313 .41681 .65775 .41024 Mtetra
.65775 .41024 .66313 .41681 .67425 .41326 .6689 .40666 Mtetra
.6689 .40666 .67425 .41326 .68541 .40969 .68009 .40307 Mtetra
.68009 .40307 .68541 .40969 .69662 .40611 .69133 .39946 Mtetra
.69133 .39946 .69662 .40611 .70787 .40252 .70261 .39584 Mtetra
.70261 .39584 .70787 .40252 .71917 .39891 .71394 .39221 Mtetra
.71394 .39221 .71917 .39891 .73051 .39529 .72531 .38856 Mtetra
.72531 .38856 .73051 .39529 .74189 .39165 .73673 .3849 Mtetra
.73673 .3849 .74189 .39165 .75332 .388 .74819 .38122 Mtetra
.74819 .38122 .75332 .388 .7648 .38433 .7597 .37752 Mtetra
.7597 .37752 .7648 .38433 .77633 .38065 .77126 .37381 Mtetra
.77126 .37381 .77633 .38065 .7879 .37695 .78286 .37009 Mtetra
.78286 .37009 .7879 .37695 .79951 .37324 .79451 .36635 Mtetra
.79451 .36635 .79951 .37324 .81118 .36952 .80621 .3626 Mtetra
.80621 .3626 .81118 .36952 .82289 .36578 .81795 .35883 Mtetra
.81795 .35883 .82289 .36578 .83465 .36202 .82975 .35505 Mtetra
.82975 .35505 .83465 .36202 .84645 .35825 .84159 .35125 Mtetra
.84159 .35125 .84645 .35825 .85831 .35446 .85348 .34743 Mtetra
.21976 .54307 .22623 .54871 .23573 .54566 .22929 .54 Mtetra
.22929 .54 .23573 .54566 .24527 .5426 .23885 .53692 Mtetra
.23885 .53692 .24527 .5426 .25484 .53953 .24844 .53383 Mtetra
.24844 .53383 .25484 .53953 .26445 .53644 .25807 .53072 Mtetra
.25807 .53072 .26445 .53644 .2741 .53335 .26774 .52761 Mtetra
.26774 .52761 .2741 .53335 .28378 .53024 .27744 .52448 Mtetra
.27744 .52448 .28378 .53024 .2935 .52712 .28718 .52134 Mtetra
.28718 .52134 .2935 .52712 .30325 .524 .29695 .51819 Mtetra
.29695 .51819 .30325 .524 .31304 .52085 .30676 .51503 Mtetra
.30676 .51503 .31304 .52085 .32286 .5177 .31661 .51185 Mtetra
.31661 .51185 .32286 .5177 .33272 .51454 .3265 .50866 Mtetra
.3265 .50866 .33272 .51454 .34262 .51136 .33642 .50547 Mtetra
.33642 .50547 .34262 .51136 .35256 .50817 .34637 .50226 Mtetra
.34637 .50226 .35256 .50817 .36253 .50497 .35637 .49903 Mtetra
.35637 .49903 .36253 .50497 .37254 .50176 .3664 .4958 Mtetra
.3664 .4958 .37254 .50176 .38258 .49854 .37647 .49255 Mtetra
.37647 .49255 .38258 .49854 .39267 .4953 .38658 .48929 Mtetra
.38658 .48929 .39267 .4953 .40279 .49205 .39673 .48602 Mtetra
.39673 .48602 .40279 .49205 .41295 .48879 .40691 .48274 Mtetra
.40691 .48274 .41295 .48879 .42315 .48552 .41714 .47944 Mtetra
.41714 .47944 .42315 .48552 .43339 .48223 .4274 .47613 Mtetra
.4274 .47613 .43339 .48223 .44367 .47893 .4377 .47281 Mtetra
.4377 .47281 .44367 .47893 .45399 .47562 .44805 .46948 Mtetra
.44805 .46948 .45399 .47562 .46434 .4723 .45843 .46613 Mtetra
.45843 .46613 .46434 .4723 .47474 .46897 .46885 .46277 Mtetra
.46885 .46277 .47474 .46897 .48517 .46562 .47931 .4594 Mtetra
.47931 .4594 .48517 .46562 .49565 .46226 .48981 .45602 Mtetra
.48981 .45602 .49565 .46226 .50617 .45888 .50035 .45262 Mtetra
.50035 .45262 .50617 .45888 .51672 .45549 .51093 .44921 Mtetra
.51093 .44921 .51672 .45549 .52732 .45209 .52156 .44578 Mtetra
.52156 .44578 .52732 .45209 .53796 .44868 .53222 .44234 Mtetra
.53222 .44234 .53796 .44868 .54864 .44525 .54293 .43889 Mtetra
.54293 .43889 .54864 .44525 .55936 .44181 .55368 .43543 Mtetra
.55368 .43543 .55936 .44181 .57012 .43836 .56447 .43195 Mtetra
.56447 .43195 .57012 .43836 .58092 .43489 .5753 .42846 Mtetra
.5753 .42846 .58092 .43489 .59177 .43141 .58617 .42495 Mtetra
.58617 .42495 .59177 .43141 .60266 .42792 .59709 .42143 Mtetra
.59709 .42143 .60266 .42792 .61359 .42441 .60805 .4179 Mtetra
.60805 .4179 .61359 .42441 .62456 .42089 .61906 .41435 Mtetra
.61906 .41435 .62456 .42089 .63558 .41735 .6301 .41079 Mtetra
.6301 .41079 .63558 .41735 .64664 .4138 .64119 .40721 Mtetra
.64119 .40721 .64664 .4138 .65775 .41024 .65233 .40362 Mtetra
.65233 .40362 .65775 .41024 .6689 .40666 .66351 .40002 Mtetra
.66351 .40002 .6689 .40666 .68009 .40307 .67473 .3964 Mtetra
.67473 .3964 .68009 .40307 .69133 .39946 .686 .39277 Mtetra
.686 .39277 .69133 .39946 .70261 .39584 .69731 .38912 Mtetra
.69731 .38912 .70261 .39584 .71394 .39221 .70867 .38546 Mtetra
.70867 .38546 .71394 .39221 .72531 .38856 .72007 .38178 Mtetra
.72007 .38178 .72531 .38856 .73673 .3849 .73152 .37809 Mtetra
.73152 .37809 .73673 .3849 .74819 .38122 .74302 .37439 Mtetra
.74302 .37439 .74819 .38122 .7597 .37752 .75456 .37067 Mtetra
.75456 .37067 .7597 .37752 .77126 .37381 .76615 .36693 Mtetra
.76615 .36693 .77126 .37381 .78286 .37009 .77779 .36318 Mtetra
.77779 .36318 .78286 .37009 .79451 .36635 .78947 .35941 Mtetra
.78947 .35941 .79451 .36635 .80621 .3626 .8012 .35563 Mtetra
.8012 .35563 .80621 .3626 .81795 .35883 .81298 .35183 Mtetra
.81298 .35183 .81795 .35883 .82975 .35505 .82481 .34802 Mtetra
.82481 .34802 .82975 .35505 .84159 .35125 .83668 .34419 Mtetra
.83668 .34419 .84159 .35125 .85348 .34743 .84861 .34035 Mtetra
.21326 .53739 .21976 .54307 .22929 .54 .2228 .5343 Mtetra
.2228 .5343 .22929 .54 .23885 .53692 .23238 .5312 Mtetra
.23238 .5312 .23885 .53692 .24844 .53383 .242 .52809 Mtetra
.242 .52809 .24844 .53383 .25807 .53072 .25165 .52496 Mtetra
.25165 .52496 .25807 .53072 .26774 .52761 .26134 .52182 Mtetra
.26134 .52182 .26774 .52761 .27744 .52448 .27106 .51867 Mtetra
.27106 .51867 .27744 .52448 .28718 .52134 .28082 .51551 Mtetra
.28082 .51551 .28718 .52134 .29695 .51819 .29062 .51234 Mtetra
.29062 .51234 .29695 .51819 .30676 .51503 .30045 .50916 Mtetra
.30045 .50916 .30676 .51503 .31661 .51185 .31032 .50596 Mtetra
.31032 .50596 .31661 .51185 .3265 .50866 .32022 .50275 Mtetra
.32022 .50275 .3265 .50866 .33642 .50547 .33017 .49953 Mtetra
.33017 .49953 .33642 .50547 .34637 .50226 .34015 .4963 Mtetra
.34015 .4963 .34637 .50226 .35637 .49903 .35017 .49305 Mtetra
.35017 .49305 .35637 .49903 .3664 .4958 .36022 .4898 Mtetra
.36022 .4898 .3664 .4958 .37647 .49255 .37032 .48653 Mtetra
.37032 .48653 .37647 .49255 .38658 .48929 .38045 .48325 Mtetra
.38045 .48325 .38658 .48929 .39673 .48602 .39062 .47995 Mtetra
.39062 .47995 .39673 .48602 .40691 .48274 .40083 .47664 Mtetra
.40083 .47664 .40691 .48274 .41714 .47944 .41108 .47333 Mtetra
.41108 .47333 .41714 .47944 .4274 .47613 .42137 .46999 Mtetra
.42137 .46999 .4274 .47613 .4377 .47281 .43169 .46665 Mtetra
.43169 .46665 .4377 .47281 .44805 .46948 .44206 .46329 Mtetra
.44206 .46329 .44805 .46948 .45843 .46613 .45247 .45992 Mtetra
.45247 .45992 .45843 .46613 .46885 .46277 .46291 .45654 Mtetra
.46291 .45654 .46885 .46277 .47931 .4594 .4734 .45314 Mtetra
.4734 .45314 .47931 .4594 .48981 .45602 .48393 .44973 Mtetra
.48393 .44973 .48981 .45602 .50035 .45262 .4945 .44631 Mtetra
.4945 .44631 .50035 .45262 .51093 .44921 .50511 .44287 Mtetra
.50511 .44287 .51093 .44921 .52156 .44578 .51576 .43942 Mtetra
.51576 .43942 .52156 .44578 .53222 .44234 .52645 .43596 Mtetra
.52645 .43596 .53222 .44234 .54293 .43889 .53718 .43248 Mtetra
.53718 .43248 .54293 .43889 .55368 .43543 .54796 .42899 Mtetra
.54796 .42899 .55368 .43543 .56447 .43195 .55878 .42549 Mtetra
.55878 .42549 .56447 .43195 .5753 .42846 .56964 .42197 Mtetra
.56964 .42197 .5753 .42846 .58617 .42495 .58054 .41844 Mtetra
.58054 .41844 .58617 .42495 .59709 .42143 .59149 .4149 Mtetra
.59149 .4149 .59709 .42143 .60805 .4179 .60247 .41134 Mtetra
.60247 .41134 .60805 .4179 .61906 .41435 .61351 .40776 Mtetra
.61351 .40776 .61906 .41435 .6301 .41079 .62458 .40418 Mtetra
.62458 .40418 .6301 .41079 .64119 .40721 .6357 .40057 Mtetra
.6357 .40057 .64119 .40721 .65233 .40362 .64687 .39696 Mtetra
.64687 .39696 .65233 .40362 .66351 .40002 .65808 .39333 Mtetra
.65808 .39333 .66351 .40002 .67473 .3964 .66933 .38968 Mtetra
.66933 .38968 .67473 .3964 .686 .39277 .68063 .38602 Mtetra
.68063 .38602 .686 .39277 .69731 .38912 .69198 .38235 Mtetra
.69198 .38235 .69731 .38912 .70867 .38546 .70336 .37866 Mtetra
.70336 .37866 .70867 .38546 .72007 .38178 .7148 .37496 Mtetra
.7148 .37496 .72007 .38178 .73152 .37809 .72628 .37124 Mtetra
.72628 .37124 .73152 .37809 .74302 .37439 .73781 .3675 Mtetra
.73781 .3675 .74302 .37439 .75456 .37067 .74939 .36376 Mtetra
.74939 .36376 .75456 .37067 .76615 .36693 .76101 .35999 Mtetra
.76101 .35999 .76615 .36693 .77779 .36318 .77268 .35621 Mtetra
.77268 .35621 .77779 .36318 .78947 .35941 .78439 .35242 Mtetra
.78439 .35242 .78947 .35941 .8012 .35563 .79616 .34861 Mtetra
.79616 .34861 .8012 .35563 .81298 .35183 .80797 .34478 Mtetra
.80797 .34478 .81298 .35183 .82481 .34802 .81983 .34094 Mtetra
.81983 .34094 .82481 .34802 .83668 .34419 .83174 .33708 Mtetra
.83174 .33708 .83668 .34419 .84861 .34035 .8437 .33321 Mtetra
.20671 .53168 .21326 .53739 .2228 .5343 .21628 .52857 Mtetra
.21628 .52857 .2228 .5343 .23238 .5312 .22588 .52544 Mtetra
.22588 .52544 .23238 .5312 .242 .52809 .23551 .52231 Mtetra
.23551 .52231 .242 .52809 .25165 .52496 .24519 .51916 Mtetra
.24519 .51916 .25165 .52496 .26134 .52182 .25489 .516 Mtetra
.25489 .516 .26134 .52182 .27106 .51867 .26464 .51283 Mtetra
.26464 .51283 .27106 .51867 .28082 .51551 .27442 .50965 Mtetra
.27442 .50965 .28082 .51551 .29062 .51234 .28424 .50645 Mtetra
.28424 .50645 .29062 .51234 .30045 .50916 .29409 .50324 Mtetra
.29409 .50324 .30045 .50916 .31032 .50596 .30398 .50003 Mtetra
.30398 .50003 .31032 .50596 .32022 .50275 .31391 .4968 Mtetra
.31391 .4968 .32022 .50275 .33017 .49953 .32388 .49355 Mtetra
.32388 .49355 .33017 .49953 .34015 .4963 .33388 .4903 Mtetra
.33388 .4903 .34015 .4963 .35017 .49305 .34392 .48703 Mtetra
.34392 .48703 .35017 .49305 .36022 .4898 .354 .48375 Mtetra
.354 .48375 .36022 .4898 .37032 .48653 .36412 .48046 Mtetra
.36412 .48046 .37032 .48653 .38045 .48325 .37428 .47715 Mtetra
.37428 .47715 .38045 .48325 .39062 .47995 .38447 .47384 Mtetra
.38447 .47384 .39062 .47995 .40083 .47664 .3947 .47051 Mtetra
.3947 .47051 .40083 .47664 .41108 .47333 .40498 .46716 Mtetra
.40498 .46716 .41108 .47333 .42137 .46999 .41529 .46381 Mtetra
.41529 .46381 .42137 .46999 .43169 .46665 .42564 .46044 Mtetra
.42564 .46044 .43169 .46665 .44206 .46329 .43603 .45706 Mtetra
.43603 .45706 .44206 .46329 .45247 .45992 .44647 .45366 Mtetra
.44647 .45366 .45247 .45992 .46291 .45654 .45694 .45026 Mtetra
.45694 .45026 .46291 .45654 .4734 .45314 .46745 .44684 Mtetra
.46745 .44684 .4734 .45314 .48393 .44973 .47801 .4434 Mtetra
.47801 .4434 .48393 .44973 .4945 .44631 .4886 .43995 Mtetra
.4886 .43995 .4945 .44631 .50511 .44287 .49924 .43649 Mtetra
.49924 .43649 .50511 .44287 .51576 .43942 .50991 .43302 Mtetra
.50991 .43302 .51576 .43942 .52645 .43596 .52063 .42953 Mtetra
.52063 .42953 .52645 .43596 .53718 .43248 .53139 .42603 Mtetra
.53139 .42603 .53718 .43248 .54796 .42899 .5422 .42251 Mtetra
.5422 .42251 .54796 .42899 .55878 .42549 .55304 .41899 Mtetra
.55304 .41899 .55878 .42549 .56964 .42197 .56393 .41544 Mtetra
.56393 .41544 .56964 .42197 .58054 .41844 .57486 .41189 Mtetra
.57486 .41189 .58054 .41844 .59149 .4149 .58584 .40831 Mtetra
.58584 .40831 .59149 .4149 .60247 .41134 .59686 .40473 Mtetra
.59686 .40473 .60247 .41134 .61351 .40776 .60792 .40113 Mtetra
.60792 .40113 .61351 .40776 .62458 .40418 .61902 .39752 Mtetra
.61902 .39752 .62458 .40418 .6357 .40057 .63017 .39389 Mtetra
.63017 .39389 .6357 .40057 .64687 .39696 .64137 .39025 Mtetra
.64137 .39025 .64687 .39696 .65808 .39333 .65261 .38659 Mtetra
.65261 .38659 .65808 .39333 .66933 .38968 .66389 .38292 Mtetra
.66389 .38292 .66933 .38968 .68063 .38602 .67522 .37923 Mtetra
.67522 .37923 .68063 .38602 .69198 .38235 .6866 .37553 Mtetra
.6866 .37553 .69198 .38235 .70336 .37866 .69802 .37181 Mtetra
.69802 .37181 .70336 .37866 .7148 .37496 .70949 .36808 Mtetra
.70949 .36808 .7148 .37496 .72628 .37124 .721 .36433 Mtetra
.721 .36433 .72628 .37124 .73781 .3675 .73256 .36057 Mtetra
.73256 .36057 .73781 .3675 .74939 .36376 .74417 .35679 Mtetra
.74417 .35679 .74939 .36376 .76101 .35999 .75583 .353 Mtetra
.75583 .353 .76101 .35999 .77268 .35621 .76753 .34919 Mtetra
.76753 .34919 .77268 .35621 .78439 .35242 .77928 .34537 Mtetra
.77928 .34537 .78439 .35242 .79616 .34861 .79108 .34153 Mtetra
.79108 .34153 .79616 .34861 .80797 .34478 .80293 .33768 Mtetra
.80293 .33768 .80797 .34478 .81983 .34094 .81482 .33381 Mtetra
.81482 .33381 .81983 .34094 .83174 .33708 .82677 .32992 Mtetra
.82677 .32992 .83174 .33708 .8437 .33321 .83876 .32602 Mtetra
.20012 .52592 .20671 .53168 .21628 .52857 .2097 .52279 Mtetra
.2097 .52279 .21628 .52857 .22588 .52544 .21932 .51964 Mtetra
.21932 .51964 .22588 .52544 .23551 .52231 .22898 .51649 Mtetra
.22898 .51649 .23551 .52231 .24519 .51916 .23867 .51332 Mtetra
.23867 .51332 .24519 .51916 .25489 .516 .2484 .51014 Mtetra
.2484 .51014 .25489 .516 .26464 .51283 .25817 .50694 Mtetra
.25817 .50694 .26464 .51283 .27442 .50965 .26797 .50374 Mtetra
.26797 .50374 .27442 .50965 .28424 .50645 .27781 .50052 Mtetra
.27781 .50052 .28424 .50645 .29409 .50324 .28769 .49729 Mtetra
.28769 .49729 .29409 .50324 .30398 .50003 .2976 .49405 Mtetra
.2976 .49405 .30398 .50003 .31391 .4968 .30755 .4908 Mtetra
.30755 .4908 .31391 .4968 .32388 .49355 .31754 .48753 Mtetra
.31754 .48753 .32388 .49355 .33388 .4903 .32757 .48426 Mtetra
.32757 .48426 .33388 .4903 .34392 .48703 .33763 .48097 Mtetra
.33763 .48097 .34392 .48703 .354 .48375 .34774 .47766 Mtetra
.34774 .47766 .354 .48375 .36412 .48046 .35788 .47435 Mtetra
.35788 .47435 .36412 .48046 .37428 .47715 .36806 .47102 Mtetra
.36806 .47102 .37428 .47715 .38447 .47384 .37828 .46768 Mtetra
.37828 .46768 .38447 .47384 .3947 .47051 .38854 .46433 Mtetra
.38854 .46433 .3947 .47051 .40498 .46716 .39883 .46096 Mtetra
.39883 .46096 .40498 .46716 .41529 .46381 .40917 .45758 Mtetra
.40917 .45758 .41529 .46381 .42564 .46044 .41955 .45419 Mtetra
.41955 .45419 .42564 .46044 .43603 .45706 .42996 .45078 Mtetra
.42996 .45078 .43603 .45706 .44647 .45366 .44042 .44736 Mtetra
.44042 .44736 .44647 .45366 .45694 .45026 .45092 .44393 Mtetra
.45092 .44393 .45694 .45026 .46745 .44684 .46146 .44049 Mtetra
.46146 .44049 .46745 .44684 .47801 .4434 .47204 .43703 Mtetra
.47204 .43703 .47801 .4434 .4886 .43995 .48266 .43355 Mtetra
.48266 .43355 .4886 .43995 .49924 .43649 .49332 .43007 Mtetra
.49332 .43007 .49924 .43649 .50991 .43302 .50403 .42657 Mtetra
.50403 .42657 .50991 .43302 .52063 .42953 .51477 .42306 Mtetra
.51477 .42306 .52063 .42953 .53139 .42603 .52556 .41953 Mtetra
.52556 .41953 .53139 .42603 .5422 .42251 .53639 .41599 Mtetra
.53639 .41599 .5422 .42251 .55304 .41899 .54727 .41243 Mtetra
.54727 .41243 .55304 .41899 .56393 .41544 .55818 .40886 Mtetra
.55818 .40886 .56393 .41544 .57486 .41189 .56914 .40528 Mtetra
.56914 .40528 .57486 .41189 .58584 .40831 .58015 .40168 Mtetra
.58015 .40168 .58584 .40831 .59686 .40473 .5912 .39807 Mtetra
.5912 .39807 .59686 .40473 .60792 .40113 .60229 .39445 Mtetra
.60229 .39445 .60792 .40113 .61902 .39752 .61342 .39081 Mtetra
.61342 .39081 .61902 .39752 .63017 .39389 .6246 .38715 Mtetra
.6246 .38715 .63017 .39389 .64137 .39025 .63583 .38348 Mtetra
.63583 .38348 .64137 .39025 .65261 .38659 .6471 .3798 Mtetra
.6471 .3798 .65261 .38659 .66389 .38292 .65841 .3761 Mtetra
.65841 .3761 .66389 .38292 .67522 .37923 .66977 .37238 Mtetra
.66977 .37238 .67522 .37923 .6866 .37553 .68118 .36866 Mtetra
.68118 .36866 .6866 .37553 .69802 .37181 .69263 .36491 Mtetra
.69263 .36491 .69802 .37181 .70949 .36808 .70413 .36115 Mtetra
.70413 .36115 .70949 .36808 .721 .36433 .71568 .35738 Mtetra
.71568 .35738 .721 .36433 .73256 .36057 .72727 .35359 Mtetra
.72727 .35359 .73256 .36057 .74417 .35679 .73892 .34978 Mtetra
.73892 .34978 .74417 .35679 .75583 .353 .7506 .34596 Mtetra
.7506 .34596 .75583 .353 .76753 .34919 .76234 .34212 Mtetra
.76234 .34212 .76753 .34919 .77928 .34537 .77412 .33827 Mtetra
.77412 .33827 .77928 .34537 .79108 .34153 .78596 .3344 Mtetra
.78596 .3344 .79108 .34153 .80293 .33768 .79784 .33052 Mtetra
.79784 .33052 .80293 .33768 .81482 .33381 .80977 .32662 Mtetra
.80977 .32662 .81482 .33381 .82677 .32992 .82175 .3227 Mtetra
.82175 .3227 .82677 .32992 .83876 .32602 .83378 .31877 Mtetra
.19348 .52013 .20012 .52592 .2097 .52279 .20308 .51697 Mtetra
.20308 .51697 .2097 .52279 .21932 .51964 .21272 .51381 Mtetra
.21272 .51381 .21932 .51964 .22898 .51649 .2224 .51063 Mtetra
.2224 .51063 .22898 .51649 .23867 .51332 .23212 .50744 Mtetra
.23212 .50744 .23867 .51332 .2484 .51014 .24187 .50423 Mtetra
.24187 .50423 .2484 .51014 .25817 .50694 .25166 .50102 Mtetra
.25166 .50102 .25817 .50694 .26797 .50374 .26148 .49779 Mtetra
.26148 .49779 .26797 .50374 .27781 .50052 .27134 .49455 Mtetra
.27134 .49455 .27781 .50052 .28769 .49729 .28124 .4913 Mtetra
.28124 .4913 .28769 .49729 .2976 .49405 .29118 .48804 Mtetra
.29118 .48804 .2976 .49405 .30755 .4908 .30115 .48476 Mtetra
.30115 .48476 .30755 .4908 .31754 .48753 .31116 .48147 Mtetra
.31116 .48147 .31754 .48753 .32757 .48426 .32121 .47817 Mtetra
.32121 .47817 .32757 .48426 .33763 .48097 .3313 .47486 Mtetra
.3313 .47486 .33763 .48097 .34774 .47766 .34143 .47153 Mtetra
.34143 .47153 .34774 .47766 .35788 .47435 .35159 .46819 Mtetra
.35159 .46819 .35788 .47435 .36806 .47102 .3618 .46484 Mtetra
.3618 .46484 .36806 .47102 .37828 .46768 .37204 .46148 Mtetra
.37204 .46148 .37828 .46768 .38854 .46433 .38232 .4581 Mtetra
.38232 .4581 .38854 .46433 .39883 .46096 .39264 .45471 Mtetra
.39264 .45471 .39883 .46096 .40917 .45758 .40301 .45131 Mtetra
.40301 .45131 .40917 .45758 .41955 .45419 .41341 .44789 Mtetra
.41341 .44789 .41955 .45419 .42996 .45078 .42385 .44446 Mtetra
.42385 .44446 .42996 .45078 .44042 .44736 .43434 .44102 Mtetra
.43434 .44102 .44042 .44736 .45092 .44393 .44486 .43756 Mtetra
.44486 .43756 .45092 .44393 .46146 .44049 .45542 .43409 Mtetra
.45542 .43409 .46146 .44049 .47204 .43703 .46603 .43061 Mtetra
.46603 .43061 .47204 .43703 .48266 .43355 .47668 .42711 Mtetra
.47668 .42711 .48266 .43355 .49332 .43007 .48737 .4236 Mtetra
.48737 .4236 .49332 .43007 .50403 .42657 .4981 .42007 Mtetra
.4981 .42007 .50403 .42657 .51477 .42306 .50887 .41653 Mtetra
.50887 .41653 .51477 .42306 .52556 .41953 .51969 .41298 Mtetra
.51969 .41298 .52556 .41953 .53639 .41599 .53055 .40941 Mtetra
.53055 .40941 .53639 .41599 .54727 .41243 .54145 .40583 Mtetra
.54145 .40583 .54727 .41243 .55818 .40886 .5524 .40224 Mtetra
.5524 .40224 .55818 .40886 .56914 .40528 .56338 .39863 Mtetra
.56338 .39863 .56914 .40528 .58015 .40168 .57442 .39501 Mtetra
.57442 .39501 .58015 .40168 .5912 .39807 .58549 .39137 Mtetra
.58549 .39137 .5912 .39807 .60229 .39445 .59661 .38772 Mtetra
.59661 .38772 .60229 .39445 .61342 .39081 .60778 .38405 Mtetra
.60778 .38405 .61342 .39081 .6246 .38715 .61899 .38037 Mtetra
.61899 .38037 .6246 .38715 .63583 .38348 .63025 .37667 Mtetra
.63025 .37667 .63583 .38348 .6471 .3798 .64155 .37296 Mtetra
.64155 .37296 .6471 .3798 .65841 .3761 .65289 .36923 Mtetra
.65289 .36923 .65841 .3761 .66977 .37238 .66429 .36549 Mtetra
.66429 .36549 .66977 .37238 .68118 .36866 .67572 .36173 Mtetra
.67572 .36173 .68118 .36866 .69263 .36491 .68721 .35796 Mtetra
.68721 .35796 .69263 .36491 .70413 .36115 .69874 .35417 Mtetra
.69874 .35417 .70413 .36115 .71568 .35738 .71032 .35037 Mtetra
.71032 .35037 .71568 .35738 .72727 .35359 .72195 .34655 Mtetra
.72195 .34655 .72727 .35359 .73892 .34978 .73362 .34271 Mtetra
.73362 .34271 .73892 .34978 .7506 .34596 .74534 .33886 Mtetra
.74534 .33886 .7506 .34596 .76234 .34212 .75711 .335 Mtetra
.75711 .335 .76234 .34212 .77412 .33827 .76893 .33112 Mtetra
.76893 .33112 .77412 .33827 .78596 .3344 .7808 .32722 Mtetra
.7808 .32722 .78596 .3344 .79784 .33052 .79272 .3233 Mtetra
.79272 .3233 .79784 .33052 .80977 .32662 .80468 .31937 Mtetra
.80468 .31937 .80977 .32662 .82175 .3227 .8167 .31543 Mtetra
.8167 .31543 .82175 .3227 .83378 .31877 .82876 .31146 Mtetra
.18679 .51429 .19348 .52013 .20308 .51697 .19642 .51112 Mtetra
.19642 .51112 .20308 .51697 .21272 .51381 .20608 .50793 Mtetra
.20608 .50793 .21272 .51381 .2224 .51063 .21578 .50473 Mtetra
.21578 .50473 .2224 .51063 .23212 .50744 .22552 .50151 Mtetra
.22552 .50151 .23212 .50744 .24187 .50423 .23529 .49829 Mtetra
.23529 .49829 .24187 .50423 .25166 .50102 .2451 .49505 Mtetra
.2451 .49505 .25166 .50102 .26148 .49779 .25494 .4918 Mtetra
.25494 .4918 .26148 .49779 .27134 .49455 .26483 .48854 Mtetra
.26483 .48854 .27134 .49455 .28124 .4913 .27475 .48527 Mtetra
.27475 .48527 .28124 .4913 .29118 .48804 .28471 .48198 Mtetra
.28471 .48198 .29118 .48804 .30115 .48476 .2947 .47868 Mtetra
.2947 .47868 .30115 .48476 .31116 .48147 .30474 .47537 Mtetra
.30474 .47537 .31116 .48147 .32121 .47817 .31481 .47205 Mtetra
.31481 .47205 .32121 .47817 .3313 .47486 .32492 .46871 Mtetra
.32492 .46871 .3313 .47486 .34143 .47153 .33507 .46536 Mtetra
.33507 .46536 .34143 .47153 .35159 .46819 .34526 .462 Mtetra
.34526 .462 .35159 .46819 .3618 .46484 .35549 .45862 Mtetra
.35549 .45862 .3618 .46484 .37204 .46148 .36576 .45523 Mtetra
.36576 .45523 .37204 .46148 .38232 .4581 .37607 .45183 Mtetra
.37607 .45183 .38232 .4581 .39264 .45471 .38641 .44842 Mtetra
.38641 .44842 .39264 .45471 .40301 .45131 .3968 .44499 Mtetra
.3968 .44499 .40301 .45131 .41341 .44789 .40723 .44155 Mtetra
.40723 .44155 .41341 .44789 .42385 .44446 .41769 .43809 Mtetra
.41769 .43809 .42385 .44446 .43434 .44102 .4282 .43462 Mtetra
.4282 .43462 .43434 .44102 .44486 .43756 .43875 .43114 Mtetra
.43875 .43114 .44486 .43756 .45542 .43409 .44934 .42765 Mtetra
.44934 .42765 .45542 .43409 .46603 .43061 .45998 .42414 Mtetra
.45998 .42414 .46603 .43061 .47668 .42711 .47065 .42062 Mtetra
.47065 .42062 .47668 .42711 .48737 .4236 .48137 .41708 Mtetra
.48137 .41708 .48737 .4236 .4981 .42007 .49213 .41353 Mtetra
.49213 .41353 .4981 .42007 .50887 .41653 .50293 .40996 Mtetra
.50293 .40996 .50887 .41653 .51969 .41298 .51377 .40639 Mtetra
.51377 .40639 .51969 .41298 .53055 .40941 .52466 .40279 Mtetra
.52466 .40279 .53055 .40941 .54145 .40583 .53559 .39919 Mtetra
.53559 .39919 .54145 .40583 .5524 .40224 .54656 .39556 Mtetra
.54656 .39556 .5524 .40224 .56338 .39863 .55758 .39193 Mtetra
.55758 .39193 .56338 .39863 .57442 .39501 .56864 .38828 Mtetra
.56864 .38828 .57442 .39501 .58549 .39137 .57975 .38461 Mtetra
.57975 .38461 .58549 .39137 .59661 .38772 .5909 .38093 Mtetra
.5909 .38093 .59661 .38772 .60778 .38405 .6021 .37724 Mtetra
.6021 .37724 .60778 .38405 .61899 .38037 .61334 .37353 Mtetra
.61334 .37353 .61899 .38037 .63025 .37667 .62462 .3698 Mtetra
.62462 .3698 .63025 .37667 .64155 .37296 .63595 .36606 Mtetra
.63595 .36606 .64155 .37296 .65289 .36923 .64733 .36231 Mtetra
.64733 .36231 .65289 .36923 .66429 .36549 .65875 .35854 Mtetra
.65875 .35854 .66429 .36549 .67572 .36173 .67023 .35475 Mtetra
.67023 .35475 .67572 .36173 .68721 .35796 .68174 .35095 Mtetra
.68174 .35095 .68721 .35796 .69874 .35417 .69331 .34714 Mtetra
.69331 .34714 .69874 .35417 .71032 .35037 .70492 .34331 Mtetra
.70492 .34331 .71032 .35037 .72195 .34655 .71658 .33946 Mtetra
.71658 .33946 .72195 .34655 .73362 .34271 .72829 .33559 Mtetra
.72829 .33559 .73362 .34271 .74534 .33886 .74004 .33171 Mtetra
.74004 .33171 .74534 .33886 .75711 .335 .75184 .32782 Mtetra
.75184 .32782 .75711 .335 .76893 .33112 .7637 .32391 Mtetra
.7637 .32391 .76893 .33112 .7808 .32722 .7756 .31998 Mtetra
.7756 .31998 .7808 .32722 .79272 .3233 .78755 .31604 Mtetra
.78755 .31604 .79272 .3233 .80468 .31937 .79955 .31208 Mtetra
.79955 .31208 .80468 .31937 .8167 .31543 .8116 .3081 Mtetra
.8116 .3081 .8167 .31543 .82876 .31146 .82371 .3041 Mtetra
.18006 .50842 .18679 .51429 .19642 .51112 .18971 .50522 Mtetra
.18971 .50522 .19642 .51112 .20608 .50793 .19939 .50201 Mtetra
.19939 .50201 .20608 .50793 .21578 .50473 .20911 .49879 Mtetra
.20911 .49879 .21578 .50473 .22552 .50151 .21887 .49555 Mtetra
.21887 .49555 .22552 .50151 .23529 .49829 .22866 .4923 Mtetra
.22866 .4923 .23529 .49829 .2451 .49505 .23849 .48904 Mtetra
.23849 .48904 .2451 .49505 .25494 .4918 .24836 .48577 Mtetra
.24836 .48577 .25494 .4918 .26483 .48854 .25827 .48249 Mtetra
.25827 .48249 .26483 .48854 .27475 .48527 .26821 .47919 Mtetra
.26821 .47919 .27475 .48527 .28471 .48198 .27819 .47588 Mtetra
.27819 .47588 .28471 .48198 .2947 .47868 .28821 .47256 Mtetra
.28821 .47256 .2947 .47868 .30474 .47537 .29827 .46922 Mtetra
.29827 .46922 .30474 .47537 .31481 .47205 .30837 .46587 Mtetra
.30837 .46587 .31481 .47205 .32492 .46871 .3185 .46251 Mtetra
.3185 .46251 .32492 .46871 .33507 .46536 .32867 .45914 Mtetra
.32867 .45914 .33507 .46536 .34526 .462 .33889 .45575 Mtetra
.33889 .45575 .34526 .462 .35549 .45862 .34914 .45235 Mtetra
.34914 .45235 .35549 .45862 .36576 .45523 .35943 .44894 Mtetra
.35943 .44894 .36576 .45523 .37607 .45183 .36976 .44552 Mtetra
.36976 .44552 .37607 .45183 .38641 .44842 .38013 .44208 Mtetra
.38013 .44208 .38641 .44842 .3968 .44499 .39055 .43862 Mtetra
.39055 .43862 .3968 .44499 .40723 .44155 .401 .43516 Mtetra
.401 .43516 .40723 .44155 .41769 .43809 .41149 .43168 Mtetra
.41149 .43168 .41769 .43809 .4282 .43462 .42203 .42819 Mtetra
.42203 .42819 .4282 .43462 .43875 .43114 .4326 .42468 Mtetra
.4326 .42468 .43875 .43114 .44934 .42765 .44322 .42116 Mtetra
.44322 .42116 .44934 .42765 .45998 .42414 .45388 .41762 Mtetra
.45388 .41762 .45998 .42414 .47065 .42062 .46458 .41408 Mtetra
.46458 .41408 .47065 .42062 .48137 .41708 .47533 .41051 Mtetra
.47533 .41051 .48137 .41708 .49213 .41353 .48611 .40694 Mtetra
.48611 .40694 .49213 .41353 .50293 .40996 .49694 .40335 Mtetra
.49694 .40335 .50293 .40996 .51377 .40639 .50781 .39974 Mtetra
.50781 .39974 .51377 .40639 .52466 .40279 .51873 .39612 Mtetra
.51873 .39612 .52466 .40279 .53559 .39919 .52969 .39249 Mtetra
.52969 .39249 .53559 .39919 .54656 .39556 .54069 .38884 Mtetra
.54069 .38884 .54656 .39556 .55758 .39193 .55174 .38518 Mtetra
.55174 .38518 .55758 .39193 .56864 .38828 .56283 .3815 Mtetra
.56283 .3815 .56864 .38828 .57975 .38461 .57396 .37781 Mtetra
.57396 .37781 .57975 .38461 .5909 .38093 .58514 .3741 Mtetra
.58514 .3741 .5909 .38093 .6021 .37724 .59637 .37038 Mtetra
.59637 .37038 .6021 .37724 .61334 .37353 .60764 .36664 Mtetra
.60764 .36664 .61334 .37353 .62462 .3698 .61896 .36289 Mtetra
.61896 .36289 .62462 .3698 .63595 .36606 .63032 .35912 Mtetra
.63032 .35912 .63595 .36606 .64733 .36231 .64173 .35534 Mtetra
.64173 .35534 .64733 .36231 .65875 .35854 .65318 .35154 Mtetra
.65318 .35154 .65875 .35854 .67023 .35475 .66469 .34773 Mtetra
.66469 .34773 .67023 .35475 .68174 .35095 .67623 .3439 Mtetra
.67623 .3439 .68174 .35095 .69331 .34714 .68783 .34005 Mtetra
.68783 .34005 .69331 .34714 .70492 .34331 .69948 .33619 Mtetra
.69948 .33619 .70492 .34331 .71658 .33946 .71117 .33231 Mtetra
.71117 .33231 .71658 .33946 .72829 .33559 .72291 .32842 Mtetra
.72291 .32842 .72829 .33559 .74004 .33171 .7347 .32451 Mtetra
.7347 .32451 .74004 .33171 .75184 .32782 .74654 .32059 Mtetra
.74654 .32059 .75184 .32782 .7637 .32391 .75842 .31664 Mtetra
.75842 .31664 .7637 .32391 .7756 .31998 .77036 .31269 Mtetra
.77036 .31269 .7756 .31998 .78755 .31604 .78235 .30871 Mtetra
.78235 .30871 .78755 .31604 .79955 .31208 .79438 .30472 Mtetra
.79438 .30472 .79955 .31208 .8116 .3081 .80647 .30071 Mtetra
.80647 .30071 .8116 .3081 .82371 .3041 .81861 .29669 Mtetra
.17328 .5025 .18006 .50842 .18971 .50522 .18295 .49928 Mtetra
.18295 .49928 .18971 .50522 .19939 .50201 .19266 .49605 Mtetra
.19266 .49605 .19939 .50201 .20911 .49879 .2024 .4928 Mtetra
.2024 .4928 .20911 .49879 .21887 .49555 .21218 .48954 Mtetra
.21218 .48954 .21887 .49555 .22866 .4923 .22199 .48627 Mtetra
.22199 .48627 .22866 .4923 .23849 .48904 .23184 .48299 Mtetra
.23184 .48299 .23849 .48904 .24836 .48577 .24173 .4797 Mtetra
.24173 .4797 .24836 .48577 .25827 .48249 .25166 .47639 Mtetra
.25166 .47639 .25827 .48249 .26821 .47919 .26163 .47307 Mtetra
.26163 .47307 .26821 .47919 .27819 .47588 .27163 .46974 Mtetra
.27163 .46974 .27819 .47588 .28821 .47256 .28167 .46639 Mtetra
.28167 .46639 .28821 .47256 .29827 .46922 .29175 .46303 Mtetra
.29175 .46303 .29827 .46922 .30837 .46587 .30187 .45966 Mtetra
.30187 .45966 .30837 .46587 .3185 .46251 .31203 .45628 Mtetra
.31203 .45628 .3185 .46251 .32867 .45914 .32223 .45288 Mtetra
.32223 .45288 .32867 .45914 .33889 .45575 .33247 .44947 Mtetra
.33247 .44947 .33889 .45575 .34914 .45235 .34274 .44604 Mtetra
.34274 .44604 .34914 .45235 .35943 .44894 .35306 .44261 Mtetra
.35306 .44261 .35943 .44894 .36976 .44552 .36342 .43916 Mtetra
.36342 .43916 .36976 .44552 .38013 .44208 .37381 .43569 Mtetra
.37381 .43569 .38013 .44208 .39055 .43862 .38425 .43222 Mtetra
.38425 .43222 .39055 .43862 .401 .43516 .39473 .42872 Mtetra
.39473 .42872 .401 .43516 .41149 .43168 .40525 .42522 Mtetra
.40525 .42522 .41149 .43168 .42203 .42819 .41581 .4217 Mtetra
.41581 .4217 .42203 .42819 .4326 .42468 .42641 .41817 Mtetra
.42641 .41817 .4326 .42468 .44322 .42116 .43705 .41462 Mtetra
.43705 .41462 .44322 .42116 .45388 .41762 .44774 .41106 Mtetra
.44774 .41106 .45388 .41762 .46458 .41408 .45847 .40749 Mtetra
.45847 .40749 .46458 .41408 .47533 .41051 .46924 .4039 Mtetra
.46924 .4039 .47533 .41051 .48611 .40694 .48005 .4003 Mtetra
.48005 .4003 .48611 .40694 .49694 .40335 .49091 .39668 Mtetra
.49091 .39668 .49694 .40335 .50781 .39974 .50181 .39305 Mtetra
.50181 .39305 .50781 .39974 .51873 .39612 .51275 .3894 Mtetra
.51275 .3894 .51873 .39612 .52969 .39249 .52374 .38574 Mtetra
.52374 .38574 .52969 .39249 .54069 .38884 .53477 .38207 Mtetra
.53477 .38207 .54069 .38884 .55174 .38518 .54585 .37838 Mtetra
.54585 .37838 .55174 .38518 .56283 .3815 .55697 .37467 Mtetra
.55697 .37467 .56283 .3815 .57396 .37781 .56813 .37095 Mtetra
.56813 .37095 .57396 .37781 .58514 .3741 .57934 .36722 Mtetra
.57934 .36722 .58514 .3741 .59637 .37038 .5906 .36347 Mtetra
.5906 .36347 .59637 .37038 .60764 .36664 .6019 .3597 Mtetra
.6019 .3597 .60764 .36664 .61896 .36289 .61325 .35592 Mtetra
.61325 .35592 .61896 .36289 .63032 .35912 .62464 .35212 Mtetra
.62464 .35212 .63032 .35912 .64173 .35534 .63608 .34831 Mtetra
.63608 .34831 .64173 .35534 .65318 .35154 .64757 .34449 Mtetra
.64757 .34449 .65318 .35154 .66469 .34773 .6591 .34064 Mtetra
.6591 .34064 .66469 .34773 .67623 .3439 .67068 .33678 Mtetra
.67068 .33678 .67623 .3439 .68783 .34005 .68231 .33291 Mtetra
.68231 .33291 .68783 .34005 .69948 .33619 .69399 .32902 Mtetra
.69399 .32902 .69948 .33619 .71117 .33231 .70572 .32511 Mtetra
.70572 .32511 .71117 .33231 .72291 .32842 .71749 .32119 Mtetra
.71749 .32119 .72291 .32842 .7347 .32451 .72932 .31725 Mtetra
.72932 .31725 .7347 .32451 .74654 .32059 .74119 .31329 Mtetra
.74119 .31329 .74654 .32059 .75842 .31664 .75311 .30932 Mtetra
.75311 .30932 .75842 .31664 .77036 .31269 .76508 .30533 Mtetra
.76508 .30533 .77036 .31269 .78235 .30871 .7771 .30133 Mtetra
.7771 .30133 .78235 .30871 .79438 .30472 .78918 .29731 Mtetra
.78918 .29731 .79438 .30472 .80647 .30071 .8013 .29327 Mtetra
.8013 .29327 .80647 .30071 .81861 .29669 .81347 .28921 Mtetra
.16646 .49655 .17328 .5025 .18295 .49928 .17615 .4933 Mtetra
.17615 .4933 .18295 .49928 .19266 .49605 .18587 .49005 Mtetra
.18587 .49005 .19266 .49605 .2024 .4928 .19564 .48678 Mtetra
.19564 .48678 .2024 .4928 .21218 .48954 .20544 .4835 Mtetra
.20544 .4835 .21218 .48954 .22199 .48627 .21527 .48021 Mtetra
.21527 .48021 .22199 .48627 .23184 .48299 .22515 .4769 Mtetra
.22515 .4769 .23184 .48299 .24173 .4797 .23506 .47358 Mtetra
.23506 .47358 .24173 .4797 .25166 .47639 .24501 .47025 Mtetra
.24501 .47025 .25166 .47639 .26163 .47307 .255 .46691 Mtetra
.255 .46691 .26163 .47307 .27163 .46974 .26502 .46355 Mtetra
.26502 .46355 .27163 .46974 .28167 .46639 .27509 .46018 Mtetra
.27509 .46018 .28167 .46639 .29175 .46303 .28519 .4568 Mtetra
.28519 .4568 .29175 .46303 .30187 .45966 .29534 .4534 Mtetra
.29534 .4534 .30187 .45966 .31203 .45628 .30552 .44999 Mtetra
.30552 .44999 .31203 .45628 .32223 .45288 .31574 .44657 Mtetra
.31574 .44657 .32223 .45288 .33247 .44947 .326 .44314 Mtetra
.326 .44314 .33247 .44947 .34274 .44604 .3363 .43969 Mtetra
.3363 .43969 .34274 .44604 .35306 .44261 .34664 .43623 Mtetra
.34664 .43623 .35306 .44261 .36342 .43916 .35702 .43275 Mtetra
.35702 .43275 .36342 .43916 .37381 .43569 .36744 .42926 Mtetra
.36744 .42926 .37381 .43569 .38425 .43222 .37791 .42576 Mtetra
.37791 .42576 .38425 .43222 .39473 .42872 .38841 .42224 Mtetra
.38841 .42224 .39473 .42872 .40525 .42522 .39896 .41871 Mtetra
.39896 .41871 .40525 .42522 .41581 .4217 .40954 .41517 Mtetra
.40954 .41517 .41581 .4217 .42641 .41817 .42017 .41161 Mtetra
.42017 .41161 .42641 .41817 .43705 .41462 .43084 .40804 Mtetra
.43084 .40804 .43705 .41462 .44774 .41106 .44155 .40445 Mtetra
.44155 .40445 .44774 .41106 .45847 .40749 .45231 .40085 Mtetra
.45231 .40085 .45847 .40749 .46924 .4039 .46311 .39724 Mtetra
.46311 .39724 .46924 .4039 .48005 .4003 .47395 .39361 Mtetra
.47395 .39361 .48005 .4003 .49091 .39668 .48483 .38996 Mtetra
.48483 .38996 .49091 .39668 .50181 .39305 .49576 .38631 Mtetra
.49576 .38631 .50181 .39305 .51275 .3894 .50673 .38263 Mtetra
.50673 .38263 .51275 .3894 .52374 .38574 .51775 .37895 Mtetra
.51775 .37895 .52374 .38574 .53477 .38207 .52881 .37524 Mtetra
.52881 .37524 .53477 .38207 .54585 .37838 .53991 .37153 Mtetra
.53991 .37153 .54585 .37838 .55697 .37467 .55106 .36779 Mtetra
.55106 .36779 .55697 .37467 .56813 .37095 .56226 .36404 Mtetra
.56226 .36404 .56813 .37095 .57934 .36722 .5735 .36028 Mtetra
.5735 .36028 .57934 .36722 .5906 .36347 .58479 .3565 Mtetra
.58479 .3565 .5906 .36347 .6019 .3597 .59612 .35271 Mtetra
.59612 .35271 .6019 .3597 .61325 .35592 .6075 .3489 Mtetra
.6075 .3489 .61325 .35592 .62464 .35212 .61892 .34508 Mtetra
.61892 .34508 .62464 .35212 .63608 .34831 .63039 .34124 Mtetra
.63039 .34124 .63608 .34831 .64757 .34449 .64191 .33738 Mtetra
.64191 .33738 .64757 .34449 .6591 .34064 .65348 .33351 Mtetra
.65348 .33351 .6591 .34064 .67068 .33678 .66509 .32962 Mtetra
.66509 .32962 .67068 .33678 .68231 .33291 .67676 .32572 Mtetra
.67676 .32572 .68231 .33291 .69399 .32902 .68847 .32179 Mtetra
.68847 .32179 .69399 .32902 .70572 .32511 .70023 .31786 Mtetra
.70023 .31786 .70572 .32511 .71749 .32119 .71203 .31391 Mtetra
.71203 .31391 .71749 .32119 .72932 .31725 .72389 .30994 Mtetra
.72389 .30994 .72932 .31725 .74119 .31329 .7358 .30595 Mtetra
.7358 .30595 .74119 .31329 .75311 .30932 .74775 .30195 Mtetra
.74775 .30195 .75311 .30932 .76508 .30533 .75976 .29793 Mtetra
.75976 .29793 .76508 .30533 .7771 .30133 .77182 .29389 Mtetra
.77182 .29389 .7771 .30133 .78918 .29731 .78393 .28984 Mtetra
.78393 .28984 .78918 .29731 .8013 .29327 .79609 .28577 Mtetra
.79609 .28577 .8013 .29327 .81347 .28921 .8083 .28168 Mtetra
.15958 .49055 .16646 .49655 .17615 .4933 .16929 .48728 Mtetra
.16929 .48728 .17615 .4933 .18587 .49005 .17904 .484 Mtetra
.17904 .484 .18587 .49005 .19564 .48678 .18883 .48071 Mtetra
.18883 .48071 .19564 .48678 .20544 .4835 .19865 .47741 Mtetra
.19865 .47741 .20544 .4835 .21527 .48021 .20851 .47409 Mtetra
.20851 .47409 .21527 .48021 .22515 .4769 .2184 .47076 Mtetra
.2184 .47076 .22515 .4769 .23506 .47358 .22834 .46742 Mtetra
.22834 .46742 .23506 .47358 .24501 .47025 .23831 .46406 Mtetra
.23831 .46406 .24501 .47025 .255 .46691 .24832 .46069 Mtetra
.24832 .46069 .255 .46691 .26502 .46355 .25837 .45731 Mtetra
.25837 .45731 .26502 .46355 .27509 .46018 .26846 .45392 Mtetra
.26846 .45392 .27509 .46018 .28519 .4568 .27859 .45051 Mtetra
.27859 .45051 .28519 .4568 .29534 .4534 .28875 .44709 Mtetra
.28875 .44709 .29534 .4534 .30552 .44999 .29896 .44366 Mtetra
.29896 .44366 .30552 .44999 .31574 .44657 .3092 .44021 Mtetra
.3092 .44021 .31574 .44657 .326 .44314 .31949 .43675 Mtetra
.31949 .43675 .326 .44314 .3363 .43969 .32981 .43328 Mtetra
.32981 .43328 .3363 .43969 .34664 .43623 .34018 .42979 Mtetra
.34018 .42979 .34664 .43623 .35702 .43275 .35058 .42629 Mtetra
.35058 .42629 .35702 .43275 .36744 .42926 .36103 .42278 Mtetra
.36103 .42278 .36744 .42926 .37791 .42576 .37152 .41925 Mtetra
.37152 .41925 .37791 .42576 .38841 .42224 .38205 .41571 Mtetra
.38205 .41571 .38841 .42224 .39896 .41871 .39262 .41215 Mtetra
.39262 .41215 .39896 .41871 .40954 .41517 .40323 .40858 Mtetra
.40323 .40858 .40954 .41517 .42017 .41161 .41389 .405 Mtetra
.41389 .405 .42017 .41161 .43084 .40804 .42458 .4014 Mtetra
.42458 .4014 .43084 .40804 .44155 .40445 .43532 .39779 Mtetra
.43532 .39779 .44155 .40445 .45231 .40085 .44611 .39416 Mtetra
.44611 .39416 .45231 .40085 .46311 .39724 .45693 .39052 Mtetra
.45693 .39052 .46311 .39724 .47395 .39361 .4678 .38686 Mtetra
.4678 .38686 .47395 .39361 .48483 .38996 .47871 .38319 Mtetra
.47871 .38319 .48483 .38996 .49576 .38631 .48967 .37951 Mtetra
.48967 .37951 .49576 .38631 .50673 .38263 .50067 .37581 Mtetra
.50067 .37581 .50673 .38263 .51775 .37895 .51171 .37209 Mtetra
.51171 .37209 .51775 .37895 .52881 .37524 .5228 .36836 Mtetra
.5228 .36836 .52881 .37524 .53991 .37153 .53394 .36462 Mtetra
.53394 .36462 .53991 .37153 .55106 .36779 .54512 .36085 Mtetra
.54512 .36085 .55106 .36779 .56226 .36404 .55634 .35708 Mtetra
.55634 .35708 .56226 .36404 .5735 .36028 .56761 .35329 Mtetra
.56761 .35329 .5735 .36028 .58479 .3565 .57893 .34948 Mtetra
.57893 .34948 .58479 .3565 .59612 .35271 .59029 .34566 Mtetra
.59029 .34566 .59612 .35271 .6075 .3489 .6017 .34182 Mtetra
.6017 .34182 .6075 .3489 .61892 .34508 .61316 .33796 Mtetra
.61316 .33796 .61892 .34508 .63039 .34124 .62466 .33409 Mtetra
.62466 .33409 .63039 .34124 .64191 .33738 .63621 .33021 Mtetra
.63621 .33021 .64191 .33738 .65348 .33351 .64781 .32631 Mtetra
.64781 .32631 .65348 .33351 .66509 .32962 .65946 .32239 Mtetra
.65946 .32239 .66509 .32962 .67676 .32572 .67115 .31846 Mtetra
.67115 .31846 .67676 .32572 .68847 .32179 .6829 .31451 Mtetra
.6829 .31451 .68847 .32179 .70023 .31786 .69469 .31054 Mtetra
.69469 .31054 .70023 .31786 .71203 .31391 .70653 .30656 Mtetra
.70653 .30656 .71203 .31391 .72389 .30994 .71842 .30256 Mtetra
.71842 .30256 .72389 .30994 .7358 .30595 .73037 .29854 Mtetra
.73037 .29854 .7358 .30595 .74775 .30195 .74236 .29451 Mtetra
.74236 .29451 .74775 .30195 .75976 .29793 .7544 .29046 Mtetra
.7544 .29046 .75976 .29793 .77182 .29389 .76649 .28639 Mtetra
.76649 .28639 .77182 .29389 .78393 .28984 .77864 .28231 Mtetra
.77864 .28231 .78393 .28984 .79609 .28577 .79083 .27821 Mtetra
.79083 .27821 .79609 .28577 .8083 .28168 .80308 .27409 Mtetra
.655 .751 .92 r
.15266 .48451 .15958 .49055 .16929 .48728 .16239 .48123 Mtetra
.655 .752 .921 r
.16239 .48123 .16929 .48728 .17904 .484 .17216 .47794 Mtetra
.656 .752 .921 r
.17216 .47794 .17904 .484 .18883 .48071 .18197 .47463 Mtetra
.18197 .47463 .18883 .48071 .19865 .47741 .19181 .4713 Mtetra
.19181 .4713 .19865 .47741 .20851 .47409 .20169 .46797 Mtetra
.20169 .46797 .20851 .47409 .2184 .47076 .21161 .46461 Mtetra
.656 .753 .921 r
.21161 .46461 .2184 .47076 .22834 .46742 .22156 .46124 Mtetra
.22156 .46124 .22834 .46742 .23831 .46406 .23156 .45786 Mtetra
.656 .752 .921 r
.23156 .45786 .23831 .46406 .24832 .46069 .24159 .45447 Mtetra
.24159 .45447 .24832 .46069 .25837 .45731 .25167 .45106 Mtetra
.25167 .45106 .25837 .45731 .26846 .45392 .26178 .44764 Mtetra
.26178 .44764 .26846 .45392 .27859 .45051 .27193 .44421 Mtetra
.27193 .44421 .27859 .45051 .28875 .44709 .28212 .44076 Mtetra
.28212 .44076 .28875 .44709 .29896 .44366 .29235 .4373 Mtetra
.29235 .4373 .29896 .44366 .3092 .44021 .30262 .43383 Mtetra
.30262 .43383 .3092 .44021 .31949 .43675 .31293 .43034 Mtetra
.31293 .43034 .31949 .43675 .32981 .43328 .32328 .42684 Mtetra
.32328 .42684 .32981 .43328 .34018 .42979 .33367 .42333 Mtetra
.33367 .42333 .34018 .42979 .35058 .42629 .3441 .4198 Mtetra
.3441 .4198 .35058 .42629 .36103 .42278 .35457 .41626 Mtetra
.35457 .41626 .36103 .42278 .37152 .41925 .36508 .41271 Mtetra
.36508 .41271 .37152 .41925 .38205 .41571 .37564 .40914 Mtetra
.656 .752 .92 r
.37564 .40914 .38205 .41571 .39262 .41215 .38623 .40556 Mtetra
.38623 .40556 .39262 .41215 .40323 .40858 .39687 .40196 Mtetra
.39687 .40196 .40323 .40858 .41389 .405 .40756 .39835 Mtetra
.40756 .39835 .41389 .405 .42458 .4014 .41828 .39473 Mtetra
.41828 .39473 .42458 .4014 .43532 .39779 .42905 .39109 Mtetra
.42905 .39109 .43532 .39779 .44611 .39416 .43986 .38743 Mtetra
.43986 .38743 .44611 .39416 .45693 .39052 .45071 .38377 Mtetra
.45071 .38377 .45693 .39052 .4678 .38686 .4616 .38008 Mtetra
.4616 .38008 .4678 .38686 .47871 .38319 .47255 .37638 Mtetra
.47255 .37638 .47871 .38319 .48967 .37951 .48353 .37267 Mtetra
.48353 .37267 .48967 .37951 .50067 .37581 .49456 .36894 Mtetra
.49456 .36894 .50067 .37581 .51171 .37209 .50563 .3652 Mtetra
.50563 .3652 .51171 .37209 .5228 .36836 .51675 .36144 Mtetra
.51675 .36144 .5228 .36836 .53394 .36462 .52791 .35767 Mtetra
.52791 .35767 .53394 .36462 .54512 .36085 .53912 .35388 Mtetra
.656 .752 .921 r
.53912 .35388 .54512 .36085 .55634 .35708 .55038 .35008 Mtetra
.55038 .35008 .55634 .35708 .56761 .35329 .56168 .34626 Mtetra
.56168 .34626 .56761 .35329 .57893 .34948 .57303 .34242 Mtetra
.57303 .34242 .57893 .34948 .59029 .34566 .58442 .33857 Mtetra
.58442 .33857 .59029 .34566 .6017 .34182 .59586 .33471 Mtetra
.59586 .33471 .6017 .34182 .61316 .33796 .60735 .33082 Mtetra
.60735 .33082 .61316 .33796 .62466 .33409 .61889 .32693 Mtetra
.61889 .32693 .62466 .33409 .63621 .33021 .63047 .32301 Mtetra
.63047 .32301 .63621 .33021 .64781 .32631 .6421 .31908 Mtetra
.6421 .31908 .64781 .32631 .65946 .32239 .65378 .31514 Mtetra
.65378 .31514 .65946 .32239 .67115 .31846 .66551 .31118 Mtetra
.66551 .31118 .67115 .31846 .6829 .31451 .67729 .3072 Mtetra
.67729 .3072 .6829 .31451 .69469 .31054 .68911 .3032 Mtetra
.68911 .3032 .69469 .31054 .70653 .30656 .70099 .29919 Mtetra
.70099 .29919 .70653 .30656 .71842 .30256 .71292 .29516 Mtetra
.71292 .29516 .71842 .30256 .73037 .29854 .72489 .29112 Mtetra
.72489 .29112 .73037 .29854 .74236 .29451 .73692 .28705 Mtetra
.73692 .28705 .74236 .29451 .7544 .29046 .749 .28297 Mtetra
.749 .28297 .7544 .29046 .76649 .28639 .76113 .27887 Mtetra
.76113 .27887 .76649 .28639 .77864 .28231 .77331 .27474 Mtetra
.77331 .27474 .77864 .28231 .79083 .27821 .78554 .2706 Mtetra
.656 .752 .92 r
.78554 .2706 .79083 .27821 .80308 .27409 .79782 .26643 Mtetra
.654 .751 .921 r
.14569 .47843 .15266 .48451 .16239 .48123 .15544 .47515 Mtetra
.655 .752 .921 r
.15544 .47515 .16239 .48123 .17216 .47794 .16523 .47185 Mtetra
.655 .753 .922 r
.16523 .47185 .17216 .47794 .18197 .47463 .17505 .46853 Mtetra
.17505 .46853 .18197 .47463 .19181 .4713 .18492 .46519 Mtetra
.656 .754 .922 r
.18492 .46519 .19181 .4713 .20169 .46797 .19482 .46183 Mtetra
.19482 .46183 .20169 .46797 .21161 .46461 .20476 .45845 Mtetra
.20476 .45845 .21161 .46461 .22156 .46124 .21474 .45505 Mtetra
.656 .753 .921 r
.21474 .45505 .22156 .46124 .23156 .45786 .22476 .45164 Mtetra
.22476 .45164 .23156 .45786 .24159 .45447 .23482 .44821 Mtetra
.23482 .44821 .24159 .45447 .25167 .45106 .24491 .44477 Mtetra
.656 .752 .921 r
.24491 .44477 .25167 .45106 .26178 .44764 .25505 .44132 Mtetra
.25505 .44132 .26178 .44764 .27193 .44421 .26522 .43785 Mtetra
.656 .752 .92 r
.26522 .43785 .27193 .44421 .28212 .44076 .27544 .43437 Mtetra
.27544 .43437 .28212 .44076 .29235 .4373 .28569 .43088 Mtetra
.656 .751 .92 r
.28569 .43088 .29235 .4373 .30262 .43383 .29599 .42738 Mtetra
.29599 .42738 .30262 .43383 .31293 .43034 .30632 .42386 Mtetra
.30632 .42386 .31293 .43034 .32328 .42684 .31669 .42033 Mtetra
.31669 .42033 .32328 .42684 .33367 .42333 .32711 .41679 Mtetra
.32711 .41679 .33367 .42333 .3441 .4198 .33757 .41323 Mtetra
.33757 .41323 .3441 .4198 .35457 .41626 .34806 .40966 Mtetra
.656 .75 .92 r
.34806 .40966 .35457 .41626 .36508 .41271 .3586 .40608 Mtetra
.656 .75 .919 r
.3586 .40608 .36508 .41271 .37564 .40914 .36918 .40248 Mtetra
.36918 .40248 .37564 .40914 .38623 .40556 .37981 .39887 Mtetra
.37981 .39887 .38623 .40556 .39687 .40196 .39047 .39525 Mtetra
.39047 .39525 .39687 .40196 .40756 .39835 .40118 .39161 Mtetra
.40118 .39161 .40756 .39835 .41828 .39473 .41193 .38796 Mtetra
.41193 .38796 .41828 .39473 .42905 .39109 .42272 .38429 Mtetra
.42272 .38429 .42905 .39109 .43986 .38743 .43356 .38061 Mtetra
.43356 .38061 .43986 .38743 .45071 .38377 .44444 .37692 Mtetra
.44444 .37692 .45071 .38377 .4616 .38008 .45536 .37321 Mtetra
.45536 .37321 .4616 .38008 .47255 .37638 .46633 .36948 Mtetra
.46633 .36948 .47255 .37638 .48353 .37267 .47735 .36574 Mtetra
.47735 .36574 .48353 .37267 .49456 .36894 .4884 .36198 Mtetra
.4884 .36198 .49456 .36894 .50563 .3652 .49951 .35821 Mtetra
.49951 .35821 .50563 .3652 .51675 .36144 .51065 .35443 Mtetra
.51065 .35443 .51675 .36144 .52791 .35767 .52185 .35063 Mtetra
.52185 .35063 .52791 .35767 .53912 .35388 .53309 .34681 Mtetra
.53309 .34681 .53912 .35388 .55038 .35008 .54437 .34298 Mtetra
.656 .75 .92 r
.54437 .34298 .55038 .35008 .56168 .34626 .5557 .33913 Mtetra
.5557 .33913 .56168 .34626 .57303 .34242 .56708 .33527 Mtetra
.56708 .33527 .57303 .34242 .58442 .33857 .57851 .3314 Mtetra
.656 .751 .92 r
.57851 .3314 .58442 .33857 .59586 .33471 .58998 .3275 Mtetra
.58998 .3275 .59586 .33471 .60735 .33082 .6015 .3236 Mtetra
.6015 .3236 .60735 .33082 .61889 .32693 .61307 .31967 Mtetra
.655 .751 .92 r
.61307 .31967 .61889 .32693 .63047 .32301 .62468 .31574 Mtetra
.62468 .31574 .63047 .32301 .6421 .31908 .63635 .31178 Mtetra
.63635 .31178 .6421 .31908 .65378 .31514 .64806 .30782 Mtetra
.655 .752 .921 r
.64806 .30782 .65378 .31514 .66551 .31118 .65982 .30383 Mtetra
.65982 .30383 .66551 .31118 .67729 .3072 .67163 .29983 Mtetra
.67163 .29983 .67729 .3072 .68911 .3032 .6835 .29582 Mtetra
.655 .753 .921 r
.6835 .29582 .68911 .3032 .70099 .29919 .69541 .29179 Mtetra
.655 .753 .922 r
.69541 .29179 .70099 .29919 .71292 .29516 .70737 .28773 Mtetra
.70737 .28773 .71292 .29516 .72489 .29112 .71938 .28366 Mtetra
.656 .753 .922 r
.71938 .28366 .72489 .29112 .73692 .28705 .73144 .27957 Mtetra
.656 .754 .922 r
.73144 .27957 .73692 .28705 .749 .28297 .74356 .27545 Mtetra
.74356 .27545 .749 .28297 .76113 .27887 .75572 .27131 Mtetra
.656 .754 .921 r
.75572 .27131 .76113 .27887 .77331 .27474 .76794 .26714 Mtetra
.657 .753 .921 r
.76794 .26714 .77331 .27474 .78554 .2706 .78021 .26294 Mtetra
.657 .753 .92 r
.78021 .26294 .78554 .2706 .79782 .26643 .79252 .25872 Mtetra
.651 .75 .922 r
.13868 .4723 .14569 .47843 .15544 .47515 .14844 .46908 Mtetra
.652 .753 .924 r
.14844 .46908 .15544 .47515 .16523 .47185 .15824 .46583 Mtetra
.652 .756 .925 r
.15824 .46583 .16523 .47185 .17505 .46853 .16808 .46255 Mtetra
.653 .758 .926 r
.16808 .46255 .17505 .46853 .18492 .46519 .17796 .45923 Mtetra
.654 .76 .927 r
.17796 .45923 .18492 .46519 .19482 .46183 .18788 .45588 Mtetra
.655 .761 .928 r
.18788 .45588 .19482 .46183 .20476 .45845 .19784 .4525 Mtetra
.655 .762 .928 r
.19784 .4525 .20476 .45845 .21474 .45505 .20784 .44909 Mtetra
.656 .762 .928 r
.20784 .44909 .21474 .45505 .22476 .45164 .21788 .44565 Mtetra
.656 .763 .928 r
.21788 .44565 .22476 .45164 .23482 .44821 .22797 .4422 Mtetra
.656 .762 .928 r
.22797 .4422 .23482 .44821 .24491 .44477 .23809 .43873 Mtetra
.23809 .43873 .24491 .44477 .25505 .44132 .24825 .43524 Mtetra
.657 .762 .927 r
.24825 .43524 .25505 .44132 .26522 .43785 .25845 .43173 Mtetra
.657 .761 .927 r
.25845 .43173 .26522 .43785 .27544 .43437 .26869 .42821 Mtetra
.26869 .42821 .27544 .43437 .28569 .43088 .27897 .42468 Mtetra
.657 .76 .926 r
.27897 .42468 .28569 .43088 .29599 .42738 .28929 .42114 Mtetra
.656 .76 .926 r
.28929 .42114 .29599 .42738 .30632 .42386 .29965 .41758 Mtetra
.656 .759 .926 r
.29965 .41758 .30632 .42386 .31669 .42033 .31005 .41401 Mtetra
.656 .759 .925 r
.31005 .41401 .31669 .42033 .32711 .41679 .32049 .41043 Mtetra
.656 .758 .925 r
.32049 .41043 .32711 .41679 .33757 .41323 .33097 .40684 Mtetra
.33097 .40684 .33757 .41323 .34806 .40966 .3415 .40323 Mtetra
.3415 .40323 .34806 .40966 .3586 .40608 .35206 .39961 Mtetra
.656 .757 .924 r
.35206 .39961 .3586 .40608 .36918 .40248 .36267 .39598 Mtetra
.36267 .39598 .36918 .40248 .37981 .39887 .37332 .39234 Mtetra
.37332 .39234 .37981 .39887 .39047 .39525 .38401 .38868 Mtetra
.38401 .38868 .39047 .39525 .40118 .39161 .39475 .38501 Mtetra
.656 .756 .924 r
.39475 .38501 .40118 .39161 .41193 .38796 .40553 .38133 Mtetra
.40553 .38133 .41193 .38796 .42272 .38429 .41635 .37763 Mtetra
.41635 .37763 .42272 .38429 .43356 .38061 .42721 .37392 Mtetra
.42721 .37392 .43356 .38061 .44444 .37692 .43812 .3702 Mtetra
.43812 .3702 .44444 .37692 .45536 .37321 .44907 .36646 Mtetra
.44907 .36646 .45536 .37321 .46633 .36948 .46007 .36271 Mtetra
.46007 .36271 .46633 .36948 .47735 .36574 .47111 .35894 Mtetra
.47111 .35894 .47735 .36574 .4884 .36198 .4822 .35516 Mtetra
.4822 .35516 .4884 .36198 .49951 .35821 .49333 .35136 Mtetra
.655 .756 .924 r
.49333 .35136 .49951 .35821 .51065 .35443 .50451 .34756 Mtetra
.50451 .34756 .51065 .35443 .52185 .35063 .51573 .34373 Mtetra
.655 .757 .924 r
.51573 .34373 .52185 .35063 .53309 .34681 .527 .33989 Mtetra
.527 .33989 .53309 .34681 .54437 .34298 .53832 .33604 Mtetra
.655 .757 .925 r
.53832 .33604 .54437 .34298 .5557 .33913 .54968 .33218 Mtetra
.54968 .33218 .5557 .33913 .56708 .33527 .56109 .3283 Mtetra
.655 .758 .925 r
.56109 .3283 .56708 .33527 .57851 .3314 .57255 .3244 Mtetra
.655 .758 .926 r
.57255 .3244 .57851 .3314 .58998 .3275 .58405 .32049 Mtetra
.58405 .32049 .58998 .3275 .6015 .3236 .59561 .31657 Mtetra
.655 .759 .926 r
.59561 .31657 .6015 .3236 .61307 .31967 .60721 .31263 Mtetra
.655 .759 .927 r
.60721 .31263 .61307 .31967 .62468 .31574 .61886 .30868 Mtetra
.655 .76 .927 r
.61886 .30868 .62468 .31574 .63635 .31178 .63056 .30472 Mtetra
.63056 .30472 .63635 .31178 .64806 .30782 .64231 .30073 Mtetra
.655 .761 .928 r
.64231 .30073 .64806 .30782 .65982 .30383 .6541 .29673 Mtetra
.6541 .29673 .65982 .30383 .67163 .29983 .66595 .29271 Mtetra
.655 .762 .928 r
.66595 .29271 .67163 .29983 .6835 .29582 .67785 .28867 Mtetra
.67785 .28867 .6835 .29582 .69541 .29179 .6898 .28461 Mtetra
.6898 .28461 .69541 .29179 .70737 .28773 .70179 .28053 Mtetra
.656 .762 .928 r
.70179 .28053 .70737 .28773 .71938 .28366 .71384 .27641 Mtetra
.71384 .27641 .71938 .28366 .73144 .27957 .72594 .27226 Mtetra
.657 .762 .927 r
.72594 .27226 .73144 .27957 .74356 .27545 .73809 .26808 Mtetra
.658 .761 .926 r
.73809 .26808 .74356 .27545 .75572 .27131 .75029 .26385 Mtetra
.659 .76 .925 r
.75029 .26385 .75572 .27131 .76794 .26714 .76253 .25959 Mtetra
.659 .758 .923 r
.76253 .25959 .76794 .26714 .78021 .26294 .77483 .25529 Mtetra
.66 .756 .921 r
.77483 .25529 .78021 .26294 .79252 .25872 .78718 .25095 Mtetra
.643 .748 .926 r
.13161 .46613 .13868 .4723 .14844 .46908 .14137 .46308 Mtetra
.644 .755 .93 r
.14137 .46308 .14844 .46908 .15824 .46583 .15117 .45998 Mtetra
.645 .761 .933 r
.15117 .45998 .15824 .46583 .16808 .46255 .16101 .45683 Mtetra
.647 .767 .936 r
.16101 .45683 .16808 .46255 .17796 .45923 .1709 .45362 Mtetra
.649 .772 .938 r
.1709 .45362 .17796 .45923 .18788 .45588 .18084 .45034 Mtetra
.651 .776 .94 r
.18084 .45034 .18788 .45588 .19784 .4525 .19082 .44701 Mtetra
.653 .779 .941 r
.19082 .44701 .19784 .4525 .20784 .44909 .20084 .44361 Mtetra
.654 .78 .941 r
.20084 .44361 .20784 .44909 .21788 .44565 .21091 .44017 Mtetra
.655 .781 .941 r
.21091 .44017 .21788 .44565 .22797 .4422 .22101 .43668 Mtetra
.656 .781 .94 r
.22101 .43668 .22797 .4422 .23809 .43873 .23116 .43316 Mtetra
.657 .781 .94 r
.23116 .43316 .23809 .43873 .24825 .43524 .24135 .42962 Mtetra
.657 .78 .939 r
.24135 .42962 .24825 .43524 .25845 .43173 .25158 .42605 Mtetra
.658 .778 .938 r
.25158 .42605 .25845 .43173 .26869 .42821 .26185 .42246 Mtetra
.658 .777 .937 r
.26185 .42246 .26869 .42821 .27897 .42468 .27216 .41886 Mtetra
.658 .775 .936 r
.27216 .41886 .27897 .42468 .28929 .42114 .28251 .41524 Mtetra
.658 .774 .935 r
.28251 .41524 .28929 .42114 .29965 .41758 .2929 .41161 Mtetra
.658 .772 .933 r
.2929 .41161 .29965 .41758 .31005 .41401 .30333 .40797 Mtetra
.658 .77 .932 r
.30333 .40797 .31005 .41401 .32049 .41043 .3138 .40432 Mtetra
.658 .769 .932 r
.3138 .40432 .32049 .41043 .33097 .40684 .32431 .40066 Mtetra
.657 .767 .931 r
.32431 .40066 .33097 .40684 .3415 .40323 .33487 .39699 Mtetra
.657 .766 .93 r
.33487 .39699 .3415 .40323 .35206 .39961 .34546 .39332 Mtetra
.657 .765 .929 r
.34546 .39332 .35206 .39961 .36267 .39598 .3561 .38963 Mtetra
.657 .764 .929 r
.3561 .38963 .36267 .39598 .37332 .39234 .36678 .38594 Mtetra
.657 .763 .928 r
.36678 .38594 .37332 .39234 .38401 .38868 .3775 .38223 Mtetra
.656 .762 .928 r
.3775 .38223 .38401 .38868 .39475 .38501 .38826 .37852 Mtetra
.656 .762 .927 r
.38826 .37852 .39475 .38501 .40553 .38133 .39907 .37479 Mtetra
.656 .761 .927 r
.39907 .37479 .40553 .38133 .41635 .37763 .40992 .37106 Mtetra
.40992 .37106 .41635 .37763 .42721 .37392 .42081 .36731 Mtetra
.656 .76 .927 r
.42081 .36731 .42721 .37392 .43812 .3702 .43175 .36356 Mtetra
.43175 .36356 .43812 .3702 .44907 .36646 .44273 .35979 Mtetra
.655 .76 .927 r
.44273 .35979 .44907 .36646 .46007 .36271 .45376 .35601 Mtetra
.45376 .35601 .46007 .36271 .47111 .35894 .46483 .35223 Mtetra
.46483 .35223 .47111 .35894 .4822 .35516 .47595 .34843 Mtetra
.655 .761 .928 r
.47595 .34843 .4822 .35516 .49333 .35136 .48711 .34462 Mtetra
.48711 .34462 .49333 .35136 .50451 .34756 .49832 .3408 Mtetra
.654 .762 .928 r
.49832 .3408 .50451 .34756 .51573 .34373 .50957 .33697 Mtetra
.654 .762 .929 r
.50957 .33697 .51573 .34373 .527 .33989 .52087 .33313 Mtetra
.654 .763 .93 r
.52087 .33313 .527 .33989 .53832 .33604 .53222 .32928 Mtetra
.654 .764 .93 r
.53222 .32928 .53832 .33604 .54968 .33218 .54362 .32542 Mtetra
.653 .765 .931 r
.54362 .32542 .54968 .33218 .56109 .3283 .55506 .32154 Mtetra
.653 .766 .932 r
.55506 .32154 .56109 .3283 .57255 .3244 .56655 .31766 Mtetra
.653 .767 .933 r
.56655 .31766 .57255 .3244 .58405 .32049 .57809 .31377 Mtetra
.653 .769 .934 r
.57809 .31377 .58405 .32049 .59561 .31657 .58968 .30986 Mtetra
.652 .77 .935 r
.58968 .30986 .59561 .31657 .60721 .31263 .60131 .30594 Mtetra
.652 .772 .937 r
.60131 .30594 .60721 .31263 .61886 .30868 .613 .30201 Mtetra
.652 .773 .938 r
.613 .30201 .61886 .30868 .63056 .30472 .62474 .29806 Mtetra
.652 .775 .939 r
.62474 .29806 .63056 .30472 .64231 .30073 .63652 .29409 Mtetra
.652 .777 .94 r
.63652 .29409 .64231 .30073 .6541 .29673 .64836 .2901 Mtetra
.652 .778 .941 r
.64836 .2901 .6541 .29673 .66595 .29271 .66024 .28608 Mtetra
.653 .779 .941 r
.66024 .28608 .66595 .29271 .67785 .28867 .67218 .28203 Mtetra
.653 .78 .941 r
.67218 .28203 .67785 .28867 .6898 .28461 .68417 .27795 Mtetra
.655 .781 .941 r
.68417 .27795 .6898 .28461 .70179 .28053 .6962 .27381 Mtetra
.656 .781 .94 r
.6962 .27381 .70179 .28053 .71384 .27641 .70829 .26963 Mtetra
.658 .78 .939 r
.70829 .26963 .71384 .27641 .72594 .27226 .72042 .26538 Mtetra
.66 .779 .937 r
.72042 .26538 .72594 .27226 .73809 .26808 .7326 .26106 Mtetra
.662 .776 .934 r
.7326 .26106 .73809 .26808 .75029 .26385 .74483 .25667 Mtetra
.664 .773 .93 r
.74483 .25667 .75029 .26385 .76253 .25959 .7571 .25221 Mtetra
.666 .768 .926 r
.7571 .25221 .76253 .25959 .77483 .25529 .76943 .24769 Mtetra
.667 .763 .922 r
.76943 .24769 .77483 .25529 .78718 .25095 .7818 .24311 Mtetra
.627 .744 .931 r
.12449 .45992 .13161 .46613 .14137 .46308 .13423 .45718 Mtetra
.628 .756 .939 r
.13423 .45718 .14137 .46308 .15117 .45998 .14402 .45437 Mtetra
.63 .767 .945 r
.14402 .45437 .15117 .45998 .16101 .45683 .15385 .45149 Mtetra
.632 .778 .951 r
.15385 .45149 .16101 .45683 .1709 .45362 .16374 .44852 Mtetra
.635 .788 .956 r
.16374 .44852 .1709 .45362 .18084 .45034 .17367 .44545 Mtetra
.638 .797 .959 r
.17367 .44545 .18084 .45034 .19082 .44701 .18366 .44227 Mtetra
.641 .805 .962 r
.18366 .44227 .19082 .44701 .20084 .44361 .19369 .439 Mtetra
.644 .811 .963 r
.19369 .439 .20084 .44361 .21091 .44017 .20378 .43563 Mtetra
.646 .815 .964 r
.20378 .43563 .21091 .44017 .22101 .43668 .2139 .4322 Mtetra
.648 .818 .965 r
.2139 .4322 .22101 .43668 .23116 .43316 .22408 .4287 Mtetra
.649 .82 .965 r
.22408 .4287 .23116 .43316 .24135 .42962 .2343 .42514 Mtetra
.651 .821 .965 r
.2343 .42514 .24135 .42962 .25158 .42605 .24455 .42155 Mtetra
.652 .821 .965 r
.24455 .42155 .25158 .42605 .26185 .42246 .25486 .41792 Mtetra
.653 .82 .964 r
.25486 .41792 .26185 .42246 .27216 .41886 .2652 .41426 Mtetra
.653 .819 .963 r
.2652 .41426 .27216 .41886 .28251 .41524 .27558 .41058 Mtetra
.654 .818 .962 r
.27558 .41058 .28251 .41524 .2929 .41161 .28601 .40688 Mtetra
.654 .817 .961 r
.28601 .40688 .2929 .41161 .30333 .40797 .29647 .40316 Mtetra
.654 .815 .96 r
.29647 .40316 .30333 .40797 .3138 .40432 .30698 .39944 Mtetra
.654 .813 .96 r
.30698 .39944 .3138 .40432 .32431 .40066 .31752 .39571 Mtetra
.655 .811 .959 r
.31752 .39571 .32431 .40066 .33487 .39699 .32811 .39197 Mtetra
.654 .809 .958 r
.32811 .39197 .33487 .39699 .34546 .39332 .33874 .38822 Mtetra
.654 .808 .957 r
.33874 .38822 .34546 .39332 .3561 .38963 .34941 .38446 Mtetra
.654 .806 .956 r
.34941 .38446 .3561 .38963 .36678 .38594 .36012 .38071 Mtetra
.654 .805 .956 r
.36012 .38071 .36678 .38594 .3775 .38223 .37088 .37694 Mtetra
.654 .804 .955 r
.37088 .37694 .3775 .38223 .38826 .37852 .38167 .37317 Mtetra
.653 .803 .955 r
.38167 .37317 .38826 .37852 .39907 .37479 .39251 .3694 Mtetra
.653 .802 .954 r
.39251 .3694 .39907 .37479 .40992 .37106 .4034 .36562 Mtetra
.653 .801 .954 r
.4034 .36562 .40992 .37106 .42081 .36731 .41432 .36184 Mtetra
.652 .8 .954 r
.41432 .36184 .42081 .36731 .43175 .36356 .42529 .35805 Mtetra
.42529 .35805 .43175 .36356 .44273 .35979 .43631 .35426 Mtetra
.651 .8 .954 r
.43631 .35426 .44273 .35979 .45376 .35601 .44737 .35046 Mtetra
.44737 .35046 .45376 .35601 .46483 .35223 .45847 .34666 Mtetra
.65 .8 .955 r
.45847 .34666 .46483 .35223 .47595 .34843 .46962 .34285 Mtetra
.65 .801 .955 r
.46962 .34285 .47595 .34843 .48711 .34462 .48082 .33903 Mtetra
.649 .801 .956 r
.48082 .33903 .48711 .34462 .49832 .3408 .49206 .33521 Mtetra
.648 .802 .957 r
.49206 .33521 .49832 .3408 .50957 .33697 .50335 .33139 Mtetra
.648 .803 .958 r
.50335 .33139 .50957 .33697 .52087 .33313 .51469 .32756 Mtetra
.647 .804 .958 r
.51469 .32756 .52087 .33313 .53222 .32928 .52607 .32372 Mtetra
.646 .805 .959 r
.52607 .32372 .53222 .32928 .54362 .32542 .53751 .31987 Mtetra
.646 .807 .961 r
.53751 .31987 .54362 .32542 .55506 .32154 .54899 .31602 Mtetra
.645 .808 .962 r
.54899 .31602 .55506 .32154 .56655 .31766 .56052 .31216 Mtetra
.644 .81 .963 r
.56052 .31216 .56655 .31766 .57809 .31377 .5721 .30829 Mtetra
.644 .812 .964 r
.5721 .30829 .57809 .31377 .58968 .30986 .58372 .3044 Mtetra
.643 .813 .965 r
.58372 .3044 .58968 .30986 .60131 .30594 .5954 .3005 Mtetra
.643 .815 .966 r
.5954 .3005 .60131 .30594 .613 .30201 .60713 .29658 Mtetra
.643 .816 .966 r
.60713 .29658 .613 .30201 .62474 .29806 .61891 .29263 Mtetra
.643 .818 .967 r
.61891 .29263 .62474 .29806 .63652 .29409 .63073 .28865 Mtetra
.644 .819 .967 r
.63073 .28865 .63652 .29409 .64836 .2901 .64261 .28464 Mtetra
.645 .819 .967 r
.64261 .28464 .64836 .2901 .66024 .28608 .65454 .28057 Mtetra
.647 .819 .966 r
.65454 .28057 .66024 .28608 .67218 .28203 .66652 .27645 Mtetra
.65 .819 .964 r
.66652 .27645 .67218 .28203 .68417 .27795 .67854 .27226 Mtetra
.653 .817 .962 r
.67854 .27226 .68417 .27795 .6962 .27381 .69062 .26799 Mtetra
.658 .815 .959 r
.69062 .26799 .6962 .27381 .70829 .26963 .70273 .26362 Mtetra
.662 .811 .955 r
.70273 .26362 .70829 .26963 .72042 .26538 .7149 .25914 Mtetra
.667 .806 .95 r
.7149 .25914 .72042 .26538 .7326 .26106 .72711 .25456 Mtetra
.671 .8 .943 r
.72711 .25456 .7326 .26106 .74483 .25667 .73936 .24986 Mtetra
.675 .791 .936 r
.73936 .24986 .74483 .25667 .7571 .25221 .75165 .24506 Mtetra
.677 .782 .929 r
.75165 .24506 .7571 .25221 .76943 .24769 .76399 .24017 Mtetra
.679 .772 .921 r
.76399 .24017 .76943 .24769 .7818 .24311 .77637 .23521 Mtetra
.598 .735 .941 r
.11732 .45366 .12449 .45992 .13423 .45718 .12701 .45148 Mtetra
.596 .755 .954 r
.12701 .45148 .13423 .45718 .14402 .45437 .13675 .44924 Mtetra
.593 .776 .967 r
.13675 .44924 .14402 .45437 .15385 .45149 .14654 .44692 Mtetra
.591 .797 .978 r
.14654 .44692 .15385 .45149 .16374 .44852 .15639 .44448 Mtetra
.59 .817 .986 r
.15639 .44448 .16374 .44852 .17367 .44545 .16629 .44189 Mtetra
.588 .836 .992 r
.16629 .44189 .17367 .44545 .18366 .44227 .17626 .43916 Mtetra
.587 .852 .994 r
.17626 .43916 .18366 .44227 .19369 .439 .18629 .43626 Mtetra
.586 .865 .995 r
.18629 .43626 .19369 .439 .20378 .43563 .19637 .43321 Mtetra
.584 .876 .994 r
.19637 .43321 .20378 .43563 .2139 .4322 .20651 .43002 Mtetra
.583 .884 .992 r
.20651 .43002 .2139 .4322 .22408 .4287 .2167 .4267 Mtetra
.583 .89 .989 r
.2167 .4267 .22408 .4287 .2343 .42514 .22694 .42328 Mtetra
.584 .895 .988 r
.22694 .42328 .2343 .42514 .24455 .42155 .23722 .41976 Mtetra
.584 .898 .986 r
.23722 .41976 .24455 .42155 .25486 .41792 .24756 .41617 Mtetra
.586 .9 .985 r
.24756 .41617 .25486 .41792 .2652 .41426 .25794 .41251 Mtetra
.588 .901 .985 r
.25794 .41251 .2652 .41426 .27558 .41058 .26836 .40879 Mtetra
.591 .902 .985 r
.26836 .40879 .27558 .41058 .28601 .40688 .27883 .40504 Mtetra
.594 .902 .985 r
.27883 .40504 .28601 .40688 .29647 .40316 .28934 .40125 Mtetra
.597 .901 .986 r
.28934 .40125 .29647 .40316 .30698 .39944 .29989 .39744 Mtetra
.599 .9 .986 r
.29989 .39744 .30698 .39944 .31752 .39571 .31048 .39361 Mtetra
.602 .899 .987 r
.31048 .39361 .31752 .39571 .32811 .39197 .32111 .38977 Mtetra
.604 .897 .988 r
.32111 .38977 .32811 .39197 .33874 .38822 .33179 .38592 Mtetra
.606 .895 .988 r
.33179 .38592 .33874 .38822 .34941 .38446 .3425 .38206 Mtetra
.608 .894 .989 r
.3425 .38206 .34941 .38446 .36012 .38071 .35326 .37821 Mtetra
.609 .892 .989 r
.35326 .37821 .36012 .38071 .37088 .37694 .36406 .37436 Mtetra
.61 .89 .989 r
.36406 .37436 .37088 .37694 .38167 .37317 .3749 .37051 Mtetra
.61 .888 .99 r
.3749 .37051 .38167 .37317 .39251 .3694 .38578 .36666 Mtetra
.61 .887 .99 r
.38578 .36666 .39251 .3694 .4034 .36562 .39671 .36282 Mtetra
.61 .885 .99 r
.39671 .36282 .4034 .36562 .41432 .36184 .40768 .35899 Mtetra
.609 .884 .99 r
.40768 .35899 .41432 .36184 .42529 .35805 .41869 .35517 Mtetra
.608 .883 .991 r
.41869 .35517 .42529 .35805 .43631 .35426 .42975 .35135 Mtetra
.607 .883 .991 r
.42975 .35135 .43631 .35426 .44737 .35046 .44085 .34754 Mtetra
.605 .883 .991 r
.44085 .34754 .44737 .35046 .45847 .34666 .452 .34373 Mtetra
.602 .883 .991 r
.452 .34373 .45847 .34666 .46962 .34285 .46319 .33993 Mtetra
.6 .883 .991 r
.46319 .33993 .46962 .34285 .48082 .33903 .47443 .33614 Mtetra
.597 .884 .991 r
.47443 .33614 .48082 .33903 .49206 .33521 .48572 .33235 Mtetra
.594 .885 .991 r
.48572 .33235 .49206 .33521 .50335 .33139 .49706 .32856 Mtetra
.59 .885 .991 r
.49706 .32856 .50335 .33139 .51469 .32756 .50844 .32478 Mtetra
.587 .886 .991 r
.50844 .32478 .51469 .32756 .52607 .32372 .51987 .32099 Mtetra
.583 .888 .99 r
.51987 .32099 .52607 .32372 .53751 .31987 .53135 .3172 Mtetra
.579 .889 .99 r
.53135 .3172 .53751 .31987 .54899 .31602 .54288 .3134 Mtetra
.576 .89 .989 r
.54288 .3134 .54899 .31602 .56052 .31216 .55446 .30959 Mtetra
.573 .891 .988 r
.55446 .30959 .56052 .31216 .5721 .30829 .56609 .30576 Mtetra
.571 .892 .987 r
.56609 .30576 .5721 .30829 .58372 .3044 .57777 .3019 Mtetra
.57 .893 .986 r
.57777 .3019 .58372 .3044 .5954 .3005 .5895 .298 Mtetra
.571 .895 .986 r
.5895 .298 .5954 .3005 .60713 .29658 .60128 .29406 Mtetra
.573 .896 .985 r
.60128 .29406 .60713 .29658 .61891 .29263 .61311 .29007 Mtetra
.577 .897 .985 r
.61311 .29007 .61891 .29263 .63073 .28865 .62499 .286 Mtetra
.584 .898 .986 r
.62499 .286 .63073 .28865 .64261 .28464 .63691 .28185 Mtetra
.594 .898 .987 r
.63691 .28185 .64261 .28464 .65454 .28057 .64889 .27761 Mtetra
.605 .898 .987 r
.64889 .27761 .65454 .28057 .66652 .27645 .66091 .27324 Mtetra
.619 .896 .987 r
.66091 .27324 .66652 .27645 .67854 .27226 .67297 .26875 Mtetra
.635 .892 .986 r
.67297 .26875 .67854 .27226 .69062 .26799 .68508 .2641 Mtetra
.651 .886 .983 r
.68508 .2641 .69062 .26799 .70273 .26362 .69723 .25928 Mtetra
.666 .876 .977 r
.69723 .25928 .70273 .26362 .7149 .25914 .70941 .2543 Mtetra
.679 .863 .969 r
.70941 .2543 .7149 .25914 .72711 .25456 .72164 .24915 Mtetra
.689 .847 .958 r
.72164 .24915 .72711 .25456 .73936 .24986 .7339 .24383 Mtetra
.696 .828 .946 r
.7339 .24383 .73936 .24986 .75165 .24506 .74619 .23839 Mtetra
.699 .808 .933 r
.74619 .23839 .75165 .24506 .76399 .24017 .75853 .23286 Mtetra
.7 .788 .919 r
.75853 .23286 .76399 .24017 .77637 .23521 .7709 .22725 Mtetra
.562 .724 .95 r
.1101 .44736 .11732 .45366 .12701 .45148 .11973 .44579 Mtetra
.555 .744 .965 r
.11973 .44579 .12701 .45148 .13675 .44924 .12941 .44418 Mtetra
.548 .766 .978 r
.12941 .44418 .13675 .44924 .14654 .44692 .13914 .4425 Mtetra
.54 .788 .99 r
.13914 .4425 .14654 .44692 .15639 .44448 .14894 .44071 Mtetra
.533 .81 .997 r
.14894 .44071 .15639 .44448 .16629 .44189 .1588 .43875 Mtetra
.524 .831 1 r
.1588 .43875 .16629 .44189 .17626 .43916 .16873 .43663 Mtetra
.516 .849 .997 r
.16873 .43663 .17626 .43916 .18629 .43626 .17872 .43429 Mtetra
.505 .862 .989 r
.17872 .43429 .18629 .43626 .19637 .43321 .18879 .43176 Mtetra
.495 .872 .977 r
.18879 .43176 .19637 .43321 .20651 .43002 .19891 .42901 Mtetra
.484 .878 .963 r
.19891 .42901 .20651 .43002 .2167 .4267 .2091 .42609 Mtetra
.474 .88 .947 r
.2091 .42609 .2167 .4267 .22694 .42328 .21935 .42298 Mtetra
.464 .881 .932 r
.21935 .42298 .22694 .42328 .23722 .41976 .22966 .41973 Mtetra
.456 .88 .918 r
.22966 .41973 .23722 .41976 .24756 .41617 .24002 .41634 Mtetra
.449 .879 .905 r
.24002 .41634 .24756 .41617 .25794 .41251 .25043 .41284 Mtetra
.444 .877 .895 r
.25043 .41284 .25794 .41251 .26836 .40879 .26088 .40925 Mtetra
.44 .876 .887 r
.26088 .40925 .26836 .40879 .27883 .40504 .27139 .40557 Mtetra
.438 .875 .881 r
.27139 .40557 .27883 .40504 .28934 .40125 .28194 .40183 Mtetra
.436 .875 .877 r
.28194 .40183 .28934 .40125 .29989 .39744 .29254 .39804 Mtetra
.435 .875 .875 r
.29254 .39804 .29989 .39744 .31048 .39361 .30318 .3942 Mtetra
.435 .875 .874 r
.30318 .3942 .31048 .39361 .32111 .38977 .31386 .39034 Mtetra
.436 .875 .874 r
.31386 .39034 .32111 .38977 .33179 .38592 .32459 .38646 Mtetra
.436 .875 .875 r
.32459 .38646 .33179 .38592 .3425 .38206 .33535 .38256 Mtetra
.437 .875 .876 r
.33535 .38256 .3425 .38206 .35326 .37821 .34616 .37866 Mtetra
.437 .876 .877 r
.34616 .37866 .35326 .37821 .36406 .37436 .35701 .37476 Mtetra
.437 .876 .879 r
.35701 .37476 .36406 .37436 .3749 .37051 .36791 .37086 Mtetra
.437 .875 .88 r
.36791 .37086 .3749 .37051 .38578 .36666 .37884 .36697 Mtetra
.436 .875 .881 r
.37884 .36697 .38578 .36666 .39671 .36282 .38982 .36309 Mtetra
.435 .874 .882 r
.38982 .36309 .39671 .36282 .40768 .35899 .40085 .35923 Mtetra
.433 .873 .882 r
.40085 .35923 .40768 .35899 .41869 .35517 .41191 .35537 Mtetra
.431 .872 .882 r
.41191 .35537 .41869 .35517 .42975 .35135 .42302 .35153 Mtetra
.428 .87 .881 r
.42302 .35153 .42975 .35135 .44085 .34754 .43418 .3477 Mtetra
.424 .868 .88 r
.43418 .3477 .44085 .34754 .452 .34373 .44538 .34389 Mtetra
.42 .866 .878 r
.44538 .34389 .452 .34373 .46319 .33993 .45663 .34008 Mtetra
.416 .864 .876 r
.45663 .34008 .46319 .33993 .47443 .33614 .46793 .33629 Mtetra
.412 .862 .874 r
.46793 .33629 .47443 .33614 .48572 .33235 .47927 .33251 Mtetra
.408 .859 .871 r
.47927 .33251 .48572 .33235 .49706 .32856 .49066 .32872 Mtetra
.404 .857 .869 r
.49066 .32872 .49706 .32856 .50844 .32478 .5021 .32494 Mtetra
.401 .856 .866 r
.5021 .32494 .50844 .32478 .51987 .32099 .51359 .32115 Mtetra
.399 .855 .865 r
.51359 .32115 .51987 .32099 .53135 .3172 .52513 .31734 Mtetra
.398 .855 .864 r
.52513 .31734 .53135 .3172 .54288 .3134 .53672 .31352 Mtetra
.4 .855 .864 r
.53672 .31352 .54288 .3134 .55446 .30959 .54835 .30966 Mtetra
.404 .858 .867 r
.54835 .30966 .55446 .30959 .56609 .30576 .56004 .30576 Mtetra
.411 .861 .871 r
.56004 .30576 .56609 .30576 .57777 .3019 .57178 .30181 Mtetra
.422 .867 .877 r
.57178 .30181 .57777 .3019 .5895 .298 .58357 .29779 Mtetra
.436 .874 .886 r
.58357 .29779 .5895 .298 .60128 .29406 .59541 .29368 Mtetra
.455 .883 .897 r
.59541 .29368 .60128 .29406 .61311 .29007 .60729 .28948 Mtetra
.478 .893 .911 r
.60729 .28948 .61311 .29007 .62499 .286 .61923 .28515 Mtetra
.505 .904 .926 r
.61923 .28515 .62499 .286 .63691 .28185 .63121 .28068 Mtetra
.535 .914 .941 r
.63121 .28068 .63691 .28185 .64889 .27761 .64323 .27605 Mtetra
.568 .921 .956 r
.64323 .27605 .64889 .27761 .66091 .27324 .65529 .27124 Mtetra
.602 .925 .967 r
.65529 .27124 .66091 .27324 .67297 .26875 .66739 .26622 Mtetra
.634 .924 .975 r
.66739 .26622 .67297 .26875 .68508 .2641 .67953 .26099 Mtetra
.662 .917 .977 r
.67953 .26099 .68508 .2641 .69723 .25928 .6917 .25554 Mtetra
.686 .905 .973 r
.6917 .25554 .69723 .25928 .70941 .2543 .7039 .24986 Mtetra
.703 .887 .965 r
.7039 .24986 .70941 .2543 .72164 .24915 .71613 .244 Mtetra
.714 .866 .953 r
.71613 .244 .72164 .24915 .7339 .24383 .7284 .23796 Mtetra
.72 .843 .94 r
.7284 .23796 .7339 .24383 .74619 .23839 .74069 .23179 Mtetra
.722 .82 .926 r
.74069 .23179 .74619 .23839 .75853 .23286 .75302 .22553 Mtetra
.721 .797 .912 r
.75302 .22553 .75853 .23286 .7709 .22725 .76539 .21923 Mtetra
.532 .713 .955 r
.10283 .44102 .1101 .44736 .11973 .44579 .11242 .43989 Mtetra
.522 .726 .966 r
.11242 .43989 .11973 .44579 .12941 .44418 .12205 .43877 Mtetra
.512 .741 .978 r
.12205 .43877 .12941 .44418 .13914 .4425 .13173 .43765 Mtetra
.499 .758 .988 r
.13173 .43765 .13914 .4425 .14894 .44071 .14148 .43648 Mtetra
.484 .777 .996 r
.14148 .43648 .14894 .44071 .1588 .43875 .15128 .43524 Mtetra
.464 .795 .999 r
.15128 .43524 .1588 .43875 .16873 .43663 .16114 .43388 Mtetra
.44 .812 .993 r
.16114 .43388 .16873 .43663 .17872 .43429 .17108 .43237 Mtetra
.408 .821 .975 r
.17108 .43237 .17872 .43429 .18879 .43176 .18108 .43067 Mtetra
.371 .82 .94 r
.18108 .43067 .18879 .43176 .19891 .42901 .19116 .42876 Mtetra
.325 .806 .889 r
.19116 .42876 .19891 .42901 .2091 .42609 .20131 .42665 Mtetra
.276 .78 .826 r
.20131 .42665 .2091 .42609 .21935 .42298 .21153 .42432 Mtetra
.227 .745 .756 r
.21153 .42432 .21935 .42298 .22966 .41973 .22181 .42179 Mtetra
.18 .705 .684 r
.22181 .42179 .22966 .41973 .24002 .41634 .23215 .41907 Mtetra
0 0 0 r
.23215 .41907 .24002 .41634 .25043 .41284 .24256 .41619 Mtetra
.24256 .41619 .25043 .41284 .26088 .40925 .25303 .41314 Mtetra
.25303 .41314 .26088 .40925 .27139 .40557 .26355 .40996 Mtetra
.26355 .40996 .27139 .40557 .28194 .40183 .27413 .40665 Mtetra
.27413 .40665 .28194 .40183 .29254 .39804 .28476 .40324 Mtetra
.005 0 0 r
.28476 .40324 .29254 .39804 .30318 .3942 .29544 .39973 Mtetra
.022 0 0 r
.29544 .39973 .30318 .3942 .31386 .39034 .30617 .39614 Mtetra
.036 0 0 r
.30617 .39614 .31386 .39034 .32459 .38646 .31694 .39249 Mtetra
.048 0 0 r
.31694 .39249 .32459 .38646 .33535 .38256 .32777 .38878 Mtetra
.057 0 0 r
.32777 .38878 .33535 .38256 .34616 .37866 .33864 .38503 Mtetra
.066 0 0 r
.33864 .38503 .34616 .37866 .35701 .37476 .34955 .38125 Mtetra
.073 0 0 r
.34955 .38125 .35701 .37476 .36791 .37086 .36051 .37744 Mtetra
.078 0 0 r
.36051 .37744 .36791 .37086 .37884 .36697 .37152 .37362 Mtetra
.083 0 0 r
.37152 .37362 .37884 .36697 .38982 .36309 .38257 .36978 Mtetra
.087 0 0 r
.38257 .36978 .38982 .36309 .40085 .35923 .39366 .36593 Mtetra
.089 0 0 r
.39366 .36593 .40085 .35923 .41191 .35537 .40481 .36208 Mtetra
.091 0 0 r
.40481 .36208 .41191 .35537 .42302 .35153 .41599 .35822 Mtetra
.092 0 0 r
.41599 .35822 .42302 .35153 .43418 .3477 .42723 .35435 Mtetra
.42723 .35435 .43418 .3477 .44538 .34389 .43851 .35048 Mtetra
.09 0 0 r
.43851 .35048 .44538 .34389 .45663 .34008 .44984 .3466 Mtetra
.088 0 0 r
.44984 .3466 .45663 .34008 .46793 .33629 .46121 .34271 Mtetra
.083 0 0 r
.46121 .34271 .46793 .33629 .47927 .33251 .47264 .3388 Mtetra
.076 0 0 r
.47264 .3388 .47927 .33251 .49066 .32872 .48411 .33486 Mtetra
.067 0 0 r
.48411 .33486 .49066 .32872 .5021 .32494 .49563 .33089 Mtetra
.055 0 0 r
.49563 .33089 .5021 .32494 .51359 .32115 .5072 .32687 Mtetra
.04 0 0 r
.5072 .32687 .51359 .32115 .52513 .31734 .51882 .32279 Mtetra
.02 0 0 r
.51882 .32279 .52513 .31734 .53672 .31352 .53048 .31865 Mtetra
0 0 0 r
.53048 .31865 .53672 .31352 .54835 .30966 .5422 .31443 Mtetra
.5422 .31443 .54835 .30966 .56004 .30576 .55396 .3101 Mtetra
.55396 .3101 .56004 .30576 .57178 .30181 .56577 .30567 Mtetra
.56577 .30567 .57178 .30181 .58357 .29779 .57763 .3011 Mtetra
.57763 .3011 .58357 .29779 .59541 .29368 .58953 .29638 Mtetra
.58953 .29638 .59541 .29368 .60729 .28948 .60148 .2915 Mtetra
.315 .789 .697 r
.60148 .2915 .60729 .28948 .61923 .28515 .61346 .28644 Mtetra
.396 .847 .772 r
.61346 .28644 .61923 .28515 .63121 .28068 .62548 .28118 Mtetra
.477 .897 .842 r
.62548 .28118 .63121 .28068 .64323 .27605 .63754 .2757 Mtetra
.554 .931 .899 r
.63754 .2757 .64323 .27605 .65529 .27124 .64964 .27 Mtetra
.619 .948 .938 r
.64964 .27 .65529 .27124 .66739 .26622 .66176 .26407 Mtetra
.67 .946 .959 r
.66176 .26407 .66739 .26622 .67953 .26099 .67392 .25791 Mtetra
.703 .931 .964 r
.67392 .25791 .67953 .26099 .6917 .25554 .6861 .25156 Mtetra
.724 .908 .959 r
.6861 .25156 .6917 .25554 .7039 .24986 .69831 .24502 Mtetra
.735 .883 .948 r
.69831 .24502 .7039 .24986 .71613 .244 .71055 .23836 Mtetra
.739 .857 .936 r
.71055 .23836 .71613 .244 .7284 .23796 .72282 .23161 Mtetra
.739 .834 .923 r
.72282 .23161 .7284 .23796 .74069 .23179 .73512 .2248 Mtetra
.737 .814 .912 r
.73512 .2248 .74069 .23179 .75302 .22553 .74746 .21796 Mtetra
.734 .796 .902 r
.74746 .21796 .75302 .22553 .76539 .21923 .75983 .21113 Mtetra
.529 .712 .956 r
.09551 .43462 .10283 .44102 .11242 .43989 .1051 .43351 Mtetra
.523 .711 .957 r
.1051 .43351 .11242 .43989 .12205 .43877 .11474 .43248 Mtetra
.516 .712 .96 r
.11474 .43248 .12205 .43877 .13173 .43765 .12442 .43151 Mtetra
.509 .716 .965 r
.12442 .43151 .13173 .43765 .14148 .43648 .13414 .43059 Mtetra
.498 .721 .972 r
.13414 .43059 .14148 .43648 .15128 .43524 .14392 .42973 Mtetra
.488 .732 .98 r
.14392 .42973 .15128 .43524 .16114 .43388 .15374 .42887 Mtetra
.477 .747 .988 r
.15374 .42887 .16114 .43388 .17108 .43237 .16363 .42795 Mtetra
.464 .765 .995 r
.16363 .42795 .17108 .43237 .18108 .43067 .17358 .42694 Mtetra
.448 .784 .998 r
.17358 .42694 .18108 .43067 .19116 .42876 .18361 .42578 Mtetra
.427 .8 .993 r
.18361 .42578 .19116 .42876 .20131 .42665 .19371 .42444 Mtetra
.4 .811 .978 r
.19371 .42444 .20131 .42665 .21153 .42432 .20388 .4229 Mtetra
.366 .813 .948 r
.20388 .4229 .21153 .42432 .22181 .42179 .21412 .42116 Mtetra
.327 .804 .905 r
.21412 .42116 .22181 .42179 .23215 .41907 .22443 .41921 Mtetra
.283 .783 .85 r
.22443 .41921 .23215 .41907 .24256 .41619 .23482 .41706 Mtetra
.238 .754 .788 r
.23482 .41706 .24256 .41619 .25303 .41314 .24527 .41472 Mtetra
.193 .719 .722 r
.24527 .41472 .25303 .41314 .26355 .40996 .25578 .41219 Mtetra
0 0 0 r
.25578 .41219 .26355 .40996 .27413 .40665 .26636 .40949 Mtetra
.26636 .40949 .27413 .40665 .28476 .40324 .277 .40663 Mtetra
.277 .40663 .28476 .40324 .29544 .39973 .2877 .40362 Mtetra
.2877 .40362 .29544 .39973 .30617 .39614 .29846 .40048 Mtetra
.29846 .40048 .30617 .39614 .31694 .39249 .30927 .39722 Mtetra
.30927 .39722 .31694 .39249 .32777 .38878 .32014 .39386 Mtetra
.008 0 0 r
.32014 .39386 .32777 .38878 .33864 .38503 .33105 .3904 Mtetra
.022 0 0 r
.33105 .3904 .33864 .38503 .34955 .38125 .34202 .38686 Mtetra
.033 0 0 r
.34202 .38686 .34955 .38125 .36051 .37744 .35304 .38325 Mtetra
.042 0 0 r
.35304 .38325 .36051 .37744 .37152 .37362 .36411 .37957 Mtetra
.049 0 0 r
.36411 .37957 .37152 .37362 .38257 .36978 .37523 .37584 Mtetra
.053 0 0 r
.37523 .37584 .38257 .36978 .39366 .36593 .38639 .37206 Mtetra
.055 0 0 r
.38639 .37206 .39366 .36593 .40481 .36208 .39761 .36823 Mtetra
.39761 .36823 .40481 .36208 .41599 .35822 .40887 .36435 Mtetra
.052 0 0 r
.40887 .36435 .41599 .35822 .42723 .35435 .42018 .36043 Mtetra
.047 0 0 r
.42018 .36043 .42723 .35435 .43851 .35048 .43154 .35645 Mtetra
.039 0 0 r
.43154 .35645 .43851 .35048 .44984 .3466 .44295 .35243 Mtetra
.029 0 0 r
.44295 .35243 .44984 .3466 .46121 .34271 .45441 .34835 Mtetra
.014 0 0 r
.45441 .34835 .46121 .34271 .47264 .3388 .46591 .3442 Mtetra
0 0 0 r
.46591 .3442 .47264 .3388 .48411 .33486 .47746 .33998 Mtetra
.47746 .33998 .48411 .33486 .49563 .33089 .48906 .33567 Mtetra
.48906 .33567 .49563 .33089 .5072 .32687 .50071 .33127 Mtetra
.50071 .33127 .5072 .32687 .51882 .32279 .51241 .32675 Mtetra
.51241 .32675 .51882 .32279 .53048 .31865 .52415 .32211 Mtetra
.52415 .32211 .53048 .31865 .5422 .31443 .53594 .31734 Mtetra
.53594 .31734 .5422 .31443 .55396 .3101 .54777 .3124 Mtetra
.312 .786 .687 r
.54777 .3124 .55396 .3101 .56577 .30567 .55965 .3073 Mtetra
.384 .839 .755 r
.55965 .3073 .56577 .30567 .57763 .3011 .57156 .30202 Mtetra
.459 .886 .821 r
.57156 .30202 .57763 .3011 .58953 .29638 .58352 .29654 Mtetra
.531 .923 .877 r
.58352 .29654 .58953 .29638 .60148 .2915 .59551 .29085 Mtetra
.596 .945 .92 r
.59551 .29085 .60148 .2915 .61346 .28644 .60754 .28495 Mtetra
.649 .952 .948 r
.60754 .28495 .61346 .28644 .62548 .28118 .6196 .27882 Mtetra
.69 .945 .96 r
.6196 .27882 .62548 .28118 .63754 .2757 .63169 .27248 Mtetra
.718 .928 .961 r
.63169 .27248 .63754 .2757 .64964 .27 .64381 .26592 Mtetra
.735 .905 .953 r
.64381 .26592 .64964 .27 .66176 .26407 .65595 .25916 Mtetra
.745 .88 .942 r
.65595 .25916 .66176 .26407 .67392 .25791 .66813 .25224 Mtetra
.749 .856 .929 r
.66813 .25224 .67392 .25791 .6861 .25156 .68033 .2452 Mtetra
.748 .835 .917 r
.68033 .2452 .6861 .25156 .69831 .24502 .69256 .23809 Mtetra
.746 .817 .908 r
.69256 .23809 .69831 .24502 .71055 .23836 .70482 .23097 Mtetra
.742 .803 .901 r
.70482 .23097 .71055 .23836 .72282 .23161 .71711 .2239 Mtetra
.739 .793 .896 r
.71711 .2239 .72282 .23161 .73512 .2248 .72944 .21687 Mtetra
.735 .787 .894 r
.72944 .21687 .73512 .2248 .74746 .21796 .74181 .20989 Mtetra
.732 .783 .893 r
.74181 .20989 .74746 .21796 .75983 .21113 .75422 .20298 Mtetra
.584 .731 .944 r
.08813 .42819 .09551 .43462 .1051 .43351 .09786 .42617 Mtetra
.585 .702 .924 r
.09786 .42617 .1051 .43351 .11474 .43248 .10762 .42424 Mtetra
.583 .675 .904 r
.10762 .42424 .11474 .43248 .12442 .43151 .11741 .42242 Mtetra
.579 .651 .885 r
.11741 .42242 .12442 .43151 .13414 .43059 .12724 .42072 Mtetra
.573 .63 .87 r
.12724 .42072 .13414 .43059 .14392 .42973 .13709 .41919 Mtetra
.568 .613 .857 r
.13709 .41919 .14392 .42973 .15374 .42887 .14698 .4178 Mtetra
.564 .6 .848 r
.14698 .4178 .15374 .42887 .16363 .42795 .15691 .41651 Mtetra
.562 .592 .841 r
.15691 .41651 .16363 .42795 .17358 .42694 .16689 .41529 Mtetra
.561 .588 .838 r
.16689 .41529 .17358 .42694 .18361 .42578 .17692 .41408 Mtetra
.562 .588 .837 r
.17692 .41408 .18361 .42578 .19371 .42444 .187 .41284 Mtetra
.564 .592 .84 r
.187 .41284 .19371 .42444 .20388 .4229 .19715 .41153 Mtetra
.567 .599 .844 r
.19715 .41153 .20388 .4229 .21412 .42116 .20736 .41013 Mtetra
.571 .608 .851 r
.20736 .41013 .21412 .42116 .22443 .41921 .21764 .40861 Mtetra
.575 .62 .86 r
.21764 .40861 .22443 .41921 .23482 .41706 .22798 .40696 Mtetra
.58 .635 .87 r
.22798 .40696 .23482 .41706 .24527 .41472 .2384 .40517 Mtetra
.584 .651 .882 r
.2384 .40517 .24527 .41472 .25578 .41219 .24887 .40323 Mtetra
.589 .669 .895 r
.24887 .40323 .25578 .41219 .26636 .40949 .25942 .40115 Mtetra
.593 .689 .908 r
.25942 .40115 .26636 .40949 .277 .40663 .27002 .39891 Mtetra
.597 .71 .922 r
.27002 .39891 .277 .40663 .2877 .40362 .2807 .39652 Mtetra
.601 .731 .936 r
.2807 .39652 .2877 .40362 .29846 .40048 .29143 .39397 Mtetra
.604 .753 .949 r
.29143 .39397 .29846 .40048 .30927 .39722 .30223 .39128 Mtetra
.606 .773 .961 r
.30223 .39128 .30927 .39722 .32014 .39386 .31309 .38844 Mtetra
.607 .793 .97 r
.31309 .38844 .32014 .39386 .33105 .3904 .32401 .38545 Mtetra
.607 .811 .978 r
.32401 .38545 .33105 .3904 .34202 .38686 .33498 .38233 Mtetra
.608 .827 .984 r
.33498 .38233 .34202 .38686 .35304 .38325 .34602 .37907 Mtetra
.608 .84 .988 r
.34602 .37907 .35304 .38325 .36411 .37957 .35711 .37567 Mtetra
.608 .851 .99 r
.35711 .37567 .36411 .37957 .37523 .37584 .36825 .37215 Mtetra
.61 .86 .991 r
.36825 .37215 .37523 .37584 .38639 .37206 .37945 .36849 Mtetra
.613 .866 .991 r
.37945 .36849 .38639 .37206 .39761 .36823 .3907 .36472 Mtetra
.618 .871 .99 r
.3907 .36472 .39761 .36823 .40887 .36435 .40201 .36081 Mtetra
.624 .873 .988 r
.40201 .36081 .40887 .36435 .42018 .36043 .41337 .35678 Mtetra
.633 .872 .987 r
.41337 .35678 .42018 .36043 .43154 .35645 .42477 .35262 Mtetra
.642 .87 .984 r
.42477 .35262 .43154 .35645 .44295 .35243 .43623 .34834 Mtetra
.652 .864 .98 r
.43623 .34834 .44295 .35243 .45441 .34835 .44774 .34392 Mtetra
.662 .856 .974 r
.44774 .34392 .45441 .34835 .46591 .3442 .45929 .33936 Mtetra
.672 .846 .966 r
.45929 .33936 .46591 .3442 .47746 .33998 .47089 .33466 Mtetra
.68 .833 .957 r
.47089 .33466 .47746 .33998 .48906 .33567 .48254 .32982 Mtetra
.687 .817 .945 r
.48254 .32982 .48906 .33567 .50071 .33127 .49423 .32483 Mtetra
.692 .8 .932 r
.49423 .32483 .50071 .33127 .51241 .32675 .50597 .31968 Mtetra
.696 .782 .917 r
.50597 .31968 .51241 .32675 .52415 .32211 .51775 .31437 Mtetra
.699 .764 .902 r
.51775 .31437 .52415 .32211 .53594 .31734 .52957 .30891 Mtetra
.7 .746 .887 r
.52957 .30891 .53594 .31734 .54777 .3124 .54143 .30327 Mtetra
.7 .728 .872 r
.54143 .30327 .54777 .3124 .55965 .3073 .55333 .29748 Mtetra
.699 .712 .858 r
.55333 .29748 .55965 .3073 .57156 .30202 .56527 .29152 Mtetra
.698 .697 .845 r
.56527 .29152 .57156 .30202 .58352 .29654 .57724 .28541 Mtetra
.697 .684 .834 r
.57724 .28541 .58352 .29654 .59551 .29085 .58924 .27914 Mtetra
.696 .673 .824 r
.58924 .27914 .59551 .29085 .60754 .28495 .60128 .27273 Mtetra
.695 .664 .815 r
.60128 .27273 .60754 .28495 .6196 .27882 .61335 .26619 Mtetra
.694 .657 .809 r
.61335 .26619 .6196 .27882 .63169 .27248 .62545 .25954 Mtetra
.694 .652 .804 r
.62545 .25954 .63169 .27248 .64381 .26592 .63759 .2528 Mtetra
.693 .65 .802 r
.63759 .2528 .64381 .26592 .65595 .25916 .64975 .24602 Mtetra
.693 .65 .803 r
.64975 .24602 .65595 .25916 .66813 .25224 .66195 .23925 Mtetra
.693 .653 .806 r
.66195 .23925 .66813 .25224 .68033 .2452 .67419 .23253 Mtetra
.693 .659 .812 r
.67419 .23253 .68033 .2452 .69256 .23809 .68647 .22591 Mtetra
.693 .668 .821 r
.68647 .22591 .69256 .23809 .70482 .23097 .6988 .21942 Mtetra
.694 .681 .834 r
.6988 .21942 .70482 .23097 .71711 .2239 .71117 .21309 Mtetra
.696 .699 .848 r
.71117 .21309 .71711 .2239 .72944 .21687 .72359 .20688 Mtetra
.699 .719 .866 r
.72359 .20688 .72944 .21687 .74181 .20989 .73605 .20078 Mtetra
.701 .744 .884 r
.73605 .20078 .74181 .20989 .75422 .20298 .74857 .19475 Mtetra
.651 .75 .922 r
.0807 .4217 .08813 .42819 .09786 .42617 .09063 .41828 Mtetra
.646 .708 .892 r
.09063 .41828 .09786 .42617 .10762 .42424 .10059 .41492 Mtetra
.638 .669 .863 r
.10059 .41492 .10762 .42424 .11741 .42242 .11057 .41169 Mtetra
.627 .634 .838 r
.11057 .41169 .11741 .42242 .12724 .42072 .12057 .40863 Mtetra
.615 .603 .816 r
.12057 .40863 .12724 .42072 .13709 .41919 .13058 .4058 Mtetra
.604 .577 .797 r
.13058 .4058 .13709 .41919 .14698 .4178 .14061 .40319 Mtetra
.594 .555 .781 r
.14061 .40319 .14698 .4178 .15691 .41651 .15065 .40085 Mtetra
.585 .537 .768 r
.15065 .40085 .15691 .41651 .16689 .41529 .16071 .39871 Mtetra
.578 .523 .757 r
.16071 .39871 .16689 .41529 .17692 .41408 .17081 .39676 Mtetra
.574 .513 .749 r
.17081 .39676 .17692 .41408 .187 .41284 .18094 .39495 Mtetra
.57 .506 .743 r
.18094 .39495 .187 .41284 .19715 .41153 .19111 .39322 Mtetra
.568 .501 .74 r
.19111 .39322 .19715 .41153 .20736 .41013 .20133 .39154 Mtetra
.568 .498 .737 r
.20133 .39154 .20736 .41013 .21764 .40861 .2116 .38988 Mtetra
.568 .498 .736 r
.2116 .38988 .21764 .40861 .22798 .40696 .22193 .38819 Mtetra
.22193 .38819 .22798 .40696 .2384 .40517 .23231 .38647 Mtetra
.57 .5 .737 r
.23231 .38647 .2384 .40517 .24887 .40323 .24276 .38468 Mtetra
.572 .503 .739 r
.24276 .38468 .24887 .40323 .25942 .40115 .25327 .38281 Mtetra
.574 .507 .742 r
.25327 .38281 .25942 .40115 .27002 .39891 .26384 .38084 Mtetra
.577 .512 .745 r
.26384 .38084 .27002 .39891 .2807 .39652 .27447 .37875 Mtetra
.581 .517 .749 r
.27447 .37875 .2807 .39652 .29143 .39397 .28517 .37652 Mtetra
.585 .523 .752 r
.28517 .37652 .29143 .39397 .30223 .39128 .29593 .37416 Mtetra
.589 .53 .756 r
.29593 .37416 .30223 .39128 .31309 .38844 .30675 .37164 Mtetra
.593 .536 .76 r
.30675 .37164 .31309 .38844 .32401 .38545 .31764 .36895 Mtetra
.598 .542 .764 r
.31764 .36895 .32401 .38545 .33498 .38233 .3286 .3661 Mtetra
.602 .549 .767 r
.3286 .3661 .33498 .38233 .34602 .37907 .33961 .36307 Mtetra
.607 .554 .77 r
.33961 .36307 .34602 .37907 .35711 .37567 .35069 .35987 Mtetra
.611 .56 .772 r
.35069 .35987 .35711 .37567 .36825 .37215 .36182 .35648 Mtetra
.616 .564 .773 r
.36182 .35648 .36825 .37215 .37945 .36849 .37301 .35291 Mtetra
.62 .568 .774 r
.37301 .35291 .37945 .36849 .3907 .36472 .38426 .34916 Mtetra
.624 .571 .774 r
.38426 .34916 .3907 .36472 .40201 .36081 .39557 .34521 Mtetra
.628 .573 .773 r
.39557 .34521 .40201 .36081 .41337 .35678 .40693 .34108 Mtetra
.631 .574 .772 r
.40693 .34108 .41337 .35678 .42477 .35262 .41834 .33677 Mtetra
.634 .574 .769 r
.41834 .33677 .42477 .35262 .43623 .34834 .4298 .33227 Mtetra
.637 .573 .767 r
.4298 .33227 .43623 .34834 .44774 .34392 .44132 .32758 Mtetra
.639 .572 .763 r
.44132 .32758 .44774 .34392 .45929 .33936 .45288 .32271 Mtetra
.641 .57 .759 r
.45288 .32271 .45929 .33936 .47089 .33466 .46449 .31766 Mtetra
.642 .567 .755 r
.46449 .31766 .47089 .33466 .48254 .32982 .47614 .31243 Mtetra
.643 .564 .75 r
.47614 .31243 .48254 .32982 .49423 .32483 .48783 .30704 Mtetra
.644 .561 .746 r
.48783 .30704 .49423 .32483 .50597 .31968 .49957 .30148 Mtetra
.645 .557 .742 r
.49957 .30148 .50597 .31968 .51775 .31437 .51135 .29576 Mtetra
.645 .554 .737 r
.51135 .29576 .51775 .31437 .52957 .30891 .52316 .28991 Mtetra
.645 .551 .734 r
.52316 .28991 .52957 .30891 .54143 .30327 .53501 .28393 Mtetra
.645 .548 .73 r
.53501 .28393 .54143 .30327 .55333 .29748 .5469 .27783 Mtetra
.645 .546 .728 r
.5469 .27783 .55333 .29748 .56527 .29152 .55883 .27164 Mtetra
.645 .544 .726 r
.55883 .27164 .56527 .29152 .57724 .28541 .57079 .26538 Mtetra
.645 .543 .725 r
.57079 .26538 .57724 .28541 .58924 .27914 .58278 .25906 Mtetra
.645 .543 .724 r
.58278 .25906 .58924 .27914 .60128 .27273 .59482 .25272 Mtetra
.645 .544 .725 r
.59482 .25272 .60128 .27273 .61335 .26619 .60688 .24638 Mtetra
.645 .546 .728 r
.60688 .24638 .61335 .26619 .62545 .25954 .61899 .24009 Mtetra
.645 .549 .731 r
.61899 .24009 .62545 .25954 .63759 .2528 .63114 .23387 Mtetra
.646 .554 .737 r
.63114 .23387 .63759 .2528 .64975 .24602 .64333 .22777 Mtetra
.646 .561 .745 r
.64333 .22777 .64975 .24602 .66195 .23925 .65557 .22187 Mtetra
.646 .57 .756 r
.65557 .22187 .66195 .23925 .67419 .23253 .66786 .21617 Mtetra
.646 .583 .769 r
.66786 .21617 .67419 .23253 .68647 .22591 .68021 .21074 Mtetra
.647 .599 .786 r
.68021 .21074 .68647 .22591 .6988 .21942 .69261 .20553 Mtetra
.649 .619 .807 r
.69261 .20553 .6988 .21942 .71117 .21309 .70509 .20056 Mtetra
.651 .644 .83 r
.70509 .20056 .71117 .21309 .72359 .20688 .71762 .19576 Mtetra
.654 .675 .858 r
.71762 .19576 .72359 .20688 .73605 .20078 .73022 .19107 Mtetra
.657 .711 .888 r
.73022 .19107 .73605 .20078 .74857 .19475 .74288 .18646 Mtetra
.704 .761 .897 r
.07322 .41517 .0807 .4217 .09063 .41828 .08336 .41027 Mtetra
.694 .719 .868 r
.08336 .41027 .09063 .41828 .10059 .41492 .09354 .4054 Mtetra
.682 .68 .842 r
.09354 .4054 .10059 .41492 .11057 .41169 .10373 .40062 Mtetra
.669 .645 .817 r
.10373 .40062 .11057 .41169 .12057 .40863 .11393 .39597 Mtetra
.655 .613 .795 r
.11393 .39597 .12057 .40863 .13058 .4058 .12415 .3915 Mtetra
.641 .583 .774 r
.12415 .3915 .13058 .4058 .14061 .40319 .13437 .38724 Mtetra
.628 .557 .755 r
.13437 .38724 .14061 .40319 .15065 .40085 .1446 .38321 Mtetra
.617 .534 .738 r
.1446 .38321 .15065 .40085 .16071 .39871 .15485 .37941 Mtetra
.606 .513 .723 r
.15485 .37941 .16071 .39871 .17081 .39676 .1651 .37583 Mtetra
.597 .496 .71 r
.1651 .37583 .17081 .39676 .18094 .39495 .17538 .37243 Mtetra
.59 .481 .698 r
.17538 .37243 .18094 .39495 .19111 .39322 .18568 .36919 Mtetra
.584 .469 .688 r
.18568 .36919 .19111 .39322 .20133 .39154 .19601 .36608 Mtetra
.58 .458 .679 r
.19601 .36608 .20133 .39154 .2116 .38988 .20637 .36306 Mtetra
.576 .45 .671 r
.20637 .36306 .2116 .38988 .22193 .38819 .21677 .36011 Mtetra
.573 .442 .665 r
.21677 .36011 .22193 .38819 .23231 .38647 .22722 .35721 Mtetra
.57 .436 .659 r
.22722 .35721 .23231 .38647 .24276 .38468 .23771 .35434 Mtetra
.568 .431 .654 r
.23771 .35434 .24276 .38468 .25327 .38281 .24824 .35148 Mtetra
.567 .427 .65 r
.24824 .35148 .25327 .38281 .26384 .38084 .25883 .34861 Mtetra
.566 .423 .646 r
.25883 .34861 .26384 .38084 .27447 .37875 .26947 .34571 Mtetra
.565 .421 .643 r
.26947 .34571 .27447 .37875 .28517 .37652 .28015 .34277 Mtetra
.565 .418 .641 r
.28015 .34277 .28517 .37652 .29593 .37416 .29089 .33977 Mtetra
.565 .417 .639 r
.29089 .33977 .29593 .37416 .30675 .37164 .30169 .3367 Mtetra
.565 .416 .637 r
.30169 .3367 .30675 .37164 .31764 .36895 .31254 .33354 Mtetra
.566 .415 .635 r
.31254 .33354 .31764 .36895 .3286 .3661 .32345 .33028 Mtetra
.566 .414 .634 r
.32345 .33028 .3286 .3661 .33961 .36307 .33441 .32692 Mtetra
.567 .414 .633 r
.33441 .32692 .33961 .36307 .35069 .35987 .34542 .32344 Mtetra
.568 .414 .633 r
.34542 .32344 .35069 .35987 .36182 .35648 .35649 .31983 Mtetra
.569 .415 .632 r
.35649 .31983 .36182 .35648 .37301 .35291 .36762 .3161 Mtetra
.57 .415 .632 r
.36762 .3161 .37301 .35291 .38426 .34916 .3788 .31224 Mtetra
.571 .416 .632 r
.3788 .31224 .38426 .34916 .39557 .34521 .39003 .30824 Mtetra
.573 .417 .632 r
.39003 .30824 .39557 .34521 .40693 .34108 .40132 .30411 Mtetra
.574 .418 .632 r
.40132 .30411 .40693 .34108 .41834 .33677 .41265 .29984 Mtetra
.575 .419 .632 r
.41265 .29984 .41834 .33677 .4298 .33227 .42403 .29545 Mtetra
.577 .42 .632 r
.42403 .29545 .4298 .33227 .44132 .32758 .43547 .29093 Mtetra
.578 .422 .633 r
.43547 .29093 .44132 .32758 .45288 .32271 .44695 .28629 Mtetra
.58 .424 .634 r
.44695 .28629 .45288 .32271 .46449 .31766 .45848 .28153 Mtetra
.581 .425 .635 r
.45848 .28153 .46449 .31766 .47614 .31243 .47005 .27668 Mtetra
.583 .428 .637 r
.47005 .27668 .47614 .31243 .48783 .30704 .48167 .27173 Mtetra
.584 .43 .638 r
.48167 .27173 .48783 .30704 .49957 .30148 .49333 .26671 Mtetra
.586 .433 .64 r
.49333 .26671 .49957 .30148 .51135 .29576 .50504 .26162 Mtetra
.587 .436 .643 r
.50504 .26162 .51135 .29576 .52316 .28991 .51678 .25649 Mtetra
.589 .439 .646 r
.51678 .25649 .52316 .28991 .53501 .28393 .52858 .25132 Mtetra
.59 .443 .649 r
.52858 .25132 .53501 .28393 .5469 .27783 .54041 .24613 Mtetra
.592 .447 .653 r
.54041 .24613 .5469 .27783 .55883 .27164 .55229 .24095 Mtetra
.594 .452 .658 r
.55229 .24095 .55883 .27164 .57079 .26538 .56422 .23579 Mtetra
.596 .458 .664 r
.56422 .23579 .57079 .26538 .58278 .25906 .57619 .23068 Mtetra
.597 .464 .67 r
.57619 .23068 .58278 .25906 .59482 .25272 .5882 .22564 Mtetra
.599 .471 .677 r
.5882 .22564 .59482 .25272 .60688 .24638 .60027 .22069 Mtetra
.601 .48 .686 r
.60027 .22069 .60688 .24638 .61899 .24009 .61239 .21586 Mtetra
.603 .489 .697 r
.61239 .21586 .61899 .24009 .63114 .23387 .62456 .21118 Mtetra
.604 .5 .709 r
.62456 .21118 .63114 .23387 .64333 .22777 .63679 .2067 Mtetra
.605 .513 .723 r
.63679 .2067 .64333 .22777 .65557 .22187 .64908 .20244 Mtetra
.607 .528 .74 r
.64908 .20244 .65557 .22187 .66786 .21617 .66144 .19841 Mtetra
.607 .545 .759 r
.66144 .19841 .66786 .21617 .68021 .21074 .67388 .19462 Mtetra
.608 .566 .781 r
.67388 .19462 .68021 .21074 .69261 .20553 .68638 .19104 Mtetra
.608 .589 .807 r
.68638 .19104 .69261 .20553 .70509 .20056 .69896 .18765 Mtetra
.608 .617 .834 r
.69896 .18765 .70509 .20056 .71762 .19576 .71161 .1844 Mtetra
.608 .649 .865 r
.71161 .1844 .71762 .19576 .73022 .19107 .72433 .18123 Mtetra
.607 .686 .898 r
.72433 .18123 .73022 .19107 .74288 .18646 .73713 .1781 Mtetra
.739 .766 .875 r
.06568 .40859 .07322 .41517 .08336 .41027 .07603 .4024 Mtetra
.729 .731 .853 r
.07603 .4024 .08336 .41027 .09354 .4054 .0864 .39621 Mtetra
.717 .699 .832 r
.0864 .39621 .09354 .4054 .10373 .40062 .09679 .39005 Mtetra
.704 .668 .812 r
.09679 .39005 .10373 .40062 .11393 .39597 .10719 .38397 Mtetra
.691 .639 .793 r
.10719 .38397 .11393 .39597 .12415 .3915 .1176 .37799 Mtetra
.678 .612 .774 r
.1176 .37799 .12415 .3915 .13437 .38724 .12802 .37214 Mtetra
.665 .586 .757 r
.12802 .37214 .13437 .38724 .1446 .38321 .13845 .36645 Mtetra
.653 .562 .741 r
.13845 .36645 .1446 .38321 .15485 .37941 .14888 .36094 Mtetra
.64 .541 .725 r
.14888 .36094 .15485 .37941 .1651 .37583 .15932 .35562 Mtetra
.63 .521 .711 r
.15932 .35562 .1651 .37583 .17538 .37243 .16977 .35048 Mtetra
.62 .503 .699 r
.16977 .35048 .17538 .37243 .18568 .36919 .18023 .34553 Mtetra
.612 .488 .688 r
.18023 .34553 .18568 .36919 .19601 .36608 .1907 .34072 Mtetra
.604 .475 .677 r
.1907 .34072 .19601 .36608 .20637 .36306 .2012 .33607 Mtetra
.598 .463 .669 r
.2012 .33607 .20637 .36306 .21677 .36011 .21171 .33154 Mtetra
.592 .453 .661 r
.21171 .33154 .21677 .36011 .22722 .35721 .22226 .32712 Mtetra
.587 .444 .654 r
.22226 .32712 .22722 .35721 .23771 .35434 .23282 .32281 Mtetra
.583 .436 .648 r
.23282 .32281 .23771 .35434 .24824 .35148 .24342 .3186 Mtetra
.58 .43 .642 r
.24342 .3186 .24824 .35148 .25883 .34861 .25405 .31446 Mtetra
.576 .424 .638 r
.25405 .31446 .25883 .34861 .26947 .34571 .26472 .3104 Mtetra
.574 .419 .634 r
.26472 .3104 .26947 .34571 .28015 .34277 .27542 .30639 Mtetra
.572 .415 .63 r
.27542 .30639 .28015 .34277 .29089 .33977 .28616 .30242 Mtetra
.57 .411 .627 r
.28616 .30242 .29089 .33977 .30169 .3367 .29694 .29849 Mtetra
.568 .408 .625 r
.29694 .29849 .30169 .3367 .31254 .33354 .30776 .29457 Mtetra
.567 .406 .622 r
.30776 .29457 .31254 .33354 .32345 .33028 .31863 .29065 Mtetra
.566 .404 .621 r
.31863 .29065 .32345 .33028 .33441 .32692 .32954 .28673 Mtetra
.566 .403 .619 r
.32954 .28673 .33441 .32692 .34542 .32344 .34049 .2828 Mtetra
.565 .402 .618 r
.34049 .2828 .34542 .32344 .35649 .31983 .35149 .27884 Mtetra
.565 .401 .617 r
.35149 .27884 .35649 .31983 .36762 .3161 .36254 .27485 Mtetra
.565 .4 .617 r
.36254 .27485 .36762 .3161 .3788 .31224 .37363 .27083 Mtetra
.37363 .27083 .3788 .31224 .39003 .30824 .38478 .26678 Mtetra
.38478 .26678 .39003 .30824 .40132 .30411 .39597 .26269 Mtetra
.566 .401 .617 r
.39597 .26269 .40132 .30411 .41265 .29984 .4072 .25856 Mtetra
.4072 .25856 .41265 .29984 .42403 .29545 .41849 .25441 Mtetra
.566 .402 .618 r
.41849 .25441 .42403 .29545 .43547 .29093 .42982 .25023 Mtetra
.567 .403 .619 r
.42982 .25023 .43547 .29093 .44695 .28629 .4412 .24603 Mtetra
.567 .405 .621 r
.4412 .24603 .44695 .28629 .45848 .28153 .45262 .24183 Mtetra
.568 .407 .623 r
.45262 .24183 .45848 .28153 .47005 .27668 .46409 .23763 Mtetra
.568 .409 .625 r
.46409 .23763 .47005 .27668 .48167 .27173 .47562 .23345 Mtetra
.569 .411 .627 r
.47562 .23345 .48167 .27173 .49333 .26671 .48719 .2293 Mtetra
.57 .414 .63 r
.48719 .2293 .49333 .26671 .50504 .26162 .4988 .22519 Mtetra
.57 .417 .634 r
.4988 .22519 .50504 .26162 .51678 .25649 .51047 .22113 Mtetra
.571 .42 .638 r
.51047 .22113 .51678 .25649 .52858 .25132 .52219 .21714 Mtetra
.572 .424 .643 r
.52219 .21714 .52858 .25132 .54041 .24613 .53397 .21324 Mtetra
.573 .429 .648 r
.53397 .21324 .54041 .24613 .55229 .24095 .54579 .20943 Mtetra
.573 .435 .654 r
.54579 .20943 .55229 .24095 .56422 .23579 .55768 .20572 Mtetra
.574 .441 .662 r
.55768 .20572 .56422 .23579 .57619 .23068 .56962 .20214 Mtetra
.575 .448 .67 r
.56962 .20214 .57619 .23068 .5882 .22564 .58162 .19868 Mtetra
.576 .456 .68 r
.58162 .19868 .5882 .22564 .60027 .22069 .59368 .19537 Mtetra
.576 .466 .691 r
.59368 .19537 .60027 .22069 .61239 .21586 .60581 .19222 Mtetra
.577 .476 .704 r
.60581 .19222 .61239 .21586 .62456 .21118 .61801 .18926 Mtetra
.577 .489 .718 r
.61801 .18926 .62456 .21118 .63679 .2067 .63029 .18649 Mtetra
.576 .503 .735 r
.63029 .18649 .63679 .2067 .64908 .20244 .64263 .18391 Mtetra
.575 .519 .755 r
.64263 .18391 .64908 .20244 .66144 .19841 .65506 .18153 Mtetra
.574 .537 .776 r
.65506 .18153 .66144 .19841 .67388 .19462 .66757 .17931 Mtetra
.573 .558 .799 r
.66757 .17931 .67388 .19462 .68638 .19104 .68015 .17723 Mtetra
.57 .581 .825 r
.68015 .17723 .68638 .19104 .69896 .18765 .69283 .17526 Mtetra
.567 .607 .852 r
.69283 .17526 .69896 .18765 .71161 .1844 .70558 .17337 Mtetra
.563 .635 .881 r
.70558 .17337 .71161 .1844 .72433 .18123 .71842 .17152 Mtetra
.557 .667 .91 r
.71842 .17152 .72433 .18123 .73713 .1781 .73134 .16968 Mtetra
.754 .768 .864 r
.05808 .40196 .06568 .40859 .07603 .4024 .06856 .39507 Mtetra
.748 .749 .853 r
.06856 .39507 .07603 .4024 .0864 .39621 .07905 .38817 Mtetra
.742 .732 .842 r
.07905 .38817 .0864 .39621 .09679 .39005 .08956 .38129 Mtetra
.734 .714 .832 r
.08956 .38129 .09679 .39005 .10719 .38397 .10008 .37447 Mtetra
.726 .697 .822 r
.10008 .37447 .10719 .38397 .1176 .37799 .1106 .36773 Mtetra
.718 .68 .813 r
.1106 .36773 .1176 .37799 .12802 .37214 .12114 .36111 Mtetra
.708 .664 .804 r
.12114 .36111 .12802 .37214 .13845 .36645 .13167 .35463 Mtetra
.699 .647 .795 r
.13167 .35463 .13845 .36645 .14888 .36094 .14221 .3483 Mtetra
.69 .631 .786 r
.14221 .3483 .14888 .36094 .15932 .35562 .15276 .34214 Mtetra
.681 .616 .776 r
.15276 .34214 .15932 .35562 .16977 .35048 .16331 .33615 Mtetra
.672 .601 .767 r
.16331 .33615 .16977 .35048 .18023 .34553 .17386 .33033 Mtetra
.663 .586 .759 r
.17386 .33033 .18023 .34553 .1907 .34072 .18443 .32465 Mtetra
.656 .573 .75 r
.18443 .32465 .1907 .34072 .2012 .33607 .19501 .31911 Mtetra
.648 .56 .742 r
.19501 .31911 .2012 .33607 .21171 .33154 .20561 .31371 Mtetra
.642 .548 .734 r
.20561 .31371 .21171 .33154 .22226 .32712 .21622 .30843 Mtetra
.635 .537 .726 r
.21622 .30843 .22226 .32712 .23282 .32281 .22686 .30327 Mtetra
.629 .527 .719 r
.22686 .30327 .23282 .32281 .24342 .3186 .23752 .29821 Mtetra
.624 .518 .713 r
.23752 .29821 .24342 .3186 .25405 .31446 .2482 .29327 Mtetra
.619 .509 .707 r
.2482 .29327 .25405 .31446 .26472 .3104 .25891 .28842 Mtetra
.615 .502 .701 r
.25891 .28842 .26472 .3104 .27542 .30639 .26965 .28366 Mtetra
.61 .494 .696 r
.26965 .28366 .27542 .30639 .28616 .30242 .28041 .279 Mtetra
.607 .488 .692 r
.28041 .279 .28616 .30242 .29694 .29849 .29121 .27441 Mtetra
.603 .483 .688 r
.29121 .27441 .29694 .29849 .30776 .29457 .30205 .26991 Mtetra
.6 .478 .684 r
.30205 .26991 .30776 .29457 .31863 .29065 .31291 .26547 Mtetra
.598 .473 .681 r
.31291 .26547 .31863 .29065 .32954 .28673 .32382 .26109 Mtetra
.596 .47 .679 r
.32382 .26109 .32954 .28673 .34049 .2828 .33476 .25678 Mtetra
.594 .467 .677 r
.33476 .25678 .34049 .2828 .35149 .27884 .34574 .25252 Mtetra
.592 .464 .676 r
.34574 .25252 .35149 .27884 .36254 .27485 .35676 .24832 Mtetra
.591 .463 .675 r
.35676 .24832 .36254 .27485 .37363 .27083 .36782 .24417 Mtetra
.589 .462 .674 r
.36782 .24417 .37363 .27083 .38478 .26678 .37892 .24007 Mtetra
.588 .461 .674 r
.37892 .24007 .38478 .26678 .39597 .26269 .39007 .23602 Mtetra
.588 .461 .675 r
.39007 .23602 .39597 .26269 .4072 .25856 .40126 .23202 Mtetra
.587 .461 .676 r
.40126 .23202 .4072 .25856 .41849 .25441 .41249 .22807 Mtetra
.586 .462 .678 r
.41249 .22807 .41849 .25441 .42982 .25023 .42378 .22418 Mtetra
.586 .464 .68 r
.42378 .22418 .42982 .25023 .4412 .24603 .4351 .22035 Mtetra
.586 .466 .682 r
.4351 .22035 .4412 .24603 .45262 .24183 .44648 .21659 Mtetra
.586 .468 .686 r
.44648 .21659 .45262 .24183 .46409 .23763 .45791 .2129 Mtetra
.585 .471 .69 r
.45791 .2129 .46409 .23763 .47562 .23345 .46939 .20929 Mtetra
.585 .475 .694 r
.46939 .20929 .47562 .23345 .48719 .2293 .48092 .20575 Mtetra
.585 .479 .699 r
.48092 .20575 .48719 .2293 .4988 .22519 .4925 .20231 Mtetra
.585 .483 .705 r
.4925 .20231 .4988 .22519 .51047 .22113 .50414 .19897 Mtetra
.585 .488 .711 r
.50414 .19897 .51047 .22113 .52219 .21714 .51583 .19572 Mtetra
.584 .494 .718 r
.51583 .19572 .52219 .21714 .53397 .21324 .52759 .19259 Mtetra
.584 .5 .726 r
.52759 .19259 .53397 .21324 .54579 .20943 .5394 .18957 Mtetra
.583 .507 .735 r
.5394 .18957 .54579 .20943 .55768 .20572 .55128 .18667 Mtetra
.583 .514 .744 r
.55128 .18667 .55768 .20572 .56962 .20214 .56322 .1839 Mtetra
.581 .522 .754 r
.56322 .1839 .56962 .20214 .58162 .19868 .57522 .18126 Mtetra
.58 .531 .765 r
.57522 .18126 .58162 .19868 .59368 .19537 .5873 .17877 Mtetra
.577 .54 .777 r
.5873 .17877 .59368 .19537 .60581 .19222 .59945 .17644 Mtetra
.574 .55 .789 r
.59945 .17644 .60581 .19222 .61801 .18926 .61168 .17428 Mtetra
.57 .56 .803 r
.61168 .17428 .61801 .18926 .63029 .18649 .62398 .1723 Mtetra
.565 .57 .817 r
.62398 .1723 .63029 .18649 .64263 .18391 .63637 .1705 Mtetra
.56 .581 .832 r
.63637 .1705 .64263 .18391 .65506 .18153 .64884 .16886 Mtetra
.554 .593 .847 r
.64884 .16886 .65506 .18153 .66757 .17931 .66139 .16737 Mtetra
.549 .606 .863 r
.66139 .16737 .66757 .17931 .68015 .17723 .67404 .16601 Mtetra
.542 .62 .879 r
.67404 .16601 .68015 .17723 .69283 .17526 .68677 .16474 Mtetra
.536 .634 .895 r
.68677 .16474 .69283 .17526 .70558 .17337 .69959 .16353 Mtetra
.53 .65 .911 r
.69959 .16353 .70558 .17337 .71842 .17152 .7125 .16235 Mtetra
.523 .667 .927 r
.7125 .16235 .71842 .17152 .73134 .16968 .7255 .16118 Mtetra
.758 .768 .861 r
.05043 .39529 .05808 .40196 .06856 .39507 .06096 .3882 Mtetra
.756 .764 .859 r
.06096 .3882 .06856 .39507 .07905 .38817 .07151 .38111 Mtetra
.754 .759 .857 r
.07151 .38111 .07905 .38817 .08956 .38129 .08207 .37404 Mtetra
.751 .755 .855 r
.08207 .37404 .08956 .38129 .10008 .37447 .09264 .36702 Mtetra
.748 .75 .854 r
.09264 .36702 .10008 .37447 .1106 .36773 .10322 .36008 Mtetra
.744 .745 .853 r
.10322 .36008 .1106 .36773 .12114 .36111 .1138 .35324 Mtetra
.739 .74 .852 r
.1138 .35324 .12114 .36111 .13167 .35463 .12439 .34654 Mtetra
.734 .734 .85 r
.12439 .34654 .13167 .35463 .14221 .3483 .13499 .33997 Mtetra
.729 .728 .849 r
.13499 .33997 .14221 .3483 .15276 .34214 .14558 .33353 Mtetra
.724 .721 .847 r
.14558 .33353 .15276 .34214 .16331 .33615 .15619 .32724 Mtetra
.718 .713 .844 r
.15619 .32724 .16331 .33615 .17386 .33033 .1668 .32108 Mtetra
.712 .704 .841 r
.1668 .32108 .17386 .33033 .18443 .32465 .17743 .31504 Mtetra
.707 .695 .837 r
.17743 .31504 .18443 .32465 .19501 .31911 .18807 .30912 Mtetra
.701 .686 .832 r
.18807 .30912 .19501 .31911 .20561 .31371 .19872 .30331 Mtetra
.696 .676 .827 r
.19872 .30331 .20561 .31371 .21622 .30843 .2094 .2976 Mtetra
.69 .667 .822 r
.2094 .2976 .21622 .30843 .22686 .30327 .22009 .29199 Mtetra
.684 .657 .817 r
.22009 .29199 .22686 .30327 .23752 .29821 .2308 .28648 Mtetra
.679 .647 .811 r
.2308 .28648 .23752 .29821 .2482 .29327 .24154 .28107 Mtetra
.673 .637 .805 r
.24154 .28107 .2482 .29327 .25891 .28842 .2523 .27576 Mtetra
.668 .627 .8 r
.2523 .27576 .25891 .28842 .26965 .28366 .26308 .27055 Mtetra
.662 .618 .794 r
.26308 .27055 .26965 .28366 .28041 .279 .27389 .26544 Mtetra
.657 .61 .789 r
.27389 .26544 .28041 .279 .29121 .27441 .28473 .26043 Mtetra
.652 .602 .785 r
.28473 .26043 .29121 .27441 .30205 .26991 .29559 .25553 Mtetra
.648 .594 .781 r
.29559 .25553 .30205 .26991 .31291 .26547 .30648 .25073 Mtetra
.643 .588 .777 r
.30648 .25073 .31291 .26547 .32382 .26109 .31741 .24604 Mtetra
.639 .582 .774 r
.31741 .24604 .32382 .26109 .33476 .25678 .32837 .24146 Mtetra
.635 .577 .772 r
.32837 .24146 .33476 .25678 .34574 .25252 .33936 .23699 Mtetra
.632 .573 .77 r
.33936 .23699 .34574 .25252 .35676 .24832 .35039 .23263 Mtetra
.628 .569 .769 r
.35039 .23263 .35676 .24832 .36782 .24417 .36145 .22838 Mtetra
.625 .567 .769 r
.36145 .22838 .36782 .24417 .37892 .24007 .37255 .22424 Mtetra
.622 .565 .77 r
.37255 .22424 .37892 .24007 .39007 .23602 .3837 .22021 Mtetra
.62 .565 .771 r
.3837 .22021 .39007 .23602 .40126 .23202 .39488 .2163 Mtetra
.617 .565 .773 r
.39488 .2163 .40126 .23202 .41249 .22807 .40611 .21249 Mtetra
.615 .566 .776 r
.40611 .21249 .41249 .22807 .42378 .22418 .41738 .2088 Mtetra
.613 .568 .78 r
.41738 .2088 .42378 .22418 .4351 .22035 .42871 .20521 Mtetra
.611 .571 .784 r
.42871 .20521 .4351 .22035 .44648 .21659 .44008 .20174 Mtetra
.609 .574 .79 r
.44008 .20174 .44648 .21659 .45791 .2129 .4515 .19837 Mtetra
.607 .579 .796 r
.4515 .19837 .45791 .2129 .46939 .20929 .46297 .19511 Mtetra
.605 .584 .802 r
.46297 .19511 .46939 .20929 .48092 .20575 .4745 .19195 Mtetra
.603 .589 .81 r
.4745 .19195 .48092 .20575 .4925 .20231 .48609 .1889 Mtetra
.601 .595 .818 r
.48609 .1889 .4925 .20231 .50414 .19897 .49773 .18596 Mtetra
.599 .602 .826 r
.49773 .18596 .50414 .19897 .51583 .19572 .50943 .18311 Mtetra
.596 .609 .834 r
.50943 .18311 .51583 .19572 .52759 .19259 .5212 .18037 Mtetra
.594 .616 .843 r
.5212 .18037 .52759 .19259 .5394 .18957 .53303 .17774 Mtetra
.59 .623 .852 r
.53303 .17774 .5394 .18957 .55128 .18667 .54492 .1752 Mtetra
.586 .629 .861 r
.54492 .1752 .55128 .18667 .56322 .1839 .55688 .17278 Mtetra
.582 .636 .87 r
.55688 .17278 .56322 .1839 .57522 .18126 .56891 .17047 Mtetra
.577 .642 .878 r
.56891 .17047 .57522 .18126 .5873 .17877 .58102 .16829 Mtetra
.571 .647 .887 r
.58102 .16829 .5873 .17877 .59945 .17644 .5932 .16623 Mtetra
.564 .652 .894 r
.5932 .16623 .59945 .17644 .61168 .17428 .60545 .16432 Mtetra
.557 .656 .901 r
.60545 .16432 .61168 .17428 .62398 .1723 .61779 .16255 Mtetra
.549 .658 .908 r
.61779 .16255 .62398 .1723 .63637 .1705 .63021 .16093 Mtetra
.541 .661 .914 r
.63021 .16093 .63637 .1705 .64884 .16886 .64271 .15946 Mtetra
.534 .662 .919 r
.64271 .15946 .64884 .16886 .66139 .16737 .6553 .15812 Mtetra
.527 .664 .924 r
.6553 .15812 .66139 .16737 .67404 .16601 .66798 .1569 Mtetra
.52 .666 .928 r
.66798 .1569 .67404 .16601 .68677 .16474 .68075 .15577 Mtetra
.516 .669 .932 r
.68075 .15577 .68677 .16474 .69959 .16353 .69362 .1547 Mtetra
.512 .672 .936 r
.69362 .1547 .69959 .16353 .7125 .16235 .70657 .15365 Mtetra
.51 .676 .94 r
.70657 .15365 .7125 .16235 .7255 .16118 .71961 .15261 Mtetra
.75 .767 .867 r
.04273 .38856 .05043 .39529 .06096 .3882 .05323 .38181 Mtetra
.753 .778 .873 r
.05323 .38181 .06096 .3882 .07151 .38111 .06376 .37504 Mtetra
.755 .788 .88 r
.06376 .37504 .07151 .38111 .08207 .37404 .07431 .36827 Mtetra
.757 .798 .886 r
.07431 .36827 .08207 .37404 .09264 .36702 .08487 .36153 Mtetra
.758 .807 .892 r
.08487 .36153 .09264 .36702 .10322 .36008 .09545 .35483 Mtetra
.758 .816 .899 r
.09545 .35483 .10322 .36008 .1138 .35324 .10604 .3482 Mtetra
.756 .823 .904 r
.10604 .3482 .1138 .35324 .12439 .34654 .11664 .34165 Mtetra
.754 .829 .91 r
.11664 .34165 .12439 .34654 .13499 .33997 .12725 .3352 Mtetra
.751 .834 .915 r
.12725 .3352 .13499 .33997 .14558 .33353 .13787 .32885 Mtetra
.748 .838 .919 r
.13787 .32885 .14558 .33353 .15619 .32724 .14851 .32262 Mtetra
.744 .841 .923 r
.14851 .32262 .15619 .32724 .1668 .32108 .15915 .31649 Mtetra
.741 .843 .927 r
.15915 .31649 .1668 .32108 .17743 .31504 .16981 .31047 Mtetra
.737 .844 .93 r
.16981 .31047 .17743 .31504 .18807 .30912 .18048 .30455 Mtetra
.733 .845 .933 r
.18048 .30455 .18807 .30912 .19872 .30331 .19117 .29872 Mtetra
.729 .845 .936 r
.19117 .29872 .19872 .30331 .2094 .2976 .20188 .293 Mtetra
.725 .845 .938 r
.20188 .293 .2094 .2976 .22009 .29199 .21261 .28736 Mtetra
.721 .845 .94 r
.21261 .28736 .22009 .29199 .2308 .28648 .22336 .28182 Mtetra
.717 .845 .943 r
.22336 .28182 .2308 .28648 .24154 .28107 .23414 .27638 Mtetra
.713 .844 .945 r
.23414 .27638 .24154 .28107 .2523 .27576 .24494 .27104 Mtetra
.708 .843 .947 r
.24494 .27104 .2523 .27576 .26308 .27055 .25576 .26579 Mtetra
.703 .842 .949 r
.25576 .26579 .26308 .27055 .27389 .26544 .2666 .26064 Mtetra
.699 .841 .951 r
.2666 .26064 .27389 .26544 .28473 .26043 .27748 .2556 Mtetra
.694 .84 .953 r
.27748 .2556 .28473 .26043 .29559 .25553 .28838 .25066 Mtetra
.688 .839 .956 r
.28838 .25066 .29559 .25553 .30648 .25073 .29931 .24583 Mtetra
.683 .838 .958 r
.29931 .24583 .30648 .25073 .31741 .24604 .31028 .24111 Mtetra
.677 .836 .96 r
.31028 .24111 .31741 .24604 .32837 .24146 .32127 .23649 Mtetra
.672 .835 .962 r
.32127 .23649 .32837 .24146 .33936 .23699 .3323 .23199 Mtetra
.666 .833 .964 r
.3323 .23199 .33936 .23699 .35039 .23263 .34337 .22759 Mtetra
.66 .832 .966 r
.34337 .22759 .35039 .23263 .36145 .22838 .35447 .22331 Mtetra
.653 .83 .968 r
.35447 .22331 .36145 .22838 .37255 .22424 .36561 .21914 Mtetra
.647 .828 .97 r
.36561 .21914 .37255 .22424 .3837 .22021 .37679 .21508 Mtetra
.641 .826 .972 r
.37679 .21508 .3837 .22021 .39488 .2163 .38801 .21114 Mtetra
.634 .824 .974 r
.38801 .21114 .39488 .2163 .40611 .21249 .39928 .20731 Mtetra
.627 .822 .975 r
.39928 .20731 .40611 .21249 .41738 .2088 .41059 .20359 Mtetra
.621 .82 .977 r
.41059 .20359 .41738 .2088 .42871 .20521 .42195 .19998 Mtetra
.614 .818 .979 r
.42195 .19998 .42871 .20521 .44008 .20174 .43336 .19648 Mtetra
.607 .816 .98 r
.43336 .19648 .44008 .20174 .4515 .19837 .44482 .19309 Mtetra
.6 .813 .982 r
.44482 .19309 .4515 .19837 .46297 .19511 .45633 .1898 Mtetra
.593 .811 .983 r
.45633 .1898 .46297 .19511 .4745 .19195 .4679 .18662 Mtetra
.586 .809 .984 r
.4679 .18662 .4745 .19195 .48609 .1889 .47952 .18355 Mtetra
.58 .806 .985 r
.47952 .18355 .48609 .1889 .49773 .18596 .49121 .18058 Mtetra
.573 .804 .986 r
.49121 .18058 .49773 .18596 .50943 .18311 .50295 .17771 Mtetra
.566 .801 .987 r
.50295 .17771 .50943 .18311 .5212 .18037 .51475 .17493 Mtetra
.559 .798 .988 r
.51475 .17493 .5212 .18037 .53303 .17774 .52662 .17226 Mtetra
.553 .795 .989 r
.52662 .17226 .53303 .17774 .54492 .1752 .53856 .16969 Mtetra
.546 .791 .989 r
.53856 .16969 .54492 .1752 .55688 .17278 .55056 .16721 Mtetra
.54 .788 .99 r
.55056 .16721 .55688 .17278 .56891 .17047 .56263 .16484 Mtetra
.533 .783 .99 r
.56263 .16484 .56891 .17047 .58102 .16829 .57477 .16258 Mtetra
.527 .779 .989 r
.57477 .16258 .58102 .16829 .5932 .16623 .58699 .16042 Mtetra
.521 .773 .989 r
.58699 .16042 .5932 .16623 .60545 .16432 .59929 .15839 Mtetra
.515 .767 .988 r
.59929 .15839 .60545 .16432 .61779 .16255 .61166 .15647 Mtetra
.51 .76 .986 r
.61166 .15647 .61779 .16255 .63021 .16093 .62411 .15466 Mtetra
.507 .753 .984 r
.62411 .15466 .63021 .16093 .64271 .15946 .63665 .15296 Mtetra
.505 .745 .981 r
.63665 .15296 .64271 .15946 .6553 .15812 .64927 .15135 Mtetra
.506 .736 .977 r
.64927 .15135 .6553 .15812 .66798 .1569 .66198 .14982 Mtetra
.508 .727 .972 r
.66198 .14982 .66798 .1569 .68075 .15577 .67477 .14833 Mtetra
.511 .718 .966 r
.67477 .14833 .68075 .15577 .69362 .1547 .68765 .14688 Mtetra
.516 .709 .959 r
.68765 .14688 .69362 .1547 .70657 .15365 .70062 .14543 Mtetra
.521 .699 .951 r
.70062 .14543 .70657 .15365 .71961 .15261 .71368 .14397 Mtetra
.73 .765 .881 r
.03496 .38178 .04273 .38856 .05323 .38181 .04538 .37582 Mtetra
.736 .789 .895 r
.04538 .37582 .05323 .38181 .06376 .37504 .05582 .36982 Mtetra
.741 .814 .91 r
.05582 .36982 .06376 .37504 .07431 .36827 .06629 .3638 Mtetra
.743 .84 .924 r
.06629 .3638 .07431 .36827 .08487 .36153 .07679 .35778 Mtetra
.744 .864 .936 r
.07679 .35778 .08487 .36153 .09545 .35483 .08731 .35175 Mtetra
.741 .887 .946 r
.08731 .35175 .09545 .35483 .10604 .3482 .09785 .34575 Mtetra
.735 .908 .954 r
.09785 .34575 .10604 .3482 .11664 .34165 .10842 .33978 Mtetra
.726 .925 .958 r
.10842 .33978 .11664 .34165 .12725 .3352 .119 .33387 Mtetra
.712 .939 .959 r
.119 .33387 .12725 .3352 .13787 .32885 .12961 .32802 Mtetra
.694 .949 .957 r
.12961 .32802 .13787 .32885 .14851 .32262 .14023 .32225 Mtetra
.673 .954 .95 r
.14023 .32225 .14851 .32262 .15915 .31649 .15087 .31655 Mtetra
.648 .956 .939 r
.15087 .31655 .15915 .31649 .16981 .31047 .16153 .31093 Mtetra
.621 .953 .924 r
.16153 .31093 .16981 .31047 .18048 .30455 .17221 .30539 Mtetra
.591 .946 .905 r
.17221 .30539 .18048 .30455 .19117 .29872 .18292 .29993 Mtetra
.559 .934 .883 r
.18292 .29993 .19117 .29872 .20188 .293 .19364 .29455 Mtetra
.524 .92 .858 r
.19364 .29455 .20188 .293 .21261 .28736 .20439 .28924 Mtetra
.489 .902 .831 r
.20439 .28924 .21261 .28736 .22336 .28182 .21517 .28401 Mtetra
.453 .881 .801 r
.21517 .28401 .22336 .28182 .23414 .27638 .22597 .27886 Mtetra
.417 .859 .771 r
.22597 .27886 .23414 .27638 .24494 .27104 .2368 .27379 Mtetra
.381 .834 .74 r
.2368 .27379 .24494 .27104 .25576 .26579 .24766 .2688 Mtetra
.347 .81 .709 r
.24766 .2688 .25576 .26579 .2666 .26064 .25855 .26389 Mtetra
.314 .785 .679 r
.25855 .26389 .2666 .26064 .27748 .2556 .26947 .25906 Mtetra
.283 .761 .65 r
.26947 .25906 .27748 .2556 .28838 .25066 .28042 .25431 Mtetra
0 0 0 r
.28042 .25431 .28838 .25066 .29931 .24583 .29141 .24964 Mtetra
.29141 .24964 .29931 .24583 .31028 .24111 .30243 .24504 Mtetra
.30243 .24504 .31028 .24111 .32127 .23649 .31348 .24053 Mtetra
.31348 .24053 .32127 .23649 .3323 .23199 .32458 .2361 Mtetra
.32458 .2361 .3323 .23199 .34337 .22759 .33571 .23175 Mtetra
.33571 .23175 .34337 .22759 .35447 .22331 .34688 .22748 Mtetra
.34688 .22748 .35447 .22331 .36561 .21914 .35809 .22328 Mtetra
.35809 .22328 .36561 .21914 .37679 .21508 .36934 .21917 Mtetra
.36934 .21917 .37679 .21508 .38801 .21114 .38064 .21514 Mtetra
.38064 .21514 .38801 .21114 .39928 .20731 .39198 .21118 Mtetra
.39198 .21118 .39928 .20731 .41059 .20359 .40337 .20731 Mtetra
.40337 .20731 .41059 .20359 .42195 .19998 .41481 .20352 Mtetra
.41481 .20352 .42195 .19998 .43336 .19648 .4263 .19981 Mtetra
.4263 .19981 .43336 .19648 .44482 .19309 .43783 .19618 Mtetra
.43783 .19618 .44482 .19309 .45633 .1898 .44942 .19263 Mtetra
.44942 .19263 .45633 .1898 .4679 .18662 .46107 .18916 Mtetra
.46107 .18916 .4679 .18662 .47952 .18355 .47276 .18578 Mtetra
.47276 .18578 .47952 .18355 .49121 .18058 .48452 .18248 Mtetra
.48452 .18248 .49121 .18058 .50295 .17771 .49633 .17926 Mtetra
.197 .719 .704 r
.49633 .17926 .50295 .17771 .51475 .17493 .50821 .17612 Mtetra
.216 .736 .735 r
.50821 .17612 .51475 .17493 .52662 .17226 .52014 .17306 Mtetra
.237 .753 .767 r
.52014 .17306 .52662 .17226 .53856 .16969 .53214 .17008 Mtetra
.259 .769 .799 r
.53214 .17008 .53856 .16969 .55056 .16721 .54421 .16719 Mtetra
.282 .784 .831 r
.54421 .16719 .55056 .16721 .56263 .16484 .55634 .16437 Mtetra
.307 .798 .863 r
.55634 .16437 .56263 .16484 .57477 .16258 .56854 .16164 Mtetra
.332 .81 .894 r
.56854 .16164 .57477 .16258 .58699 .16042 .58081 .15899 Mtetra
.358 .82 .922 r
.58081 .15899 .58699 .16042 .59929 .15839 .59315 .15642 Mtetra
.385 .826 .948 r
.59315 .15642 .59929 .15839 .61166 .15647 .60557 .15393 Mtetra
.411 .829 .969 r
.60557 .15393 .61166 .15647 .62411 .15466 .61806 .15151 Mtetra
.438 .827 .986 r
.61806 .15151 .62411 .15466 .63665 .15296 .63063 .14914 Mtetra
.464 .821 .996 r
.63063 .14914 .63665 .15296 .64927 .15135 .64328 .14682 Mtetra
.489 .811 1 r
.64328 .14682 .64927 .15135 .66198 .14982 .656 .14452 Mtetra
.511 .795 .997 r
.656 .14452 .66198 .14982 .67477 .14833 .66881 .14223 Mtetra
.53 .776 .988 r
.66881 .14223 .67477 .14833 .68765 .14688 .68169 .13992 Mtetra
.545 .755 .974 r
.68169 .13992 .68765 .14688 .70062 .14543 .69465 .1376 Mtetra
.556 .732 .957 r
.69465 .1376 .70062 .14543 .71368 .14397 .70769 .13525 Mtetra
.695 .76 .902 r
.02714 .37496 .03496 .38178 .04538 .37582 .0374 .37016 Mtetra
.7 .797 .925 r
.0374 .37016 .04538 .37582 .05582 .36982 .0477 .36533 Mtetra
.701 .837 .948 r
.0477 .36533 .05582 .36982 .06629 .3638 .05803 .36047 Mtetra
.696 .875 .965 r
.05803 .36047 .06629 .3638 .07679 .35778 .0684 .35557 Mtetra
.682 .909 .974 r
.0684 .35557 .07679 .35778 .08731 .35175 .07881 .35065 Mtetra
.654 .933 .97 r
.07881 .35065 .08731 .35175 .09785 .34575 .08925 .34571 Mtetra
.612 .942 .947 r
.08925 .34571 .09785 .34575 .10842 .33978 .09972 .34076 Mtetra
.554 .931 .903 r
.09972 .34076 .10842 .33978 .119 .33387 .11023 .33582 Mtetra
.482 .899 .839 r
.11023 .33582 .119 .33387 .12961 .32802 .12077 .3309 Mtetra
.403 .849 .76 r
.12077 .3309 .12961 .32802 .14023 .32225 .13134 .32601 Mtetra
.322 .788 .674 r
.13134 .32601 .14023 .32225 .15087 .31655 .14193 .32116 Mtetra
0 0 0 r
.14193 .32116 .15087 .31655 .16153 .31093 .15256 .31633 Mtetra
.15256 .31633 .16153 .31093 .17221 .30539 .16322 .31155 Mtetra
.16322 .31155 .17221 .30539 .18292 .29993 .17392 .3068 Mtetra
.17392 .3068 .18292 .29993 .19364 .29455 .18464 .30209 Mtetra
.18464 .30209 .19364 .29455 .20439 .28924 .1954 .29742 Mtetra
.027 0 0 r
.1954 .29742 .20439 .28924 .21517 .28401 .20619 .29278 Mtetra
.061 0 0 r
.20619 .29278 .21517 .28401 .22597 .27886 .21702 .28819 Mtetra
.09 0 0 r
.21702 .28819 .22597 .27886 .2368 .27379 .22788 .28364 Mtetra
.115 0 0 r
.22788 .28364 .2368 .27379 .24766 .2688 .23878 .27912 Mtetra
.136 0 0 r
.23878 .27912 .24766 .2688 .25855 .26389 .24972 .27464 Mtetra
.155 0 0 r
.24972 .27464 .25855 .26389 .26947 .25906 .26069 .27019 Mtetra
.17 0 0 r
.26069 .27019 .26947 .25906 .28042 .25431 .27171 .26578 Mtetra
.183 0 0 r
.27171 .26578 .28042 .25431 .29141 .24964 .28276 .2614 Mtetra
.194 0 0 r
.28276 .2614 .29141 .24964 .30243 .24504 .29386 .25705 Mtetra
.204 0 0 r
.29386 .25705 .30243 .24504 .31348 .24053 .305 .25273 Mtetra
.211 0 0 r
.305 .25273 .31348 .24053 .32458 .2361 .31618 .24844 Mtetra
.217 0 0 r
.31618 .24844 .32458 .2361 .33571 .23175 .3274 .24417 Mtetra
.222 0 0 r
.3274 .24417 .33571 .23175 .34688 .22748 .33867 .23994 Mtetra
.225 0 0 r
.33867 .23994 .34688 .22748 .35809 .22328 .34998 .23573 Mtetra
.227 0 .001 r
.34998 .23573 .35809 .22328 .36934 .21917 .36134 .23154 Mtetra
.228 0 0 r
.36134 .23154 .36934 .21917 .38064 .21514 .37274 .22739 Mtetra
.37274 .22739 .38064 .21514 .39198 .21118 .3842 .22326 Mtetra
.227 0 0 r
.3842 .22326 .39198 .21118 .40337 .20731 .3957 .21915 Mtetra
.224 0 0 r
.3957 .21915 .40337 .20731 .41481 .20352 .40725 .21508 Mtetra
.221 0 0 r
.40725 .21508 .41481 .20352 .4263 .19981 .41885 .21104 Mtetra
.215 0 0 r
.41885 .21104 .4263 .19981 .43783 .19618 .4305 .20703 Mtetra
.209 0 0 r
.4305 .20703 .43783 .19618 .44942 .19263 .4422 .20305 Mtetra
.201 0 0 r
.4422 .20305 .44942 .19263 .46107 .18916 .45396 .19911 Mtetra
.191 0 0 r
.45396 .19911 .46107 .18916 .47276 .18578 .46576 .19521 Mtetra
.179 0 0 r
.46576 .19521 .47276 .18578 .48452 .18248 .47763 .19134 Mtetra
.164 0 0 r
.47763 .19134 .48452 .18248 .49633 .17926 .48955 .18751 Mtetra
.147 0 0 r
.48955 .18751 .49633 .17926 .50821 .17612 .50152 .18372 Mtetra
.127 0 0 r
.50152 .18372 .50821 .17612 .52014 .17306 .51355 .17997 Mtetra
.102 0 0 r
.51355 .17997 .52014 .17306 .53214 .17008 .52564 .17626 Mtetra
.073 0 0 r
.52564 .17626 .53214 .17008 .54421 .16719 .5378 .17259 Mtetra
.038 0 0 r
.5378 .17259 .54421 .16719 .55634 .16437 .55001 .16895 Mtetra
0 0 0 r
.55001 .16895 .55634 .16437 .56854 .16164 .56228 .16535 Mtetra
.56228 .16535 .56854 .16164 .58081 .15899 .57462 .16179 Mtetra
.57462 .16179 .58081 .15899 .59315 .15642 .58702 .15826 Mtetra
.58702 .15826 .59315 .15642 .60557 .15393 .59949 .15476 Mtetra
.258 .766 .763 r
.59949 .15476 .60557 .15393 .61806 .15151 .61203 .15128 Mtetra
.338 .819 .852 r
.61203 .15128 .61806 .15151 .63063 .14914 .62463 .1478 Mtetra
.415 .855 .924 r
.62463 .1478 .63063 .14914 .64328 .14682 .6373 .14432 Mtetra
.483 .87 .973 r
.6373 .14432 .64328 .14682 .656 .14452 .65003 .14082 Mtetra
.536 .863 .995 r
.65003 .14082 .656 .14452 .66881 .14223 .66284 .13728 Mtetra
.572 .839 .995 r
.66284 .13728 .66881 .14223 .68169 .13992 .67571 .13371 Mtetra
.596 .807 .98 r
.67571 .13371 .68169 .13992 .69465 .1376 .68865 .13011 Mtetra
.609 .77 .957 r
.68865 .13011 .69465 .1376 .70769 .13525 .70165 .12647 Mtetra
.636 .746 .928 r
.01926 .36808 .02714 .37496 .0374 .37016 .02931 .36479 Mtetra
.632 .795 .961 r
.02931 .36479 .0374 .37016 .0477 .36533 .0394 .36147 Mtetra
.616 .843 .986 r
.0394 .36147 .0477 .36533 .05803 .36047 .04954 .35812 Mtetra
.58 .882 .992 r
.04954 .35812 .05803 .36047 .0684 .35557 .05972 .35473 Mtetra
.515 .894 .962 r
.05972 .35473 .0684 .35557 .07881 .35065 .06995 .35132 Mtetra
.418 .865 .883 r
.06995 .35132 .07881 .35065 .08925 .34571 .08023 .34788 Mtetra
.3 .792 .759 r
.08023 .34788 .08925 .34571 .09972 .34076 .09055 .34441 Mtetra
0 0 0 r
.09055 .34441 .09972 .34076 .11023 .33582 .10092 .3409 Mtetra
.10092 .3409 .11023 .33582 .12077 .3309 .11134 .33736 Mtetra
.011 0 0 r
.11134 .33736 .12077 .3309 .13134 .32601 .12181 .3338 Mtetra
.078 0 0 r
.12181 .3338 .13134 .32601 .14193 .32116 .13232 .3302 Mtetra
.13 0 0 r
.13232 .3302 .14193 .32116 .15256 .31633 .14288 .32657 Mtetra
.17 0 0 r
.14288 .32657 .15256 .31633 .16322 .31155 .15349 .32291 Mtetra
.201 0 0 r
.15349 .32291 .16322 .31155 .17392 .3068 .16414 .31922 Mtetra
.226 0 0 r
.16414 .31922 .17392 .3068 .18464 .30209 .17485 .31549 Mtetra
.246 0 .022 r
.17485 .31549 .18464 .30209 .1954 .29742 .1856 .31173 Mtetra
.263 0 .05 r
.1856 .31173 .1954 .29742 .20619 .29278 .1964 .30794 Mtetra
.276 0 .073 r
.1964 .30794 .20619 .29278 .21702 .28819 .20725 .30412 Mtetra
.287 0 .092 r
.20725 .30412 .21702 .28819 .22788 .28364 .21814 .30027 Mtetra
.296 0 .108 r
.21814 .30027 .22788 .28364 .23878 .27912 .22909 .29638 Mtetra
.303 0 .121 r
.22909 .29638 .23878 .27912 .24972 .27464 .24009 .29246 Mtetra
.309 0 .133 r
.24009 .29246 .24972 .27464 .26069 .27019 .25113 .28851 Mtetra
.314 0 .142 r
.25113 .28851 .26069 .27019 .27171 .26578 .26222 .28452 Mtetra
.319 0 .15 r
.26222 .28452 .27171 .26578 .28276 .2614 .27337 .2805 Mtetra
.322 0 .156 r
.27337 .2805 .28276 .2614 .29386 .25705 .28456 .27645 Mtetra
.324 0 .161 r
.28456 .27645 .29386 .25705 .305 .25273 .2958 .27236 Mtetra
.326 0 .165 r
.2958 .27236 .305 .25273 .31618 .24844 .30709 .26824 Mtetra
.327 0 .167 r
.30709 .26824 .31618 .24844 .3274 .24417 .31843 .26409 Mtetra
.328 0 .169 r
.31843 .26409 .3274 .24417 .33867 .23994 .32982 .2599 Mtetra
.328 0 .17 r
.32982 .2599 .33867 .23994 .34998 .23573 .34127 .25567 Mtetra
.328 0 .169 r
.34127 .25567 .34998 .23573 .36134 .23154 .35276 .25142 Mtetra
.327 0 .168 r
.35276 .25142 .36134 .23154 .37274 .22739 .3643 .24713 Mtetra
.325 0 .166 r
.3643 .24713 .37274 .22739 .3842 .22326 .37589 .2428 Mtetra
.323 0 .163 r
.37589 .2428 .3842 .22326 .3957 .21915 .38754 .23844 Mtetra
.32 0 .159 r
.38754 .23844 .3957 .21915 .40725 .21508 .39923 .23404 Mtetra
.316 0 .153 r
.39923 .23404 .40725 .21508 .41885 .21104 .41098 .22961 Mtetra
.312 0 .146 r
.41098 .22961 .41885 .21104 .4305 .20703 .42278 .22514 Mtetra
.307 0 .138 r
.42278 .22514 .4305 .20703 .4422 .20305 .43463 .22064 Mtetra
.3 0 .128 r
.43463 .22064 .4422 .20305 .45396 .19911 .44653 .2161 Mtetra
.293 0 .116 r
.44653 .2161 .45396 .19911 .46576 .19521 .45848 .21153 Mtetra
.284 0 .102 r
.45848 .21153 .46576 .19521 .47763 .19134 .47048 .20692 Mtetra
.273 0 .085 r
.47048 .20692 .47763 .19134 .48955 .18751 .48254 .20227 Mtetra
.26 0 .065 r
.48254 .20227 .48955 .18751 .50152 .18372 .49464 .19759 Mtetra
.244 0 .04 r
.49464 .19759 .50152 .18372 .51355 .17997 .5068 .19287 Mtetra
.225 0 .01 r
.5068 .19287 .51355 .17997 .52564 .17626 .51902 .18812 Mtetra
.201 0 0 r
.51902 .18812 .52564 .17626 .5378 .17259 .53128 .18332 Mtetra
.172 0 0 r
.53128 .18332 .5378 .17259 .55001 .16895 .5436 .17849 Mtetra
.136 0 0 r
.5436 .17849 .55001 .16895 .56228 .16535 .55597 .17363 Mtetra
.089 0 0 r
.55597 .17363 .56228 .16535 .57462 .16179 .56839 .16873 Mtetra
.03 0 0 r
.56839 .16873 .57462 .16179 .58702 .15826 .58087 .16378 Mtetra
0 0 0 r
.58087 .16378 .58702 .15826 .59949 .15476 .5934 .15881 Mtetra
.5934 .15881 .59949 .15476 .61203 .15128 .60598 .15379 Mtetra
.60598 .15379 .61203 .15128 .62463 .1478 .61862 .14874 Mtetra
.379 .84 .788 r
.61862 .14874 .62463 .1478 .6373 .14432 .63131 .14364 Mtetra
.493 .903 .9 r
.63131 .14364 .6373 .14432 .65003 .14082 .64405 .13851 Mtetra
.581 .92 .965 r
.64405 .13851 .65003 .14082 .66284 .13728 .65685 .13334 Mtetra
.635 .899 .985 r
.65685 .13334 .66284 .13728 .67571 .13371 .6697 .12814 Mtetra
.662 .857 .974 r
.6697 .12814 .67571 .13371 .68865 .13011 .6826 .12289 Mtetra
.672 .807 .947 r
.6826 .12289 .68865 .13011 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Rooooo`;o[<kb00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`1Aooooo`00H?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B47ooooo`03o`000?oooooooooo01gooooo0ol00002ooooo`03o`000?oooooooooo05gooooo00?o
ZM_iojc>l_n/c_800_n/c_800ol0003o[<kbooooo`0Eooooo`03o`000?oooooooooo053ooooo001P
ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0001cooooo0_l0001Sooooo`CoZM_i0on/
c_800ol0003oVlGdooooo`0Dooooo`03o`000?oooooo0000057ooooo001Pooooo`05o`000?oooooo
ooooooooool000002oooool01?m4A4CogMgMooooool0000Jooooo`?o0000Hoooool2oj;Vo0GoZM_i
00?o[<kboi_5m?l000000_nKaO@Fooooo`03o`000?oooooooooo04oooooo001Pooooo`05o`000?oo
ooooooooooooool000002oooool01?oMgMgoEEEEooooool0000Hooooo`;o0000I?ooool5oj;Vo0;o
ZM_i0onHc_X00onKaOCo0000oi_5m002oi_5m1Kooooo00?o0000ooooooooool0C_ooool0063ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001Gooooo0ol00002ooooo`03
o`000?oooooooooo05kooooo0onDjoL3oj;Vo0;oT]Kn1_nHc_X01?l0003oVlGdohjkm?n>^o@Foooo
o`03o`000?oooooooooo04kooooo001Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^
k^koA4A4o`00000Cooooo`;o0000Hoooool2ogkWiP;oU>_g1?n9g?h4oi;FoP?oV<kj0_n;`OT00ol0
003oS[_dohjkm002ohjkm1Kooooo00?o0000ooooooooool0COooool0063ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00oooooo0ol0001Rooooo`?oO^OV1?mkg_T2ohWL
oP?oP/_o1?n7a_`4oh_1n@03o`000?n>^oCoS[_d00?oS[_d5_ooool00ol0003oooooooooo`1<oooo
o`00P_ooool2o`0006;ooooo0_mQelT4of[Jk0;oNmki0ommcol5oh;;o`CoQlKl0_n;`OT00on4]OGo
0000ohFbl`04ohFblaKooooo00?o0000ooooooooool0C?ooool007oooooo0ol00002ooooo`03o`00
0?oooooooooo05cooooo00?o0000oeKAf_mFdMX00_mFdMX2of[Jk0CoM];n1?mmcol2oh;;o`;oP[[h
1On2]oL2ohBem@03o`000?n4]OGoQK;c00CoQK;c5?ooool3o`0004gooooo001looooo`?o0000HOoo
ool00ol0003o@/C3ofWDn003ofWDn0CoL=?l0_mfd_h3oh6nn`CoPKcj1?n2^_P5oh:gm`04ohBemOl0
003oQ;GeohBem@CoQK;c5oooool00ol0003oooooooooo`1:ooooo`00N_ooool2o`00063ooooo0ol0
0003of;ClP;oJMCh0on2`_`4oh70n`GoPKkk1?n1_?X4oh:jn0;oP[Og0_n4Znh2oh>/k`03o`000?n3
[>ooPZg`00CoPZg`5_ooool00ol0003oooooooooo`1:ooooo`00Moooool3o`0005oooooo00Go1`00
o`000?l0003o0000oe_Ak002of;ClP?oPlCl1On2`_`4oh70n`;oPKkk0_n8ZN/4ohJYk0CoQJ[]1On4
Znh01?n3[>oo0000oh>/kon3[>l5oh:]l1Kooooo00?o0000ooooooooool0BOooool007Gooooo0_l0
0002ooooo`03o`000?oooooooooo05_ooooo0_l700000ol0003oQ/OmohG5o@04ohG5o@CoPlCl0_n2
`_`2ohbXj0CoRZWY1On8ZN/4ohJYk0CoQJ[]1On4Znh01?l0003oPjc_oh>/kon3[>l2oh:]l0;oQJ[]
5oooool00ol0003oooooooooo`18ooooo`00L_ooool3o`0000Gooooo00?o0000ooooooooool0D_oo
ool2o`T000Co000000?o5P00o`L00?n8b?d01?n6aod2ohG5o@;oT:KT1?n>YnH5ohbXj0CoRZWY1On8
ZN/4ohJYk0CoQJ[]0_n4Znh2ohVRi@04o`000?n7Y^WoQjKYohNVj@GoQJ[]5_ooool00ol0003ooooo
ooooo`18ooooo`00L?ooool2o`0005Wooooo0_lB0003o`T00003o`000?lR003o8P0000?o5P000on8
b?d2ohK7o@03oi:Uhon@Y^CoT:KT00?oT:KT1?n>YnH5ohbXj0CoRZWY0_n8ZN/2ohfGf0CoS9_L1?n:
W^44ohVRi@03o`000?n7Y^WoQjKY00;oQjKY1On5Z^dFooooo`03o`000?oooooooooo04Oooooo000h
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000Pooooo`?o0000Eooo
ool2oaX000?o4P0000?o2@00ob`00?l/00000olR00000olF003oU:;NoiBRgP04oi>Th0CoTZGS1?n@
Y^@5ohjWiP;oS:SX0_n@TM44ohnDe0GoSIOH1?n<Vm`4ohZNh@?oRJ;U00?o0000ohVRiOn7Y^T00on7
Y^T2ohFZk@;oSZ[X5Oooool3o`0004Sooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Nooooo`;o00000oooool00ol0003ooooo
ooooo`1@ooooo`;o80000olJ00000olB003o<`00oc<00004ob`00003ob800?nFXMcoU:;N00CoU:;N
1?nCY>04oi:Uh`CoT:KT0_n>YnH2oi6?c@GoT97A1?n?U=@4ohfGf0GoS9_L1?n:W^42ohVRi@03o`00
0?nAVm[oT:;Q00?oT:;Q1On>Z^PFooooo`03o`000?oooooooooo00Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo02Wooooo000hooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Looooo`?o0000EOooool01OlU003o
8000ob000?lP003o6P0000;o>@021?lc0003ob`000CoUZ7L1?nDX]h5oi>Th0;oTZGS00?oTh[6oi:<
bOnBS<T00_nBS<T5oi6?c@CoT97A1?n?U=@5ohfGf0;oS9_L0_nBS/`4oi6Dd`;oTI_J00?o0000oi6K
f_nAVmX01?n@X^45ohjZj1Kooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02[ooooo000hooooo`05o`000?oooooooooo
ooooool000003Oooool00onHV9So8B4Qonk^kP0Hooooo`?o0000E?ooool2obT000?o9@0000?o8000
och02_li00800oli0083oc<00004ob`00?nGWm[oUioJoiNOfPCoUZ7L1OnDX]h2oi>Th0;oU8O31?nC
R/H4oi:<b@CoTHo=1?n@TM45ohnDe0;oSIOH0_nBRLH5oi:>c0CoTICC00CoTI_Jo`000?nAVm[oTI_J
1On@X^42ohjZj0?oVjoU5_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
41002oooool5o`0002_ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`0Eooooo`?o0000D_ooool2obd000Co:@000_lU0003och02P?o>@020_lc0002oiRMe`Go
UioJ1?nFXM`2oiBRgP;oU8G11OnDQl<3oi>:aPCoTXc91OnASld4oi2Ad@;oSiCD0_nCQ<45oi:9aPCo
TXk<1?nAU=<00onAVm[o0000oi6KfP02oi6KfP;oT:;Q0_nKY]d6oi^_iAGooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000;?ooool0
03Sooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo017ooooo0ol00003
ooooo`03o`000?oooooooooo04[ooooo00?o0000oc000?l`00001?l]0003obT00003obD00?m2013o
?P0:00;o?P0:1?li00800onHVmGoV9gGoiRMe`02oiRMe`;oUioJ0_nEPK`4oiF3_PGoU8G11?nDQl<3
oi>:aPGoTXc90_nASld2oi=m]`CoTh2l1OnCQ<44oi:9aPCoTXk<1OnAU=<01?l0003oTI_Joi^MeOnK
WMD5oi^Vg@CoVjoU00?oZ;KSooooooooool05?ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000002oooool01?oMgMgoEEEEooooool0000/ooooo`00>?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Aooooo`;o0000D?ooool00ol0
003o<`00oc000003oc0000?o;@0000?o:@00odD05Om501D00om20103och02P03ocT00_nHVmGoV9_E
00?oV9_E0_nHWML00onEOkWoUH6loiF1_002oiF1_0GoUH>n1?nDQL44oiB7``CoTh[60_nBS<T2oi=i
]0CoTgfg1OnCP;`4oi>4`@CoTXW61OnBS/`2oi6Dd`;oViK>00?o0000oi^MeOnKWMD00_nKWMD5oi^V
g@03oi^_iOnX]^?oZ;KS00;oZ;KS5_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`00000/ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00>ooooo`?o0000D?ooool01?le003o<`00oc<0
0?lc0003oc000003obd00?m801[oB00J00CoA@0E0_m20102och02PCoVI[C0_nHVmD2oiEn]`?oUGni
1OnEPK`4oiF3_PCoU8G11OnDQl<2oi>:aP03oi=g/?nCNKCoTgVd00;oTgVd1OnCOKL4oi>0_0CoThC1
1OnBRLH2oi:>c0;oVi371?nKU/h00ol0003oVigEoi^Me@03oi^Me@;oVjKM0_nW[=/6ojRfhaCooooo
0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000/ooooo`00
FOooool3o`00053ooooo0ole0002oc<00003oc000?m;01goB`0M00CoB00J0om501D3od8040;oVISA
0_nIV]<2oiEl]PCoUGjg1?nEOkT4oiF1_0CoUH>n1OnDQL42oiB7``;oTgB^0onCMk05oi=i]0CoTgfg
1?nCP;`5oi>4`@;oTXW60_nKRl85oi^@a`?oViK>00?o0000oi^MeOnKWMD00_nKWMD00onVY=CoYjcK
ojN/f`03ojN/f`CoZ;KS00?o/kkRooooooooool04Oooool01?l0003oooooooooool00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0[ooooo`00E_ooool3o`0000?o
oooo00?o0000ooooooooool0BOooool00ol0003o=`00ocL00003ocD00003oc<00?m<023oB`0M00?o
B`0M0om801X3odD05@04od804?nJU/ooVISAoiVHd@;oUG^d1?nEO;H5oiEn]`?oUGni1?nEPK`5oiF3
_P;oU8G10_nCLZ/4oi=d[PCoTgN`1?nCNK@4oi=m]`GoTh2l0_nCQ<42oi^7_@GoVh_21?nKT<L3oi^F
cP03o`000?nKU/koVigE00CoYZCD1OnW[=/00onX]^?o/kkRok>nhP02ok>nhQKooooo00?o0000oooo
ooooool0@?ooool005Cooooo0_l0001>ooooo`;o000000?o>000ocL00?lg00000_lg0002ocD000?o
C00P0om;01d3odP06P;oA@0E0onJU/l00onEN[;oUG^doiEk]002oiEk]0GoUGbf1?nEO[L3oiEo^@Go
UH6l0onEPkh00onBL:WoTg:[oi=bZ`02oi=bZ`GoTgB^0onCMk04oi=i]0GoTgfg0onCP;`00onJPkWo
VhNmoi^7_@03oi^7_@CoVh_21OnKT<L2oi^FcP03o`000?nVW/koYZCD00CoYZCD1?nW[=/00onb^=go
/kkRok>nhP03ok>nhQKooooo00?o0000ooooooooool0@?ooool0057ooooo0ol0001=ooooo`03o`00
0?li003o>@0000?o>0000olg00000ole003oCP0Sod`08002od`080CoB`0M0om801X3oiZEc@03oiZF
conEN[;oUGZb00GoUG^d1?nEO;H4oiEn]`CoUGni1?nEPK`01?nEPkkoTW2Yoi9`ZOnBL:T5oi=bZ`Co
TgB^0onCMk05oi=i]0CoTgfg00CoTh2loiZ3^OnJPkWoVX>i1OnKQkd4oi^;`PCoVi3700CoYIW9ojJN
c_nVW/ko00000_nVW/h5ojJTe003ojN/fonb^=go/[SM00;o/[SM0onc_^82ok_8i1Kooooo00?o0000
ooooooooool0?oooool004kooooo1Ol0001:ooooo`;o000000?o>P00ocT00?li00000_li0002ocP0
0003ocL00?m?02GoC`0U00?oCP0S0om<0204od/07@04odP06_nKU<_oVYG=oiZEc@;oUGVa1?nEN[84
oiEk]0CoUGbf1OnEO[L3oiEo^@;oUH6l0_nBKjL5oi9`Z@CoTg:[1?nCM:h3oi=g/0GoTgVd0_nCOKL2
oiYo]@GoVX>i1?nKQkd5oi^;`P03oi^@aonUVLWoYIW900;oYIW900CoYYk>o`000?nVW/koYYk>1?nV
Y=@00onb/]Wo/[SMok:hg@04ok:hg@03ok>nh_nkb>Co^lST00;o^lST5_ooool00ol0003ooooooooo
o`0nooooo`00C?ooool2o`0000Gooooo00?o0000ooooooooool0A?ooool2o`0000Co>P000oli0000
0olh003oD00Wodl09@03odl09@;oCP0S1?m<0202od/07@;oViC;0_nEN;04oiEi/@CoUGZb1?nENk@5
oiEl]PCoUGjg0_nEOkT00onBKJGoTVnWoi9_Y`02oi9_Y`GoTW2Y1?nCLZ/4oi=d[PCoTgN`0onCNK@0
0onJOK;oVWneoiYo]@02oiYo]@GoVX>i1OnKQkd3oi^;`P03ojFEa?nUVLWoYIW900?oYIW900?oYYk>
o`000?nVW/h00_nVW/h00onVY=Co/[;Iok:bf@02ok:bf@Co/[SM00?o_<WTok_8i?nkb>@00_nkb>@0
0onkbnKoooooooooo`0Dooooo`03o`000?oooooooooo03kooooo0019ooooo`?o0000COooool00ol0
003o>P00ocX00003ocX000?o>@000om@02L3odl09@?oCP0S0om<02000om;01goVi;:oiIg[`04oiEh
/0GoUGVa0onEN[85oiEk]0CoUGbf0_nEO[L2oi9/Y0?oTVfU1OnBKjL4oi9`Z@CoTg:[1OnCM:h3oi=g
/004oi=i]?nJOK;oVWfboiYm/PGoVWne1?nJPkT5oi^7_@03oi^;`_nUULCoYIG400;oYIG41?nUVLT2
ojJNcP03o`000?nVW/ko/JkE00Ko/[;I00?o/[SMokc9i?nlbN@00_nlbN@00onkb>Co^l_Vok_;iP02
ok_;iQCooooo0ol0000oooooo`008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^023ooooo0_l0001=
ooooo`03o`000?lj003o>P0000Ko>P0000?o>@00oe40:?m@02L00_m@02L4odl09@?oCP0S00?oC00P
oiIg[_nFMjh00onFMjl5oiEh/0CoUGVa0onEN[85oiEk]0;oUGbf0_nBJj<4oi9/Y0CoTVfU1?nBKjL4
oi9`Z@CoTg:[1OnCM:h2oi=g/003oiUj[onJOK;oVWfb00?oVWfb1?nJOkD5oiZ3^@?oVhNm00?oYI71
ojFEa?nUUL@00onUUL@5ojFIb@03ojJNc_l0003o/JkE00;o/JkE1?nb/]T00onmbnGo_<WTokc9i002
okc9i003okc@jOnkbnKo^l_V00Co^l_V5Oooool00ol0003oooooooooo`0mooooo`008_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg01gooooo0ol00002ooooo`03o`000?oooooooooo04Oooooo00?o0000
ocX00?lj00001_lj0002oe80:@?oD@0X0om@02L3odl09@;oCP0S00?oUWJ^oiIg[_nFMjh00_nFMjh4
oiIg[`CoUGR`1?nENK44oiEj/P?oUG^d00?oTFZRoi9[XonBJj<00_nBJj<5oi9/Y0?oTVfU1?nBKjL4
oi9`Z@GoTg:[0onCM:h00onIN:goVGZ_oiUj[`02oiUj[`CoVWfb1?nJOkD5oiZ3^@03oi^7_OnUTL7o
YI7100;oYI711?nUUL@4ojFIb@03ok6[d_na[]Go000000Co/JkE00?o/[;Iokg;iOnmbnD00_nmbnD2
okc9i0?o_=3Y1?nkbnH2okS<jAGooooo00?o0000ooooooooool0??ooool002;ooooo00Go410@oooo
oooooooooooooa0@400Kooooo`;o0000Boooool00ol0003o>@00ocT00006ocX000;oD`0Z1?mB02T2
oe40:0CoD00W0om?02D3oiIf[PGoUWN^0onFMjl4oiEh/0GoUGVa0onEN[801?nENkCoTFZRoi5ZX_nA
JZ84oi9[X`GoTVbT0onBKJD4oi9_Y`GoTW2Y1?nCLZ/01?nCM:koVGR]oiUh[OnIN:d4oiUj[`CoVWfb
1OnJOkD3oiZ3^@03ojF?__nUTL7oYI7100?oYI711OnUUL@00onUVLWo/J_Bok6[dP02ok6[dP05o`00
0?na[]Go/JkEok6^eOnmcNH01OnmbnD00onlbNCo_=3Yokc@j@03okc@j@03ok_;i_nhc>Wo^<cY00?o
^<cY5Oooool00ol0003oooooooooo`0kooooo`008_ooool01Ol0003ooooooooooooooooo000001So
oooo0ol0001:ooooo`03o`000?lh003o>@0000?o>@000olj00000omC02_oD`0Zoe<0:P02oe<0:P?o
DP0Y0omA02P3oe009`;oC`0U0_nFMZd4oiIf[PCoUWN^0onFMjl5oiEh/0CoUGVa0_nEN[800onAJJ7o
TFZRoi5ZXP02oi5ZXPGoTV^S1?nBK:@3oi9]Y@CoTVnW1OnBL:T2oi=bZ`;oV7J[1OnIN:d4oiUj[`Co
VWfb1?nJOkD00onJPkWoYHnnojF?_P02ojF?_PCoYI711?nUUL@00onaZ<oo/J_Bok6[dP03ok6[dP03
o`000?na[]Go/JkE00?o_LgV0onmbnD2okgEk0Co_=3Y0_nhdNd4okS<j@03ok?9jooooooooooo01?o
oooo00?o0000ooooooooool0>oooool002;ooooo00Go0000ooooooooooooooooo`00000Fooooo`?o
0000Boooool00ol0003o>000ocP00003ocT000?o>P000_mC02/3oe<0:PCoDP0Y0omA02P2oe009`Ko
UWJ]0onFMZh4oiIg[P?oUWN_1OnEN;02oiEi/@;oTFVP0onAJJ45oi5ZXPCoTV^S1?nBK:@3oi9]Y@Go
TVnW0onBL:T00onHMJWoV7J[oiQfZ`02oiQfZ`GoVGR]1?nINZl4oiYm/P;oVWne0_nUSK`5ojF?_PGo
YI7100?oYIG4ok6XconaZ<l00_naZ<l4ok6[dP03o`000?na[]Go_LgV00?o_LgV00?o_L_UokgEk?nm
eN`00onmeN`00onld>Wo^=7]okSAk@03okSAk@03okS<jOncbN_o/lW[00;o/lW[5Oooool00ol0003o
ooooooooo`0jooooo`008_ooool01Ol@413ooooooooooooooooo410@01?ooooo0ol00002ooooo`03
o`000?oooooooooo04Kooooo00?o0000ocL00?lg00000_lh0003ocT00003ocX00?mC02_oD`0[00?o
D`0[0omC02X3oe80:@?oD@0X00?oD00WoiIf[OnFMZd01_nFMZd3oiIf[PCoUWN^1?nFMjl3oiEh/003
oi5XWonAJJ3oTFVP00;oTFVP0onAJJ45oi5ZXPCoTV^S1?nBK:@4oi9]Y@CoTVnW00CoTW2YoiQeZOnH
MJWoV7FY1OnHMZ/4oiUh[@CoVGZ_0onJOK800onUS;_oYHflojF=_003ojF=_0CoYHnn1?nUTL400ona
Ylko/JS?ok6Xc`03ok6Xc`Co/J_B00?o0000okkAj?nmcNH00_nmcNH2okgKk`Co_MG/0_nheo04okSA
k@;o//k^1?ncbN/Fooooo`03o`000?oooooooooo03Wooooo000Rooooo`05ogMgMonHV9SooooooiRH
V?mgMgL04?ooool3o`0004_ooooo00?o0000ocH00?lg00000olg0002ocP00003ocT00?mC02_oD`0[
00GoD`0[0omC02X4oe80:@04oe40:?nFMZcoUWJ/oiIf[0SoUWJ]0onFMZh5oiIg[P?oUWN_00CoUGR`
oi5XWonAJ9ooTFRO1?nAJJ04oi5YX@CoTFZR1?nBJj<5oi9/Y0?oTVfU0onBKjL00onHLjSoV7FYoiQe
Z@03oiQeZ@CoV7J[1?nIN:d5oiUj[`04oiYm/_nUS;_oYHbkojF<^`CoYHfl1OnUSkh00onUTL7o/JO>
ok6WcP02ok6WcPGo/JS?00Co/J_BokkAj?nndNSo00000_nndNP00onmcNKo_M__okgKk`02okgKk`03
okgEk?nheo3o^=O`00?o^=O`00?o^=7]ok;>k_nbc^h00onbc^h2ok?9j`;o[LG[5?ooool2o`0003_o
oooo000Rooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool2o`0004gooooo00?o0000ocH00?lf
00000olg00000olh003oD`0[oe<0:`08oe<0:`?oD`0Z00?oDP0YoiIf[?nFMZ`01OnFMZ`8oiIf[@Co
UWJ^1?nFMjh2oiIg[`GoTFRO1OnAJJ03oi5YX@CoTFZR1?nBJj<5oi9/Y0?oTVfU00CoTVnWoiQcZ?nH
LjSoV7>X1OnHMJT4oiQfZ`GoVGR]0onINZl00onURk[oYHbkojF<^`02ojF<^`CoYHfl1?nUSkh00ona
Y/go/JO>ok6WcP03ok6WcPCo/JS?0_noeNX2okkAj003o`000?nndNSo_>;b00Co_M__0_nfgO<4okSG
l0;o/]?b1?nbc^h00on]b>go[LG[ojg5j`03ojg5jaGooooo00?o0000ooooooooool0>?ooool003;o
oooo1Ol0001:ooooo`03o`000?ld003o=00000;o=P000olg000<oe<0:`03oe<0:_nFMZcoUWJ/00So
UWJ/2?nFMZd4oiIf[P;oUWN^0_nAIih8oi5XW`CoTFVP0onAJJ44oi5ZXPGoTV^S1?nBK:@2oi9]Y@03
oiMbYonHLjSoV7>X00?oV7>X1?nHMJT4oiQfZ`GoVGR]00CoVGZ_ojF;^_nURk[oYH^j1?nUS;/5ojF=
_003ojF?__naY/go/JK=00;o/JK=1OnaYlh00onaZ<oo_mGZokoEjP03okoEjP;o00000onlh_800onm
fnoo]]gcokKMl`03okKMl`03okSGl?nbdo;o/]?b00?o/]?b00?o//k^ojg8kOn]b>d00_n]b>d3ojg5
j`03oj[3k?oooooooooo01Cooooo00?o0000ooooooooool0=oooool0033ooooo0_l0001<ooooo`03
o`000?la003o=00000;o=0000olf00000olg003oD`0Zoe<0:`0;oe<0:`03oe<0:_nFMZcoUWJ/00[o
UWJ/2?nFMZd2oiIf[PGoTFNN2?nAJ9l4oi5YX0?oTFVQ1?nAJZ85oi9[X`?oTVbT00CoUg6VoiMbYonG
LZOoUg:W1OnHLjP4oiQeZ@GoV7J[0onIN:d00onURkWoYH^jojF;^P03ojF;^PCoYHbk0onUSK`6ok6V
c@Co/JO>0_nofnd2okoEjP?o000000Co_>;bo`000?nlh_;o_>;b0onchoL2okKMl`?o/=Se1?nbdo80
0on/b^oo[LS]ojg8k@03ojg8k@03ojg5jonZ`ncoZ/?/00;oZ/?/5Oooool00ol0003oooooooooo`0g
ooooo`00;Oooool3o`0004cooooo00Co;P00oc400?la003o<@000_ld00000olf003oD`0Zoe<0:P03
oe<0:P[oD`0[0onGMZ`<oiIf[0SoUWJ]00?oUWJ^oi5WW_nAIih01?nAIih8oi5XW`CoTFVP0onAJJ45
oi5ZXPCoTV^S00CoTVbToiMaY_nGLJKoUg6V1?nGLZL4oiQcZ0CoV7FY1OnHMZ/01?nIN:goYH^iojF;
^OnURkT5ojF;^PCoYHbk00?oYHflok6VcOnaY/d01onaY/d01?naYlko_m_]okoKkOnofnd3o`0000Co
^NSe00?o_>;bo`000?nchoL00_nchoL2ojgLn0Go/=Se00?o/]?bojc:kon/b^l00_n/b^l2ojg8k@?o
Z/C]1OnZ`n`Eooooo`03o`000?oooooooooo03Kooooo000/ooooo`;o0000C?ooool3obh000;o<@00
00?o=000oe80:OmC02X01OmC02X7oe<0:`?oUgJ]1OnGMZ`;oiIf[0KoUWJ]0_n@IYh8oi5WWPOoTFRO
1?nAJJ04oi5YX@CoTFZR0onBJj<00onFL:GoUg6VoiMaYP03oiMaYP?oUg:W1?nHLjP5oiQeZ@?oV7J[
1_nURkT4ojF;^PCoYHbk2OnaY/d2okkQl@?o000000Co_m_]ok?^m_nck_Ko/nkf0_nij?D3ojoWn@03
o`000?n]g?So[Mch00?o[Mch0_n`f?D2oj_<l@Co[<[_00?oZLG^oj[4kOnZa>d01?nZa>d2oj[3k0?o
Z<7[5Oooool00ol0003oooooooooo`0eooooo`00;?ooool3o`0004Sooooo00?oB<:Vob/00?l^0000
0_l^0002oc4000?oDP0Y1_mC02X4oe<0:`?oV7N]1?nGMZd4oiMf[0_oUWJ/0_nFMZd2oi1VW@CoT6JN
2?nAIih7oi5XW`CoTFVP1?nAJJ44oi5ZXP04oi9[XonFL:GoUW2UoiI`Y@GoUg6V0onGLZL4oiQcZ0Go
V7FY00?oV7J[ojF;^OnURkT01_nURkT5ojF;^P;oYHbk2?naY/d01_nnhO7o0000o`000?l0003o_^7a
okoKk@Co/nkf00?oZN[jojoWnOn_ioT00_n_ioT2oj[PnP03o`000?n]g?So[Mch00?oZ/kc1?n[c?40
0on/b^ooZLG^ojW5kP02ojW5kPCoZ/C]00?oZ<;/ojS1jonX`N/01?nX`N/Dooooo`03o`000?oooooo
oooo03Gooooo000/ooooo`04o`000?oooooo0000o`0004Gooooo00Co9`00ob/00?l[003o:`000_l^
00000ola003oDP0Woe80:@02oe80:@KoD`0Z1?mC02/5oiQg[@?oUgJ]1?nGMZ`:oiIf[0GoT6JM1?n@
IYh8oi5WWPOoTFRO1OnAJJ03oi5YX@;oTFZR0_nFKj@5oiI`Y@CoUg6V0onGLZL5oiQcZ0?oV7FY2_nU
RkT5ojF;^P03ojF<^onaY/go/JK=00Go/JK=0ol00003okkQl@?oZo;e00?o/nkfojWZn_nYj_X00_nY
j_X00on_ioWoZ^3joj[PnP02oj[PnP03o`000?nYcoCoZ/kc00CoZ/kc0_n[c?42ojW6k`GoZLG^00?o
Z/C]ojS2k?nX`^`00_nX`^`4ojS1j`03ojS0jooooooooooo017ooooo00?o0000ooooool000002?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<
c<`06Oooool002cooooo0_l00002ooooo`03o`000?oooooooooo043ooooo0olW0002ob/00003obh0
0?mA02KoDP0W00;oDP0W0omB02T6oe<0:P04oe<0:onHN:goV7R]oiQh[@GoV7N]0onGMZd4oiMf[0Wo
UWJ/1_n@IYd4oi1VWPSoTFNN2?nAJ9l4oi5YX0;oTFVQ00?oUVjSoiI_Y?nFKj@00_nFKj@5oiI`Y@Co
Ug6V0onGLZL5oiQcZ003oiQeZOnURkWoYH^i00_oYH^i0onURkX00onaZ<oo/JK=ok6Vc@03ok6Vc@?o
00000onlio<00onnhO7oZo;eoj_bm@02oj_bm@?oX^ci0_nYj_X3ojKRn`06oj[Pn_nYcoCoZLodojW?
m?l0003oZLod0_nZc_<2ojS7k`GoZLK_0_nYaNh8ojS2k003ojS1jonX`>_oZ<3[00;oZ<3[5Oooool0
0ol0003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0Iooooo`00:oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo03gooooo00Co8P00obL00?lW003o9`000_l[0003oe409P;oDP0W0omB02T5oe<0:P?oVGV^
1?nHN:d4oiQg[@?oUgJ]1OnGMZ`5oiIf[0[oT6JM0on@IYh8oi5WWPSoTFRO1?nAJJ000onAJJ7oUVjS
oiI^X`05oiI_Y0CoUW2U1?nGLJH4oiMbY`?oV7>X3onURkT00onURk[o/JS?ok6Xc`02ok6Xc`;o/JK=
0_l000000onaY/go_>OcokcWl`02okcWl`?oW_;`00?oZo;eoj;/nOnRk?T00_nRk?T2oj;To0;oY^;k
0onXd?D4ojW?m003o`000?nXanooZ<O_00?oZ<O_0_nYa^l3ojS2k@OoZ<;/1onX`>/Eooooo`03o`00
0?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool000006Oooool002_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0kooooo`06
ob800?lW003o9`00obL00?l[003oD00T0omA02H3oe809`?oDP0Y0_mC02X2oiUj[`GoVGV^0onHN:d4
oiQg[@CoUgJ]1?nGMZ`2oiIf[0goT6JM0on@IYh8oi5WWPSoTFRO0_nAJJ02oiE^X`?oUVjS1OnFKj@4
oiI`Y@GoUg6V0onGLZL00onHLjSoYH^iojF;^@0>ojF;^@03ok6Yd?naZ<oo/JS?00;o/JS?0ol00000
1OnaY/go]ngfokO]m_ngkOKo_>Oc00?oW_;`1?nJk?L01?nRk?WoX^Cloj;To?nRi?`2ojOAmPGoZ=3e
00GoZLodojS7l?nXao3o0000ojS7l003ojS7k`03ojS3kOnX`^goZ<;]00CoZ<;]0_nX`^`2ojO1j`Oo
Z<3[0onW`>/Eooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?nHV9SooooooiRHV?lQ8B406Oooool002_ooooo0ol00005ooooo`03o`000?oooooooooo
03Oooooo0_lM00001?lR003o9`00odl08_m?0283oe0090?oD@0V0omB02L3oe80:@03oiYk/?nINZoo
VGZ_00;oVGZ_1?nINJh3oiQh[@CoV7N]1?nGMZd2oiMf[17oT6JM1?n@IYh7oi5WWPOoTFRO00?oUFfS
oiE^XonEKZ<00_nEKZ<4oiI^X`CoUVnT1?nFL:D5oiMaYP;oUg:W00?oYH^jojF;^OnURkT03OnURkT4
ok6Yd0?o00000_naZ<l01?naY/go]ngfokO]m_ngkOH2ohg^iP?oTN_d0_nJk?L3oikUo003oj;To?nW
dOKoYm7f00?oYm7f0_nXd?D3ojO7l0?oZ<O`00?o0000ojS7konX`nd00onX`nd4ojS2k@03ojO1k?nW
`N_oYl7[00?oYl7[0_nX`>/8ojO0jaGooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Iooooo`00:oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo03?ooooo00Go5`00oad00?lM003o7@00odd07P04odl08P;o
D00T0omA02H3oe809`;oDP0Y0onJNk04oiUj[`CoVGV^0onHN:d5oiQg[@;oUgJ]5?n@IYd4oi1VWPSo
TFNN1?nAJ9l3oiE]X`CoUFjS1?nFKZ<4oiI_Y0GoUW2U1?nGLJH01?nGLZOoYH^jojF;^_nURkX<ojF;
^@03ok:/d_naZM3o/JW@00?o00001?naZ<l2ok3am@03okO]m_n=k^KoSNkV00?oTN_d1?nJiO`2oikU
o0?oY]7f0_nWdOH8ojO7l0;oZ<O`00?oYl?]o`000?nX`nd01?nX`nd00onX`^goYl7/ojO1k002ojO1
k0?oYl7[2onW`>/Eooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooooooooa0@400;
ooooo`03oeEEEOn7QhOooooo01_ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0<Oooool2oaL000;o7@000_m=01h3odl08P?oD00T0omA02H00omB02OoZ9c9oi]l/@02oi]l
/@CoVW^`0onINZl4oiUi[PCoV7R]1?nHMjd00onGMZgoT6JMoi1VW@0Coi1VW@CoT6JN2?nAIih2oi5X
W`03oiA/X_nEKJ?oUFfS00;oUFfS1OnEKZ<3oiI^X`CoUVnT1OnFL:D3oiMaYP03ojF<^_nURk[oYH^j
00;oYH^j2_nURkT2ok:/dP?o00001?naZM001OnaZ<oo/?7eok3amOn`lOGoN^GG00?oR>W`0onHiO`2
oi[Uo0;oYM7g1?nVdOH9ojO7l0KoYl?]00?o0000ojS3kOnX`nd02?nW`N`00onW`N_oYl3[ojO0j`0;
ojO0ja?ooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRH
V00Kooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o
410@ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02gooooo0_l?
0002oaL00004oad00?m;01_oC@0Nodd07PCoC`0R0_m@02@2oe409P;oZIk;00?oW7jboi]l/OnKO;40
0_nKO;44oiYk/0?oVGZ_1OnINJh3oiQh[@;oV7N]0_n@IYhFoi1VW@CoT6JN2?nAIih00onAJ9ooU6bR
oiA/XP05oiE]X`CoUFjS0onFKZ<5oiI_Y0CoUW2U00CoUg6VojF<^_nUS;[oYHbj1OnURkX7ojF;^@04
ok:_eOl0003o0000o`0000;o/ZcB1?naZM02ojKclP05ofGHaOn1ingoPNO]oh7WkOn8jO001?nHiO`6
ojGAm`03ojKAm_nWao3oYlO`00KoYlO`2?nW`nd00onW`>co0000ojO0k007ojO1k17oYl3[5Oooool0
2Ol0003oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@
41Wooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01?ooool3o`0000[ooooo00?o0000ooooooooool0:Oooool01_l6003o3`00o`l00?l?003o
5`00odT05`?oB`0K0_m=01h3odl08P?oD00T00?oZj3<oif0/onLO[800_nLO[84oi]l/@CoVW^`1?nI
NZl4oiUi[P;oV7R]00?oT6NNoi1VW_n@IYh00_n@IYhFoi1VW@CoT6JN1_nAIih5oiA/XPGoUFfS1?nE
KZ<3oiI^X`GoUVnT0onFL:D00onUSK_oYHbjojF<^P03ojF<^PCoYH^j1OnURkT3o`000003ok:_eOnb
[=;o/ZcB00?o/ZcB00?o/JW@ojKcl_nVlo800_mUf<D2oh7Wk@CoUNGl00?oV>GlojGAmonUdOL01OnU
dOL8ojO7l0OoYl?]1OnW`>`01?l0003oYl3/ojO1k?nW`N`EojO0jaGooooo00?o0000ooooooooool0
;oooool000Sooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Wooooo`;o1P000_l?0003odT05`;oB`0K
0_m=01h4odl08P03oe009?n[X<coWH2c00;oWH2c1?nLO[84oi]l/@?oVW^`1?nINZl2oiUi[PGoT6NN
1?n@IYhGoi1VW@?oT6JN0onAIih00onCK:;oU6bRoiA/XP06oiA/XPCoUFfS1?nEKZ<4oiI^X`CoUVnT
00?oUW2UojF=^onUSK/00_nUSK/4ojF<^PCoYH^j0onURkT2o`0000Co/ZoE1?nb[=82oiSaj`03oe39
/_mji>WoN^CY00?oTnGl0_nEiO`4ojCAm`;oYM7g0_nVao07ojO7l0WoYl?]1onW`>`00ol0003oYl3[
ojO0j`0FojO0jaGooooo00?o0000ooooooooool0;_ooool0013ooooo00Go0000oooooooooooooooo
o`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Tooooo`05o`000?l6003o1P00o`l00?m601800om901L2od/06`?oC@0N00GoC`0RojfU
con/Xlko[:?>oij2]005oif0/`?oW7jb1?nKO;44oiYk/0;oVGZ_00?oTFNOoi1WW_n@Iih01On@Iih4
oi1VWQOoT6JM0on@IYh01?nAIikoTfbRoi=/X_nCK:88oiA/XPCoUFfS1?nEKZ<4oiI^X`?oUVnT00?o
YHflojF=^onUSK/00onUSK/4ojF<^PCoYH^j0ol00002ok:bf0Go/ZoE00?o/ZcBoiSajonHlN/00_md
h^D3oi;Uo0;oTnGl1_nTdOL2ojK6l0CoY/O`0_nWao0:ojO3k@SoYl3/0_nW`>/00ol0003oYl3[ojO0
j`0GojO0jaGooooo00?o0000ooooooooool0;Oooool0013ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?l6003o@`0<00?oAP0B0_m901L3od/06`05odd07_n]YLoo[JG?ojfUconO
Q;H00onNP[@5oif0/`?oW7jb1?nKO;44oiYk/003oiUj[onAIiooTFNO00SoT6NN0on@IYhGoi1VW@;o
T6JN00?oTf^Qoi=/X_nCK:800_nCK:88oiA/XPCoUFfS1OnEKZ<3oiI^X`03oiI_Y?nUSKcoYHfl00;o
YHfl1?nUSK/5ojF<^P?o000000?o/[KKok:bf?nb/]P00onb/]P2ok:_e@;oQncP0_m_gn801?mdh^Go
T^Gloi;Uo?nBiO`2ojC@m`KoY=7g1OnVa_02ojK7l0;oYl;]1onW`nd3ojO0j`KoYl3/1_nW`>/00ol0
003oYl3[ojO0j`0GojO0jaCooooo00?o0000ooooooooool0;Oooool0013ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo0_l0000?ooooo`;o00007oooool3o`00
00?o@`0<0_m60183odT05`03od/06on_Z=7o[jSA00;o[jSA00?o[JG?oin4]_nOQ;H01?nNP[@4oif0
/`CoW7jb0onKO;42oiYk/0;oTFRO0onAIil8oi1WWP?oT6JN5On@IYd5oi=[X@GoTfbR1onDK:84oiE]
X`GoUFjS0_nFKZ<00onUS[goYHflojF=_003ojF=_0GoYHfk00GoYHbjo`000?l0003o0000ojF;^P04
ok:ff`?o/[;H0_meh]83ofoOhP?oT^Gl1_nTd?L2ojCAm`OoY/K`1_nW`^d2ojO3k@SoYl3[0_nW`>`:
ojO0j`03o`000?nW`>_oYl3[01KoYl3[5Oooool00ol0003oooooooooo`0/ooooo`004?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo01Wooooo1?l000001?ln00Go@`0<od<03?m300`2odH04P?oB@0G0_n`
Z]82ojnXd@;oXHJh1?nOQ;H3oij2]0GoWH2c0onLO[82oi]l/@03oi5YX?nAJ9ooTFRO00;oTFRO1?nA
Iil7oi1WWPCoT6JN4On@IYd00onBJj7oTf^Qoi=[X@05oi=[X@GoTfbR1onDK:85oiE]X`CoUFjS00Co
UVjSojF>_OnUS[goYHjm1?nUSK`3ojF=^`?o000000?oYHbjok>jgonc^]l01_nb]]/00onb/]SoMN;B
ofcMh004oi7To003oi;Uo?nTd?OoY=3g00GoY=3g0_nVaO06ojK6l0OoYl;]6?nW`>/00ol0003oYl3[
ojO0j`0FojO0ja?ooooo0_l0000^ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo
00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Oooooo
0_l000001?li003o?P05och01Oln00D2od<030?oAP0B00GoB@0Gok2Zd_n`Z];o/:[Boj:9^@04oj66
^0CoWhBf0onNP[@5oif0/`;oW7jb00CoTVZQoi5YX?nAJJ3oTFVP1?nAJ9l4oi5WW`OoT6NN1?n@IYh@
oi1VW@;oTV^Q2?nCJj44oi=/XPSoU6bR1?nEKJ<3oiE^X`03ojB?__nUS[goYHjm00;oYHjm1?nUSK`3
o`000003ojF=^onc_^?o/k[O00Co/k[O1?nb]]/01?mRe/7oT^Cloi;To?nBi?`2oi7To0KoY=3g0onV
aNl4ojK5l0;oY/K`2OnW`^dIojO0j`03o`000?nW`>_oYl3[01KoYl3[5Oooool00ol0003ooooooooo
o`0[ooooo`00:Oooool2o`0001Cooooo00?o0000ooooooooool05?ooool2o`0000?o>@000_ln00D3
od<03003odH04_nb[M?o/ZgC00;o/ZgC00?o/:[Boj:9^OnRRKT01?nQQ[P4oin4]PCoWX:d0onMP;<0
1?nBJj;oTVZQoi9ZXOnBJZ43oi5YX0CoTFRO1?nAIil7oi1WWPCoT6JN3On@IYd2oi9ZX@?oTV^Q2?nC
Jj44oi=/XPSoU6bR1?nEKJ<00onEKZ?oY8nnojB?_P02ojB?_P?oYHjm00KoYHflo`000?l0003o0000
ojF=_?nUSK/4ok>nh`Go/k[O00?o/[KKoi;To?nBi?`00onBi?`2ojC?mPCoY=3g1onVaNl2ojK5l0Wo
Yl;]7OnW`>/00ol0003oYl3[ojO0j`0FojO0jaGooooo00?o0000ooooooooool0:_ooool002Wooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Aooooo`;o000000Co<`00ocT00?li003o
>@000_ln00D01?m300co/joDok>_e?nc[m@4ok:]d`03ojB<^onRRKWoXXVi00;oXXVi1?nQQ[P4oin4
]P?oWX:d00CoWH2coi9[X_nBJj;oTV^R0onBJZ44oi5YX0?oTFRO1?nAIil7oi1WWPCoT6JN2On@IYd6
oi9ZX@CoTV^Q1onCJj44oi=/XPSoU6bR0_nEKJ<2ojB@_`GoY8nn0_nUS[d2o`0000?oYHfl00?o//?V
ok>nhonc_^<01?nc_^<2ok>jg`04odo9[onChogoT^Cloi;To0OoY<of00?oY=3gojK5konVaNl01OnV
aNl9ojO2kB;oYl3[00?o0000ojO0jonW`>/05_nW`>/Dooooo`03o`000?oooooooooo02[ooooo000Y
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03_ooool00ol0003o:`00oc<00002
oc<000;o>@0000Co?P05okBae_nd/MKo];7F1?nc[m@00onb[M?oY8bkojB<^`02ojB<^`?oXXVi1?nQ
Q[P4oin4]P;oWX:d00?oTfbSoi9[X_nBJj800_nBJj84oi9ZX@?oTFVP0onAJ9l4oi5WW`OoT6NN1?n@
IYh6oi1VW@03oi5ZXOnBJZ7oTVZQ00KoTVZQ1?nBJj47oi=[X@CoTfbR1onDK:800onTTL7oY92oojB@
_`03ojB@_`?oY8nn0ol00002ojF>_@03ojF=_?nb`nKo//?V00;o//?V1?nc_^<01?l0003oTn?moi?S
oOnChod2ojG>mPOoY<of0_nWa>l4ojK5k`SoYl;]9onW`>/00ol0003oYl3[ojO0j`0FojO0jaCooooo
00?o0000ooooooooool0:Oooool002Wooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?l[003o:`0000;o<`0000?o>@00okgGkOnf]=L01Ond/MH2ok>_e003ojF?_OnT
S;_oY8bk00?oY8bk0onRRKT4oj66^0;oWhBf0_nDKZ@3oi=/X`CoTV^R1?nBJZ43oi5YX0CoTFRO0onA
Iil8oi1WWP?oT6JN1On@IYd2oi5ZX@SoTVZQ1?nBJj47oi=[X@GoTfbR1OnDK:83ojBA`@CoY92o0ol0
0002ojB?_P;oYHjm0_nbb>X5ok;3iP05ok>nhonDhogoU>?moiCSoOnChod01OnUc_H2ojC?mP;oYlC^
1OnWa>l00onVaNooYl;]ojO2k@05ojO2kB[oYl3[00?o0000ojO0jonW`>/05onW`>/Dooooo`03o`00
0?oooooooooo02Sooooo000Yooooo`?o00005oooool00ol0003oooooooooo`09ooooo`;o8@000_l[
0002oc<00003okgGkOnf]=Oo][CG00;o][CG0ond/MH00onWT[ooYHnmojF?_@02ojF?_@CoY8bk1?nR
RKT2oj66^003oiE_YOnDKZCoU6jT00;oU6jT0onCK:<4oi9[XPCoTVZQ0onAJJ04oi5XW`?oTFNO2?n@
Iih3oi1VWP;oT6JM1OnAJZ48oi9ZX@CoTV^Q2?nCJj44oi=/XP?oU6bR00?oY972ojBA`OnTTL400_nT
TL401?nTT;oo0000o`000?l00005ojB?_P03ojF>_Onbb>[o//SZ00;o//SZ0_nb`nH3oiGSo@;oU>?m
1OnUc_H7ojO4kP;oYlC_2OnW`^d/ojO0j`03o`000?nW`>_oYl3[01KoYl3[4oooool2o`0002[ooooo
000Yooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01Oooool01?lC003o8@00ob40
0?lQ0002ob/00003oc<00?nnenco]kKH00Ko][CG00Co];7FojNB_onWT[ooYi:o0onUSkd5ojB<^`?o
XXVi00?oXHJhoiE_YOnEKjD01?nDKZ@4oi=/X`?oTV^R1?nBJZ43oi5YX0CoTFRO1?nAIil7oi1WWP;o
T6JN00?oTFVRoi5ZXOnAJZ401_nAJZ48oi9ZX@?oTV^Q2?nCJj44oi=/XP03oiA/X_nTTL;oY97200;o
Y97200CoY971o`000?l0003o00001?nTT;l2ojB?_P?o/Lc^0onbb>X01?l0003oU^;moiGSoOnEhod4
ojG>m@;oYLkf0_nW`nh7ojO4kPWoYl;]<?nW`>/00ol0003oYl3[ojO0j`0FojO0jaCooooo00?o0000
ooooooooool09oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`03ofOI`_lC003o
8@0000;o8@0000Co:`00okoFjonoe^_o_]O/0ong]]P4okJde`03ojVF`_nWT[ooYi:o00;oYi:o0onU
Skd5ojB<^`;oXXVi00CoUW6WoiE_YOnEKjGoUFnU1?nDKZ@4oi=/X`CoTV^R0onBJZ43oi5YX0CoTFRO
1?nAIil5oi1WWPGoTFVR2?nAJZ48oi9ZX@?oTV^Q2?nCJj42oi=/XP;oXi;30onTTL83o`0000?oY971
0onTT;l2ojoAl@Go/Lc^00?o//SZoiKRoOnUcOD00_nUcOD4ojG>m@KoYl?^0_nWa>h3ojO2k0KoYl;]
=?nW`>/00ol0003oYl3[ojO0j`0FojO0jaGooooo00?o0000ooooooooool09_ooool000kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Go
oooo00?o0000ooooooooool06oooool00ol0003oooooofOI`P02oa<00003ob400?nal_Co_mK[00?o
_mK[00?o^KSHokNff?ng]]P00ong]]P00onf]=OoZIK2ojVF`P02ojVF`P?oYi:o1?nUSkd2ojB<^`;o
Ug>Y0onFLJL4oiE_Y@?oU6jT1?nCK:<4oi9[XP?oTVZQ1?nAJJ03oi5XW`CoTFNO0_n@Iih00on@JJ;o
TFVRoi5YXP05oi5YXPSoTFZQ2?nBJZ44oi9[X@KoTf^Q00?oXi;4oj>B`onST/<00_nST/<3o`0000;o
Y9721?nTTL400onTT;oo[m7aojoAl@03ojoAl@;o/Lc^00?oUn;mojG=mOnUcOD01OnUcOD00onUc_Go
Yl?^ojO3kP05ojO3kP03ojO1k?nW`^coYl;/00CoYl;/0_nW`^dhojO0j`03o`000?nW`>_oYl3[01Ko
Yl3[5?ooool00ol0003oooooooooo`0Vooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0_l0000Looooo`;o0P0000?o4`00okK`mOnf
l?D00oo0eNX00onoe^_o^KSHokVhf002okVhf0?o]kKH00?o[9W4ojVF`_nYU/800onYU/84ojNB_`;o
YHnm00?oVGJ[oiMcZOnGLjT00_nGLjT4oiIaY`?oUFnU1?nDKZ@3oi=/X`CoTV^R1?nBJZ43oi5YX0?o
TFRO0_nAIil2oi1ZXP?oT6VR2?nAJJ87oi5ZX@SoTVZQ1?nBJj45oi=[X@?oXi;400CoXi;3o`000?l0
003oXi;31OnTTL82ojBA`@;o[]Gd1?n_dO400onHh_goYLgdojG=m006ojG=m@WoYl?^0onW`N`4ojO2
k003ojNojonW`>_oYl3[03WoYl3[00?o0000ojO0jonW`>/05_nW`>/Dooooo`03o`000?oooooooooo
02Gooooo000>ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05oooo
o`03o`000?oooooooooo01Wooooo00?o0000o`800?nik?D00_nik?D01?nfl?Go`=GZol3Ej_o0eNX2
okZjf@Go^KSH00Co]kKHojbIa?n/VLCo[9W41?nYU/84ojNB_`03ojF?_OnIMZ_oVGJ[00CoUg>Y1?nF
LJL3oiE_Y@CoU6jT0onCK:<4oi9[XPCoTVZQ0onAJJ02oi5XW`03oi1ZXon@JZ;oT6ZR00;oT6ZR0on@
JJ88oi5YXPOoTFZQ2?nBJZ44oi9[X@;oTf^Q0_nRT/@2oj>Ba0?o00000onST/<4ojBA`P;o[=Sg1?n^
eO@00on_dO7oV>;mojG=m004ojG=m0;oYLge0_nW`nd7ojO3kPOoYl7/00?oYl;/ojNojonW_n/00_nW
_n/kojO0j`03o`000?nW`>_oYl3[01GoYl3[5Oooool00ol0003oooooooooo`0Tooooo`003_ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01?ooool00ol0003ooooooooo
o`0Gooooo`;oSNkW1?nik?D3ol7Dj003ol3Ej_nj^]Wo^[[I00;o^[[I0oni^=P00on^WLKo[9W4ojbI
a002ojbIa0GoZIK20_nWT[l00onJNJgoVGJ[oiUfZ`02oiUfZ`?oUg>Y1?nFLJL3oiE_Y@CoU6jT1?nC
K:<3oi9[XPCoTVZQ0_nAJJ04oi1ZX`CoT6ZR1?n@JJ87oi5YXPOoTFZQ2?nBJZ42oi9[X@;oXI;50onR
T/@3o`0000;oXi;41OnST/<00onTTL;o[=SgojcHm`03ojcHm`;o[]Gd00CoV>;mojK=m?nVcOCoY/gd
0_nUcO@7ojO3k@;oYl?^2OnW`N`8ojNojc[oYl3[00?o0000ojO0jonW`>/05_nW`>/Cooooo`;o0000
2?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`02Oooool000kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo
00?ooooo0_l0000Eooooo`?oW?7b0onlj?@00onik?Go`MCXol7Dj002ol7Dj003ok^kfOnj^]Wo^[[I
00Co^[[I00Co^KSHojjMa_n^WLKo[Yg60on/VL@4ojVF`P04oial/?nJNJgoVWV]oiYi[@CoVGJ[0onG
LjT4oiIaY`?oUFnU1?nDKZ@4oi=/X`?oTV^R0_nBJZ42oi1[Y0KoT6ZS1?n@JZ84oi1YXPOoTFVR2?nA
JZ46oi9ZX@03oj2BaOnQT/GoXI;500;oXI;50ol00002oj:Ba0CoXi;40_nST/<4ojWKn@;o[=Sg00?o
VN;mojK=m?nVcO@01?nVcO@00onW`^goYl?]ojO3k@06ojO3k@WoYl7/2OnW_n/mojO0j`03o`000?nW
`>_oYl3[01KoYl3[5?ooool00ol0003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@09ooooo`003_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`;o00005Oooool2oica
lPCo_>Sd1?o1d^L01?o1e>So^k_Iok^kfOnk^mT4okZjf@03ok2QbOn^WLKo[Yg600;o[Yg61?n/VL@0
1?nYU/;oW7b`oial/?nLO;04oiYi[@?oVGJ[1?nGLjT3oiIaY`CoUFnU0onDKZ@4oi=/X`;oTV^R1On@
Jj@7oi1ZX`?oT6ZR1?n@JJ87oi5YXPSoTFZQ1OnBJZ43oj2Ba@?o000000?oXI;5oj:Ba?nRT/@00_nR
T/@3oj>Ba0;oY]gj1?nYfoT00onJh_goY/cdojK<m006ojK=m0?oYl;]1?nW`nd8ojO1k0WoYko[@_nW
`>/00ol0003oYl3[ojO0j`0FojO0jaCooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go0000ooooooooooooooooo`000009ooooo`003_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`03o`000?oooooooooo
017ooooo00?oJmgRojO^n?nWk_P01?nmho800onlj?Co`M;Wol7Bi`02ol7Bi`03okfmf_nk^mWo^k_I
00?o^k_I00?o^[[Iok2QbOn`XLT00_n`XLT4ojjMaP;o[9W400?oWX2boial/?nLO;000_nLO;04oiYi
[@?oVGJ[1?nGLjT4oiIaY`?oUFnU0onDKZ@2oi=/X`;oT6bU1on@Jj@7oi1ZX`CoT6ZR0on@JJ88oi5Y
XPOoTFZQ0_nBJZ42oinBaP04oj2BaOl0003o0000o`0000CoXI;51OnRT/@00onST/CoY]gjojKMnP02
ojKMnP03ojWKnOnVc?CoY/cd00CoY/cd0_nVcO@7ojO2k@03ojO3kOnW`NcoYl7/00GoYl7/2OnW_n]6
ojO0j`03o`000?nW`>_oYl3[01GoYl3[5?ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Wooooo000Wooooo`03o`000?oo
oooooooo00kooooo1?n^j?T00onWk_So_N?bokgSlP02okgSlP?o`]3V00?o`M;Wokfmf_nm_MX00_nm
_MX3ok^kf@03ok:Ubon`XLWo/:7900?o/:790on^WLH01?nQQKKoWX2boij0/_nNP;84oial/0CoVWV]
0onIMZ/4oiMcZ@CoUW6W0onEKjD2oiA^Y003oi5]Y_n@K:GoT6bU00;oT6bU1on@Jj@7oi1ZX`CoT6ZR
0on@JJ88oi5YXPKoTFZQ00?oWY76oinBa_nOT/H00ol00003oj2Ba@GoXI;50_nRT/@4ojCNn`;oY]gj
1onVc?@9ojO2k@KoYl7/2OnW_n]9ojO0j`03o`000?nW`>_oYl3[01KoYl3[5?ooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<
00Wooooo000Wooooo`;o00003?ooool2oh?TmPCo[^Si1?nngNl01?nmho;o`]3Vol;@i_o2d>H2okjn
fPGo_KgJ00Co^k_Iok:UbonbYL_o/ZG;1On`XLT00on^WLKoXHFfoj65]P04oij0/PCoW7b`0onJNJd4
oiUfZ`?oUg>Y1?nFLJL2oiE_Y@04oi5^YonAKJKoTFfVoi5]YPCoT6bU1on@Jj@7oi1ZX`CoT6ZR1?n@
JJ87oi5YXP;oTFZQ0_nMT<D3oijAaP;o00000onOT/H4oj2Ba@;oXI;51?nRgo`2ojCNn`03oi_RoOnV
c?CoY/cd00CoY/cd2OnW`^d8ojO1k0WoYko[C?nW`>/00ol0003oYl3[ojO0j`0EojO0jaGooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo
^[Zjoa0@4009ooooo`009oooool00ol0003oooooooooo`08ooooo`?oU>7m1?nbgoL00on^j?Wo_]g_
okkMk`02okkMk`?o`/kT00?o`]3Vokjnf_nn_]X00_nn_]X3okfmfP03okFYcOnbYL_o/ZG;00;o/ZG;
1?n`XLT00onSR[WoXHFfoj65]P02oj65]P?oWX2b1?nLO;04oiYi[@?oVGJ[0onGLjT2oiIaY`;oTFnX
0onAKZL4oi5]YP?oT6bU2?n@Jj@6oi1ZX`CoT6ZR1?n@JJ85oi5YXP;oW8o51?nMT<D3o`000003oijA
a_nOT/KoWi;600;oWi;60onPT/D3oioOo0?oX]ol00?oVn;mojK<m?nVc?@01?nVc?@9ojO2k@WoYl7/
2OnW_n]?ojO0j`03o`000?nW`>_oYl3[01GoYl3[4_ooool3o`0000Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000002Oooool002Oooooo00?o0000oooooooo
ool01Oooool4oigGo003oiCQoOnbgoOo/]og00;o/]og0onnen`00onngNoo`/kTol;>i003ol;>i0Ko
_[kJ00Co_KgJokFYcOneZLgo]JW=1?nbYL/00on`XLWoXhZioj>:^@02oj>:^@?oXHFf0onNP;84oial
/0CoVWV]0_nIMZ/01?nCLj_oTW6Zoi9aZ_nBLJX4oi5_Z0CoTFjW0onAKJH3oi1/Y@SoT6^T1on@JZ<3
oi1ZXPCoT6VR0_nAJJ800onKSLGoW8o5oib?a@03oib?a@?o000000CoWI35oijAa_nNTLKoWY761OnO
T/H00onPT/GoWmoloioOo003oioOo003oj;Oo?nVc?CoY/cd00?oY/cd2?nW`^d9ojO1k0WoYko[DonW
`>/00ol0003oYl3[ojO0j`0FojO0jaCooooo00Wo0000ooooooooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Wooooo000Vooooo`?o00000oooool3oj7;
mP;oWMOl1?nce_800onbgoOo_]O/okkGk002okkGk0?o`LcR0oo2c^@2oknofPCo_[kJ00?o]jk@okFY
cOneZLd00_neZLd3ok:Ub`03ojN?_OnSR[WoXhZi00?oXhZi0onQQKH4oij0/P?oW7b`0_nJNJd2oiAe
[@?oTg>[0onBLJX4oi5_Z0CoTFjW0onAKJH4oi1/Y@OoT6^T1on@JZ<3oi1ZXP;oT6VR0_nJS<@4oi^=
a@04oib?aOl0003o0000o`0000CoWI351?nNTLH2oinBaPCoW]km0_nOgo`00onWcOCoY/cdojK<m003
ojK<m0OoYl;]2OnW`N`9ojNojeOoYl3[00?o0000ojO0jonW`>/05OnW`>/Eooooo`03o`000?oooooo
oooo01kooooo000Vooooo`03o`000?ooooooX[k]00;oX[k]0onQboH3ok?<k0?o/mKb1?nmd>P00onn
enco`LcRol7<hP03ol7<hP03ol;>i?no_m[o_koJ00;o_koJ00?o_[kJokN^d?ng[]000_ng[]04okFY
c@04ok:UbonWSkgoYhnmojN?_@CoXhZi1?nQQKH3oij0/P;oW7b`00?oUGR`oiAe[OnDMJd00_nDMJd4
oi=cZ`?oTW6Z0onAKjP4oi5^Y`?oTFfV1?n@K:D7oi1[Y0OoT6ZS0_n@JZ800onIR/?oVXc4oiZ<a003
oiZ<a004oi^=aOl0003o0000o`0000?oW8o51OnMT<D2oijAaP?oW=gm0_nNg_d6ojO=m0;oY/cd2?nW
`^d6ojO1k0WoYko[G?nW`>/00ol0003oYl3[ojO0j`0EojO0jaCooooo00?o0000ooooooooool07_oo
ool001_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?ooooooX[k]00?oX[k]00?o
XL_fok?<k?ncc>`00oncc>`00once_;o_M3Xokg@j002okg@j0;o`LWQ1?o1c>82ol31fP?o_koJ0_ni
/]85okN^d0;o]JW=00?oZYK1ojN?_OnWSkd00_nWSkd5oj>:^@?oXHFf0_nNP;801?nGNk;oUGR`oiEh
/?nEN;04oiAe[@CoTg>[0onBLJX4oi5_Z0?oTFjW0onAKJH4oi1/Y@OoT6^T1_n@JZ<00onGRL;oVH[3
oiV:``02oiV:``;oVXc40ol00003oi^=a@CoW8o50_nMT<D4oicLo@;oW=gm1onWcO@9ojO2k@KoYl7/
2OnW_n]PojO0j`03o`000?nW`>_oYl3[01GoYl3[5?ooool00ol0003oooooooooo`0Mooooo`006ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool00_nR_^d4ok72iP;o/lc/
0onlbND00onmd>So`LWQol79h@03ol79h@03ol7<h_o0`M[o`<7J00?o`<7J00?o_koJokVbd_ni/]80
0_ni/]83okN^d003ojfLa_nZU/7oZYK100;oZYK10onWSkd5oj>:^@;oXHFf00CoV7jeoiMk/_nGNk;o
Ug^b1?nEN;03oiAe[@CoTg>[0onBLJX4oi5_Z0?oTFjW1?nAKJH3oi1/Y@OoT6^T0_n@JZ<2oiJ7`@Co
UhW20_nIR/<3o`0000;oVXc41OnKSLD2oib?a@?oVmWm0_nLg?d00onLhogoYlgdojO=m005ojO=m0Wo
Yl;]2?nW`N`7ojNojf?oYl3[00?o0000ojO0jonW`>/05_nW`>/Cooooo`;o00007_ooool001_ooooo
00Go410@oooooooooooooooooa0@4006ooooo`;o00000_ooool4ok72iP;o^/?Q0onlbND3ol37g`?o
`LWQ0oo1`]/3ol31fP03ok^fe?ni/];o^K;B00Co^K;B00Co]jk@ojfLa_n]W<Ko[Ic60onZU/44ojN?
_@?oXhZi00CoVh>ioiQn]OnHO[GoV7je1?nGNk83oiEh/0CoU7F]0onCLj/3oi9aZPCoTFnX1?nAKZL3
oi5]YP?oT6bU1_n@Jj@00onEQL3oUXO1oiJ7`@03oiJ7`@;oUhW20ol000000onIR/?oVXc4oiZ<a003
oiZ<a0?oVhg50_nKeo`3oi_Io@;oW>?m1OnWcO@3ojO3k@KoYl;]2OnW`N`8ojNojfKoYl3[00?o0000
ojO0jonW`>/05OnW`>/Booooo`03o`000?oooooo000001kooooo000Kooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`02ooooo`03ok72i_nj`n7o^/?Q00?o^/?Q00?o_<WU
ol37goo0aml00oo0aml00oo1bN7o`L;Kol72f`03ol72f`04ol31f_nk]]Co^kKDok^fe0Co^K;B00?o
/:?;ojfLa_n]W<H00_n]W<H3ojZF`@CoYhnm00CoXhZioi^3^OnKPkWoVh>i1?nHO[D3oiMk/P?oUGR`
1?nDMJd3oi=cZ`?oTW6Z1?nAKjP4oi5^Y`?oTFfV0_n@K:D00onCPkkoU8BooiB4_`02oiB4_`CoUHG0
1?nFQl42o`000003oiN9`_nIR/?oVH[300;oVH[31?nJS<@00onKSLGoVmOloi_Go003oi_Go003oi_I
oOnWc_CoYlkd00?oYlgd1onW`nd2ojO2k@WoYl7/2OnW_n]YojO0j`03o`000?nW`>_oYl3[01GoYl3[
5?ooool00ol0003oooooooooo`0Kooooo`006oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00oooool5ok[3h@;o_lCM0oo0aml2ol73f`Co`L;K00?o_K_Gok^fe?nk]]@0
0onk]]@00oni/];o/:?;ok2Sb`02ok2Sb`?o[Ic61?nZU/42ojN?_@03oif8_?nKPkWoVh>i00;oVh>i
1?nHO[D3oiMk/P?oUGR`1?nDMJd4oi=cZ`?oTW6Z0onAKjP4oi5^Y`;oTFfV00?oTX6moi>3__nCPkh0
0_nCPkh4oiB4_`?oUHG000CoUXO1o`000?l0003o00001?nGRL83oiV:``;oVXc41?nKdo/2oi_Go0Ko
Ylkd00?oYlgdojO3kOnW`nd01?nW`nd9ojO1k0WoYko[KOnW`>/00ol0003oYl3[ojO0j`0EojO0jaGo
oooo00?o0000ooooooooool06_ooool001_ooooo00Go410@oooooooooooooooooa0@4005ooooo`03
o`000?oooooooooo00Gooooo0onj`n44oko4g@03ol37goo1`m_o`L?K00;o`L?K00?o`L;Kokfkeonm
^mL00_nm^mL3ok^fe003okB[con`Xl_o/:?;00?o/:?;1?n]W<H2ojZF`@03oj2>`OnMR;coWHRl00;o
WHRl1?nKPkT3oiQn]@?oUg^b1?nEN;03oiAe[@CoTg>[0onBLJX2oi5_Z003oi5o_?nBP;goTX2m00;o
TX2m1?nBPKd3oi>3_PCoU8Bo00CoUHG0o`000?l0003o00001?nFQl43oiN9`P;oVH[31?nKcoX2oi_C
n`SoYlkd0_nX`nd3ojO3k@WoYl7/2OnW_n]aojO0j`03o`000?nW`>_oYl3[01GoYl3[5?ooool00ol0
003oooooooooo`0Jooooo`006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00007oooo
o`03ok[3hOnoa=go_lCM00;o_lCM00?o`/CLol73foo1`m/00oo1`m/00ono_m[o_K_Gokfke`03okfk
e`04ok^fe?ndZloo]:_?okB[c`Go/:?;0_n]W<H00onTULKoX8k1oj2>`@02oj2>`@?oWHRl1?nKPkT3
oiQn]@CoUg^b0onEN;03oiAe[@;oTg>[2OnAOk`4oi:0_@?oTX6m0onCPkh2oiB4_`?o00000onEQL02
oiJ7`@?oVlGf1?nKboP2oi_?nP;oYloe1_nWc_@7ojS3k@03ojO3kOnW`NcoYl7/00CoYl7/2OnW_n]f
ojO0j`03o`000?nW`>_oYl3[01GoYl3[5?ooool00ol0003oooooooooo`0Iooooo`006oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool01oooool3oko4g@?o`/CL0oo1`m/3
oknofP?o_K_G00?o]k;DokB[condZll00_ndZll4ok2Sb`03ojNLbonTULKoY9G600;oY9G60onPS/43
oif8_0CoVh>i1?nHO[D3oiMk/P;oUGR`00?oTH2moi5o_?nAOk`03?nAOk`4oi:0_@?oTX6m0_nCPkh3
o`0000?oU8Bo0_nEQL02oi[0lPGoVlGf0_nKboP00onJiOcoYloeojO?m@03ojO?m@;oYlkd2OnX`nd5
ojO1k0WoYko[N_nW`>/00ol0003oYl3[ojO0j`0DojO0jaCooooo00?o0000ooooooooool06Oooool0
02Gooooo00?o0000ooooooooool02?ooool00onoa=go`/CLol;4g003ol;4g003ol73fono_m[o_koJ
00?o_koJ00Co_K_GokNbe?ng/]Co]k;D1?ndZll00on`Xl_oYic;ojNLb`02ojNLb`?oY9G60onPS/44
oif8_0?oVh>i1?nHO[D2oiMk/P03oi61__nAP;goTH2m00;oTH2m3OnAOk`4oi:0_@;oTX6m0ol00002
oi>3_P;oU8Bo0onI^nl4oi[0lP;oVlGf00?oVNKloi[Vo?nJi_`01OnWcoD3ojS4kPKoZ<?]2?nW`N`7
ojNojggoYl3[00?o0000ojO0jonW`>/05OnW`>/Booooo`03o`000?oooooo000001[ooooo000Uoooo
o`03o`000?oooooooooo00[ooooo0oo2a=`2ol74g@Co_koJ00?o^[_JokNbe?ng/]@00ong/]@2okB[
c`03oj^UdOnWW<_oYic;00?oYic;0onTULH4oj2>`@?oWHRl0_nKPkT00onCQL7oTX>ooi:3_`02oi:3
_`CoTH6n0onAP;d>oi5o_0;oTX2m0ol00002oi:1_@;oTh>n0_nH]N`5oiVkk`;oV/3b00?oV>KloiWV
o?nIi_`00onWd?D2ojO?m@OoZ<C^0_nX`nd9ojO1k0SoYko[OonW`>/00ol0003oYl3[ojO0j`0EojO0
jaCooooo00?o0000ooooooooool05oooool002Gooooo0_l0000<ooooo`03ol;4g?o1a=go`LCM00;o
`LCM00?o_koJokZkf_nj^mX00_nj^mX3okNbe003ojj^eon[YM7oZjGA00;oZjGA1?nWW</4ojBEaP;o
X8k100CoV8k7oiF9a?nERLCoUHW41?nCQL44oi:3_`?oTH6n0onAP;d>oi5o_0;o00000_nBP;d2oi:1
_@;oUk3X1?nH]N`2oiVkk`?oV>Kl1_nWd?D9ojS4kP;oYl;/1_nW`N`9ojNojh?oYl3[00?o0000ojO0
jonW`>/05OnW`>/Cooooo`03o`000?oooooooooo01Oooooo000Tooooo`03o`000?oooooooooo00go
oooo0oo1a=d3okg4g`Co^[_J00Co]k;Dojj^eon^[]Oo[ZkG0on[YM45ojNLb`;oY9G600?oVY?<oiR>
aonHS/L00_nHS/L3oiF9a0?oThG11?nBPkl3oi61_PCoTH2m2_nAOk`3o`0000GoUZ_U1?nG/>P2oiRe
k003og3OhOnHi_coV>Kl00;oYm7f1_nWd?D6ojS4kPOoYl;/0_nW`N`9ojNojhOoYl3[00?o0000ojO0
jonW`>/05?nW`>/Dooooo`03o`000?oooooooooo01Kooooo000Tooooo`03o`000?oooooooooo00ko
oooo00?o`LCMokg4gonma=l00onma=l2okZkfP03ok6hg_n^[]Oo[ZkG00;o[ZkG1?n[YM42ojNLb`;o
WI[@1?nJTl`3oiR>a`?oUHW40onCQL44oi:3_`CoTH6n0onAP;d5oi5o_0;oTikL0ol00004oiFVh@Go
UZ_U0_nG/>P3oiOVo0KoYm7f0_nWd?D4ojS5kP;oZ<C^2OnW`^`8ojNojh_oYl3[00?o0000ojO0jonW
`>/05OnW`>/Dooooo`03o`000?oooooooooo01Gooooo000Tooooo`?o00003oooool4okg4g`03okC2
iOna^=ko/KSN00;o/KSN1?n^[]L2oj^Ud@03oj2Re_nMV]3oWI[@00?oWI[@0onJTl`3oiR>a`?oUHW4
1?nCQL44oi:3_`?oTH6n0_nAP;d01OnAVMSoTY_Ioi:KfOnBVmWoTikL00?o000000CoTikLoiBRg_nD
X]koU:;N1?nEY^42oiJ[i@03og7PiOnFi_coU^Kl00;oU^Kl00?oUnKlojOAm_nWdOH01?nWdOH6ojS5
kPSoYl;/0onW`>/6ojNojhooYl3[00?o0000ojO0jonW`>/05OnW`>/Booooo`;o00002Oooool4o`00
0003oa0@4?oooooooooo00Oooooo000Tooooo`03o`000?oooooooooo013ooooo00?o_LCOokC2iOnd
`^D00_nd`^D4ok6hgP;o[ZkG00?oXj_Loj2Re_nPX]H00_nPX]H4oifJd0?oVY?<1?nHS/L3oiF9a0?o
ThG10_nBPkl2ohnFeP?oT9OG1?nAVMP3o`0000CoTikL1?nDX]h2oiFVh@03og;QionFi_coU^Kl00?o
U^Kl1_nWdOH2ojS6k`KoZ<G^1_nW`^`7ojO0j`;oYko[TonW`>/00ol0003oYl3[ojO0j`0EojO0ja?o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`002Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`0Booooo`Co
]<;U0_na^=h00onU]NCoXj_Loj>[g002oj>[g0CoX:;F1?nMV]03oiZCc0;oV8k700CoT9WIohnGeon?
UmOoSiOG2?n?U]H3oi2Ge`?o00001?nBVmT4oi>Ng0;oU:;N1?nEiO`2oiKVo0KoYm7f1_nXa^l2ojS5
kP?oYl;]0onW`^bOojO0j`03o`000?nW`>_oYl3[01GoYl3[5?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Wooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo01?ooooo0_nd`^D2
ojJok0?oYKGT1?nSZm`4oj2ReP;oWI[@00CoTZ7Noi6LfonAW=_oTIcK1?n@VMT3ohnGe`OoSiKF0ol0
00001?n@UmOoTIWHoi6If?nAVMP2oi:Kf@?oDlgW00?oM^7^oiGUo?nEiO`01?nEiO`3ojKBm`;oYm7f
2OnXa^l7ojO2k@03ojO2k?nW`>_oYl3[09ooYl3[00?o0000ojO0jonW`>/05OnW`>/Cooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02Oooool000Wooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool05Oooool4ojJok0?oYKGT
0_nSZm`2oiF/i`?oU:KR1?nBXMh3oi6Lf`?oT9WI0on?UmL5ohnFeP;o000000?oSiKFoi2Geon@UmL0
0omVcoX2oeg@lP?oNN7b00?oM^7^oiGUo?nEiO`00_nEiO`5ojKBm`;oZ<O`1onXa^l2ojS2k@KoYl;]
YOnW`>/00ol0003oYl3[ojO0j`0EojO0ja?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`09ooooo`002Oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1Oooool3o`0001Kooooo0_nV_n`2oiFkl@CoUK?/0onE[>L3oiBVhP?oTZ7N1?nAW=/3oi2If@?oSiOG
00CoSiKFo`000?l0003o00000_mbb?l3ofg<oP;oI/oj0omkh?H2ogWQlP;oUN?m0onVdOL3ojKBm`Ko
Z<O`0_nXa^l7ojS2k@;oYl;]ZOnW`>/00ol0003oYl3[ojO0j`0EojO0ja7ooooo0ol00007ooooo`03
o`000?oooooooooo00Wooooo0009ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`04ooooo`03o`000?oooooooooo01Sooooo0onE^o44oiFck0?oUJcW0onDY^83oi:QgP;o
TIcK0_ml^oX3ogZoo0?o00000_mf`oh2og;8o`;oG]7`1?mngoX2og_PmP;oUN;m0onUdOL4ojKAm`03
ojKBmonXao3oZ<O`00CoZ<O`2OnX`^f/ojO0j`03o`000?nW`>_oYl3[01GoYl3[3_ooool4o`000003
ooooool0003ooooo00Kooooo00?o0000ooooooooool02Oooool000Wooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06Oooool3oiFkl@;o
UK?/0_n5]_@3ohBfm@?oP[Og1?mo^?P2ogbknP?o00001?m`coh2ofSBn@CoPMcm0_mngoX2oiGPoP;o
YM3f1OnUdOL2ojKAm`GoZ<O`0_nX`nd7ojS2kK3oYl3[00?o0000ojO0jonW`>/05OnW`>/:ooooo`?o
00001Oooool00ol0003oooooooooo`03ooooo`03oeEEEOmVIVKo000000_ooooo0009ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo0_l0000Koooo
o`?oQkKd1?n5]_@3ohBfm@?oP[Og0_mo^?P3o`000004og_6o_mfboooM/_oogK;o`;oL<on0on4fOl2
oh7Lo@?oU]gn0_nTcoH4ojG@mP;oYM7g1?nWao02ojS7l0;oYl?]1?nX`nd2ojS2kKGoYl3[00?o0000
ojO0jonW`>/05?nW`>/6ooooo`Co00002?ooool00ol0003oooooooooo`0Aooooo`002Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oo
oooooooo01_ooooo0on7]_@2ohFfm0;oQKWg0on3_OX01?mo`_co0000o`000?l00002og_6oPCoR<oo
0on6e?l2ohCIo`CoU][n00?oU]gnojC?m_nTcoH00_nTcoH2ojG@mPKoYlO`1_nW`nd2ojS3kKSoYl3[
00?o0000ojO0jonW`>/05OnW`>/2ooooo`?o00003?ooool00ol0003oooooooooo`0Aooooo`008_oo
ool00ol0003oooooooooo`0Mooooo`?oR;Kd1?n5^OL3o`0000;oOl;l1?n:bOd2ohS?o`;oUm7l1OnF
e_d2oiKJoP?oY<kf0_nTcoH8ojO7l0KoYl?]_?nW`>/00ol0003oYl3[ojO0j`0EojO0j`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool07_ooool3
ohRfm003ohFimol0003o000000;oS[kg1?n<a?X2oh[9o@;oUlcj1?nGdO`2oiKFo@CoXlce0_nTc_H8
ojO7l0KoYl?]`?nW`>/00ol0003oYl3[ojO0j`0EojO0ja3ooooo00?o0000ooooooooool04?ooool0
02;ooooo0_l0000Pooooo`?o00000_n?^O<3ohjnm`;oS<Cj0onGa_L3oiO<nP;oUm7l1?nRbO@2oj?<
m@;oY/K`1_nWao06ojO3kLCoYl3[00?o0000ojO0jonW`>/05?nW`>/@ooooo`03o`000?oooooooooo
013ooooo000Rooooo`03o`000?oooooooooo01cooooo0ol000000oooooooSkWcohnil`03oiVll0Co
V<7d0_nGa_L2oj74l@CoXLOc0_nRbO@3ojK5l0CoY/K`0_nWao08ojO3kLGoYl3[00?o0000ojO0jonW
`>/05OnW`>/?ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo01Wooooo
0ol00006ooooo`CoVKc`0_nH`O@2oj31l0CoXLCa0_nQao<3ojG4k`CoY/G`0_nVa_02ojO2k@KoYl?]
bOnW`>/00ol0003oYl3[ojO0j`0DojO0j`oooooo00?o0000ooooooooool04?ooool002;ooooo00?o
0000ooooooooool05_ooool3o`0000[ooooo0_nI_?02oj2nkPCoX<7`0_nQa?43ojG2kPCoYLC_0_nV
aO06ojO2k@;oYl?]0onW`Nc:ojO0j`03o`000?nW`>_oYl3[01CoYl3[3_ooool00ol0003ooooooooo
o`0@ooooo`008_ooool2o`0001Cooooo0ol0000>ooooo`CoX;k^0_nP`O02ojC1kPGoYL;^0_nUa>l8
ojO2k@OoYl7/b_nW`>/00ol0003oYl3[ojO0j`0DojO0j`gooooo00?o0000ooooooooool04?ooool0
027ooooo0_l0000Booooo`?o00004_ooool2oj2nkP;oY;o]1?nT`Nh2ojG2kP?oY/7/1_nW`^d8ojO1
k<coYl3[00?o0000ojO0jonW`>/05OnW`>/<ooooo`03o`000?oooooooooo013ooooo0007ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03oooo
o`03o`000?oooooooooo00oooooo0_l0000Fooooo`CoY;o]0_nT`Nh3ojK0k0CoY/7/0_nW`^d2ojO0
k0KoYl7/d?nW`>/00ol0003oYl3[ojO0j`0DojO0j`gooooo00?o0000ooooooooool03oooool000Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00cooooo0ol0000Iooooo`;oY;o]0onV_n`4ojK0k0;oY/7/1_nW`>`2ojO1
k=CoYl3[00?o0000ojO0jonW`>/05?nW`>/<ooooo`03o`000?oooooooooo00oooooo0007ooooo`05
oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo0_l0000:ooooo`?o00007Oooool5ojJo
k0;oY/3/0_nW`>/6ojO0k=OoYl3[00?o0000ojO0jonW`>/05OnW`>/;ooooo`03o`000?oooooooooo
00oooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00006
ooooo`03o`000?oooooooooo00Kooooo0ol0000Qooooo`;oY[o/1onW`>/2ojO0k=_oYl3[00?o0000
ojO0jonW`>/05OnW`>/:ooooo`03o`000?oooooooooo00oooooo0007ooooo`05o`000?oooooooooo
ooooool000002oooool01?oMgMgoEEEEooooool00006ooooo`03o`000?oooooooooo00?ooooo0ol0
000VooooonGoYl3[00?o0000ojO0jonW`>/05?nW`>/:ooooo`03o`000?oooooooooo00oooooo0007
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000005ooooo`04o`000?oo
ooooooooooooo`?o0000:_oooooUojO0j`03o`000?nW`>_oYl3[01CoYl3[2Oooool00ol0003ooooo
ooooo`0?ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
1Oooool4o`0002koooooi?nW`>/00ol0003oYl3[ojO0j`0DojO0j`Wooooo00?o0000ooooooooool0
3oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Cooooo
0_l0000aooooonCoYl3[00?o0000ojO0jonW`>/05?nW`>/8ooooo`03o`000?oooooooooo00oooooo
000Rooooo`03o`000?oooooooooo02ooooooi?nW`>/00ol0003oYl3[ojO0j`0CojO0j`Wooooo00?o
0000ooooooooool03_ooool002?ooooo00?o0000ooooooooool0;ooooooSojO0j`03o`000?nW`>_o
Yl3[01CoYl3[2?ooool00ol0003oooooooooo`0>ooooo`009?ooool00ol0003oooooooooo`0_oooo
on?oYl3[00?o0000ojO0jonW`>/05?nW`>/7ooooo`03o`000?oooooooooo00kooooo000Uooooo`;o
0000<?oooooSojO0j`03o`000?nW`>_oYl3[01CoYl3[1_ooool00ol0003oooooooooo`0>ooooo`00
9oooool00ol0003oooooooooo`0^ooooon?oYl3[00?o0000ojO0jonW`>/04onW`>/6ooooo`03o`00
0?oooooooooo00kooooo000Xooooo`03o`000?oooooooooo02koooooh_nW`>/00ol0003oYl3[ojO0
j`0DojO0j`Gooooo00?o0000ooooooooool03_ooool002Wooooo00?o0000ooooooooool0;ooooooQ
ojO0j`03o`000?nW`>_oYl3[01CoYl3[1?ooool00ol0003oooooooooo`0>ooooo`00:_ooool2o`00
037oooooh?nW`>/00ol0003oYl3[ojO0j`0DojO0j`?ooooo00?o0000ooooooooool03_ooool002co
oooo00?o0000ooooooooool0;ooooooPojO0j`03o`000?nW`>_oYl3[01CoYl3[0oooool00ol0003o
ooooooooo`0=ooooo`00;Oooool00ol0003oooooooooo`0_ooooomooYl3[00?o0000ojO0jonW`>/0
5?nW`>/3ooooo`03o`000?oooooooooo00gooooo000^ooooo`03o`000?oooooooooo02oooooogonW
`>/00ol0003oYl3[ojO0j`0DojO0j`;ooooo00?o0000ooooooooool03Oooool002oooooo00?o0000
ooooooooool0;ooooooOojO0j`03o`000?nW`>_oYl3[01?oYl3[0_ooool00ol0003oooooooooo`0=
ooooo`00<?ooool2o`00033ooooog_nW`>/00ol0003oYl3[ojO0j`0DojO0j`03ooooool0003ooooo
00kooooo000booooo`03o`000?oooooooooo02kooooog_nW`>/00ol0003oYl3[ojO0j`0CojO0j`03
ooooool0003ooooo00kooooo000cooooo`03o`000?oooooooooo02kooooog_nW`>/00ol0003oYl3[
ojO0j`0CojO0j`03o`000?oooooooooo00gooooo000dooooo`03o`000?oooooooooo02kooooog_nW
`>/00ol0003oYl3[ojO0j`0AojO0j`03ooooool0003ooooo00kooooo000eooooo`;o0000;ooooooM
ojO0j`03o`000?nW`>_oYl3[00goYl3[1_ooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0
003oooooooooo`0^ooooomcoYl3[00?o0000ojO0jonW`>/02OnW`>/9ooooo`03o`000?oooooooooo
00cooooo000hooooo`03o`000?oooooooooo02kooooog?nW`>/00ol0003oYl3[ojO0j`05ojO0j`co
oooo00?o0000ooooooooool03?ooool003Wooooo00?o0000ooooooooool0;_oooooLojO0j`03o`00
0?nW`>_oYl3[013ooooo00?o0000ooooooooool03?ooool003[ooooo0_l0000_ooooom_oYl3[00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`00??ooool00ol0003oooooooooo`0]
ooooomKoYl3[1Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo000moooo
o`03o`000?oooooooooo02goooood_nW`>/9ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03?ooool003kooooo00?o0000ooooooooool0;Oooooo:ojO0ja3ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0<ooooo`00?oooool2o`0002ooooooaOnW`>/Dooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool02oooool0047ooooo00?o0000ooooooooool0;Ooo
ooo1ojO0jaSooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`00@_ooool0
0ol0003oooooooooo`0]oooookcoYl3[7Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo0013ooooo`03o`000?oooooooooo02gooooo^?nW`>/Pooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02oooool004Cooooo00?o0000ooooooooool0;OoooondojO0jbCo
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`00AOooool2o`0002oooooo
[_nW`>/Yooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool004Oooooo00?o
0000ooooooooool0;OoooonZojO0jbcooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0;ooooo`00B?ooool00ol0003oooooooooo`0]ooooojKoYl3[<?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00_ooooo0019ooooo`03o`000?oooooooooo02goooooX_nW`>/doooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool004[ooooo0_l0000^oooooigo
Yl3[>Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo001<ooooo`03o`00
0?oooooooooo02coooooVOnW`>/looooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2_ooool004gooooo00?o0000ooooooooool0;?oooonBojO0jd?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0:ooooo`00C_ooool00ol0003oooooooooo`0]ooooohgoYl3[Aoooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo001?ooooo`;o0000;_oooon8ojO0
jdcooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`00DOooool00ol0003o
ooooooooo`0/ooooohCoYl3[Coooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[o
oooo001Booooo`03o`000?oooooooooo02_oooooPOnW`>]Cooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02_ooool005?ooooo00?o0000ooooooooool0:ooooommojO0jeOooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`00E?ooool2o`0002goooooN?nW`>]J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool005Kooooo00?o0000oooo
ooooool0:ooooomdojO0jekooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09oooo
o`00Eoooool00ol0003oooooooooo`0[ooooofcoYl3[I_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Wooooo001Hooooo`03o`000?oooooooooo02coooooIonW`>]Zooooo`05o`00
0?ooooooooooooooool000002oooool005Wooooo00?o0000ooooooooool0;?oooomSojO0jfgooooo
00Go0000ooooooooooooooooo`00000;ooooo`00F_ooool2o`0002goooooGonW`>]aooooo`04o`00
0?ooooooooooo`0000_ooooo001Looooo`03o`000?oooooooooo02_oooooFonW`>]eooooo`03o`00
0?oooooo000000_ooooo001Mooooo`03o`000?oooooooooo02_oooooEonW`>]hooooo`04o`000?oo
ooooooooo`0000[ooooo001Nooooo`03o`000?oooooooooo02_oooooDonW`>]looooo`03o`000?oo
oooo000000[ooooo001Oooooo`;o0000;?oooom<ojO0jh?ooooo0_l0000:ooooo`00HOooool00ol0
003oooooooooo`0ZooooodSoYl3[QOooool3o`0000[ooooo001Rooooo`03o`000?oooooooooo02_o
oooo@onW`>^4ooooo`Co00003Oooool006?ooooo00?o0000ooooooooool0:oooooloojO0jh?ooooo
1?l0000Aooooo`00I?ooool2o`0002cooooo>onW`>^3ooooo`?o00005Oooool006Kooooo00?o0000
ooooooooool0:ooooolcojO0jhGooooo1?l0000Hooooo`00Ioooool00ol0003oooooooooo`0Zoooo
oc3oYl3[Q?ooool4o`0001cooooo001Xooooo`03o`000?oooooooooo02[ooooo;?nW`>^3ooooo`Co
00008?ooool006Wooooo0_l0000/ooooobOoYl3[P_ooool4o`0002Cooooo001[ooooo`03o`000?oo
oooooooo02[ooooo8onW`>^2ooooo`?o0000:?ooool006cooooo00?o0000ooooooooool0:_oooolM
ojO0jh?ooooo1?l0000[ooooo`00KOooool00ol0003oooooooooo`0[oooooaSoYl3[P_ooool4o`00
02oooooo001^ooooo`03o`000?oooooooooo02[ooooo5OnW`>^1ooooo`Co0000<oooool006oooooo
0_l0000[oooooa7oYl3[P?ooool4o`0003Oooooo001aooooo`03o`000?oooooooooo02[ooooo2OnW
`>^2ooooo`Co0000>oooool007;ooooo00?o0000ooooooooool0:_ooool5ojO0jh;ooooo0ol0000o
ooooo`00Loooool00ol0003oooooooooo`0Zooooo`03ojO0jooooooooooo07oooooo1?l00012oooo
o`00M?ooool2o`0002[ooooo00?o0000ooooooooool0Noooool4o`0004Kooooo001fooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0N?ooool4o`0004[ooooo001gooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0M?ooool4o`0004kooooo001hooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0LOooool3o`0005;ooooo001iooooo`;o00009?ooool00ol0
003oooooooooo`1]ooooo`Co0000EOooool007_ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`1Yooooo`Co0000FOooool007cooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`1Uooooo`Co0000GOooool007gooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`1Qooooo`Co0000HOooool007kooooo0_l0000Oooooo`03o`000?oooooooooo05gooooo1?l0001U
ooooo`00P?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05[ooooo0ol0001Yoooo
o`00POooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Kooooo1?l0001/ooooo`00
P_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05;ooooo1?l0001`ooooo`00Pooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04kooooo1?l0001dooooo`00Q?ooool2
o`0001Wooooo00?o0000ooooooooool0B_ooool4o`0007Sooooo0026ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0A_ooool4o`0007cooooo0027ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0@oooool3o`00083ooooo0028ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0?oooool4o`0008?ooooo0029ooooo`;o00005?ooool00ol0003ooooooooo
o`0kooooo`Co0000Qoooool008_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0g
ooooo`Co0000Roooool008cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0coooo
o`Co0000Soooool008gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0`ooooo`?o
0000Toooool008kooooo0_l0000?ooooo`03o`000?oooooooooo02cooooo1?l0002Fooooo`00T?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Sooooo1?l0002Jooooo`00TOooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Cooooo1?l0002Nooooo`00T_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo1?l0002Rooooo`00Toooool2o`0000Wo
oooo00?o0000ooooooooool07Oooool4o`000:Kooooo002Eooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool06_ooool3o`000:[ooooo002Fooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool05_ooool4o`000:gooooo002Gooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool04_ooool4o`000;7ooooo002Hooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool03_ooool4o`000;Gooooo002Iooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co
0000^Oooool009_ooooo00Co0000oooooooooooo00002Oooool3o`000;gooooo002Looooo`03o`00
0?oooooo000000Gooooo1?l00030ooooo`00WOooool2o`000003ooooool0003o000000;o0000a?oo
ool009kooooo0_l00038ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00[_ooool01OnHV9So0000
o`000?m4A4Co^[Zj00Wooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`;o8B4Q1?ooool5o`00
09Oooooo002^ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool6o`000006ooooool@413o^[Zj
oooooomgMgOo<S8b1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A02Gooooo`00[_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h0V?oo
ool00:kooooo00?o0000ooooooooool01?ooool6o`0000Cooooo00?oZJVYoa0@4?ooool03?ooool0
0onHV9So8B4Qonk^kP2Gooooo`00[_ooool00ol0003oooooooooo`0=ooooo`03oa0@4?l0003o^[Zj
00kooooo00?oMgMgofIVI_ooool0U_ooool00:cooooo00?o410@o`000?l000000ol0000=ooooo`03
okZj^_lQ8B7ooooo00kooooo00?o0000ooooooooool0UOooool00:kooooo00?o0000ooooooooool0
2oooool01Ol@413oV9RHoooooonj^[[o000000_ooooo00Go0000okZj^_ooooooV9RHoa0@402Goooo
o`00[_ooool00ol0003oooooooooo`0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT02oooool01OnH
V9So410@o`000?lQ8B7oc<c<09Oooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -14 0 ]
[.5 .82364 14 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69467 Mtetra
.4053 .69467 .41061 .69934 .41957 .69681 .41427 .69213 Mtetra
.41427 .69213 .41957 .69681 .42855 .69428 .42327 .68958 Mtetra
.42327 .68958 .42855 .69428 .43756 .69174 .43231 .68703 Mtetra
.43231 .68703 .43756 .69174 .4466 .68919 .44137 .68446 Mtetra
.44137 .68446 .4466 .68919 .45567 .68663 .45046 .68189 Mtetra
.45046 .68189 .45567 .68663 .46478 .68407 .45958 .67931 Mtetra
.45958 .67931 .46478 .68407 .47391 .68149 .46873 .67671 Mtetra
.46873 .67671 .47391 .68149 .48307 .67891 .47792 .67412 Mtetra
.47792 .67412 .48307 .67891 .49227 .67632 .48713 .67151 Mtetra
.48713 .67151 .49227 .67632 .50149 .67371 .49638 .66889 Mtetra
.49638 .66889 .50149 .67371 .51075 .6711 .50565 .66626 Mtetra
.50565 .66626 .51075 .6711 .52004 .66849 .51496 .66363 Mtetra
.51496 .66363 .52004 .66849 .52936 .66586 .5243 .66098 Mtetra
.5243 .66098 .52936 .66586 .53871 .66322 .53367 .65833 Mtetra
.53367 .65833 .53871 .66322 .54809 .66058 .54308 .65567 Mtetra
.54308 .65567 .54809 .66058 .55751 .65792 .55251 .653 Mtetra
.55251 .653 .55751 .65792 .56695 .65526 .56198 .65032 Mtetra
.56198 .65032 .56695 .65526 .57643 .65259 .57148 .64763 Mtetra
.57148 .64763 .57643 .65259 .58595 .6499 .58102 .64493 Mtetra
.58102 .64493 .58595 .6499 .59549 .64721 .59058 .64222 Mtetra
.59058 .64222 .59549 .64721 .60507 .64451 .60018 .6395 Mtetra
.60018 .6395 .60507 .64451 .61468 .6418 .60982 .63678 Mtetra
.60982 .63678 .61468 .6418 .62432 .63908 .61948 .63404 Mtetra
.61948 .63404 .62432 .63908 .634 .63636 .62918 .63129 Mtetra
.62918 .63129 .634 .63636 .64371 .63362 .63892 .62854 Mtetra
.63892 .62854 .64371 .63362 .65345 .63087 .64868 .62577 Mtetra
.64868 .62577 .65345 .63087 .66323 .62811 .65848 .623 Mtetra
.65848 .623 .66323 .62811 .67304 .62535 .66832 .62021 Mtetra
.66832 .62021 .67304 .62535 .68289 .62257 .67819 .61742 Mtetra
.67819 .61742 .68289 .62257 .69277 .61979 .68809 .61462 Mtetra
.68809 .61462 .69277 .61979 .70269 .61699 .69803 .6118 Mtetra
.69803 .6118 .70269 .61699 .71264 .61418 .70801 .60898 Mtetra
.70801 .60898 .71264 .61418 .72262 .61137 .71802 .60615 Mtetra
.71802 .60615 .72262 .61137 .73264 .60854 .72806 .6033 Mtetra
.72806 .6033 .73264 .60854 .7427 .60571 .73814 .60045 Mtetra
.73814 .60045 .7427 .60571 .75279 .60286 .74826 .59759 Mtetra
.74826 .59759 .75279 .60286 .76291 .60001 .75841 .59471 Mtetra
.75841 .59471 .76291 .60001 .77308 .59714 .7686 .59183 Mtetra
.7686 .59183 .77308 .59714 .78328 .59427 .77882 .58893 Mtetra
.77882 .58893 .78328 .59427 .79351 .59138 .78908 .58603 Mtetra
.78908 .58603 .79351 .59138 .80378 .58849 .79938 .58311 Mtetra
.79938 .58311 .80378 .58849 .81409 .58558 .80971 .58019 Mtetra
.80971 .58019 .81409 .58558 .82443 .58267 .82008 .57725 Mtetra
.82008 .57725 .82443 .58267 .83482 .57974 .83049 .57431 Mtetra
.83049 .57431 .83482 .57974 .84523 .5768 .84094 .57135 Mtetra
.84094 .57135 .84523 .5768 .85569 .57385 .85142 .56838 Mtetra
.85142 .56838 .85569 .57385 .86618 .57089 .86194 .5654 Mtetra
.86194 .5654 .86618 .57089 .87672 .56792 .8725 .56241 Mtetra
.8725 .56241 .87672 .56792 .88729 .56494 .8831 .55941 Mtetra
.8831 .55941 .88729 .56494 .89789 .56195 .89374 .5564 Mtetra
.89374 .5564 .89789 .56195 .90854 .55895 .90441 .55338 Mtetra
.90441 .55338 .90854 .55895 .91923 .55594 .91512 .55035 Mtetra
.91512 .55035 .91923 .55594 .92995 .55292 .92588 .5473 Mtetra
.92588 .5473 .92995 .55292 .94071 .54988 .93667 .54425 Mtetra
.93667 .54425 .94071 .54988 .95152 .54684 .9475 .54118 Mtetra
.9475 .54118 .95152 .54684 .96236 .54378 .95837 .53811 Mtetra
.95837 .53811 .96236 .54378 .97324 .54071 .96928 .53502 Mtetra
.96928 .53502 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.391 .69252 .39636 .6972 .4053 .69467 .39996 .68998 Mtetra
.39996 .68998 .4053 .69467 .41427 .69213 .40895 .68742 Mtetra
.40895 .68742 .41427 .69213 .42327 .68958 .41797 .68486 Mtetra
.41797 .68486 .42327 .68958 .43231 .68703 .42702 .68228 Mtetra
.42702 .68228 .43231 .68703 .44137 .68446 .4361 .6797 Mtetra
.4361 .6797 .44137 .68446 .45046 .68189 .44521 .67711 Mtetra
.44521 .67711 .45046 .68189 .45958 .67931 .45435 .67452 Mtetra
.45435 .67452 .45958 .67931 .46873 .67671 .46352 .67191 Mtetra
.46352 .67191 .46873 .67671 .47792 .67412 .47273 .66929 Mtetra
.47273 .66929 .47792 .67412 .48713 .67151 .48196 .66667 Mtetra
.48196 .66667 .48713 .67151 .49638 .66889 .49123 .66403 Mtetra
.49123 .66403 .49638 .66889 .50565 .66626 .50053 .66139 Mtetra
.50053 .66139 .50565 .66626 .51496 .66363 .50985 .65874 Mtetra
.50985 .65874 .51496 .66363 .5243 .66098 .51922 .65608 Mtetra
.51922 .65608 .5243 .66098 .53367 .65833 .52861 .65341 Mtetra
.52861 .65341 .53367 .65833 .54308 .65567 .53803 .65073 Mtetra
.53803 .65073 .54308 .65567 .55251 .653 .54749 .64804 Mtetra
.54749 .64804 .55251 .653 .56198 .65032 .55698 .64534 Mtetra
.55698 .64534 .56198 .65032 .57148 .64763 .5665 .64264 Mtetra
.5665 .64264 .57148 .64763 .58102 .64493 .57606 .63992 Mtetra
.57606 .63992 .58102 .64493 .59058 .64222 .58565 .6372 Mtetra
.58565 .6372 .59058 .64222 .60018 .6395 .59527 .63446 Mtetra
.59527 .63446 .60018 .6395 .60982 .63678 .60493 .63172 Mtetra
.60493 .63172 .60982 .63678 .61948 .63404 .61461 .62896 Mtetra
.61461 .62896 .61948 .63404 .62918 .63129 .62434 .6262 Mtetra
.62434 .6262 .62918 .63129 .63892 .62854 .63409 .62343 Mtetra
.63409 .62343 .63892 .62854 .64868 .62577 .64388 .62064 Mtetra
.64388 .62064 .64868 .62577 .65848 .623 .65371 .61785 Mtetra
.65371 .61785 .65848 .623 .66832 .62021 .66357 .61505 Mtetra
.66357 .61505 .66832 .62021 .67819 .61742 .67346 .61224 Mtetra
.67346 .61224 .67819 .61742 .68809 .61462 .68339 .60942 Mtetra
.68339 .60942 .68809 .61462 .69803 .6118 .69335 .60658 Mtetra
.69335 .60658 .69803 .6118 .70801 .60898 .70335 .60374 Mtetra
.70335 .60374 .70801 .60898 .71802 .60615 .71338 .60089 Mtetra
.71338 .60089 .71802 .60615 .72806 .6033 .72345 .59803 Mtetra
.72345 .59803 .72806 .6033 .73814 .60045 .73356 .59516 Mtetra
.73356 .59516 .73814 .60045 .74826 .59759 .7437 .59227 Mtetra
.7437 .59227 .74826 .59759 .75841 .59471 .75387 .58938 Mtetra
.75387 .58938 .75841 .59471 .7686 .59183 .76409 .58648 Mtetra
.76409 .58648 .7686 .59183 .77882 .58893 .77434 .58356 Mtetra
.77434 .58356 .77882 .58893 .78908 .58603 .78462 .58064 Mtetra
.78462 .58064 .78908 .58603 .79938 .58311 .79495 .57771 Mtetra
.79495 .57771 .79938 .58311 .80971 .58019 .80531 .57476 Mtetra
.80531 .57476 .80971 .58019 .82008 .57725 .81571 .57181 Mtetra
.81571 .57181 .82008 .57725 .83049 .57431 .82614 .56884 Mtetra
.82614 .56884 .83049 .57431 .84094 .57135 .83661 .56586 Mtetra
.83661 .56586 .84094 .57135 .85142 .56838 .84712 .56288 Mtetra
.84712 .56288 .85142 .56838 .86194 .5654 .85767 .55988 Mtetra
.85767 .55988 .86194 .5654 .8725 .56241 .86826 .55687 Mtetra
.86826 .55687 .8725 .56241 .8831 .55941 .87889 .55385 Mtetra
.87889 .55385 .8831 .55941 .89374 .5564 .88955 .55082 Mtetra
.88955 .55082 .89374 .5564 .90441 .55338 .90025 .54777 Mtetra
.90025 .54777 .90441 .55338 .91512 .55035 .911 .54472 Mtetra
.911 .54472 .91512 .55035 .92588 .5473 .92178 .54166 Mtetra
.92178 .54166 .92588 .5473 .93667 .54425 .9326 .53858 Mtetra
.9326 .53858 .93667 .54425 .9475 .54118 .94346 .53549 Mtetra
.94346 .53549 .9475 .54118 .95837 .53811 .95436 .53239 Mtetra
.95436 .53239 .95837 .53811 .96928 .53502 .9653 .52928 Mtetra
.9653 .52928 .96928 .53502 .98024 .53192 .97628 .52616 Mtetra
.38561 .68781 .391 .69252 .39996 .68998 .39459 .68525 Mtetra
.39459 .68525 .39996 .68998 .40895 .68742 .40359 .68268 Mtetra
.40359 .68268 .40895 .68742 .41797 .68486 .41263 .6801 Mtetra
.41263 .6801 .41797 .68486 .42702 .68228 .4217 .67751 Mtetra
.4217 .67751 .42702 .68228 .4361 .6797 .4308 .67492 Mtetra
.4308 .67492 .4361 .6797 .44521 .67711 .43993 .67231 Mtetra
.43993 .67231 .44521 .67711 .45435 .67452 .44909 .6697 Mtetra
.44909 .6697 .45435 .67452 .46352 .67191 .45828 .66707 Mtetra
.45828 .66707 .46352 .67191 .47273 .66929 .46751 .66444 Mtetra
.46751 .66444 .47273 .66929 .48196 .66667 .47676 .6618 Mtetra
.47676 .6618 .48196 .66667 .49123 .66403 .48605 .65915 Mtetra
.48605 .65915 .49123 .66403 .50053 .66139 .49537 .65649 Mtetra
.49537 .65649 .50053 .66139 .50985 .65874 .50472 .65382 Mtetra
.50472 .65382 .50985 .65874 .51922 .65608 .5141 .65114 Mtetra
.5141 .65114 .51922 .65608 .52861 .65341 .52351 .64846 Mtetra
.52351 .64846 .52861 .65341 .53803 .65073 .53296 .64576 Mtetra
.53296 .64576 .53803 .65073 .54749 .64804 .54244 .64305 Mtetra
.54244 .64305 .54749 .64804 .55698 .64534 .55195 .64034 Mtetra
.55195 .64034 .55698 .64534 .5665 .64264 .56149 .63762 Mtetra
.56149 .63762 .5665 .64264 .57606 .63992 .57107 .63488 Mtetra
.57107 .63488 .57606 .63992 .58565 .6372 .58068 .63214 Mtetra
.58068 .63214 .58565 .6372 .59527 .63446 .59032 .62939 Mtetra
.59032 .62939 .59527 .63446 .60493 .63172 .6 .62663 Mtetra
.6 .62663 .60493 .63172 .61461 .62896 .60971 .62385 Mtetra
.60971 .62385 .61461 .62896 .62434 .6262 .61946 .62107 Mtetra
.61946 .62107 .62434 .6262 .63409 .62343 .62924 .61828 Mtetra
.62924 .61828 .63409 .62343 .64388 .62064 .63905 .61548 Mtetra
.63905 .61548 .64388 .62064 .65371 .61785 .6489 .61267 Mtetra
.6489 .61267 .65371 .61785 .66357 .61505 .65878 .60985 Mtetra
.65878 .60985 .66357 .61505 .67346 .61224 .6687 .60702 Mtetra
.6687 .60702 .67346 .61224 .68339 .60942 .67865 .60418 Mtetra
.67865 .60418 .68339 .60942 .69335 .60658 .68864 .60133 Mtetra
.68864 .60133 .69335 .60658 .70335 .60374 .69866 .59847 Mtetra
.69866 .59847 .70335 .60374 .71338 .60089 .70872 .5956 Mtetra
.70872 .5956 .71338 .60089 .72345 .59803 .71881 .59272 Mtetra
.71881 .59272 .72345 .59803 .73356 .59516 .72894 .58983 Mtetra
.72894 .58983 .73356 .59516 .7437 .59227 .73911 .58692 Mtetra
.73911 .58692 .7437 .59227 .75387 .58938 .74931 .58401 Mtetra
.74931 .58401 .75387 .58938 .76409 .58648 .75955 .58109 Mtetra
.75955 .58109 .76409 .58648 .77434 .58356 .76982 .57816 Mtetra
.76982 .57816 .77434 .58356 .78462 .58064 .78014 .57521 Mtetra
.78014 .57521 .78462 .58064 .79495 .57771 .79049 .57226 Mtetra
.79049 .57226 .79495 .57771 .80531 .57476 .80087 .5693 Mtetra
.80087 .5693 .80531 .57476 .81571 .57181 .8113 .56632 Mtetra
.8113 .56632 .81571 .57181 .82614 .56884 .82176 .56334 Mtetra
.82176 .56334 .82614 .56884 .83661 .56586 .83226 .56034 Mtetra
.83226 .56034 .83661 .56586 .84712 .56288 .8428 .55733 Mtetra
.8428 .55733 .84712 .56288 .85767 .55988 .85337 .55431 Mtetra
.85337 .55431 .85767 .55988 .86826 .55687 .86399 .55128 Mtetra
.86399 .55128 .86826 .55687 .87889 .55385 .87464 .54824 Mtetra
.87464 .54824 .87889 .55385 .88955 .55082 .88533 .54519 Mtetra
.88533 .54519 .88955 .55082 .90025 .54777 .89607 .54213 Mtetra
.89607 .54213 .90025 .54777 .911 .54472 .90684 .53905 Mtetra
.90684 .53905 .911 .54472 .92178 .54166 .91765 .53597 Mtetra
.91765 .53597 .92178 .54166 .9326 .53858 .9285 .53287 Mtetra
.9285 .53287 .9326 .53858 .94346 .53549 .93939 .52976 Mtetra
.93939 .52976 .94346 .53549 .95436 .53239 .95032 .52664 Mtetra
.95032 .52664 .95436 .53239 .9653 .52928 .96129 .52351 Mtetra
.96129 .52351 .9653 .52928 .97628 .52616 .9723 .52037 Mtetra
.38018 .68308 .38561 .68781 .39459 .68525 .38918 .6805 Mtetra
.38918 .6805 .39459 .68525 .40359 .68268 .3982 .67791 Mtetra
.3982 .67791 .40359 .68268 .41263 .6801 .40726 .67532 Mtetra
.40726 .67532 .41263 .6801 .4217 .67751 .41635 .67271 Mtetra
.41635 .67271 .4217 .67751 .4308 .67492 .42547 .6701 Mtetra
.42547 .6701 .4308 .67492 .43993 .67231 .43462 .66748 Mtetra
.43462 .66748 .43993 .67231 .44909 .6697 .4438 .66485 Mtetra
.4438 .66485 .44909 .6697 .45828 .66707 .45301 .66221 Mtetra
.45301 .66221 .45828 .66707 .46751 .66444 .46225 .65956 Mtetra
.46225 .65956 .46751 .66444 .47676 .6618 .47153 .6569 Mtetra
.47153 .6569 .47676 .6618 .48605 .65915 .48083 .65423 Mtetra
.48083 .65423 .48605 .65915 .49537 .65649 .49017 .65156 Mtetra
.49017 .65156 .49537 .65649 .50472 .65382 .49954 .64887 Mtetra
.49954 .64887 .50472 .65382 .5141 .65114 .50895 .64618 Mtetra
.50895 .64618 .5141 .65114 .52351 .64846 .51838 .64347 Mtetra
.51838 .64347 .52351 .64846 .53296 .64576 .52785 .64076 Mtetra
.52785 .64076 .53296 .64576 .54244 .64305 .53735 .63804 Mtetra
.53735 .63804 .54244 .64305 .55195 .64034 .54688 .6353 Mtetra
.54688 .6353 .55195 .64034 .56149 .63762 .55645 .63256 Mtetra
.55645 .63256 .56149 .63762 .57107 .63488 .56605 .62981 Mtetra
.56605 .62981 .57107 .63488 .58068 .63214 .57568 .62705 Mtetra
.57568 .62705 .58068 .63214 .59032 .62939 .58535 .62428 Mtetra
.58535 .62428 .59032 .62939 .6 .62663 .59505 .6215 Mtetra
.59505 .6215 .6 .62663 .60971 .62385 .60478 .61871 Mtetra
.60478 .61871 .60971 .62385 .61946 .62107 .61455 .61591 Mtetra
.61455 .61591 .61946 .62107 .62924 .61828 .62435 .6131 Mtetra
.62435 .6131 .62924 .61828 .63905 .61548 .63419 .61028 Mtetra
.63419 .61028 .63905 .61548 .6489 .61267 .64406 .60746 Mtetra
.64406 .60746 .6489 .61267 .65878 .60985 .65396 .60462 Mtetra
.65396 .60462 .65878 .60985 .6687 .60702 .66391 .60177 Mtetra
.66391 .60177 .6687 .60702 .67865 .60418 .67388 .59891 Mtetra
.67388 .59891 .67865 .60418 .68864 .60133 .68389 .59604 Mtetra
.68389 .59604 .68864 .60133 .69866 .59847 .69394 .59316 Mtetra
.69394 .59316 .69866 .59847 .70872 .5956 .70402 .59027 Mtetra
.70402 .59027 .70872 .5956 .71881 .59272 .71414 .58737 Mtetra
.71414 .58737 .71881 .59272 .72894 .58983 .7243 .58446 Mtetra
.7243 .58446 .72894 .58983 .73911 .58692 .73449 .58154 Mtetra
.73449 .58154 .73911 .58692 .74931 .58401 .74472 .57861 Mtetra
.74472 .57861 .74931 .58401 .75955 .58109 .75498 .57567 Mtetra
.75498 .57567 .75955 .58109 .76982 .57816 .76528 .57272 Mtetra
.76528 .57272 .76982 .57816 .78014 .57521 .77562 .56975 Mtetra
.77562 .56975 .78014 .57521 .79049 .57226 .786 .56678 Mtetra
.786 .56678 .79049 .57226 .80087 .5693 .79641 .5638 Mtetra
.79641 .5638 .80087 .5693 .8113 .56632 .80686 .5608 Mtetra
.80686 .5608 .8113 .56632 .82176 .56334 .81735 .55779 Mtetra
.81735 .55779 .82176 .56334 .83226 .56034 .82788 .55478 Mtetra
.82788 .55478 .83226 .56034 .8428 .55733 .83844 .55175 Mtetra
.83844 .55175 .8428 .55733 .85337 .55431 .84905 .54871 Mtetra
.84905 .54871 .85337 .55431 .86399 .55128 .85969 .54566 Mtetra
.85969 .54566 .86399 .55128 .87464 .54824 .87037 .5426 Mtetra
.87037 .5426 .87464 .54824 .88533 .54519 .88109 .53953 Mtetra
.88109 .53953 .88533 .54519 .89607 .54213 .89185 .53644 Mtetra
.89185 .53644 .89607 .54213 .90684 .53905 .90265 .53335 Mtetra
.90265 .53335 .90684 .53905 .91765 .53597 .91349 .53024 Mtetra
.91349 .53024 .91765 .53597 .9285 .53287 .92437 .52712 Mtetra
.92437 .52712 .9285 .53287 .93939 .52976 .93529 .524 Mtetra
.93529 .524 .93939 .52976 .95032 .52664 .94625 .52085 Mtetra
.94625 .52085 .95032 .52664 .96129 .52351 .95725 .5177 Mtetra
.95725 .5177 .96129 .52351 .9723 .52037 .96829 .51454 Mtetra
.37472 .67831 .38018 .68308 .38918 .6805 .38373 .67572 Mtetra
.38373 .67572 .38918 .6805 .3982 .67791 .39278 .67311 Mtetra
.39278 .67311 .3982 .67791 .40726 .67532 .40186 .6705 Mtetra
.40186 .6705 .40726 .67532 .41635 .67271 .41096 .66788 Mtetra
.41096 .66788 .41635 .67271 .42547 .6701 .4201 .66525 Mtetra
.4201 .66525 .42547 .6701 .43462 .66748 .42927 .66261 Mtetra
.42927 .66261 .43462 .66748 .4438 .66485 .43847 .65996 Mtetra
.43847 .65996 .4438 .66485 .45301 .66221 .4477 .65731 Mtetra
.4477 .65731 .45301 .66221 .46225 .65956 .45697 .65464 Mtetra
.45697 .65464 .46225 .65956 .47153 .6569 .46626 .65197 Mtetra
.46626 .65197 .47153 .6569 .48083 .65423 .47559 .64928 Mtetra
.47559 .64928 .48083 .65423 .49017 .65156 .48495 .64659 Mtetra
.48495 .64659 .49017 .65156 .49954 .64887 .49434 .64389 Mtetra
.49434 .64389 .49954 .64887 .50895 .64618 .50376 .64118 Mtetra
.50376 .64118 .50895 .64618 .51838 .64347 .51322 .63846 Mtetra
.51322 .63846 .51838 .64347 .52785 .64076 .52271 .63572 Mtetra
.52271 .63572 .52785 .64076 .53735 .63804 .53223 .63298 Mtetra
.53223 .63298 .53735 .63804 .54688 .6353 .54178 .63024 Mtetra
.54178 .63024 .54688 .6353 .55645 .63256 .55137 .62748 Mtetra
.55137 .62748 .55645 .63256 .56605 .62981 .56099 .62471 Mtetra
.56099 .62471 .56605 .62981 .57568 .62705 .57065 .62193 Mtetra
.57065 .62193 .57568 .62705 .58535 .62428 .58034 .61914 Mtetra
.58034 .61914 .58535 .62428 .59505 .6215 .59006 .61634 Mtetra
.59006 .61634 .59505 .6215 .60478 .61871 .59982 .61354 Mtetra
.59982 .61354 .60478 .61871 .61455 .61591 .60961 .61072 Mtetra
.60961 .61072 .61455 .61591 .62435 .6131 .61943 .60789 Mtetra
.61943 .60789 .62435 .6131 .63419 .61028 .62929 .60505 Mtetra
.62929 .60505 .63419 .61028 .64406 .60746 .63919 .60221 Mtetra
.63919 .60221 .64406 .60746 .65396 .60462 .64912 .59935 Mtetra
.64912 .59935 .65396 .60462 .66391 .60177 .65908 .59648 Mtetra
.65908 .59648 .66391 .60177 .67388 .59891 .66908 .5936 Mtetra
.66908 .5936 .67388 .59891 .68389 .59604 .67912 .59072 Mtetra
.67912 .59072 .68389 .59604 .69394 .59316 .68919 .58782 Mtetra
.68919 .58782 .69394 .59316 .70402 .59027 .6993 .58491 Mtetra
.6993 .58491 .70402 .59027 .71414 .58737 .70944 .58199 Mtetra
.70944 .58199 .71414 .58737 .7243 .58446 .71962 .57906 Mtetra
.71962 .57906 .7243 .58446 .73449 .58154 .72984 .57612 Mtetra
.72984 .57612 .73449 .58154 .74472 .57861 .74009 .57317 Mtetra
.74009 .57317 .74472 .57861 .75498 .57567 .75038 .57021 Mtetra
.75038 .57021 .75498 .57567 .76528 .57272 .76071 .56724 Mtetra
.76071 .56724 .76528 .57272 .77562 .56975 .77107 .56426 Mtetra
.77107 .56426 .77562 .56975 .786 .56678 .78148 .56126 Mtetra
.78148 .56126 .786 .56678 .79641 .5638 .79192 .55826 Mtetra
.79192 .55826 .79641 .5638 .80686 .5608 .80239 .55524 Mtetra
.80239 .55524 .80686 .5608 .81735 .55779 .81291 .55222 Mtetra
.81291 .55222 .81735 .55779 .82788 .55478 .82346 .54918 Mtetra
.82346 .54918 .82788 .55478 .83844 .55175 .83406 .54613 Mtetra
.83406 .54613 .83844 .55175 .84905 .54871 .84469 .54307 Mtetra
.84469 .54307 .84905 .54871 .85969 .54566 .85536 .54 Mtetra
.85536 .54 .85969 .54566 .87037 .5426 .86607 .53692 Mtetra
.86607 .53692 .87037 .5426 .88109 .53953 .87682 .53383 Mtetra
.87682 .53383 .88109 .53953 .89185 .53644 .88761 .53072 Mtetra
.88761 .53072 .89185 .53644 .90265 .53335 .89844 .52761 Mtetra
.89844 .52761 .90265 .53335 .91349 .53024 .90931 .52448 Mtetra
.90931 .52448 .91349 .53024 .92437 .52712 .92022 .52134 Mtetra
.92022 .52134 .92437 .52712 .93529 .524 .93116 .51819 Mtetra
.93116 .51819 .93529 .524 .94625 .52085 .94216 .51503 Mtetra
.94216 .51503 .94625 .52085 .95725 .5177 .95319 .51185 Mtetra
.95319 .51185 .95725 .5177 .96829 .51454 .96426 .50866 Mtetra
.36922 .67351 .37472 .67831 .38373 .67572 .37826 .6709 Mtetra
.37826 .6709 .38373 .67572 .39278 .67311 .38732 .66828 Mtetra
.38732 .66828 .39278 .67311 .40186 .6705 .39642 .66566 Mtetra
.39642 .66566 .40186 .6705 .41096 .66788 .40554 .66302 Mtetra
.40554 .66302 .41096 .66788 .4201 .66525 .4147 .66037 Mtetra
.4147 .66037 .4201 .66525 .42927 .66261 .42389 .65772 Mtetra
.42389 .65772 .42927 .66261 .43847 .65996 .43311 .65505 Mtetra
.43311 .65505 .43847 .65996 .4477 .65731 .44236 .65238 Mtetra
.44236 .65238 .4477 .65731 .45697 .65464 .45165 .6497 Mtetra
.45165 .6497 .45697 .65464 .46626 .65197 .46096 .64701 Mtetra
.46096 .64701 .46626 .65197 .47559 .64928 .47031 .6443 Mtetra
.47031 .6443 .47559 .64928 .48495 .64659 .47969 .64159 Mtetra
.47969 .64159 .48495 .64659 .49434 .64389 .4891 .63887 Mtetra
.4891 .63887 .49434 .64389 .50376 .64118 .49855 .63615 Mtetra
.49855 .63615 .50376 .64118 .51322 .63846 .50802 .63341 Mtetra
.50802 .63341 .51322 .63846 .52271 .63572 .51753 .63066 Mtetra
.51753 .63066 .52271 .63572 .53223 .63298 .52708 .6279 Mtetra
.52708 .6279 .53223 .63298 .54178 .63024 .53665 .62513 Mtetra
.53665 .62513 .54178 .63024 .55137 .62748 .54626 .62236 Mtetra
.54626 .62236 .55137 .62748 .56099 .62471 .55591 .61957 Mtetra
.55591 .61957 .56099 .62471 .57065 .62193 .56558 .61677 Mtetra
.56558 .61677 .57065 .62193 .58034 .61914 .57529 .61397 Mtetra
.57529 .61397 .58034 .61914 .59006 .61634 .58504 .61115 Mtetra
.58504 .61115 .59006 .61634 .59982 .61354 .59482 .60833 Mtetra
.59482 .60833 .59982 .61354 .60961 .61072 .60463 .60549 Mtetra
.60463 .60549 .60961 .61072 .61943 .60789 .61448 .60265 Mtetra
.61448 .60265 .61943 .60789 .62929 .60505 .62437 .59979 Mtetra
.62437 .59979 .62929 .60505 .63919 .60221 .63428 .59692 Mtetra
.63428 .59692 .63919 .60221 .64912 .59935 .64424 .59405 Mtetra
.64424 .59405 .64912 .59935 .65908 .59648 .65423 .59116 Mtetra
.65423 .59116 .65908 .59648 .66908 .5936 .66425 .58826 Mtetra
.66425 .58826 .66908 .5936 .67912 .59072 .67431 .58536 Mtetra
.67431 .58536 .67912 .59072 .68919 .58782 .68441 .58244 Mtetra
.68441 .58244 .68919 .58782 .6993 .58491 .69454 .57951 Mtetra
.69454 .57951 .6993 .58491 .70944 .58199 .70471 .57657 Mtetra
.70471 .57657 .70944 .58199 .71962 .57906 .71491 .57363 Mtetra
.71491 .57363 .71962 .57906 .72984 .57612 .72516 .57067 Mtetra
.72516 .57067 .72984 .57612 .74009 .57317 .73544 .5677 Mtetra
.73544 .5677 .74009 .57317 .75038 .57021 .74575 .56471 Mtetra
.74575 .56471 .75038 .57021 .76071 .56724 .75611 .56172 Mtetra
.75611 .56172 .76071 .56724 .77107 .56426 .7665 .55872 Mtetra
.7665 .55872 .77107 .56426 .78148 .56126 .77693 .55571 Mtetra
.77693 .55571 .78148 .56126 .79192 .55826 .78739 .55268 Mtetra
.78739 .55268 .79192 .55826 .80239 .55524 .7979 .54965 Mtetra
.7979 .54965 .80239 .55524 .81291 .55222 .80844 .5466 Mtetra
.80844 .5466 .81291 .55222 .82346 .54918 .81902 .54354 Mtetra
.81902 .54354 .82346 .54918 .83406 .54613 .82964 .54047 Mtetra
.82964 .54047 .83406 .54613 .84469 .54307 .8403 .53739 Mtetra
.8403 .53739 .84469 .54307 .85536 .54 .851 .5343 Mtetra
.851 .5343 .85536 .54 .86607 .53692 .86174 .5312 Mtetra
.86174 .5312 .86607 .53692 .87682 .53383 .87252 .52809 Mtetra
.87252 .52809 .87682 .53383 .88761 .53072 .88334 .52496 Mtetra
.88334 .52496 .88761 .53072 .89844 .52761 .89419 .52182 Mtetra
.89419 .52182 .89844 .52761 .90931 .52448 .90509 .51867 Mtetra
.90509 .51867 .90931 .52448 .92022 .52134 .91603 .51551 Mtetra
.91603 .51551 .92022 .52134 .93116 .51819 .92701 .51234 Mtetra
.92701 .51234 .93116 .51819 .94216 .51503 .93803 .50916 Mtetra
.93803 .50916 .94216 .51503 .95319 .51185 .94909 .50596 Mtetra
.94909 .50596 .95319 .51185 .96426 .50866 .9602 .50275 Mtetra
.36369 .66869 .36922 .67351 .37826 .6709 .37275 .66606 Mtetra
.37275 .66606 .37826 .6709 .38732 .66828 .38183 .66342 Mtetra
.38183 .66342 .38732 .66828 .39642 .66566 .39094 .66078 Mtetra
.39094 .66078 .39642 .66566 .40554 .66302 .40009 .65813 Mtetra
.40009 .65813 .40554 .66302 .4147 .66037 .40927 .65546 Mtetra
.40927 .65546 .4147 .66037 .42389 .65772 .41848 .65279 Mtetra
.41848 .65279 .42389 .65772 .43311 .65505 .42772 .65011 Mtetra
.42772 .65011 .43311 .65505 .44236 .65238 .43699 .64742 Mtetra
.43699 .64742 .44236 .65238 .45165 .6497 .44629 .64472 Mtetra
.44629 .64472 .45165 .6497 .46096 .64701 .45563 .64201 Mtetra
.45563 .64201 .46096 .64701 .47031 .6443 .465 .63929 Mtetra
.465 .63929 .47031 .6443 .47969 .64159 .4744 .63657 Mtetra
.4744 .63657 .47969 .64159 .4891 .63887 .48383 .63383 Mtetra
.48383 .63383 .4891 .63887 .49855 .63615 .4933 .63108 Mtetra
.4933 .63108 .49855 .63615 .50802 .63341 .50279 .62833 Mtetra
.50279 .62833 .50802 .63341 .51753 .63066 .51233 .62556 Mtetra
.51233 .62556 .51753 .63066 .52708 .6279 .52189 .62279 Mtetra
.52189 .62279 .52708 .6279 .53665 .62513 .53149 .62 Mtetra
.53149 .62 .53665 .62513 .54626 .62236 .54112 .61721 Mtetra
.54112 .61721 .54626 .62236 .55591 .61957 .55079 .6144 Mtetra
.55079 .6144 .55591 .61957 .56558 .61677 .56049 .61159 Mtetra
.56049 .61159 .56558 .61677 .57529 .61397 .57022 .60876 Mtetra
.57022 .60876 .57529 .61397 .58504 .61115 .57999 .60593 Mtetra
.57999 .60593 .58504 .61115 .59482 .60833 .58979 .60308 Mtetra
.58979 .60308 .59482 .60833 .60463 .60549 .59963 .60023 Mtetra
.59963 .60023 .60463 .60549 .61448 .60265 .6095 .59737 Mtetra
.6095 .59737 .61448 .60265 .62437 .59979 .61941 .59449 Mtetra
.61941 .59449 .62437 .59979 .63428 .59692 .62935 .59161 Mtetra
.62935 .59161 .63428 .59692 .64424 .59405 .63933 .58871 Mtetra
.63933 .58871 .64424 .59405 .65423 .59116 .64934 .58581 Mtetra
.64934 .58581 .65423 .59116 .66425 .58826 .65939 .58289 Mtetra
.65939 .58289 .66425 .58826 .67431 .58536 .66947 .57996 Mtetra
.66947 .57996 .67431 .58536 .68441 .58244 .67959 .57703 Mtetra
.67959 .57703 .68441 .58244 .69454 .57951 .68975 .57408 Mtetra
.68975 .57408 .69454 .57951 .70471 .57657 .69995 .57112 Mtetra
.69995 .57112 .70471 .57657 .71491 .57363 .71018 .56815 Mtetra
.71018 .56815 .71491 .57363 .72516 .57067 .72044 .56517 Mtetra
.72044 .56517 .72516 .57067 .73544 .5677 .73075 .56218 Mtetra
.73075 .56218 .73544 .5677 .74575 .56471 .74109 .55918 Mtetra
.74109 .55918 .74575 .56471 .75611 .56172 .75147 .55617 Mtetra
.75147 .55617 .75611 .56172 .7665 .55872 .76189 .55315 Mtetra
.76189 .55315 .7665 .55872 .77693 .55571 .77234 .55012 Mtetra
.77234 .55012 .77693 .55571 .78739 .55268 .78284 .54707 Mtetra
.78284 .54707 .78739 .55268 .7979 .54965 .79337 .54401 Mtetra
.79337 .54401 .7979 .54965 .80844 .5466 .80394 .54095 Mtetra
.80394 .54095 .80844 .5466 .81902 .54354 .81455 .53787 Mtetra
.81455 .53787 .81902 .54354 .82964 .54047 .8252 .53478 Mtetra
.8252 .53478 .82964 .54047 .8403 .53739 .83589 .53168 Mtetra
.83589 .53168 .8403 .53739 .851 .5343 .84661 .52857 Mtetra
.84661 .52857 .851 .5343 .86174 .5312 .85738 .52544 Mtetra
.85738 .52544 .86174 .5312 .87252 .52809 .86819 .52231 Mtetra
.86819 .52231 .87252 .52809 .88334 .52496 .87903 .51916 Mtetra
.87903 .51916 .88334 .52496 .89419 .52182 .88992 .516 Mtetra
.88992 .516 .89419 .52182 .90509 .51867 .90085 .51283 Mtetra
.90085 .51283 .90509 .51867 .91603 .51551 .91182 .50965 Mtetra
.91182 .50965 .91603 .51551 .92701 .51234 .92283 .50645 Mtetra
.92283 .50645 .92701 .51234 .93803 .50916 .93388 .50324 Mtetra
.93388 .50324 .93803 .50916 .94909 .50596 .94497 .50003 Mtetra
.94497 .50003 .94909 .50596 .9602 .50275 .9561 .4968 Mtetra
.35813 .66383 .36369 .66869 .37275 .66606 .3672 .66119 Mtetra
.3672 .66119 .37275 .66606 .38183 .66342 .3763 .65854 Mtetra
.3763 .65854 .38183 .66342 .39094 .66078 .38544 .65587 Mtetra
.38544 .65587 .39094 .66078 .40009 .65813 .3946 .6532 Mtetra
.3946 .6532 .40009 .65813 .40927 .65546 .4038 .65052 Mtetra
.4038 .65052 .40927 .65546 .41848 .65279 .41303 .64783 Mtetra
.41303 .64783 .41848 .65279 .42772 .65011 .42229 .64514 Mtetra
.42229 .64514 .42772 .65011 .43699 .64742 .43158 .64243 Mtetra
.43158 .64243 .43699 .64742 .44629 .64472 .4409 .63971 Mtetra
.4409 .63971 .44629 .64472 .45563 .64201 .45026 .63699 Mtetra
.45026 .63699 .45563 .64201 .465 .63929 .45965 .63425 Mtetra
.45965 .63425 .465 .63929 .4744 .63657 .46907 .63151 Mtetra
.46907 .63151 .4744 .63657 .48383 .63383 .47853 .62875 Mtetra
.47853 .62875 .48383 .63383 .4933 .63108 .48801 .62599 Mtetra
.48801 .62599 .4933 .63108 .50279 .62833 .49753 .62321 Mtetra
.49753 .62321 .50279 .62833 .51233 .62556 .50709 .62043 Mtetra
.50709 .62043 .51233 .62556 .52189 .62279 .51667 .61764 Mtetra
.51667 .61764 .52189 .62279 .53149 .62 .52629 .61483 Mtetra
.52629 .61483 .53149 .62 .54112 .61721 .53595 .61202 Mtetra
.53595 .61202 .54112 .61721 .55079 .6144 .54563 .6092 Mtetra
.54563 .6092 .55079 .6144 .56049 .61159 .55536 .60636 Mtetra
.55536 .60636 .56049 .61159 .57022 .60876 .56511 .60352 Mtetra
.56511 .60352 .57022 .60876 .57999 .60593 .5749 .60067 Mtetra
.5749 .60067 .57999 .60593 .58979 .60308 .58473 .59781 Mtetra
.58473 .59781 .58979 .60308 .59963 .60023 .59459 .59493 Mtetra
.59459 .59493 .59963 .60023 .6095 .59737 .60448 .59205 Mtetra
.60448 .59205 .6095 .59737 .61941 .59449 .61441 .58916 Mtetra
.61441 .58916 .61941 .59449 .62935 .59161 .62438 .58625 Mtetra
.62438 .58625 .62935 .59161 .63933 .58871 .63438 .58334 Mtetra
.63438 .58334 .63933 .58871 .64934 .58581 .64442 .58041 Mtetra
.64442 .58041 .64934 .58581 .65939 .58289 .65449 .57748 Mtetra
.65449 .57748 .65939 .58289 .66947 .57996 .6646 .57453 Mtetra
.6646 .57453 .66947 .57996 .67959 .57703 .67475 .57158 Mtetra
.67475 .57158 .67959 .57703 .68975 .57408 .68493 .56861 Mtetra
.68493 .56861 .68975 .57408 .69995 .57112 .69515 .56563 Mtetra
.69515 .56563 .69995 .57112 .71018 .56815 .70541 .56264 Mtetra
.70541 .56264 .71018 .56815 .72044 .56517 .7157 .55965 Mtetra
.7157 .55965 .72044 .56517 .73075 .56218 .72603 .55664 Mtetra
.72603 .55664 .73075 .56218 .74109 .55918 .7364 .55361 Mtetra
.7364 .55361 .74109 .55918 .75147 .55617 .7468 .55058 Mtetra
.7468 .55058 .75147 .55617 .76189 .55315 .75725 .54754 Mtetra
.75725 .54754 .76189 .55315 .77234 .55012 .76773 .54449 Mtetra
.76773 .54449 .77234 .55012 .78284 .54707 .77825 .54142 Mtetra
.77825 .54142 .78284 .54707 .79337 .54401 .78881 .53834 Mtetra
.78881 .53834 .79337 .54401 .80394 .54095 .79941 .53526 Mtetra
.79941 .53526 .80394 .54095 .81455 .53787 .81005 .53216 Mtetra
.81005 .53216 .81455 .53787 .8252 .53478 .82072 .52905 Mtetra
.82072 .52905 .8252 .53478 .83589 .53168 .83144 .52592 Mtetra
.83144 .52592 .83589 .53168 .84661 .52857 .84219 .52279 Mtetra
.84219 .52279 .84661 .52857 .85738 .52544 .85299 .51964 Mtetra
.85299 .51964 .85738 .52544 .86819 .52231 .86383 .51649 Mtetra
.86383 .51649 .86819 .52231 .87903 .51916 .8747 .51332 Mtetra
.8747 .51332 .87903 .51916 .88992 .516 .88562 .51014 Mtetra
.88562 .51014 .88992 .516 .90085 .51283 .89658 .50694 Mtetra
.89658 .50694 .90085 .51283 .91182 .50965 .90758 .50374 Mtetra
.90758 .50374 .91182 .50965 .92283 .50645 .91862 .50052 Mtetra
.91862 .50052 .92283 .50645 .93388 .50324 .9297 .49729 Mtetra
.9297 .49729 .93388 .50324 .94497 .50003 .94082 .49405 Mtetra
.94082 .49405 .94497 .50003 .9561 .4968 .95198 .4908 Mtetra
.35253 .65894 .35813 .66383 .3672 .66119 .36162 .65628 Mtetra
.36162 .65628 .3672 .66119 .3763 .65854 .37074 .65361 Mtetra
.37074 .65361 .3763 .65854 .38544 .65587 .3799 .65094 Mtetra
.3799 .65094 .38544 .65587 .3946 .6532 .38908 .64825 Mtetra
.38908 .64825 .3946 .6532 .4038 .65052 .3983 .64555 Mtetra
.3983 .64555 .4038 .65052 .41303 .64783 .40755 .64285 Mtetra
.40755 .64285 .41303 .64783 .42229 .64514 .41683 .64013 Mtetra
.41683 .64013 .42229 .64514 .43158 .64243 .42614 .63741 Mtetra
.42614 .63741 .43158 .64243 .4409 .63971 .43548 .63467 Mtetra
.43548 .63467 .4409 .63971 .45026 .63699 .44486 .63193 Mtetra
.44486 .63193 .45026 .63699 .45965 .63425 .45427 .62918 Mtetra
.45427 .62918 .45965 .63425 .46907 .63151 .46371 .62641 Mtetra
.46371 .62641 .46907 .63151 .47853 .62875 .47319 .62364 Mtetra
.47319 .62364 .47853 .62875 .48801 .62599 .48269 .62086 Mtetra
.48269 .62086 .48801 .62599 .49753 .62321 .49224 .61807 Mtetra
.49224 .61807 .49753 .62321 .50709 .62043 .50181 .61527 Mtetra
.50181 .61527 .50709 .62043 .51667 .61764 .51142 .61245 Mtetra
.51142 .61245 .51667 .61764 .52629 .61483 .52106 .60963 Mtetra
.52106 .60963 .52629 .61483 .53595 .61202 .53074 .6068 Mtetra
.53074 .6068 .53595 .61202 .54563 .6092 .54045 .60396 Mtetra
.54045 .60396 .54563 .6092 .55536 .60636 .55019 .60111 Mtetra
.55019 .60111 .55536 .60636 .56511 .60352 .55997 .59825 Mtetra
.55997 .59825 .56511 .60352 .5749 .60067 .56978 .59538 Mtetra
.56978 .59538 .5749 .60067 .58473 .59781 .57963 .59249 Mtetra
.57963 .59249 .58473 .59781 .59459 .59493 .58952 .5896 Mtetra
.58952 .5896 .59459 .59493 .60448 .59205 .59944 .5867 Mtetra
.59944 .5867 .60448 .59205 .61441 .58916 .60939 .58379 Mtetra
.60939 .58379 .61441 .58916 .62438 .58625 .61938 .58087 Mtetra
.61938 .58087 .62438 .58625 .63438 .58334 .62941 .57793 Mtetra
.62941 .57793 .63438 .58334 .64442 .58041 .63947 .57499 Mtetra
.63947 .57499 .64442 .58041 .65449 .57748 .64957 .57203 Mtetra
.64957 .57203 .65449 .57748 .6646 .57453 .6597 .56907 Mtetra
.6597 .56907 .6646 .57453 .67475 .57158 .66987 .56609 Mtetra
.66987 .56609 .67475 .57158 .68493 .56861 .68008 .56311 Mtetra
.68008 .56311 .68493 .56861 .69515 .56563 .69032 .56011 Mtetra
.69032 .56011 .69515 .56563 .70541 .56264 .7006 .5571 Mtetra
.7006 .5571 .70541 .56264 .7157 .55965 .71092 .55408 Mtetra
.71092 .55408 .7157 .55965 .72603 .55664 .72128 .55105 Mtetra
.72128 .55105 .72603 .55664 .7364 .55361 .73168 .54801 Mtetra
.73168 .54801 .7364 .55361 .7468 .55058 .74211 .54496 Mtetra
.74211 .54496 .7468 .55058 .75725 .54754 .75258 .54189 Mtetra
.75258 .54189 .75725 .54754 .76773 .54449 .76309 .53882 Mtetra
.76309 .53882 .76773 .54449 .77825 .54142 .77364 .53573 Mtetra
.77364 .53573 .77825 .54142 .78881 .53834 .78422 .53263 Mtetra
.78422 .53263 .78881 .53834 .79941 .53526 .79485 .52952 Mtetra
.79485 .52952 .79941 .53526 .81005 .53216 .80551 .5264 Mtetra
.80551 .5264 .81005 .53216 .82072 .52905 .81622 .52327 Mtetra
.81622 .52327 .82072 .52905 .83144 .52592 .82696 .52013 Mtetra
.82696 .52013 .83144 .52592 .84219 .52279 .83775 .51697 Mtetra
.83775 .51697 .84219 .52279 .85299 .51964 .84857 .51381 Mtetra
.84857 .51381 .85299 .51964 .86383 .51649 .85944 .51063 Mtetra
.85944 .51063 .86383 .51649 .8747 .51332 .87034 .50744 Mtetra
.87034 .50744 .8747 .51332 .88562 .51014 .88129 .50423 Mtetra
.88129 .50423 .88562 .51014 .89658 .50694 .89227 .50102 Mtetra
.89227 .50102 .89658 .50694 .90758 .50374 .9033 .49779 Mtetra
.9033 .49779 .90758 .50374 .91862 .50052 .91437 .49455 Mtetra
.91437 .49455 .91862 .50052 .9297 .49729 .92549 .4913 Mtetra
.92549 .4913 .9297 .49729 .94082 .49405 .93664 .48804 Mtetra
.93664 .48804 .94082 .49405 .95198 .4908 .94784 .48476 Mtetra
.34689 .65403 .35253 .65894 .36162 .65628 .356 .65135 Mtetra
.356 .65135 .36162 .65628 .37074 .65361 .36515 .64866 Mtetra
.36515 .64866 .37074 .65361 .3799 .65094 .37432 .64597 Mtetra
.37432 .64597 .3799 .65094 .38908 .64825 .38352 .64326 Mtetra
.38352 .64326 .38908 .64825 .3983 .64555 .39276 .64055 Mtetra
.39276 .64055 .3983 .64555 .40755 .64285 .40203 .63783 Mtetra
.40203 .63783 .40755 .64285 .41683 .64013 .41133 .63509 Mtetra
.41133 .63509 .41683 .64013 .42614 .63741 .42066 .63235 Mtetra
.42066 .63235 .42614 .63741 .43548 .63467 .43003 .6296 Mtetra
.43003 .6296 .43548 .63467 .44486 .63193 .43942 .62684 Mtetra
.43942 .62684 .44486 .63193 .45427 .62918 .44885 .62407 Mtetra
.44885 .62407 .45427 .62918 .46371 .62641 .45832 .62129 Mtetra
.45832 .62129 .46371 .62641 .47319 .62364 .46781 .6185 Mtetra
.46781 .6185 .47319 .62364 .48269 .62086 .47734 .6157 Mtetra
.47734 .6157 .48269 .62086 .49224 .61807 .4869 .61289 Mtetra
.4869 .61289 .49224 .61807 .50181 .61527 .4965 .61007 Mtetra
.4965 .61007 .50181 .61527 .51142 .61245 .50613 .60724 Mtetra
.50613 .60724 .51142 .61245 .52106 .60963 .5158 .6044 Mtetra
.5158 .6044 .52106 .60963 .53074 .6068 .52549 .60155 Mtetra
.52549 .60155 .53074 .6068 .54045 .60396 .53523 .59869 Mtetra
.53523 .59869 .54045 .60396 .55019 .60111 .54499 .59582 Mtetra
.54499 .59582 .55019 .60111 .55997 .59825 .5548 .59294 Mtetra
.5548 .59294 .55997 .59825 .56978 .59538 .56463 .59005 Mtetra
.56463 .59005 .56978 .59538 .57963 .59249 .5745 .58715 Mtetra
.5745 .58715 .57963 .59249 .58952 .5896 .58441 .58424 Mtetra
.58441 .58424 .58952 .5896 .59944 .5867 .59435 .58132 Mtetra
.59435 .58132 .59944 .5867 .60939 .58379 .60433 .57838 Mtetra
.60433 .57838 .60939 .58379 .61938 .58087 .61435 .57544 Mtetra
.61435 .57544 .61938 .58087 .62941 .57793 .6244 .57249 Mtetra
.6244 .57249 .62941 .57793 .63947 .57499 .63448 .56952 Mtetra
.63448 .56952 .63947 .57499 .64957 .57203 .6446 .56655 Mtetra
.6446 .56655 .64957 .57203 .6597 .56907 .65476 .56357 Mtetra
.65476 .56357 .6597 .56907 .66987 .56609 .66496 .56057 Mtetra
.66496 .56057 .66987 .56609 .68008 .56311 .67519 .55756 Mtetra
.67519 .55756 .68008 .56311 .69032 .56011 .68546 .55455 Mtetra
.68546 .55455 .69032 .56011 .7006 .5571 .69577 .55152 Mtetra
.69577 .55152 .7006 .5571 .71092 .55408 .70612 .54848 Mtetra
.70612 .54848 .71092 .55408 .72128 .55105 .7165 .54543 Mtetra
.7165 .54543 .72128 .55105 .73168 .54801 .72692 .54236 Mtetra
.72692 .54236 .73168 .54801 .74211 .54496 .73738 .53929 Mtetra
.73738 .53929 .74211 .54496 .75258 .54189 .74788 .53621 Mtetra
.74788 .53621 .75258 .54189 .76309 .53882 .75841 .53311 Mtetra
.75841 .53311 .76309 .53882 .77364 .53573 .76899 .53 Mtetra
.76899 .53 .77364 .53573 .78422 .53263 .7796 .52688 Mtetra
.7796 .52688 .78422 .53263 .79485 .52952 .79026 .52375 Mtetra
.79026 .52375 .79485 .52952 .80551 .5264 .80095 .52061 Mtetra
.80095 .52061 .80551 .5264 .81622 .52327 .81168 .51746 Mtetra
.81168 .51746 .81622 .52327 .82696 .52013 .82245 .51429 Mtetra
.82245 .51429 .82696 .52013 .83775 .51697 .83327 .51112 Mtetra
.83327 .51112 .83775 .51697 .84857 .51381 .84412 .50793 Mtetra
.84412 .50793 .84857 .51381 .85944 .51063 .85501 .50473 Mtetra
.85501 .50473 .85944 .51063 .87034 .50744 .86595 .50151 Mtetra
.86595 .50151 .87034 .50744 .88129 .50423 .87693 .49829 Mtetra
.87693 .49829 .88129 .50423 .89227 .50102 .88794 .49505 Mtetra
.88794 .49505 .89227 .50102 .9033 .49779 .899 .4918 Mtetra
.899 .4918 .9033 .49779 .91437 .49455 .9101 .48854 Mtetra
.9101 .48854 .91437 .49455 .92549 .4913 .92125 .48527 Mtetra
.92125 .48527 .92549 .4913 .93664 .48804 .93243 .48198 Mtetra
.93243 .48198 .93664 .48804 .94784 .48476 .94366 .47868 Mtetra
.34122 .64908 .34689 .65403 .356 .65135 .35035 .64638 Mtetra
.35035 .64638 .356 .65135 .36515 .64866 .35951 .64368 Mtetra
.35951 .64368 .36515 .64866 .37432 .64597 .36871 .64097 Mtetra
.36871 .64097 .37432 .64597 .38352 .64326 .37793 .63825 Mtetra
.37793 .63825 .38352 .64326 .39276 .64055 .38719 .63551 Mtetra
.38719 .63551 .39276 .64055 .40203 .63783 .39647 .63277 Mtetra
.39647 .63277 .40203 .63783 .41133 .63509 .40579 .63002 Mtetra
.40579 .63002 .41133 .63509 .42066 .63235 .41515 .62726 Mtetra
.41515 .62726 .42066 .63235 .43003 .6296 .42453 .62449 Mtetra
.42453 .62449 .43003 .6296 .43942 .62684 .43395 .62172 Mtetra
.43395 .62172 .43942 .62684 .44885 .62407 .4434 .61893 Mtetra
.4434 .61893 .44885 .62407 .45832 .62129 .45289 .61613 Mtetra
.45289 .61613 .45832 .62129 .46781 .6185 .4624 .61332 Mtetra
.4624 .61332 .46781 .6185 .47734 .6157 .47195 .6105 Mtetra
.47195 .6105 .47734 .6157 .4869 .61289 .48154 .60767 Mtetra
.48154 .60767 .4869 .61289 .4965 .61007 .49116 .60484 Mtetra
.49116 .60484 .4965 .61007 .50613 .60724 .50081 .60199 Mtetra
.50081 .60199 .50613 .60724 .5158 .6044 .5105 .59913 Mtetra
.5105 .59913 .5158 .6044 .52549 .60155 .52022 .59626 Mtetra
.52022 .59626 .52549 .60155 .53523 .59869 .52997 .59338 Mtetra
.52997 .59338 .53523 .59869 .54499 .59582 .53976 .59049 Mtetra
.53976 .59049 .54499 .59582 .5548 .59294 .54959 .58759 Mtetra
.54959 .58759 .5548 .59294 .56463 .59005 .55945 .58469 Mtetra
.55945 .58469 .56463 .59005 .5745 .58715 .56934 .58177 Mtetra
.56934 .58177 .5745 .58715 .58441 .58424 .57927 .57884 Mtetra
.57927 .57884 .58441 .58424 .59435 .58132 .58924 .57589 Mtetra
.58924 .57589 .59435 .58132 .60433 .57838 .59924 .57294 Mtetra
.59924 .57294 .60433 .57838 .61435 .57544 .60928 .56998 Mtetra
.60928 .56998 .61435 .57544 .6244 .57249 .61935 .56701 Mtetra
.61935 .56701 .6244 .57249 .63448 .56952 .62946 .56403 Mtetra
.62946 .56403 .63448 .56952 .6446 .56655 .63961 .56103 Mtetra
.63961 .56103 .6446 .56655 .65476 .56357 .64979 .55803 Mtetra
.64979 .55803 .65476 .56357 .66496 .56057 .66002 .55501 Mtetra
.66002 .55501 .66496 .56057 .67519 .55756 .67027 .55198 Mtetra
.67027 .55198 .67519 .55756 .68546 .55455 .68057 .54895 Mtetra
.68057 .54895 .68546 .55455 .69577 .55152 .6909 .5459 Mtetra
.6909 .5459 .69577 .55152 .70612 .54848 .70127 .54284 Mtetra
.70127 .54284 .70612 .54848 .7165 .54543 .71168 .53976 Mtetra
.71168 .53976 .7165 .54543 .72692 .54236 .72213 .53668 Mtetra
.72213 .53668 .72692 .54236 .73738 .53929 .73262 .53359 Mtetra
.73262 .53359 .73738 .53929 .74788 .53621 .74314 .53048 Mtetra
.74314 .53048 .74788 .53621 .75841 .53311 .75371 .52737 Mtetra
.75371 .52737 .75841 .53311 .76899 .53 .76431 .52424 Mtetra
.76431 .52424 .76899 .53 .7796 .52688 .77495 .5211 Mtetra
.77495 .5211 .7796 .52688 .79026 .52375 .78563 .51794 Mtetra
.78563 .51794 .79026 .52375 .80095 .52061 .79635 .51478 Mtetra
.79635 .51478 .80095 .52061 .81168 .51746 .80711 .51161 Mtetra
.80711 .51161 .81168 .51746 .82245 .51429 .81792 .50842 Mtetra
.81792 .50842 .82245 .51429 .83327 .51112 .82876 .50522 Mtetra
.82876 .50522 .83327 .51112 .84412 .50793 .83964 .50201 Mtetra
.83964 .50201 .84412 .50793 .85501 .50473 .85056 .49879 Mtetra
.85056 .49879 .85501 .50473 .86595 .50151 .86153 .49555 Mtetra
.86153 .49555 .86595 .50151 .87693 .49829 .87253 .4923 Mtetra
.87253 .4923 .87693 .49829 .88794 .49505 .88358 .48904 Mtetra
.88358 .48904 .88794 .49505 .899 .4918 .89467 .48577 Mtetra
.89467 .48577 .899 .4918 .9101 .48854 .9058 .48249 Mtetra
.9058 .48249 .9101 .48854 .92125 .48527 .91698 .47919 Mtetra
.91698 .47919 .92125 .48527 .93243 .48198 .92819 .47588 Mtetra
.92819 .47588 .93243 .48198 .94366 .47868 .93945 .47256 Mtetra
.33552 .6441 .34122 .64908 .35035 .64638 .34467 .64139 Mtetra
.34467 .64139 .35035 .64638 .35951 .64368 .35385 .63866 Mtetra
.35385 .63866 .35951 .64368 .36871 .64097 .36306 .63594 Mtetra
.36306 .63594 .36871 .64097 .37793 .63825 .3723 .6332 Mtetra
.3723 .6332 .37793 .63825 .38719 .63551 .38158 .63045 Mtetra
.38158 .63045 .38719 .63551 .39647 .63277 .39089 .62769 Mtetra
.39089 .62769 .39647 .63277 .40579 .63002 .40023 .62492 Mtetra
.40023 .62492 .40579 .63002 .41515 .62726 .4096 .62214 Mtetra
.4096 .62214 .41515 .62726 .42453 .62449 .41901 .61936 Mtetra
.41901 .61936 .42453 .62449 .43395 .62172 .42844 .61656 Mtetra
.42844 .61656 .43395 .62172 .4434 .61893 .43792 .61375 Mtetra
.43792 .61375 .4434 .61893 .45289 .61613 .44742 .61094 Mtetra
.44742 .61094 .45289 .61613 .4624 .61332 .45696 .60811 Mtetra
.45696 .60811 .4624 .61332 .47195 .6105 .46653 .60527 Mtetra
.46653 .60527 .47195 .6105 .48154 .60767 .47614 .60243 Mtetra
.47614 .60243 .48154 .60767 .49116 .60484 .48578 .59957 Mtetra
.48578 .59957 .49116 .60484 .50081 .60199 .49545 .5967 Mtetra
.49545 .5967 .50081 .60199 .5105 .59913 .50516 .59383 Mtetra
.50516 .59383 .5105 .59913 .52022 .59626 .5149 .59094 Mtetra
.5149 .59094 .52022 .59626 .52997 .59338 .52468 .58804 Mtetra
.52468 .58804 .52997 .59338 .53976 .59049 .5345 .58513 Mtetra
.5345 .58513 .53976 .59049 .54959 .58759 .54434 .58222 Mtetra
.54434 .58222 .54959 .58759 .55945 .58469 .55423 .57929 Mtetra
.55423 .57929 .55945 .58469 .56934 .58177 .56414 .57635 Mtetra
.56414 .57635 .56934 .58177 .57927 .57884 .5741 .5734 Mtetra
.5741 .5734 .57927 .57884 .58924 .57589 .58409 .57044 Mtetra
.58409 .57044 .58924 .57589 .59924 .57294 .59412 .56747 Mtetra
.59412 .56747 .59924 .57294 .60928 .56998 .60418 .56449 Mtetra
.60418 .56449 .60928 .56998 .61935 .56701 .61428 .56149 Mtetra
.61428 .56149 .61935 .56701 .62946 .56403 .62441 .55849 Mtetra
.62441 .55849 .62946 .56403 .63961 .56103 .63458 .55547 Mtetra
.63458 .55547 .63961 .56103 .64979 .55803 .64479 .55245 Mtetra
.64479 .55245 .64979 .55803 .66002 .55501 .65504 .54941 Mtetra
.65504 .54941 .66002 .55501 .67027 .55198 .66532 .54637 Mtetra
.66532 .54637 .67027 .55198 .68057 .54895 .67564 .54331 Mtetra
.67564 .54331 .68057 .54895 .6909 .5459 .686 .54024 Mtetra
.686 .54024 .6909 .5459 .70127 .54284 .6964 .53716 Mtetra
.6964 .53716 .70127 .54284 .71168 .53976 .70684 .53406 Mtetra
.70684 .53406 .71168 .53976 .72213 .53668 .71731 .53096 Mtetra
.71731 .53096 .72213 .53668 .73262 .53359 .72782 .52785 Mtetra
.72782 .52785 .73262 .53359 .74314 .53048 .73838 .52472 Mtetra
.73838 .52472 .74314 .53048 .75371 .52737 .74897 .52158 Mtetra
.74897 .52158 .75371 .52737 .76431 .52424 .7596 .51843 Mtetra
.7596 .51843 .76431 .52424 .77495 .5211 .77027 .51527 Mtetra
.77027 .51527 .77495 .5211 .78563 .51794 .78098 .5121 Mtetra
.78098 .5121 .78563 .51794 .79635 .51478 .79173 .50891 Mtetra
.79173 .50891 .79635 .51478 .80711 .51161 .80251 .50571 Mtetra
.80251 .50571 .80711 .51161 .81792 .50842 .81335 .5025 Mtetra
.81335 .5025 .81792 .50842 .82876 .50522 .82422 .49928 Mtetra
.82422 .49928 .82876 .50522 .83964 .50201 .83513 .49605 Mtetra
.83513 .49605 .83964 .50201 .85056 .49879 .84608 .4928 Mtetra
.84608 .4928 .85056 .49879 .86153 .49555 .85707 .48955 Mtetra
.85707 .48955 .86153 .49555 .87253 .4923 .86811 .48627 Mtetra
.86811 .48627 .87253 .4923 .88358 .48904 .87919 .48299 Mtetra
.87919 .48299 .88358 .48904 .89467 .48577 .89031 .4797 Mtetra
.89031 .4797 .89467 .48577 .9058 .48249 .90147 .47639 Mtetra
.90147 .47639 .9058 .48249 .91698 .47919 .91268 .47307 Mtetra
.91268 .47307 .91698 .47919 .92819 .47588 .92392 .46974 Mtetra
.92392 .46974 .92819 .47588 .93945 .47256 .93521 .46639 Mtetra
.32977 .63908 .33552 .6441 .34467 .64139 .33894 .63636 Mtetra
.33894 .63636 .34467 .64139 .35385 .63866 .34814 .63362 Mtetra
.34814 .63362 .35385 .63866 .36306 .63594 .35737 .63087 Mtetra
.35737 .63087 .36306 .63594 .3723 .6332 .36664 .62811 Mtetra
.36664 .62811 .3723 .6332 .38158 .63045 .37593 .62535 Mtetra
.37593 .62535 .38158 .63045 .39089 .62769 .38526 .62257 Mtetra
.38526 .62257 .39089 .62769 .40023 .62492 .39462 .61979 Mtetra
.39462 .61979 .40023 .62492 .4096 .62214 .40402 .61699 Mtetra
.40402 .61699 .4096 .62214 .41901 .61936 .41344 .61418 Mtetra
.41344 .61418 .41901 .61936 .42844 .61656 .4229 .61137 Mtetra
.4229 .61137 .42844 .61656 .43792 .61375 .43239 .60854 Mtetra
.43239 .60854 .43792 .61375 .44742 .61094 .44192 .60571 Mtetra
.44192 .60571 .44742 .61094 .45696 .60811 .45148 .60286 Mtetra
.45148 .60286 .45696 .60811 .46653 .60527 .46108 .60001 Mtetra
.46108 .60001 .46653 .60527 .47614 .60243 .4707 .59714 Mtetra
.4707 .59714 .47614 .60243 .48578 .59957 .48037 .59427 Mtetra
.48037 .59427 .48578 .59957 .49545 .5967 .49006 .59138 Mtetra
.49006 .59138 .49545 .5967 .50516 .59383 .49979 .58849 Mtetra
.49979 .58849 .50516 .59383 .5149 .59094 .50956 .58558 Mtetra
.50956 .58558 .5149 .59094 .52468 .58804 .51936 .58267 Mtetra
.51936 .58267 .52468 .58804 .5345 .58513 .52919 .57974 Mtetra
.52919 .57974 .5345 .58513 .54434 .58222 .53907 .5768 Mtetra
.53907 .5768 .54434 .58222 .55423 .57929 .54897 .57385 Mtetra
.54897 .57385 .55423 .57929 .56414 .57635 .55891 .57089 Mtetra
.55891 .57089 .56414 .57635 .5741 .5734 .56889 .56792 Mtetra
.56889 .56792 .5741 .5734 .58409 .57044 .57891 .56494 Mtetra
.57891 .56494 .58409 .57044 .59412 .56747 .58896 .56195 Mtetra
.58896 .56195 .59412 .56747 .60418 .56449 .59904 .55895 Mtetra
.59904 .55895 .60418 .56449 .61428 .56149 .60917 .55594 Mtetra
.60917 .55594 .61428 .56149 .62441 .55849 .61933 .55292 Mtetra
.61933 .55292 .62441 .55849 .63458 .55547 .62952 .54988 Mtetra
.62952 .54988 .63458 .55547 .64479 .55245 .63976 .54684 Mtetra
.63976 .54684 .64479 .55245 .65504 .54941 .65003 .54378 Mtetra
.65003 .54378 .65504 .54941 .66532 .54637 .66034 .54071 Mtetra
.66034 .54071 .66532 .54637 .67564 .54331 .67069 .53763 Mtetra
.67069 .53763 .67564 .54331 .686 .54024 .68107 .53454 Mtetra
.68107 .53454 .686 .54024 .6964 .53716 .69149 .53144 Mtetra
.69149 .53144 .6964 .53716 .70684 .53406 .70196 .52833 Mtetra
.70196 .52833 .70684 .53406 .71731 .53096 .71246 .5252 Mtetra
.71246 .5252 .71731 .53096 .72782 .52785 .723 .52206 Mtetra
.723 .52206 .72782 .52785 .73838 .52472 .73358 .51892 Mtetra
.73358 .51892 .73838 .52472 .74897 .52158 .74419 .51576 Mtetra
.74419 .51576 .74897 .52158 .7596 .51843 .75485 .51258 Mtetra
.75485 .51258 .7596 .51843 .77027 .51527 .76555 .5094 Mtetra
.76555 .5094 .77027 .51527 .78098 .5121 .77629 .50621 Mtetra
.77629 .50621 .78098 .5121 .79173 .50891 .78707 .503 Mtetra
.78707 .503 .79173 .50891 .80251 .50571 .79788 .49978 Mtetra
.79788 .49978 .80251 .50571 .81335 .5025 .80874 .49655 Mtetra
.80874 .49655 .81335 .5025 .82422 .49928 .81964 .4933 Mtetra
.81964 .4933 .82422 .49928 .83513 .49605 .83058 .49005 Mtetra
.83058 .49005 .83513 .49605 .84608 .4928 .84157 .48678 Mtetra
.84157 .48678 .84608 .4928 .85707 .48955 .85259 .4835 Mtetra
.85259 .4835 .85707 .48955 .86811 .48627 .86366 .4802 Mtetra
.86366 .4802 .86811 .48627 .87919 .48299 .87477 .4769 Mtetra
.87477 .4769 .87919 .48299 .89031 .4797 .88592 .47358 Mtetra
.88592 .47358 .89031 .4797 .90147 .47639 .89711 .47025 Mtetra
.89711 .47025 .90147 .47639 .91268 .47307 .90834 .46691 Mtetra
.90834 .46691 .91268 .47307 .92392 .46974 .91962 .46355 Mtetra
.91962 .46355 .92392 .46974 .93521 .46639 .93095 .46018 Mtetra
.32399 .63404 .32977 .63908 .33894 .63636 .33318 .63129 Mtetra
.33318 .63129 .33894 .63636 .34814 .63362 .3424 .62854 Mtetra
.3424 .62854 .34814 .63362 .35737 .63087 .35165 .62577 Mtetra
.35165 .62577 .35737 .63087 .36664 .62811 .36094 .623 Mtetra
.36094 .623 .36664 .62811 .37593 .62535 .37025 .62021 Mtetra
.37025 .62021 .37593 .62535 .38526 .62257 .3796 .61742 Mtetra
.3796 .61742 .38526 .62257 .39462 .61979 .38898 .61462 Mtetra
.38898 .61462 .39462 .61979 .40402 .61699 .3984 .6118 Mtetra
.3984 .6118 .40402 .61699 .41344 .61418 .40784 .60898 Mtetra
.40784 .60898 .41344 .61418 .4229 .61137 .41732 .60615 Mtetra
.41732 .60615 .4229 .61137 .43239 .60854 .42684 .6033 Mtetra
.42684 .6033 .43239 .60854 .44192 .60571 .43639 .60045 Mtetra
.43639 .60045 .44192 .60571 .45148 .60286 .44597 .59759 Mtetra
.44597 .59759 .45148 .60286 .46108 .60001 .45558 .59471 Mtetra
.45558 .59471 .46108 .60001 .4707 .59714 .46523 .59183 Mtetra
.46523 .59183 .4707 .59714 .48037 .59427 .47492 .58893 Mtetra
.47492 .58893 .48037 .59427 .49006 .59138 .48463 .58603 Mtetra
.48463 .58603 .49006 .59138 .49979 .58849 .49439 .58311 Mtetra
.49439 .58311 .49979 .58849 .50956 .58558 .50418 .58019 Mtetra
.50418 .58019 .50956 .58558 .51936 .58267 .514 .57725 Mtetra
.514 .57725 .51936 .58267 .52919 .57974 .52386 .57431 Mtetra
.52386 .57431 .52919 .57974 .53907 .5768 .53375 .57135 Mtetra
.53375 .57135 .53907 .5768 .54897 .57385 .54368 .56838 Mtetra
.54368 .56838 .54897 .57385 .55891 .57089 .55365 .5654 Mtetra
.55365 .5654 .55891 .57089 .56889 .56792 .56365 .56241 Mtetra
.56365 .56241 .56889 .56792 .57891 .56494 .57369 .55941 Mtetra
.57369 .55941 .57891 .56494 .58896 .56195 .58376 .5564 Mtetra
.58376 .5564 .58896 .56195 .59904 .55895 .59387 .55338 Mtetra
.59387 .55338 .59904 .55895 .60917 .55594 .60402 .55035 Mtetra
.60402 .55035 .60917 .55594 .61933 .55292 .61421 .5473 Mtetra
.61421 .5473 .61933 .55292 .62952 .54988 .62443 .54425 Mtetra
.62443 .54425 .62952 .54988 .63976 .54684 .63469 .54118 Mtetra
.63469 .54118 .63976 .54684 .65003 .54378 .64498 .53811 Mtetra
.64498 .53811 .65003 .54378 .66034 .54071 .65532 .53502 Mtetra
.65532 .53502 .66034 .54071 .67069 .53763 .66569 .53192 Mtetra
.66569 .53192 .67069 .53763 .68107 .53454 .6761 .52881 Mtetra
.6761 .52881 .68107 .53454 .69149 .53144 .68655 .52568 Mtetra
.68655 .52568 .69149 .53144 .70196 .52833 .69704 .52255 Mtetra
.69704 .52255 .70196 .52833 .71246 .5252 .70757 .5194 Mtetra
.70757 .5194 .71246 .5252 .723 .52206 .71814 .51624 Mtetra
.71814 .51624 .723 .52206 .73358 .51892 .72874 .51307 Mtetra
.72874 .51307 .73358 .51892 .74419 .51576 .73939 .50989 Mtetra
.73939 .50989 .74419 .51576 .75485 .51258 .75008 .5067 Mtetra
.75008 .5067 .75485 .51258 .76555 .5094 .7608 .50349 Mtetra
.7608 .50349 .76555 .5094 .77629 .50621 .77157 .50027 Mtetra
.77157 .50027 .77629 .50621 .78707 .503 .78237 .49704 Mtetra
.78237 .49704 .78707 .503 .79788 .49978 .79322 .4938 Mtetra
.79322 .4938 .79788 .49978 .80874 .49655 .80411 .49055 Mtetra
.80411 .49055 .80874 .49655 .81964 .4933 .81504 .48728 Mtetra
.81504 .48728 .81964 .4933 .83058 .49005 .82601 .484 Mtetra
.82601 .484 .83058 .49005 .84157 .48678 .83702 .48071 Mtetra
.83702 .48071 .84157 .48678 .85259 .4835 .84808 .47741 Mtetra
.84808 .47741 .85259 .4835 .86366 .4802 .85917 .47409 Mtetra
.85917 .47409 .86366 .4802 .87477 .4769 .87031 .47076 Mtetra
.87031 .47076 .87477 .4769 .88592 .47358 .88149 .46742 Mtetra
.88149 .46742 .88592 .47358 .89711 .47025 .89272 .46407 Mtetra
.89272 .46407 .89711 .47025 .90834 .46691 .90398 .4607 Mtetra
.90398 .4607 .90834 .46691 .91962 .46355 .91529 .45732 Mtetra
.91529 .45732 .91962 .46355 .93095 .46018 .92665 .45393 Mtetra
.31818 .62896 .32399 .63404 .33318 .63129 .32738 .6262 Mtetra
.32738 .6262 .33318 .63129 .3424 .62854 .33662 .62343 Mtetra
.33662 .62343 .3424 .62854 .35165 .62577 .34589 .62064 Mtetra
.34589 .62064 .35165 .62577 .36094 .623 .3552 .61785 Mtetra
.3552 .61785 .36094 .623 .37025 .62021 .36453 .61505 Mtetra
.36453 .61505 .37025 .62021 .3796 .61742 .3739 .61224 Mtetra
.3739 .61224 .3796 .61742 .38898 .61462 .3833 .60942 Mtetra
.3833 .60942 .38898 .61462 .3984 .6118 .39274 .60658 Mtetra
.39274 .60658 .3984 .6118 .40784 .60898 .40221 .60374 Mtetra
.40221 .60374 .40784 .60898 .41732 .60615 .41171 .60089 Mtetra
.41171 .60089 .41732 .60615 .42684 .6033 .42124 .59803 Mtetra
.42124 .59803 .42684 .6033 .43639 .60045 .43081 .59516 Mtetra
.43081 .59516 .43639 .60045 .44597 .59759 .44042 .59227 Mtetra
.44042 .59227 .44597 .59759 .45558 .59471 .45005 .58938 Mtetra
.45005 .58938 .45558 .59471 .46523 .59183 .45972 .58648 Mtetra
.45972 .58648 .46523 .59183 .47492 .58893 .46943 .58356 Mtetra
.46943 .58356 .47492 .58893 .48463 .58603 .47917 .58064 Mtetra
.47917 .58064 .48463 .58603 .49439 .58311 .48895 .57771 Mtetra
.48895 .57771 .49439 .58311 .50418 .58019 .49876 .57476 Mtetra
.49876 .57476 .50418 .58019 .514 .57725 .5086 .57181 Mtetra
.5086 .57181 .514 .57725 .52386 .57431 .51849 .56884 Mtetra
.51849 .56884 .52386 .57431 .53375 .57135 .5284 .56586 Mtetra
.5284 .56586 .53375 .57135 .54368 .56838 .53836 .56288 Mtetra
.53836 .56288 .54368 .56838 .55365 .5654 .54835 .55988 Mtetra
.54835 .55988 .55365 .5654 .56365 .56241 .55837 .55687 Mtetra
.55837 .55687 .56365 .56241 .57369 .55941 .56843 .55385 Mtetra
.56843 .55385 .57369 .55941 .58376 .5564 .57853 .55082 Mtetra
.57853 .55082 .58376 .5564 .59387 .55338 .58867 .54777 Mtetra
.58867 .54777 .59387 .55338 .60402 .55035 .59884 .54472 Mtetra
.59884 .54472 .60402 .55035 .61421 .5473 .60905 .54166 Mtetra
.60905 .54166 .61421 .5473 .62443 .54425 .6193 .53858 Mtetra
.6193 .53858 .62443 .54425 .63469 .54118 .62958 .53549 Mtetra
.62958 .53549 .63469 .54118 .64498 .53811 .63991 .53239 Mtetra
.63991 .53239 .64498 .53811 .65532 .53502 .65027 .52928 Mtetra
.65027 .52928 .65532 .53502 .66569 .53192 .66067 .52616 Mtetra
.66067 .52616 .66569 .53192 .6761 .52881 .6711 .52303 Mtetra
.6711 .52303 .6761 .52881 .68655 .52568 .68158 .51989 Mtetra
.68158 .51989 .68655 .52568 .69704 .52255 .6921 .51673 Mtetra
.6921 .51673 .69704 .52255 .70757 .5194 .70265 .51356 Mtetra
.70265 .51356 .70757 .5194 .71814 .51624 .71324 .51038 Mtetra
.71324 .51038 .71814 .51624 .72874 .51307 .72388 .50719 Mtetra
.72388 .50719 .72874 .51307 .73939 .50989 .73455 .50399 Mtetra
.73455 .50399 .73939 .50989 .75008 .5067 .74527 .50077 Mtetra
.74527 .50077 .75008 .5067 .7608 .50349 .75602 .49754 Mtetra
.75602 .49754 .7608 .50349 .77157 .50027 .76681 .4943 Mtetra
.76681 .4943 .77157 .50027 .78237 .49704 .77765 .49105 Mtetra
.77765 .49105 .78237 .49704 .79322 .4938 .78852 .48779 Mtetra
.78852 .48779 .79322 .4938 .80411 .49055 .79944 .48451 Mtetra
.79944 .48451 .80411 .49055 .81504 .48728 .8104 .48122 Mtetra
.8104 .48122 .81504 .48728 .82601 .484 .8214 .47792 Mtetra
.8214 .47792 .82601 .484 .83702 .48071 .83244 .4746 Mtetra
.83244 .4746 .83702 .48071 .84808 .47741 .84353 .47128 Mtetra
.84353 .47128 .84808 .47741 .85917 .47409 .85465 .46794 Mtetra
.85465 .46794 .85917 .47409 .87031 .47076 .86582 .46458 Mtetra
.86582 .46458 .87031 .47076 .88149 .46742 .87704 .46122 Mtetra
.87704 .46122 .88149 .46742 .89272 .46407 .88829 .45784 Mtetra
.88829 .45784 .89272 .46407 .90398 .4607 .89959 .45445 Mtetra
.89959 .45445 .90398 .4607 .91529 .45732 .91093 .45104 Mtetra
.91093 .45104 .91529 .45732 .92665 .45393 .92232 .44763 Mtetra
.31232 .62385 .31818 .62896 .32738 .6262 .32155 .62107 Mtetra
.32155 .62107 .32738 .6262 .33662 .62343 .33081 .61828 Mtetra
.33081 .61828 .33662 .62343 .34589 .62064 .3401 .61548 Mtetra
.3401 .61548 .34589 .62064 .3552 .61785 .34942 .61267 Mtetra
.34942 .61267 .3552 .61785 .36453 .61505 .35878 .60985 Mtetra
.35878 .60985 .36453 .61505 .3739 .61224 .36817 .60702 Mtetra
.36817 .60702 .3739 .61224 .3833 .60942 .37759 .60418 Mtetra
.37759 .60418 .3833 .60942 .39274 .60658 .38704 .60133 Mtetra
.38704 .60133 .39274 .60658 .40221 .60374 .39653 .59847 Mtetra
.39653 .59847 .40221 .60374 .41171 .60089 .40606 .5956 Mtetra
.40606 .5956 .41171 .60089 .42124 .59803 .41561 .59272 Mtetra
.41561 .59272 .42124 .59803 .43081 .59516 .4252 .58983 Mtetra
.4252 .58983 .43081 .59516 .44042 .59227 .43483 .58692 Mtetra
.43483 .58692 .44042 .59227 .45005 .58938 .44449 .58401 Mtetra
.44449 .58401 .45005 .58938 .45972 .58648 .45418 .58109 Mtetra
.45418 .58109 .45972 .58648 .46943 .58356 .46391 .57816 Mtetra
.46391 .57816 .46943 .58356 .47917 .58064 .47367 .57521 Mtetra
.47367 .57521 .47917 .58064 .48895 .57771 .48347 .57226 Mtetra
.48347 .57226 .48895 .57771 .49876 .57476 .4933 .5693 Mtetra
.4933 .5693 .49876 .57476 .5086 .57181 .50317 .56632 Mtetra
.50317 .56632 .5086 .57181 .51849 .56884 .51308 .56334 Mtetra
.51308 .56334 .51849 .56884 .5284 .56586 .52302 .56034 Mtetra
.52302 .56034 .5284 .56586 .53836 .56288 .533 .55733 Mtetra
.533 .55733 .53836 .56288 .54835 .55988 .54301 .55431 Mtetra
.54301 .55431 .54835 .55988 .55837 .55687 .55306 .55128 Mtetra
.55306 .55128 .55837 .55687 .56843 .55385 .56314 .54824 Mtetra
.56314 .54824 .56843 .55385 .57853 .55082 .57327 .54519 Mtetra
.57327 .54519 .57853 .55082 .58867 .54777 .58343 .54213 Mtetra
.58343 .54213 .58867 .54777 .59884 .54472 .59363 .53905 Mtetra
.59363 .53905 .59884 .54472 .60905 .54166 .60386 .53597 Mtetra
.60386 .53597 .60905 .54166 .6193 .53858 .61413 .53287 Mtetra
.61413 .53287 .6193 .53858 .62958 .53549 .62444 .52976 Mtetra
.62444 .52976 .62958 .53549 .63991 .53239 .63479 .52664 Mtetra
.63479 .52664 .63991 .53239 .65027 .52928 .64518 .52351 Mtetra
.64518 .52351 .65027 .52928 .66067 .52616 .6556 .52037 Mtetra
.6556 .52037 .66067 .52616 .6711 .52303 .66607 .51722 Mtetra
.66607 .51722 .6711 .52303 .68158 .51989 .67657 .51405 Mtetra
.67657 .51405 .68158 .51989 .6921 .51673 .68711 .51087 Mtetra
.68711 .51087 .6921 .51673 .70265 .51356 .6977 .50768 Mtetra
.6977 .50768 .70265 .51356 .71324 .51038 .70832 .50448 Mtetra
.70832 .50448 .71324 .51038 .72388 .50719 .71898 .50127 Mtetra
.71898 .50127 .72388 .50719 .73455 .50399 .72968 .49804 Mtetra
.72968 .49804 .73455 .50399 .74527 .50077 .74042 .4948 Mtetra
.74042 .4948 .74527 .50077 .75602 .49754 .7512 .49155 Mtetra
.7512 .49155 .75602 .49754 .76681 .4943 .76203 .48829 Mtetra
.76203 .48829 .76681 .4943 .77765 .49105 .77289 .48501 Mtetra
.77289 .48501 .77765 .49105 .78852 .48779 .7838 .48173 Mtetra
.7838 .48173 .78852 .48779 .79944 .48451 .79474 .47843 Mtetra
.79474 .47843 .79944 .48451 .8104 .48122 .80573 .47511 Mtetra
.80573 .47511 .8104 .48122 .8214 .47792 .81676 .47179 Mtetra
.81676 .47179 .8214 .47792 .83244 .4746 .82783 .46845 Mtetra
.82783 .46845 .83244 .4746 .84353 .47128 .83895 .4651 Mtetra
.83895 .4651 .84353 .47128 .85465 .46794 .85011 .46174 Mtetra
.85011 .46174 .85465 .46794 .86582 .46458 .86131 .45836 Mtetra
.86131 .45836 .86582 .46458 .87704 .46122 .87255 .45497 Mtetra
.87255 .45497 .87704 .46122 .88829 .45784 .88384 .45157 Mtetra
.88384 .45157 .88829 .45784 .89959 .45445 .89517 .44815 Mtetra
.89517 .44815 .89959 .45445 .91093 .45104 .90654 .44472 Mtetra
.90654 .44472 .91093 .45104 .92232 .44763 .91796 .44128 Mtetra
.30643 .61871 .31232 .62385 .32155 .62107 .31568 .61591 Mtetra
.31568 .61591 .32155 .62107 .33081 .61828 .32495 .6131 Mtetra
.32495 .6131 .33081 .61828 .3401 .61548 .33427 .61028 Mtetra
.33427 .61028 .3401 .61548 .34942 .61267 .34361 .60746 Mtetra
.34361 .60746 .34942 .61267 .35878 .60985 .35299 .60462 Mtetra
.35299 .60462 .35878 .60985 .36817 .60702 .36239 .60177 Mtetra
.36239 .60177 .36817 .60702 .37759 .60418 .37184 .59891 Mtetra
.37184 .59891 .37759 .60418 .38704 .60133 .38131 .59604 Mtetra
.38131 .59604 .38704 .60133 .39653 .59847 .39082 .59316 Mtetra
.39082 .59316 .39653 .59847 .40606 .5956 .40037 .59027 Mtetra
.40037 .59027 .40606 .5956 .41561 .59272 .40995 .58737 Mtetra
.40995 .58737 .41561 .59272 .4252 .58983 .41956 .58446 Mtetra
.41956 .58446 .4252 .58983 .43483 .58692 .4292 .58154 Mtetra
.4292 .58154 .43483 .58692 .44449 .58401 .43888 .57861 Mtetra
.43888 .57861 .44449 .58401 .45418 .58109 .4486 .57567 Mtetra
.4486 .57567 .45418 .58109 .46391 .57816 .45835 .57272 Mtetra
.45835 .57272 .46391 .57816 .47367 .57521 .46814 .56975 Mtetra
.46814 .56975 .47367 .57521 .48347 .57226 .47796 .56678 Mtetra
.47796 .56678 .48347 .57226 .4933 .5693 .48781 .5638 Mtetra
.48781 .5638 .4933 .5693 .50317 .56632 .49771 .5608 Mtetra
.49771 .5608 .50317 .56632 .51308 .56334 .50763 .55779 Mtetra
.50763 .55779 .51308 .56334 .52302 .56034 .5176 .55478 Mtetra
.5176 .55478 .52302 .56034 .533 .55733 .5276 .55175 Mtetra
.5276 .55175 .533 .55733 .54301 .55431 .53764 .54871 Mtetra
.53764 .54871 .54301 .55431 .55306 .55128 .54771 .54566 Mtetra
.54771 .54566 .55306 .55128 .56314 .54824 .55782 .5426 Mtetra
.55782 .5426 .56314 .54824 .57327 .54519 .56797 .53953 Mtetra
.56797 .53953 .57327 .54519 .58343 .54213 .57815 .53644 Mtetra
.57815 .53644 .58343 .54213 .59363 .53905 .58837 .53335 Mtetra
.58837 .53335 .59363 .53905 .60386 .53597 .59864 .53024 Mtetra
.59864 .53024 .60386 .53597 .61413 .53287 .60893 .52712 Mtetra
.60893 .52712 .61413 .53287 .62444 .52976 .61927 .524 Mtetra
.61927 .524 .62444 .52976 .63479 .52664 .62964 .52085 Mtetra
.62964 .52085 .63479 .52664 .64518 .52351 .64006 .5177 Mtetra
.64006 .5177 .64518 .52351 .6556 .52037 .65051 .51454 Mtetra
.65051 .51454 .6556 .52037 .66607 .51722 .661 .51136 Mtetra
.661 .51136 .66607 .51722 .67657 .51405 .67153 .50817 Mtetra
.67153 .50817 .67657 .51405 .68711 .51087 .6821 .50497 Mtetra
.6821 .50497 .68711 .51087 .6977 .50768 .69271 .50176 Mtetra
.69271 .50176 .6977 .50768 .70832 .50448 .70336 .49854 Mtetra
.70336 .49854 .70832 .50448 .71898 .50127 .71405 .4953 Mtetra
.71405 .4953 .71898 .50127 .72968 .49804 .72477 .49205 Mtetra
.72477 .49205 .72968 .49804 .74042 .4948 .73554 .48879 Mtetra
.73554 .48879 .74042 .4948 .7512 .49155 .74636 .48552 Mtetra
.74636 .48552 .7512 .49155 .76203 .48829 .75721 .48223 Mtetra
.75721 .48223 .76203 .48829 .77289 .48501 .7681 .47893 Mtetra
.7681 .47893 .77289 .48501 .7838 .48173 .77903 .47562 Mtetra
.77903 .47562 .7838 .48173 .79474 .47843 .79001 .4723 Mtetra
.79001 .4723 .79474 .47843 .80573 .47511 .80103 .46897 Mtetra
.80103 .46897 .80573 .47511 .81676 .47179 .81209 .46562 Mtetra
.81209 .46562 .81676 .47179 .82783 .46845 .82319 .46226 Mtetra
.82319 .46226 .82783 .46845 .83895 .4651 .83434 .45888 Mtetra
.83434 .45888 .83895 .4651 .85011 .46174 .84552 .45549 Mtetra
.84552 .45549 .85011 .46174 .86131 .45836 .85676 .45209 Mtetra
.85676 .45209 .86131 .45836 .87255 .45497 .86803 .44868 Mtetra
.86803 .44868 .87255 .45497 .88384 .45157 .87935 .44525 Mtetra
.87935 .44525 .88384 .45157 .89517 .44815 .89071 .44181 Mtetra
.89071 .44181 .89517 .44815 .90654 .44472 .90212 .43836 Mtetra
.90212 .43836 .90654 .44472 .91796 .44128 .91357 .43489 Mtetra
.3005 .61354 .30643 .61871 .31568 .61591 .30977 .61072 Mtetra
.30977 .61072 .31568 .61591 .32495 .6131 .31906 .60789 Mtetra
.31906 .60789 .32495 .6131 .33427 .61028 .32839 .60505 Mtetra
.32839 .60505 .33427 .61028 .34361 .60746 .33776 .60221 Mtetra
.33776 .60221 .34361 .60746 .35299 .60462 .34715 .59935 Mtetra
.34715 .59935 .35299 .60462 .36239 .60177 .35658 .59648 Mtetra
.35658 .59648 .36239 .60177 .37184 .59891 .36605 .5936 Mtetra
.36605 .5936 .37184 .59891 .38131 .59604 .37555 .59072 Mtetra
.37555 .59072 .38131 .59604 .39082 .59316 .38508 .58782 Mtetra
.38508 .58782 .39082 .59316 .40037 .59027 .39464 .58491 Mtetra
.39464 .58491 .40037 .59027 .40995 .58737 .40424 .58199 Mtetra
.40424 .58199 .40995 .58737 .41956 .58446 .41387 .57906 Mtetra
.41387 .57906 .41956 .58446 .4292 .58154 .42354 .57612 Mtetra
.42354 .57612 .4292 .58154 .43888 .57861 .43324 .57317 Mtetra
.43324 .57317 .43888 .57861 .4486 .57567 .44298 .57021 Mtetra
.44298 .57021 .4486 .57567 .45835 .57272 .45276 .56724 Mtetra
.45276 .56724 .45835 .57272 .46814 .56975 .46256 .56426 Mtetra
.46256 .56426 .46814 .56975 .47796 .56678 .47241 .56126 Mtetra
.47241 .56126 .47796 .56678 .48781 .5638 .48229 .55826 Mtetra
.48229 .55826 .48781 .5638 .49771 .5608 .4922 .55524 Mtetra
.4922 .55524 .49771 .5608 .50763 .55779 .50215 .55222 Mtetra
.50215 .55222 .50763 .55779 .5176 .55478 .51214 .54918 Mtetra
.51214 .54918 .5176 .55478 .5276 .55175 .52217 .54613 Mtetra
.52217 .54613 .5276 .55175 .53764 .54871 .53223 .54307 Mtetra
.53223 .54307 .53764 .54871 .54771 .54566 .54232 .54 Mtetra
.54232 .54 .54771 .54566 .55782 .5426 .55246 .53692 Mtetra
.55246 .53692 .55782 .5426 .56797 .53953 .56263 .53383 Mtetra
.56263 .53383 .56797 .53953 .57815 .53644 .57284 .53072 Mtetra
.57284 .53072 .57815 .53644 .58837 .53335 .58309 .52761 Mtetra
.58309 .52761 .58837 .53335 .59864 .53024 .59337 .52448 Mtetra
.59337 .52448 .59864 .53024 .60893 .52712 .6037 .52134 Mtetra
.6037 .52134 .60893 .52712 .61927 .524 .61406 .51819 Mtetra
.61406 .51819 .61927 .524 .62964 .52085 .62446 .51503 Mtetra
.62446 .51503 .62964 .52085 .64006 .5177 .6349 .51185 Mtetra
.6349 .51185 .64006 .5177 .65051 .51454 .64538 .50866 Mtetra
.64538 .50866 .65051 .51454 .661 .51136 .65589 .50547 Mtetra
.65589 .50547 .661 .51136 .67153 .50817 .66645 .50226 Mtetra
.66645 .50226 .67153 .50817 .6821 .50497 .67705 .49903 Mtetra
.67705 .49903 .6821 .50497 .69271 .50176 .68768 .4958 Mtetra
.68768 .4958 .69271 .50176 .70336 .49854 .69836 .49255 Mtetra
.69836 .49255 .70336 .49854 .71405 .4953 .70908 .48929 Mtetra
.70908 .48929 .71405 .4953 .72477 .49205 .71984 .48602 Mtetra
.71984 .48602 .72477 .49205 .73554 .48879 .73063 .48274 Mtetra
.73063 .48274 .73554 .48879 .74636 .48552 .74147 .47944 Mtetra
.74147 .47944 .74636 .48552 .75721 .48223 .75235 .47613 Mtetra
.75235 .47613 .75721 .48223 .7681 .47893 .76328 .47281 Mtetra
.76328 .47281 .7681 .47893 .77903 .47562 .77424 .46948 Mtetra
.77424 .46948 .77903 .47562 .79001 .4723 .78524 .46613 Mtetra
.78524 .46613 .79001 .4723 .80103 .46897 .79629 .46277 Mtetra
.79629 .46277 .80103 .46897 .81209 .46562 .80738 .4594 Mtetra
.80738 .4594 .81209 .46562 .82319 .46226 .81852 .45602 Mtetra
.81852 .45602 .82319 .46226 .83434 .45888 .82969 .45262 Mtetra
.82969 .45262 .83434 .45888 .84552 .45549 .84091 .44921 Mtetra
.84091 .44921 .84552 .45549 .85676 .45209 .85217 .44578 Mtetra
.85217 .44578 .85676 .45209 .86803 .44868 .86348 .44234 Mtetra
.86348 .44234 .86803 .44868 .87935 .44525 .87483 .43889 Mtetra
.87483 .43889 .87935 .44525 .89071 .44181 .88623 .43543 Mtetra
.88623 .43543 .89071 .44181 .90212 .43836 .89766 .43195 Mtetra
.89766 .43195 .90212 .43836 .91357 .43489 .90915 .42846 Mtetra
.29453 .60833 .3005 .61354 .30977 .61072 .30382 .60549 Mtetra
.30382 .60549 .30977 .61072 .31906 .60789 .31314 .60265 Mtetra
.31314 .60265 .31906 .60789 .32839 .60505 .32249 .59979 Mtetra
.32249 .59979 .32839 .60505 .33776 .60221 .33187 .59692 Mtetra
.33187 .59692 .33776 .60221 .34715 .59935 .34129 .59405 Mtetra
.34129 .59405 .34715 .59935 .35658 .59648 .35074 .59116 Mtetra
.35074 .59116 .35658 .59648 .36605 .5936 .36022 .58826 Mtetra
.36022 .58826 .36605 .5936 .37555 .59072 .36974 .58536 Mtetra
.36974 .58536 .37555 .59072 .38508 .58782 .37929 .58244 Mtetra
.37929 .58244 .38508 .58782 .39464 .58491 .38888 .57951 Mtetra
.38888 .57951 .39464 .58491 .40424 .58199 .3985 .57657 Mtetra
.3985 .57657 .40424 .58199 .41387 .57906 .40815 .57363 Mtetra
.40815 .57363 .41387 .57906 .42354 .57612 .41784 .57067 Mtetra
.41784 .57067 .42354 .57612 .43324 .57317 .42757 .5677 Mtetra
.42757 .5677 .43324 .57317 .44298 .57021 .43733 .56471 Mtetra
.43733 .56471 .44298 .57021 .45276 .56724 .44712 .56172 Mtetra
.44712 .56172 .45276 .56724 .46256 .56426 .45695 .55872 Mtetra
.45695 .55872 .46256 .56426 .47241 .56126 .46682 .55571 Mtetra
.46682 .55571 .47241 .56126 .48229 .55826 .47672 .55268 Mtetra
.47672 .55268 .48229 .55826 .4922 .55524 .48666 .54965 Mtetra
.48666 .54965 .4922 .55524 .50215 .55222 .49664 .5466 Mtetra
.49664 .5466 .50215 .55222 .51214 .54918 .50665 .54354 Mtetra
.50665 .54354 .51214 .54918 .52217 .54613 .5167 .54047 Mtetra
.5167 .54047 .52217 .54613 .53223 .54307 .52678 .53739 Mtetra
.52678 .53739 .53223 .54307 .54232 .54 .5369 .5343 Mtetra
.5369 .5343 .54232 .54 .55246 .53692 .54706 .5312 Mtetra
.54706 .5312 .55246 .53692 .56263 .53383 .55726 .52809 Mtetra
.55726 .52809 .56263 .53383 .57284 .53072 .56749 .52496 Mtetra
.56749 .52496 .57284 .53072 .58309 .52761 .57777 .52182 Mtetra
.57777 .52182 .58309 .52761 .59337 .52448 .58808 .51867 Mtetra
.58808 .51867 .59337 .52448 .6037 .52134 .59843 .51551 Mtetra
.59843 .51551 .6037 .52134 .61406 .51819 .60881 .51234 Mtetra
.60881 .51234 .61406 .51819 .62446 .51503 .61924 .50916 Mtetra
.61924 .50916 .62446 .51503 .6349 .51185 .62971 .50596 Mtetra
.62971 .50596 .6349 .51185 .64538 .50866 .64021 .50275 Mtetra
.64021 .50275 .64538 .50866 .65589 .50547 .65075 .49953 Mtetra
.65075 .49953 .65589 .50547 .66645 .50226 .66134 .4963 Mtetra
.66134 .4963 .66645 .50226 .67705 .49903 .67196 .49305 Mtetra
.67196 .49305 .67705 .49903 .68768 .4958 .68263 .4898 Mtetra
.68263 .4898 .68768 .4958 .69836 .49255 .69333 .48653 Mtetra
.69333 .48653 .69836 .49255 .70908 .48929 .70408 .48325 Mtetra
.70408 .48325 .70908 .48929 .71984 .48602 .71486 .47995 Mtetra
.71486 .47995 .71984 .48602 .73063 .48274 .72569 .47664 Mtetra
.72569 .47664 .73063 .48274 .74147 .47944 .73656 .47333 Mtetra
.73656 .47333 .74147 .47944 .75235 .47613 .74746 .46999 Mtetra
.74746 .46999 .75235 .47613 .76328 .47281 .75842 .46665 Mtetra
.75842 .46665 .76328 .47281 .77424 .46948 .76941 .46329 Mtetra
.76941 .46329 .77424 .46948 .78524 .46613 .78044 .45992 Mtetra
.78044 .45992 .78524 .46613 .79629 .46277 .79152 .45654 Mtetra
.79152 .45654 .79629 .46277 .80738 .4594 .80264 .45314 Mtetra
.80264 .45314 .80738 .4594 .81852 .45602 .81381 .44973 Mtetra
.81381 .44973 .81852 .45602 .82969 .45262 .82501 .44631 Mtetra
.82501 .44631 .82969 .45262 .84091 .44921 .83626 .44287 Mtetra
.83626 .44287 .84091 .44921 .85217 .44578 .84756 .43942 Mtetra
.84756 .43942 .85217 .44578 .86348 .44234 .8589 .43596 Mtetra
.8589 .43596 .86348 .44234 .87483 .43889 .87028 .43248 Mtetra
.87028 .43248 .87483 .43889 .88623 .43543 .88171 .42899 Mtetra
.88171 .42899 .88623 .43543 .89766 .43195 .89318 .42549 Mtetra
.89318 .42549 .89766 .43195 .90915 .42846 .90469 .42197 Mtetra
.28853 .60308 .29453 .60833 .30382 .60549 .29783 .60023 Mtetra
.29783 .60023 .30382 .60549 .31314 .60265 .30717 .59737 Mtetra
.30717 .59737 .31314 .60265 .32249 .59979 .31654 .59449 Mtetra
.31654 .59449 .32249 .59979 .33187 .59692 .32594 .59161 Mtetra
.32594 .59161 .33187 .59692 .34129 .59405 .33538 .58871 Mtetra
.33538 .58871 .34129 .59405 .35074 .59116 .34485 .58581 Mtetra
.34485 .58581 .35074 .59116 .36022 .58826 .35435 .58289 Mtetra
.35435 .58289 .36022 .58826 .36974 .58536 .36389 .57996 Mtetra
.36389 .57996 .36974 .58536 .37929 .58244 .37347 .57703 Mtetra
.37347 .57703 .37929 .58244 .38888 .57951 .38307 .57408 Mtetra
.38307 .57408 .38888 .57951 .3985 .57657 .39272 .57112 Mtetra
.39272 .57112 .3985 .57657 .40815 .57363 .40239 .56815 Mtetra
.40239 .56815 .40815 .57363 .41784 .57067 .41211 .56517 Mtetra
.41211 .56517 .41784 .57067 .42757 .5677 .42185 .56218 Mtetra
.42185 .56218 .42757 .5677 .43733 .56471 .43163 .55918 Mtetra
.43163 .55918 .43733 .56471 .44712 .56172 .44145 .55617 Mtetra
.44145 .55617 .44712 .56172 .45695 .55872 .45131 .55315 Mtetra
.45131 .55315 .45695 .55872 .46682 .55571 .4612 .55012 Mtetra
.4612 .55012 .46682 .55571 .47672 .55268 .47112 .54707 Mtetra
.47112 .54707 .47672 .55268 .48666 .54965 .48108 .54401 Mtetra
.48108 .54401 .48666 .54965 .49664 .5466 .49108 .54095 Mtetra
.49108 .54095 .49664 .5466 .50665 .54354 .50112 .53787 Mtetra
.50112 .53787 .50665 .54354 .5167 .54047 .51119 .53478 Mtetra
.51119 .53478 .5167 .54047 .52678 .53739 .5213 .53168 Mtetra
.5213 .53168 .52678 .53739 .5369 .5343 .53144 .52857 Mtetra
.53144 .52857 .5369 .5343 .54706 .5312 .54163 .52544 Mtetra
.54163 .52544 .54706 .5312 .55726 .52809 .55185 .52231 Mtetra
.55185 .52231 .55726 .52809 .56749 .52496 .56211 .51916 Mtetra
.56211 .51916 .56749 .52496 .57777 .52182 .57241 .516 Mtetra
.57241 .516 .57777 .52182 .58808 .51867 .58274 .51283 Mtetra
.58274 .51283 .58808 .51867 .59843 .51551 .59312 .50965 Mtetra
.59312 .50965 .59843 .51551 .60881 .51234 .60353 .50645 Mtetra
.60353 .50645 .60881 .51234 .61924 .50916 .61398 .50324 Mtetra
.61398 .50324 .61924 .50916 .62971 .50596 .62448 .50003 Mtetra
.62448 .50003 .62971 .50596 .64021 .50275 .63501 .4968 Mtetra
.63501 .4968 .64021 .50275 .65075 .49953 .64558 .49355 Mtetra
.64558 .49355 .65075 .49953 .66134 .4963 .65619 .4903 Mtetra
.65619 .4903 .66134 .4963 .67196 .49305 .66684 .48703 Mtetra
.66684 .48703 .67196 .49305 .68263 .4898 .67753 .48375 Mtetra
.67753 .48375 .68263 .4898 .69333 .48653 .68826 .48046 Mtetra
.68826 .48046 .69333 .48653 .70408 .48325 .69904 .47715 Mtetra
.69904 .47715 .70408 .48325 .71486 .47995 .70985 .47384 Mtetra
.70985 .47384 .71486 .47995 .72569 .47664 .72071 .47051 Mtetra
.72071 .47051 .72569 .47664 .73656 .47333 .7316 .46716 Mtetra
.7316 .46716 .73656 .47333 .74746 .46999 .74254 .46381 Mtetra
.74254 .46381 .74746 .46999 .75842 .46665 .75352 .46044 Mtetra
.75352 .46044 .75842 .46665 .76941 .46329 .76455 .45706 Mtetra
.76455 .45706 .76941 .46329 .78044 .45992 .77561 .45366 Mtetra
.77561 .45366 .78044 .45992 .79152 .45654 .78672 .45026 Mtetra
.78672 .45026 .79152 .45654 .80264 .45314 .79787 .44684 Mtetra
.79787 .44684 .80264 .45314 .81381 .44973 .80906 .4434 Mtetra
.80906 .4434 .81381 .44973 .82501 .44631 .8203 .43995 Mtetra
.8203 .43995 .82501 .44631 .83626 .44287 .83158 .43649 Mtetra
.83158 .43649 .83626 .44287 .84756 .43942 .84291 .43302 Mtetra
.84291 .43302 .84756 .43942 .8589 .43596 .85428 .42953 Mtetra
.85428 .42953 .8589 .43596 .87028 .43248 .86569 .42603 Mtetra
.86569 .42603 .87028 .43248 .88171 .42899 .87715 .42251 Mtetra
.87715 .42251 .88171 .42899 .89318 .42549 .88866 .41899 Mtetra
.88866 .41899 .89318 .42549 .90469 .42197 .90021 .41544 Mtetra
.28248 .59781 .28853 .60308 .29783 .60023 .2918 .59493 Mtetra
.2918 .59493 .29783 .60023 .30717 .59737 .30116 .59205 Mtetra
.30116 .59205 .30717 .59737 .31654 .59449 .31055 .58916 Mtetra
.31055 .58916 .31654 .59449 .32594 .59161 .31998 .58625 Mtetra
.31998 .58625 .32594 .59161 .33538 .58871 .32943 .58334 Mtetra
.32943 .58334 .33538 .58871 .34485 .58581 .33892 .58041 Mtetra
.33892 .58041 .34485 .58581 .35435 .58289 .34845 .57748 Mtetra
.34845 .57748 .35435 .58289 .36389 .57996 .35801 .57453 Mtetra
.35801 .57453 .36389 .57996 .37347 .57703 .3676 .57158 Mtetra
.3676 .57158 .37347 .57703 .38307 .57408 .37723 .56861 Mtetra
.37723 .56861 .38307 .57408 .39272 .57112 .3869 .56563 Mtetra
.3869 .56563 .39272 .57112 .40239 .56815 .3966 .56264 Mtetra
.3966 .56264 .40239 .56815 .41211 .56517 .40633 .55965 Mtetra
.40633 .55965 .41211 .56517 .42185 .56218 .4161 .55664 Mtetra
.4161 .55664 .42185 .56218 .43163 .55918 .4259 .55361 Mtetra
.4259 .55361 .43163 .55918 .44145 .55617 .43574 .55058 Mtetra
.43574 .55058 .44145 .55617 .45131 .55315 .44562 .54754 Mtetra
.44562 .54754 .45131 .55315 .4612 .55012 .45553 .54449 Mtetra
.45553 .54449 .4612 .55012 .47112 .54707 .46548 .54142 Mtetra
.46548 .54142 .47112 .54707 .48108 .54401 .47547 .53834 Mtetra
.47547 .53834 .48108 .54401 .49108 .54095 .48549 .53526 Mtetra
.48549 .53526 .49108 .54095 .50112 .53787 .49555 .53216 Mtetra
.49555 .53216 .50112 .53787 .51119 .53478 .50564 .52905 Mtetra
.50564 .52905 .51119 .53478 .5213 .53168 .51578 .52592 Mtetra
.51578 .52592 .5213 .53168 .53144 .52857 .52595 .52279 Mtetra
.52595 .52279 .53144 .52857 .54163 .52544 .53616 .51964 Mtetra
.53616 .51964 .54163 .52544 .55185 .52231 .5464 .51649 Mtetra
.5464 .51649 .55185 .52231 .56211 .51916 .55669 .51332 Mtetra
.55669 .51332 .56211 .51916 .57241 .516 .56701 .51014 Mtetra
.56701 .51014 .57241 .516 .58274 .51283 .57737 .50694 Mtetra
.57737 .50694 .58274 .51283 .59312 .50965 .58777 .50374 Mtetra
.58777 .50374 .59312 .50965 .60353 .50645 .59821 .50052 Mtetra
.59821 .50052 .60353 .50645 .61398 .50324 .60869 .49729 Mtetra
.60869 .49729 .61398 .50324 .62448 .50003 .61921 .49405 Mtetra
.61921 .49405 .62448 .50003 .63501 .4968 .62977 .4908 Mtetra
.62977 .4908 .63501 .4968 .64558 .49355 .64037 .48753 Mtetra
.64037 .48753 .64558 .49355 .65619 .4903 .65101 .48426 Mtetra
.65101 .48426 .65619 .4903 .66684 .48703 .66168 .48097 Mtetra
.66168 .48097 .66684 .48703 .67753 .48375 .6724 .47766 Mtetra
.6724 .47766 .67753 .48375 .68826 .48046 .68316 .47435 Mtetra
.68316 .47435 .68826 .48046 .69904 .47715 .69396 .47102 Mtetra
.69396 .47102 .69904 .47715 .70985 .47384 .70481 .46768 Mtetra
.70481 .46768 .70985 .47384 .72071 .47051 .71569 .46433 Mtetra
.71569 .46433 .72071 .47051 .7316 .46716 .72662 .46096 Mtetra
.72662 .46096 .7316 .46716 .74254 .46381 .73758 .45758 Mtetra
.73758 .45758 .74254 .46381 .75352 .46044 .74859 .45419 Mtetra
.74859 .45419 .75352 .46044 .76455 .45706 .75965 .45078 Mtetra
.75965 .45078 .76455 .45706 .77561 .45366 .77074 .44736 Mtetra
.77074 .44736 .77561 .45366 .78672 .45026 .78188 .44393 Mtetra
.78188 .44393 .78672 .45026 .79787 .44684 .79306 .44049 Mtetra
.79306 .44049 .79787 .44684 .80906 .4434 .80429 .43703 Mtetra
.80429 .43703 .80906 .4434 .8203 .43995 .81556 .43355 Mtetra
.81556 .43355 .8203 .43995 .83158 .43649 .82687 .43007 Mtetra
.82687 .43007 .83158 .43649 .84291 .43302 .83823 .42657 Mtetra
.83823 .42657 .84291 .43302 .85428 .42953 .84963 .42306 Mtetra
.84963 .42306 .85428 .42953 .86569 .42603 .86108 .41953 Mtetra
.86108 .41953 .86569 .42603 .87715 .42251 .87257 .41599 Mtetra
.87257 .41599 .87715 .42251 .88866 .41899 .8841 .41243 Mtetra
.8841 .41243 .88866 .41899 .90021 .41544 .89569 .40886 Mtetra
.27639 .59249 .28248 .59781 .2918 .59493 .28574 .5896 Mtetra
.28574 .5896 .2918 .59493 .30116 .59205 .29511 .5867 Mtetra
.29511 .5867 .30116 .59205 .31055 .58916 .30452 .58379 Mtetra
.30452 .58379 .31055 .58916 .31998 .58625 .31397 .58087 Mtetra
.31397 .58087 .31998 .58625 .32943 .58334 .32345 .57793 Mtetra
.32345 .57793 .32943 .58334 .33892 .58041 .33296 .57499 Mtetra
.33296 .57499 .33892 .58041 .34845 .57748 .34251 .57203 Mtetra
.34251 .57203 .34845 .57748 .35801 .57453 .35209 .56907 Mtetra
.35209 .56907 .35801 .57453 .3676 .57158 .3617 .56609 Mtetra
.3617 .56609 .3676 .57158 .37723 .56861 .37135 .56311 Mtetra
.37135 .56311 .37723 .56861 .3869 .56563 .38104 .56011 Mtetra
.38104 .56011 .3869 .56563 .3966 .56264 .39076 .5571 Mtetra
.39076 .5571 .3966 .56264 .40633 .55965 .40052 .55408 Mtetra
.40052 .55408 .40633 .55965 .4161 .55664 .41031 .55105 Mtetra
.41031 .55105 .4161 .55664 .4259 .55361 .42013 .54801 Mtetra
.42013 .54801 .4259 .55361 .43574 .55058 .43 .54496 Mtetra
.43 .54496 .43574 .55058 .44562 .54754 .4399 .54189 Mtetra
.4399 .54189 .44562 .54754 .45553 .54449 .44983 .53882 Mtetra
.44983 .53882 .45553 .54449 .46548 .54142 .4598 .53573 Mtetra
.4598 .53573 .46548 .54142 .47547 .53834 .46981 .53263 Mtetra
.46981 .53263 .47547 .53834 .48549 .53526 .47986 .52952 Mtetra
.47986 .52952 .48549 .53526 .49555 .53216 .48994 .5264 Mtetra
.48994 .5264 .49555 .53216 .50564 .52905 .50006 .52327 Mtetra
.50006 .52327 .50564 .52905 .51578 .52592 .51022 .52013 Mtetra
.51022 .52013 .51578 .52592 .52595 .52279 .52041 .51697 Mtetra
.52041 .51697 .52595 .52279 .53616 .51964 .53065 .51381 Mtetra
.53065 .51381 .53616 .51964 .5464 .51649 .54092 .51063 Mtetra
.54092 .51063 .5464 .51649 .55669 .51332 .55123 .50744 Mtetra
.55123 .50744 .55669 .51332 .56701 .51014 .56158 .50423 Mtetra
.56158 .50423 .56701 .51014 .57737 .50694 .57197 .50102 Mtetra
.57197 .50102 .57737 .50694 .58777 .50374 .58239 .49779 Mtetra
.58239 .49779 .58777 .50374 .59821 .50052 .59286 .49455 Mtetra
.59286 .49455 .59821 .50052 .60869 .49729 .60336 .4913 Mtetra
.60336 .4913 .60869 .49729 .61921 .49405 .61391 .48804 Mtetra
.61391 .48804 .61921 .49405 .62977 .4908 .62449 .48476 Mtetra
.62449 .48476 .62977 .4908 .64037 .48753 .63512 .48147 Mtetra
.63512 .48147 .64037 .48753 .65101 .48426 .64578 .47817 Mtetra
.64578 .47817 .65101 .48426 .66168 .48097 .65649 .47486 Mtetra
.65649 .47486 .66168 .48097 .6724 .47766 .66724 .47153 Mtetra
.66724 .47153 .6724 .47766 .68316 .47435 .67803 .46819 Mtetra
.67803 .46819 .68316 .47435 .69396 .47102 .68886 .46484 Mtetra
.68886 .46484 .69396 .47102 .70481 .46768 .69973 .46148 Mtetra
.69973 .46148 .70481 .46768 .71569 .46433 .71064 .4581 Mtetra
.71064 .4581 .71569 .46433 .72662 .46096 .72159 .45471 Mtetra
.72159 .45471 .72662 .46096 .73758 .45758 .73259 .45131 Mtetra
.73259 .45131 .73758 .45758 .74859 .45419 .74363 .44789 Mtetra
.74363 .44789 .74859 .45419 .75965 .45078 .75471 .44446 Mtetra
.75471 .44446 .75965 .45078 .77074 .44736 .76584 .44102 Mtetra
.76584 .44102 .77074 .44736 .78188 .44393 .77701 .43756 Mtetra
.77701 .43756 .78188 .44393 .79306 .44049 .78822 .43409 Mtetra
.78822 .43409 .79306 .44049 .80429 .43703 .79948 .43061 Mtetra
.79948 .43061 .80429 .43703 .81556 .43355 .81078 .42711 Mtetra
.81078 .42711 .81556 .43355 .82687 .43007 .82212 .4236 Mtetra
.82212 .4236 .82687 .43007 .83823 .42657 .83351 .42007 Mtetra
.83351 .42007 .83823 .42657 .84963 .42306 .84494 .41653 Mtetra
.84494 .41653 .84963 .42306 .86108 .41953 .85642 .41298 Mtetra
.85642 .41298 .86108 .41953 .87257 .41599 .86795 .40941 Mtetra
.86795 .40941 .87257 .41599 .8841 .41243 .87952 .40583 Mtetra
.87952 .40583 .8841 .41243 .89569 .40886 .89113 .40224 Mtetra
.27027 .58715 .27639 .59249 .28574 .5896 .27963 .58424 Mtetra
.27963 .58424 .28574 .5896 .29511 .5867 .28903 .58132 Mtetra
.28903 .58132 .29511 .5867 .30452 .58379 .29846 .57838 Mtetra
.29846 .57838 .30452 .58379 .31397 .58087 .30792 .57544 Mtetra
.30792 .57544 .31397 .58087 .32345 .57793 .31742 .57249 Mtetra
.31742 .57249 .32345 .57793 .33296 .57499 .32696 .56952 Mtetra
.32696 .56952 .33296 .57499 .34251 .57203 .33652 .56655 Mtetra
.33652 .56655 .34251 .57203 .35209 .56907 .34613 .56357 Mtetra
.34613 .56357 .35209 .56907 .3617 .56609 .35576 .56057 Mtetra
.35576 .56057 .3617 .56609 .37135 .56311 .36543 .55756 Mtetra
.36543 .55756 .37135 .56311 .38104 .56011 .37514 .55455 Mtetra
.37514 .55455 .38104 .56011 .39076 .5571 .38488 .55152 Mtetra
.38488 .55152 .39076 .5571 .40052 .55408 .39466 .54848 Mtetra
.39466 .54848 .40052 .55408 .41031 .55105 .40448 .54543 Mtetra
.40448 .54543 .41031 .55105 .42013 .54801 .41432 .54236 Mtetra
.41432 .54236 .42013 .54801 .43 .54496 .42421 .53929 Mtetra
.42421 .53929 .43 .54496 .4399 .54189 .43413 .53621 Mtetra
.43413 .53621 .4399 .54189 .44983 .53882 .44409 .53311 Mtetra
.44409 .53311 .44983 .53882 .4598 .53573 .45409 .53 Mtetra
.45409 .53 .4598 .53573 .46981 .53263 .46412 .52688 Mtetra
.46412 .52688 .46981 .53263 .47986 .52952 .47419 .52375 Mtetra
.47419 .52375 .47986 .52952 .48994 .5264 .4843 .52061 Mtetra
.4843 .52061 .48994 .5264 .50006 .52327 .49444 .51746 Mtetra
.49444 .51746 .50006 .52327 .51022 .52013 .50462 .51429 Mtetra
.50462 .51429 .51022 .52013 .52041 .51697 .51484 .51112 Mtetra
.51484 .51112 .52041 .51697 .53065 .51381 .5251 .50793 Mtetra
.5251 .50793 .53065 .51381 .54092 .51063 .5354 .50473 Mtetra
.5354 .50473 .54092 .51063 .55123 .50744 .54573 .50151 Mtetra
.54573 .50151 .55123 .50744 .56158 .50423 .55611 .49829 Mtetra
.55611 .49829 .56158 .50423 .57197 .50102 .56652 .49505 Mtetra
.56652 .49505 .57197 .50102 .58239 .49779 .57697 .4918 Mtetra
.57697 .4918 .58239 .49779 .59286 .49455 .58747 .48854 Mtetra
.58747 .48854 .59286 .49455 .60336 .4913 .598 .48527 Mtetra
.598 .48527 .60336 .4913 .61391 .48804 .60857 .48198 Mtetra
.60857 .48198 .61391 .48804 .62449 .48476 .61918 .47868 Mtetra
.61918 .47868 .62449 .48476 .63512 .48147 .62983 .47537 Mtetra
.62983 .47537 .63512 .48147 .64578 .47817 .64053 .47205 Mtetra
.64053 .47205 .64578 .47817 .65649 .47486 .65126 .46871 Mtetra
.65126 .46871 .65649 .47486 .66724 .47153 .66204 .46536 Mtetra
.66204 .46536 .66724 .47153 .67803 .46819 .67285 .462 Mtetra
.67285 .462 .67803 .46819 .68886 .46484 .68371 .45862 Mtetra
.68371 .45862 .68886 .46484 .69973 .46148 .69461 .45523 Mtetra
.69461 .45523 .69973 .46148 .71064 .4581 .70555 .45183 Mtetra
.70555 .45183 .71064 .4581 .72159 .45471 .71654 .44842 Mtetra
.71654 .44842 .72159 .45471 .73259 .45131 .72756 .44499 Mtetra
.72756 .44499 .73259 .45131 .74363 .44789 .73863 .44155 Mtetra
.73863 .44155 .74363 .44789 .75471 .44446 .74974 .43809 Mtetra
.74974 .43809 .75471 .44446 .76584 .44102 .7609 .43462 Mtetra
.7609 .43462 .76584 .44102 .77701 .43756 .7721 .43114 Mtetra
.7721 .43114 .77701 .43756 .78822 .43409 .78334 .42765 Mtetra
.78334 .42765 .78822 .43409 .79948 .43061 .79463 .42414 Mtetra
.79463 .42414 .79948 .43061 .81078 .42711 .80596 .42062 Mtetra
.80596 .42062 .81078 .42711 .82212 .4236 .81734 .41708 Mtetra
.81734 .41708 .82212 .4236 .83351 .42007 .82876 .41353 Mtetra
.82876 .41353 .83351 .42007 .84494 .41653 .84023 .40996 Mtetra
.84023 .40996 .84494 .41653 .85642 .41298 .85174 .40639 Mtetra
.85174 .40639 .85642 .41298 .86795 .40941 .8633 .40279 Mtetra
.8633 .40279 .86795 .40941 .87952 .40583 .8749 .39919 Mtetra
.8749 .39919 .87952 .40583 .89113 .40224 .88655 .39556 Mtetra
.2641 .58177 .27027 .58715 .27963 .58424 .27348 .57884 Mtetra
.27348 .57884 .27963 .58424 .28903 .58132 .2829 .57589 Mtetra
.2829 .57589 .28903 .58132 .29846 .57838 .29235 .57294 Mtetra
.29235 .57294 .29846 .57838 .30792 .57544 .30184 .56998 Mtetra
.30184 .56998 .30792 .57544 .31742 .57249 .31136 .56701 Mtetra
.31136 .56701 .31742 .57249 .32696 .56952 .32091 .56403 Mtetra
.32091 .56403 .32696 .56952 .33652 .56655 .3305 .56103 Mtetra
.3305 .56103 .33652 .56655 .34613 .56357 .34012 .55803 Mtetra
.34012 .55803 .34613 .56357 .35576 .56057 .34978 .55501 Mtetra
.34978 .55501 .35576 .56057 .36543 .55756 .35947 .55198 Mtetra
.35947 .55198 .36543 .55756 .37514 .55455 .3692 .54895 Mtetra
.3692 .54895 .37514 .55455 .38488 .55152 .37897 .5459 Mtetra
.37897 .5459 .38488 .55152 .39466 .54848 .38877 .54284 Mtetra
.38877 .54284 .39466 .54848 .40448 .54543 .3986 .53976 Mtetra
.3986 .53976 .40448 .54543 .41432 .54236 .40848 .53668 Mtetra
.40848 .53668 .41432 .54236 .42421 .53929 .41839 .53359 Mtetra
.41839 .53359 .42421 .53929 .43413 .53621 .42833 .53048 Mtetra
.42833 .53048 .43413 .53621 .44409 .53311 .43831 .52737 Mtetra
.43831 .52737 .44409 .53311 .45409 .53 .44833 .52424 Mtetra
.44833 .52424 .45409 .53 .46412 .52688 .45839 .5211 Mtetra
.45839 .5211 .46412 .52688 .47419 .52375 .46848 .51794 Mtetra
.46848 .51794 .47419 .52375 .4843 .52061 .47861 .51478 Mtetra
.47861 .51478 .4843 .52061 .49444 .51746 .48878 .51161 Mtetra
.48878 .51161 .49444 .51746 .50462 .51429 .49899 .50842 Mtetra
.49899 .50842 .50462 .51429 .51484 .51112 .50923 .50522 Mtetra
.50923 .50522 .51484 .51112 .5251 .50793 .51952 .50201 Mtetra
.51952 .50201 .5251 .50793 .5354 .50473 .52984 .49879 Mtetra
.52984 .49879 .5354 .50473 .54573 .50151 .5402 .49555 Mtetra
.5402 .49555 .54573 .50151 .55611 .49829 .5506 .4923 Mtetra
.5506 .4923 .55611 .49829 .56652 .49505 .56104 .48904 Mtetra
.56104 .48904 .56652 .49505 .57697 .4918 .57152 .48577 Mtetra
.57152 .48577 .57697 .4918 .58747 .48854 .58203 .48249 Mtetra
.58203 .48249 .58747 .48854 .598 .48527 .59259 .47919 Mtetra
.59259 .47919 .598 .48527 .60857 .48198 .60319 .47588 Mtetra
.60319 .47588 .60857 .48198 .61918 .47868 .61383 .47256 Mtetra
.61383 .47256 .61918 .47868 .62983 .47537 .62451 .46922 Mtetra
.62451 .46922 .62983 .47537 .64053 .47205 .63523 .46587 Mtetra
.63523 .46587 .64053 .47205 .65126 .46871 .64599 .46251 Mtetra
.64599 .46251 .65126 .46871 .66204 .46536 .6568 .45914 Mtetra
.6568 .45914 .66204 .46536 .67285 .462 .66764 .45575 Mtetra
.66764 .45575 .67285 .462 .68371 .45862 .67853 .45235 Mtetra
.67853 .45235 .68371 .45862 .69461 .45523 .68946 .44894 Mtetra
.68946 .44894 .69461 .45523 .70555 .45183 .70043 .44552 Mtetra
.70043 .44552 .70555 .45183 .71654 .44842 .71144 .44208 Mtetra
.71144 .44208 .71654 .44842 .72756 .44499 .7225 .43862 Mtetra
.7225 .43862 .72756 .44499 .73863 .44155 .7336 .43516 Mtetra
.7336 .43516 .73863 .44155 .74974 .43809 .74474 .43168 Mtetra
.74474 .43168 .74974 .43809 .7609 .43462 .75593 .42819 Mtetra
.75593 .42819 .7609 .43462 .7721 .43114 .76716 .42468 Mtetra
.76716 .42468 .7721 .43114 .78334 .42765 .77843 .42116 Mtetra
.77843 .42116 .78334 .42765 .79463 .42414 .78975 .41762 Mtetra
.78975 .41762 .79463 .42414 .80596 .42062 .80111 .41408 Mtetra
.80111 .41408 .80596 .42062 .81734 .41708 .81252 .41051 Mtetra
.81252 .41051 .81734 .41708 .82876 .41353 .82397 .40694 Mtetra
.82397 .40694 .82876 .41353 .84023 .40996 .83547 .40335 Mtetra
.83547 .40335 .84023 .40996 .85174 .40639 .84702 .39974 Mtetra
.84702 .39974 .85174 .40639 .8633 .40279 .85861 .39612 Mtetra
.85861 .39612 .8633 .40279 .8749 .39919 .87025 .39249 Mtetra
.87025 .39249 .8749 .39919 .88655 .39556 .88193 .38884 Mtetra
.25789 .57635 .2641 .58177 .27348 .57884 .2673 .5734 Mtetra
.2673 .5734 .27348 .57884 .2829 .57589 .27673 .57044 Mtetra
.27673 .57044 .2829 .57589 .29235 .57294 .2862 .56747 Mtetra
.2862 .56747 .29235 .57294 .30184 .56998 .29571 .56449 Mtetra
.29571 .56449 .30184 .56998 .31136 .56701 .30525 .56149 Mtetra
.30525 .56149 .31136 .56701 .32091 .56403 .31483 .55849 Mtetra
.31483 .55849 .32091 .56403 .3305 .56103 .32444 .55547 Mtetra
.32444 .55547 .3305 .56103 .34012 .55803 .33408 .55245 Mtetra
.33408 .55245 .34012 .55803 .34978 .55501 .34376 .54941 Mtetra
.34376 .54941 .34978 .55501 .35947 .55198 .35348 .54637 Mtetra
.35348 .54637 .35947 .55198 .3692 .54895 .36323 .54331 Mtetra
.36323 .54331 .3692 .54895 .37897 .5459 .37301 .54024 Mtetra
.37301 .54024 .37897 .5459 .38877 .54284 .38284 .53716 Mtetra
.38284 .53716 .38877 .54284 .3986 .53976 .39269 .53406 Mtetra
.39269 .53406 .3986 .53976 .40848 .53668 .40259 .53096 Mtetra
.40259 .53096 .40848 .53668 .41839 .53359 .41252 .52785 Mtetra
.41252 .52785 .41839 .53359 .42833 .53048 .42249 .52472 Mtetra
.42249 .52472 .42833 .53048 .43831 .52737 .43249 .52158 Mtetra
.43249 .52158 .43831 .52737 .44833 .52424 .44254 .51843 Mtetra
.44254 .51843 .44833 .52424 .45839 .5211 .45262 .51527 Mtetra
.45262 .51527 .45839 .5211 .46848 .51794 .46273 .5121 Mtetra
.46273 .5121 .46848 .51794 .47861 .51478 .47289 .50891 Mtetra
.47289 .50891 .47861 .51478 .48878 .51161 .48308 .50571 Mtetra
.48308 .50571 .48878 .51161 .49899 .50842 .49331 .5025 Mtetra
.49331 .5025 .49899 .50842 .50923 .50522 .50358 .49928 Mtetra
.50358 .49928 .50923 .50522 .51952 .50201 .51389 .49605 Mtetra
.51389 .49605 .51952 .50201 .52984 .49879 .52424 .4928 Mtetra
.52424 .4928 .52984 .49879 .5402 .49555 .53463 .48955 Mtetra
.53463 .48955 .5402 .49555 .5506 .4923 .54505 .48627 Mtetra
.54505 .48627 .5506 .4923 .56104 .48904 .55552 .48299 Mtetra
.55552 .48299 .56104 .48904 .57152 .48577 .56602 .4797 Mtetra
.56602 .4797 .57152 .48577 .58203 .48249 .57657 .47639 Mtetra
.57657 .47639 .58203 .48249 .59259 .47919 .58715 .47307 Mtetra
.58715 .47307 .59259 .47919 .60319 .47588 .59778 .46974 Mtetra
.59778 .46974 .60319 .47588 .61383 .47256 .60844 .46639 Mtetra
.60844 .46639 .61383 .47256 .62451 .46922 .61915 .46303 Mtetra
.61915 .46303 .62451 .46922 .63523 .46587 .6299 .45966 Mtetra
.6299 .45966 .63523 .46587 .64599 .46251 .64069 .45628 Mtetra
.64069 .45628 .64599 .46251 .6568 .45914 .65152 .45288 Mtetra
.65152 .45288 .6568 .45914 .66764 .45575 .66239 .44947 Mtetra
.66239 .44947 .66764 .45575 .67853 .45235 .67331 .44604 Mtetra
.67331 .44604 .67853 .45235 .68946 .44894 .68427 .44261 Mtetra
.68427 .44261 .68946 .44894 .70043 .44552 .69527 .43916 Mtetra
.69527 .43916 .70043 .44552 .71144 .44208 .70631 .43569 Mtetra
.70631 .43569 .71144 .44208 .7225 .43862 .7174 .43222 Mtetra
.7174 .43222 .7225 .43862 .7336 .43516 .72853 .42872 Mtetra
.72853 .42872 .7336 .43516 .74474 .43168 .7397 .42522 Mtetra
.7397 .42522 .74474 .43168 .75593 .42819 .75092 .4217 Mtetra
.75092 .4217 .75593 .42819 .76716 .42468 .76218 .41817 Mtetra
.76218 .41817 .76716 .42468 .77843 .42116 .77348 .41462 Mtetra
.77348 .41462 .77843 .42116 .78975 .41762 .78483 .41106 Mtetra
.78483 .41106 .78975 .41762 .80111 .41408 .79623 .40749 Mtetra
.79623 .40749 .80111 .41408 .81252 .41051 .80767 .4039 Mtetra
.80767 .4039 .81252 .41051 .82397 .40694 .81915 .4003 Mtetra
.81915 .4003 .82397 .40694 .83547 .40335 .83069 .39668 Mtetra
.83069 .39668 .83547 .40335 .84702 .39974 .84226 .39305 Mtetra
.84226 .39305 .84702 .39974 .85861 .39612 .85389 .3894 Mtetra
.85389 .3894 .85861 .39612 .87025 .39249 .86556 .38574 Mtetra
.86556 .38574 .87025 .39249 .88193 .38884 .87727 .38207 Mtetra
.25164 .57089 .25789 .57635 .2673 .5734 .26107 .56792 Mtetra
.26107 .56792 .2673 .5734 .27673 .57044 .27052 .56494 Mtetra
.27052 .56494 .27673 .57044 .2862 .56747 .28002 .56195 Mtetra
.28002 .56195 .2862 .56747 .29571 .56449 .28954 .55895 Mtetra
.28954 .55895 .29571 .56449 .30525 .56149 .2991 .55594 Mtetra
.2991 .55594 .30525 .56149 .31483 .55849 .3087 .55292 Mtetra
.3087 .55292 .31483 .55849 .32444 .55547 .31833 .54988 Mtetra
.31833 .54988 .32444 .55547 .33408 .55245 .328 .54684 Mtetra
.328 .54684 .33408 .55245 .34376 .54941 .3377 .54378 Mtetra
.3377 .54378 .34376 .54941 .35348 .54637 .34744 .54071 Mtetra
.34744 .54071 .35348 .54637 .36323 .54331 .35721 .53763 Mtetra
.35721 .53763 .36323 .54331 .37301 .54024 .36702 .53454 Mtetra
.36702 .53454 .37301 .54024 .38284 .53716 .37686 .53144 Mtetra
.37686 .53144 .38284 .53716 .39269 .53406 .38674 .52833 Mtetra
.38674 .52833 .39269 .53406 .40259 .53096 .39666 .5252 Mtetra
.39666 .5252 .40259 .53096 .41252 .52785 .40662 .52206 Mtetra
.40662 .52206 .41252 .52785 .42249 .52472 .41661 .51892 Mtetra
.41661 .51892 .42249 .52472 .43249 .52158 .42664 .51576 Mtetra
.42664 .51576 .43249 .52158 .44254 .51843 .4367 .51258 Mtetra
.4367 .51258 .44254 .51843 .45262 .51527 .44681 .5094 Mtetra
.44681 .5094 .45262 .51527 .46273 .5121 .45695 .50621 Mtetra
.45695 .50621 .46273 .5121 .47289 .50891 .46713 .503 Mtetra
.46713 .503 .47289 .50891 .48308 .50571 .47734 .49978 Mtetra
.47734 .49978 .48308 .50571 .49331 .5025 .4876 .49655 Mtetra
.4876 .49655 .49331 .5025 .50358 .49928 .49789 .4933 Mtetra
.49789 .4933 .50358 .49928 .51389 .49605 .50823 .49005 Mtetra
.50823 .49005 .51389 .49605 .52424 .4928 .5186 .48678 Mtetra
.5186 .48678 .52424 .4928 .53463 .48955 .52901 .4835 Mtetra
.52901 .4835 .53463 .48955 .54505 .48627 .53946 .4802 Mtetra
.53946 .4802 .54505 .48627 .55552 .48299 .54996 .4769 Mtetra
.54996 .4769 .55552 .48299 .56602 .4797 .56049 .47358 Mtetra
.56049 .47358 .56602 .4797 .57657 .47639 .57106 .47025 Mtetra
.57106 .47025 .57657 .47639 .58715 .47307 .58167 .46691 Mtetra
.58167 .46691 .58715 .47307 .59778 .46974 .59232 .46355 Mtetra
.59232 .46355 .59778 .46974 .60844 .46639 .60302 .46018 Mtetra
.60302 .46018 .60844 .46639 .61915 .46303 .61375 .4568 Mtetra
.61375 .4568 .61915 .46303 .6299 .45966 .62453 .4534 Mtetra
.62453 .4534 .6299 .45966 .64069 .45628 .63535 .44999 Mtetra
.63535 .44999 .64069 .45628 .65152 .45288 .64621 .44657 Mtetra
.64621 .44657 .65152 .45288 .66239 .44947 .65711 .44314 Mtetra
.65711 .44314 .66239 .44947 .67331 .44604 .66805 .43969 Mtetra
.66805 .43969 .67331 .44604 .68427 .44261 .67904 .43623 Mtetra
.67904 .43623 .68427 .44261 .69527 .43916 .69007 .43275 Mtetra
.69007 .43275 .69527 .43916 .70631 .43569 .70114 .42926 Mtetra
.70114 .42926 .70631 .43569 .7174 .43222 .71226 .42576 Mtetra
.71226 .42576 .7174 .43222 .72853 .42872 .72342 .42224 Mtetra
.72342 .42224 .72853 .42872 .7397 .42522 .73462 .41871 Mtetra
.73462 .41871 .7397 .42522 .75092 .4217 .74587 .41517 Mtetra
.74587 .41517 .75092 .4217 .76218 .41817 .75716 .41161 Mtetra
.75716 .41161 .76218 .41817 .77348 .41462 .7685 .40804 Mtetra
.7685 .40804 .77348 .41462 .78483 .41106 .77988 .40445 Mtetra
.77988 .40445 .78483 .41106 .79623 .40749 .79131 .40085 Mtetra
.79131 .40085 .79623 .40749 .80767 .4039 .80278 .39724 Mtetra
.80278 .39724 .80767 .4039 .81915 .4003 .8143 .39361 Mtetra
.8143 .39361 .81915 .4003 .83069 .39668 .82586 .38996 Mtetra
.82586 .38996 .83069 .39668 .84226 .39305 .83747 .38631 Mtetra
.83747 .38631 .84226 .39305 .85389 .3894 .84913 .38263 Mtetra
.84913 .38263 .85389 .3894 .86556 .38574 .86083 .37895 Mtetra
.86083 .37895 .86556 .38574 .87727 .38207 .87259 .37524 Mtetra
.24535 .5654 .25164 .57089 .26107 .56792 .2548 .56241 Mtetra
.2548 .56241 .26107 .56792 .27052 .56494 .26427 .55941 Mtetra
.26427 .55941 .27052 .56494 .28002 .56195 .27379 .5564 Mtetra
.27379 .5564 .28002 .56195 .28954 .55895 .28333 .55338 Mtetra
.28333 .55338 .28954 .55895 .2991 .55594 .29292 .55035 Mtetra
.29292 .55035 .2991 .55594 .3087 .55292 .30253 .5473 Mtetra
.30253 .5473 .3087 .55292 .31833 .54988 .31218 .54425 Mtetra
.31218 .54425 .31833 .54988 .328 .54684 .32187 .54118 Mtetra
.32187 .54118 .328 .54684 .3377 .54378 .3316 .53811 Mtetra
.3316 .53811 .3377 .54378 .34744 .54071 .34135 .53502 Mtetra
.34135 .53502 .34744 .54071 .35721 .53763 .35115 .53192 Mtetra
.35115 .53192 .35721 .53763 .36702 .53454 .36098 .52881 Mtetra
.36098 .52881 .36702 .53454 .37686 .53144 .37085 .52568 Mtetra
.37085 .52568 .37686 .53144 .38674 .52833 .38075 .52255 Mtetra
.38075 .52255 .38674 .52833 .39666 .5252 .39069 .5194 Mtetra
.39069 .5194 .39666 .5252 .40662 .52206 .40067 .51624 Mtetra
.40067 .51624 .40662 .52206 .41661 .51892 .41068 .51307 Mtetra
.41068 .51307 .41661 .51892 .42664 .51576 .42074 .50989 Mtetra
.42074 .50989 .42664 .51576 .4367 .51258 .43083 .5067 Mtetra
.43083 .5067 .4367 .51258 .44681 .5094 .44095 .50349 Mtetra
.44095 .50349 .44681 .5094 .45695 .50621 .45112 .50027 Mtetra
.45112 .50027 .45695 .50621 .46713 .503 .46132 .49704 Mtetra
.46132 .49704 .46713 .503 .47734 .49978 .47157 .4938 Mtetra
.47157 .4938 .47734 .49978 .4876 .49655 .48185 .49055 Mtetra
.48185 .49055 .4876 .49655 .49789 .4933 .49217 .48728 Mtetra
.49217 .48728 .49789 .4933 .50823 .49005 .50253 .484 Mtetra
.50253 .484 .50823 .49005 .5186 .48678 .51292 .48071 Mtetra
.51292 .48071 .5186 .48678 .52901 .4835 .52336 .47741 Mtetra
.52336 .47741 .52901 .4835 .53946 .4802 .53384 .47409 Mtetra
.53384 .47409 .53946 .4802 .54996 .4769 .54436 .47076 Mtetra
.54436 .47076 .54996 .4769 .56049 .47358 .55491 .46742 Mtetra
.55491 .46742 .56049 .47358 .57106 .47025 .56551 .46407 Mtetra
.56551 .46407 .57106 .47025 .58167 .46691 .57615 .4607 Mtetra
.57615 .4607 .58167 .46691 .59232 .46355 .58683 .45732 Mtetra
.58683 .45732 .59232 .46355 .60302 .46018 .59755 .45393 Mtetra
.59755 .45393 .60302 .46018 .61375 .4568 .60832 .45052 Mtetra
.60832 .45052 .61375 .4568 .62453 .4534 .61912 .4471 Mtetra
.61912 .4471 .62453 .4534 .63535 .44999 .62997 .44367 Mtetra
.62997 .44367 .63535 .44999 .64621 .44657 .64085 .44022 Mtetra
.64085 .44022 .64621 .44657 .65711 .44314 .65178 .43676 Mtetra
.65178 .43676 .65711 .44314 .66805 .43969 .66276 .43329 Mtetra
.66276 .43329 .66805 .43969 .67904 .43623 .67377 .4298 Mtetra
.67377 .4298 .67904 .43623 .69007 .43275 .68483 .4263 Mtetra
.68483 .4263 .69007 .43275 .70114 .42926 .69594 .42279 Mtetra
.69594 .42279 .70114 .42926 .71226 .42576 .70708 .41926 Mtetra
.70708 .41926 .71226 .42576 .72342 .42224 .71827 .41572 Mtetra
.71827 .41572 .72342 .42224 .73462 .41871 .72951 .41216 Mtetra
.72951 .41216 .73462 .41871 .74587 .41517 .74079 .40859 Mtetra
.74079 .40859 .74587 .41517 .75716 .41161 .75211 .40501 Mtetra
.75211 .40501 .75716 .41161 .7685 .40804 .76348 .40141 Mtetra
.76348 .40141 .7685 .40804 .77988 .40445 .77489 .39779 Mtetra
.77489 .39779 .77988 .40445 .79131 .40085 .78635 .39417 Mtetra
.78635 .39417 .79131 .40085 .80278 .39724 .79786 .39053 Mtetra
.79786 .39053 .80278 .39724 .8143 .39361 .80941 .38687 Mtetra
.80941 .38687 .8143 .39361 .82586 .38996 .821 .3832 Mtetra
.821 .3832 .82586 .38996 .83747 .38631 .83265 .37951 Mtetra
.83265 .37951 .83747 .38631 .84913 .38263 .84434 .37581 Mtetra
.84434 .37581 .84913 .38263 .86083 .37895 .85608 .3721 Mtetra
.85608 .3721 .86083 .37895 .87259 .37524 .86786 .36837 Mtetra
.23902 .55988 .24535 .5654 .2548 .56241 .24848 .55687 Mtetra
.24848 .55687 .2548 .56241 .26427 .55941 .25798 .55385 Mtetra
.25798 .55385 .26427 .55941 .27379 .5564 .26751 .55082 Mtetra
.26751 .55082 .27379 .5564 .28333 .55338 .27708 .54777 Mtetra
.27708 .54777 .28333 .55338 .29292 .55035 .28669 .54472 Mtetra
.28669 .54472 .29292 .55035 .30253 .5473 .29632 .54166 Mtetra
.29632 .54166 .30253 .5473 .31218 .54425 .306 .53858 Mtetra
.306 .53858 .31218 .54425 .32187 .54118 .31571 .53549 Mtetra
.31571 .53549 .32187 .54118 .3316 .53811 .32545 .53239 Mtetra
.32545 .53239 .3316 .53811 .34135 .53502 .33523 .52928 Mtetra
.33523 .52928 .34135 .53502 .35115 .53192 .34505 .52616 Mtetra
.34505 .52616 .35115 .53192 .36098 .52881 .3549 .52303 Mtetra
.3549 .52303 .36098 .52881 .37085 .52568 .36479 .51989 Mtetra
.36479 .51989 .37085 .52568 .38075 .52255 .37472 .51673 Mtetra
.37472 .51673 .38075 .52255 .39069 .5194 .38468 .51356 Mtetra
.38468 .51356 .39069 .5194 .40067 .51624 .39468 .51038 Mtetra
.39468 .51038 .40067 .51624 .41068 .51307 .40472 .50719 Mtetra
.40472 .50719 .41068 .51307 .42074 .50989 .4148 .50399 Mtetra
.4148 .50399 .42074 .50989 .43083 .5067 .42491 .50077 Mtetra
.42491 .50077 .43083 .5067 .44095 .50349 .43506 .49754 Mtetra
.43506 .49754 .44095 .50349 .45112 .50027 .44525 .4943 Mtetra
.44525 .4943 .45112 .50027 .46132 .49704 .45548 .49105 Mtetra
.45548 .49105 .46132 .49704 .47157 .4938 .46575 .48779 Mtetra
.46575 .48779 .47157 .4938 .48185 .49055 .47605 .48451 Mtetra
.47605 .48451 .48185 .49055 .49217 .48728 .4864 .48122 Mtetra
.4864 .48122 .49217 .48728 .50253 .484 .49678 .47792 Mtetra
.49678 .47792 .50253 .484 .51292 .48071 .50721 .4746 Mtetra
.50721 .4746 .51292 .48071 .52336 .47741 .51767 .47128 Mtetra
.51767 .47128 .52336 .47741 .53384 .47409 .52817 .46794 Mtetra
.52817 .46794 .53384 .47409 .54436 .47076 .53872 .46458 Mtetra
.53872 .46458 .54436 .47076 .55491 .46742 .5493 .46122 Mtetra
.5493 .46122 .55491 .46742 .56551 .46407 .55993 .45784 Mtetra
.55993 .45784 .56551 .46407 .57615 .4607 .57059 .45445 Mtetra
.57059 .45445 .57615 .4607 .58683 .45732 .5813 .45104 Mtetra
.5813 .45104 .58683 .45732 .59755 .45393 .59205 .44763 Mtetra
.59205 .44763 .59755 .45393 .60832 .45052 .60284 .4442 Mtetra
.60284 .4442 .60832 .45052 .61912 .4471 .61367 .44075 Mtetra
.61367 .44075 .61912 .4471 .62997 .44367 .62455 .43729 Mtetra
.62455 .43729 .62997 .44367 .64085 .44022 .63546 .43382 Mtetra
.63546 .43382 .64085 .44022 .65178 .43676 .64642 .43034 Mtetra
.64642 .43034 .65178 .43676 .66276 .43329 .65743 .42684 Mtetra
.65743 .42684 .66276 .43329 .67377 .4298 .66847 .42333 Mtetra
.66847 .42333 .67377 .4298 .68483 .4263 .67956 .4198 Mtetra
.67956 .4198 .68483 .4263 .69594 .42279 .69069 .41626 Mtetra
.69069 .41626 .69594 .42279 .70708 .41926 .70187 .41271 Mtetra
.70187 .41271 .70708 .41926 .71827 .41572 .71309 .40914 Mtetra
.71309 .40914 .71827 .41572 .72951 .41216 .72436 .40556 Mtetra
.72436 .40556 .72951 .41216 .74079 .40859 .73566 .40196 Mtetra
.73566 .40196 .74079 .40859 .75211 .40501 .74702 .39835 Mtetra
.74702 .39835 .75211 .40501 .76348 .40141 .75842 .39473 Mtetra
.75842 .39473 .76348 .40141 .77489 .39779 .76987 .39109 Mtetra
.76987 .39109 .77489 .39779 .78635 .39417 .78136 .38743 Mtetra
.78136 .38743 .78635 .39417 .79786 .39053 .79289 .38376 Mtetra
.79289 .38376 .79786 .39053 .80941 .38687 .80448 .38008 Mtetra
.80448 .38008 .80941 .38687 .821 .3832 .81611 .37638 Mtetra
.81611 .37638 .821 .3832 .83265 .37951 .82779 .37267 Mtetra
.82779 .37267 .83265 .37951 .84434 .37581 .83951 .36894 Mtetra
.83951 .36894 .84434 .37581 .85608 .3721 .85128 .3652 Mtetra
.85128 .3652 .85608 .3721 .86786 .36837 .8631 .36144 Mtetra
.23264 .55431 .23902 .55988 .24848 .55687 .24213 .55128 Mtetra
.24213 .55128 .24848 .55687 .25798 .55385 .25165 .54824 Mtetra
.25165 .54824 .25798 .55385 .26751 .55082 .2612 .54519 Mtetra
.2612 .54519 .26751 .55082 .27708 .54777 .27079 .54213 Mtetra
.27079 .54213 .27708 .54777 .28669 .54472 .28041 .53905 Mtetra
.28041 .53905 .28669 .54472 .29632 .54166 .29007 .53597 Mtetra
.29007 .53597 .29632 .54166 .306 .53858 .29977 .53287 Mtetra
.29977 .53287 .306 .53858 .31571 .53549 .3095 .52976 Mtetra
.3095 .52976 .31571 .53549 .32545 .53239 .31926 .52664 Mtetra
.31926 .52664 .32545 .53239 .33523 .52928 .32907 .52351 Mtetra
.32907 .52351 .33523 .52928 .34505 .52616 .33891 .52037 Mtetra
.33891 .52037 .34505 .52616 .3549 .52303 .34878 .51722 Mtetra
.34878 .51722 .3549 .52303 .36479 .51989 .35869 .51405 Mtetra
.35869 .51405 .36479 .51989 .37472 .51673 .36864 .51087 Mtetra
.36864 .51087 .37472 .51673 .38468 .51356 .37863 .50768 Mtetra
.37863 .50768 .38468 .51356 .39468 .51038 .38865 .50448 Mtetra
.38865 .50448 .39468 .51038 .40472 .50719 .39872 .50127 Mtetra
.39872 .50127 .40472 .50719 .4148 .50399 .40882 .49804 Mtetra
.40882 .49804 .4148 .50399 .42491 .50077 .41895 .4948 Mtetra
.41895 .4948 .42491 .50077 .43506 .49754 .42913 .49155 Mtetra
.42913 .49155 .43506 .49754 .44525 .4943 .43934 .48829 Mtetra
.43934 .48829 .44525 .4943 .45548 .49105 .4496 .48501 Mtetra
.4496 .48501 .45548 .49105 .46575 .48779 .45989 .48173 Mtetra
.45989 .48173 .46575 .48779 .47605 .48451 .47022 .47843 Mtetra
.47022 .47843 .47605 .48451 .4864 .48122 .48059 .47511 Mtetra
.48059 .47511 .4864 .48122 .49678 .47792 .491 .47179 Mtetra
.491 .47179 .49678 .47792 .50721 .4746 .50145 .46845 Mtetra
.50145 .46845 .50721 .4746 .51767 .47128 .51194 .4651 Mtetra
.51194 .4651 .51767 .47128 .52817 .46794 .52247 .46174 Mtetra
.52247 .46174 .52817 .46794 .53872 .46458 .53304 .45836 Mtetra
.53304 .45836 .53872 .46458 .5493 .46122 .54365 .45497 Mtetra
.54365 .45497 .5493 .46122 .55993 .45784 .5543 .45157 Mtetra
.5543 .45157 .55993 .45784 .57059 .45445 .565 .44815 Mtetra
.565 .44815 .57059 .45445 .5813 .45104 .57573 .44472 Mtetra
.57573 .44472 .5813 .45104 .59205 .44763 .58651 .44128 Mtetra
.58651 .44128 .59205 .44763 .60284 .4442 .59732 .43783 Mtetra
.59732 .43783 .60284 .4442 .61367 .44075 .60819 .43436 Mtetra
.60819 .43436 .61367 .44075 .62455 .43729 .61909 .43087 Mtetra
.61909 .43087 .62455 .43729 .63546 .43382 .63003 .42738 Mtetra
.63003 .42738 .63546 .43382 .64642 .43034 .64102 .42387 Mtetra
.64102 .42387 .64642 .43034 .65743 .42684 .65205 .42034 Mtetra
.65205 .42034 .65743 .42684 .66847 .42333 .66313 .41681 Mtetra
.66313 .41681 .66847 .42333 .67956 .4198 .67425 .41326 Mtetra
.67425 .41326 .67956 .4198 .69069 .41626 .68541 .40969 Mtetra
.68541 .40969 .69069 .41626 .70187 .41271 .69662 .40611 Mtetra
.69662 .40611 .70187 .41271 .71309 .40914 .70787 .40252 Mtetra
.70787 .40252 .71309 .40914 .72436 .40556 .71917 .39891 Mtetra
.71917 .39891 .72436 .40556 .73566 .40196 .73051 .39529 Mtetra
.73051 .39529 .73566 .40196 .74702 .39835 .74189 .39165 Mtetra
.74189 .39165 .74702 .39835 .75842 .39473 .75332 .388 Mtetra
.75332 .388 .75842 .39473 .76987 .39109 .7648 .38433 Mtetra
.7648 .38433 .76987 .39109 .78136 .38743 .77633 .38065 Mtetra
.77633 .38065 .78136 .38743 .79289 .38376 .7879 .37695 Mtetra
.7879 .37695 .79289 .38376 .80448 .38008 .79951 .37324 Mtetra
.79951 .37324 .80448 .38008 .81611 .37638 .81118 .36952 Mtetra
.81118 .36952 .81611 .37638 .82779 .37267 .82289 .36578 Mtetra
.82289 .36578 .82779 .37267 .83951 .36894 .83465 .36202 Mtetra
.83465 .36202 .83951 .36894 .85128 .3652 .84645 .35825 Mtetra
.84645 .35825 .85128 .3652 .8631 .36144 .85831 .35446 Mtetra
.22623 .54871 .23264 .55431 .24213 .55128 .23573 .54566 Mtetra
.23573 .54566 .24213 .55128 .25165 .54824 .24527 .5426 Mtetra
.24527 .5426 .25165 .54824 .2612 .54519 .25484 .53953 Mtetra
.25484 .53953 .2612 .54519 .27079 .54213 .26445 .53644 Mtetra
.26445 .53644 .27079 .54213 .28041 .53905 .2741 .53335 Mtetra
.2741 .53335 .28041 .53905 .29007 .53597 .28378 .53024 Mtetra
.28378 .53024 .29007 .53597 .29977 .53287 .2935 .52712 Mtetra
.2935 .52712 .29977 .53287 .3095 .52976 .30325 .524 Mtetra
.30325 .524 .3095 .52976 .31926 .52664 .31304 .52085 Mtetra
.31304 .52085 .31926 .52664 .32907 .52351 .32286 .5177 Mtetra
.32286 .5177 .32907 .52351 .33891 .52037 .33272 .51454 Mtetra
.33272 .51454 .33891 .52037 .34878 .51722 .34262 .51136 Mtetra
.34262 .51136 .34878 .51722 .35869 .51405 .35256 .50817 Mtetra
.35256 .50817 .35869 .51405 .36864 .51087 .36253 .50497 Mtetra
.36253 .50497 .36864 .51087 .37863 .50768 .37254 .50176 Mtetra
.37254 .50176 .37863 .50768 .38865 .50448 .38258 .49854 Mtetra
.38258 .49854 .38865 .50448 .39872 .50127 .39267 .4953 Mtetra
.39267 .4953 .39872 .50127 .40882 .49804 .40279 .49205 Mtetra
.40279 .49205 .40882 .49804 .41895 .4948 .41295 .48879 Mtetra
.41295 .48879 .41895 .4948 .42913 .49155 .42315 .48552 Mtetra
.42315 .48552 .42913 .49155 .43934 .48829 .43339 .48223 Mtetra
.43339 .48223 .43934 .48829 .4496 .48501 .44367 .47893 Mtetra
.44367 .47893 .4496 .48501 .45989 .48173 .45399 .47562 Mtetra
.45399 .47562 .45989 .48173 .47022 .47843 .46434 .4723 Mtetra
.46434 .4723 .47022 .47843 .48059 .47511 .47474 .46897 Mtetra
.47474 .46897 .48059 .47511 .491 .47179 .48517 .46562 Mtetra
.48517 .46562 .491 .47179 .50145 .46845 .49565 .46226 Mtetra
.49565 .46226 .50145 .46845 .51194 .4651 .50617 .45888 Mtetra
.50617 .45888 .51194 .4651 .52247 .46174 .51672 .45549 Mtetra
.51672 .45549 .52247 .46174 .53304 .45836 .52732 .45209 Mtetra
.52732 .45209 .53304 .45836 .54365 .45497 .53796 .44868 Mtetra
.53796 .44868 .54365 .45497 .5543 .45157 .54864 .44525 Mtetra
.54864 .44525 .5543 .45157 .565 .44815 .55936 .44181 Mtetra
.55936 .44181 .565 .44815 .57573 .44472 .57012 .43836 Mtetra
.57012 .43836 .57573 .44472 .58651 .44128 .58092 .43489 Mtetra
.58092 .43489 .58651 .44128 .59732 .43783 .59177 .43141 Mtetra
.59177 .43141 .59732 .43783 .60819 .43436 .60266 .42792 Mtetra
.60266 .42792 .60819 .43436 .61909 .43087 .61359 .42441 Mtetra
.61359 .42441 .61909 .43087 .63003 .42738 .62456 .42089 Mtetra
.62456 .42089 .63003 .42738 .64102 .42387 .63558 .41735 Mtetra
.63558 .41735 .64102 .42387 .65205 .42034 .64664 .4138 Mtetra
.64664 .4138 .65205 .42034 .66313 .41681 .65775 .41024 Mtetra
.65775 .41024 .66313 .41681 .67425 .41326 .6689 .40666 Mtetra
.6689 .40666 .67425 .41326 .68541 .40969 .68009 .40307 Mtetra
.68009 .40307 .68541 .40969 .69662 .40611 .69133 .39946 Mtetra
.69133 .39946 .69662 .40611 .70787 .40252 .70261 .39584 Mtetra
.70261 .39584 .70787 .40252 .71917 .39891 .71394 .39221 Mtetra
.71394 .39221 .71917 .39891 .73051 .39529 .72531 .38856 Mtetra
.72531 .38856 .73051 .39529 .74189 .39165 .73673 .3849 Mtetra
.73673 .3849 .74189 .39165 .75332 .388 .74819 .38122 Mtetra
.74819 .38122 .75332 .388 .7648 .38433 .7597 .37752 Mtetra
.7597 .37752 .7648 .38433 .77633 .38065 .77126 .37381 Mtetra
.77126 .37381 .77633 .38065 .7879 .37695 .78286 .37009 Mtetra
.78286 .37009 .7879 .37695 .79951 .37324 .79451 .36635 Mtetra
.79451 .36635 .79951 .37324 .81118 .36952 .80621 .3626 Mtetra
.80621 .3626 .81118 .36952 .82289 .36578 .81795 .35883 Mtetra
.81795 .35883 .82289 .36578 .83465 .36202 .82975 .35505 Mtetra
.82975 .35505 .83465 .36202 .84645 .35825 .84159 .35125 Mtetra
.84159 .35125 .84645 .35825 .85831 .35446 .85348 .34743 Mtetra
.21976 .54307 .22623 .54871 .23573 .54566 .22929 .54 Mtetra
.22929 .54 .23573 .54566 .24527 .5426 .23885 .53692 Mtetra
.23885 .53692 .24527 .5426 .25484 .53953 .24844 .53383 Mtetra
.24844 .53383 .25484 .53953 .26445 .53644 .25807 .53072 Mtetra
.25807 .53072 .26445 .53644 .2741 .53335 .26774 .52761 Mtetra
.26774 .52761 .2741 .53335 .28378 .53024 .27744 .52448 Mtetra
.27744 .52448 .28378 .53024 .2935 .52712 .28718 .52134 Mtetra
.28718 .52134 .2935 .52712 .30325 .524 .29695 .51819 Mtetra
.29695 .51819 .30325 .524 .31304 .52085 .30676 .51503 Mtetra
.30676 .51503 .31304 .52085 .32286 .5177 .31661 .51185 Mtetra
.31661 .51185 .32286 .5177 .33272 .51454 .3265 .50866 Mtetra
.3265 .50866 .33272 .51454 .34262 .51136 .33642 .50547 Mtetra
.33642 .50547 .34262 .51136 .35256 .50817 .34637 .50226 Mtetra
.34637 .50226 .35256 .50817 .36253 .50497 .35637 .49903 Mtetra
.35637 .49903 .36253 .50497 .37254 .50176 .3664 .4958 Mtetra
.3664 .4958 .37254 .50176 .38258 .49854 .37647 .49255 Mtetra
.37647 .49255 .38258 .49854 .39267 .4953 .38658 .48929 Mtetra
.38658 .48929 .39267 .4953 .40279 .49205 .39673 .48602 Mtetra
.39673 .48602 .40279 .49205 .41295 .48879 .40691 .48274 Mtetra
.40691 .48274 .41295 .48879 .42315 .48552 .41714 .47944 Mtetra
.41714 .47944 .42315 .48552 .43339 .48223 .4274 .47613 Mtetra
.4274 .47613 .43339 .48223 .44367 .47893 .4377 .47281 Mtetra
.4377 .47281 .44367 .47893 .45399 .47562 .44805 .46948 Mtetra
.44805 .46948 .45399 .47562 .46434 .4723 .45843 .46613 Mtetra
.45843 .46613 .46434 .4723 .47474 .46897 .46885 .46277 Mtetra
.46885 .46277 .47474 .46897 .48517 .46562 .47931 .4594 Mtetra
.47931 .4594 .48517 .46562 .49565 .46226 .48981 .45602 Mtetra
.48981 .45602 .49565 .46226 .50617 .45888 .50035 .45262 Mtetra
.50035 .45262 .50617 .45888 .51672 .45549 .51093 .44921 Mtetra
.51093 .44921 .51672 .45549 .52732 .45209 .52156 .44578 Mtetra
.52156 .44578 .52732 .45209 .53796 .44868 .53222 .44234 Mtetra
.53222 .44234 .53796 .44868 .54864 .44525 .54293 .43889 Mtetra
.54293 .43889 .54864 .44525 .55936 .44181 .55368 .43543 Mtetra
.55368 .43543 .55936 .44181 .57012 .43836 .56447 .43195 Mtetra
.56447 .43195 .57012 .43836 .58092 .43489 .5753 .42846 Mtetra
.5753 .42846 .58092 .43489 .59177 .43141 .58617 .42495 Mtetra
.58617 .42495 .59177 .43141 .60266 .42792 .59709 .42143 Mtetra
.59709 .42143 .60266 .42792 .61359 .42441 .60805 .4179 Mtetra
.60805 .4179 .61359 .42441 .62456 .42089 .61906 .41435 Mtetra
.61906 .41435 .62456 .42089 .63558 .41735 .6301 .41079 Mtetra
.6301 .41079 .63558 .41735 .64664 .4138 .64119 .40721 Mtetra
.64119 .40721 .64664 .4138 .65775 .41024 .65233 .40362 Mtetra
.65233 .40362 .65775 .41024 .6689 .40666 .66351 .40002 Mtetra
.66351 .40002 .6689 .40666 .68009 .40307 .67473 .3964 Mtetra
.67473 .3964 .68009 .40307 .69133 .39946 .686 .39277 Mtetra
.686 .39277 .69133 .39946 .70261 .39584 .69731 .38912 Mtetra
.69731 .38912 .70261 .39584 .71394 .39221 .70867 .38546 Mtetra
.70867 .38546 .71394 .39221 .72531 .38856 .72007 .38178 Mtetra
.72007 .38178 .72531 .38856 .73673 .3849 .73152 .37809 Mtetra
.73152 .37809 .73673 .3849 .74819 .38122 .74302 .37439 Mtetra
.74302 .37439 .74819 .38122 .7597 .37752 .75456 .37067 Mtetra
.75456 .37067 .7597 .37752 .77126 .37381 .76615 .36693 Mtetra
.76615 .36693 .77126 .37381 .78286 .37009 .77779 .36318 Mtetra
.77779 .36318 .78286 .37009 .79451 .36635 .78947 .35941 Mtetra
.78947 .35941 .79451 .36635 .80621 .3626 .8012 .35563 Mtetra
.8012 .35563 .80621 .3626 .81795 .35883 .81298 .35183 Mtetra
.81298 .35183 .81795 .35883 .82975 .35505 .82481 .34802 Mtetra
.82481 .34802 .82975 .35505 .84159 .35125 .83668 .34419 Mtetra
.83668 .34419 .84159 .35125 .85348 .34743 .84861 .34035 Mtetra
.21326 .53739 .21976 .54307 .22929 .54 .2228 .5343 Mtetra
.2228 .5343 .22929 .54 .23885 .53692 .23238 .5312 Mtetra
.23238 .5312 .23885 .53692 .24844 .53383 .242 .52809 Mtetra
.242 .52809 .24844 .53383 .25807 .53072 .25165 .52496 Mtetra
.25165 .52496 .25807 .53072 .26774 .52761 .26134 .52182 Mtetra
.26134 .52182 .26774 .52761 .27744 .52448 .27106 .51867 Mtetra
.27106 .51867 .27744 .52448 .28718 .52134 .28082 .51551 Mtetra
.28082 .51551 .28718 .52134 .29695 .51819 .29062 .51234 Mtetra
.29062 .51234 .29695 .51819 .30676 .51503 .30045 .50916 Mtetra
.30045 .50916 .30676 .51503 .31661 .51185 .31032 .50596 Mtetra
.31032 .50596 .31661 .51185 .3265 .50866 .32022 .50275 Mtetra
.32022 .50275 .3265 .50866 .33642 .50547 .33017 .49953 Mtetra
.33017 .49953 .33642 .50547 .34637 .50226 .34015 .4963 Mtetra
.34015 .4963 .34637 .50226 .35637 .49903 .35017 .49305 Mtetra
.35017 .49305 .35637 .49903 .3664 .4958 .36022 .4898 Mtetra
.36022 .4898 .3664 .4958 .37647 .49255 .37032 .48653 Mtetra
.37032 .48653 .37647 .49255 .38658 .48929 .38045 .48325 Mtetra
.38045 .48325 .38658 .48929 .39673 .48602 .39062 .47995 Mtetra
.39062 .47995 .39673 .48602 .40691 .48274 .40083 .47664 Mtetra
.40083 .47664 .40691 .48274 .41714 .47944 .41108 .47333 Mtetra
.41108 .47333 .41714 .47944 .4274 .47613 .42137 .46999 Mtetra
.42137 .46999 .4274 .47613 .4377 .47281 .43169 .46665 Mtetra
.43169 .46665 .4377 .47281 .44805 .46948 .44206 .46329 Mtetra
.44206 .46329 .44805 .46948 .45843 .46613 .45247 .45992 Mtetra
.45247 .45992 .45843 .46613 .46885 .46277 .46291 .45654 Mtetra
.46291 .45654 .46885 .46277 .47931 .4594 .4734 .45314 Mtetra
.4734 .45314 .47931 .4594 .48981 .45602 .48393 .44973 Mtetra
.48393 .44973 .48981 .45602 .50035 .45262 .4945 .44631 Mtetra
.4945 .44631 .50035 .45262 .51093 .44921 .50511 .44287 Mtetra
.50511 .44287 .51093 .44921 .52156 .44578 .51576 .43942 Mtetra
.51576 .43942 .52156 .44578 .53222 .44234 .52645 .43596 Mtetra
.52645 .43596 .53222 .44234 .54293 .43889 .53718 .43248 Mtetra
.53718 .43248 .54293 .43889 .55368 .43543 .54796 .42899 Mtetra
.54796 .42899 .55368 .43543 .56447 .43195 .55878 .42549 Mtetra
.55878 .42549 .56447 .43195 .5753 .42846 .56964 .42197 Mtetra
.56964 .42197 .5753 .42846 .58617 .42495 .58054 .41844 Mtetra
.58054 .41844 .58617 .42495 .59709 .42143 .59149 .4149 Mtetra
.59149 .4149 .59709 .42143 .60805 .4179 .60247 .41134 Mtetra
.60247 .41134 .60805 .4179 .61906 .41435 .61351 .40776 Mtetra
.61351 .40776 .61906 .41435 .6301 .41079 .62458 .40418 Mtetra
.62458 .40418 .6301 .41079 .64119 .40721 .6357 .40057 Mtetra
.6357 .40057 .64119 .40721 .65233 .40362 .64687 .39696 Mtetra
.64687 .39696 .65233 .40362 .66351 .40002 .65808 .39333 Mtetra
.65808 .39333 .66351 .40002 .67473 .3964 .66933 .38968 Mtetra
.66933 .38968 .67473 .3964 .686 .39277 .68063 .38602 Mtetra
.68063 .38602 .686 .39277 .69731 .38912 .69198 .38235 Mtetra
.69198 .38235 .69731 .38912 .70867 .38546 .70336 .37866 Mtetra
.70336 .37866 .70867 .38546 .72007 .38178 .7148 .37496 Mtetra
.7148 .37496 .72007 .38178 .73152 .37809 .72628 .37124 Mtetra
.72628 .37124 .73152 .37809 .74302 .37439 .73781 .3675 Mtetra
.73781 .3675 .74302 .37439 .75456 .37067 .74939 .36376 Mtetra
.74939 .36376 .75456 .37067 .76615 .36693 .76101 .35999 Mtetra
.76101 .35999 .76615 .36693 .77779 .36318 .77268 .35621 Mtetra
.77268 .35621 .77779 .36318 .78947 .35941 .78439 .35242 Mtetra
.78439 .35242 .78947 .35941 .8012 .35563 .79616 .34861 Mtetra
.79616 .34861 .8012 .35563 .81298 .35183 .80797 .34478 Mtetra
.80797 .34478 .81298 .35183 .82481 .34802 .81983 .34094 Mtetra
.81983 .34094 .82481 .34802 .83668 .34419 .83174 .33708 Mtetra
.83174 .33708 .83668 .34419 .84861 .34035 .8437 .33321 Mtetra
.20671 .53168 .21326 .53739 .2228 .5343 .21628 .52857 Mtetra
.21628 .52857 .2228 .5343 .23238 .5312 .22588 .52544 Mtetra
.22588 .52544 .23238 .5312 .242 .52809 .23551 .52231 Mtetra
.23551 .52231 .242 .52809 .25165 .52496 .24519 .51916 Mtetra
.24519 .51916 .25165 .52496 .26134 .52182 .25489 .516 Mtetra
.25489 .516 .26134 .52182 .27106 .51867 .26464 .51283 Mtetra
.26464 .51283 .27106 .51867 .28082 .51551 .27442 .50965 Mtetra
.27442 .50965 .28082 .51551 .29062 .51234 .28424 .50645 Mtetra
.28424 .50645 .29062 .51234 .30045 .50916 .29409 .50324 Mtetra
.29409 .50324 .30045 .50916 .31032 .50596 .30398 .50003 Mtetra
.30398 .50003 .31032 .50596 .32022 .50275 .31391 .4968 Mtetra
.31391 .4968 .32022 .50275 .33017 .49953 .32388 .49355 Mtetra
.32388 .49355 .33017 .49953 .34015 .4963 .33388 .4903 Mtetra
.33388 .4903 .34015 .4963 .35017 .49305 .34392 .48703 Mtetra
.34392 .48703 .35017 .49305 .36022 .4898 .354 .48375 Mtetra
.354 .48375 .36022 .4898 .37032 .48653 .36412 .48046 Mtetra
.36412 .48046 .37032 .48653 .38045 .48325 .37428 .47715 Mtetra
.37428 .47715 .38045 .48325 .39062 .47995 .38447 .47384 Mtetra
.38447 .47384 .39062 .47995 .40083 .47664 .3947 .47051 Mtetra
.3947 .47051 .40083 .47664 .41108 .47333 .40498 .46716 Mtetra
.40498 .46716 .41108 .47333 .42137 .46999 .41529 .46381 Mtetra
.41529 .46381 .42137 .46999 .43169 .46665 .42564 .46044 Mtetra
.42564 .46044 .43169 .46665 .44206 .46329 .43603 .45706 Mtetra
.43603 .45706 .44206 .46329 .45247 .45992 .44647 .45366 Mtetra
.44647 .45366 .45247 .45992 .46291 .45654 .45694 .45026 Mtetra
.45694 .45026 .46291 .45654 .4734 .45314 .46745 .44684 Mtetra
.46745 .44684 .4734 .45314 .48393 .44973 .47801 .4434 Mtetra
.47801 .4434 .48393 .44973 .4945 .44631 .4886 .43995 Mtetra
.4886 .43995 .4945 .44631 .50511 .44287 .49924 .43649 Mtetra
.49924 .43649 .50511 .44287 .51576 .43942 .50991 .43302 Mtetra
.50991 .43302 .51576 .43942 .52645 .43596 .52063 .42953 Mtetra
.52063 .42953 .52645 .43596 .53718 .43248 .53139 .42603 Mtetra
.53139 .42603 .53718 .43248 .54796 .42899 .5422 .42251 Mtetra
.5422 .42251 .54796 .42899 .55878 .42549 .55304 .41899 Mtetra
.55304 .41899 .55878 .42549 .56964 .42197 .56393 .41544 Mtetra
.56393 .41544 .56964 .42197 .58054 .41844 .57486 .41189 Mtetra
.57486 .41189 .58054 .41844 .59149 .4149 .58584 .40831 Mtetra
.58584 .40831 .59149 .4149 .60247 .41134 .59686 .40473 Mtetra
.59686 .40473 .60247 .41134 .61351 .40776 .60792 .40113 Mtetra
.60792 .40113 .61351 .40776 .62458 .40418 .61902 .39752 Mtetra
.61902 .39752 .62458 .40418 .6357 .40057 .63017 .39389 Mtetra
.63017 .39389 .6357 .40057 .64687 .39696 .64137 .39025 Mtetra
.64137 .39025 .64687 .39696 .65808 .39333 .65261 .38659 Mtetra
.65261 .38659 .65808 .39333 .66933 .38968 .66389 .38292 Mtetra
.66389 .38292 .66933 .38968 .68063 .38602 .67522 .37923 Mtetra
.67522 .37923 .68063 .38602 .69198 .38235 .6866 .37553 Mtetra
.6866 .37553 .69198 .38235 .70336 .37866 .69802 .37181 Mtetra
.69802 .37181 .70336 .37866 .7148 .37496 .70949 .36808 Mtetra
.70949 .36808 .7148 .37496 .72628 .37124 .721 .36433 Mtetra
.721 .36433 .72628 .37124 .73781 .3675 .73256 .36057 Mtetra
.73256 .36057 .73781 .3675 .74939 .36376 .74417 .35679 Mtetra
.74417 .35679 .74939 .36376 .76101 .35999 .75583 .353 Mtetra
.75583 .353 .76101 .35999 .77268 .35621 .76753 .34919 Mtetra
.76753 .34919 .77268 .35621 .78439 .35242 .77928 .34537 Mtetra
.77928 .34537 .78439 .35242 .79616 .34861 .79108 .34153 Mtetra
.79108 .34153 .79616 .34861 .80797 .34478 .80293 .33768 Mtetra
.80293 .33768 .80797 .34478 .81983 .34094 .81482 .33381 Mtetra
.81482 .33381 .81983 .34094 .83174 .33708 .82677 .32992 Mtetra
.82677 .32992 .83174 .33708 .8437 .33321 .83876 .32602 Mtetra
.20012 .52592 .20671 .53168 .21628 .52857 .2097 .52279 Mtetra
.2097 .52279 .21628 .52857 .22588 .52544 .21932 .51964 Mtetra
.21932 .51964 .22588 .52544 .23551 .52231 .22898 .51649 Mtetra
.22898 .51649 .23551 .52231 .24519 .51916 .23867 .51332 Mtetra
.23867 .51332 .24519 .51916 .25489 .516 .2484 .51014 Mtetra
.2484 .51014 .25489 .516 .26464 .51283 .25817 .50694 Mtetra
.25817 .50694 .26464 .51283 .27442 .50965 .26797 .50374 Mtetra
.26797 .50374 .27442 .50965 .28424 .50645 .27781 .50052 Mtetra
.27781 .50052 .28424 .50645 .29409 .50324 .28769 .49729 Mtetra
.28769 .49729 .29409 .50324 .30398 .50003 .2976 .49405 Mtetra
.2976 .49405 .30398 .50003 .31391 .4968 .30755 .4908 Mtetra
.30755 .4908 .31391 .4968 .32388 .49355 .31754 .48753 Mtetra
.31754 .48753 .32388 .49355 .33388 .4903 .32757 .48426 Mtetra
.32757 .48426 .33388 .4903 .34392 .48703 .33763 .48097 Mtetra
.33763 .48097 .34392 .48703 .354 .48375 .34774 .47766 Mtetra
.34774 .47766 .354 .48375 .36412 .48046 .35788 .47435 Mtetra
.35788 .47435 .36412 .48046 .37428 .47715 .36806 .47102 Mtetra
.36806 .47102 .37428 .47715 .38447 .47384 .37828 .46768 Mtetra
.37828 .46768 .38447 .47384 .3947 .47051 .38854 .46433 Mtetra
.38854 .46433 .3947 .47051 .40498 .46716 .39883 .46096 Mtetra
.39883 .46096 .40498 .46716 .41529 .46381 .40917 .45758 Mtetra
.40917 .45758 .41529 .46381 .42564 .46044 .41955 .45419 Mtetra
.41955 .45419 .42564 .46044 .43603 .45706 .42996 .45078 Mtetra
.42996 .45078 .43603 .45706 .44647 .45366 .44042 .44736 Mtetra
.44042 .44736 .44647 .45366 .45694 .45026 .45092 .44393 Mtetra
.45092 .44393 .45694 .45026 .46745 .44684 .46146 .44049 Mtetra
.46146 .44049 .46745 .44684 .47801 .4434 .47204 .43703 Mtetra
.47204 .43703 .47801 .4434 .4886 .43995 .48266 .43355 Mtetra
.48266 .43355 .4886 .43995 .49924 .43649 .49332 .43007 Mtetra
.49332 .43007 .49924 .43649 .50991 .43302 .50403 .42657 Mtetra
.50403 .42657 .50991 .43302 .52063 .42953 .51477 .42306 Mtetra
.51477 .42306 .52063 .42953 .53139 .42603 .52556 .41953 Mtetra
.52556 .41953 .53139 .42603 .5422 .42251 .53639 .41599 Mtetra
.53639 .41599 .5422 .42251 .55304 .41899 .54727 .41243 Mtetra
.54727 .41243 .55304 .41899 .56393 .41544 .55818 .40886 Mtetra
.55818 .40886 .56393 .41544 .57486 .41189 .56914 .40528 Mtetra
.56914 .40528 .57486 .41189 .58584 .40831 .58015 .40168 Mtetra
.58015 .40168 .58584 .40831 .59686 .40473 .5912 .39807 Mtetra
.5912 .39807 .59686 .40473 .60792 .40113 .60229 .39445 Mtetra
.60229 .39445 .60792 .40113 .61902 .39752 .61342 .39081 Mtetra
.61342 .39081 .61902 .39752 .63017 .39389 .6246 .38715 Mtetra
.6246 .38715 .63017 .39389 .64137 .39025 .63583 .38348 Mtetra
.63583 .38348 .64137 .39025 .65261 .38659 .6471 .3798 Mtetra
.6471 .3798 .65261 .38659 .66389 .38292 .65841 .3761 Mtetra
.65841 .3761 .66389 .38292 .67522 .37923 .66977 .37238 Mtetra
.66977 .37238 .67522 .37923 .6866 .37553 .68118 .36866 Mtetra
.68118 .36866 .6866 .37553 .69802 .37181 .69263 .36491 Mtetra
.69263 .36491 .69802 .37181 .70949 .36808 .70413 .36115 Mtetra
.70413 .36115 .70949 .36808 .721 .36433 .71568 .35738 Mtetra
.71568 .35738 .721 .36433 .73256 .36057 .72727 .35359 Mtetra
.72727 .35359 .73256 .36057 .74417 .35679 .73892 .34978 Mtetra
.73892 .34978 .74417 .35679 .75583 .353 .7506 .34596 Mtetra
.7506 .34596 .75583 .353 .76753 .34919 .76234 .34212 Mtetra
.76234 .34212 .76753 .34919 .77928 .34537 .77412 .33827 Mtetra
.77412 .33827 .77928 .34537 .79108 .34153 .78596 .3344 Mtetra
.78596 .3344 .79108 .34153 .80293 .33768 .79784 .33052 Mtetra
.79784 .33052 .80293 .33768 .81482 .33381 .80977 .32662 Mtetra
.80977 .32662 .81482 .33381 .82677 .32992 .82175 .3227 Mtetra
.82175 .3227 .82677 .32992 .83876 .32602 .83378 .31877 Mtetra
.19348 .52013 .20012 .52592 .2097 .52279 .20308 .51697 Mtetra
.20308 .51697 .2097 .52279 .21932 .51964 .21272 .51381 Mtetra
.21272 .51381 .21932 .51964 .22898 .51649 .2224 .51063 Mtetra
.2224 .51063 .22898 .51649 .23867 .51332 .23212 .50744 Mtetra
.23212 .50744 .23867 .51332 .2484 .51014 .24187 .50423 Mtetra
.24187 .50423 .2484 .51014 .25817 .50694 .25166 .50102 Mtetra
.25166 .50102 .25817 .50694 .26797 .50374 .26148 .49779 Mtetra
.26148 .49779 .26797 .50374 .27781 .50052 .27134 .49455 Mtetra
.27134 .49455 .27781 .50052 .28769 .49729 .28124 .4913 Mtetra
.28124 .4913 .28769 .49729 .2976 .49405 .29118 .48804 Mtetra
.29118 .48804 .2976 .49405 .30755 .4908 .30115 .48476 Mtetra
.30115 .48476 .30755 .4908 .31754 .48753 .31116 .48147 Mtetra
.31116 .48147 .31754 .48753 .32757 .48426 .32121 .47817 Mtetra
.32121 .47817 .32757 .48426 .33763 .48097 .3313 .47486 Mtetra
.3313 .47486 .33763 .48097 .34774 .47766 .34143 .47153 Mtetra
.34143 .47153 .34774 .47766 .35788 .47435 .35159 .46819 Mtetra
.35159 .46819 .35788 .47435 .36806 .47102 .3618 .46484 Mtetra
.3618 .46484 .36806 .47102 .37828 .46768 .37204 .46148 Mtetra
.37204 .46148 .37828 .46768 .38854 .46433 .38232 .4581 Mtetra
.38232 .4581 .38854 .46433 .39883 .46096 .39264 .45471 Mtetra
.39264 .45471 .39883 .46096 .40917 .45758 .40301 .45131 Mtetra
.40301 .45131 .40917 .45758 .41955 .45419 .41341 .44789 Mtetra
.41341 .44789 .41955 .45419 .42996 .45078 .42385 .44446 Mtetra
.42385 .44446 .42996 .45078 .44042 .44736 .43434 .44102 Mtetra
.43434 .44102 .44042 .44736 .45092 .44393 .44486 .43756 Mtetra
.44486 .43756 .45092 .44393 .46146 .44049 .45542 .43409 Mtetra
.45542 .43409 .46146 .44049 .47204 .43703 .46603 .43061 Mtetra
.46603 .43061 .47204 .43703 .48266 .43355 .47668 .42711 Mtetra
.47668 .42711 .48266 .43355 .49332 .43007 .48737 .4236 Mtetra
.48737 .4236 .49332 .43007 .50403 .42657 .4981 .42007 Mtetra
.4981 .42007 .50403 .42657 .51477 .42306 .50887 .41653 Mtetra
.50887 .41653 .51477 .42306 .52556 .41953 .51969 .41298 Mtetra
.51969 .41298 .52556 .41953 .53639 .41599 .53055 .40941 Mtetra
.53055 .40941 .53639 .41599 .54727 .41243 .54145 .40583 Mtetra
.54145 .40583 .54727 .41243 .55818 .40886 .5524 .40224 Mtetra
.5524 .40224 .55818 .40886 .56914 .40528 .56338 .39863 Mtetra
.56338 .39863 .56914 .40528 .58015 .40168 .57442 .39501 Mtetra
.57442 .39501 .58015 .40168 .5912 .39807 .58549 .39137 Mtetra
.58549 .39137 .5912 .39807 .60229 .39445 .59661 .38772 Mtetra
.59661 .38772 .60229 .39445 .61342 .39081 .60778 .38405 Mtetra
.60778 .38405 .61342 .39081 .6246 .38715 .61899 .38037 Mtetra
.61899 .38037 .6246 .38715 .63583 .38348 .63025 .37667 Mtetra
.63025 .37667 .63583 .38348 .6471 .3798 .64155 .37296 Mtetra
.64155 .37296 .6471 .3798 .65841 .3761 .65289 .36923 Mtetra
.65289 .36923 .65841 .3761 .66977 .37238 .66429 .36549 Mtetra
.66429 .36549 .66977 .37238 .68118 .36866 .67572 .36173 Mtetra
.67572 .36173 .68118 .36866 .69263 .36491 .68721 .35796 Mtetra
.68721 .35796 .69263 .36491 .70413 .36115 .69874 .35417 Mtetra
.69874 .35417 .70413 .36115 .71568 .35738 .71032 .35037 Mtetra
.71032 .35037 .71568 .35738 .72727 .35359 .72195 .34655 Mtetra
.72195 .34655 .72727 .35359 .73892 .34978 .73362 .34271 Mtetra
.73362 .34271 .73892 .34978 .7506 .34596 .74534 .33886 Mtetra
.74534 .33886 .7506 .34596 .76234 .34212 .75711 .335 Mtetra
.75711 .335 .76234 .34212 .77412 .33827 .76893 .33112 Mtetra
.76893 .33112 .77412 .33827 .78596 .3344 .7808 .32722 Mtetra
.7808 .32722 .78596 .3344 .79784 .33052 .79272 .3233 Mtetra
.79272 .3233 .79784 .33052 .80977 .32662 .80468 .31937 Mtetra
.80468 .31937 .80977 .32662 .82175 .3227 .8167 .31543 Mtetra
.8167 .31543 .82175 .3227 .83378 .31877 .82876 .31146 Mtetra
.18679 .51429 .19348 .52013 .20308 .51697 .19642 .51112 Mtetra
.19642 .51112 .20308 .51697 .21272 .51381 .20608 .50793 Mtetra
.20608 .50793 .21272 .51381 .2224 .51063 .21578 .50473 Mtetra
.21578 .50473 .2224 .51063 .23212 .50744 .22552 .50151 Mtetra
.22552 .50151 .23212 .50744 .24187 .50423 .23529 .49829 Mtetra
.23529 .49829 .24187 .50423 .25166 .50102 .2451 .49505 Mtetra
.2451 .49505 .25166 .50102 .26148 .49779 .25495 .4918 Mtetra
.25495 .4918 .26148 .49779 .27134 .49455 .26483 .48854 Mtetra
.26483 .48854 .27134 .49455 .28124 .4913 .27475 .48526 Mtetra
.27475 .48526 .28124 .4913 .29118 .48804 .28471 .48198 Mtetra
.28471 .48198 .29118 .48804 .30115 .48476 .2947 .47868 Mtetra
.2947 .47868 .30115 .48476 .31116 .48147 .30474 .47537 Mtetra
.30474 .47537 .31116 .48147 .32121 .47817 .31481 .47204 Mtetra
.31481 .47204 .32121 .47817 .3313 .47486 .32492 .46871 Mtetra
.32492 .46871 .3313 .47486 .34143 .47153 .33507 .46536 Mtetra
.33507 .46536 .34143 .47153 .35159 .46819 .34526 .46199 Mtetra
.34526 .46199 .35159 .46819 .3618 .46484 .35549 .45862 Mtetra
.35549 .45862 .3618 .46484 .37204 .46148 .36576 .45523 Mtetra
.36576 .45523 .37204 .46148 .38232 .4581 .37607 .45183 Mtetra
.37607 .45183 .38232 .4581 .39264 .45471 .38641 .44841 Mtetra
.38641 .44841 .39264 .45471 .40301 .45131 .3968 .44499 Mtetra
.3968 .44499 .40301 .45131 .41341 .44789 .40723 .44155 Mtetra
.40723 .44155 .41341 .44789 .42385 .44446 .4177 .43809 Mtetra
.4177 .43809 .42385 .44446 .43434 .44102 .4282 .43462 Mtetra
.4282 .43462 .43434 .44102 .44486 .43756 .43875 .43114 Mtetra
.43875 .43114 .44486 .43756 .45542 .43409 .44934 .42765 Mtetra
.44934 .42765 .45542 .43409 .46603 .43061 .45998 .42414 Mtetra
.45998 .42414 .46603 .43061 .47668 .42711 .47065 .42062 Mtetra
.47065 .42062 .47668 .42711 .48737 .4236 .48137 .41708 Mtetra
.48137 .41708 .48737 .4236 .4981 .42007 .49213 .41353 Mtetra
.49213 .41353 .4981 .42007 .50887 .41653 .50293 .40996 Mtetra
.50293 .40996 .50887 .41653 .51969 .41298 .51377 .40638 Mtetra
.51377 .40638 .51969 .41298 .53055 .40941 .52466 .40279 Mtetra
.52466 .40279 .53055 .40941 .54145 .40583 .53559 .39918 Mtetra
.53559 .39918 .54145 .40583 .5524 .40224 .54656 .39556 Mtetra
.54656 .39556 .5524 .40224 .56338 .39863 .55758 .39193 Mtetra
.55758 .39193 .56338 .39863 .57442 .39501 .56864 .38828 Mtetra
.56864 .38828 .57442 .39501 .58549 .39137 .57975 .38461 Mtetra
.57975 .38461 .58549 .39137 .59661 .38772 .5909 .38093 Mtetra
.5909 .38093 .59661 .38772 .60778 .38405 .6021 .37724 Mtetra
.6021 .37724 .60778 .38405 .61899 .38037 .61334 .37353 Mtetra
.61334 .37353 .61899 .38037 .63025 .37667 .62462 .3698 Mtetra
.62462 .3698 .63025 .37667 .64155 .37296 .63595 .36606 Mtetra
.63595 .36606 .64155 .37296 .65289 .36923 .64733 .36231 Mtetra
.64733 .36231 .65289 .36923 .66429 .36549 .65875 .35854 Mtetra
.65875 .35854 .66429 .36549 .67572 .36173 .67023 .35475 Mtetra
.67023 .35475 .67572 .36173 .68721 .35796 .68174 .35095 Mtetra
.68174 .35095 .68721 .35796 .69874 .35417 .69331 .34713 Mtetra
.69331 .34713 .69874 .35417 .71032 .35037 .70492 .3433 Mtetra
.70492 .3433 .71032 .35037 .72195 .34655 .71658 .33945 Mtetra
.71658 .33945 .72195 .34655 .73362 .34271 .72828 .33559 Mtetra
.72828 .33559 .73362 .34271 .74534 .33886 .74004 .33171 Mtetra
.74004 .33171 .74534 .33886 .75711 .335 .75184 .32782 Mtetra
.75184 .32782 .75711 .335 .76893 .33112 .7637 .32391 Mtetra
.7637 .32391 .76893 .33112 .7808 .32722 .7756 .31998 Mtetra
.7756 .31998 .7808 .32722 .79272 .3233 .78755 .31604 Mtetra
.78755 .31604 .79272 .3233 .80468 .31937 .79955 .31208 Mtetra
.79955 .31208 .80468 .31937 .8167 .31543 .8116 .3081 Mtetra
.8116 .3081 .8167 .31543 .82876 .31146 .82371 .3041 Mtetra
.18006 .50842 .18679 .51429 .19642 .51112 .18971 .50522 Mtetra
.18971 .50522 .19642 .51112 .20608 .50793 .19939 .50202 Mtetra
.656 .752 .92 r
.19939 .50202 .20608 .50793 .21578 .50473 .20911 .49879 Mtetra
.20911 .49879 .21578 .50473 .22552 .50151 .21887 .49556 Mtetra
.21887 .49556 .22552 .50151 .23529 .49829 .22866 .49231 Mtetra
.22866 .49231 .23529 .49829 .2451 .49505 .23849 .48905 Mtetra
.23849 .48905 .2451 .49505 .25495 .4918 .24836 .48578 Mtetra
.24836 .48578 .25495 .4918 .26483 .48854 .25827 .48249 Mtetra
.25827 .48249 .26483 .48854 .27475 .48526 .26821 .47919 Mtetra
.26821 .47919 .27475 .48526 .28471 .48198 .27819 .47588 Mtetra
.27819 .47588 .28471 .48198 .2947 .47868 .28821 .47256 Mtetra
.28821 .47256 .2947 .47868 .30474 .47537 .29827 .46922 Mtetra
.29827 .46922 .30474 .47537 .31481 .47204 .30837 .46588 Mtetra
.30837 .46588 .31481 .47204 .32492 .46871 .3185 .46251 Mtetra
.656 .751 .92 r
.3185 .46251 .32492 .46871 .33507 .46536 .32867 .45914 Mtetra
.32867 .45914 .33507 .46536 .34526 .46199 .33889 .45575 Mtetra
.33889 .45575 .34526 .46199 .35549 .45862 .34914 .45235 Mtetra
.34914 .45235 .35549 .45862 .36576 .45523 .35943 .44894 Mtetra
.35943 .44894 .36576 .45523 .37607 .45183 .36976 .44552 Mtetra
.36976 .44552 .37607 .45183 .38641 .44841 .38013 .44208 Mtetra
.38013 .44208 .38641 .44841 .3968 .44499 .39055 .43862 Mtetra
.39055 .43862 .3968 .44499 .40723 .44155 .401 .43516 Mtetra
.401 .43516 .40723 .44155 .4177 .43809 .41149 .43168 Mtetra
.41149 .43168 .4177 .43809 .4282 .43462 .42203 .42819 Mtetra
.42203 .42819 .4282 .43462 .43875 .43114 .4326 .42468 Mtetra
.4326 .42468 .43875 .43114 .44934 .42765 .44322 .42116 Mtetra
.44322 .42116 .44934 .42765 .45998 .42414 .45388 .41762 Mtetra
.45388 .41762 .45998 .42414 .47065 .42062 .46458 .41408 Mtetra
.46458 .41408 .47065 .42062 .48137 .41708 .47533 .41051 Mtetra
.47533 .41051 .48137 .41708 .49213 .41353 .48611 .40694 Mtetra
.48611 .40694 .49213 .41353 .50293 .40996 .49694 .40335 Mtetra
.49694 .40335 .50293 .40996 .51377 .40638 .50781 .39974 Mtetra
.50781 .39974 .51377 .40638 .52466 .40279 .51873 .39612 Mtetra
.51873 .39612 .52466 .40279 .53559 .39918 .52969 .39249 Mtetra
.52969 .39249 .53559 .39918 .54656 .39556 .54069 .38884 Mtetra
.54069 .38884 .54656 .39556 .55758 .39193 .55174 .38518 Mtetra
.55174 .38518 .55758 .39193 .56864 .38828 .56283 .3815 Mtetra
.56283 .3815 .56864 .38828 .57975 .38461 .57396 .37781 Mtetra
.57396 .37781 .57975 .38461 .5909 .38093 .58514 .3741 Mtetra
.58514 .3741 .5909 .38093 .6021 .37724 .59637 .37038 Mtetra
.59637 .37038 .6021 .37724 .61334 .37353 .60764 .36664 Mtetra
.60764 .36664 .61334 .37353 .62462 .3698 .61896 .36289 Mtetra
.61896 .36289 .62462 .3698 .63595 .36606 .63032 .35912 Mtetra
.63032 .35912 .63595 .36606 .64733 .36231 .64173 .35534 Mtetra
.64173 .35534 .64733 .36231 .65875 .35854 .65318 .35154 Mtetra
.65318 .35154 .65875 .35854 .67023 .35475 .66469 .34773 Mtetra
.656 .752 .92 r
.66469 .34773 .67023 .35475 .68174 .35095 .67623 .3439 Mtetra
.67623 .3439 .68174 .35095 .69331 .34713 .68783 .34005 Mtetra
.68783 .34005 .69331 .34713 .70492 .3433 .69948 .33619 Mtetra
.69948 .33619 .70492 .3433 .71658 .33945 .71117 .33232 Mtetra
.71117 .33232 .71658 .33945 .72828 .33559 .72291 .32842 Mtetra
.72291 .32842 .72828 .33559 .74004 .33171 .7347 .32452 Mtetra
.7347 .32452 .74004 .33171 .75184 .32782 .74654 .32059 Mtetra
.656 .752 .921 r
.74654 .32059 .75184 .32782 .7637 .32391 .75842 .31665 Mtetra
.75842 .31665 .7637 .32391 .7756 .31998 .77036 .31269 Mtetra
.77036 .31269 .7756 .31998 .78755 .31604 .78235 .30872 Mtetra
.656 .752 .92 r
.78235 .30872 .78755 .31604 .79955 .31208 .79439 .30473 Mtetra
.79439 .30473 .79955 .31208 .8116 .3081 .80647 .30072 Mtetra
.80647 .30072 .8116 .3081 .82371 .3041 .81861 .29669 Mtetra
.655 .751 .92 r
.17328 .5025 .18006 .50842 .18971 .50522 .18295 .49929 Mtetra
.655 .752 .921 r
.18295 .49929 .18971 .50522 .19939 .50202 .19265 .49607 Mtetra
.656 .752 .921 r
.19265 .49607 .19939 .50202 .20911 .49879 .20239 .49283 Mtetra
.20239 .49283 .20911 .49879 .21887 .49556 .21217 .48957 Mtetra
.21217 .48957 .21887 .49556 .22866 .49231 .22199 .4863 Mtetra
.22199 .4863 .22866 .49231 .23849 .48905 .23184 .48301 Mtetra
.656 .752 .92 r
.23184 .48301 .23849 .48905 .24836 .48578 .24173 .47971 Mtetra
.24173 .47971 .24836 .48578 .25827 .48249 .25166 .4764 Mtetra
.25166 .4764 .25827 .48249 .26821 .47919 .26163 .47307 Mtetra
.656 .751 .92 r
.26163 .47307 .26821 .47919 .27819 .47588 .27163 .46973 Mtetra
.27163 .46973 .27819 .47588 .28821 .47256 .28167 .46639 Mtetra
.28167 .46639 .28821 .47256 .29827 .46922 .29175 .46302 Mtetra
.29175 .46302 .29827 .46922 .30837 .46588 .30187 .45965 Mtetra
.30187 .45965 .30837 .46588 .3185 .46251 .31203 .45627 Mtetra
.31203 .45627 .3185 .46251 .32867 .45914 .32223 .45287 Mtetra
.32223 .45287 .32867 .45914 .33889 .45575 .33247 .44946 Mtetra
.33247 .44946 .33889 .45575 .34914 .45235 .34274 .44603 Mtetra
.34274 .44603 .34914 .45235 .35943 .44894 .35306 .44259 Mtetra
.35306 .44259 .35943 .44894 .36976 .44552 .36342 .43914 Mtetra
.36342 .43914 .36976 .44552 .38013 .44208 .37381 .43568 Mtetra
.37381 .43568 .38013 .44208 .39055 .43862 .38425 .4322 Mtetra
.38425 .4322 .39055 .43862 .401 .43516 .39473 .42871 Mtetra
.39473 .42871 .401 .43516 .41149 .43168 .40525 .42521 Mtetra
.40525 .42521 .41149 .43168 .42203 .42819 .41581 .42169 Mtetra
.41581 .42169 .42203 .42819 .4326 .42468 .42641 .41816 Mtetra
.42641 .41816 .4326 .42468 .44322 .42116 .43705 .41461 Mtetra
.43705 .41461 .44322 .42116 .45388 .41762 .44774 .41105 Mtetra
.44774 .41105 .45388 .41762 .46458 .41408 .45847 .40748 Mtetra
.45847 .40748 .46458 .41408 .47533 .41051 .46924 .40389 Mtetra
.46924 .40389 .47533 .41051 .48611 .40694 .48005 .40029 Mtetra
.48005 .40029 .48611 .40694 .49694 .40335 .49091 .39667 Mtetra
.49091 .39667 .49694 .40335 .50781 .39974 .50181 .39304 Mtetra
.50181 .39304 .50781 .39974 .51873 .39612 .51275 .38939 Mtetra
.51275 .38939 .51873 .39612 .52969 .39249 .52374 .38573 Mtetra
.52374 .38573 .52969 .39249 .54069 .38884 .53477 .38206 Mtetra
.53477 .38206 .54069 .38884 .55174 .38518 .54585 .37837 Mtetra
.54585 .37837 .55174 .38518 .56283 .3815 .55697 .37466 Mtetra
.55697 .37466 .56283 .3815 .57396 .37781 .56813 .37094 Mtetra
.56813 .37094 .57396 .37781 .58514 .3741 .57934 .3672 Mtetra
.57934 .3672 .58514 .3741 .59637 .37038 .5906 .36345 Mtetra
.5906 .36345 .59637 .37038 .60764 .36664 .6019 .35969 Mtetra
.6019 .35969 .60764 .36664 .61896 .36289 .61325 .35591 Mtetra
.61325 .35591 .61896 .36289 .63032 .35912 .62464 .35211 Mtetra
.62464 .35211 .63032 .35912 .64173 .35534 .63608 .3483 Mtetra
.63608 .3483 .64173 .35534 .65318 .35154 .64757 .34447 Mtetra
.64757 .34447 .65318 .35154 .66469 .34773 .6591 .34063 Mtetra
.6591 .34063 .66469 .34773 .67623 .3439 .67068 .33678 Mtetra
.67068 .33678 .67623 .3439 .68783 .34005 .68231 .33291 Mtetra
.68231 .33291 .68783 .34005 .69948 .33619 .69399 .32902 Mtetra
.69399 .32902 .69948 .33619 .71117 .33232 .70572 .32512 Mtetra
.70572 .32512 .71117 .33232 .72291 .32842 .71749 .3212 Mtetra
.71749 .3212 .72291 .32842 .7347 .32452 .72932 .31726 Mtetra
.656 .752 .921 r
.72932 .31726 .7347 .32452 .74654 .32059 .74119 .31331 Mtetra
.74119 .31331 .74654 .32059 .75842 .31665 .75311 .30935 Mtetra
.75311 .30935 .75842 .31665 .77036 .31269 .76508 .30536 Mtetra
.76508 .30536 .77036 .31269 .78235 .30872 .77711 .30135 Mtetra
.77711 .30135 .78235 .30872 .79439 .30473 .78918 .29733 Mtetra
.78918 .29733 .79439 .30473 .80647 .30072 .8013 .29328 Mtetra
.656 .752 .92 r
.8013 .29328 .80647 .30072 .81861 .29669 .81347 .28921 Mtetra
.654 .751 .921 r
.16646 .49655 .17328 .5025 .18295 .49929 .17614 .49335 Mtetra
.654 .752 .922 r
.17614 .49335 .18295 .49929 .19265 .49607 .18586 .49013 Mtetra
.655 .753 .922 r
.18586 .49013 .19265 .49607 .20239 .49283 .19563 .48688 Mtetra
.655 .754 .923 r
.19563 .48688 .20239 .49283 .21217 .48957 .20542 .48362 Mtetra
.655 .755 .923 r
.20542 .48362 .21217 .48957 .22199 .4863 .21526 .48033 Mtetra
.656 .755 .923 r
.21526 .48033 .22199 .4863 .23184 .48301 .22514 .47702 Mtetra
.22514 .47702 .23184 .48301 .24173 .47971 .23505 .4737 Mtetra
.23505 .4737 .24173 .47971 .25166 .4764 .245 .47035 Mtetra
.656 .755 .922 r
.245 .47035 .25166 .4764 .26163 .47307 .25499 .467 Mtetra
.25499 .467 .26163 .47307 .27163 .46973 .26502 .46363 Mtetra
.656 .754 .922 r
.26502 .46363 .27163 .46973 .28167 .46639 .27508 .46025 Mtetra
.27508 .46025 .28167 .46639 .29175 .46302 .28519 .45686 Mtetra
.28519 .45686 .29175 .46302 .30187 .45965 .29533 .45345 Mtetra
.656 .753 .922 r
.29533 .45345 .30187 .45965 .31203 .45627 .30551 .45004 Mtetra
.656 .753 .921 r
.30551 .45004 .31203 .45627 .32223 .45287 .31574 .44661 Mtetra
.31574 .44661 .32223 .45287 .33247 .44946 .326 .44317 Mtetra
.326 .44317 .33247 .44946 .34274 .44603 .3363 .43971 Mtetra
.3363 .43971 .34274 .44603 .35306 .44259 .34664 .43625 Mtetra
.656 .752 .921 r
.34664 .43625 .35306 .44259 .36342 .43914 .35702 .43277 Mtetra
.35702 .43277 .36342 .43914 .37381 .43568 .36744 .42928 Mtetra
.36744 .42928 .37381 .43568 .38425 .4322 .37791 .42577 Mtetra
.37791 .42577 .38425 .4322 .39473 .42871 .38841 .42225 Mtetra
.38841 .42225 .39473 .42871 .40525 .42521 .39896 .41872 Mtetra
.39896 .41872 .40525 .42521 .41581 .42169 .40954 .41518 Mtetra
.40954 .41518 .41581 .42169 .42641 .41816 .42017 .41162 Mtetra
.42017 .41162 .42641 .41816 .43705 .41461 .43084 .40804 Mtetra
.43084 .40804 .43705 .41461 .44774 .41105 .44155 .40446 Mtetra
.44155 .40446 .44774 .41105 .45847 .40748 .45231 .40086 Mtetra
.45231 .40086 .45847 .40748 .46924 .40389 .46311 .39724 Mtetra
.46311 .39724 .46924 .40389 .48005 .40029 .47395 .39361 Mtetra
.47395 .39361 .48005 .40029 .49091 .39667 .48483 .38997 Mtetra
.48483 .38997 .49091 .39667 .50181 .39304 .49576 .38631 Mtetra
.49576 .38631 .50181 .39304 .51275 .38939 .50673 .38264 Mtetra
.50673 .38264 .51275 .38939 .52374 .38573 .51775 .37895 Mtetra
.51775 .37895 .52374 .38573 .53477 .38206 .52881 .37525 Mtetra
.52881 .37525 .53477 .38206 .54585 .37837 .53991 .37153 Mtetra
.53991 .37153 .54585 .37837 .55697 .37466 .55106 .3678 Mtetra
.55106 .3678 .55697 .37466 .56813 .37094 .56226 .36406 Mtetra
.56226 .36406 .56813 .37094 .57934 .3672 .5735 .3603 Mtetra
.5735 .3603 .57934 .3672 .5906 .36345 .58479 .35652 Mtetra
.58479 .35652 .5906 .36345 .6019 .35969 .59612 .35273 Mtetra
.59612 .35273 .6019 .35969 .61325 .35591 .6075 .34892 Mtetra
.656 .753 .921 r
.6075 .34892 .61325 .35591 .62464 .35211 .61892 .34511 Mtetra
.61892 .34511 .62464 .35211 .63608 .3483 .63039 .34127 Mtetra
.655 .753 .921 r
.63039 .34127 .63608 .3483 .64757 .34447 .64191 .33742 Mtetra
.655 .753 .922 r
.64191 .33742 .64757 .34447 .6591 .34063 .65348 .33356 Mtetra
.65348 .33356 .6591 .34063 .67068 .33678 .6651 .32968 Mtetra
.6651 .32968 .67068 .33678 .68231 .33291 .67676 .32579 Mtetra
.655 .754 .922 r
.67676 .32579 .68231 .33291 .69399 .32902 .68847 .32188 Mtetra
.68847 .32188 .69399 .32902 .70572 .32512 .70023 .31795 Mtetra
.655 .754 .923 r
.70023 .31795 .70572 .32512 .71749 .3212 .71204 .31401 Mtetra
.71204 .31401 .71749 .3212 .72932 .31726 .7239 .31005 Mtetra
.655 .755 .923 r
.7239 .31005 .72932 .31726 .74119 .31331 .73581 .30608 Mtetra
.656 .755 .923 r
.73581 .30608 .74119 .31331 .75311 .30935 .74776 .30208 Mtetra
.74776 .30208 .75311 .30935 .76508 .30536 .75977 .29805 Mtetra
.656 .755 .922 r
.75977 .29805 .76508 .30536 .77711 .30135 .77183 .294 Mtetra
.657 .754 .922 r
.77183 .294 .77711 .30135 .78918 .29733 .78393 .28992 Mtetra
.657 .754 .921 r
.78393 .28992 .78918 .29733 .8013 .29328 .79609 .28581 Mtetra
.657 .753 .921 r
.79609 .28581 .8013 .29328 .81347 .28921 .8083 .28168 Mtetra
.651 .75 .922 r
.15958 .49055 .16646 .49655 .17614 .49335 .16928 .4874 Mtetra
.651 .753 .924 r
.16928 .4874 .17614 .49335 .18586 .49013 .17902 .48423 Mtetra
.652 .755 .925 r
.17902 .48423 .18586 .49013 .19563 .48688 .1888 .48101 Mtetra
.653 .758 .926 r
.1888 .48101 .19563 .48688 .20542 .48362 .19861 .47777 Mtetra
.654 .759 .927 r
.19861 .47777 .20542 .48362 .21526 .48033 .20847 .47447 Mtetra
.655 .76 .927 r
.20847 .47447 .21526 .48033 .22514 .47702 .21837 .47115 Mtetra
.656 .76 .927 r
.21837 .47115 .22514 .47702 .23505 .4737 .2283 .46779 Mtetra
.657 .76 .926 r
.2283 .46779 .23505 .4737 .245 .47035 .23828 .46441 Mtetra
.23828 .46441 .245 .47035 .25499 .467 .24829 .46101 Mtetra
.657 .759 .925 r
.24829 .46101 .25499 .467 .26502 .46363 .25835 .45759 Mtetra
.657 .758 .924 r
.25835 .45759 .26502 .46363 .27508 .46025 .26844 .45416 Mtetra
.657 .757 .924 r
.26844 .45416 .27508 .46025 .28519 .45686 .27857 .45072 Mtetra
.657 .756 .923 r
.27857 .45072 .28519 .45686 .29533 .45345 .28874 .44726 Mtetra
.28874 .44726 .29533 .45345 .30551 .45004 .29895 .4438 Mtetra
.657 .755 .922 r
.29895 .4438 .30551 .45004 .31574 .44661 .30919 .44033 Mtetra
.657 .754 .922 r
.30919 .44033 .31574 .44661 .326 .44317 .31948 .43684 Mtetra
.657 .753 .921 r
.31948 .43684 .326 .44317 .3363 .43971 .32981 .43335 Mtetra
.656 .753 .921 r
.32981 .43335 .3363 .43971 .34664 .43625 .34017 .42984 Mtetra
.656 .752 .921 r
.34017 .42984 .34664 .43625 .35702 .43277 .35058 .42633 Mtetra
.656 .752 .92 r
.35058 .42633 .35702 .43277 .36744 .42928 .36103 .4228 Mtetra
.36103 .4228 .36744 .42928 .37791 .42577 .37152 .41927 Mtetra
.656 .751 .92 r
.37152 .41927 .37791 .42577 .38841 .42225 .38205 .41572 Mtetra
.38205 .41572 .38841 .42225 .39896 .41872 .39262 .41215 Mtetra
.39262 .41215 .39896 .41872 .40954 .41518 .40323 .40858 Mtetra
.40323 .40858 .40954 .41518 .42017 .41162 .41389 .40499 Mtetra
.41389 .40499 .42017 .41162 .43084 .40804 .42458 .40139 Mtetra
.42458 .40139 .43084 .40804 .44155 .40446 .43532 .39778 Mtetra
.43532 .39778 .44155 .40446 .45231 .40086 .44611 .39415 Mtetra
.44611 .39415 .45231 .40086 .46311 .39724 .45693 .3905 Mtetra
.45693 .3905 .46311 .39724 .47395 .39361 .4678 .38685 Mtetra
.4678 .38685 .47395 .39361 .48483 .38997 .47871 .38318 Mtetra
.47871 .38318 .48483 .38997 .49576 .38631 .48967 .37949 Mtetra
.48967 .37949 .49576 .38631 .50673 .38264 .50067 .3758 Mtetra
.50067 .3758 .50673 .38264 .51775 .37895 .51171 .37208 Mtetra
.51171 .37208 .51775 .37895 .52881 .37525 .5228 .36836 Mtetra
.5228 .36836 .52881 .37525 .53991 .37153 .53394 .36462 Mtetra
.53394 .36462 .53991 .37153 .55106 .3678 .54512 .36086 Mtetra
.655 .751 .92 r
.54512 .36086 .55106 .3678 .56226 .36406 .55634 .35709 Mtetra
.55634 .35709 .56226 .36406 .5735 .3603 .56761 .35331 Mtetra
.655 .751 .921 r
.56761 .35331 .5735 .3603 .58479 .35652 .57893 .34952 Mtetra
.655 .752 .921 r
.57893 .34952 .58479 .35652 .59612 .35273 .59029 .34571 Mtetra
.59029 .34571 .59612 .35273 .6075 .34892 .6017 .34189 Mtetra
.6017 .34189 .6075 .34892 .61892 .34511 .61316 .33806 Mtetra
.655 .753 .922 r
.61316 .33806 .61892 .34511 .63039 .34127 .62467 .33421 Mtetra
.62467 .33421 .63039 .34127 .64191 .33742 .63622 .33036 Mtetra
.655 .754 .923 r
.63622 .33036 .64191 .33742 .65348 .33356 .64782 .32649 Mtetra
.654 .755 .924 r
.64782 .32649 .65348 .33356 .6651 .32968 .65947 .3226 Mtetra
.654 .756 .924 r
.65947 .3226 .6651 .32968 .67676 .32579 .67117 .31871 Mtetra
.654 .756 .925 r
.67117 .31871 .67676 .32579 .68847 .32188 .68291 .3148 Mtetra
.654 .757 .926 r
.68291 .3148 .68847 .32188 .70023 .31795 .69471 .31087 Mtetra
.654 .758 .926 r
.69471 .31087 .70023 .31795 .71204 .31401 .70655 .30692 Mtetra
.655 .759 .927 r
.70655 .30692 .71204 .31401 .7239 .31005 .71845 .30295 Mtetra
.655 .76 .927 r
.71845 .30295 .7239 .31005 .73581 .30608 .73039 .29895 Mtetra
.656 .76 .927 r
.73039 .29895 .73581 .30608 .74776 .30208 .74239 .29491 Mtetra
.656 .761 .926 r
.74239 .29491 .74776 .30208 .75977 .29805 .75443 .29083 Mtetra
.658 .76 .926 r
.75443 .29083 .75977 .29805 .77183 .294 .76652 .28671 Mtetra
.659 .759 .924 r
.76652 .28671 .77183 .294 .78393 .28992 .77866 .28254 Mtetra
.659 .758 .923 r
.77866 .28254 .78393 .28992 .79609 .28581 .79084 .27834 Mtetra
.66 .756 .921 r
.79084 .27834 .79609 .28581 .8083 .28168 .80308 .27409 Mtetra
.644 .748 .925 r
.15266 .48451 .15958 .49055 .16928 .4874 .16236 .4815 Mtetra
.645 .754 .929 r
.16236 .4815 .16928 .4874 .17902 .48423 .17211 .47845 Mtetra
.646 .76 .932 r
.17211 .47845 .17902 .48423 .1888 .48101 .18189 .47535 Mtetra
.648 .765 .934 r
.18189 .47535 .1888 .48101 .19861 .47777 .19172 .47218 Mtetra
.65 .769 .936 r
.19172 .47218 .19861 .47777 .20847 .47447 .20159 .46895 Mtetra
.652 .772 .937 r
.20159 .46895 .20847 .47447 .21837 .47115 .21151 .46565 Mtetra
.654 .774 .937 r
.21151 .46565 .21837 .47115 .2283 .46779 .22147 .4623 Mtetra
.655 .776 .937 r
.22147 .4623 .2283 .46779 .23828 .46441 .23147 .4589 Mtetra
.656 .776 .937 r
.23147 .4589 .23828 .46441 .24829 .46101 .24151 .45547 Mtetra
.657 .776 .937 r
.24151 .45547 .24829 .46101 .25835 .45759 .25159 .45201 Mtetra
.658 .776 .936 r
.25159 .45201 .25835 .45759 .26844 .45416 .26171 .44852 Mtetra
.658 .775 .935 r
.26171 .44852 .26844 .45416 .27857 .45072 .27186 .44502 Mtetra
.658 .773 .934 r
.27186 .44502 .27857 .45072 .28874 .44726 .28206 .4415 Mtetra
.658 .772 .933 r
.28206 .4415 .28874 .44726 .29895 .4438 .2923 .43797 Mtetra
.658 .771 .933 r
.2923 .43797 .29895 .4438 .30919 .44033 .30257 .43444 Mtetra
.658 .769 .932 r
.30257 .43444 .30919 .44033 .31948 .43684 .31289 .43089 Mtetra
.658 .768 .931 r
.31289 .43089 .31948 .43684 .32981 .43335 .32324 .42734 Mtetra
.657 .767 .93 r
.32324 .42734 .32981 .43335 .34017 .42984 .33364 .42378 Mtetra
.657 .765 .929 r
.33364 .42378 .34017 .42984 .35058 .42633 .34407 .42021 Mtetra
.657 .764 .929 r
.34407 .42021 .35058 .42633 .36103 .4228 .35455 .41663 Mtetra
.657 .763 .928 r
.35455 .41663 .36103 .4228 .37152 .41927 .36507 .41305 Mtetra
.36507 .41305 .37152 .41927 .38205 .41572 .37562 .40945 Mtetra
.656 .762 .927 r
.37562 .40945 .38205 .41572 .39262 .41215 .38622 .40585 Mtetra
.656 .761 .927 r
.38622 .40585 .39262 .41215 .40323 .40858 .39686 .40223 Mtetra
.39686 .40223 .40323 .40858 .41389 .40499 .40755 .3986 Mtetra
.656 .76 .927 r
.40755 .3986 .41389 .40499 .42458 .40139 .41827 .39497 Mtetra
.656 .76 .926 r
.41827 .39497 .42458 .40139 .43532 .39778 .42904 .39132 Mtetra
.42904 .39132 .43532 .39778 .44611 .39415 .43985 .38766 Mtetra
.43985 .38766 .44611 .39415 .45693 .3905 .4507 .38399 Mtetra
.656 .759 .926 r
.4507 .38399 .45693 .3905 .4678 .38685 .4616 .38031 Mtetra
.655 .759 .926 r
.4616 .38031 .4678 .38685 .47871 .38318 .47254 .37661 Mtetra
.47254 .37661 .47871 .38318 .48967 .37949 .48353 .3729 Mtetra
.655 .76 .926 r
.48353 .3729 .48967 .37949 .50067 .3758 .49456 .36919 Mtetra
.655 .76 .927 r
.49456 .36919 .50067 .3758 .51171 .37208 .50563 .36546 Mtetra
.50563 .36546 .51171 .37208 .5228 .36836 .51675 .36171 Mtetra
.51675 .36171 .5228 .36836 .53394 .36462 .52792 .35796 Mtetra
.655 .761 .928 r
.52792 .35796 .53394 .36462 .54512 .36086 .53913 .35419 Mtetra
.654 .761 .928 r
.53913 .35419 .54512 .36086 .55634 .35709 .55038 .35042 Mtetra
.654 .762 .929 r
.55038 .35042 .55634 .35709 .56761 .35331 .56168 .34663 Mtetra
.654 .763 .929 r
.56168 .34663 .56761 .35331 .57893 .34952 .57303 .34283 Mtetra
.654 .763 .93 r
.57303 .34283 .57893 .34952 .59029 .34571 .58443 .33903 Mtetra
.653 .764 .931 r
.58443 .33903 .59029 .34571 .6017 .34189 .59587 .33521 Mtetra
.653 .765 .932 r
.59587 .33521 .6017 .34189 .61316 .33806 .60737 .33139 Mtetra
.653 .766 .933 r
.60737 .33139 .61316 .33806 .62467 .33421 .6189 .32755 Mtetra
.652 .768 .934 r
.6189 .32755 .62467 .33421 .63622 .33036 .63049 .3237 Mtetra
.652 .769 .935 r
.63049 .3237 .63622 .33036 .64782 .32649 .64213 .31984 Mtetra
.652 .77 .936 r
.64213 .31984 .64782 .32649 .65947 .3226 .65382 .31597 Mtetra
.652 .771 .936 r
.65382 .31597 .65947 .3226 .67117 .31871 .66555 .31208 Mtetra
.652 .773 .937 r
.66555 .31208 .67117 .31871 .68291 .3148 .67733 .30817 Mtetra
.652 .774 .938 r
.67733 .30817 .68291 .3148 .69471 .31087 .68917 .30424 Mtetra
.653 .775 .938 r
.68917 .30424 .69471 .31087 .70655 .30692 .70105 .30027 Mtetra
.654 .776 .938 r
.70105 .30027 .70655 .30692 .71845 .30295 .71298 .29626 Mtetra
.655 .776 .938 r
.71298 .29626 .71845 .30295 .73039 .29895 .72496 .2922 Mtetra
.657 .776 .936 r
.72496 .2922 .73039 .29895 .74239 .29491 .73699 .28807 Mtetra
.659 .774 .934 r
.73699 .28807 .74239 .29491 .75443 .29083 .74907 .28388 Mtetra
.661 .773 .932 r
.74907 .28388 .75443 .29083 .76652 .28671 .76119 .27962 Mtetra
.663 .77 .929 r
.76119 .27962 .76652 .28671 .77866 .28254 .77335 .27528 Mtetra
.665 .766 .925 r
.77335 .27528 .77866 .28254 .79084 .27834 .78556 .27088 Mtetra
.666 .761 .921 r
.78556 .27088 .79084 .27834 .80308 .27409 .79782 .26643 Mtetra
.629 .744 .931 r
.14569 .47843 .15266 .48451 .16236 .4815 .15538 .47573 Mtetra
.629 .756 .938 r
.15538 .47573 .16236 .4815 .17211 .47845 .16511 .47297 Mtetra
.631 .768 .945 r
.16511 .47297 .17211 .47845 .18189 .47535 .17488 .47013 Mtetra
.633 .779 .951 r
.17488 .47013 .18189 .47535 .19172 .47218 .18471 .46721 Mtetra
.637 .789 .955 r
.18471 .46721 .19172 .47218 .20159 .46895 .19459 .46417 Mtetra
.64 .798 .959 r
.19459 .46417 .20159 .46895 .21151 .46565 .20451 .46102 Mtetra
.643 .805 .961 r
.20451 .46102 .21151 .46565 .22147 .4623 .21449 .45776 Mtetra
.647 .81 .962 r
.21449 .45776 .22147 .4623 .23147 .4589 .22451 .45441 Mtetra
.65 .813 .962 r
.22451 .45441 .23147 .4589 .24151 .45547 .23457 .45097 Mtetra
.652 .815 .961 r
.23457 .45097 .24151 .45547 .25159 .45201 .24468 .44747 Mtetra
.654 .814 .96 r
.24468 .44747 .25159 .45201 .26171 .44852 .25483 .44391 Mtetra
.656 .813 .959 r
.25483 .44391 .26171 .44852 .27186 .44502 .26503 .44032 Mtetra
.657 .811 .957 r
.26503 .44032 .27186 .44502 .28206 .4415 .27526 .4367 Mtetra
.658 .808 .955 r
.27526 .4367 .28206 .4415 .2923 .43797 .28553 .43306 Mtetra
.658 .805 .953 r
.28553 .43306 .2923 .43797 .30257 .43444 .29584 .4294 Mtetra
.659 .801 .951 r
.29584 .4294 .30257 .43444 .31289 .43089 .30619 .42574 Mtetra
.659 .798 .949 r
.30619 .42574 .31289 .43089 .32324 .42734 .31658 .42207 Mtetra
.659 .795 .947 r
.31658 .42207 .32324 .42734 .33364 .42378 .32701 .41839 Mtetra
.659 .791 .945 r
.32701 .41839 .33364 .42378 .34407 .42021 .33748 .41471 Mtetra
.658 .788 .944 r
.33748 .41471 .34407 .42021 .35455 .41663 .34799 .41104 Mtetra
.658 .786 .942 r
.34799 .41104 .35455 .41663 .36507 .41305 .35854 .40736 Mtetra
.658 .783 .941 r
.35854 .40736 .36507 .41305 .37562 .40945 .36913 .40367 Mtetra
.657 .781 .939 r
.36913 .40367 .37562 .40945 .38622 .40585 .37976 .39999 Mtetra
.657 .779 .938 r
.37976 .39999 .38622 .40585 .39686 .40223 .39043 .3963 Mtetra
.657 .777 .938 r
.39043 .3963 .39686 .40223 .40755 .3986 .40114 .39262 Mtetra
.656 .776 .937 r
.40114 .39262 .40755 .3986 .41827 .39497 .4119 .38892 Mtetra
.656 .775 .936 r
.4119 .38892 .41827 .39497 .42904 .39132 .42269 .38523 Mtetra
.656 .774 .936 r
.42269 .38523 .42904 .39132 .43985 .38766 .43353 .38153 Mtetra
.655 .773 .936 r
.43353 .38153 .43985 .38766 .4507 .38399 .44442 .37782 Mtetra
.44442 .37782 .4507 .38399 .4616 .38031 .45535 .37411 Mtetra
.654 .773 .936 r
.45535 .37411 .4616 .38031 .47254 .37661 .46632 .3704 Mtetra
.46632 .3704 .47254 .37661 .48353 .3729 .47733 .36668 Mtetra
.654 .773 .937 r
.47733 .36668 .48353 .3729 .49456 .36919 .48839 .36295 Mtetra
.653 .774 .937 r
.48839 .36295 .49456 .36919 .50563 .36546 .4995 .35923 Mtetra
.652 .775 .938 r
.4995 .35923 .50563 .36546 .51675 .36171 .51065 .35549 Mtetra
.652 .776 .939 r
.51065 .35549 .51675 .36171 .52792 .35796 .52185 .35176 Mtetra
.651 .777 .94 r
.52185 .35176 .52792 .35796 .53913 .35419 .53309 .34802 Mtetra
.65 .779 .942 r
.53309 .34802 .53913 .35419 .55038 .35042 .54438 .34427 Mtetra
.65 .78 .943 r
.54438 .34427 .55038 .35042 .56168 .34663 .55572 .34053 Mtetra
.649 .783 .945 r
.55572 .34053 .56168 .34663 .57303 .34283 .5671 .33678 Mtetra
.648 .785 .947 r
.5671 .33678 .57303 .34283 .58443 .33903 .57853 .33303 Mtetra
.647 .788 .949 r
.57853 .33303 .58443 .33903 .59587 .33521 .59002 .32928 Mtetra
.646 .791 .952 r
.59002 .32928 .59587 .33521 .60737 .33139 .60155 .32552 Mtetra
.645 .794 .954 r
.60155 .32552 .60737 .33139 .6189 .32755 .61312 .32175 Mtetra
.644 .797 .956 r
.61312 .32175 .6189 .32755 .63049 .3237 .62475 .31797 Mtetra
.643 .8 .958 r
.62475 .31797 .63049 .3237 .64213 .31984 .63643 .31418 Mtetra
.643 .804 .96 r
.63643 .31418 .64213 .31984 .65382 .31597 .64816 .31036 Mtetra
.643 .807 .962 r
.64816 .31036 .65382 .31597 .66555 .31208 .65994 .30651 Mtetra
.644 .81 .963 r
.65994 .30651 .66555 .31208 .67733 .30817 .67177 .30262 Mtetra
.645 .812 .963 r
.67177 .30262 .67733 .30817 .68917 .30424 .68364 .29867 Mtetra
.647 .813 .963 r
.68364 .29867 .68917 .30424 .70105 .30027 .69556 .29465 Mtetra
.651 .814 .962 r
.69556 .29465 .70105 .30027 .71298 .29626 .70753 .29054 Mtetra
.655 .813 .959 r
.70753 .29054 .71298 .29626 .72496 .2922 .71955 .28633 Mtetra
.66 .81 .955 r
.71955 .28633 .72496 .2922 .73699 .28807 .73161 .282 Mtetra
.665 .806 .95 r
.73161 .282 .73699 .28807 .74907 .28388 .74371 .27756 Mtetra
.67 .8 .944 r
.74371 .27756 .74907 .28388 .76119 .27962 .75585 .27298 Mtetra
.674 .791 .937 r
.75585 .27298 .76119 .27962 .77335 .27528 .76803 .26831 Mtetra
.677 .782 .929 r
.76803 .26831 .77335 .27528 .78556 .27088 .78026 .26355 Mtetra
.678 .772 .921 r
.78026 .26355 .78556 .27088 .79782 .26643 .79252 .25872 Mtetra
.607 .738 .938 r
.13868 .4723 .14569 .47843 .15538 .47573 .14833 .47001 Mtetra
.606 .753 .948 r
.14833 .47001 .15538 .47573 .16511 .47297 .15803 .46767 Mtetra
.606 .769 .958 r
.15803 .46767 .16511 .47297 .17488 .47013 .16778 .46524 Mtetra
.608 .785 .966 r
.16778 .46524 .17488 .47013 .18471 .46721 .17759 .4627 Mtetra
.611 .801 .973 r
.17759 .4627 .18471 .46721 .19459 .46417 .18746 .46 Mtetra
.614 .816 .978 r
.18746 .46 .19459 .46417 .20451 .46102 .19738 .45715 Mtetra
.618 .829 .981 r
.19738 .45715 .20451 .46102 .21449 .45776 .20735 .45413 Mtetra
.622 .84 .983 r
.20735 .45413 .21449 .45776 .22451 .45441 .21739 .45096 Mtetra
.627 .849 .984 r
.21739 .45096 .22451 .45441 .23457 .45097 .22747 .44764 Mtetra
.631 .855 .984 r
.22747 .44764 .23457 .45097 .24468 .44747 .2376 .44421 Mtetra
.634 .859 .984 r
.2376 .44421 .24468 .44747 .25483 .44391 .24779 .44067 Mtetra
.638 .861 .984 r
.24779 .44067 .25483 .44391 .26503 .44032 .25801 .43706 Mtetra
.64 .862 .983 r
.25801 .43706 .26503 .44032 .27526 .4367 .26828 .43338 Mtetra
.643 .862 .982 r
.26828 .43338 .27526 .4367 .28553 .43306 .27859 .42966 Mtetra
.645 .86 .981 r
.27859 .42966 .28553 .43306 .29584 .4294 .28894 .42591 Mtetra
.647 .858 .98 r
.28894 .42591 .29584 .4294 .30619 .42574 .29933 .42214 Mtetra
.648 .855 .979 r
.29933 .42214 .30619 .42574 .31658 .42207 .30976 .41835 Mtetra
.649 .852 .978 r
.30976 .41835 .31658 .42207 .32701 .41839 .32023 .41456 Mtetra
.649 .848 .976 r
.32023 .41456 .32701 .41839 .33748 .41471 .33074 .41076 Mtetra
.65 .845 .975 r
.33074 .41076 .33748 .41471 .34799 .41104 .34128 .40697 Mtetra
.65 .842 .974 r
.34128 .40697 .34799 .41104 .35854 .40736 .35187 .40318 Mtetra
.65 .838 .973 r
.35187 .40318 .35854 .40736 .36913 .40367 .3625 .3994 Mtetra
.65 .835 .972 r
.3625 .3994 .36913 .40367 .37976 .39999 .37317 .39562 Mtetra
.65 .833 .971 r
.37317 .39562 .37976 .39999 .39043 .3963 .38387 .39184 Mtetra
.649 .83 .97 r
.38387 .39184 .39043 .3963 .40114 .39262 .39462 .38808 Mtetra
.649 .828 .969 r
.39462 .38808 .40114 .39262 .4119 .38892 .40541 .38432 Mtetra
.648 .826 .969 r
.40541 .38432 .4119 .38892 .42269 .38523 .41625 .38057 Mtetra
.648 .825 .968 r
.41625 .38057 .42269 .38523 .43353 .38153 .42712 .37682 Mtetra
.647 .824 .968 r
.42712 .37682 .43353 .38153 .44442 .37782 .43804 .37308 Mtetra
.646 .823 .968 r
.43804 .37308 .44442 .37782 .45535 .37411 .44901 .36934 Mtetra
.645 .823 .969 r
.44901 .36934 .45535 .37411 .46632 .3704 .46001 .36561 Mtetra
.644 .823 .969 r
.46001 .36561 .46632 .3704 .47733 .36668 .47106 .36189 Mtetra
.642 .824 .97 r
.47106 .36189 .47733 .36668 .48839 .36295 .48216 .35817 Mtetra
.641 .824 .971 r
.48216 .35817 .48839 .36295 .4995 .35923 .4933 .35446 Mtetra
.639 .825 .972 r
.4933 .35446 .4995 .35923 .51065 .35549 .50449 .35075 Mtetra
.638 .827 .973 r
.50449 .35075 .51065 .35549 .52185 .35176 .51572 .34705 Mtetra
.636 .829 .975 r
.51572 .34705 .52185 .35176 .53309 .34802 .52701 .34335 Mtetra
.634 .831 .976 r
.52701 .34335 .53309 .34802 .54438 .34427 .53833 .33966 Mtetra
.632 .833 .978 r
.53833 .33966 .54438 .34427 .55572 .34053 .54971 .33598 Mtetra
.629 .835 .98 r
.54971 .33598 .55572 .34053 .5671 .33678 .56114 .3323 Mtetra
.627 .838 .981 r
.56114 .3323 .5671 .33678 .57853 .33303 .57261 .32861 Mtetra
.624 .841 .983 r
.57261 .32861 .57853 .33303 .59002 .32928 .58414 .32493 Mtetra
.622 .844 .984 r
.58414 .32493 .59002 .32928 .60155 .32552 .59571 .32124 Mtetra
.62 .847 .986 r
.59571 .32124 .60155 .32552 .61312 .32175 .60734 .31753 Mtetra
.619 .85 .987 r
.60734 .31753 .61312 .32175 .62475 .31797 .61901 .3138 Mtetra
.619 .852 .987 r
.61901 .3138 .62475 .31797 .63643 .31418 .63074 .31004 Mtetra
.619 .855 .988 r
.63074 .31004 .63643 .31418 .64816 .31036 .64251 .30622 Mtetra
.621 .857 .987 r
.64251 .30622 .64816 .31036 .65994 .30651 .65434 .30234 Mtetra
.625 .858 .987 r
.65434 .30234 .65994 .30651 .67177 .30262 .66621 .29838 Mtetra
.631 .858 .985 r
.66621 .29838 .67177 .30262 .68364 .29867 .67812 .29431 Mtetra
.638 .857 .983 r
.67812 .29431 .68364 .29867 .69556 .29465 .69009 .29011 Mtetra
.647 .855 .979 r
.69009 .29011 .69556 .29465 .70753 .29054 .70209 .28576 Mtetra
.657 .851 .974 r
.70209 .28576 .70753 .29054 .71955 .28633 .71414 .28125 Mtetra
.668 .844 .967 r
.71414 .28125 .71955 .28633 .73161 .282 .72622 .27656 Mtetra
.677 .835 .959 r
.72622 .27656 .73161 .282 .74371 .27756 .73834 .2717 Mtetra
.684 .823 .95 r
.73834 .2717 .74371 .27756 .75585 .27298 .75049 .26667 Mtetra
.69 .81 .94 r
.75049 .26667 .75585 .27298 .76803 .26831 .76268 .26152 Mtetra
.693 .796 .929 r
.76268 .26152 .76803 .26831 .78026 .26355 .77491 .25627 Mtetra
.694 .781 .918 r
.77491 .25627 .78026 .26355 .79252 .25872 .78718 .25095 Mtetra
.577 .729 .946 r
.13161 .46613 .13868 .4723 .14833 .47001 .14122 .46436 Mtetra
.572 .746 .959 r
.14122 .46436 .14833 .47001 .15803 .46767 .15087 .46257 Mtetra
.566 .766 .972 r
.15087 .46257 .15803 .46767 .16778 .46524 .16058 .46071 Mtetra
.561 .787 .984 r
.16058 .46071 .16778 .46524 .17759 .4627 .17035 .45877 Mtetra
.555 .808 .993 r
.17035 .45877 .17759 .4627 .18746 .46 .18017 .45669 Mtetra
.547 .83 .998 r
.18017 .45669 .18746 .46 .19738 .45715 .19006 .45445 Mtetra
.54 .85 .998 r
.19006 .45445 .19738 .45715 .20735 .45413 .20001 .45201 Mtetra
.53 .866 .993 r
.20001 .45201 .20735 .45413 .21739 .45096 .21002 .44936 Mtetra
.521 .878 .984 r
.21002 .44936 .21739 .45096 .22747 .44764 .2201 .44651 Mtetra
.511 .886 .971 r
.2201 .44651 .22747 .44764 .2376 .44421 .23023 .44346 Mtetra
.503 .891 .958 r
.23023 .44346 .2376 .44421 .24779 .44067 .24043 .44022 Mtetra
.496 .893 .945 r
.24043 .44022 .24779 .44067 .25801 .43706 .25067 .43683 Mtetra
.491 .894 .934 r
.25067 .43683 .25801 .43706 .26828 .43338 .26097 .43331 Mtetra
.489 .895 .926 r
.26097 .43331 .26828 .43338 .27859 .42966 .27132 .42967 Mtetra
.488 .896 .922 r
.27132 .42967 .27859 .42966 .28894 .42591 .28171 .42595 Mtetra
.49 .898 .92 r
.28171 .42595 .28894 .42591 .29933 .42214 .29214 .42216 Mtetra
.494 .899 .92 r
.29214 .42216 .29933 .42214 .30976 .41835 .30262 .41832 Mtetra
.498 .901 .923 r
.30262 .41832 .30976 .41835 .32023 .41456 .31314 .41444 Mtetra
.504 .903 .926 r
.31314 .41444 .32023 .41456 .33074 .41076 .3237 .41054 Mtetra
.51 .905 .931 r
.3237 .41054 .33074 .41076 .34128 .40697 .3343 .40663 Mtetra
.515 .906 .936 r
.3343 .40663 .34128 .40697 .35187 .40318 .34494 .40271 Mtetra
.52 .907 .941 r
.34494 .40271 .35187 .40318 .3625 .3994 .35562 .3988 Mtetra
.525 .907 .946 r
.35562 .3988 .3625 .3994 .37317 .39562 .36634 .3949 Mtetra
.529 .907 .95 r
.36634 .3949 .37317 .39562 .38387 .39184 .37709 .39102 Mtetra
.532 .907 .954 r
.37709 .39102 .38387 .39184 .39462 .38808 .38789 .38715 Mtetra
.534 .906 .957 r
.38789 .38715 .39462 .38808 .40541 .38432 .39873 .38329 Mtetra
.535 .905 .959 r
.39873 .38329 .40541 .38432 .41625 .38057 .40962 .37947 Mtetra
.535 .904 .961 r
.40962 .37947 .41625 .38057 .42712 .37682 .42054 .37566 Mtetra
.534 .903 .962 r
.42054 .37566 .42712 .37682 .43804 .37308 .43151 .37188 Mtetra
.531 .901 .963 r
.43151 .37188 .43804 .37308 .44901 .36934 .44252 .36812 Mtetra
.528 .9 .962 r
.44252 .36812 .44901 .36934 .46001 .36561 .45357 .36438 Mtetra
.523 .898 .961 r
.45357 .36438 .46001 .36561 .47106 .36189 .46467 .36067 Mtetra
.518 .897 .96 r
.46467 .36067 .47106 .36189 .48216 .35817 .47582 .35698 Mtetra
.511 .895 .957 r
.47582 .35698 .48216 .35817 .4933 .35446 .48701 .35331 Mtetra
.504 .893 .954 r
.48701 .35331 .4933 .35446 .50449 .35075 .49824 .34967 Mtetra
.495 .89 .95 r
.49824 .34967 .50449 .35075 .51572 .34705 .50953 .34604 Mtetra
.486 .888 .945 r
.50953 .34604 .51572 .34705 .52701 .34335 .52086 .34242 Mtetra
.477 .885 .939 r
.52086 .34242 .52701 .34335 .53833 .33966 .53224 .33881 Mtetra
.467 .882 .933 r
.53224 .33881 .53833 .33966 .54971 .33598 .54367 .33521 Mtetra
.458 .879 .927 r
.54367 .33521 .54971 .33598 .56114 .3323 .55516 .3316 Mtetra
.45 .876 .921 r
.55516 .3316 .56114 .3323 .57261 .32861 .56669 .32798 Mtetra
.444 .874 .916 r
.56669 .32798 .57261 .32861 .58414 .32493 .57827 .32433 Mtetra
.441 .873 .912 r
.57827 .32433 .58414 .32493 .59571 .32124 .5899 .32065 Mtetra
.442 .874 .91 r
.5899 .32065 .59571 .32124 .60734 .31753 .60158 .31692 Mtetra
.447 .877 .911 r
.60158 .31692 .60734 .31753 .61901 .3138 .61331 .31311 Mtetra
.458 .882 .916 r
.61331 .31311 .61901 .3138 .63074 .31004 .62509 .30921 Mtetra
.475 .889 .924 r
.62509 .30921 .63074 .31004 .64251 .30622 .63692 .3052 Mtetra
.498 .898 .935 r
.63692 .3052 .64251 .30622 .65434 .30234 .64879 .30104 Mtetra
.527 .907 .948 r
.64879 .30104 .65434 .30234 .66621 .29838 .66071 .29672 Mtetra
.56 .915 .961 r
.66071 .29672 .66621 .29838 .67812 .29431 .67266 .29221 Mtetra
.595 .919 .972 r
.67266 .29221 .67812 .29431 .69009 .29011 .68466 .28749 Mtetra
.628 .917 .979 r
.68466 .28749 .69009 .29011 .70209 .28576 .69669 .28254 Mtetra
.657 .909 .98 r
.69669 .28254 .70209 .28576 .71414 .28125 .70875 .27737 Mtetra
.681 .895 .975 r
.70875 .27737 .71414 .28125 .72622 .27656 .72084 .27199 Mtetra
.696 .876 .965 r
.72084 .27199 .72622 .27656 .73834 .2717 .73296 .26643 Mtetra
.706 .854 .953 r
.73296 .26643 .73834 .2717 .75049 .26667 .74512 .26073 Mtetra
.711 .833 .94 r
.74512 .26073 .75049 .26667 .76268 .26152 .75731 .25491 Mtetra
.713 .811 .926 r
.75731 .25491 .76268 .26152 .77491 .25627 .76953 .24903 Mtetra
.712 .791 .914 r
.76953 .24903 .77491 .25627 .78718 .25095 .7818 .24311 Mtetra
.555 .721 .951 r
.12449 .45992 .13161 .46613 .14122 .46436 .13407 .4585 Mtetra
.546 .732 .961 r
.13407 .4585 .14122 .46436 .15087 .46257 .1437 .45712 Mtetra
.538 .745 .971 r
.1437 .45712 .15087 .46257 .16058 .46071 .15337 .45574 Mtetra
.529 .76 .982 r
.15337 .45574 .16058 .46071 .17035 .45877 .16309 .45433 Mtetra
.519 .778 .991 r
.16309 .45433 .17035 .45877 .18017 .45669 .17288 .45286 Mtetra
.507 .797 .998 r
.17288 .45286 .18017 .45669 .19006 .45445 .18272 .45127 Mtetra
.495 .817 1 r
.18272 .45127 .19006 .45445 .20001 .45201 .19263 .44951 Mtetra
.48 .835 .995 r
.19263 .44951 .20001 .45201 .21002 .44936 .2026 .44755 Mtetra
.464 .849 .982 r
.2026 .44755 .21002 .44936 .2201 .44651 .21265 .44535 Mtetra
.445 .856 .961 r
.21265 .44535 .2201 .44651 .23023 .44346 .22276 .4429 Mtetra
.425 .858 .934 r
.22276 .4429 .23023 .44346 .24043 .44022 .23295 .44021 Mtetra
.405 .854 .904 r
.23295 .44021 .24043 .44022 .25067 .43683 .24319 .43729 Mtetra
.386 .847 .873 r
.24319 .43729 .25067 .43683 .26097 .43331 .2535 .43416 Mtetra
.369 .838 .843 r
.2535 .43416 .26097 .43331 .27132 .42967 .26387 .43085 Mtetra
.355 .829 .818 r
.26387 .43085 .27132 .42967 .28171 .42595 .27429 .42739 Mtetra
.343 .821 .796 r
.27429 .42739 .28171 .42595 .29214 .42216 .28475 .42379 Mtetra
.333 .813 .779 r
.28475 .42379 .29214 .42216 .30262 .41832 .29527 .42008 Mtetra
.326 .808 .766 r
.29527 .42008 .30262 .41832 .31314 .41444 .30584 .4163 Mtetra
.321 .804 .756 r
.30584 .4163 .31314 .41444 .3237 .41054 .31644 .41245 Mtetra
.318 .801 .75 r
.31644 .41245 .3237 .41054 .3343 .40663 .32709 .40855 Mtetra
.316 .799 .747 r
.32709 .40855 .3343 .40663 .34494 .40271 .33779 .40463 Mtetra
.314 .798 .745 r
.33779 .40463 .34494 .40271 .35562 .3988 .34852 .4007 Mtetra
.313 .797 .745 r
.34852 .4007 .35562 .3988 .36634 .3949 .3593 .39676 Mtetra
.312 .797 .745 r
.3593 .39676 .36634 .3949 .37709 .39102 .37011 .39282 Mtetra
.311 .796 .747 r
.37011 .39282 .37709 .39102 .38789 .38715 .38097 .38891 Mtetra
.309 .795 .748 r
.38097 .38891 .38789 .38715 .39873 .38329 .39187 .38501 Mtetra
.307 .794 .748 r
.39187 .38501 .39873 .38329 .40962 .37947 .4028 .38114 Mtetra
.304 .792 .749 r
.4028 .38114 .40962 .37947 .42054 .37566 .41379 .3773 Mtetra
.3 .79 .748 r
.41379 .3773 .42054 .37566 .43151 .37188 .42481 .37348 Mtetra
.296 .787 .747 r
.42481 .37348 .43151 .37188 .44252 .36812 .43588 .3697 Mtetra
.291 .784 .745 r
.43588 .3697 .44252 .36812 .45357 .36438 .44699 .36596 Mtetra
.285 .78 .742 r
.44699 .36596 .45357 .36438 .46467 .36067 .45815 .36224 Mtetra
.278 .775 .738 r
.45815 .36224 .46467 .36067 .47582 .35698 .46935 .35855 Mtetra
.272 .771 .734 r
.46935 .35855 .47582 .35698 .48701 .35331 .4806 .35489 Mtetra
.265 .766 .729 r
.4806 .35489 .48701 .35331 .49824 .34967 .4919 .35124 Mtetra
.259 .762 .725 r
.4919 .35124 .49824 .34967 .50953 .34604 .50324 .34762 Mtetra
.255 .758 .721 r
.50324 .34762 .50953 .34604 .52086 .34242 .51464 .344 Mtetra
.252 .756 .719 r
.51464 .344 .52086 .34242 .53224 .33881 .52608 .34037 Mtetra
.251 .756 .719 r
.52608 .34037 .53224 .33881 .54367 .33521 .53758 .33673 Mtetra
.254 .758 .721 r
.53758 .33673 .54367 .33521 .55516 .3316 .54912 .33307 Mtetra
.261 .763 .726 r
.54912 .33307 .55516 .3316 .56669 .32798 .56071 .32935 Mtetra
.273 .772 .736 r
.56071 .32935 .56669 .32798 .57827 .32433 .57236 .32557 Mtetra
.291 .785 .751 r
.57236 .32557 .57827 .32433 .5899 .32065 .58405 .32171 Mtetra
.316 .802 .771 r
.58405 .32171 .5899 .32065 .60158 .31692 .59579 .31773 Mtetra
.348 .824 .797 r
.59579 .31773 .60158 .31692 .61331 .31311 .60758 .31362 Mtetra
.388 .849 .828 r
.60758 .31362 .61331 .31311 .62509 .30921 .61941 .30934 Mtetra
.435 .875 .862 r
.61941 .30934 .62509 .30921 .63692 .3052 .63129 .30487 Mtetra
.487 .9 .896 r
.63129 .30487 .63692 .3052 .64879 .30104 .6432 .30019 Mtetra
.541 .92 .928 r
.6432 .30019 .64879 .30104 .66071 .29672 .65515 .29526 Mtetra
.594 .933 .952 r
.65515 .29526 .66071 .29672 .67266 .29221 .66714 .29007 Mtetra
.639 .934 .967 r
.66714 .29007 .67266 .29221 .68466 .28749 .67916 .28462 Mtetra
.675 .926 .972 r
.67916 .28462 .68466 .28749 .69669 .28254 .6912 .27891 Mtetra
.701 .909 .968 r
.6912 .27891 .69669 .28254 .70875 .27737 .70327 .27298 Mtetra
.717 .888 .959 r
.70327 .27298 .70875 .27737 .72084 .27199 .71537 .26687 Mtetra
.725 .865 .947 r
.71537 .26687 .72084 .27199 .73296 .26643 .72751 .26062 Mtetra
.728 .843 .935 r
.72751 .26062 .73296 .26643 .74512 .26073 .73967 .2543 Mtetra
.728 .823 .924 r
.73967 .2543 .74512 .26073 .75731 .25491 .75186 .24794 Mtetra
.726 .805 .914 r
.75186 .24794 .75731 .25491 .76953 .24903 .7641 .24156 Mtetra
.723 .79 .905 r
.7641 .24156 .76953 .24903 .7818 .24311 .77637 .23521 Mtetra
.567 .726 .948 r
.11732 .45366 .12449 .45992 .13407 .4585 .12694 .45202 Mtetra
.564 .717 .945 r
.12694 .45202 .13407 .4585 .1437 .45712 .1366 .45047 Mtetra
.56 .711 .942 r
.1366 .45047 .1437 .45712 .15337 .45574 .1463 .44901 Mtetra
.555 .707 .942 r
.1463 .44901 .15337 .45574 .16309 .45433 .15603 .44763 Mtetra
.548 .706 .944 r
.15603 .44763 .16309 .45433 .17288 .45286 .1658 .44635 Mtetra
.542 .712 .95 r
.1658 .44635 .17288 .45286 .18272 .45127 .17562 .44511 Mtetra
.536 .722 .96 r
.17562 .44511 .18272 .45127 .19263 .44951 .18549 .44388 Mtetra
.529 .74 .972 r
.18549 .44388 .19263 .44951 .2026 .44755 .19542 .44259 Mtetra
.522 .763 .985 r
.19542 .44259 .2026 .44755 .21265 .44535 .20541 .44117 Mtetra
.51 .789 .996 r
.20541 .44117 .21265 .44535 .22276 .4429 .21547 .4396 Mtetra
.494 .816 1 r
.21547 .4396 .22276 .4429 .23295 .44021 .2256 .43782 Mtetra
.467 .835 .992 r
.2256 .43782 .23295 .44021 .24319 .43729 .2358 .43583 Mtetra
.431 .844 .966 r
.2358 .43583 .24319 .43729 .2535 .43416 .24606 .43362 Mtetra
.383 .836 .92 r
.24606 .43362 .2535 .43416 .26387 .43085 .2564 .43119 Mtetra
.328 .813 .857 r
.2564 .43119 .26387 .43085 .27429 .42739 .26679 .42855 Mtetra
.27 .775 .782 r
.26679 .42855 .27429 .42739 .28475 .42379 .27725 .42572 Mtetra
.214 .731 .704 r
.27725 .42572 .28475 .42379 .29527 .42008 .28777 .42273 Mtetra
0 0 0 r
.28777 .42273 .29527 .42008 .30584 .4163 .29834 .41957 Mtetra
.29834 .41957 .30584 .4163 .31644 .41245 .30897 .41628 Mtetra
.30897 .41628 .31644 .41245 .32709 .40855 .31965 .41288 Mtetra
.31965 .41288 .32709 .40855 .33779 .40463 .33038 .40938 Mtetra
.33038 .40938 .33779 .40463 .34852 .4007 .34115 .4058 Mtetra
.003 0 0 r
.34115 .4058 .34852 .4007 .3593 .39676 .35198 .40216 Mtetra
.021 0 0 r
.35198 .40216 .3593 .39676 .37011 .39282 .36285 .39846 Mtetra
.036 0 0 r
.36285 .39846 .37011 .39282 .38097 .38891 .37376 .39474 Mtetra
.048 0 0 r
.37376 .39474 .38097 .38891 .39187 .38501 .38472 .39098 Mtetra
.058 0 0 r
.38472 .39098 .39187 .38501 .4028 .38114 .39573 .38721 Mtetra
.065 0 0 r
.39573 .38721 .4028 .38114 .41379 .3773 .40678 .38342 Mtetra
.07 0 0 r
.40678 .38342 .41379 .3773 .42481 .37348 .41787 .37963 Mtetra
.074 0 0 r
.41787 .37963 .42481 .37348 .43588 .3697 .42902 .37583 Mtetra
.42902 .37583 .43588 .3697 .44699 .36596 .4402 .37203 Mtetra
.073 0 0 r
.4402 .37203 .44699 .36596 .45815 .36224 .45144 .36822 Mtetra
.069 0 0 r
.45144 .36822 .45815 .36224 .46935 .35855 .46272 .3644 Mtetra
.062 0 0 r
.46272 .3644 .46935 .35855 .4806 .35489 .47404 .36056 Mtetra
.051 0 0 r
.47404 .36056 .4806 .35489 .4919 .35124 .48542 .35669 Mtetra
.036 0 0 r
.48542 .35669 .4919 .35124 .50324 .34762 .49684 .35278 Mtetra
.016 0 0 r
.49684 .35278 .50324 .34762 .51464 .344 .50831 .34883 Mtetra
0 0 0 r
.50831 .34883 .51464 .344 .52608 .34037 .51983 .3448 Mtetra
.51983 .3448 .52608 .34037 .53758 .33673 .5314 .3407 Mtetra
.5314 .3407 .53758 .33673 .54912 .33307 .54301 .33649 Mtetra
.54301 .33649 .54912 .33307 .56071 .32935 .55467 .33217 Mtetra
.55467 .33217 .56071 .32935 .57236 .32557 .56638 .3277 Mtetra
.281 .767 .683 r
.56638 .3277 .57236 .32557 .58405 .32171 .57813 .32307 Mtetra
.366 .831 .766 r
.57813 .32307 .58405 .32171 .59579 .31773 .58992 .31826 Mtetra
.455 .886 .844 r
.58992 .31826 .59579 .31773 .60758 .31362 .60175 .31325 Mtetra
.539 .924 .907 r
.60175 .31325 .60758 .31362 .61941 .30934 .61362 .30802 Mtetra
.61 .94 .949 r
.61362 .30802 .61941 .30934 .63129 .30487 .62552 .30256 Mtetra
.664 .935 .968 r
.62552 .30256 .63129 .30487 .6432 .30019 .63745 .29686 Mtetra
.699 .915 .969 r
.63745 .29686 .6432 .30019 .65515 .29526 .64942 .29094 Mtetra
.72 .887 .957 r
.64942 .29094 .65515 .29526 .66714 .29007 .66142 .28479 Mtetra
.73 .857 .941 r
.66142 .28479 .66714 .29007 .67916 .28462 .67344 .27847 Mtetra
.733 .829 .924 r
.67344 .27847 .67916 .28462 .6912 .27891 .68549 .27201 Mtetra
.732 .806 .91 r
.68549 .27201 .6912 .27891 .70327 .27298 .69757 .26548 Mtetra
.729 .787 .899 r
.69757 .26548 .70327 .27298 .71537 .26687 .70969 .25894 Mtetra
.726 .774 .892 r
.70969 .25894 .71537 .26687 .72751 .26062 .72185 .25243 Mtetra
.721 .766 .888 r
.72185 .25243 .72751 .26062 .73967 .2543 .73405 .24602 Mtetra
.718 .764 .888 r
.73405 .24602 .73967 .2543 .75186 .24794 .74629 .23968 Mtetra
.716 .765 .891 r
.74629 .23968 .75186 .24794 .7641 .24156 .75857 .23343 Mtetra
.714 .768 .895 r
.75857 .23343 .7641 .24156 .77637 .23521 .7709 .22725 Mtetra
.608 .739 .938 r
.1101 .44736 .11732 .45366 .12694 .45202 .11983 .44496 Mtetra
.605 .713 .921 r
.11983 .44496 .12694 .45202 .1366 .45047 .12959 .44269 Mtetra
.599 .69 .906 r
.12959 .44269 .1366 .45047 .1463 .44901 .13937 .44057 Mtetra
.591 .669 .893 r
.13937 .44057 .1463 .44901 .15603 .44763 .14918 .43865 Mtetra
.581 .651 .884 r
.14918 .43865 .15603 .44763 .1658 .44635 .159 .43699 Mtetra
.572 .638 .878 r
.159 .43699 .1658 .44635 .17562 .44511 .16885 .43555 Mtetra
.562 .629 .876 r
.16885 .43555 .17562 .44511 .18549 .44388 .17872 .43433 Mtetra
.556 .628 .878 r
.17872 .43433 .18549 .44388 .19542 .44259 .18863 .43325 Mtetra
.55 .632 .885 r
.18863 .43325 .19542 .44259 .20541 .44117 .19859 .43226 Mtetra
.548 .642 .896 r
.19859 .43226 .20541 .44117 .21547 .4396 .2086 .43127 Mtetra
.547 .66 .91 r
.2086 .43127 .21547 .4396 .2256 .43782 .21867 .4302 Mtetra
.546 .682 .928 r
.21867 .4302 .2256 .43782 .2358 .43583 .22881 .42902 Mtetra
.546 .709 .947 r
.22881 .42902 .2358 .43583 .24606 .43362 .23902 .42767 Mtetra
.543 .74 .967 r
.23902 .42767 .24606 .43362 .2564 .43119 .2493 .42614 Mtetra
.538 .772 .984 r
.2493 .42614 .2564 .43119 .26679 .42855 .25965 .42441 Mtetra
.528 .803 .996 r
.25965 .42441 .26679 .42855 .27725 .42572 .27006 .42247 Mtetra
.512 .829 1 r
.27006 .42247 .27725 .42572 .28777 .42273 .28055 .42032 Mtetra
.489 .848 .992 r
.28055 .42032 .28777 .42273 .29834 .41957 .2911 .41797 Mtetra
.459 .857 .972 r
.2911 .41797 .29834 .41957 .30897 .41628 .30172 .41543 Mtetra
.423 .854 .939 r
.30172 .41543 .30897 .41628 .31965 .41288 .31239 .41271 Mtetra
.384 .842 .898 r
.31239 .41271 .31965 .41288 .33038 .40938 .32313 .40982 Mtetra
.345 .823 .851 r
.32313 .40982 .33038 .40938 .34115 .4058 .33392 .40679 Mtetra
.308 .8 .804 r
.33392 .40679 .34115 .4058 .35198 .40216 .34477 .40361 Mtetra
.275 .776 .759 r
.34477 .40361 .35198 .40216 .36285 .39846 .35567 .40032 Mtetra
.246 .753 .719 r
.35567 .40032 .36285 .39846 .37376 .39474 .36663 .39691 Mtetra
.224 .733 .685 r
.36663 .39691 .37376 .39474 .38472 .39098 .37763 .39341 Mtetra
0 0 0 r
.37763 .39341 .38472 .39098 .39573 .38721 .38869 .38982 Mtetra
.38869 .38982 .39573 .38721 .40678 .38342 .3998 .38615 Mtetra
.3998 .38615 .40678 .38342 .41787 .37963 .41095 .3824 Mtetra
.41095 .3824 .41787 .37963 .42902 .37583 .42216 .37859 Mtetra
.42216 .37859 .42902 .37583 .4402 .37203 .43341 .3747 Mtetra
.43341 .3747 .4402 .37203 .45144 .36822 .44471 .37073 Mtetra
.44471 .37073 .45144 .36822 .46272 .3644 .45606 .36668 Mtetra
.254 .751 .68 r
.45606 .36668 .46272 .3644 .47404 .36056 .46745 .36254 Mtetra
.289 .778 .713 r
.46745 .36254 .47404 .36056 .48542 .35669 .4789 .3583 Mtetra
.331 .809 .753 r
.4789 .3583 .48542 .35669 .49684 .35278 .49039 .35395 Mtetra
.381 .842 .798 r
.49039 .35395 .49684 .35278 .50831 .34883 .50192 .34948 Mtetra
.436 .876 .845 r
.50192 .34948 .50831 .34883 .51983 .3448 .5135 .34486 Mtetra
.495 .904 .89 r
.5135 .34486 .51983 .3448 .5314 .3407 .52513 .34008 Mtetra
.552 .925 .929 r
.52513 .34008 .5314 .3407 .54301 .33649 .5368 .33514 Mtetra
.605 .934 .957 r
.5368 .33514 .54301 .33649 .55467 .33217 .54851 .33 Mtetra
.649 .93 .971 r
.54851 .33 .55467 .33217 .56638 .3277 .56026 .32466 Mtetra
.683 .915 .973 r
.56026 .32466 .56638 .3277 .57813 .32307 .57204 .31911 Mtetra
.706 .89 .964 r
.57204 .31911 .57813 .32307 .58992 .31826 .58386 .31333 Mtetra
.72 .861 .948 r
.58386 .31333 .58992 .31826 .60175 .31325 .59572 .30734 Mtetra
.728 .83 .928 r
.59572 .30734 .60175 .31325 .61362 .30802 .6076 .30113 Mtetra
.73 .8 .907 r
.6076 .30113 .61362 .30802 .62552 .30256 .61952 .29472 Mtetra
.73 .773 .887 r
.61952 .29472 .62552 .30256 .63745 .29686 .63146 .28813 Mtetra
.727 .748 .869 r
.63146 .28813 .63745 .29686 .64942 .29094 .64343 .2814 Mtetra
.722 .727 .854 r
.64343 .2814 .64942 .29094 .66142 .28479 .65543 .27459 Mtetra
.717 .711 .843 r
.65543 .27459 .66142 .28479 .67344 .27847 .66746 .26777 Mtetra
.711 .699 .836 r
.66746 .26777 .67344 .27847 .68549 .27201 .67953 .26103 Mtetra
.706 .691 .833 r
.67953 .26103 .68549 .27201 .69757 .26548 .69164 .25441 Mtetra
.7 .688 .835 r
.69164 .25441 .69757 .26548 .70969 .25894 .70379 .24802 Mtetra
.696 .69 .84 r
.70379 .24802 .70969 .25894 .72185 .25243 .716 .24185 Mtetra
.692 .696 .849 r
.716 .24185 .72185 .25243 .73405 .24602 .72826 .23593 Mtetra
.69 .707 .861 r
.72826 .23593 .73405 .24602 .74629 .23968 .74058 .23022 Mtetra
.689 .723 .876 r
.74058 .23022 .74629 .23968 .75857 .23343 .75296 .22467 Mtetra
.689 .743 .892 r
.75296 .22467 .75857 .23343 .7709 .22725 .76539 .21923 Mtetra
.669 .755 .914 r
.10283 .44102 .1101 .44736 .11983 .44496 .11275 .43722 Mtetra
.662 .712 .885 r
.11275 .43722 .11983 .44496 .12959 .44269 .1227 .4335 Mtetra
.652 .672 .857 r
.1227 .4335 .12959 .44269 .13937 .44057 .13267 .42993 Mtetra
.639 .637 .832 r
.13267 .42993 .13937 .44057 .14918 .43865 .14264 .42656 Mtetra
.625 .604 .809 r
.14264 .42656 .14918 .43865 .159 .43699 .15263 .42347 Mtetra
.612 .576 .789 r
.15263 .42347 .159 .43699 .16885 .43555 .16262 .42067 Mtetra
.599 .551 .772 r
.16262 .42067 .16885 .43555 .17872 .43433 .17262 .41819 Mtetra
.589 .531 .758 r
.17262 .41819 .17872 .43433 .18863 .43325 .18263 .41601 Mtetra
.579 .514 .746 r
.18263 .41601 .18863 .43325 .19859 .43226 .19267 .4141 Mtetra
.573 .502 .737 r
.19267 .4141 .19859 .43226 .2086 .43127 .20273 .41239 Mtetra
.568 .493 .731 r
.20273 .41239 .2086 .43127 .21867 .4302 .21283 .41084 Mtetra
.566 .488 .727 r
.21283 .41084 .21867 .4302 .22881 .42902 .22297 .40937 Mtetra
.565 .485 .724 r
.22297 .40937 .22881 .42902 .23902 .42767 .23316 .40791 Mtetra
.23316 .40791 .23902 .42767 .2493 .42614 .24341 .40644 Mtetra
.566 .487 .725 r
.24341 .40644 .2493 .42614 .25965 .42441 .25372 .40491 Mtetra
.568 .49 .727 r
.25372 .40491 .25965 .42441 .27006 .42247 .26409 .40329 Mtetra
.571 .495 .73 r
.26409 .40329 .27006 .42247 .28055 .42032 .27452 .40156 Mtetra
.575 .501 .735 r
.27452 .40156 .28055 .42032 .2911 .41797 .28502 .39969 Mtetra
.578 .508 .74 r
.28502 .39969 .2911 .41797 .30172 .41543 .29558 .39768 Mtetra
.583 .516 .746 r
.29558 .39768 .30172 .41543 .31239 .41271 .30621 .39551 Mtetra
.587 .525 .752 r
.30621 .39551 .31239 .41271 .32313 .40982 .3169 .39318 Mtetra
.592 .534 .759 r
.3169 .39318 .32313 .40982 .33392 .40679 .32765 .39068 Mtetra
.597 .544 .765 r
.32765 .39068 .33392 .40679 .34477 .40361 .33846 .38801 Mtetra
.603 .553 .771 r
.33846 .38801 .34477 .40361 .35567 .40032 .34934 .38516 Mtetra
.608 .562 .777 r
.34934 .38516 .35567 .40032 .36663 .39691 .36027 .38215 Mtetra
.613 .57 .782 r
.36027 .38215 .36663 .39691 .37763 .39341 .37126 .37897 Mtetra
.618 .577 .787 r
.37126 .37897 .37763 .39341 .38869 .38982 .38231 .37561 Mtetra
.622 .584 .79 r
.38231 .37561 .38869 .38982 .3998 .38615 .39341 .37209 Mtetra
.627 .589 .791 r
.39341 .37209 .3998 .38615 .41095 .3824 .40457 .36841 Mtetra
.63 .592 .792 r
.40457 .36841 .41095 .3824 .42216 .37859 .41578 .36455 Mtetra
.634 .594 .791 r
.41578 .36455 .42216 .37859 .43341 .3747 .42704 .36053 Mtetra
.637 .594 .789 r
.42704 .36053 .43341 .3747 .44471 .37073 .43835 .35634 Mtetra
.64 .592 .785 r
.43835 .35634 .44471 .37073 .45606 .36668 .44971 .35199 Mtetra
.642 .59 .781 r
.44971 .35199 .45606 .36668 .46745 .36254 .46112 .34745 Mtetra
.643 .586 .775 r
.46112 .34745 .46745 .36254 .4789 .3583 .47257 .34275 Mtetra
.644 .581 .769 r
.47257 .34275 .4789 .3583 .49039 .35395 .48407 .33787 Mtetra
.645 .576 .762 r
.48407 .33787 .49039 .35395 .50192 .34948 .49561 .33281 Mtetra
.645 .57 .755 r
.49561 .33281 .50192 .34948 .5135 .34486 .50719 .32757 Mtetra
.645 .564 .748 r
.50719 .32757 .5135 .34486 .52513 .34008 .51882 .32215 Mtetra
.645 .558 .742 r
.51882 .32215 .52513 .34008 .5368 .33514 .53048 .31656 Mtetra
.645 .552 .735 r
.53048 .31656 .5368 .33514 .54851 .33 .54218 .31081 Mtetra
.644 .547 .729 r
.54218 .31081 .54851 .33 .56026 .32466 .55391 .3049 Mtetra
.644 .542 .724 r
.55391 .3049 .56026 .32466 .57204 .31911 .56568 .29884 Mtetra
.643 .538 .72 r
.56568 .29884 .57204 .31911 .58386 .31333 .57749 .29266 Mtetra
.643 .535 .716 r
.57749 .29266 .58386 .31333 .59572 .30734 .58932 .28638 Mtetra
.643 .533 .714 r
.58932 .28638 .59572 .30734 .6076 .30113 .60119 .28002 Mtetra
.642 .532 .713 r
.60119 .28002 .6076 .30113 .61952 .29472 .6131 .27364 Mtetra
.642 .532 .714 r
.6131 .27364 .61952 .29472 .63146 .28813 .62503 .26727 Mtetra
.642 .534 .716 r
.62503 .26727 .63146 .28813 .64343 .2814 .63701 .26097 Mtetra
.641 .537 .72 r
.63701 .26097 .64343 .2814 .65543 .27459 .64903 .25482 Mtetra
.641 .542 .727 r
.64903 .25482 .65543 .27459 .66746 .26777 .66109 .24887 Mtetra
.64 .549 .736 r
.66109 .24887 .66746 .26777 .67953 .26103 .67321 .24319 Mtetra
.64 .56 .748 r
.67321 .24319 .67953 .26103 .69164 .25441 .68538 .23781 Mtetra
.639 .573 .764 r
.68538 .23781 .69164 .25441 .70379 .24802 .69762 .23276 Mtetra
.639 .59 .783 r
.69762 .23276 .70379 .24802 .716 .24185 .70992 .22801 Mtetra
.639 .611 .805 r
.70992 .22801 .716 .24185 .72826 .23593 .7223 .22354 Mtetra
.64 .637 .831 r
.7223 .22354 .72826 .23593 .74058 .23022 .73474 .21928 Mtetra
.641 .668 .86 r
.73474 .21928 .74058 .23022 .75296 .22467 .74725 .21517 Mtetra
.642 .704 .891 r
.74725 .21517 .75296 .22467 .76539 .21923 .75983 .21113 Mtetra
.719 .764 .888 r
.09551 .43462 .10283 .44102 .11275 .43722 .10565 .4293 Mtetra
.708 .72 .859 r
.10565 .4293 .11275 .43722 .1227 .4335 .11581 .42399 Mtetra
.695 .68 .832 r
.11581 .42399 .1227 .4335 .13267 .42993 .12599 .41875 Mtetra
.68 .644 .807 r
.12599 .41875 .13267 .42993 .14264 .42656 .13618 .41367 Mtetra
.664 .61 .784 r
.13618 .41367 .14264 .42656 .15263 .42347 .14637 .40879 Mtetra
.648 .579 .764 r
.14637 .40879 .15263 .42347 .16262 .42067 .15656 .40418 Mtetra
.633 .552 .745 r
.15656 .40418 .16262 .42067 .17262 .41819 .16675 .3999 Mtetra
.618 .527 .729 r
.16675 .3999 .17262 .41819 .18263 .41601 .17693 .39598 Mtetra
.605 .506 .715 r
.17693 .39598 .18263 .41601 .19267 .4141 .18711 .39245 Mtetra
.594 .488 .703 r
.18711 .39245 .19267 .4141 .20273 .41239 .19729 .38928 Mtetra
.585 .473 .693 r
.19729 .38928 .20273 .41239 .21283 .41084 .20748 .38645 Mtetra
.577 .461 .685 r
.20748 .38645 .21283 .41084 .22297 .40937 .21769 .3839 Mtetra
.572 .452 .678 r
.21769 .3839 .22297 .40937 .23316 .40791 .22792 .38156 Mtetra
.567 .446 .674 r
.22792 .38156 .23316 .40791 .24341 .40644 .23819 .3794 Mtetra
.565 .441 .67 r
.23819 .3794 .24341 .40644 .25372 .40491 .24849 .37735 Mtetra
.563 .438 .668 r
.24849 .37735 .25372 .40491 .26409 .40329 .25885 .37537 Mtetra
.562 .436 .666 r
.25885 .37537 .26409 .40329 .27452 .40156 .26925 .37341 Mtetra
.562 .435 .665 r
.26925 .37341 .27452 .40156 .28502 .39969 .2797 .37145 Mtetra
.2797 .37145 .28502 .39969 .29558 .39768 .29022 .36944 Mtetra
.563 .436 .665 r
.29022 .36944 .29558 .39768 .30621 .39551 .30079 .36736 Mtetra
.565 .438 .666 r
.30079 .36736 .30621 .39551 .3169 .39318 .31142 .36517 Mtetra
.567 .44 .667 r
.31142 .36517 .3169 .39318 .32765 .39068 .32211 .36285 Mtetra
.569 .443 .668 r
.32211 .36285 .32765 .39068 .33846 .38801 .33287 .36037 Mtetra
.572 .446 .67 r
.33287 .36037 .33846 .38801 .34934 .38516 .34368 .35772 Mtetra
.575 .449 .671 r
.34368 .35772 .34934 .38516 .36027 .38215 .35456 .35489 Mtetra
.578 .452 .672 r
.35456 .35489 .36027 .38215 .37126 .37897 .3655 .35185 Mtetra
.581 .455 .673 r
.3655 .35185 .37126 .37897 .38231 .37561 .3765 .34861 Mtetra
.584 .458 .674 r
.3765 .34861 .38231 .37561 .39341 .37209 .38756 .34516 Mtetra
.588 .46 .674 r
.38756 .34516 .39341 .37209 .40457 .36841 .39868 .34148 Mtetra
.591 .463 .674 r
.39868 .34148 .40457 .36841 .41578 .36455 .40985 .33758 Mtetra
.593 .464 .674 r
.40985 .33758 .41578 .36455 .42704 .36053 .42107 .33345 Mtetra
.596 .466 .674 r
.42107 .33345 .42704 .36053 .43835 .35634 .43234 .32911 Mtetra
.599 .467 .673 r
.43234 .32911 .43835 .35634 .44971 .35199 .44367 .32454 Mtetra
.601 .468 .672 r
.44367 .32454 .44971 .35199 .46112 .34745 .45504 .31977 Mtetra
.603 .468 .67 r
.45504 .31977 .46112 .34745 .47257 .34275 .46646 .31479 Mtetra
.604 .468 .669 r
.46646 .31479 .47257 .34275 .48407 .33787 .47792 .30961 Mtetra
.606 .468 .668 r
.47792 .30961 .48407 .33787 .49561 .33281 .48942 .30426 Mtetra
.607 .468 .666 r
.48942 .30426 .49561 .33281 .50719 .32757 .50096 .29874 Mtetra
.608 .467 .665 r
.50096 .29874 .50719 .32757 .51882 .32215 .51254 .29309 Mtetra
.608 .467 .664 r
.51254 .29309 .51882 .32215 .53048 .31656 .52416 .28732 Mtetra
.609 .466 .663 r
.52416 .28732 .53048 .31656 .54218 .31081 .53581 .28147 Mtetra
.609 .466 .662 r
.53581 .28147 .54218 .31081 .55391 .3049 .5475 .27556 Mtetra
.609 .467 .663 r
.5475 .27556 .55391 .3049 .56568 .29884 .55923 .26963 Mtetra
.55923 .26963 .56568 .29884 .57749 .29266 .57099 .26372 Mtetra
.609 .468 .665 r
.57099 .26372 .57749 .29266 .58932 .28638 .58279 .25788 Mtetra
.608 .47 .667 r
.58279 .25788 .58932 .28638 .60119 .28002 .59463 .25215 Mtetra
.608 .472 .671 r
.59463 .25215 .60119 .28002 .6131 .27364 .60652 .24658 Mtetra
.607 .476 .676 r
.60652 .24658 .6131 .27364 .62503 .26727 .61845 .24123 Mtetra
.606 .48 .682 r
.61845 .24123 .62503 .26727 .63701 .26097 .63044 .23616 Mtetra
.604 .486 .691 r
.63044 .23616 .63701 .26097 .64903 .25482 .64248 .23144 Mtetra
.603 .493 .702 r
.64248 .23144 .64903 .25482 .66109 .24887 .65459 .22707 Mtetra
.601 .503 .715 r
.65459 .22707 .66109 .24887 .67321 .24319 .66677 .22312 Mtetra
.599 .516 .732 r
.66677 .22312 .67321 .24319 .68538 .23781 .67903 .21953 Mtetra
.597 .532 .752 r
.67903 .21953 .68538 .23781 .69762 .23276 .69136 .21629 Mtetra
.596 .551 .775 r
.69136 .21629 .69762 .23276 .70992 .22801 .70378 .21332 Mtetra
.595 .575 .801 r
.70378 .21332 .70992 .22801 .7223 .22354 .71627 .21058 Mtetra
.594 .603 .831 r
.71627 .21058 .7223 .22354 .73474 .21928 .72884 .20798 Mtetra
.592 .637 .864 r
.72884 .20798 .73474 .21928 .74725 .21517 .7415 .20547 Mtetra
.589 .675 .9 r
.7415 .20547 .74725 .21517 .75983 .21113 .75422 .20298 Mtetra
.743 .767 .872 r
.08813 .42819 .09551 .43462 .10565 .4293 .09842 .42192 Mtetra
.736 .741 .856 r
.09842 .42192 .10565 .4293 .11581 .42399 .10872 .41562 Mtetra
.727 .716 .84 r
.10872 .41562 .11581 .42399 .12599 .41875 .11905 .40935 Mtetra
.717 .691 .824 r
.11905 .40935 .12599 .41875 .13618 .41367 .12939 .40313 Mtetra
.706 .666 .808 r
.12939 .40313 .13618 .41367 .14637 .40879 .13975 .39701 Mtetra
.693 .641 .793 r
.13975 .39701 .14637 .40879 .15656 .40418 .1501 .39105 Mtetra
.68 .615 .777 r
.1501 .39105 .15656 .40418 .16675 .3999 .16046 .3853 Mtetra
.666 .59 .761 r
.16046 .3853 .16675 .3999 .17693 .39598 .17081 .3798 Mtetra
.651 .566 .745 r
.17081 .3798 .17693 .39598 .18711 .39245 .18116 .37459 Mtetra
.638 .542 .73 r
.18116 .37459 .18711 .39245 .19729 .38928 .19151 .36968 Mtetra
.625 .521 .716 r
.19151 .36968 .19729 .38928 .20748 .38645 .20186 .36507 Mtetra
.614 .502 .703 r
.20186 .36507 .20748 .38645 .21769 .3839 .21221 .36074 Mtetra
.604 .485 .691 r
.21221 .36074 .21769 .3839 .22792 .38156 .22258 .35666 Mtetra
.596 .471 .68 r
.22258 .35666 .22792 .38156 .23819 .3794 .23296 .35279 Mtetra
.589 .459 .671 r
.23296 .35279 .23819 .3794 .24849 .37735 .24337 .3491 Mtetra
.584 .448 .663 r
.24337 .3491 .24849 .37735 .25885 .37537 .25381 .34555 Mtetra
.579 .439 .655 r
.25381 .34555 .25885 .37537 .26925 .37341 .26428 .34213 Mtetra
.575 .432 .649 r
.26428 .34213 .26925 .37341 .2797 .37145 .27478 .33879 Mtetra
.572 .426 .644 r
.27478 .33879 .2797 .37145 .29022 .36944 .28533 .33551 Mtetra
.57 .421 .639 r
.28533 .33551 .29022 .36944 .30079 .36736 .29591 .33227 Mtetra
.568 .416 .635 r
.29591 .33227 .30079 .36736 .31142 .36517 .30654 .32903 Mtetra
.567 .413 .632 r
.30654 .32903 .31142 .36517 .32211 .36285 .31722 .32579 Mtetra
.566 .41 .629 r
.31722 .32579 .32211 .36285 .33287 .36037 .32795 .3225 Mtetra
.566 .408 .627 r
.32795 .3225 .33287 .36037 .34368 .35772 .33873 .31916 Mtetra
.566 .407 .625 r
.33873 .31916 .34368 .35772 .35456 .35489 .34956 .31574 Mtetra
.566 .406 .623 r
.34956 .31574 .35456 .35489 .3655 .35185 .36044 .31223 Mtetra
.566 .405 .622 r
.36044 .31223 .3655 .35185 .3765 .34861 .37137 .30862 Mtetra
.567 .405 .621 r
.37137 .30862 .3765 .34861 .38756 .34516 .38235 .30491 Mtetra
.568 .405 .621 r
.38235 .30491 .38756 .34516 .39868 .34148 .39338 .30107 Mtetra
.569 .406 .621 r
.39338 .30107 .39868 .34148 .40985 .33758 .40447 .29711 Mtetra
.57 .406 .621 r
.40447 .29711 .40985 .33758 .42107 .33345 .4156 .29303 Mtetra
.571 .407 .621 r
.4156 .29303 .42107 .33345 .43234 .32911 .42678 .28884 Mtetra
.572 .409 .621 r
.42678 .28884 .43234 .32911 .44367 .32454 .43801 .28453 Mtetra
.573 .41 .622 r
.43801 .28453 .44367 .32454 .45504 .31977 .44929 .28011 Mtetra
.575 .412 .623 r
.44929 .28011 .45504 .31977 .46646 .31479 .46061 .27561 Mtetra
.576 .414 .625 r
.46061 .27561 .46646 .31479 .47792 .30961 .47198 .27102 Mtetra
.577 .416 .627 r
.47198 .27102 .47792 .30961 .48942 .30426 .48339 .26638 Mtetra
.578 .419 .629 r
.48339 .26638 .48942 .30426 .50096 .29874 .49485 .26169 Mtetra
.58 .422 .632 r
.49485 .26169 .50096 .29874 .51254 .29309 .50635 .25699 Mtetra
.581 .425 .635 r
.50635 .25699 .51254 .29309 .52416 .28732 .51789 .25229 Mtetra
.582 .429 .639 r
.51789 .25229 .52416 .28732 .53581 .28147 .52948 .24763 Mtetra
.584 .434 .644 r
.52948 .24763 .53581 .28147 .5475 .27556 .54111 .24302 Mtetra
.585 .439 .649 r
.54111 .24302 .5475 .27556 .55923 .26963 .55279 .2385 Mtetra
.586 .444 .655 r
.55279 .2385 .55923 .26963 .57099 .26372 .56452 .2341 Mtetra
.587 .451 .662 r
.56452 .2341 .57099 .26372 .58279 .25788 .5763 .22984 Mtetra
.588 .458 .671 r
.5763 .22984 .58279 .25788 .59463 .25215 .58814 .22576 Mtetra
.588 .466 .681 r
.58814 .22576 .59463 .25215 .60652 .24658 .60003 .2219 Mtetra
.588 .475 .693 r
.60003 .2219 .60652 .24658 .61845 .24123 .61198 .2183 Mtetra
.587 .486 .706 r
.61198 .2183 .61845 .24123 .63044 .23616 .624 .21497 Mtetra
.586 .498 .721 r
.624 .21497 .63044 .23616 .64248 .23144 .63609 .21197 Mtetra
.584 .511 .739 r
.63609 .21197 .64248 .23144 .65459 .22707 .64826 .20927 Mtetra
.58 .526 .759 r
.64826 .20927 .65459 .22707 .66677 .22312 .66051 .20687 Mtetra
.577 .543 .78 r
.66051 .20687 .66677 .22312 .67903 .21953 .67283 .20474 Mtetra
.573 .561 .803 r
.67283 .20474 .67903 .21953 .69136 .21629 .68525 .20283 Mtetra
.569 .581 .826 r
.68525 .20283 .69136 .21629 .70378 .21332 .69775 .20108 Mtetra
.564 .602 .85 r
.69775 .20108 .70378 .21332 .71627 .21058 .71033 .19944 Mtetra
.559 .624 .873 r
.71033 .19944 .71627 .21058 .72884 .20798 .723 .19787 Mtetra
.554 .648 .896 r
.723 .19787 .72884 .20798 .7415 .20547 .73574 .19632 Mtetra
.549 .672 .919 r
.73574 .19632 .7415 .20547 .75422 .20298 .74857 .19475 Mtetra
.751 .767 .866 r
.0807 .4217 .08813 .42819 .09842 .42192 .09106 .41504 Mtetra
.749 .757 .859 r
.09106 .41504 .09842 .42192 .10872 .41562 .10145 .40833 Mtetra
.746 .747 .852 r
.10145 .40833 .10872 .41562 .11905 .40935 .11186 .40159 Mtetra
.743 .735 .845 r
.11186 .40159 .11905 .40935 .12939 .40313 .12229 .39482 Mtetra
.738 .722 .837 r
.12229 .39482 .12939 .40313 .13975 .39701 .13275 .38805 Mtetra
.732 .706 .827 r
.13275 .38805 .13975 .39701 .1501 .39105 .14322 .38129 Mtetra
.724 .689 .816 r
.14322 .38129 .1501 .39105 .16046 .3853 .1537 .37459 Mtetra
.714 .668 .803 r
.1537 .37459 .16046 .3853 .17081 .3798 .16419 .36797 Mtetra
.703 .646 .79 r
.16419 .36797 .17081 .3798 .18116 .37459 .17469 .36146 Mtetra
.69 .622 .775 r
.17469 .36146 .18116 .37459 .19151 .36968 .1852 .35511 Mtetra
.677 .598 .759 r
.1852 .35511 .19151 .36968 .20186 .36507 .19571 .34894 Mtetra
.665 .574 .744 r
.19571 .34894 .20186 .36507 .21221 .36074 .20622 .34296 Mtetra
.652 .552 .729 r
.20622 .34296 .21221 .36074 .22258 .35666 .21674 .33717 Mtetra
.641 .532 .715 r
.21674 .33717 .22258 .35666 .23296 .35279 .22727 .33156 Mtetra
.631 .514 .702 r
.22727 .33156 .23296 .35279 .24337 .3491 .23781 .32613 Mtetra
.622 .498 .691 r
.23781 .32613 .24337 .3491 .25381 .34555 .24837 .32087 Mtetra
.614 .484 .68 r
.24837 .32087 .25381 .34555 .26428 .34213 .25895 .31577 Mtetra
.606 .471 .671 r
.25895 .31577 .26428 .34213 .27478 .33879 .26954 .31081 Mtetra
.6 .461 .663 r
.26954 .31081 .27478 .33879 .28533 .33551 .28016 .306 Mtetra
.595 .451 .656 r
.28016 .306 .28533 .33551 .29591 .33227 .2908 .30132 Mtetra
.59 .443 .65 r
.2908 .30132 .29591 .33227 .30654 .32903 .30147 .29676 Mtetra
.586 .436 .645 r
.30147 .29676 .30654 .32903 .31722 .32579 .31217 .2923 Mtetra
.583 .43 .64 r
.31217 .2923 .31722 .32579 .32795 .3225 .3229 .28794 Mtetra
.58 .425 .636 r
.3229 .28794 .32795 .3225 .33873 .31916 .33367 .28366 Mtetra
.577 .421 .633 r
.33367 .28366 .33873 .31916 .34956 .31574 .34447 .27944 Mtetra
.575 .418 .631 r
.34447 .27944 .34956 .31574 .36044 .31223 .35532 .27528 Mtetra
.574 .416 .629 r
.35532 .27528 .36044 .31223 .37137 .30862 .3662 .27117 Mtetra
.573 .414 .628 r
.3662 .27117 .37137 .30862 .38235 .30491 .37712 .2671 Mtetra
.572 .412 .627 r
.37712 .2671 .38235 .30491 .39338 .30107 .38808 .26305 Mtetra
.571 .411 .626 r
.38808 .26305 .39338 .30107 .40447 .29711 .39909 .25904 Mtetra
.39909 .25904 .40447 .29711 .4156 .29303 .41014 .25506 Mtetra
.57 .411 .627 r
.41014 .25506 .4156 .29303 .42678 .28884 .42123 .25111 Mtetra
.57 .412 .628 r
.42123 .25111 .42678 .28884 .43801 .28453 .43237 .2472 Mtetra
.57 .413 .629 r
.43237 .2472 .43801 .28453 .44929 .28011 .44355 .24334 Mtetra
.57 .414 .631 r
.44355 .24334 .44929 .28011 .46061 .27561 .45478 .23953 Mtetra
.57 .416 .633 r
.45478 .23953 .46061 .27561 .47198 .27102 .46606 .23579 Mtetra
.57 .419 .637 r
.46606 .23579 .47198 .27102 .48339 .26638 .47739 .23213 Mtetra
.57 .422 .641 r
.47739 .23213 .48339 .26638 .49485 .26169 .48876 .22857 Mtetra
.571 .426 .645 r
.48876 .22857 .49485 .26169 .50635 .25699 .50019 .22512 Mtetra
.571 .43 .651 r
.50019 .22512 .50635 .25699 .51789 .25229 .51167 .22178 Mtetra
.571 .435 .657 r
.51167 .22178 .51789 .25229 .52948 .24763 .5232 .21858 Mtetra
.571 .441 .665 r
.5232 .21858 .52948 .24763 .54111 .24302 .53479 .21553 Mtetra
.572 .449 .674 r
.53479 .21553 .54111 .24302 .55279 .2385 .54644 .21263 Mtetra
.572 .457 .684 r
.54644 .21263 .55279 .2385 .56452 .2341 .55815 .20989 Mtetra
.572 .467 .696 r
.55815 .20989 .56452 .2341 .5763 .22984 .56993 .20733 Mtetra
.572 .478 .709 r
.56993 .20733 .5763 .22984 .58814 .22576 .58177 .20495 Mtetra
.571 .49 .725 r
.58177 .20495 .58814 .22576 .60003 .2219 .59368 .20276 Mtetra
.569 .504 .743 r
.59368 .20276 .60003 .2219 .61198 .2183 .60567 .20077 Mtetra
.567 .52 .762 r
.60567 .20077 .61198 .2183 .624 .21497 .61773 .19898 Mtetra
.564 .537 .784 r
.61773 .19898 .624 .21497 .63609 .21197 .62987 .19739 Mtetra
.56 .556 .806 r
.62987 .19739 .63609 .21197 .64826 .20927 .64209 .19595 Mtetra
.555 .575 .829 r
.64209 .19595 .64826 .20927 .66051 .20687 .6544 .19464 Mtetra
.55 .594 .85 r
.6544 .19464 .66051 .20687 .67283 .20474 .66679 .19343 Mtetra
.545 .612 .87 r
.66679 .19343 .67283 .20474 .68525 .20283 .67926 .19227 Mtetra
.54 .628 .887 r
.67926 .19227 .68525 .20283 .69775 .20108 .69182 .19115 Mtetra
.536 .643 .902 r
.69182 .19115 .69775 .20108 .71033 .19944 .70446 .19001 Mtetra
.532 .656 .914 r
.70446 .19001 .71033 .19944 .723 .19787 .71718 .18887 Mtetra
.529 .667 .925 r
.71718 .18887 .723 .19787 .73574 .19632 .72999 .18769 Mtetra
.527 .678 .934 r
.72999 .18769 .73574 .19632 .74857 .19475 .74288 .18646 Mtetra
.746 .767 .87 r
.07322 .41517 .0807 .4217 .09106 .41504 .08358 .40871 Mtetra
.749 .774 .873 r
.08358 .40871 .09106 .41504 .10145 .40833 .09397 .40219 Mtetra
.752 .78 .876 r
.09397 .40219 .10145 .40833 .11186 .40159 .10438 .39562 Mtetra
.754 .786 .879 r
.10438 .39562 .11186 .40159 .12229 .39482 .11483 .38899 Mtetra
.757 .792 .881 r
.11483 .38899 .12229 .39482 .13275 .38805 .1253 .3823 Mtetra
.758 .795 .883 r
.1253 .3823 .13275 .38805 .14322 .38129 .13579 .37559 Mtetra
.758 .798 .885 r
.13579 .37559 .14322 .38129 .1537 .37459 .1463 .36889 Mtetra
.757 .799 .887 r
.1463 .36889 .1537 .37459 .16419 .36797 .15683 .36222 Mtetra
.755 .798 .888 r
.15683 .36222 .16419 .36797 .17469 .36146 .16737 .35562 Mtetra
.752 .796 .888 r
.16737 .35562 .17469 .36146 .1852 .35511 .17793 .34911 Mtetra
.747 .792 .889 r
.17793 .34911 .1852 .35511 .19571 .34894 .18849 .34272 Mtetra
.742 .785 .888 r
.18849 .34272 .19571 .34894 .20622 .34296 .19906 .33647 Mtetra
.736 .778 .886 r
.19906 .33647 .20622 .34296 .21674 .33717 .20964 .33036 Mtetra
.73 .768 .883 r
.20964 .33036 .21674 .33717 .22727 .33156 .22023 .32439 Mtetra
.724 .757 .879 r
.22023 .32439 .22727 .33156 .23781 .32613 .23084 .31856 Mtetra
.717 .746 .874 r
.23084 .31856 .23781 .32613 .24837 .32087 .24146 .31286 Mtetra
.71 .733 .869 r
.24146 .31286 .24837 .32087 .25895 .31577 .2521 .30729 Mtetra
.704 .72 .862 r
.2521 .30729 .25895 .31577 .26954 .31081 .26275 .30185 Mtetra
.697 .707 .856 r
.26275 .30185 .26954 .31081 .28016 .306 .27343 .29654 Mtetra
.69 .693 .849 r
.27343 .29654 .28016 .306 .2908 .30132 .28413 .29135 Mtetra
.683 .681 .841 r
.28413 .29135 .2908 .30132 .30147 .29676 .29485 .28629 Mtetra
.676 .668 .835 r
.29485 .28629 .30147 .29676 .31217 .2923 .3056 .28136 Mtetra
.67 .657 .828 r
.3056 .28136 .31217 .2923 .3229 .28794 .31638 .27654 Mtetra
.664 .646 .822 r
.31638 .27654 .3229 .28794 .33367 .28366 .32718 .27185 Mtetra
.659 .637 .817 r
.32718 .27185 .33367 .28366 .34447 .27944 .33802 .26726 Mtetra
.653 .628 .812 r
.33802 .26726 .34447 .27944 .35532 .27528 .34888 .26279 Mtetra
.649 .621 .809 r
.34888 .26279 .35532 .27528 .3662 .27117 .35979 .25843 Mtetra
.645 .616 .806 r
.35979 .25843 .3662 .27117 .37712 .2671 .37072 .25417 Mtetra
.641 .612 .805 r
.37072 .25417 .37712 .2671 .38808 .26305 .3817 .25002 Mtetra
.638 .609 .804 r
.3817 .25002 .38808 .26305 .39909 .25904 .39271 .24598 Mtetra
.635 .607 .805 r
.39271 .24598 .39909 .25904 .41014 .25506 .40377 .24204 Mtetra
.632 .607 .807 r
.40377 .24204 .41014 .25506 .42123 .25111 .41487 .2382 Mtetra
.629 .609 .81 r
.41487 .2382 .42123 .25111 .43237 .2472 .42601 .23447 Mtetra
.627 .611 .815 r
.42601 .23447 .43237 .2472 .44355 .24334 .43719 .23085 Mtetra
.624 .615 .821 r
.43719 .23085 .44355 .24334 .45478 .23953 .44843 .22735 Mtetra
.622 .62 .827 r
.44843 .22735 .45478 .23953 .46606 .23579 .45971 .22396 Mtetra
.619 .626 .835 r
.45971 .22396 .46606 .23579 .47739 .23213 .47104 .22069 Mtetra
.616 .633 .844 r
.47104 .22069 .47739 .23213 .48876 .22857 .48242 .21755 Mtetra
.613 .641 .854 r
.48242 .21755 .48876 .22857 .50019 .22512 .49386 .21453 Mtetra
.609 .65 .865 r
.49386 .21453 .50019 .22512 .51167 .22178 .50536 .21164 Mtetra
.605 .659 .877 r
.50536 .21164 .51167 .22178 .5232 .21858 .51691 .20888 Mtetra
.599 .669 .888 r
.51691 .20888 .5232 .21858 .53479 .21553 .52852 .20626 Mtetra
.593 .678 .9 r
.52852 .20626 .53479 .21553 .54644 .21263 .5402 .20377 Mtetra
.586 .687 .911 r
.5402 .20377 .54644 .21263 .55815 .20989 .55194 .20142 Mtetra
.578 .696 .922 r
.55194 .20142 .55815 .20989 .56993 .20733 .56375 .1992 Mtetra
.568 .703 .933 r
.56375 .1992 .56993 .20733 .58177 .20495 .57562 .19713 Mtetra
.558 .71 .942 r
.57562 .19713 .58177 .20495 .59368 .20276 .58757 .19521 Mtetra
.547 .714 .95 r
.58757 .19521 .59368 .20276 .60567 .20077 .59959 .19344 Mtetra
.536 .717 .956 r
.59959 .19344 .60567 .20077 .61773 .19898 .61169 .19181 Mtetra
.526 .719 .961 r
.61169 .19181 .61773 .19898 .62987 .19739 .62387 .19031 Mtetra
.518 .719 .964 r
.62387 .19031 .62987 .19739 .64209 .19595 .63613 .18892 Mtetra
.512 .719 .966 r
.63613 .18892 .64209 .19595 .6544 .19464 .64848 .1876 Mtetra
.509 .718 .966 r
.64848 .1876 .6544 .19464 .66679 .19343 .6609 .18632 Mtetra
.509 .717 .966 r
.6609 .18632 .66679 .19343 .67926 .19227 .6734 .18505 Mtetra
.511 .715 .964 r
.6734 .18505 .67926 .19227 .69182 .19115 .68599 .18377 Mtetra
.515 .713 .961 r
.68599 .18377 .69182 .19115 .70446 .19001 .69865 .18243 Mtetra
.52 .709 .957 r
.69865 .18243 .70446 .19001 .71718 .18887 .7114 .18105 Mtetra
.525 .705 .953 r
.7114 .18105 .71718 .18887 .72999 .18769 .72423 .17961 Mtetra
.531 .7 .947 r
.72423 .17961 .72999 .18769 .74288 .18646 .73713 .1781 Mtetra
.728 .765 .882 r
.06568 .40859 .07322 .41517 .08358 .40871 .07597 .40284 Mtetra
.734 .787 .895 r
.07597 .40284 .08358 .40871 .09397 .40219 .08629 .39701 Mtetra
.74 .81 .908 r
.08629 .39701 .09397 .40219 .10438 .39562 .09664 .39112 Mtetra
.744 .834 .92 r
.09664 .39112 .10438 .39562 .11483 .38899 .10703 .38516 Mtetra
.748 .858 .93 r
.10703 .38516 .11483 .38899 .1253 .3823 .11746 .37913 Mtetra
.748 .88 .94 r
.11746 .37913 .1253 .3823 .13579 .37559 .12791 .37306 Mtetra
.745 .902 .948 r
.12791 .37306 .13579 .37559 .1463 .36889 .13839 .36698 Mtetra
.738 .923 .953 r
.13839 .36698 .1463 .36889 .15683 .36222 .14888 .36092 Mtetra
.725 .94 .955 r
.14888 .36092 .15683 .36222 .16737 .35562 .1594 .35491 Mtetra
.707 .953 .952 r
.1594 .35491 .16737 .35562 .17793 .34911 .16994 .34897 Mtetra
.682 .96 .943 r
.16994 .34897 .17793 .34911 .18849 .34272 .18049 .3431 Mtetra
.652 .961 .928 r
.18049 .3431 .18849 .34272 .19906 .33647 .19106 .33732 Mtetra
.618 .955 .908 r
.19106 .33732 .19906 .33647 .20964 .33036 .20165 .33163 Mtetra
.582 .944 .884 r
.20165 .33163 .20964 .33036 .22023 .32439 .21226 .32603 Mtetra
.546 .929 .858 r
.21226 .32603 .22023 .32439 .23084 .31856 .22289 .3205 Mtetra
.512 .913 .831 r
.22289 .3205 .23084 .31856 .24146 .31286 .23354 .31505 Mtetra
.481 .896 .807 r
.23354 .31505 .24146 .31286 .2521 .30729 .24422 .30967 Mtetra
.453 .879 .785 r
.24422 .30967 .2521 .30729 .26275 .30185 .25492 .30436 Mtetra
.43 .865 .767 r
.25492 .30436 .26275 .30185 .27343 .29654 .26565 .29913 Mtetra
.41 .852 .754 r
.26565 .29913 .27343 .29654 .28413 .29135 .27641 .29397 Mtetra
.394 .842 .744 r
.27641 .29397 .28413 .29135 .29485 .28629 .28719 .2889 Mtetra
.381 .834 .738 r
.28719 .2889 .29485 .28629 .3056 .28136 .298 .28392 Mtetra
.37 .827 .735 r
.298 .28392 .3056 .28136 .31638 .27654 .30884 .27903 Mtetra
.361 .822 .733 r
.30884 .27903 .31638 .27654 .32718 .27185 .31971 .27425 Mtetra
.352 .818 .734 r
.31971 .27425 .32718 .27185 .33802 .26726 .33061 .26957 Mtetra
.344 .813 .734 r
.33061 .26957 .33802 .26726 .34888 .26279 .34155 .26501 Mtetra
.334 .808 .735 r
.34155 .26501 .34888 .26279 .35979 .25843 .35251 .26057 Mtetra
.324 .802 .734 r
.35251 .26057 .35979 .25843 .37072 .25417 .36351 .25625 Mtetra
.312 .794 .732 r
.36351 .25625 .37072 .25417 .3817 .25002 .37455 .25205 Mtetra
.298 .786 .727 r
.37455 .25205 .3817 .25002 .39271 .24598 .38563 .24798 Mtetra
.283 .775 .721 r
.38563 .24798 .39271 .24598 .40377 .24204 .39675 .24404 Mtetra
.265 .763 .712 r
.39675 .24404 .40377 .24204 .41487 .2382 .4079 .24022 Mtetra
.247 .75 .701 r
.4079 .24022 .41487 .2382 .42601 .23447 .4191 .23652 Mtetra
.227 .736 .689 r
.4191 .23652 .42601 .23447 .43719 .23085 .43035 .23295 Mtetra
0 0 0 r
.43035 .23295 .43719 .23085 .44843 .22735 .44165 .22949 Mtetra
.44165 .22949 .44843 .22735 .45971 .22396 .45299 .22614 Mtetra
.45299 .22614 .45971 .22396 .47104 .22069 .46439 .2229 Mtetra
.46439 .2229 .47104 .22069 .48242 .21755 .47584 .21975 Mtetra
.47584 .21975 .48242 .21755 .49386 .21453 .48734 .2167 Mtetra
.48734 .2167 .49386 .21453 .50536 .21164 .4989 .21374 Mtetra
.4989 .21374 .50536 .21164 .51691 .20888 .51052 .21085 Mtetra
.51052 .21085 .51691 .20888 .52852 .20626 .5222 .20805 Mtetra
.5222 .20805 .52852 .20626 .5402 .20377 .53394 .20531 Mtetra
.53394 .20531 .5402 .20377 .55194 .20142 .54575 .20266 Mtetra
.159 .694 .702 r
.54575 .20266 .55194 .20142 .56375 .1992 .55762 .20008 Mtetra
.179 .711 .735 r
.55762 .20008 .56375 .1992 .57562 .19713 .56955 .19759 Mtetra
.204 .731 .772 r
.56955 .19759 .57562 .19713 .58757 .19521 .58155 .19519 Mtetra
.233 .752 .813 r
.58155 .19519 .58757 .19521 .59959 .19344 .59363 .19288 Mtetra
.268 .773 .856 r
.59363 .19288 .59959 .19344 .61169 .19181 .60577 .19066 Mtetra
.305 .791 .898 r
.60577 .19066 .61169 .19181 .62387 .19031 .61799 .18853 Mtetra
.344 .805 .935 r
.61799 .18853 .62387 .19031 .63613 .18892 .63029 .18647 Mtetra
.383 .812 .965 r
.63029 .18647 .63613 .18892 .64848 .1876 .64265 .18446 Mtetra
.42 .814 .985 r
.64265 .18446 .64848 .1876 .6609 .18632 .6551 .18248 Mtetra
.454 .81 .997 r
.6551 .18248 .6609 .18632 .6734 .18505 .66762 .18049 Mtetra
.484 .801 1 r
.66762 .18049 .6734 .18505 .68599 .18377 .68022 .17847 Mtetra
.511 .788 .995 r
.68022 .17847 .68599 .18377 .69865 .18243 .69289 .17637 Mtetra
.532 .771 .985 r
.69289 .17637 .69865 .18243 .7114 .18105 .70563 .17421 Mtetra
.548 .752 .972 r
.70563 .17421 .7114 .18105 .72423 .17961 .71845 .17198 Mtetra
.561 .732 .955 r
.71845 .17198 .72423 .17961 .73713 .1781 .73134 .16968 Mtetra
.691 .759 .904 r
.05808 .40196 .06568 .40859 .07597 .40284 .06823 .3974 Mtetra
.697 .798 .928 r
.06823 .3974 .07597 .40284 .08629 .39701 .07841 .39276 Mtetra
.699 .84 .95 r
.07841 .39276 .08629 .39701 .09664 .39112 .08864 .38804 Mtetra
.696 .88 .967 r
.08864 .38804 .09664 .39112 .10703 .38516 .09891 .38322 Mtetra
.684 .915 .973 r
.09891 .38322 .10703 .38516 .11746 .37913 .10923 .37827 Mtetra
.66 .939 .965 r
.10923 .37827 .11746 .37913 .12791 .37306 .1196 .37324 Mtetra
.622 .948 .94 r
.1196 .37324 .12791 .37306 .13839 .36698 .13001 .36811 Mtetra
.571 .939 .897 r
.13001 .36811 .13839 .36698 .14888 .36092 .14045 .36293 Mtetra
.51 .912 .84 r
.14045 .36293 .14888 .36092 .1594 .35491 .15093 .35771 Mtetra
.444 .873 .775 r
.15093 .35771 .1594 .35491 .16994 .34897 .16144 .35248 Mtetra
.378 .826 .706 r
.16144 .35248 .16994 .34897 .18049 .3431 .17198 .34726 Mtetra
.316 .776 .639 r
.17198 .34726 .18049 .3431 .19106 .33732 .18255 .34205 Mtetra
0 0 0 r
.18255 .34205 .19106 .33732 .20165 .33163 .19315 .33688 Mtetra
.19315 .33688 .20165 .33163 .21226 .32603 .20377 .33174 Mtetra
.20377 .33174 .21226 .32603 .22289 .3205 .21443 .32665 Mtetra
.21443 .32665 .22289 .3205 .23354 .31505 .22511 .32158 Mtetra
.22511 .32158 .23354 .31505 .24422 .30967 .23583 .31656 Mtetra
.23583 .31656 .24422 .30967 .25492 .30436 .24657 .31158 Mtetra
.24657 .31158 .25492 .30436 .26565 .29913 .25735 .30664 Mtetra
.25735 .30664 .26565 .29913 .27641 .29397 .26816 .30175 Mtetra
.02 0 0 r
.26816 .30175 .27641 .29397 .28719 .2889 .279 .29692 Mtetra
.041 0 0 r
.279 .29692 .28719 .2889 .298 .28392 .28987 .29215 Mtetra
.06 0 0 r
.28987 .29215 .298 .28392 .30884 .27903 .30078 .28745 Mtetra
.077 0 0 r
.30078 .28745 .30884 .27903 .31971 .27425 .31172 .28283 Mtetra
.092 0 0 r
.31172 .28283 .31971 .27425 .33061 .26957 .32269 .27828 Mtetra
.106 0 0 r
.32269 .27828 .33061 .26957 .34155 .26501 .3337 .27383 Mtetra
.119 0 0 r
.3337 .27383 .34155 .26501 .35251 .26057 .34475 .26946 Mtetra
.13 0 0 r
.34475 .26946 .35251 .26057 .36351 .25625 .35583 .26518 Mtetra
.14 0 0 r
.35583 .26518 .36351 .25625 .37455 .25205 .36695 .26099 Mtetra
.149 0 0 r
.36695 .26099 .37455 .25205 .38563 .24798 .37812 .2569 Mtetra
.156 0 0 r
.37812 .2569 .38563 .24798 .39675 .24404 .38932 .25291 Mtetra
.162 0 0 r
.38932 .25291 .39675 .24404 .4079 .24022 .40057 .24901 Mtetra
.167 0 0 r
.40057 .24901 .4079 .24022 .4191 .23652 .41186 .24521 Mtetra
.17 0 0 r
.41186 .24521 .4191 .23652 .43035 .23295 .4232 .24149 Mtetra
.172 0 0 r
.4232 .24149 .43035 .23295 .44165 .22949 .43459 .23786 Mtetra
.43459 .23786 .44165 .22949 .45299 .22614 .44603 .23431 Mtetra
.171 0 0 r
.44603 .23431 .45299 .22614 .46439 .2229 .45751 .23084 Mtetra
.169 0 0 r
.45751 .23084 .46439 .2229 .47584 .21975 .46905 .22744 Mtetra
.165 0 0 r
.46905 .22744 .47584 .21975 .48734 .2167 .48065 .2241 Mtetra
.159 0 0 r
.48065 .2241 .48734 .2167 .4989 .21374 .4923 .22083 Mtetra
.151 0 0 r
.4923 .22083 .4989 .21374 .51052 .21085 .50401 .2176 Mtetra
.142 0 0 r
.50401 .2176 .51052 .21085 .5222 .20805 .51578 .21442 Mtetra
.13 0 0 r
.51578 .21442 .5222 .20805 .53394 .20531 .5276 .21129 Mtetra
.115 0 0 r
.5276 .21129 .53394 .20531 .54575 .20266 .53949 .20819 Mtetra
.098 0 0 r
.53949 .20819 .54575 .20266 .55762 .20008 .55144 .20513 Mtetra
.077 0 0 r
.55144 .20513 .55762 .20008 .56955 .19759 .56345 .20212 Mtetra
.051 0 0 r
.56345 .20212 .56955 .19759 .58155 .19519 .57552 .19914 Mtetra
.021 0 0 r
.57552 .19914 .58155 .19519 .59363 .19288 .58766 .19619 Mtetra
0 0 0 r
.58766 .19619 .59363 .19288 .60577 .19066 .59987 .19327 Mtetra
.59987 .19327 .60577 .19066 .61799 .18853 .61214 .19035 Mtetra
.61214 .19035 .61799 .18853 .63029 .18647 .62448 .18742 Mtetra
.2 .726 .732 r
.62448 .18742 .63029 .18647 .64265 .18446 .63689 .18446 Mtetra
.284 .785 .823 r
.63689 .18446 .64265 .18446 .6551 .18248 .64936 .18144 Mtetra
.372 .833 .904 r
.64936 .18144 .6551 .18248 .66762 .18049 .66189 .17832 Mtetra
.453 .86 .963 r
.66189 .17832 .66762 .18049 .68022 .17847 .67449 .17511 Mtetra
.52 .862 .993 r
.67449 .17511 .68022 .17847 .69289 .17637 .68715 .17177 Mtetra
.567 .843 .996 r
.68715 .17177 .69289 .17637 .70563 .17421 .69987 .16833 Mtetra
.597 .811 .982 r
.69987 .16833 .70563 .17421 .71845 .17198 .71266 .1648 Mtetra
.614 .774 .957 r
.71266 .1648 .71845 .17198 .73134 .16968 .7255 .16118 Mtetra
.635 .746 .928 r
.05043 .39529 .05808 .40196 .06823 .3974 .06039 .39213 Mtetra
.633 .793 .959 r
.06039 .39213 .06823 .3974 .07841 .39276 .0704 .3889 Mtetra
.622 .841 .984 r
.0704 .3889 .07841 .39276 .08864 .38804 .08047 .38557 Mtetra
.598 .881 .992 r
.08047 .38557 .08864 .38804 .09891 .38322 .09059 .38211 Mtetra
.557 .904 .974 r
.09059 .38211 .09891 .38322 .10923 .37827 .10078 .37848 Mtetra
.494 .899 .923 r
.10078 .37848 .10923 .37827 .1196 .37324 .11102 .37471 Mtetra
.415 .864 .84 r
.11102 .37471 .1196 .37324 .13001 .36811 .12133 .37077 Mtetra
.328 .805 .738 r
.12133 .37077 .13001 .36811 .14045 .36293 .13169 .36669 Mtetra
0 0 0 r
.13169 .36669 .14045 .36293 .15093 .35771 .1421 .36249 Mtetra
.1421 .36249 .15093 .35771 .16144 .35248 .15257 .3582 Mtetra
.15257 .3582 .16144 .35248 .17198 .34726 .16307 .35384 Mtetra
.16307 .35384 .17198 .34726 .18255 .34205 .17362 .34944 Mtetra
.006 0 0 r
.17362 .34944 .18255 .34205 .19315 .33688 .18421 .34501 Mtetra
.047 0 0 r
.18421 .34501 .19315 .33688 .20377 .33174 .19484 .34057 Mtetra
.082 0 0 r
.19484 .34057 .20377 .33174 .21443 .32665 .2055 .33612 Mtetra
.112 0 0 r
.2055 .33612 .21443 .32665 .22511 .32158 .21621 .33167 Mtetra
.137 0 0 r
.21621 .33167 .22511 .32158 .23583 .31656 .22695 .32723 Mtetra
.16 0 0 r
.22695 .32723 .23583 .31656 .24657 .31158 .23773 .32279 Mtetra
.179 0 0 r
.23773 .32279 .24657 .31158 .25735 .30664 .24855 .31837 Mtetra
.197 0 0 r
.24855 .31837 .25735 .30664 .26816 .30175 .25941 .31397 Mtetra
.212 0 0 r
.25941 .31397 .26816 .30175 .279 .29692 .2703 .30959 Mtetra
.225 0 .012 r
.2703 .30959 .279 .29692 .28987 .29215 .28124 .30523 Mtetra
.237 0 .029 r
.28124 .30523 .28987 .29215 .30078 .28745 .29221 .3009 Mtetra
.248 0 .043 r
.29221 .3009 .30078 .28745 .31172 .28283 .30323 .2966 Mtetra
.256 0 .055 r
.30323 .2966 .31172 .28283 .32269 .27828 .31428 .29233 Mtetra
.264 0 .065 r
.31428 .29233 .32269 .27828 .3337 .27383 .32538 .28809 Mtetra
.271 0 .073 r
.32538 .28809 .3337 .27383 .34475 .26946 .33652 .28389 Mtetra
.276 0 .079 r
.33652 .28389 .34475 .26946 .35583 .26518 .3477 .27971 Mtetra
.28 0 .083 r
.3477 .27971 .35583 .26518 .36695 .26099 .35892 .27558 Mtetra
.283 0 .086 r
.35892 .27558 .36695 .26099 .37812 .2569 .37019 .27147 Mtetra
.285 0 .087 r
.37019 .27147 .37812 .2569 .38932 .25291 .38151 .2674 Mtetra
.286 0 .086 r
.38151 .2674 .38932 .25291 .40057 .24901 .39287 .26337 Mtetra
.286 0 .084 r
.39287 .26337 .40057 .24901 .41186 .24521 .40428 .25937 Mtetra
.285 0 .08 r
.40428 .25937 .41186 .24521 .4232 .24149 .41573 .2554 Mtetra
.283 0 .074 r
.41573 .2554 .4232 .24149 .43459 .23786 .42724 .25146 Mtetra
.28 0 .067 r
.42724 .25146 .43459 .23786 .44603 .23431 .43879 .24755 Mtetra
.276 0 .057 r
.43879 .24755 .44603 .23431 .45751 .23084 .4504 .24368 Mtetra
.271 0 .046 r
.4504 .24368 .45751 .23084 .46905 .22744 .46206 .23983 Mtetra
.264 0 .033 r
.46206 .23983 .46905 .22744 .48065 .2241 .47377 .236 Mtetra
.256 0 .017 r
.47377 .236 .48065 .2241 .4923 .22083 .48553 .2322 Mtetra
.247 0 0 r
.48553 .2322 .4923 .22083 .50401 .2176 .49735 .22842 Mtetra
.235 0 0 r
.49735 .22842 .50401 .2176 .51578 .21442 .50922 .22464 Mtetra
.222 0 0 r
.50922 .22464 .51578 .21442 .5276 .21129 .52115 .22088 Mtetra
.206 0 0 r
.52115 .22088 .5276 .21129 .53949 .20819 .53313 .21712 Mtetra
.187 0 0 r
.53313 .21712 .53949 .20819 .55144 .20513 .54518 .21336 Mtetra
.165 0 0 r
.54518 .21336 .55144 .20513 .56345 .20212 .55728 .20959 Mtetra
.137 0 0 r
.55728 .20959 .56345 .20212 .57552 .19914 .56943 .2058 Mtetra
.103 0 0 r
.56943 .2058 .57552 .19914 .58766 .19619 .58165 .20199 Mtetra
.059 0 0 r
.58165 .20199 .58766 .19619 .59987 .19327 .59393 .19814 Mtetra
.003 0 0 r
.59393 .19814 .59987 .19327 .61214 .19035 .60626 .19421 Mtetra
0 0 0 r
.60626 .19421 .61214 .19035 .62448 .18742 .61865 .19018 Mtetra
.61865 .19018 .62448 .18742 .63689 .18446 .63109 .18602 Mtetra
.266 .764 .711 r
.63109 .18602 .63689 .18446 .64936 .18144 .64359 .18172 Mtetra
.383 .846 .829 r
.64359 .18172 .64936 .18144 .66189 .17832 .65614 .17724 Mtetra
.492 .898 .922 r
.65614 .17724 .66189 .17832 .67449 .17511 .66874 .1726 Mtetra
.578 .912 .974 r
.66874 .1726 .67449 .17511 .68715 .17177 .68138 .16779 Mtetra
.633 .892 .986 r
.68138 .16779 .68715 .17177 .69987 .16833 .69408 .16283 Mtetra
.662 .852 .973 r
.69408 .16283 .69987 .16833 .71266 .1648 .70682 .15776 Mtetra
.673 .805 .946 r
.70682 .15776 .71266 .1648 .7255 .16118 .71961 .15261 Mtetra
.563 .724 .949 r
.04273 .38856 .05043 .39529 .06039 .39213 .0525 .38676 Mtetra
.548 .767 .979 r
.0525 .38676 .06039 .39213 .0704 .3889 .06234 .38489 Mtetra
.523 .807 .998 r
.06234 .38489 .0704 .3889 .08047 .38557 .07224 .38293 Mtetra
.48 .836 .995 r
.07224 .38293 .08047 .38557 .09059 .38211 .0822 .38084 Mtetra
.418 .842 .958 r
.0822 .38084 .09059 .38211 .10078 .37848 .09224 .37859 Mtetra
.334 .814 .878 r
.09224 .37859 .10078 .37848 .11102 .37471 .10234 .37619 Mtetra
.237 .752 .762 r
.10234 .37619 .11102 .37471 .12133 .37077 .11252 .37362 Mtetra
0 0 0 r
.11252 .37362 .12133 .37077 .13169 .36669 .12276 .3709 Mtetra
.12276 .3709 .13169 .36669 .1421 .36249 .13306 .36804 Mtetra
.031 0 0 r
.13306 .36804 .1421 .36249 .15257 .3582 .14343 .36506 Mtetra
.094 0 0 r
.14343 .36506 .15257 .3582 .16307 .35384 .15385 .36198 Mtetra
.144 0 0 r
.15385 .36198 .16307 .35384 .17362 .34944 .16433 .3588 Mtetra
.184 0 0 r
.16433 .3588 .17362 .34944 .18421 .34501 .17487 .35554 Mtetra
.215 0 0 r
.17487 .35554 .18421 .34501 .19484 .34057 .18546 .35221 Mtetra
.24 0 0 r
.18546 .35221 .19484 .34057 .2055 .33612 .1961 .34882 Mtetra
.261 0 .026 r
.1961 .34882 .2055 .33612 .21621 .33167 .20679 .34536 Mtetra
.277 0 .056 r
.20679 .34536 .21621 .33167 .22695 .32723 .21754 .34184 Mtetra
.29 0 .082 r
.21754 .34184 .22695 .32723 .23773 .32279 .22833 .33826 Mtetra
.301 0 .103 r
.22833 .33826 .23773 .32279 .24855 .31837 .23918 .33463 Mtetra
.311 0 .121 r
.23918 .33463 .24855 .31837 .25941 .31397 .25008 .33094 Mtetra
.318 0 .136 r
.25008 .33094 .25941 .31397 .2703 .30959 .26103 .3272 Mtetra
.325 0 .148 r
.26103 .3272 .2703 .30959 .28124 .30523 .27203 .32341 Mtetra
.33 0 .158 r
.27203 .32341 .28124 .30523 .29221 .3009 .28308 .31958 Mtetra
.334 0 .167 r
.28308 .31958 .29221 .3009 .30323 .2966 .29418 .3157 Mtetra
.337 0 .174 r
.29418 .3157 .30323 .2966 .31428 .29233 .30532 .31178 Mtetra
.34 0 .179 r
.30532 .31178 .31428 .29233 .32538 .28809 .31652 .30782 Mtetra
.342 0 .184 r
.31652 .30782 .32538 .28809 .33652 .28389 .32777 .30383 Mtetra
.343 0 .187 r
.32777 .30383 .33652 .28389 .3477 .27971 .33907 .29979 Mtetra
.344 0 .189 r
.33907 .29979 .3477 .27971 .35892 .27558 .35042 .29571 Mtetra
.35042 .29571 .35892 .27558 .37019 .27147 .36181 .2916 Mtetra
.343 0 .189 r
.36181 .2916 .37019 .27147 .38151 .2674 .37326 .28745 Mtetra
.342 0 .188 r
.37326 .28745 .38151 .2674 .39287 .26337 .38476 .28326 Mtetra
.34 0 .185 r
.38476 .28326 .39287 .26337 .40428 .25937 .39631 .27903 Mtetra
.338 0 .182 r
.39631 .27903 .40428 .25937 .41573 .2554 .4079 .27476 Mtetra
.334 0 .177 r
.4079 .27476 .41573 .2554 .42724 .25146 .41955 .27044 Mtetra
.33 0 .171 r
.41955 .27044 .42724 .25146 .43879 .24755 .43125 .26609 Mtetra
.325 0 .163 r
.43125 .26609 .43879 .24755 .4504 .24368 .443 .26169 Mtetra
.319 0 .153 r
.443 .26169 .4504 .24368 .46206 .23983 .4548 .25723 Mtetra
.311 0 .142 r
.4548 .25723 .46206 .23983 .47377 .236 .46665 .25273 Mtetra
.302 0 .128 r
.46665 .25273 .47377 .236 .48553 .2322 .47855 .24818 Mtetra
.291 0 .111 r
.47855 .24818 .48553 .2322 .49735 .22842 .4905 .24356 Mtetra
.277 0 .091 r
.4905 .24356 .49735 .22842 .50922 .22464 .5025 .23889 Mtetra
.261 0 .067 r
.5025 .23889 .50922 .22464 .52115 .22088 .51455 .23415 Mtetra
.242 0 .038 r
.51455 .23415 .52115 .22088 .53313 .21712 .52665 .22935 Mtetra
.218 0 .004 r
.52665 .22935 .53313 .21712 .54518 .21336 .53881 .22447 Mtetra
.189 0 0 r
.53881 .22447 .54518 .21336 .55728 .20959 .55101 .21953 Mtetra
.152 0 0 r
.55101 .21953 .55728 .20959 .56943 .2058 .56326 .2145 Mtetra
.105 0 0 r
.56326 .2145 .56943 .2058 .58165 .20199 .57556 .20939 Mtetra
.045 0 0 r
.57556 .20939 .58165 .20199 .59393 .19814 .5879 .20418 Mtetra
0 0 0 r
.5879 .20418 .59393 .19814 .60626 .19421 .6003 .19885 Mtetra
.6003 .19885 .60626 .19421 .61865 .19018 .61274 .19339 Mtetra
.61274 .19339 .61865 .19018 .63109 .18602 .62522 .18778 Mtetra
.374 .829 .73 r
.62522 .18778 .63109 .18602 .64359 .18172 .63774 .182 Mtetra
.499 .907 .849 r
.63774 .182 .64359 .18172 .65614 .17724 .65031 .17604 Mtetra
.599 .944 .928 r
.65031 .17604 .65614 .17724 .66874 .1726 .66291 .16991 Mtetra
.667 .941 .964 r
.66291 .16991 .66874 .1726 .68138 .16779 .67554 .16361 Mtetra
.704 .911 .967 r
.67554 .16361 .68138 .16779 .69408 .16283 .68822 .15716 Mtetra
.72 .868 .951 r
.68822 .15716 .69408 .16283 .70682 .15776 .70093 .15061 Mtetra
.723 .821 .926 r
.70093 .15061 .70682 .15776 .71961 .15261 .71368 .14397 Mtetra
.485 .695 .961 r
.03496 .38178 .04273 .38856 .0525 .38676 .04458 .38111 Mtetra
.463 .727 .983 r
.04458 .38111 .0525 .38676 .06234 .38489 .05427 .38037 Mtetra
.433 .755 .995 r
.05427 .38037 .06234 .38489 .07224 .38293 .06403 .37954 Mtetra
.391 .775 .99 r
.06403 .37954 .07224 .38293 .0822 .38084 .07385 .37859 Mtetra
.336 .779 .961 r
.07385 .37859 .0822 .38084 .09224 .37859 .08376 .37751 Mtetra
.266 .761 .901 r
.08376 .37751 .09224 .37859 .10234 .37619 .09374 .37629 Mtetra
.186 .719 .811 r
.09374 .37629 .10234 .37619 .11252 .37362 .10379 .37493 Mtetra
0 0 0 r
.10379 .37493 .11252 .37362 .12276 .3709 .11392 .37343 Mtetra
.11392 .37343 .12276 .3709 .13306 .36804 .12411 .3718 Mtetra
.05 0 0 r
.12411 .3718 .13306 .36804 .14343 .36506 .13438 .37005 Mtetra
.109 0 0 r
.13438 .37005 .14343 .36506 .15385 .36198 .14472 .36816 Mtetra
.156 0 0 r
.14472 .36816 .15385 .36198 .16433 .3588 .15513 .36615 Mtetra
.193 0 0 r
.15513 .36615 .16433 .3588 .17487 .35554 .1656 .36402 Mtetra
.222 0 0 r
.1656 .36402 .17487 .35554 .18546 .35221 .17614 .36177 Mtetra
.245 0 0 r
.17614 .36177 .18546 .35221 .1961 .34882 .18675 .3594 Mtetra
.263 0 0 r
.18675 .3594 .1961 .34882 .20679 .34536 .19743 .35691 Mtetra
.277 0 .003 r
.19743 .35691 .20679 .34536 .21754 .34184 .20816 .35429 Mtetra
.288 0 .031 r
.20816 .35429 .21754 .34184 .22833 .33826 .21897 .35154 Mtetra
.297 0 .054 r
.21897 .35154 .22833 .33826 .23918 .33463 .22984 .34867 Mtetra
.304 0 .073 r
.22984 .34867 .23918 .33463 .25008 .33094 .24077 .34568 Mtetra
.309 0 .089 r
.24077 .34568 .25008 .33094 .26103 .3272 .25176 .34256 Mtetra
.313 0 .102 r
.25176 .34256 .26103 .3272 .27203 .32341 .26282 .33932 Mtetra
.316 0 .113 r
.26282 .33932 .27203 .32341 .28308 .31958 .27394 .33597 Mtetra
.319 0 .122 r
.27394 .33597 .28308 .31958 .29418 .3157 .28511 .3325 Mtetra
.32 0 .129 r
.28511 .3325 .29418 .3157 .30532 .31178 .29635 .32891 Mtetra
.321 0 .134 r
.29635 .32891 .30532 .31178 .31652 .30782 .30764 .32522 Mtetra
.32 0 .138 r
.30764 .32522 .31652 .30782 .32777 .30383 .31899 .32142 Mtetra
.32 0 .14 r
.31899 .32142 .32777 .30383 .33907 .29979 .33039 .3175 Mtetra
.318 0 .141 r
.33039 .3175 .33907 .29979 .35042 .29571 .34186 .31349 Mtetra
.316 0 .141 r
.34186 .31349 .35042 .29571 .36181 .2916 .35337 .30936 Mtetra
.313 0 .14 r
.35337 .30936 .36181 .2916 .37326 .28745 .36495 .30513 Mtetra
.309 0 .137 r
.36495 .30513 .37326 .28745 .38476 .28326 .37657 .30079 Mtetra
.305 0 .133 r
.37657 .30079 .38476 .28326 .39631 .27903 .38825 .29634 Mtetra
.299 0 .128 r
.38825 .29634 .39631 .27903 .4079 .27476 .39998 .29178 Mtetra
.293 0 .121 r
.39998 .29178 .4079 .27476 .41955 .27044 .41177 .2871 Mtetra
.285 0 .112 r
.41177 .2871 .41955 .27044 .43125 .26609 .4236 .28231 Mtetra
.275 0 .101 r
.4236 .28231 .43125 .26609 .443 .26169 .43549 .2774 Mtetra
.264 0 .087 r
.43549 .2774 .443 .26169 .4548 .25723 .44743 .27236 Mtetra
.251 0 .071 r
.44743 .27236 .4548 .25723 .46665 .25273 .45941 .2672 Mtetra
.235 0 .052 r
.45941 .2672 .46665 .25273 .47855 .24818 .47145 .26191 Mtetra
.217 0 .029 r
.47145 .26191 .47855 .24818 .4905 .24356 .48353 .25649 Mtetra
.194 0 .001 r
.48353 .25649 .4905 .24356 .5025 .23889 .49565 .25093 Mtetra
.168 0 0 r
.49565 .25093 .5025 .23889 .51455 .23415 .50782 .24524 Mtetra
.136 0 0 r
.50782 .24524 .51455 .23415 .52665 .22935 .52004 .23941 Mtetra
.096 0 0 r
.52004 .23941 .52665 .22935 .53881 .22447 .5323 .23345 Mtetra
.049 0 0 r
.5323 .23345 .53881 .22447 .55101 .21953 .5446 .22736 Mtetra
0 0 0 r
.5446 .22736 .55101 .21953 .56326 .2145 .55694 .22113 Mtetra
.55694 .22113 .56326 .2145 .57556 .20939 .56932 .21477 Mtetra
.56932 .21477 .57556 .20939 .5879 .20418 .58174 .20827 Mtetra
.58174 .20827 .5879 .20418 .6003 .19885 .59419 .20163 Mtetra
.38 .818 .669 r
.59419 .20163 .6003 .19885 .61274 .19339 .60668 .19485 Mtetra
.491 .896 .778 r
.60668 .19485 .61274 .19339 .62522 .18778 .6192 .18792 Mtetra
.588 .947 .865 r
.6192 .18792 .62522 .18778 .63774 .182 .63176 .18083 Mtetra
.662 .966 .92 r
.63176 .18083 .63774 .182 .65031 .17604 .64435 .17358 Mtetra
.712 .959 .946 r
.64435 .17358 .65031 .17604 .66291 .16991 .65696 .16618 Mtetra
.742 .934 .951 r
.65696 .16618 .66291 .16991 .67554 .16361 .6696 .15863 Mtetra
.756 .9 .941 r
.6696 .15863 .67554 .16361 .68822 .15716 .68227 .15094 Mtetra
.759 .862 .925 r
.68227 .15094 .68822 .15716 .70093 .15061 .69497 .14314 Mtetra
.757 .824 .905 r
.69497 .14314 .70093 .15061 .71368 .14397 .70769 .13525 Mtetra
.426 .669 .963 r
.02714 .37496 .03496 .38178 .04458 .38111 .03666 .37499 Mtetra
.412 .689 .976 r
.03666 .37499 .04458 .38111 .05427 .38037 .04626 .37494 Mtetra
.396 .708 .985 r
.04626 .37494 .05427 .38037 .06403 .37954 .05593 .37479 Mtetra
.378 .724 .989 r
.05593 .37479 .06403 .37954 .07385 .37859 .06568 .37452 Mtetra
.358 .738 .987 r
.06568 .37452 .07385 .37859 .08376 .37751 .0755 .37414 Mtetra
.332 .747 .978 r
.0755 .37414 .08376 .37751 .09374 .37629 .08541 .37363 Mtetra
.301 .751 .959 r
.08541 .37363 .09374 .37629 .10379 .37493 .09539 .37299 Mtetra
.264 .746 .929 r
.09539 .37299 .10379 .37493 .11392 .37343 .10545 .37224 Mtetra
.222 .733 .886 r
.10545 .37224 .11392 .37343 .12411 .3718 .11558 .37135 Mtetra
.178 .71 .833 r
.11558 .37135 .12411 .3718 .13438 .37005 .12579 .37034 Mtetra
.134 .681 .772 r
.12579 .37034 .13438 .37005 .14472 .36816 .13608 .36919 Mtetra
.091 .647 .706 r
.13608 .36919 .14472 .36816 .15513 .36615 .14645 .36791 Mtetra
0 0 0 r
.14645 .36791 .15513 .36615 .1656 .36402 .15689 .36647 Mtetra
.15689 .36647 .1656 .36402 .17614 .36177 .1674 .36489 Mtetra
.013 0 0 r
.1674 .36489 .17614 .36177 .18675 .3594 .17799 .36315 Mtetra
.039 0 0 r
.17799 .36315 .18675 .3594 .19743 .35691 .18866 .36125 Mtetra
.059 0 0 r
.18866 .36125 .19743 .35691 .20816 .35429 .1994 .35919 Mtetra
.076 0 0 r
.1994 .35919 .20816 .35429 .21897 .35154 .21021 .35697 Mtetra
.09 0 0 r
.21021 .35697 .21897 .35154 .22984 .34867 .2211 .35458 Mtetra
.1 0 0 r
.2211 .35458 .22984 .34867 .24077 .34568 .23206 .35203 Mtetra
.108 0 0 r
.23206 .35203 .24077 .34568 .25176 .34256 .24309 .34931 Mtetra
.114 0 0 r
.24309 .34931 .25176 .34256 .26282 .33932 .25418 .34642 Mtetra
.118 0 0 r
.25418 .34642 .26282 .33932 .27394 .33597 .26535 .34337 Mtetra
.12 0 0 r
.26535 .34337 .27394 .33597 .28511 .3325 .27658 .34016 Mtetra
.121 0 0 r
.27658 .34016 .28511 .3325 .29635 .32891 .28788 .33679 Mtetra
.119 0 0 r
.28788 .33679 .29635 .32891 .30764 .32522 .29924 .33327 Mtetra
.117 0 0 r
.29924 .33327 .30764 .32522 .31899 .32142 .31066 .32958 Mtetra
.112 0 0 r
.31066 .32958 .31899 .32142 .33039 .3175 .32215 .32575 Mtetra
.106 0 0 r
.32215 .32575 .33039 .3175 .34186 .31349 .33369 .32175 Mtetra
.099 0 0 r
.33369 .32175 .34186 .31349 .35337 .30936 .3453 .31761 Mtetra
.089 0 0 r
.3453 .31761 .35337 .30936 .36495 .30513 .35696 .31331 Mtetra
.078 0 0 r
.35696 .31331 .36495 .30513 .37657 .30079 .36868 .30886 Mtetra
.064 0 0 r
.36868 .30886 .37657 .30079 .38825 .29634 .38046 .30425 Mtetra
.048 0 0 r
.38046 .30425 .38825 .29634 .39998 .29178 .39229 .29948 Mtetra
.029 0 0 r
.39229 .29948 .39998 .29178 .41177 .2871 .40417 .29455 Mtetra
.007 0 0 r
.40417 .29455 .41177 .2871 .4236 .28231 .41611 .28945 Mtetra
0 0 0 r
.41611 .28945 .4236 .28231 .43549 .2774 .42809 .28419 Mtetra
.42809 .28419 .43549 .2774 .44743 .27236 .44013 .27875 Mtetra
.44013 .27875 .44743 .27236 .45941 .2672 .45222 .27315 Mtetra
.45222 .27315 .45941 .2672 .47145 .26191 .46435 .26736 Mtetra
.46435 .26736 .47145 .26191 .48353 .25649 .47653 .2614 Mtetra
.47653 .2614 .48353 .25649 .49565 .25093 .48875 .25527 Mtetra
.48875 .25527 .49565 .25093 .50782 .24524 .50101 .24895 Mtetra
.50101 .24895 .50782 .24524 .52004 .23941 .51332 .24246 Mtetra
.381 .82 .673 r
.51332 .24246 .52004 .23941 .5323 .23345 .52566 .2358 Mtetra
.444 .865 .732 r
.52566 .2358 .5323 .23345 .5446 .22736 .53804 .22897 Mtetra
.507 .905 .788 r
.53804 .22897 .5446 .22736 .55694 .22113 .55045 .22198 Mtetra
.567 .937 .838 r
.55045 .22198 .55694 .22113 .56932 .21477 .5629 .21482 Mtetra
.621 .959 .879 r
.5629 .21482 .56932 .21477 .58174 .20827 .57538 .20751 Mtetra
.667 .97 .91 r
.57538 .20751 .58174 .20827 .59419 .20163 .58789 .20004 Mtetra
.703 .97 .931 r
.58789 .20004 .59419 .20163 .60668 .19485 .60044 .19243 Mtetra
.731 .961 .942 r
.60044 .19243 .60668 .19485 .6192 .18792 .61301 .18467 Mtetra
.75 .946 .944 r
.61301 .18467 .6192 .18792 .63176 .18083 .6256 .17677 Mtetra
.763 .926 .941 r
.6256 .17677 .63176 .18083 .64435 .17358 .63822 .16873 Mtetra
.771 .905 .934 r
.63822 .16873 .64435 .17358 .65696 .16618 .65087 .16054 Mtetra
.776 .883 .923 r
.65087 .16054 .65696 .16618 .6696 .15863 .66353 .15221 Mtetra
.777 .86 .912 r
.66353 .15221 .6696 .15863 .68227 .15094 .67622 .14374 Mtetra
.776 .838 .899 r
.67622 .14374 .68227 .15094 .69497 .14314 .68893 .13516 Mtetra
.773 .815 .886 r
.68893 .13516 .69497 .14314 .70769 .13525 .70165 .12647 Mtetra
.416 .665 .963 r
.01926 .36808 .02714 .37496 .03666 .37499 .02878 .3682 Mtetra
.425 .673 .965 r
.02878 .3682 .03666 .37499 .04626 .37494 .03837 .36819 Mtetra
.435 .68 .967 r
.03837 .36819 .04626 .37494 .05593 .37479 .04805 .36804 Mtetra
.445 .685 .967 r
.04805 .36804 .05593 .37479 .06568 .37452 .05781 .36776 Mtetra
.456 .69 .967 r
.05781 .36776 .06568 .37452 .0755 .37414 .06765 .36734 Mtetra
.467 .694 .966 r
.06765 .36734 .0755 .37414 .08541 .37363 .07758 .36679 Mtetra
.478 .698 .965 r
.07758 .36679 .08541 .37363 .09539 .37299 .08758 .36609 Mtetra
.489 .701 .964 r
.08758 .36609 .09539 .37299 .10545 .37224 .09766 .36525 Mtetra
.499 .704 .961 r
.09766 .36525 .10545 .37224 .11558 .37135 .10782 .36427 Mtetra
.51 .706 .959 r
.10782 .36427 .11558 .37135 .12579 .37034 .11806 .36315 Mtetra
.52 .707 .956 r
.11806 .36315 .12579 .37034 .13608 .36919 .12837 .36189 Mtetra
.53 .708 .953 r
.12837 .36189 .13608 .36919 .14645 .36791 .13877 .36048 Mtetra
.539 .708 .949 r
.13877 .36048 .14645 .36791 .15689 .36647 .14923 .35892 Mtetra
.548 .709 .946 r
.14923 .35892 .15689 .36647 .1674 .36489 .15978 .35721 Mtetra
.557 .709 .942 r
.15978 .35721 .1674 .36489 .17799 .36315 .1704 .35536 Mtetra
.565 .71 .939 r
.1704 .35536 .17799 .36315 .18866 .36125 .18109 .35336 Mtetra
.573 .71 .936 r
.18109 .35336 .18866 .36125 .1994 .35919 .19186 .35121 Mtetra
.58 .711 .933 r
.19186 .35121 .1994 .35919 .21021 .35697 .2027 .3489 Mtetra
.587 .712 .93 r
.2027 .3489 .21021 .35697 .2211 .35458 .21361 .34645 Mtetra
.593 .713 .927 r
.21361 .34645 .2211 .35458 .23206 .35203 .22459 .34384 Mtetra
.6 .715 .925 r
.22459 .34384 .23206 .35203 .24309 .34931 .23564 .34108 Mtetra
.606 .717 .923 r
.23564 .34108 .24309 .34931 .25418 .34642 .24676 .33816 Mtetra
.612 .719 .922 r
.24676 .33816 .25418 .34642 .26535 .34337 .25795 .33509 Mtetra
.618 .722 .92 r
.25795 .33509 .26535 .34337 .27658 .34016 .2692 .33186 Mtetra
.624 .724 .919 r
.2692 .33186 .27658 .34016 .28788 .33679 .28052 .32847 Mtetra
.629 .727 .918 r
.28052 .32847 .28788 .33679 .29924 .33327 .29191 .32493 Mtetra
.635 .729 .916 r
.29191 .32493 .29924 .33327 .31066 .32958 .30336 .32123 Mtetra
.64 .731 .915 r
.30336 .32123 .31066 .32958 .32215 .32575 .31487 .31737 Mtetra
.645 .734 .913 r
.31487 .31737 .32215 .32575 .33369 .32175 .32644 .31335 Mtetra
.65 .736 .912 r
.32644 .31335 .33369 .32175 .3453 .31761 .33807 .30917 Mtetra
.655 .737 .91 r
.33807 .30917 .3453 .31761 .35696 .31331 .34977 .30483 Mtetra
.66 .739 .908 r
.34977 .30483 .35696 .31331 .36868 .30886 .36152 .30033 Mtetra
.665 .74 .906 r
.36152 .30033 .36868 .30886 .38046 .30425 .37332 .29567 Mtetra
.67 .741 .904 r
.37332 .29567 .38046 .30425 .39229 .29948 .38519 .29085 Mtetra
.674 .742 .902 r
.38519 .29085 .39229 .29948 .40417 .29455 .3971 .28587 Mtetra
.679 .743 .9 r
.3971 .28587 .40417 .29455 .41611 .28945 .40907 .28072 Mtetra
.683 .744 .898 r
.40907 .28072 .41611 .28945 .42809 .28419 .42109 .27541 Mtetra
.687 .746 .896 r
.42109 .27541 .42809 .28419 .44013 .27875 .43316 .26994 Mtetra
.692 .747 .894 r
.43316 .26994 .44013 .27875 .45222 .27315 .44528 .2643 Mtetra
.696 .749 .892 r
.44528 .2643 .45222 .27315 .46435 .26736 .45745 .25851 Mtetra
.7 .751 .891 r
.45745 .25851 .46435 .26736 .47653 .2614 .46966 .25255 Mtetra
.704 .753 .89 r
.46966 .25255 .47653 .2614 .48875 .25527 .48192 .24642 Mtetra
.708 .756 .889 r
.48192 .24642 .48875 .25527 .50101 .24895 .49422 .24014 Mtetra
.713 .759 .889 r
.49422 .24014 .50101 .24895 .51332 .24246 .50656 .23369 Mtetra
.717 .763 .888 r
.50656 .23369 .51332 .24246 .52566 .2358 .51894 .22708 Mtetra
.721 .766 .888 r
.51894 .22708 .52566 .2358 .53804 .22897 .53136 .2203 Mtetra
.726 .77 .888 r
.53136 .2203 .53804 .22897 .55045 .22198 .54382 .21337 Mtetra
.73 .774 .888 r
.54382 .21337 .55045 .22198 .5629 .21482 .55631 .20627 Mtetra
.734 .778 .888 r
.55631 .20627 .5629 .21482 .57538 .20751 .56883 .19901 Mtetra
.739 .782 .888 r
.56883 .19901 .57538 .20751 .58789 .20004 .58139 .19159 Mtetra
.743 .786 .887 r
.58139 .19159 .58789 .20004 .60044 .19243 .59398 .184 Mtetra
.747 .789 .887 r
.59398 .184 .60044 .19243 .61301 .18467 .60659 .17626 Mtetra
.751 .792 .886 r
.60659 .17626 .61301 .18467 .6256 .17677 .61924 .16836 Mtetra
.755 .794 .885 r
.61924 .16836 .6256 .17677 .63822 .16873 .6319 .16029 Mtetra
.758 .796 .883 r
.6319 .16029 .63822 .16873 .65087 .16054 .6446 .15207 Mtetra
.762 .797 .882 r
.6446 .15207 .65087 .16054 .66353 .15221 .65731 .14369 Mtetra
.765 .798 .88 r
.65731 .14369 .66353 .15221 .67622 .14374 .67004 .13515 Mtetra
.768 .798 .877 r
.67004 .13515 .67622 .14374 .68893 .13516 .6828 .12646 Mtetra
.77 .797 .874 r
.6828 .12646 .68893 .13516 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Sooooo`03olG<gol0003ooooo01Gooooo00?o
0000ooooooooool0DOooool0063ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`0Mooooo`?o00000_ooool00ol0003oooooooooo`1Oooooo`?oaLcO00?o
0000olG<goooool05Oooool00ol0003oooooooooo`1@ooooo`00H?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol0000Looooo`;o0000IOooool00oo4c>3oaLcOolG<g`02olG<g`03o`000?o5
d>;ooooo01Cooooo00?o0000ooooool00000DOooool0063ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0001[ooooo0ol0001Vooooo`?oa<cP0oo5c=l00ol0003oaM3R
olG@hP0Fooooo`03o`000?oooooooooo04oooooo001Pooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool0000Hooooo`;o0000J?ooool5olC<h003olG<goo5d>;o000000?o
aM3R5_ooool00ol0003oooooooooo`1>ooooo`00H?ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l000005Oooool3o`0000;ooooo00?o0000ooooooooool0Hoooool00oo3c>7o
a<cPolC<h003olC<h004olKFi_o5d>;oaM3Ro`0000;oaM3R00?o`M;Wooooooooool05?ooool00ol0
003oooooooooo`1>ooooo`00H?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4
A?l000004oooool2o`0006[ooooo0oo3c>43olC<h0?oa]KV00?oaM3Ro`000?o5d>800oo1d^LFoooo
o`03o`000?oooooooooo04gooooo001Pooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omg
MgOo0000ooooo`0?ooooo`?o0000Joooool5ol?<h@03olC<h?o6e^Koa]KV00?oa]KV00?o0000ol7B
ioo1d^L00oo1d^LFooooo`03o`000?oooooooooo04cooooo0022ooooo`;o0000K?ooool6ol?<h@;o
a]cY1?o6e^H00oo2g>co0000ol7Bi`03ol7Bi`03okWBkOoooooooooo01Cooooo00?o0000oooooooo
ool0C?ooool007oooooo0ol00002ooooo`03o`000?oooooooooo06Sooooo1_o3c>44olKLj@07olKF
i_o2g>co`]c/ol;Lk?l0003o`]c/ol7Bi`04okWBkACooooo0ol0001=ooooo`00O?ooool3o`0006oo
oooo1_o3c>44olKLj@;o`NK`0oo2g>`00ol0003o^=kcokWBk@04okWBkAOooooo00?o0000oooooooo
ool0B_ooool007[ooooo0_l0001`ooooo`;o`/_R1?o3c>42olKRk0?oa]cY1?o1i_001Oo2g>co^=kc
okSNlol0003o^=kc00;o^M;]0on/c_8Fooooo`03o`000?oooooooooo04[ooooo001gooooo`?o0000
L?ooool5ol;;hP03ol?<hOo6h^coa^;/00?oa^;/00?oa]cYol7Vl?o1i_000_o1i_001_ndjOOo^=kc
okSNlonhg_?o0000ojWJn@Ko[<kb5_ooool00ol0003oooooooooo`19ooooo`00MOooool2o`0000;o
oooo00?o0000ooooooooool0K?ooool00oo1bn;o`/_Rol;;hP03ol;;hP;oaNO_1?o6h^`2okg_l`03
ol7Vl?ndjOOo]>Wg00?o]>Wg00?o^=kcojWJnOl000000_nYf_T4ojc>lP03oig6m?oooooooooo01Go
oooo00?o0000ooooooooool0B?ooool007;ooooo0ol00005ooooo`03o`000?oooooooooo06[ooooo
0oo1bn83ol;;hPCoaNO_00Coa^;/okg_lonmko?o_Noc0_nZl?H4okCYm`;oX^Cl00?oZM[io`000?nY
f_T00_nYf_T00on/c_;oWLKdoig6m002oig6m1Kooooo00?o0000ooooooooool0B?ooool0073ooooo
0_l0001dooooo`Go`L_R00?o`/_RolGWkoo5inl00_o5inl2okKelP03okg_lonZl?KoZ_3f00?oZ_3f
00?o]>Wgoj;To?nRi?`00onRi?`00ol0003oZM[ioiS?n`02oiS?n`GoWLKd5_ooool00ol0003ooooo
ooooo`17ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
8?ooool3o`0007Cooooo0_o0b^84ol7;hP?o`ng`00CoaNO_okKel_nfmO;o]_Gb0onIlNd2oj[`mPCo
TnWi0_nRi?`2oi7GoP03o`000?nHco_oV<ok00?oV<ok0_nMa_@2ohnkm1Gooooo0ol00018ooooo`00
>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@07_ooool2o`0000?ooooo00?o0000ooooooooool0Koooool5ol3:hP03ol7;h_o3kO3o`ng`
00;o`ng`0_nYmn/00onfmO;oVO7]oiWak@02oiWak@?oONG/0_nCjOT4ohGLoP;oTMOn00Co0000oi7G
o_nHco_oV<ok0on<`?P4ohnkm1Kooooo00?o0000ooooooooool01_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:Oooool003Sooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^01cooooo0ol0001eooooo`03oko9hoo0
b^;o`<[R00?o`<[R0_nol_43ol?]l0;oZOO[0omoj=T01?nIlNgoONG/oggUk?mmiN`4og?LmP;oQMcn
0on2bOh01?n8aOco0000ohS5o?n8aO`5ohc0n0CoSk_d5_ooool00ol0003oooooooooo`05ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0:_ooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Sooooo0ol0001goooo
o`?o_lWS0oo0b^84okobl@03ol?]l?nYmn_oZOO[00;oOnSI0_mRf=@4oeoEi`;oLmcf0omkcOl5oh;9
oP04o`000?n8aOcoR<GlohS5o0;oS<3h0_n6]?<5ohNclQKooooo00?o0000ooooooooool01?ooool0
1Ol@413ooooooooooooooooo410@00_ooooo1Ol0000[ooooo`00>?ooool01Ol0003ooooooooooooo
oooo000000kooooo00?oMgMgofIVI_ooool05Oooool3o`0007Sooooo1OnobN<00oo0b^;o_o;aokob
l@02okobl@;oU_;M0_m4`kH2odS8dPCoJm3l1?mdcol4og_=o`;oP/Wn0_n3]_H00ol0003oQKGdohFe
m002ohFem0CoQ[Cc1On7/o8Eooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`00000;ooooo`04odA4A?oMgMgoooooo`0002cooooo000hooooo`05oa0@4?ooooooooooooooool@
41003oooool00ol0003oooooooooo`0Aooooo`?o00000oooool00ol0003oooooooooo`1cooooo`;o
_/WS1?nobN<3ok_fl@03okoblOnFl]goU_;M00;oF<k_1?mRcoL2of_@o0OoP[Og1?n2]oH3oh>fmP03
o`000?n5]OCoQKGd00?oQKGd1?n6]?<2ohNclP;oQZg_5_ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000/ooooo`00>?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Aooooo`;o0000N_oo
ool5okk9h`03oko9honkm_7o^oKa00;o^oKa0_mmiLL2oeS>k`?oQ;Sf1?n3^?L9oh:gm`CoP[Of0_n3
]_H01?l0003oPkKfohFem?n5]O@2ohRWj@CoQj[/1On6[NlFooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000002cooooo000hooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00kooooo0ol0001joooo
o`03okg8honnbN?o_/WS00?o_/WS0oncn>h00onkm_7oONG7oggUa`03ohJhmPGoQ;Sf1?n3^?L6oh:g
m`;oRicN1?n:X><2ohVTiP03o`000?n9Y>KoR:OY00CoR:OY1?n7Z^`5ohJ]kaCooooo0_l00004oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000/ooooo`00FOooool3o`00
07[ooooo1?nmb><3okk9h`?o/oS^00CoHM6[ohVgm?n9]oCoRKOd1?n6^?H2ohBhmP;oShk>1?n>Tm@4
ohbHf@GoRicN1?n:X><01?n9Y>Ko0000ohVTi_n9Y>H5ohRWj@CoQj[/0_n6[Nl2ohb/ja?ooooo00Co
0000oooooooooooo00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?oo
ool0:oooool005Kooooo0ol00003ooooo`03o`000?oooooooooo07;ooooo00Co:;6cobff_?lC003o
^lOS1_nmb><00onnbN?o/oS^ok?hkP02ohbfl`;oRKOd0_nAQL<4oi29b0GoShk>1?n>Tm@4ohbHf@Co
RicN1On:X><01?l0003oRJCVohVTi_n9Y>H2ohRWj@;oSioO1?n=YND5ohb/jaKooooo00?o0000oooo
ooooool0@?ooool005Cooooo0_l0001hooooo`03obRa/olI003o4`0000;o:P000onkan<4okg8h`;o
Z_SX00CoS[Gaohbflon<]_?oTH6n1OnAQL<4oi29b0CoShk>1?n>Tm@5ohbHf@CoRicN0_n:X><2oi6D
d`04o`000?n@V]WoT9[Ioi2Jf@GoSioO1?n=YND4ohb/jaKooooo00?o0000ooooooooool0@?ooool0
057ooooo0ol0001dooooo`;o8@000_lM00000olI003o;`00obl00003obX000Go^lOS00?o_LSSoj[h
j?nZn>P00onBOKT4oi61_PCoTHG31?n@RLP4ohn>cPGoSY?D0_n<V=T2oi>;a`CoTXo=1?nAU=<00ol0
003oT9[Ioi2Jf@02oi2Jf@CoSioO0_n=YND2oiNSg@GoUZcV5_ooool00ol0003oooooooooo`0ooooo
o`00C_ooool5o`00077ooooo0_lT0003ob400003oad00?ld003o;`0000?o;`0000?o:P00ok[6honj
a^<01?nkan<2oikeh@03oi9j]OnBOKWoTWfi00?oTWfi0onAPKh4oi65``CoT8W81On?S/h2ohjCe0;o
U8K21OnCRlL4oi:?c@?oTICC00?o0000oi2JfOn@V]T00_n@V]T2ohnOg`;oV9[D1OnGXmd5oiJ/iQKo
oooo00?o0000ooooooooool0?_ooool004cooooo0_l00005ooooo`03o`000?oooooooooo06Wooooo
00?o0000obH00?lV00000olT00000olQ003o>000ocP00003oc@000?o;`001Onja^<00onkan?oW_GQ
oikeh@04oi9j]@CoTWfi0onAPKh5oi65``CoT8W80_n?S/h2oiF2_@GoU8K21?nCRlL4oi:?c@?oTICC
00?o0000oi2JfOn@V]T00_nHTld5oiRJe0CoUj?M1?nF[>H00onT]>Coooooooooo`0Dooooo`03o`00
0?oooooooooo03kooooo0019ooooo`?o0000Koooool2o`000005obP00?lV003o9P00obH00?lT0000
0_ll0004ocP000;o=00000?o;`00ocL00OniaN<01Onja^<2oi7_eP;oTWNb1?nBN[D4oi9m^@CoTH6n
0onAQL<00onFO;CoUWnhoiIo^002oiIo^0GoUH:m1?nDQ/84oi>;a`GoTXo=0_nAU=<00onHSLKo0000
oiRCc@03oiRCc@CoV9[D1OnGXmd00onF[>KoY;CTojBdi002ojBdi1Cooooo0ol0000oooooo`008_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^023ooooo0_l0001_ooooo`03o`000?lZ003o:P0000;o:000
00?o9P00ocl00?lo00001?ll0003ocP00003oc@00?lm00Wo=`0100Co^LGS0onja^<00onAkmKoTWNb
oi9g/P02oi9g/PCoTWZe1OnBOKT3oi61_P04oi65`onFO;CoUWbdoiIl]0GoUWnh1?nEP[d4oiB6`PGo
Th_70_nBSld2oiR8`0?oV8g600?o0000oiRCcOnHTld00_nHTld5oiRJe0;oUj?M0_nTZm`6ojBdi1Go
oooo00?o0000ooooooooool0?Oooool002;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`?o
00000_ooool00ol0003oooooooooo`1Xooooo`;o000000Ko:`00obX00?lZ003o:P00obP00?m100@4
ocl000?o?0000_lh00001?m2017o?@09ocd02Onha><6okW5h`03ok[6honBM:ooTWB_00CoTWNb1OnB
N[D4oi9m^@;oTH6n00?oUWVaoiIl]?nFO;@00onFO;@4oiIo^0CoUH:m1OnDQ/82oi>;a`;oVHBk1?nH
R<03oiR=aP03o`000?nHTlgoV9?=00?oV9?=0_nHV]@2oj>Se0GoY:_L1?nT]>@2ok2ni1Gooooo00?o
0000ooooooooool0??ooool002;ooooo00Go410@oooooooooooooooooa0@400Kooooo`;o0000K?oo
ool2o`0000Co:`0000?o:P00od<02?m300P00om100@3ocl000Co?0000om20144okS4h`Co^LGS00Co
TW:/oi9d[onBM:ooTWB_1OnBMk84oi9j]@;oTWfi0_nFMjh3oiIi/@GoUWbd1?nFOkP5oiF2_@;oU8K2
0_nIP;L5oiV4^`CoV8S00_nHSLH00ol0003oV9?=oiRCc@02oiRCc@03oj>Lc_nSXmCoXj?D00?oXj?D
1OnTZm`00onT]>Co/;kTok2ni003ok2ni1Gooooo00?o0000ooooooooool0>oooool002;ooooo00Go
0000ooooooooooooooooo`00000Hooooo`?o0000Joooool00ol0003o;000ob`00004ob/00003odD0
2om300So@`0800;o@`080_m100@4ocl00003oc`00?m601OoAP0G00;o@P0A00?o]l?SokS4honha><0
1?nha><01?niaN?oTW:/oi9b[?nBLZ`3oi9d[`GoTWNb0_nBN[D2oiIeZ`CoUWN^1?nFNK44oiIl]0Go
UWnh0onEP[d00onJO[?oVH2goiV0]`03oiV0]`CoVHBk1?nHR<02oiR=aP03o`000?nHSLKoV9?=00Co
Xic>1OnSXm@2ojB[g0?o/;WP1?n`_^@00onfa>Goooooooooo`0Cooooo`03o`000?oooooooooo03_o
oooo000Rooooo`05o`000?ooooooooooooooool000005_ooool3o`0006_ooooo1Ol/0002ob/000?o
A@0;0om300P3od401003ocl00?m:01coBP0L00CoAP0G1?ng`n<4okS4h`03oi9`Z_nBLZcoTW:/00;o
TW:/1?nBM:l3oi9g/P03oiIcZOnFMJ_oUWF[00;oUWF[1OnFMjh3oiIi/@GoUWbd1?nFOkP01?nEP[go
VWjcoiYn/onJO[<5oiV0]`CoVHBk1?nHR<02oiR=aP03o`000?nSUlSoXic>00CoXic>1?nSXm@00on`
]=co/;WPok2ih004ok2ih003ok2ni?nfa>Go]/CU00;o]/CU5Oooool00ol0003oooooooooo`0joooo
o`008_ooool01Ol@413ooooooooooooooooo410@01?ooooo0ol00002ooooo`03o`000?oooooooooo
06Gooooo0_l[0006ob`00003ob/00?m600koA@0;00;oA@0;1?m300P00om100CoC@0PodX07003odX0
70;oAP0G00?o]/;SokO3hong`n<01?ng`n<01?nha>?oTW2Zoi9`Z_nBL:X5oi9b[0?oTWB_00CoTWNb
oiIcZOnFLjWoUW>Y1OnFMJ/4oiIg[P?oUWVa1OnFO;@2oiIo^0;oVWb`1OnJO[<4oiV0]`GoVHBk0_nH
R<001?nST/?oXiO8oj>Gb?l00002oj>Gb0GoXic>00?oXj?Dok2dg?n`]=`00_n`]=`4ok2ih003okO3
i?nfa>Go]/CU00?o]/CU5_ooool00ol0003oooooooooo`0iooooo`008_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg013ooooo0ol0001Zooooo`04obX00?l[003o:`00ob/000Co;0000_m70143odH03P?o
A@0;00?o@`08odl09?m?02@00om=0203odX07003odH05onf`^?o]/;S00;o]/;S1?ng`n<00onBKjSo
TW2Zoi9`ZP03oi9`ZPCoTW:/0_nBM:l00onFLJOoUW>YoiIcZ@03oiIcZ@CoUWF[1?nFMjh4oiIi/@?o
UWbd00?oVgZ^oiYl/?nJO;000_nJO;05oiYn/`GoVH2g1?nIQ;/01_nHR<3oXi;3oj>B`onST/?oXiO8
o`0000;oXiO81?nSW<h00ona/]Wo/;CLok2dg004ok2dg003ok2ih?ng`nCo]l?T00;o]l?T0onfa>D2
okW:iaCooooo0_l0000kooooo`008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo0_l0001Z
ooooo`04obT00?lZ003o:P00obX000;o:`0000?o;000odP04_m801801?m70142odH03P;oA@0;00?o
D@0Wodl09?m?02@00_m?02@2odd080?oBP0L00?o]L7SokK2honf`^<01?nf`^<01?ng`n?oTVnXoi9_
Z?nBKjP5oi9`ZP;oTW:/0_nEL:H3oiIaY`GoUW>Y1?nFMJ/5oiIg[P?oUWVa00CoUWbdoi]j[_nKNZko
VgZ^1OnJO;04oiYn/`GoVH2g0_nIQ;/2oj>?_`CoXi;300?oXiO8o`000?nSUlP00_nSUlP00onSW<ko
/K;Iok6bf@02ok6bf@Co/;CL00?o]l?SokO3i?ng`n@01?ng`n@00onfa>Go^L[WokW:i`02okW:iaGo
oooo00?o0000ooooooooool0>?ooool003;ooooo1Ol0001Xooooo`;o:@000olZ00000ol[003oB00D
odP04P03odP04P?oA`0A0om600h3oe409`?oC`0T0om=02000om:01co]L7SokG1h`02okG1h`Co]/;S
0_nBKZH4oi9_Z0?oTW2Z00?oUFnToiE`Y_nEL:H00_nEL:H4oiIaY`CoUW>Y1?nFMJ/5oiIg[P;oUWVa
00?oVgV]oi]j[_nKNZh00onKNZh4oiYl/0GoVWjc0onIP;L00onSS;coXhnooj>?_`03oj>?_`?oXi;3
0_l00002oj>Gb003ok:`eona/]Wo/K;I00Co/K;I00?o/;CLokO3hong`n<00_ng`n<4okO3i003okW>
jOnib^Oo^L[W00;o^L[W00?o]/[Yooooooooool05?ooool00ol0003oooooooooo`0gooooo`00<?oo
ool2o`0006[ooooo00GoB<JhobL00?lY003o:@00obX00002odT05@?oB00D0om80183odL04@03odH0
3_mC02WoD`0Y00?oD@0W0om?02@3odd08003okC0hone`N?o]L7S00Co]L7S00?o]/;Soi9^Y_nBKZH0
0_nBKZH4oi9_Z004oi9`Z_nEKjCoUFnToiE_Y0GoUG2V0onFLJL4oiIcZ@GoUWF[0onFMjh01?nKN:_o
VgV]oi]i[OnKNJd5oi]j[PCoVWb`1OnJO[<00onIP;OoXhbloj><_002oj><_0CoXhno0ol000000onS
T/?o0000ok:`e`03ok:`e`Co/K;I00?o^<CSokO3hong`n<01?ng`n<00ong`nCo^LkYokW>j@02okW>
j@03okW:ionfb^Wo]/[Y00;o]/[Y5Oooool00ol0003oooooooooo`0gooooo`00;Oooool3o`0006Wo
oooo0_lV0002obL00003obT00?m901KoB@0E00?oB@0E0_m801@4odP04P03odL04OmD02_oD`0Y00?o
D`0Y0omA02L3odl09003odd08?nd`>?o]<3S00;o]<3S1?ne`N<3oi9]Y@?oTVjV0_nBKjP2oiA]X`Co
UFnT1OnEL:H3oiIaY`CoUW>Y1OnFMJ/01?nFMjkoVgR[oi]hZonKN:/4oi]i[@CoVgZ^1OnJO;03oiYn
/`03ojB:^_nSS;coXhbl00?oXhbl00CoXhnoo`000?l0003o00000onST/<00onc/=Go/[3Go`000004
ok:`e`03ok6bfOnha>?o^<CS00;o^<CS1?ng`n<00onjd^co^LkYokW>j@02okW>j@03okK?kOnfb^Wo
]/[Y00Co]/[Y5Oooool00ol0003oooooooooo`0fooooo`00;?ooool2o`0006Sooooo00Ko8`00obH0
0?lV003o9P00obL00?m801H3odT05P?oB@0E0om801@00om801;oE@0]oeD0;@03oe@0:`?oD`0Y0omA
02L2odl09003od004_nc`>Co]<3S00Go]<3S00?o]L7Soi5/Y?nBKJD00onBKJD2oi9^YP03oiA/X_nD
KJ?oU6fS00;oU6fS1OnEKj@4oiE`YP?oUW6W1OnFLjT3oiIeZ`03oi]hZ_nKN:_oVgR[00?oVgR[0onK
NJd4oi]j[PGoVWb`00?oVWjcojB:^_nTR[X00_nTR[X2oj><_0?o00001?nSSkl01_nST/?o/k3Eok>`
eOnc/=Go/[3Go`0000;o/[3G00?o^LKTokS4honha><01?nha><00ong`n?o^];/ok[Bk002ok[Bk003
okW>jOnfcngo]/o]00;o]/o]1?nfb^T2ok77jaGooooo00?o0000ooooooooool0=Oooool002cooooo
0ol0001Uooooo`03oe;=^olS003o8`0000;o9P000om801H2odT05P?oB@0E0_m801@00omF02koE@0]
oeD0;@02oeD0;@;oE00[1?mC02T3oe409`03od004_nc`>Co/l3T00;o/l3T1?nd`><00ol0003oTFbT
oi5/Y004oi9]Y@03oi9^Y_nDK:;oU6bR00CoU6fS1OnEKj@4oiE`YP?oUW6W1OnFLjT01?nFMJ_oVgRZ
oi]hZ_nKN:X5oi]hZ`?oVgV]1OnKNZh3oiYl/003ojB9^?nTR[[oY8Zj00;oY8Zj0ol00003oj><_0?o
Xhno00?o];3Eok>`eOnc/=D00onc/=D00onb/=Oo0000okW6i002okW6i0Co^<CS0_njenl3ok[Bk0;o
]]G`1Onfcnd00onfb^Wo/LO[ok77j`03ok77jaCooooo00?o0000ooooooooool0=Oooool002cooooo
00Co0000ooooool0003o0000HOooool00omBcK_o8@00ob<00002ob<00003obH00?m801KoB00F00;o
B00F0om901H3odT05@?oEP0^0omE02d3oe@0:`CoD`0Y00CoD@0Wod<05_nb_nCo/[oT1Onc`>@00ond
`>?o0000oi5[X`03oi5/Y0;oTVfU0_nDK:43oiA/XPGoU6fS1?nEKj@4oiE`YPCoUW6W0onFLjT00onK
Mj[oVgRZoi]hZP03oi]hZPCoVgR[0onKNJd5oi]j[P03oiYl/?nTRKSoY8Vh00;oY8Vh0ol000000onT
R[[oXhbloj><_003oj><_003oj>?_ond/=Go];3E00;o];3E0onc/=D00onjbNKo^LKTo`000004okW6
i003okS4honjenoo^]O_00?o^]O_00?o^];/okKEl?nfeO000_nfeO02okK?k@?o/L_]1?naan/00on]
aN_oooooooooo`0Aooooo`03o`000?oooooo000000Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<01Wooooo000/ooooo`;o00000_ooool0
0ol0003oooooooooo`1Looooo`04oah00?lQ003o8@00ob<000;oA`0E1Om801H4odT05P03odT05OmG
02ooEP0^00;oEP0^1?mE02d3oe@0:`;oD`0Y00?oAP0Iod<05_nb_n@01?nb_n@3ok?0i0CoTF^S0_nA
K:@00onCJj7oU6bQoiA/X@02oiA/X@CoU6bR1?nDKJ<4oiE_Y0GoUG2V0onFLJL01?nFLjWoVgNZoi]g
Z_nKMjX5oi]hZPCoVgR[1?nKNJd3oi]j[P03ojB8]onTRKSoY8Vh00?o00001OnTR[X3oj><_003okJb
e_nd/=Go];3E00?o];3E00?o/k3Eok[9i_njbNH00_njbNH01?nia^Co0000okW6i?nia^@2okWMlPCo
^]O_00?o]=[cokKEl?nfeO000_nfeO02ok3?l0Go/L_]00?o/LO[ojg5jon]aN/00_n]aN/Eooooo`03
o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q01Wooooo000[ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0F?ooool01OlK003o7P00oah00?lN003oAP0D00CoA`0E1Om801H00om901KoE`0`oeL0<003
oeL0;`?oEP0^0omE02d3oe@0:`03oe<0:Om601WoAP0I00;o/KoT1_nb_n@00onc`>CoTFZRoi5[X`03
oi5[X`03oi5/Y?nCJj7oTf^Q00CoU6bQ1?nDK:84oiA]X`CoUFnT1OnEL:H2oiIaY`03oi]gZOnKMj[o
VgNZ00?oVgNZ1?nKN:X4oi]hZ`CoVgV]00CoVgZ^ojB8]onTR;OoY8Rg0_l00003ojB9^0GoY8Zj00?o
XhblokJbe_nf/]H00_nf/]H4okB`e@Ko^/WV00?o^LKTo`000?nigO800onigO800onjenoo]=[cokCJ
l`02okCJl`03okKEl?n`co3o/<o`00?o/<o`0_nabnd2ojg8k@Go[LG[5Oooool00ol0003ooooooooo
o`05ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001Wo
oooo000[ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0EOooool2oa/000?o7P00
0_m601@3odL05@CoB00F1OmG0302oeL0;`CoEP0^0omE02d00omD02_oB00LodP07002odH06@Co/KoT
1?nb_n@3oi5ZXP;oTF^S0_nCJZ03oi=[X@GoU6bQ0onDK:84oiA]X`GoUFnT1?nEL:H00onFLJOoVgNY
oi]gZ@05oi]gZPCoVgRZ1OnKN:/2oi]i[@03ojB8]_nTR;Oo000000;o000000?oY8RgojB9^?nTRKP0
0onTRKP3ojB:^P03okNfeonf/]Ko][;F00?o][;F0ond/=D2ok_>j0Co^/WV0_nghoD01?l0003o^Mgb
okWMl_nigO82ok;Pm`;o]=[c0on_d_<4ok3?l003ojc:kon]b>go[LS]00?o[LS]0_n]aN/3oj[2jaGo
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRH
V?ooooooV9RHob4Q8@0Iooooo`00:oooool3o`0000Gooooo00?o0000ooooooooool0D_ooool01?lG
003o6`00oa/00?lN0002odD04P;oAP0D0om701D2odP05P03oeP0<?mG033oE`0`00CoE`0`0omG02l3
oeH0;P;oE@0]00?oB`0NodP07?m801`00_m801`00on__^Go/KoTok6oi004ok6oi003ok:oi?nAJJ7o
TFZR00;oTFZR00?oTfVOoi=ZX?nCJZ000_nCJZ04oi=[X@CoU6bQ0onDK:84oiA]X`GoUFnT0onEL:H5
oi]gZ@CoVgNZ1?nKN:X5oi]hZ`04oi]i[Ol0003o0000o`0000CoY8Rg1OnTRKP00onTR[[o]kKGokNf
e`02okNfe`Go][;F00?o];3Eok_>j?nkc^P00_nkc^P00onjbNKo]n?eokOSm@03okOSm@04o`000?nb
h?Oo/^3gok;Pm`;o[MGe1On_d_<00on`co3o[<[_ojc:k`02ojc:k`?o[LS]00?oZ/C/oj[2jonZ`^/0
1?nZ`^/Eooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`06Oooool002_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1>ooooo`05oa<00?lG003o5`00oaL00?m301001?m50182odH050?oA`0E0omH0306oeL0
<0?oE`0_0_mF02h01?m<023oB`0Nod/07_m;01h2odP070Co[kkU1?na_n@3oi5YX@04oi5ZX_nCJIoo
TfVOoi=YW`CoTfZP1?nCJj44oiA/X@?oU6bR1OnDKJ<4oiE_Y003oiE`Y_nKMjWoVgNY00GoVgNY1?nK
MjX5oi]hZP;oVgR[0ol00003ojB8]PCoY8Rg1?nTRKP00onh^][o]kKGokNfe`03okNfe`Co][;F00?o
^mC/ok_>j?nkc^P00_nkc^P3ok?Xm`;o]n?e0on^iOT00ol0003o/^3gojgEm@03ojgEm@;o[m;c0on[
c?45ojc:k`04ojg8kOnZa>coZ/C/oj[4k0CoZ/;[00?oZ<7[ooooooooool04oooool00ol0003ooooo
ooooo`03ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Kooooo`00
:oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04_ooooo0_lC0003oaL000;o@`0@
0om50183odH05003odL05OmH033oF00`00;oF00`1_mG0303oeL0;`04oeH0;_m<023oC00Pod`080;o
B`0N0on^_^D5ojnni@03ok6oi?nAJJ7oTFVQ00;oTFVQ1OnCJIl4oi=ZX0CoTf^Q1?nDK:44oiA/XPCo
U6fS0onEKj@9oi]gZ@CoVgNZ1?nKN:X3o`0000OoY8Rf1?nTR;L2ojB9^0?o^;[J1Ong]]L00onf/]Ko
^mC/ok_Dk002ok_Dk003ok_>j?ncj?Oo/nSg00;o/nSg0onXj?X2ojkUn@;oZmSg00Co0000ojgEmOn]
eOGo[MGe0_nZc_<5oj_<l@;o[<[_0_nYaNd5oj[4k003oj[2jonX`N_oZ<7[00;oZ<7[4oooool3o`00
00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01_ooooo000@oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0B?ooool01?l?003o4`00oa<00?lG
0002od403P;o@`0@0om501800om601CoE`0_oeL0;`06oeP0<0KoE`0`00?oE`0_odh08_m>02800om<
02000on]_^Ko[[kUojjni@04ojjni@;o[kkU00GoTFVPoi5YXOnAJJ7oTFVQoi9XW`08oi=YW`?oTfZP
1?nCJj44oiA/X@CoU6bR1?nDKJ<00onEKjCoVgNYoi]gZ@09oi]gZ@GoVgNZ0ol0000:ojB8]PCoY8Rg
00?oY8VhokRjf_nh^]X00_nh^]X4okNfe`;o^]_`0onke>`3ojc]n003ok?XmonXj?[oZ>Sj00;oZ>Sj
00?oZ=Wioj_Hmon[f?L00_n[f?L00ol0003o[MGeoj[>l`04oj[>l`;oZlca0_nYaNh5ojW5k@;oZ/C/
0onX`^`5ojS1jaGooooo00Wo0000ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03?ooool0
1?o<c<coA4A4o`000?l@410Iooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B47ooooo`03o`000?oooooooooo00Cooooo0ol0000:ooooo`03o`000?oooooooooo04Cooooo00Go
2P00o`l00?l?003o4`00ocl02`04od403P03od<04?m501;oA@0B00GoE`0_1OmH0305oeL0<003odl0
8om>02;oCP0R00;oCP0R00?oC00Pojfni_n]_^H00_n]_^H4ojjni@CoTFVP00CoTFVQoi9XWonBJ9oo
TVRO2?nCJIl3oi=ZX0CoTf^Q1OnDK:43oiA/XP;oU6fS3_nKMjT2oi]gZP?o000000?oVgRZojB8]_nT
R;H02_nTR;H3ojB8]`03okZog_nh^][o^;[J00Co^;[J00?o]kKGok[Kl?njfo000onjfo000onke>co
[>ghojc]n004oj3ZnP03ojSXn_nXfOWoZ=Wi00;oZ=Wi0_n[f?L2ojS?m003o`000?nZc_?oZ/kc00;o
Z/kc00?oZ<K_ojW5k_nYaNh00onYaNh2ojW5k@SoZ<;/0_nX`N/2ojS0jaGooooo00?o0000oooooooo
ool0;oooool000Sooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`11ooooo`;o2P0000?o3`00oc`01olo
00/00_lo00/3od403P;o@`0@1_mG02l6oeP0<0;oE`0`00CoD00Sodl08om?02?oC`0S0om>02800on/
_NKo[KkVojfniP04ojfniP03ojjniOnAJJ3oTFVP00?oTFVP00?oTVRNoi9XWonBJ9l00_nBJ9l8oi=Y
W`CoTfZP0onCJj45oiA/X@;oU6bR4OnKMjT2o`0000;oVgNZ00?oY8RgojB8]_nTR;H03?nTR;H01?nT
R;Oo^[oNokZog_nj_mh4okRjfP?o^>?d0_njfo02oj?_m`?oV>_h0_nPj_X4ojGJnP;oZ=Wi0_nWd?D4
ojS?m003o`000?nZc_?oZ<K_00?oZ<K_0onYaNh00onX`^goZ<;/ojS2k006ojS2k0;oZ<7[1OnX`>/E
ooooo`03o`000?oooooooooo02kooooo000@ooooo`05o`000?ooooooooooooooool000002oooool0
1?m4A4CogMgMooooool00006ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0?_oo
ool00ol5003o2P00o`X00003oc`01`;o?`0;0om100h00om3013oE`0]oeL0;`06oeL0;`KoF00`0om@
02<2odl08`;oCP0R1?n/_NH4ojfniP03oi9YX?nAJJ3oTFVP00GoTVRN1OnBJ9l7oi=YW`CoTfZP1?nC
Jj44oiA/X@03oiA/X_nKMjWoVgNY00goVgNY0ol000000onKMjWoVgNZojB8]`02ojB8]`goY8Rf00?o
^/GSokZog_nj_mh00onj_mh00onh^][o^>?dokSSm002okSSm0?oV>kc00CoXnogoiS[n?nHjoSoV>_h
0_nSfo/4ojGJnP03ojK@m_nWd?GoYm3e00?oYm3e0_nXco@00onXa^oo0000ojS6k`05ojS6k`04ojW5
k_nX`^goZ<;]ojS2k@CoZ<;/00?oZ<7/ojS1jonX`N/00onX`N/2ojS0j`?oYl3[5Oooool00ol0003o
ooooooooo`0]ooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoo
oooo00001_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03cooooo00?o1@00o`X0
0?li00<00oll00L2ocl02`03od403_mF02coEP0/00?oE`0]1_mG02l4oeP0<0;oD00T0om@02<3odl0
8`?oZkgW1?n/_NH01?n]_^KoTVVPoi9YX?nAIih7oi9XWPGoTVRO1onCJIl4oi=ZX0CoTf^Q0onDK:40
0onKMj[oVgNYoi]gZ@0;oi]gZ@?o00000onKMjT00onTRKSoY8RgojB8]`03ojB8]`[oY8Rf1?njaN<2
okZogPCo/^[h00Co^>?doiS^lonHk_?oV>kc0on?j_H00onHjoSoXm_koj?Kn`03oj?Kn`03ojGJn_nV
d?KoY]3f00;oY]3f0_nWd?D3ojO6l0?oZ<K_00Co0000ojS6konXa^ooZ<K_0_nW`^d5ojS2k@03ojS2
k?nX`NcoZ<7/00;oZ<7/0onX`N/7ojO0jaCooooo00?o0000ooooooooool0;Oooool0013ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo0_l0000?ooooo`;o0000
>Oooool00omXf/7o1@00ocH00003ocT00`;o?00700?o?`0;oeD0:_mF02`00omF02`2oeL0;@OoE`0_
00?oF00`oe409?m@02@00om@02@3oe008`03ojZmion[_NOoZkgW00CoZkgW0_n/_NH3oi9YX0;oTFNN
2?nBJ9h4oi9XW`OoTfVO1?nCJZ04oi=[X@04oiA/XOnKMj[oVgNZoi]gZP[oVgNY0ol00005oi]gZ@;o
Y8Vh1OnTR;L8ojB8]P;o^/cX0onjaN<3ojW_m`;o/^[h0on:jnd3ohKXlP;oSn[f0onQfo`2oj?Kn`?o
YM3f0onVd?H7ojO6l0;oZ<K_00?oYl;]o`000?nW`^d01?nW`^d2ojS2k@?oYl7/1OnX`N`00onX`N_o
Yl3[ojO0j`06ojO0jaGooooo00?o0000ooooooooool0;?ooool0013ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0dooooo`;o00000olf0002ocT00`?o?0070_mE02X3oeH0;0?oE`0]1OmG02l01?mA02?o
D@0Toe409?mA02@3oe0090;oD00S1?nZ_NL4oj^mi`?oTVVP1OnAIih8oi9XWPCoTVRO2?nCJIl3oi=Z
X0?oTf^Q1_nKMjX6oi]gZ@?o00001_nKMjT00onTR[WoY8VhojB9^002ojB9^0CoY8Rg1_nTR;H5ok[<
j004ok[5honYkoOoZNogojW_m`?oO>KU00CoR^_]ohKXl_n6j?;oQ^Sb0onOfo`2oj7Ko0?oYLof1OnU
d?H00onVd?KoYlK`ojO6l004ojO6l0KoYl;]00?o0000ojO2kOnW`^d02?nW`N`2ojS1k0coYl3[4ooo
ool2o`0002kooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<Oooool2o`000004oc800?lf
003o=P00ocH000;o>@0300?o?007oe@0:?mD02P00_mE02X4oeH0;0?oE`0]0omG02l3oe408`;oD@0T
0om@02@3ojRmj0GoZ[gW00?oZkgWoi9YX?nBJJ002OnAIih7oi9XWPCoTVRO2?nCJIl3oi=ZX003oi=[
XOnKMj[oVgNZ00KoVgNZ0onKMjT3o`0000OoVgNY1?nTR[T3ojB9^0GoY8Rg0onTR;H2ok[Dk@Co^/cX
0_nLl?801?nYkoOoO>KUogcViOmli^D2ogoUk`CoW]_l0_nOfo`2ojC?mPGoYLof0_nUd?H6ojO6l0Wo
Yl;]00?o0000ojO1k?nW`N`01_nW`N`@ojO0jaGooooo00?o0000ooooooooool0:oooool002Wooooo
0_l0000Dooooo`03o`000?oooooooooo02kooooo0ol00002oc8000;o=P0000?o>@03oe<09OmD02P0
0omD02P2oeD0:P?oEP0/0omG02d2oeL0;`CoD@0S0_mA02@2ojNlj0KoZ;gX0_nZ_NL00onBJJ3oTFNN
oi5WWP0;oi5WWPOoTVRN1?nBJ9l8oi=YW`;oTfZP00?oVgN[oi]gZ_nKMjX01onKMjX3o`0000SoVgNY
00?oY8bjojB:^OnTR[T00onTR[T3ojB9^0GoY8Rg00?oY8Rfok[DkOnje>d00onje>d01Onjc>SoW?3b
oic`l_nLl?;oKmoL00?oNN?/0_nNf_`4oikKo003ojC>m_nTcoKoY<of00?oY<of0_nUcoH3ojK6l0Go
YlK`2?nW`^d4ojO1k004o`000?nW`NcoYl7/ojO1k1GoYl3[5Oooool00ol0003oooooooooo`0Zoooo
o`00:Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02cooooo00?o0000obd00?l]
00000_lb00000olf003oD@0Roe<09@02oe<09@?oE00X0omE02X3oeH0;003oeL0;OmB02;oDP0R00Go
D@0S0_nV_>T4ojNlj0CoZ;gX00?oTVZQoi1WWonAIih03_nAIih7oi9XWPCoTVRO1onCJIl01?nJMj_o
VgN[oi]gZonKMj/7oi]gZP;o00002OnKMjT4ojB<^PCoY8Zi1?nTRKP3ojB8]`;o^=cb1?nje>d2ohW/
j005of?IdomehN[oMN7ZogGQj_mihn`01OnNf_`00onNfocoY<kfojC>mP02ojC>mP;oY<of0onVaNl5
ojK6l0;oYlK`2?nW`^d7ojO1k003o`000?nW`>_oYl3[01KoYl3[5?ooool00ol0003oooooooooo`0Z
ooooo`00:Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Sooooo00?o0000obP0
0?l]00000_l]0003oc8000;oD@0R0_mC02D4oe@0:0;oE@0Z0_mF02`00omA027oDP0Roe808P02oe80
8PCoD@0S1?nV_>T4ojNlj003ojRmj?n@IiooT6NO00;oT6NO3onAIih7oi9XWPGoTVRO1?nCJIl3oiYg
Z`CoVgN[0onKMjX3o`0000;oVgNZ1onKMjT00onUSKcoY8bjojB<^P03ojB<^PGoY8Zi0onTRKP00onT
R;Oo^=cbokSLlP03okSLlP03ok[DkOn9k>SoRNcX00;oHmWC0omehNX5oikJo0CoY<ge0_nTc_H7ojK5
k`;oY/K`0_nW`Nd7ojO2k@SoYl7/0onW`>/00ol0003oYl3[ojO0j`0FojO0jaCooooo00?o0000oooo
ooooool0:Oooool002Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Tooooo`?o
00000_lX0002obd00003oc800?m?01koC`0N00;oD@0R0omC02D3oe@0:0;oE@0Z00CoD@0Ooe408OmA
027oD@0Q0omB0282oe408`?oYK_Y1OnV_>T2ojNlj0KoT6NO3onAIih8oi9XWPCoTVRO0_nCJIl6oiYg
Z`?oVgN[0ol00006oi]gZPCoVgNY1?nUSK`4ojB<^PGoY8Zi0_nTRKP3okCSmP;o^=cb0_mdh]P2oeWB
c0;oL^3Y0onNfO`2oikJo0?oY<ce1?nTcOD8ojK5k`?oYl7/1?nW`Nd2ojO2k@[oYl7/1OnW`>/00ol0
003oYl3[ojO0j`0GojO0jaCooooo00?o0000ooooooooool0:?ooool002Wooooo0ol0000Gooooo`03
o`000?oooooooooo02;ooooo0_l000001OlS003o:000obP00?l]003oC@0J00CoC`0N0_mA0283oe<0
9@?oE00X0omA01l2oe408@;oDP0R0_nS^nX6ojFkj@;oY[cY00?oTf^Roi1XWon@J9l02?n@Iil>oi5W
WPSoTVRN1?nBJ9l00onCJIooVWN[oiYgZ`05oiYgZ`?o00002OnKMjX2oi]gZ@03ojF>_OnUSKcoYHfl
00?oYHfl1OnTS;X3ojB:^@;o[^[i0ondhoH00omMe<CoD<g5oe3=a@02og7Oj0CoW]Sl0_nNfO`2ojC<
m0GoY<ce00?oY<geojK5konVaNl01OnVaNl7ojO1k0;oYl7]2OnW`N`:ojO0j`03o`000?nW`>_oYl3[
01KoYl3[4oooool2o`0002[ooooo000Yooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool07oooool01?l0003o7000ob<00?lS0003obP000;oC@0J0om?01h2oe408P?oD`0U0_mD02P01?m@
01coD@0Ooe407omA01l2oe408@;oX[[Z1?nS^nX4ojFkj@03oiA/X_n@J:3oT6RP00?oT6RO2?n@Iil>
oi5WWPSoTVRN0_nBJ9l2oiUg[0GoVWN[0ol00003oi]gZ`SoVgNZ00?oYI2oojF>_OnUS[d00_nUS[d4
ojF=_0GoY8bj00?oY8ZiojkZnOn^j_T00on^j_T01?ndhoKoB/S0og3OjOm`gnT2oioHn`CoW]Sl0_nU
bo@4ojC<m0;oY<ce0onVa>l5ojK5ka3oYl7/3onW`>/00ol0003oYl3[ojO0j`0FojO0jaCooooo00?o
0000ooooooooool09oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0000Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Mooooo`;o70000_lS
00000olX003oBP0DodX05002odd06P?oC`0N0omA02800omC02GoD00Joe006P03oe007003oe407onQ
^^_oXK[[00GoX[[Z1?nS^nX00onU^nWoT6RQoi1XX003oi1XX0CoT6RO1on@Iil?oi5WWPKoTVRN1OnI
Mj`2oiYgZ`?o00000onJMj/3oi]gZ`KoVgNZ1?nUT;l3ojF>_@GoYHfl0onTS;X3ojK^n0;o[^[i00Co
AlB^og7Oj_magn[oWmOk1OnOf?/00onNf?coYL_dojG;m003ojG;m0;oY<cd1onVa>l2ojK5k`ooYl7/
4_nW`>/00ol0003oYl3[ojO0j`0FojO0jaGooooo00?o0000ooooooooool09_ooool000kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Go
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Iooooo`06o`000?lD003o7000oa`0
0?lS003oAP0>1?m:01@00om=01[oC`0Nodl07P02odl07P03oe408_m?01KoD00J00?oD00J00?oD00L
oinijonO^N/01?nQ^^/5oj:jjP;oXk_Z0on@J:44oi1XX0CoT6RO1on@Iil?oi5WWPCoTVRN1_nIMj`3
o`0000KoVWN[1?nKMj/3oi]gZP03ojFA`OnUT;ooYI2o00?oYI2o0onUS[d5ojF=_003ojB<^_nVk_So
Y^kh00;oY^kh00Co0000og?Pjomch>_oLMoZ1?nOeo/2oioHn`CoYL[c0_nUbo@2ojO4kPOoY/C_2OnW
`N`3ojO0k0GoYl7/5OnW`>/00ol0003oYl3[ojO0j`0FojO0jaCooooo00?o0000ooooooooool09_oo
ool000Kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP06ooooo`;o00007Oooool00ol0003oooooooooo`0Eooooo`06o`000?l<003o5000oa@00?lL003o
@P060om600h3odX050;oC@0J00?oC`0Nodd04_m=01800om?01H3oe006P03oe007?nO^N_oWkW[00;o
WkW[1?nQ^^/2oj:jjPCoTFVQ0on@J:44oi1XX0CoT6RO1on@Iil?oi5WWP;oTVRN00?oV7N/oiUg[?nI
Mj`00onIMj`2o`000003oiUg[?nJMj_oVWN[00OoVWN[0onKMj/00onKMj[oYI71ojFA`@02ojFA`@Co
YI2o1?nUS[d3ojF=_0?oV^od00CoY^khogGQkOmch>_oLn3[1?nPe_/2oioGn`;oYLWb1?nUb_<00onW
`nkoYlC^ojO4kP03ojO4kP;oY/C_0onW`>`6ojO1k0SoYl3/0_nW`N`HojO0j`03o`000?nW`>_oYl3[
01KoYl3[5?ooool00ol0003oooooooooo`0Uooooo`003_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
01?ooooo00Co0000o``00?lD003o50000om200H2odH03P?oBP0D00?oC@0Jod`03Om=01800om=0182
odl05P;oD00J0onN^>/5oinij`;oXK[[0onAJZ84oi5YX@CoT6RQ0on@J:04oi1XW`OoT6NO3OnAIih2
oiMf[0?oV7N/0_nIMj`3o`0000CoVGN/2?nJMj/2oi]gZ`03ojFC`onUTL7oYI7100?oYI711OnUT;l3
ojF>_@04ojF=_?nJkoCoV^odoi[_m0?oMN7]0onQeOX2oj3Fn`?oYLSb1?nUbO800onUb_?oYl?^ojO3
kP02ojO3kP?oYlC^1onW`>`2ojO1k0WoYl3/7OnW`>/00ol0003oYl3[ojO0j`0EojO0jaGooooo00?o
0000ooooooooool09?ooool000kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00Cooooo00?o0000ooooooooool07_ooool2o`00017ooooo00Go0000o`400?l<003o5000
ocd00003od801P;oAP0>1?m:01@2od`03@?oC@0B0_m?01H2oibhk0GoW[S[0_nO^N/01?nBKJCoTF^S
oi5[XonAJj<3oi5ZXPCoTFVQ1?n@J:43oi1XX0CoT6RO1on@Iil:oi5WWPGoUgJ/0_nHMj`3o`0000Oo
VGN/1onJMj/00onTU<CoYI?3ojFC``02ojFC``CoYI711OnUT;l2ojF>_@;oSNc]0_mghNh5oj7EnP?o
Y/Sa1OnUb?82ojG9lPOoYl?^00?oYlC^ojO0k?nW`>`01OnW`>`00onW`>_oYl3/ojO0k005ojO0k27o
Yl3[00?o0000ojO0jonW`>/05_nW`>/Cooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`02Oooool000kooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00?ooooo0_l0000Qooooo`03o`000?oooooo
oooo00cooooo00CoD<JSo`400?l1003o=`000olm0002od801P?oAP0>00?oBP0DodT01om900L00_nI
]n`5oi^gk0CoW;S/0_nN^>/00onCKZKoTVfToi9]Y002oi9]Y0?oTF^S1?nAJZ83oi5YX@CoT6RQ1?n@
J:03oi1XW`SoT6NO2?nAIih5oiMf[0?o00000_nHMj`8oiUg[0GoVWN[1?nTU<@3ojFC``GoYI710onU
T;l2ogkWh`03og[Rl?nRe?WoX]Ci00;oX]Ci0_nQeOX2ojK7l@GoY/Sa0_nUb?89ojO3kP?oYl3[1OnW
`>`4ojO0j`?oYl3/9OnW`>/00ol0003oYl3[ojO0j`0FojO0jaCooooo00?o0000ooooooooool01Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ
8B402Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001?ooool2o`0002?ooooo00?o0000ooooooooool02Oooool01?m@aZ?o0@00o`400?l10002
ocL000;o?@000om200H00om600koAP00odT01`02oiNfk@CoVKO/1OnK]n`2oibhk004oiA`YonCKZKo
TfjVoi=^YPCoTVfT1?nAJj<3oi5ZXPCoTFVQ0on@J:44oi1XX0?oT6RO2?n@Iil5oi5WWP;oUWF/0onG
MZ`3o`0000;oUgJ/0onHMj`8oiUg[0;oVWN[0_nTU/H5ojBDa0?oYI?31OnUTL400onUT;ooO^OSogkW
h`06oj;Dn@KoY/Oa0_nVb?43ojO3k@KoYl?^2?nW`>/2ojO0k0OoYl3[00?oYl3/ojO0jonW`>/09OnW
`>/00ol0003oYl3[ojO0j`0FojO0jaCooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go0000ooooooooooooooooo`000009ooooo`003_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool01_ooool2o`000003o`400?l_003o;`0000;o=`000_lm00001Om2
00Ko@`00od<00?m6003oU[K^00GoUkK]1?nI]n`2oi^gk0;oUG:Y0onDL:L4oi=^YP?oTVfT1?nAJj<3
oi5ZXPCoTFVQ0on@J:44oi1XX0CoT6RO1on@Iil2oi5WWP03oiEe[?nFMJcoUWF/00;oUWF/0ol00005
oiMf[0?oV7N/1onIMj`00onTUlOoY9K6ojBFaP03ojBFaPCoY9C41?nUTl<2ojFA`@;oKn3H0_nSdoT5
oj;Dn@OoY/Oa1onW`nd2ojO3kSgoYl3[00?o0000ojO0jonW`>/05OnW`>/Dooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80
2Oooool002Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`03ooooo`;o000000Co
9000obl00?l_003o;`000_lg00000olm003o?P00od<00002oiBfkPCoU[K^1OnG]^d2oiVgk003oiIe
ZonELZWoUG:Y00;oUG:Y1?nDL:L3oi=^YP?oTVfT1?nAJj<3oi5ZXPCoTFVQ0on@J:44oi1XX0CoT6RO
1On@Iil2oiAd[0?oUGF/00GoUWF/o`000?l0003o0000oiIe[007oiMf[0CoV7N/1OnIMj`3ojBGa`Co
Y9K61OnTU<@2ojFC``;oHMO<00?oO^?coj?CnOnSdoT00onSdoT2oj;Dn@;oY/K`1?nVao400onW`^go
Yl?]ojO3k@05ojO3kD7oYl3[00?o0000ojO0jonW`>/05_nW`>/Dooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`02Oooool0
02Oooooo0_l0000Vooooo`03o`000?oooooooooo00?o000000?o9000obl00?l_00000_n@]O04oi:e
k`CoU;K^1?nF]^h2oiNfk@03ojB8]onHN:koUWF[00;oUWF[1?nELZT4oiA`Y`?oTfjV1?nBKJ@3oi5[
X`?oTFZR1?nAJJ44oi1XX@?oT6RP1?n@J9l2oi1WW`03oi=c[?nDM:coU7B/00;oU7B/0_nEMJ`2o`00
00CoUWF/1onGMZ`4oiQg[0;oVGN/0_nSUlP5ojBGa`?oY9K61OnTU<@00onUTl?oPNCdoh7Tm003oj?C
n0;oXm?i1onVa_000onVao7oYl;]ojO2k@02ojO2k@?oYl?]AOnW`>/00ol0003oYl3[ojO0j`0EojO0
jaGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@
okZj^_oooooo^[Zjoa0@4009ooooo`009oooool00ol0003oooooooooo`0Vooooo`?o00000_lT0003
ohjel@?oT;G`1?nB]Nl4oiBfkP;oU[K^00?oYXfjoiYl/?nHN:h00_nHN:h4oiIeZ`?oUG:Y1?nDL:L3
oi=^YPCoTVfT0onAJj<4oi5ZXP?oTFVQ1?n@J:43oi1XX0;oT6RO0_nCLZ/3oi=c[0?oU7B/0ol00002
oiEe[0CoUWF/2?nGMZ`2oiQg[003oj>HbOnSUlSoXiO800?oXiO81?nTUlL4ojBFaP;oY9C400?oP^Gd
ojCBn?nTd_P00_nTd_P2oj?Cn0WoY/K`1onW`^d00onW`ngoYl3[ojO0j`15ojO0j`03o`000?nW`>_o
Yl3[01GoYl3[4_ooool3o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooookZj^_l000002Oooool002Oooooo00?o0000ooooooooool09?ooool2ohVelPCoS;Gb1On>
]O43oi2el0;oT[G_00?o[IW2ojZB__nZT[h00onZT[h00onVSK[oVWb`oiYl/004oiQh[P?oUWF[1?nE
LZT3oiA`Y`?oTfjV1?nBKJ@4oi5[X`?oTFZR0onAJJ44oi1XX@;oT6RP00?oTW:[oi=bZonCLZ/00_nC
LZ/3oi=c[0?o00000_nDM:`3oiEe[0CoUWF/2?nGMZ`01?nHMjcoXiS9oj>HbOnSV<T4oj>Gb0GoY9O7
0_nTU/H00om9akKoY=;hojCBn003ojCBn0?oYlK_1_nVa_09ojO2kD[oYl3[00?o0000ojO0jonW`>/0
5_nW`>/Dooooo`09o`000?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@09ooooo`009_ooool3o`0001_ooooo0_n2]?D4ohFdm0CoQkGc0on9]O84
ohbelP;oS[Ga00?o/jG:ok2Oa_n`WlH00_n`WlH4ojfI`P;oZY:n0_nMP;<4oiYl/0?oV7R^0onFMJ/4
oiEbZ@?oU72W1?nCKZH3oi9]Y0CoTF^S0onAJZ82oi5YX@03oi5`Z_nALJ_oTG6[00;oTG6[0onBLZ/4
oi=bZ`?o000000?oTg>/oiAd[?nDM:`00_nDM:`3oiEe[0GoUWF/1OnGMZ`2oj:HbPCoXiS91?nSUlP4
ojBGa`03od70[_nTd_SoY=;h00?oY=;h0_nWaNl5ojO6k`;oY/K`2OnW`^e>ojO0j`03o`000?nW`>_o
Yl3[01GoYl3[5Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Boooo
o`;oN[;g1?mm/oH3ogndmP?oP[Ce1?n5]?@4ohNel`?oRKGb0_n<]O800oo1c>?o/jG:ok>UbP02ok>U
bP?o/9o60on]VL800onOQKOoWH2coif0/`02oif0/`CoVWb`0onHN:h3oiIeZ`CoUG:Y1?nDL:L3oi=^
YP?oTVfT1?nAJj<2oi5ZXP04oi1`Z_nAL:[oTG2Zoi5`ZPCoTG6[1?nBLZ/3o`000004oi=bZonCLjco
Tg>/oi=c[0CoU7B/1?nEMJ`4oiIe[0;oUgJ/00?oXIO:oj:Hb_nRV<X00onRV<X3oj>Hb@GoXiO800?o
Y9O7ojGBn?nTd_P01OnTd_P4ojO5k`;oYlK_2OnW`^eCojO0j`03o`000?nW`>_oYl3[01GoYl3[5?oo
ool00ol0003oooooooooo`0Nooooo`006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o
0000oooooomZZ_H00_mZZ_H3ofb/m`?oKjkg0oma[oL3ogB`m`?oMk7g1?mj/_L4ogfcmP?oOkCf0on2
]?D2ohFdm0?o8Zk500?o_^Kbol;<h_o2c>800oo1c><00onfZlgo/jG:ok>UbP03ok>UbPCo/9o600?o
[IW2oin5]onOQKL01?nMP;<4oiYl/0?oV7R^0onFMJ/4oiEbZ@CoU72W0onCKZH2oi9]Y003ohm_Z_n@
Kj[oT6nZ00;oT6nZ0on@L:X4oi5`ZPCoTG6[0ol00004oi=bZ`?oTg>/1OnDM:`3oiEe[0;oUWF/0_nP
U/X4oj6GbPCoXYS:1?nSV<T2oj>Gb003ojGBmonUd_SoYM;h00;oYM;h0_nTd_P6ojO5k`WoYl;]EonW
`>/00ol0003oYl3[ojO0j`0EojO0jaCooooo00?o0000ooooooooool07Oooool001_ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00?oJZ[f0om/[?L3ofn^m`?oLJog0omd
/?L3ogNam`CoN[;g0_mm/oH3od>nk@;o>;_R00CoJ]gGoiobl?nOl_3oWo;`0_nni_85ol;<hP04ol7<
honfZlgo]Z_=okJ[c@Go/jG:0_n`WlH00onSR[[oWhFgoin5]`02oin5]`CoWH2c0onJO;03oiQh[PCo
UWF[0onELZT4oiA`Y`;oTfjV1?n?KjX4oi1_ZPCoT72Z0onAL:X01?nALJ_o0000o`000?l00003oi9b
Z`CoTg:[1?nCLj`4oiAd[0;oUGF/00?oWiG:oj2Fb_nPU/X00onPU/X3oj6GbPGoXYS:0_nSV<T5ojGB
m`;oYM;h2?nWaNl6ojO2kE_oYl3[00?o0000ojO0jonW`>/05_nW`>/Cooooo`;o00007_ooool001_o
oooo00Go410@oooooooooooooooooa0@4006ooooo`;o00000_ooool3off[mP?oJK3i1?mU]O`4of2i
o@?oFkcl0omD_oX2odg0m@?o;kS?0_mni^`3ojS`m`?o_n7`0_o2bn83ol;<hP03okV`d?nfZlgo]Z_=
00;o]Z_=1?ncYLX00onVT;koXhZjoj>:^P02oj>:^P?oWhFg1?nMP;<4oiYl/0?oV7R^0onFMJ/2oiEb
Z@03oi1`Zon?Kj[oSfnZ00WoSfnZ0on@KjX4oi1`ZP04oi5`Z_l0003o0000o`0000?oTG6[0onBLZ/5
oi=bZ`?oTg>/0_nDM:`2oijCb@CoWiG:1?nPU/X4oj6GbP;oXYS:0_n8ioH5ojGBm`WoYlG_1_nW`^eO
ojO0j`03o`000?nW`>_oYl3[01GoYl3[4_ooool00ol0003oooooo`00000Nooooo`006oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool3off[mP?oJK3i1?mU]O`2
of2io@?oI<Km0_mFaoH3of_Gm@?oS^Oi1?n_j_T01?nXl?Oo_n7`okoQl?nohO04ol;;hP04ol;<h_ni
/=3o^K3@okV`d0Co]Z_=00?o/jG:ojJ@__nVT;h00_nVT;h3oj>:^P?oWhFg1?nMP;<4oiYl/0?oV7R^
0_nFMJ/4oi1`Z`_oSfnZ0on@KjX3oi1`ZP;o00000_nAL:X4oi5aZ`CoTW:[1?nCLZ/2oi=c[003oibA
b?nNTlWoWY?900?oWY?90onOULX4oj2FbP?oXIO:00?o0000ojGCmonUdoL00_nUdoL2ojGBm`WoYlG_
2?nW`^eQojO0j`03o`000?nW`>_oYl3[01GoYl3[5?ooool00ol0003oooooooooo`0Kooooo`006ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool4ogbamPCoM[[k
0om^`Oh2ofC6o@?oN]Kn1?nIhOd01?n>ioWo[n[iojoZnOn_j_T4okoKkP03okoQl?o2bn;o`/_R00;o
`/_R00?o^kCCokV`d?ni/=000oni/=02okJ[c@03ojZG`_nVT;koYY2n00?oYY2n0onSR[X4oin5]`?o
WH2c0_nJO;02oi9c[@?oTG:/1on@L:/:ohm_ZP?oT6nZ0ol000001?n@L:[oTG2Zoi5`Z_nAL:X5oi5a
Z`?oTW:[0_nCLZ/2oi^?aPCoW9781?nNTlT3oinEbPGoX9K:00?oXIO:ojGCn?nUdoP00_nUdoL3ojO6
k`KoYlG_2OnW`^eTojO0j`03o`000?nW`>_oYl3[01GoYl3[5Oooool00ol0003oooooooooo`0Joooo
o`006oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool01Oooool4ogba
mP;oM[[k0on<a?X4ohG>o`04og[Fo_nIhOgoVN7moiWQo@?o/^7g0onneN/3okoKkP?o`L[Q00?o`/_R
ok^ddonk]=<00_nk]=<3okV`d003ojjMa_nZUl;oZYO200;oZYO21?nVT;h4oj>:^P?oWhFg0_nMP;<0
0onCMZooTW>]oi9c[@02oi9c[@?oTG:/1on@L:/:ohm_ZP?o000000CoT6nZoi1`Z_n@L:[oT72Z1?nA
L:X4oi5aZ`;oTW:[00?oVXg5oi^?a_nKSlH00onKSlH3oibAb0CoWY?91?nOULX2oj2FbP04ojKCn?nU
doSoYM?hojGCn0OoYlK_0_nWaNl9ojO2kFSoYl3[00?o0000ojO0jonW`>/05OnW`>/Dooooo`03o`00
0?oooooooooo01[ooooo000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000Oooooo
0_ml/OH2oi2ilPGoS<Cj0_n5c_l2oioGn`Co/]Oc00?o/^7gokkEjonneN/00onneN/00onofnko`L[Q
ol7:h@02ol7:h@03okbhe_nk]=?o^kCC00?o^kCC00Co^K3@ojjMa_n^WLKo[Yg60onZUl85ojJ@_P?o
XhZj0_nOQKL01?nENK7oTgJ_oi=f[onCMZl4oi9c[@?oTG:/1on@L:/7ohm_ZP?o00001?n@KjX4oi1`
ZP?oTG2Z0_nALJ/2oiR;``CoVXg51?nKSlH3oibAb0GoWY?90_nOULX5ojKCn003ojGCn?nWa^ooYlK_
00CoYlK_2OnW`^e]ojO0j`03o`000?nW`>_oYl3[01GoYl3[5?ooool00ol0003oooooooooo`0Ioooo
o`006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool01oooool4oi2i
lP;oS<Cj1?nRboD00onOeo_o/]Ocok;Gl`02ok;Gl`;o_LoX1?nneN/2ol79h@?o`L[Q0onl^=H3ok^d
d`03ok6Tbon^WLKo[Yg600;o[Yg60onZUl85ojJ@_P;oXhZj00CoV7bcoiEi/OnENK7oUGVa1?nCMZl3
oi9c[@?oTG:/1on@L:/4ohm_ZP?o00001?n?KjX3oi1_ZPCoT72Z0_nAL:X00onGR<;oV8_3oiR;``03
oiR;``?oVXg51?nKSlH4oibAb0;oWY?900?oR>SdojKDn?nVe?P00_nVe?P2ojKCn0KoYlK_2OnW`^ea
ojO0j`03o`000?nW`>_oYl3[01CoYl3[5?ooool00ol0003oooooooooo`0Iooooo`009Oooool00ol0
003oooooooooo`08ooooo`;oT;Wb1?nR_^d2oj;;m@Co//c]00?o/]Ocokg?j?nmcnP00_nmcnP00onn
eN_o`LWQol79h@03ol79h@03ol7:hOnl^=Ko_;SF00?o_;SF00Co^kCCok6TbonaY<_o/JC;0on^WLH4
ojZG`P;oYY2n0_nJPKL3oiQl/`CoUGVa0onCMZl4oi9c[@?oTG:/1_n@L:/01?n?Kj[o0000o`000?l0
0007ohm_ZP?oT6nZ0_n@L:X2oiJ6`0CoUhS21?nHRl<3oiZ=a@GoVho60_nLTLP2ohOXl`?oY]Gh0_nV
e?P3ojS6l0GoYlK_1_nW`^eeojO0j`03o`000?nW`>_oYl3[01GoYl3[4_ooool00ol0003oooooo`00
000Jooooo`009Oooool00ol0003oooooooooo`0:ooooo`?oX[k]0_n``^L4ok;<k@;o^lWU0onmcnP3
ol37h0?o`LWQ0_nn_=P4okbheP03okBZc_naY<_o/JC;00;o/JC;1?n^WLH2ojZG`P03oij6^_nJPKOo
VX6g00;oVX6g1?nHO;<3oiEi/@?oTgJ_1?nBLjd3oi5b[0CoT72[0ol00009ohm_ZP04oi>2_OnEQ;ko
UHBnoiF4_PGoUXK00onGR<84oiR;``CoVXg50_nKSlH00oln`;SoQ^SbojKEn005ojKEn0;oZ<O`1OnX
a_02ojO6k`GoYl;]NOnW`>/00ol0003oYl3[ojO0j`0EojO0jaCooooo00?o0000ooooooooool05ooo
ool002Gooooo0_l0000<ooooo`03oj:nkOn``^Oo/<;W00;o/<;W00?o//c]ok_9iOnkbND00onkbND0
0onmcnSo`<OPol37h003ol37h003ol79hOnn_=So_[cH00;o_[cH00?o_;SFokBZc_ndZ/h00_ndZ/h4
ok6Tb`;o[Yg600?oXXfnoij6^_nNQ[X00_nNQ[X3oiZ1]`CoV7bc0onENK43oi=f[`CoTW>]0onALZ`2
oi1`Z`;o00000on@L:/5ohm_ZP;oTh2l1?nCP[d3oiF4_PCoUXK00onGR<85oiR;``;oVXg50_m6a/83
ojKFn@;oY]Gh1onXao02ojS6l0SoYl;]NonW`>/00ol0003oYl3[ojO0j`0EojO0ja?ooooo00?o0000
ooooooooool05oooool002Cooooo00?o0000ooooooooool03Oooool3ok32i`?o^/?Q0onkbND2oko6
g`Co`<OP0_nn_mX3okjlf003okN`d_ndZ/ko]:[>00?o]:[>0onaY</00onUU<?oXXfnoj:=_P02oj:=
_P?oWXJj1?nJPKL3oiQl/`?oUGVa1?nCMZl3oi9c[@;oTG:/0ol00004oi1`Z`04oi5m^_nBO[[oTWjj
oi9n^PGoTh2l0onCP[d3oiF4_PCoUXK01?nGR<82oiR;``;oC/c=1?nVeoT2ojKFn@;oZ<S`1onXao09
ojO2kGkoYl3[00?o0000ojO0jonW`>/05?nW`>/Dooooo`03o`000?oooooooooo01Kooooo000Toooo
o`03o`000?oooooooooo00kooooo00?o/<;Wok[3hOnj`n400onj`n400onkbNGo_lKOoko6g`02oko6
g`03ol37h?nn_m[o_[oJ00?o_[oJ00Co_[cHokN`d_ng/=;o]k3B1OndZ/h01?naY<_oYIC3ojFD`onU
U<<3oj:=_P?oWXJj1?nJPKL4oiQl/`?oUGVa0onCMZl2oi9c[@?o00001On@O;T4oi5m^P?oTWjj1?nC
P;`3oi>2_@?oUHBn1OnFQ/02oiN8`P;oF=;I0onVf?T3ojKGn@;oZ<Wa1?nXb?02ojS7l0?oYl?]1_nW
`^f2ojO0j`03o`000?nW`>_oYl3[01GoYl3[5?ooool00ol0003oooooooooo`0Eooooo`009?ooool3
o`0000oooooo1?nj`n42okk4gP?o_lKO0ono`M/3okjofP03okZgeong/=;o]k3B00?o]k3B0_ndZ/h2
ojVLb0CoYIC30onRSKh4oij6^P?oVX6g1?nHO;<3oiEi/@;oTgJ_0ol00009oi1l^@?oTGfj0onBO[X4
oi>0_0CoTh:m0onEQ;h2oiJ6`0?oH]OU00?oPNO]oh;Wk_nVf?T01?nVf?T00onVeoWoZ<WaojS9l@02
ojS9l@;oZ<S`0_nX`nd5ojO3k@;oYl;]Q_nW`>/00ol0003oYl3[ojO0j`0EojO0ja;ooooo0_l00009
ooooo`Co000000?o410@ooooooooool01oooool002Cooooo00?o0000ooooooooool04?ooool00onj
`n7o_/CNokk4gP03okk4gP03oko6gono`M_o_l7K00?o_l7K00Co_[oJokZgeonj]mOo^[OG0ong/=80
0on^Y<koZIc8ojVLb003ojVLb0?oYIC31?nRSKh3oij6^P?oVX6g0_nHO;<2oi:0_0;oTGjk0ol00002
oi1l^P[oT7bi0onAOKX3oi9n^PGoTh2l0onCP[d2oiF4_P;oK=[`00CoD/g1oh7WkOn1ingoPNO]0onV
fOT2ojKHn@KoZ<Wa1_nX`nd2ojO3kH_oYl3[00?o0000ojO0jonW`>/05OnW`>/Cooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02Oooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool04_ooool3okk4gP;o`<CM1?no
`M/00onl_M_o^[OGokZge`03okZge`04okN`d_n^Y<ko[ZC>ojjTcPCoZIc81?nUU<<3oj:=_P;oWXJj
00CoUXO2oiB3__nDPkkoU8>n0onBP;`3o`0000;oTGjk0on@O;X:oi1l^@CoTGfj0onBO[X4oi>0_0;o
Th:m0_mefoP00omCc/CoOnK/ogoVk004ojKJnP;oY]Wi0_nXb_44ojS9l@SoZ<?]S_nW`>/00ol0003o
Yl3[ojO0j`0EojO0jaCooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`00
2Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01_ooool00ol0003oooooooooo`0Cooooo`03okk4g_o0a=go`<CM00;o`<CM00?o_l7Kokbm
fonl_M/00_nl_M/3okZge`03ok6^e?n^Y<ko[ZC>00;o[ZC>1?nYW<P4ojFD``;oXXfn00?oVHg5oiJ7
`_nFQl800_nFQl82oiB3_P?o000000?oTX2loi5n^onAO[/00_nAO[/3oi1l^P_oT7bi0onAOKX3oi9n
^P;oTh2l0ommfOd00ol0003oO^K[ogkVj`04ojGJnP;oY][j0_nXbo84ojS:l@03ojS9lOnX`ngoZ<?]
00GoZ<?]T_nW`>/00ol0003oYl3[ojO0j`0EojO0ja?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`09ooooo`002Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h01_ooool00ol0003oooooooooo`0Eooooo`?o`<CM0onna=l4okbmf`04okZgeona[]Co/JkD
ok6^e0?o[ZC>1OnYW<P2ojFD``03oibCbOnISLGoVHg500;oVHg50onFQl82o`000003oiB3__nBP;co
TX2l00;oTX2l0onAO[/4oi1l^P[oT7bi0_nAOKX3ohO=oP;oPmCo0olf^k@01?mmiN_oYM_jojGKn_nU
foX2ojGJnP?oZ<cb1?nXbo82ojS:l@GoZ<?]UonW`>/00ol0003oYl3[ojO0j`0EojO0ja?ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`002Oooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`0001Kooooo00?o`<CMokk4gonna=l00onn
a=l2okbmf`03okFhfona[]Co/JkD00;o/JkD1?n^Y<h2ojVLb0;oWi[?1?nLTlT3oiV=a@?o00000onD
Pkh4oi:0_0CoTGjk0on@O;X5oi1l^@?oRkgg1?n9aO/2ohO=oP;oALK80_mliN`3ojGLn`;oYM_j0_nX
cO<5ojS<lP;oZ<_b0_nXa>h3ojS3kI_oYl3[00?o0000ojO0jonW`>/05OnW`>/Aooooo`?o00001ooo
ool00ol0003oooooooooo`09ooooo`002Oooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool01?ooool00ol0003oooooooooo`0Hooooo`?o_/CO00?o^<?SokFhfone^=/00_ne
^=/4ok6^e0;o[ZC>0_nSXm@4oinJc`?oW9?90ol00004oiJ7`P?oU8>n0onBP;`4oi5n^`;oT7bj00?o
Rjk]oh^el_n;]O800_n;]O85oh^mm`;oRLGk0_mCd=/01?mJe=7oO>G/ogcUk?mliN`3ojGLn`;oZ<kc
1?nXcO<2ojS<lPOoZ<C^00?oZ<?]ojO0jonW`>/0V_nW`>/00ol0003oYl3[ojO0j`0EojO0j`kooooo
1?l000000ooooooo0000ooooo`06ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo
00Co_/COokS3honh`n?o^<?S1?ne^=/2ok6^e003ojJ/fonSXmCoXj?D00?oXj?D0onOV/l3o`000004
oibCbOnISLGoVHg5oiV=a@?oUXO20_nDPkh00on<XN;oS:CUohbTi@02ohbTi@CoS:SX0on;[^d4oh^e
lP;oRkgg0omRe^/2oekFe`;oONG]1?nTg?/00onUg?_oZ<kcojS>l`02ojS>l`;oZ<gc2OnXa>jOojO0
j`03o`000?nW`>_oYl3[01GoYl3[2_ooool3o`0000Gooooo00?o0000ooooooooool00oooool00omE
EEGoIVIVo`00000;ooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_ooooooV9RHoa0@4005ooooo`;o00006oooool4okS3h`;o]KSK00?oZKKRojJ/fonV[=/00_nV[=/4
oj>Se0?o000000CoWi[?oibCbOnLTlWoTZ?P0on?XN03ohjPh0CoS:7R1?n<Y>D4ohbXj0?oRjk]0_n;
]O82ofkHm`?oH]SO0_mmi>l4oj?Ln`;oY=ck0onXc_@2ojS>l`;oZ<G^1onXa>h2ojS0jj7oYl3[00?o
0000ojO0jonW`>/05?nW`>/6ooooo`Co00002?ooool00ol0003oooooooooo`0Aooooo`002Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`00
0?oooooooooo01_ooooo0_nh`n<2oj_1j@?oZKKR1?nV[=/3o`000004oiN[i?nDY^;oU:KRoiBVhPCo
TZ?P0on?XN03ohjPh0CoS:7R1?n<Y>D2ohbXj0?oO]3o0_mgeOd3ofOJi`;oO^Ca1OnSg?/4ojS?m0;o
Z<kd1_nXaNh2ojS4kP?oZ<7/1?nX`>^PojO0j`03o`000?nW`>_oYl3[01GoYl3[0_ooool3o`0000co
oooo00?o0000ooooooooool04Oooool002;ooooo00?o0000ooooooooool07Oooool4oj_1j@?oZKKR
0ol000000onI/>OoUj_ToiN[i002oiN[i0?oU:KR1?nBXn03ohnQh0?oSZ3P0_n<XN83ohG3o0CoP/Wn
0_mnd?l2ofcKk`?oP>Ce0onRfo/2oj?Ln`?oYm3e0_nXco@3ojS5k`KoZ<G^1onX`N`2ojS0jj;oYl3[
00?o0000ojO0jonW`>/05OnW`>/00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo013ooooo
000Rooooo`03o`000?oooooooooo01kooooo0_n[`NT2oi^ml0;o00000_nJ]^/3oiV`i`CoUj_T0onD
Y^82oi:Sh0;oR[Kc0on9^?D5ohNmn0?oQL?l0_n2bOh2og7KmP;oP^;h1?nQf_/2oj;Kn`GoYm3e0onX
a^l4ojS5k`;oZ<G^2?nX`NbWojO0j`03o`000?nW`>_oYl3[01GoYl3[4?ooool00ol0003ooooooooo
o`0@ooooo`008_ooool2o`00023ooooo0ol000000onK_O3oV[K[oiZfj`02oiZfj`?oVK3W0_nGZn@2
ohjdl@?oS;Ca1?n:]_<3ohVhm@;oQkgh1?mjeOh2ogKIn`;oQN3k1?nPfO/2oj7Jn`;oY]3f1OnWd?D5
ojS6k`;oZ<G_2?nX`Nb[ojO0j`03o`000?nW`>_oYl3[01CoYl3[4?ooool00ol0003oooooooooo`0@
ooooo`008_ooool00ol0003oooooooooo`0Looooo`?o000000?ooooooi^ml?nK_O000_nK_O02oiZf
j`;oT;Oa0on?]_44ohjdl@?oS;Ca0_n:]_<4oh7<o`?oO]7o0_mjeOh2ohOMoP?oWmOk0_nPfO/7ojK@
mP;oYm3e1OnXa^l9ojS1k0;oYl3/[?nW`>/00ol0003oYl3[ojO0j`0EojO0j`oooooo00?o0000oooo
ooooool04?ooool002;ooooo00?o0000ooooooooool06Oooool3o`0000Kooooo0onA^O84oi2gl@?o
SkKa0_n>]?42ohO2n`CoQ<Om0_n1c?l4ohcDo`;oR]Wo0onNe?/2oioGn`?oYLof1_nVd?H5ojS6k`;o
Z<;/1onX`N`2ojO1k0CoYl3/[?nW`>/00ol0003oYl3[ojO0j`0DojO0j`oooooo00?o0000oooooooo
ool04?ooool002;ooooo00?o0000ooooooooool05_ooool3o`0000[ooooo0onA^O82oi2gl@;oRk_f
1?n9__P3ohO2n`;oQ<Om1?n>c_h2ohcDo`?oWM3j0_nNe?/2ojC>mPGoYLof0_nVd?H3ojO6k`;oZ<K_
1_nX`^`2ojS1k0OoYl7/0_nW`>b^ojO0j`03o`000?nW`>_oYl3[01CoYl3[3_ooool00ol0003ooooo
ooooo`0@ooooo`008_ooool2o`0001Cooooo0ol0000>ooooo`?oS[Sc1?n;^oH2ohVnn0;oT<Ch1On?
bO/2ohk>oP?oW<gi0_nMd?X2oj?<m@CoY<kf0_nUcoH6ojO6k`;oZ<;]1_nX`^`9ojO1k;;oYl3[00?o
0000ojO0jonW`>/05?nW`>/=ooooo`03o`000?oooooooooo013ooooo000Qooooo`;o00004_ooool3
o`0001;ooooo0on>^?<2oh^kmP;oT[ke1?n@a?P2oho9n`CoVlSg0_nLcOT2oj?9m0CoXlce0_nTc_H8
ojO6k`CoZ<;]0_nX`^`9ojO1k;GoYl3[00?o0000ojO0jonW`>/05OnW`>/<ooooo`03o`000?oooooo
oooo013ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l00000
0ol@413oooooooooo`03ooooo`03o`000?oooooooooo00oooooo0_l0000Fooooo`CoTk[b0onB__D2
oi34n0CoVlCe0_nKb?L2oj;7l`CoXlWd0_nSc?D3ojK5k`KoYlK_1OnX`^d8ojO1k;[oYl3[00?o0000
ojO0jonW`>/05?nW`>/=ooooo`03o`000?oooooooooo00oooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<
ooooo`?o00006Oooool2oi>jlP?oVkc`1?nK`?82oi_4m@;oXLCa1?nRao<2oj?9m0;oY/C_1OnVaNl2
ojO6k`;oYl;]0onX`^d8ojO1k;koYl3[00?o0000ojO0jonW`>/05?nW`>/<ooooo`03o`000?oooooo
oooo00oooooo0007ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo0_l0000:
ooooo`?o00007Oooool5oi^ll0;oVl3b0_nQ`O04oj74l@;oX/Oc0_nU`nl4ojK4k`;oY/G_1onW`^d0
0onX`^goYl7/ojO1k004ojO1k<7oYl3[00?o0000ojO0jonW`>/05OnW`>/;ooooo`03o`000?oooooo
oooo00oooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0
0006ooooo`03o`000?oooooooooo00Kooooo0ol0000Qooooo`;oVkc`0onQ_^h4oj71l0;oXLCa0_nU
`^h4ojG3k`;oY/C_2OnW`^d5ojO1k<GoYl3[00?o0000ojO0jonW`>/05OnW`>/:ooooo`03o`000?oo
oooooooo00oooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEoooo
ool00006ooooo`03o`000?oooooooooo00?ooooo0ol0000Vooooo`CoXKk^0_nQ`O02ojG1k@CoYL;^
0_nU`nl9ojO2k@GoYl7/bOnW`>/00ol0003oYl3[ojO0j`0DojO0j`[ooooo00?o0000ooooooooool0
3oooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Gooooo
00Co0000oooooooooooooooo0ol0000Zooooo`;oXKk^0_nT_n`4ojG1k@;oYL;^0_nV`N`6ojO2k@Ko
Yl7/cOnW`>/00ol0003oYl3[ojO0j`0DojO0j`Wooooo00?o0000ooooooooool03oooool000Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Gooooo1?l0000^ooooo`Co
Y;o/0_nU`Nd2ojK0k0CoY/7/0_nW`^d8ojO1k<koYl3[00?o0000ojO0jonW`>/05?nW`>/9ooooo`03
o`000?oooooooooo00oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo
0000ooooo`04ooooo`;o0000<Oooool2ojBok0;oY[o/1?nV`>`2ojK1k0;oYl3/1onW`NcAojO0j`03
o`000?nW`>_oYl3[01CoYl3[2?ooool00ol0003oooooooooo`0?ooooo`008_ooool00ol0003ooooo
ooooo`0_ooooo`CoY[o/0_nV`>`6ojO0k0;oYl7/e_nW`>/00ol0003oYl3[ojO0j`0CojO0j`Wooooo
00?o0000ooooooooool03_ooool002?ooooo00?o0000ooooooooool0;oooool2ojJok0;oYl3[1_nW
`>cIojO0j`03o`000?nW`>_oYl3[01CoYl3[2?ooool00ol0003oooooooooo`0>ooooo`009?ooool0
0ol0003oooooooooo`0_ooooo`CoYl3[0_nW`>cMojO0j`03o`000?nW`>_oYl3[01CoYl3[1oooool0
0ol0003oooooooooo`0>ooooo`009Oooool2o`00033ooooohonW`>/00ol0003oYl3[ojO0j`0DojO0
j`Kooooo00?o0000ooooooooool03_ooool002Oooooo00?o0000ooooooooool0;_oooooSojO0j`03
o`000?nW`>_oYl3[01?oYl3[1_ooool00ol0003oooooooooo`0>ooooo`00:?ooool00ol0003ooooo
ooooo`0^ooooon;oYl3[00?o0000ojO0jonW`>/05?nW`>/5ooooo`03o`000?oooooooooo00kooooo
000Yooooo`03o`000?oooooooooo02oooooohOnW`>/00ol0003oYl3[ojO0j`0DojO0j`Cooooo00?o
0000ooooooooool03_ooool002[ooooo0_l0000aooooon3oYl3[00?o0000ojO0jonW`>/05?nW`>/3
ooooo`03o`000?oooooooooo00kooooo000/ooooo`03o`000?oooooooooo02ooooooh?nW`>/00ol0
003oYl3[ojO0j`0DojO0j`?ooooo00?o0000ooooooooool03Oooool002gooooo00?o0000oooooooo
ool0;ooooooOojO0j`03o`000?nW`>_oYl3[01CoYl3[0oooool00ol0003oooooooooo`0=ooooo`00
;_ooool00ol0003oooooooooo`0_ooooomooYl3[00?o0000ojO0jonW`>/05?nW`>/2ooooo`03o`00
0?oooooooooo00gooooo000_ooooo`03o`000?oooooooooo02oooooogonW`>/00ol0003oYl3[ojO0
j`0CojO0j`;ooooo00?o0000ooooooooool03Oooool0033ooooo0_l0000`ooooomkoYl3[00?o0000
ojO0jonW`>/05?nW`>/00ooooooo0000ooooo`0>ooooo`00<_ooool00ol0003oooooooooo`0^oooo
omkoYl3[00?o0000ojO0jonW`>/04onW`>/00ooooooo0000ooooo`0>ooooo`00<oooool00ol0003o
ooooooooo`0^ooooomkoYl3[00?o0000ojO0jonW`>/04onW`>/00ol0003oooooooooo`0=ooooo`00
=?ooool00ol0003oooooooooo`0^ooooomkoYl3[00?o0000ojO0jonW`>/04OnW`>/00ooooooo0000
ooooo`0>ooooo`00=Oooool2o`0002oooooogOnW`>/00ol0003oYl3[ojO0j`0=ojO0j`Kooooo00?o
0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0;_oooooLojO0j`03o`000?nW`>_o
Yl3[00WoYl3[2Oooool00ol0003oooooooooo`0<ooooo`00>?ooool00ol0003oooooooooo`0^oooo
omcoYl3[00?o0000ojO0jonW`>/01OnW`>/<ooooo`03o`000?oooooooooo00cooooo000iooooo`03
o`000?oooooooooo02kooooog?nW`>/00ol0003oYl3[ojO0j`0@ooooo`03o`000?oooooooooo00co
oooo000jooooo`;o0000;ooooooKojO0j`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
3?ooool003cooooo00?o0000ooooooooool0;OoooooFojO0j`Gooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0<ooooo`00?Oooool00ol0003oooooooooo`0]ooooom;oYl3[2Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo000nooooo`03o`000?oooooooooo
02gooooob_nW`>/@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool003oo
oooo0_l0000_ooooolGoYl3[5?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_o
oooo0011ooooo`03o`000?oooooooooo02gooooo`OnW`>/Hooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02oooool004;ooooo00?o0000ooooooooool0;OoooonlojO0jagooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`00@oooool00ol0003oooooooooo`0]
oooookSoYl3[8?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0014oooo
o`03o`000?oooooooooo02gooooo]?nW`>/Tooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool004Gooooo0_l0000_ooooojkoYl3[:Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00_ooooo0017ooooo`03o`000?oooooooooo02goooooZ_nW`>//ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02oooool004Sooooo00?o0000ooooooooool0;Ooo
oonVojO0jc3ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`00BOooool0
0ol0003oooooooooo`0]oooooj;oYl3[=?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo001:ooooo`;o0000;_oooonMojO0jcWooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0:ooooo`00C?ooool00ol0003oooooooooo`0/oooooiWoYl3[??ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00[ooooo001=ooooo`03o`000?oooooooooo02cooooo
T_nW`>]3ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool004kooooo00?o
0000ooooooooool0;Ooooon=ojO0jdOooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0:ooooo`00Coooool2o`0002koooooR?nW`>]<ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02_ooool0057ooooo00?o0000ooooooooool0;?oooon4ojO0jdoooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0:ooooo`00D_ooool00ol0003oooooooooo`0[oooooh7o
Yl3[Doooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo001Cooooo`03o`00
0?oooooooooo02_oooooOOnW`>]Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2Oooool005Cooooo0_l0000]ooooogSoYl3[F_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Wooooo001Fooooo`03o`000?oooooooooo02_oooooM?nW`>]Nooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02Oooool005Oooooo00?o0000ooooooooool0:ooooom/ojO0
jfKooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`00F?ooool00ol0003o
ooooooooo`0/ooooofOoYl3[J_ooool01Ol0003ooooooooooooooooo000000_ooooo001Iooooo`03
o`000?oooooooooo02coooooHonW`>]]ooooo`05o`000?ooooooooooooooool000002oooool005[o
oooo0_l0000]oooooeooYl3[LOooool01?l0003oooooooooool0000;ooooo`00G?ooool00ol0003o
ooooooooo`0[oooooe_oYl3[MOooool00ol0003oooooo`00000;ooooo`00GOooool00ol0003ooooo
ooooo`0[oooooeOoYl3[N?ooool01?l0003oooooooooool0000:ooooo`00G_ooool00ol0003ooooo
ooooo`0[oooooe?oYl3[O?ooool00ol0003oooooo`00000:ooooo`00Goooool2o`0002coooooC?nW
`>^3ooooo`;o00002_ooool0067ooooo00?o0000ooooooooool0:_oooom8ojO0jhGooooo0ol0000:
ooooo`00H_ooool00ol0003oooooooooo`0[oooood?oYl3[Q?ooool4o`0000gooooo001Sooooo`03
o`000?oooooooooo02_ooooo?onW`>^3ooooo`Co00004Oooool006Cooooo0_l0000/oooooc_oYl3[
Poooool3o`0001Gooooo001Vooooo`03o`000?oooooooooo02_ooooo<onW`>^5ooooo`Co00006?oo
ool006Oooooo00?o0000ooooooooool0:_ooool`ojO0jhCooooo1?l0000Looooo`00J?ooool00ol0
003oooooooooo`0ZooooobcoYl3[Poooool4o`00023ooooo001Yooooo`;o0000;?oooolWojO0jh;o
oooo1?l0000Tooooo`00Joooool00ol0003oooooooooo`0Zooooob?oYl3[P_ooool3o`0002Sooooo
001/ooooo`03o`000?oooooooooo02[ooooo7OnW`>^3ooooo`Co0000:oooool006gooooo00?o0000
ooooooooool0:ooooolHojO0jh;ooooo1?l0000_ooooo`00K_ooool00ol0003oooooooooo`0Zoooo
oaGoYl3[POooool4o`0003?ooooo001_ooooo`;o0000:ooooolAojO0jh3ooooo1?l0000gooooo`00
LOooool00ol0003oooooooooo`0Zooooo`WoYl3[P_ooool4o`0003_ooooo001booooo`03o`000?oo
oooooooo02[ooooo1OnW`>^2ooooo`?o0000?oooool007?ooooo00?o0000ooooooooool0:_ooool0
0onW`>_oooooooooo`1oooooo`Co0000@_ooool007Cooooo0_l0000Zooooo`03o`000?oooooooooo
07_ooooo1?l00016ooooo`00M_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07So
oooo1?l0001:ooooo`00Moooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07Cooooo
1?l0001>ooooo`00N?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo077ooooo0ol0
001Booooo`00NOooool2o`0002Cooooo00?o0000ooooooooool0KOooool4o`0005Gooooo001koooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0JOooool4o`0005Wooooo001looooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0IOooool4o`0005gooooo001mooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0HOooool4o`00067ooooo001nooooo`;o00007ooo
ool00ol0003oooooooooo`1Mooooo`Co0000IOooool0083ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`1Jooooo`?o0000JOooool0087ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`1Fooooo`Co0000K?ooool008;ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`1Booooo`Co0000L?ooool008?ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`1>ooooo`Co0000M?ooool008Cooooo0_l0000Iooooo`03o`000?oooooooooo04[ooooo1?l0
001hooooo`00Q_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Kooooo1?l0001l
ooooo`00Qoooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04?ooooo0ol00020oooo
o`00R?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03oooooo1?l00023ooooo`00
ROooool2o`0001Cooooo00?o0000ooooooooool0>oooool4o`0008Oooooo002;ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0=oooool4o`0008_ooooo002<ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0<oooool4o`0008oooooo002=ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0<?ooool3o`0009?ooooo002>ooooo`;o00003oooool00ol0003o
ooooooooo`0/ooooo`Co0000U_ooool0093ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Xooooo`Co0000V_ooool0097ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Tooooo`Co0000W_ooool009;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Q
ooooo`Co0000X_ooool009?ooooo0_l00009ooooo`03o`000?oooooooooo01gooooo1?l0002Voooo
o`00UOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo0ol0002Zooooo`00
U_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo1?l0002]ooooo`00Uooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo1?l0002aooooo`00V?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0002eooooo`00VOooool2o`00
00?ooooo00?o0000ooooooooool02_ooool4o`000;Wooooo002Kooooo`04o`000?ooooooooooo`00
00Wooooo0ol0002mooooo`00W?ooool00ol0003oooooo`000005ooooo`Co0000`?ooool009gooooo
0_l000000ooooooo0000o`000002o`000<Cooooo002Nooooo`;o0000b?ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00;;ooooo00GoV9RHo`000?l0003oA4A4okZj^P0;ooooo`;o000000?o410@oooo
ooooool00oooool2ob4Q8Icooooo002booooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l00005
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B6Looooo`00/_ooool00ol0003oooooooooo`0;oooo
o`Go0000Xoooool00;;ooooo00?o0000ooooooooool00oooool6o`0000;ooooo00CoA4A4omgMgOoo
oooo0000Y?ooool00;;ooooo00?o0000ooooooooool02oooool01?oMgMgoEEEEooooool0002Toooo
o`00/?ooool00ol@413o0000o`000003o`0000_ooooo00?oMgMgolc<c?l00000Y?ooool00;;ooooo
00?o0000ooooooooool03?ooool00oo^k^koA4A4o`00002Tooooo`00/_ooool00ol0003ooooooooo
o`0=ooooo`03ogMgMol0003ooooo0:?ooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -17 0 ]
[.5 .82364 17 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.8) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69467 Mtetra
.4053 .69467 .41061 .69934 .41957 .69681 .41427 .69213 Mtetra
.41427 .69213 .41957 .69681 .42855 .69428 .42327 .68958 Mtetra
.42327 .68958 .42855 .69428 .43756 .69174 .43231 .68703 Mtetra
.43231 .68703 .43756 .69174 .4466 .68919 .44137 .68446 Mtetra
.44137 .68446 .4466 .68919 .45567 .68663 .45046 .68189 Mtetra
.45046 .68189 .45567 .68663 .46478 .68407 .45958 .67931 Mtetra
.45958 .67931 .46478 .68407 .47391 .68149 .46873 .67671 Mtetra
.46873 .67671 .47391 .68149 .48307 .67891 .47792 .67412 Mtetra
.47792 .67412 .48307 .67891 .49227 .67632 .48713 .67151 Mtetra
.48713 .67151 .49227 .67632 .50149 .67371 .49638 .66889 Mtetra
.49638 .66889 .50149 .67371 .51075 .6711 .50565 .66626 Mtetra
.50565 .66626 .51075 .6711 .52004 .66849 .51496 .66363 Mtetra
.51496 .66363 .52004 .66849 .52936 .66586 .5243 .66098 Mtetra
.5243 .66098 .52936 .66586 .53871 .66322 .53367 .65833 Mtetra
.53367 .65833 .53871 .66322 .54809 .66058 .54308 .65567 Mtetra
.54308 .65567 .54809 .66058 .55751 .65792 .55251 .653 Mtetra
.55251 .653 .55751 .65792 .56695 .65526 .56198 .65032 Mtetra
.56198 .65032 .56695 .65526 .57643 .65259 .57148 .64763 Mtetra
.57148 .64763 .57643 .65259 .58595 .6499 .58102 .64493 Mtetra
.58102 .64493 .58595 .6499 .59549 .64721 .59058 .64222 Mtetra
.59058 .64222 .59549 .64721 .60507 .64451 .60018 .6395 Mtetra
.60018 .6395 .60507 .64451 .61468 .6418 .60982 .63678 Mtetra
.60982 .63678 .61468 .6418 .62432 .63908 .61948 .63404 Mtetra
.61948 .63404 .62432 .63908 .634 .63636 .62918 .63129 Mtetra
.62918 .63129 .634 .63636 .64371 .63362 .63892 .62854 Mtetra
.63892 .62854 .64371 .63362 .65345 .63087 .64868 .62577 Mtetra
.64868 .62577 .65345 .63087 .66323 .62811 .65848 .623 Mtetra
.65848 .623 .66323 .62811 .67304 .62535 .66832 .62021 Mtetra
.66832 .62021 .67304 .62535 .68289 .62257 .67819 .61742 Mtetra
.67819 .61742 .68289 .62257 .69277 .61979 .68809 .61462 Mtetra
.68809 .61462 .69277 .61979 .70269 .61699 .69803 .6118 Mtetra
.69803 .6118 .70269 .61699 .71264 .61418 .70801 .60898 Mtetra
.70801 .60898 .71264 .61418 .72262 .61137 .71802 .60615 Mtetra
.71802 .60615 .72262 .61137 .73264 .60854 .72806 .6033 Mtetra
.72806 .6033 .73264 .60854 .7427 .60571 .73814 .60045 Mtetra
.73814 .60045 .7427 .60571 .75279 .60286 .74826 .59759 Mtetra
.74826 .59759 .75279 .60286 .76291 .60001 .75841 .59471 Mtetra
.75841 .59471 .76291 .60001 .77308 .59714 .7686 .59183 Mtetra
.7686 .59183 .77308 .59714 .78328 .59427 .77882 .58893 Mtetra
.77882 .58893 .78328 .59427 .79351 .59138 .78908 .58603 Mtetra
.78908 .58603 .79351 .59138 .80378 .58849 .79938 .58311 Mtetra
.79938 .58311 .80378 .58849 .81409 .58558 .80971 .58019 Mtetra
.80971 .58019 .81409 .58558 .82443 .58267 .82008 .57725 Mtetra
.82008 .57725 .82443 .58267 .83482 .57974 .83049 .57431 Mtetra
.83049 .57431 .83482 .57974 .84523 .5768 .84094 .57135 Mtetra
.84094 .57135 .84523 .5768 .85569 .57385 .85142 .56838 Mtetra
.85142 .56838 .85569 .57385 .86618 .57089 .86194 .5654 Mtetra
.86194 .5654 .86618 .57089 .87672 .56792 .8725 .56241 Mtetra
.8725 .56241 .87672 .56792 .88729 .56494 .8831 .55941 Mtetra
.8831 .55941 .88729 .56494 .89789 .56195 .89374 .5564 Mtetra
.89374 .5564 .89789 .56195 .90854 .55895 .90441 .55338 Mtetra
.90441 .55338 .90854 .55895 .91923 .55594 .91512 .55035 Mtetra
.91512 .55035 .91923 .55594 .92995 .55292 .92588 .5473 Mtetra
.92588 .5473 .92995 .55292 .94071 .54988 .93667 .54425 Mtetra
.93667 .54425 .94071 .54988 .95152 .54684 .9475 .54118 Mtetra
.9475 .54118 .95152 .54684 .96236 .54378 .95837 .53811 Mtetra
.95837 .53811 .96236 .54378 .97324 .54071 .96928 .53502 Mtetra
.96928 .53502 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.391 .69252 .39636 .6972 .4053 .69467 .39996 .68998 Mtetra
.39996 .68998 .4053 .69467 .41427 .69213 .40895 .68742 Mtetra
.40895 .68742 .41427 .69213 .42327 .68958 .41797 .68486 Mtetra
.41797 .68486 .42327 .68958 .43231 .68703 .42702 .68228 Mtetra
.42702 .68228 .43231 .68703 .44137 .68446 .4361 .6797 Mtetra
.4361 .6797 .44137 .68446 .45046 .68189 .44521 .67711 Mtetra
.44521 .67711 .45046 .68189 .45958 .67931 .45435 .67452 Mtetra
.45435 .67452 .45958 .67931 .46873 .67671 .46352 .67191 Mtetra
.46352 .67191 .46873 .67671 .47792 .67412 .47273 .66929 Mtetra
.47273 .66929 .47792 .67412 .48713 .67151 .48196 .66667 Mtetra
.48196 .66667 .48713 .67151 .49638 .66889 .49123 .66403 Mtetra
.49123 .66403 .49638 .66889 .50565 .66626 .50053 .66139 Mtetra
.50053 .66139 .50565 .66626 .51496 .66363 .50985 .65874 Mtetra
.50985 .65874 .51496 .66363 .5243 .66098 .51922 .65608 Mtetra
.51922 .65608 .5243 .66098 .53367 .65833 .52861 .65341 Mtetra
.52861 .65341 .53367 .65833 .54308 .65567 .53803 .65073 Mtetra
.53803 .65073 .54308 .65567 .55251 .653 .54749 .64804 Mtetra
.54749 .64804 .55251 .653 .56198 .65032 .55698 .64534 Mtetra
.55698 .64534 .56198 .65032 .57148 .64763 .5665 .64264 Mtetra
.5665 .64264 .57148 .64763 .58102 .64493 .57606 .63992 Mtetra
.57606 .63992 .58102 .64493 .59058 .64222 .58565 .6372 Mtetra
.58565 .6372 .59058 .64222 .60018 .6395 .59527 .63446 Mtetra
.59527 .63446 .60018 .6395 .60982 .63678 .60493 .63172 Mtetra
.60493 .63172 .60982 .63678 .61948 .63404 .61461 .62896 Mtetra
.61461 .62896 .61948 .63404 .62918 .63129 .62434 .6262 Mtetra
.62434 .6262 .62918 .63129 .63892 .62854 .63409 .62343 Mtetra
.63409 .62343 .63892 .62854 .64868 .62577 .64388 .62064 Mtetra
.64388 .62064 .64868 .62577 .65848 .623 .65371 .61785 Mtetra
.65371 .61785 .65848 .623 .66832 .62021 .66357 .61505 Mtetra
.66357 .61505 .66832 .62021 .67819 .61742 .67346 .61224 Mtetra
.67346 .61224 .67819 .61742 .68809 .61462 .68339 .60942 Mtetra
.68339 .60942 .68809 .61462 .69803 .6118 .69335 .60658 Mtetra
.69335 .60658 .69803 .6118 .70801 .60898 .70335 .60374 Mtetra
.70335 .60374 .70801 .60898 .71802 .60615 .71338 .60089 Mtetra
.71338 .60089 .71802 .60615 .72806 .6033 .72345 .59803 Mtetra
.72345 .59803 .72806 .6033 .73814 .60045 .73356 .59516 Mtetra
.73356 .59516 .73814 .60045 .74826 .59759 .7437 .59227 Mtetra
.7437 .59227 .74826 .59759 .75841 .59471 .75387 .58938 Mtetra
.75387 .58938 .75841 .59471 .7686 .59183 .76409 .58648 Mtetra
.76409 .58648 .7686 .59183 .77882 .58893 .77434 .58356 Mtetra
.77434 .58356 .77882 .58893 .78908 .58603 .78462 .58064 Mtetra
.78462 .58064 .78908 .58603 .79938 .58311 .79495 .57771 Mtetra
.79495 .57771 .79938 .58311 .80971 .58019 .80531 .57476 Mtetra
.80531 .57476 .80971 .58019 .82008 .57725 .81571 .57181 Mtetra
.81571 .57181 .82008 .57725 .83049 .57431 .82614 .56884 Mtetra
.82614 .56884 .83049 .57431 .84094 .57135 .83661 .56586 Mtetra
.83661 .56586 .84094 .57135 .85142 .56838 .84712 .56288 Mtetra
.84712 .56288 .85142 .56838 .86194 .5654 .85767 .55988 Mtetra
.85767 .55988 .86194 .5654 .8725 .56241 .86826 .55687 Mtetra
.86826 .55687 .8725 .56241 .8831 .55941 .87889 .55385 Mtetra
.87889 .55385 .8831 .55941 .89374 .5564 .88955 .55082 Mtetra
.88955 .55082 .89374 .5564 .90441 .55338 .90025 .54777 Mtetra
.90025 .54777 .90441 .55338 .91512 .55035 .911 .54472 Mtetra
.911 .54472 .91512 .55035 .92588 .5473 .92178 .54166 Mtetra
.92178 .54166 .92588 .5473 .93667 .54425 .9326 .53858 Mtetra
.9326 .53858 .93667 .54425 .9475 .54118 .94346 .53549 Mtetra
.94346 .53549 .9475 .54118 .95837 .53811 .95436 .53239 Mtetra
.95436 .53239 .95837 .53811 .96928 .53502 .9653 .52928 Mtetra
.9653 .52928 .96928 .53502 .98024 .53192 .97628 .52616 Mtetra
.38561 .68781 .391 .69252 .39996 .68998 .39459 .68525 Mtetra
.39459 .68525 .39996 .68998 .40895 .68742 .40359 .68268 Mtetra
.40359 .68268 .40895 .68742 .41797 .68486 .41263 .6801 Mtetra
.41263 .6801 .41797 .68486 .42702 .68228 .4217 .67751 Mtetra
.4217 .67751 .42702 .68228 .4361 .6797 .4308 .67492 Mtetra
.4308 .67492 .4361 .6797 .44521 .67711 .43993 .67231 Mtetra
.43993 .67231 .44521 .67711 .45435 .67452 .44909 .6697 Mtetra
.44909 .6697 .45435 .67452 .46352 .67191 .45828 .66707 Mtetra
.45828 .66707 .46352 .67191 .47273 .66929 .46751 .66444 Mtetra
.46751 .66444 .47273 .66929 .48196 .66667 .47676 .6618 Mtetra
.47676 .6618 .48196 .66667 .49123 .66403 .48605 .65915 Mtetra
.48605 .65915 .49123 .66403 .50053 .66139 .49537 .65649 Mtetra
.49537 .65649 .50053 .66139 .50985 .65874 .50472 .65382 Mtetra
.50472 .65382 .50985 .65874 .51922 .65608 .5141 .65114 Mtetra
.5141 .65114 .51922 .65608 .52861 .65341 .52351 .64846 Mtetra
.52351 .64846 .52861 .65341 .53803 .65073 .53296 .64576 Mtetra
.53296 .64576 .53803 .65073 .54749 .64804 .54244 .64305 Mtetra
.54244 .64305 .54749 .64804 .55698 .64534 .55195 .64034 Mtetra
.55195 .64034 .55698 .64534 .5665 .64264 .56149 .63762 Mtetra
.56149 .63762 .5665 .64264 .57606 .63992 .57107 .63488 Mtetra
.57107 .63488 .57606 .63992 .58565 .6372 .58068 .63214 Mtetra
.58068 .63214 .58565 .6372 .59527 .63446 .59032 .62939 Mtetra
.59032 .62939 .59527 .63446 .60493 .63172 .6 .62663 Mtetra
.6 .62663 .60493 .63172 .61461 .62896 .60971 .62385 Mtetra
.60971 .62385 .61461 .62896 .62434 .6262 .61946 .62107 Mtetra
.61946 .62107 .62434 .6262 .63409 .62343 .62924 .61828 Mtetra
.62924 .61828 .63409 .62343 .64388 .62064 .63905 .61548 Mtetra
.63905 .61548 .64388 .62064 .65371 .61785 .6489 .61267 Mtetra
.6489 .61267 .65371 .61785 .66357 .61505 .65878 .60985 Mtetra
.65878 .60985 .66357 .61505 .67346 .61224 .6687 .60702 Mtetra
.6687 .60702 .67346 .61224 .68339 .60942 .67865 .60418 Mtetra
.67865 .60418 .68339 .60942 .69335 .60658 .68864 .60133 Mtetra
.68864 .60133 .69335 .60658 .70335 .60374 .69866 .59847 Mtetra
.69866 .59847 .70335 .60374 .71338 .60089 .70872 .5956 Mtetra
.70872 .5956 .71338 .60089 .72345 .59803 .71881 .59272 Mtetra
.71881 .59272 .72345 .59803 .73356 .59516 .72894 .58983 Mtetra
.72894 .58983 .73356 .59516 .7437 .59227 .73911 .58692 Mtetra
.73911 .58692 .7437 .59227 .75387 .58938 .74931 .58401 Mtetra
.74931 .58401 .75387 .58938 .76409 .58648 .75955 .58109 Mtetra
.75955 .58109 .76409 .58648 .77434 .58356 .76982 .57816 Mtetra
.76982 .57816 .77434 .58356 .78462 .58064 .78014 .57521 Mtetra
.78014 .57521 .78462 .58064 .79495 .57771 .79049 .57226 Mtetra
.79049 .57226 .79495 .57771 .80531 .57476 .80087 .5693 Mtetra
.80087 .5693 .80531 .57476 .81571 .57181 .8113 .56632 Mtetra
.8113 .56632 .81571 .57181 .82614 .56884 .82176 .56334 Mtetra
.82176 .56334 .82614 .56884 .83661 .56586 .83226 .56034 Mtetra
.83226 .56034 .83661 .56586 .84712 .56288 .8428 .55733 Mtetra
.8428 .55733 .84712 .56288 .85767 .55988 .85337 .55431 Mtetra
.85337 .55431 .85767 .55988 .86826 .55687 .86399 .55128 Mtetra
.86399 .55128 .86826 .55687 .87889 .55385 .87464 .54824 Mtetra
.87464 .54824 .87889 .55385 .88955 .55082 .88533 .54519 Mtetra
.88533 .54519 .88955 .55082 .90025 .54777 .89607 .54213 Mtetra
.89607 .54213 .90025 .54777 .911 .54472 .90684 .53905 Mtetra
.90684 .53905 .911 .54472 .92178 .54166 .91765 .53597 Mtetra
.91765 .53597 .92178 .54166 .9326 .53858 .9285 .53287 Mtetra
.9285 .53287 .9326 .53858 .94346 .53549 .93939 .52976 Mtetra
.93939 .52976 .94346 .53549 .95436 .53239 .95032 .52664 Mtetra
.95032 .52664 .95436 .53239 .9653 .52928 .96129 .52351 Mtetra
.96129 .52351 .9653 .52928 .97628 .52616 .9723 .52037 Mtetra
.38018 .68308 .38561 .68781 .39459 .68525 .38918 .6805 Mtetra
.38918 .6805 .39459 .68525 .40359 .68268 .3982 .67791 Mtetra
.3982 .67791 .40359 .68268 .41263 .6801 .40726 .67532 Mtetra
.40726 .67532 .41263 .6801 .4217 .67751 .41635 .67271 Mtetra
.41635 .67271 .4217 .67751 .4308 .67492 .42547 .6701 Mtetra
.42547 .6701 .4308 .67492 .43993 .67231 .43462 .66748 Mtetra
.43462 .66748 .43993 .67231 .44909 .6697 .4438 .66485 Mtetra
.4438 .66485 .44909 .6697 .45828 .66707 .45301 .66221 Mtetra
.45301 .66221 .45828 .66707 .46751 .66444 .46225 .65956 Mtetra
.46225 .65956 .46751 .66444 .47676 .6618 .47153 .6569 Mtetra
.47153 .6569 .47676 .6618 .48605 .65915 .48083 .65423 Mtetra
.48083 .65423 .48605 .65915 .49537 .65649 .49017 .65156 Mtetra
.49017 .65156 .49537 .65649 .50472 .65382 .49954 .64887 Mtetra
.49954 .64887 .50472 .65382 .5141 .65114 .50895 .64618 Mtetra
.50895 .64618 .5141 .65114 .52351 .64846 .51838 .64347 Mtetra
.51838 .64347 .52351 .64846 .53296 .64576 .52785 .64076 Mtetra
.52785 .64076 .53296 .64576 .54244 .64305 .53735 .63804 Mtetra
.53735 .63804 .54244 .64305 .55195 .64034 .54688 .6353 Mtetra
.54688 .6353 .55195 .64034 .56149 .63762 .55645 .63256 Mtetra
.55645 .63256 .56149 .63762 .57107 .63488 .56605 .62981 Mtetra
.56605 .62981 .57107 .63488 .58068 .63214 .57568 .62705 Mtetra
.57568 .62705 .58068 .63214 .59032 .62939 .58535 .62428 Mtetra
.58535 .62428 .59032 .62939 .6 .62663 .59505 .6215 Mtetra
.59505 .6215 .6 .62663 .60971 .62385 .60478 .61871 Mtetra
.60478 .61871 .60971 .62385 .61946 .62107 .61455 .61591 Mtetra
.61455 .61591 .61946 .62107 .62924 .61828 .62435 .6131 Mtetra
.62435 .6131 .62924 .61828 .63905 .61548 .63419 .61028 Mtetra
.63419 .61028 .63905 .61548 .6489 .61267 .64406 .60746 Mtetra
.64406 .60746 .6489 .61267 .65878 .60985 .65396 .60462 Mtetra
.65396 .60462 .65878 .60985 .6687 .60702 .66391 .60177 Mtetra
.66391 .60177 .6687 .60702 .67865 .60418 .67388 .59891 Mtetra
.67388 .59891 .67865 .60418 .68864 .60133 .68389 .59604 Mtetra
.68389 .59604 .68864 .60133 .69866 .59847 .69394 .59316 Mtetra
.69394 .59316 .69866 .59847 .70872 .5956 .70402 .59027 Mtetra
.70402 .59027 .70872 .5956 .71881 .59272 .71414 .58737 Mtetra
.71414 .58737 .71881 .59272 .72894 .58983 .7243 .58446 Mtetra
.7243 .58446 .72894 .58983 .73911 .58692 .73449 .58154 Mtetra
.73449 .58154 .73911 .58692 .74931 .58401 .74472 .57861 Mtetra
.74472 .57861 .74931 .58401 .75955 .58109 .75498 .57567 Mtetra
.75498 .57567 .75955 .58109 .76982 .57816 .76528 .57272 Mtetra
.76528 .57272 .76982 .57816 .78014 .57521 .77562 .56975 Mtetra
.77562 .56975 .78014 .57521 .79049 .57226 .786 .56678 Mtetra
.786 .56678 .79049 .57226 .80087 .5693 .79641 .5638 Mtetra
.79641 .5638 .80087 .5693 .8113 .56632 .80686 .5608 Mtetra
.80686 .5608 .8113 .56632 .82176 .56334 .81735 .55779 Mtetra
.81735 .55779 .82176 .56334 .83226 .56034 .82788 .55478 Mtetra
.82788 .55478 .83226 .56034 .8428 .55733 .83844 .55175 Mtetra
.83844 .55175 .8428 .55733 .85337 .55431 .84905 .54871 Mtetra
.84905 .54871 .85337 .55431 .86399 .55128 .85969 .54566 Mtetra
.85969 .54566 .86399 .55128 .87464 .54824 .87037 .5426 Mtetra
.87037 .5426 .87464 .54824 .88533 .54519 .88109 .53953 Mtetra
.88109 .53953 .88533 .54519 .89607 .54213 .89185 .53644 Mtetra
.89185 .53644 .89607 .54213 .90684 .53905 .90265 .53335 Mtetra
.90265 .53335 .90684 .53905 .91765 .53597 .91349 .53024 Mtetra
.91349 .53024 .91765 .53597 .9285 .53287 .92437 .52712 Mtetra
.92437 .52712 .9285 .53287 .93939 .52976 .93529 .524 Mtetra
.93529 .524 .93939 .52976 .95032 .52664 .94625 .52085 Mtetra
.94625 .52085 .95032 .52664 .96129 .52351 .95725 .5177 Mtetra
.95725 .5177 .96129 .52351 .9723 .52037 .96829 .51454 Mtetra
.37472 .67831 .38018 .68308 .38918 .6805 .38373 .67572 Mtetra
.38373 .67572 .38918 .6805 .3982 .67791 .39278 .67311 Mtetra
.39278 .67311 .3982 .67791 .40726 .67532 .40186 .6705 Mtetra
.40186 .6705 .40726 .67532 .41635 .67271 .41096 .66788 Mtetra
.41096 .66788 .41635 .67271 .42547 .6701 .4201 .66525 Mtetra
.4201 .66525 .42547 .6701 .43462 .66748 .42927 .66261 Mtetra
.42927 .66261 .43462 .66748 .4438 .66485 .43847 .65996 Mtetra
.43847 .65996 .4438 .66485 .45301 .66221 .4477 .65731 Mtetra
.4477 .65731 .45301 .66221 .46225 .65956 .45697 .65464 Mtetra
.45697 .65464 .46225 .65956 .47153 .6569 .46626 .65197 Mtetra
.46626 .65197 .47153 .6569 .48083 .65423 .47559 .64928 Mtetra
.47559 .64928 .48083 .65423 .49017 .65156 .48495 .64659 Mtetra
.48495 .64659 .49017 .65156 .49954 .64887 .49434 .64389 Mtetra
.49434 .64389 .49954 .64887 .50895 .64618 .50376 .64118 Mtetra
.50376 .64118 .50895 .64618 .51838 .64347 .51322 .63846 Mtetra
.51322 .63846 .51838 .64347 .52785 .64076 .52271 .63572 Mtetra
.52271 .63572 .52785 .64076 .53735 .63804 .53223 .63298 Mtetra
.53223 .63298 .53735 .63804 .54688 .6353 .54178 .63024 Mtetra
.54178 .63024 .54688 .6353 .55645 .63256 .55137 .62748 Mtetra
.55137 .62748 .55645 .63256 .56605 .62981 .56099 .62471 Mtetra
.56099 .62471 .56605 .62981 .57568 .62705 .57065 .62193 Mtetra
.57065 .62193 .57568 .62705 .58535 .62428 .58034 .61914 Mtetra
.58034 .61914 .58535 .62428 .59505 .6215 .59006 .61634 Mtetra
.59006 .61634 .59505 .6215 .60478 .61871 .59982 .61354 Mtetra
.59982 .61354 .60478 .61871 .61455 .61591 .60961 .61072 Mtetra
.60961 .61072 .61455 .61591 .62435 .6131 .61943 .60789 Mtetra
.61943 .60789 .62435 .6131 .63419 .61028 .62929 .60505 Mtetra
.62929 .60505 .63419 .61028 .64406 .60746 .63919 .60221 Mtetra
.63919 .60221 .64406 .60746 .65396 .60462 .64912 .59935 Mtetra
.64912 .59935 .65396 .60462 .66391 .60177 .65908 .59648 Mtetra
.65908 .59648 .66391 .60177 .67388 .59891 .66908 .5936 Mtetra
.66908 .5936 .67388 .59891 .68389 .59604 .67912 .59072 Mtetra
.67912 .59072 .68389 .59604 .69394 .59316 .68919 .58782 Mtetra
.68919 .58782 .69394 .59316 .70402 .59027 .6993 .58491 Mtetra
.6993 .58491 .70402 .59027 .71414 .58737 .70944 .58199 Mtetra
.70944 .58199 .71414 .58737 .7243 .58446 .71962 .57906 Mtetra
.71962 .57906 .7243 .58446 .73449 .58154 .72984 .57612 Mtetra
.72984 .57612 .73449 .58154 .74472 .57861 .74009 .57317 Mtetra
.74009 .57317 .74472 .57861 .75498 .57567 .75038 .57021 Mtetra
.75038 .57021 .75498 .57567 .76528 .57272 .76071 .56724 Mtetra
.76071 .56724 .76528 .57272 .77562 .56975 .77107 .56426 Mtetra
.77107 .56426 .77562 .56975 .786 .56678 .78148 .56126 Mtetra
.78148 .56126 .786 .56678 .79641 .5638 .79192 .55826 Mtetra
.79192 .55826 .79641 .5638 .80686 .5608 .80239 .55524 Mtetra
.80239 .55524 .80686 .5608 .81735 .55779 .81291 .55222 Mtetra
.81291 .55222 .81735 .55779 .82788 .55478 .82346 .54918 Mtetra
.82346 .54918 .82788 .55478 .83844 .55175 .83406 .54613 Mtetra
.83406 .54613 .83844 .55175 .84905 .54871 .84469 .54307 Mtetra
.84469 .54307 .84905 .54871 .85969 .54566 .85536 .54 Mtetra
.85536 .54 .85969 .54566 .87037 .5426 .86607 .53692 Mtetra
.86607 .53692 .87037 .5426 .88109 .53953 .87682 .53383 Mtetra
.87682 .53383 .88109 .53953 .89185 .53644 .88761 .53072 Mtetra
.88761 .53072 .89185 .53644 .90265 .53335 .89844 .52761 Mtetra
.89844 .52761 .90265 .53335 .91349 .53024 .90931 .52448 Mtetra
.90931 .52448 .91349 .53024 .92437 .52712 .92022 .52134 Mtetra
.92022 .52134 .92437 .52712 .93529 .524 .93116 .51819 Mtetra
.93116 .51819 .93529 .524 .94625 .52085 .94216 .51503 Mtetra
.94216 .51503 .94625 .52085 .95725 .5177 .95319 .51185 Mtetra
.95319 .51185 .95725 .5177 .96829 .51454 .96426 .50866 Mtetra
.36922 .67351 .37472 .67831 .38373 .67572 .37826 .6709 Mtetra
.37826 .6709 .38373 .67572 .39278 .67311 .38732 .66828 Mtetra
.38732 .66828 .39278 .67311 .40186 .6705 .39642 .66566 Mtetra
.39642 .66566 .40186 .6705 .41096 .66788 .40554 .66302 Mtetra
.40554 .66302 .41096 .66788 .4201 .66525 .4147 .66037 Mtetra
.4147 .66037 .4201 .66525 .42927 .66261 .42389 .65772 Mtetra
.42389 .65772 .42927 .66261 .43847 .65996 .43311 .65505 Mtetra
.43311 .65505 .43847 .65996 .4477 .65731 .44236 .65238 Mtetra
.44236 .65238 .4477 .65731 .45697 .65464 .45165 .6497 Mtetra
.45165 .6497 .45697 .65464 .46626 .65197 .46096 .64701 Mtetra
.46096 .64701 .46626 .65197 .47559 .64928 .47031 .6443 Mtetra
.47031 .6443 .47559 .64928 .48495 .64659 .47969 .64159 Mtetra
.47969 .64159 .48495 .64659 .49434 .64389 .4891 .63887 Mtetra
.4891 .63887 .49434 .64389 .50376 .64118 .49855 .63615 Mtetra
.49855 .63615 .50376 .64118 .51322 .63846 .50802 .63341 Mtetra
.50802 .63341 .51322 .63846 .52271 .63572 .51753 .63066 Mtetra
.51753 .63066 .52271 .63572 .53223 .63298 .52708 .6279 Mtetra
.52708 .6279 .53223 .63298 .54178 .63024 .53665 .62513 Mtetra
.53665 .62513 .54178 .63024 .55137 .62748 .54626 .62236 Mtetra
.54626 .62236 .55137 .62748 .56099 .62471 .55591 .61957 Mtetra
.55591 .61957 .56099 .62471 .57065 .62193 .56558 .61677 Mtetra
.56558 .61677 .57065 .62193 .58034 .61914 .57529 .61397 Mtetra
.57529 .61397 .58034 .61914 .59006 .61634 .58504 .61115 Mtetra
.58504 .61115 .59006 .61634 .59982 .61354 .59482 .60833 Mtetra
.59482 .60833 .59982 .61354 .60961 .61072 .60463 .60549 Mtetra
.60463 .60549 .60961 .61072 .61943 .60789 .61448 .60265 Mtetra
.61448 .60265 .61943 .60789 .62929 .60505 .62437 .59979 Mtetra
.62437 .59979 .62929 .60505 .63919 .60221 .63428 .59692 Mtetra
.63428 .59692 .63919 .60221 .64912 .59935 .64424 .59405 Mtetra
.64424 .59405 .64912 .59935 .65908 .59648 .65423 .59116 Mtetra
.65423 .59116 .65908 .59648 .66908 .5936 .66425 .58826 Mtetra
.66425 .58826 .66908 .5936 .67912 .59072 .67431 .58536 Mtetra
.67431 .58536 .67912 .59072 .68919 .58782 .68441 .58244 Mtetra
.68441 .58244 .68919 .58782 .6993 .58491 .69454 .57951 Mtetra
.69454 .57951 .6993 .58491 .70944 .58199 .70471 .57657 Mtetra
.70471 .57657 .70944 .58199 .71962 .57906 .71491 .57363 Mtetra
.71491 .57363 .71962 .57906 .72984 .57612 .72516 .57067 Mtetra
.72516 .57067 .72984 .57612 .74009 .57317 .73544 .5677 Mtetra
.73544 .5677 .74009 .57317 .75038 .57021 .74575 .56471 Mtetra
.74575 .56471 .75038 .57021 .76071 .56724 .75611 .56172 Mtetra
.75611 .56172 .76071 .56724 .77107 .56426 .7665 .55872 Mtetra
.7665 .55872 .77107 .56426 .78148 .56126 .77693 .55571 Mtetra
.77693 .55571 .78148 .56126 .79192 .55826 .78739 .55268 Mtetra
.78739 .55268 .79192 .55826 .80239 .55524 .7979 .54965 Mtetra
.7979 .54965 .80239 .55524 .81291 .55222 .80844 .5466 Mtetra
.80844 .5466 .81291 .55222 .82346 .54918 .81902 .54354 Mtetra
.81902 .54354 .82346 .54918 .83406 .54613 .82964 .54047 Mtetra
.82964 .54047 .83406 .54613 .84469 .54307 .8403 .53739 Mtetra
.8403 .53739 .84469 .54307 .85536 .54 .851 .5343 Mtetra
.851 .5343 .85536 .54 .86607 .53692 .86174 .5312 Mtetra
.86174 .5312 .86607 .53692 .87682 .53383 .87252 .52809 Mtetra
.87252 .52809 .87682 .53383 .88761 .53072 .88334 .52496 Mtetra
.88334 .52496 .88761 .53072 .89844 .52761 .89419 .52182 Mtetra
.89419 .52182 .89844 .52761 .90931 .52448 .90509 .51867 Mtetra
.90509 .51867 .90931 .52448 .92022 .52134 .91603 .51551 Mtetra
.91603 .51551 .92022 .52134 .93116 .51819 .92701 .51234 Mtetra
.92701 .51234 .93116 .51819 .94216 .51503 .93803 .50916 Mtetra
.93803 .50916 .94216 .51503 .95319 .51185 .94909 .50596 Mtetra
.94909 .50596 .95319 .51185 .96426 .50866 .9602 .50275 Mtetra
.36369 .66869 .36922 .67351 .37826 .6709 .37275 .66606 Mtetra
.37275 .66606 .37826 .6709 .38732 .66828 .38183 .66342 Mtetra
.38183 .66342 .38732 .66828 .39642 .66566 .39094 .66078 Mtetra
.39094 .66078 .39642 .66566 .40554 .66302 .40009 .65813 Mtetra
.40009 .65813 .40554 .66302 .4147 .66037 .40927 .65546 Mtetra
.40927 .65546 .4147 .66037 .42389 .65772 .41848 .65279 Mtetra
.41848 .65279 .42389 .65772 .43311 .65505 .42772 .65011 Mtetra
.42772 .65011 .43311 .65505 .44236 .65238 .43699 .64742 Mtetra
.43699 .64742 .44236 .65238 .45165 .6497 .44629 .64472 Mtetra
.44629 .64472 .45165 .6497 .46096 .64701 .45563 .64201 Mtetra
.45563 .64201 .46096 .64701 .47031 .6443 .465 .63929 Mtetra
.465 .63929 .47031 .6443 .47969 .64159 .4744 .63657 Mtetra
.4744 .63657 .47969 .64159 .4891 .63887 .48383 .63383 Mtetra
.48383 .63383 .4891 .63887 .49855 .63615 .4933 .63108 Mtetra
.4933 .63108 .49855 .63615 .50802 .63341 .50279 .62833 Mtetra
.50279 .62833 .50802 .63341 .51753 .63066 .51233 .62556 Mtetra
.51233 .62556 .51753 .63066 .52708 .6279 .52189 .62279 Mtetra
.52189 .62279 .52708 .6279 .53665 .62513 .53149 .62 Mtetra
.53149 .62 .53665 .62513 .54626 .62236 .54112 .61721 Mtetra
.54112 .61721 .54626 .62236 .55591 .61957 .55079 .6144 Mtetra
.55079 .6144 .55591 .61957 .56558 .61677 .56049 .61159 Mtetra
.56049 .61159 .56558 .61677 .57529 .61397 .57022 .60876 Mtetra
.57022 .60876 .57529 .61397 .58504 .61115 .57999 .60593 Mtetra
.57999 .60593 .58504 .61115 .59482 .60833 .58979 .60308 Mtetra
.58979 .60308 .59482 .60833 .60463 .60549 .59963 .60023 Mtetra
.59963 .60023 .60463 .60549 .61448 .60265 .6095 .59737 Mtetra
.6095 .59737 .61448 .60265 .62437 .59979 .61941 .59449 Mtetra
.61941 .59449 .62437 .59979 .63428 .59692 .62935 .59161 Mtetra
.62935 .59161 .63428 .59692 .64424 .59405 .63933 .58871 Mtetra
.63933 .58871 .64424 .59405 .65423 .59116 .64934 .58581 Mtetra
.64934 .58581 .65423 .59116 .66425 .58826 .65939 .58289 Mtetra
.65939 .58289 .66425 .58826 .67431 .58536 .66947 .57996 Mtetra
.66947 .57996 .67431 .58536 .68441 .58244 .67959 .57703 Mtetra
.67959 .57703 .68441 .58244 .69454 .57951 .68975 .57408 Mtetra
.68975 .57408 .69454 .57951 .70471 .57657 .69995 .57112 Mtetra
.69995 .57112 .70471 .57657 .71491 .57363 .71018 .56815 Mtetra
.71018 .56815 .71491 .57363 .72516 .57067 .72044 .56517 Mtetra
.72044 .56517 .72516 .57067 .73544 .5677 .73075 .56218 Mtetra
.73075 .56218 .73544 .5677 .74575 .56471 .74109 .55918 Mtetra
.74109 .55918 .74575 .56471 .75611 .56172 .75147 .55617 Mtetra
.75147 .55617 .75611 .56172 .7665 .55872 .76189 .55315 Mtetra
.76189 .55315 .7665 .55872 .77693 .55571 .77234 .55012 Mtetra
.77234 .55012 .77693 .55571 .78739 .55268 .78284 .54707 Mtetra
.78284 .54707 .78739 .55268 .7979 .54965 .79337 .54401 Mtetra
.79337 .54401 .7979 .54965 .80844 .5466 .80394 .54095 Mtetra
.80394 .54095 .80844 .5466 .81902 .54354 .81455 .53787 Mtetra
.81455 .53787 .81902 .54354 .82964 .54047 .8252 .53478 Mtetra
.8252 .53478 .82964 .54047 .8403 .53739 .83589 .53168 Mtetra
.83589 .53168 .8403 .53739 .851 .5343 .84661 .52857 Mtetra
.84661 .52857 .851 .5343 .86174 .5312 .85738 .52544 Mtetra
.85738 .52544 .86174 .5312 .87252 .52809 .86819 .52231 Mtetra
.86819 .52231 .87252 .52809 .88334 .52496 .87903 .51916 Mtetra
.87903 .51916 .88334 .52496 .89419 .52182 .88992 .516 Mtetra
.88992 .516 .89419 .52182 .90509 .51867 .90085 .51283 Mtetra
.90085 .51283 .90509 .51867 .91603 .51551 .91182 .50965 Mtetra
.91182 .50965 .91603 .51551 .92701 .51234 .92283 .50645 Mtetra
.92283 .50645 .92701 .51234 .93803 .50916 .93388 .50324 Mtetra
.93388 .50324 .93803 .50916 .94909 .50596 .94497 .50003 Mtetra
.94497 .50003 .94909 .50596 .9602 .50275 .9561 .4968 Mtetra
.35813 .66383 .36369 .66869 .37275 .66606 .3672 .66119 Mtetra
.3672 .66119 .37275 .66606 .38183 .66342 .3763 .65854 Mtetra
.3763 .65854 .38183 .66342 .39094 .66078 .38544 .65587 Mtetra
.38544 .65587 .39094 .66078 .40009 .65813 .3946 .6532 Mtetra
.3946 .6532 .40009 .65813 .40927 .65546 .4038 .65052 Mtetra
.4038 .65052 .40927 .65546 .41848 .65279 .41303 .64783 Mtetra
.41303 .64783 .41848 .65279 .42772 .65011 .42229 .64514 Mtetra
.42229 .64514 .42772 .65011 .43699 .64742 .43158 .64243 Mtetra
.43158 .64243 .43699 .64742 .44629 .64472 .4409 .63971 Mtetra
.4409 .63971 .44629 .64472 .45563 .64201 .45026 .63699 Mtetra
.45026 .63699 .45563 .64201 .465 .63929 .45965 .63425 Mtetra
.45965 .63425 .465 .63929 .4744 .63657 .46907 .63151 Mtetra
.46907 .63151 .4744 .63657 .48383 .63383 .47853 .62875 Mtetra
.47853 .62875 .48383 .63383 .4933 .63108 .48801 .62599 Mtetra
.48801 .62599 .4933 .63108 .50279 .62833 .49753 .62321 Mtetra
.49753 .62321 .50279 .62833 .51233 .62556 .50709 .62043 Mtetra
.50709 .62043 .51233 .62556 .52189 .62279 .51667 .61764 Mtetra
.51667 .61764 .52189 .62279 .53149 .62 .52629 .61483 Mtetra
.52629 .61483 .53149 .62 .54112 .61721 .53595 .61202 Mtetra
.53595 .61202 .54112 .61721 .55079 .6144 .54563 .6092 Mtetra
.54563 .6092 .55079 .6144 .56049 .61159 .55536 .60636 Mtetra
.55536 .60636 .56049 .61159 .57022 .60876 .56511 .60352 Mtetra
.56511 .60352 .57022 .60876 .57999 .60593 .5749 .60067 Mtetra
.5749 .60067 .57999 .60593 .58979 .60308 .58473 .59781 Mtetra
.58473 .59781 .58979 .60308 .59963 .60023 .59459 .59493 Mtetra
.59459 .59493 .59963 .60023 .6095 .59737 .60448 .59205 Mtetra
.60448 .59205 .6095 .59737 .61941 .59449 .61441 .58916 Mtetra
.61441 .58916 .61941 .59449 .62935 .59161 .62438 .58625 Mtetra
.62438 .58625 .62935 .59161 .63933 .58871 .63438 .58334 Mtetra
.63438 .58334 .63933 .58871 .64934 .58581 .64442 .58041 Mtetra
.64442 .58041 .64934 .58581 .65939 .58289 .65449 .57748 Mtetra
.65449 .57748 .65939 .58289 .66947 .57996 .6646 .57453 Mtetra
.6646 .57453 .66947 .57996 .67959 .57703 .67475 .57158 Mtetra
.67475 .57158 .67959 .57703 .68975 .57408 .68493 .56861 Mtetra
.68493 .56861 .68975 .57408 .69995 .57112 .69515 .56563 Mtetra
.69515 .56563 .69995 .57112 .71018 .56815 .70541 .56264 Mtetra
.70541 .56264 .71018 .56815 .72044 .56517 .7157 .55965 Mtetra
.7157 .55965 .72044 .56517 .73075 .56218 .72603 .55664 Mtetra
.72603 .55664 .73075 .56218 .74109 .55918 .7364 .55361 Mtetra
.7364 .55361 .74109 .55918 .75147 .55617 .7468 .55058 Mtetra
.7468 .55058 .75147 .55617 .76189 .55315 .75725 .54754 Mtetra
.75725 .54754 .76189 .55315 .77234 .55012 .76773 .54449 Mtetra
.76773 .54449 .77234 .55012 .78284 .54707 .77825 .54142 Mtetra
.77825 .54142 .78284 .54707 .79337 .54401 .78881 .53834 Mtetra
.78881 .53834 .79337 .54401 .80394 .54095 .79941 .53526 Mtetra
.79941 .53526 .80394 .54095 .81455 .53787 .81005 .53216 Mtetra
.81005 .53216 .81455 .53787 .8252 .53478 .82072 .52905 Mtetra
.82072 .52905 .8252 .53478 .83589 .53168 .83144 .52592 Mtetra
.83144 .52592 .83589 .53168 .84661 .52857 .84219 .52279 Mtetra
.84219 .52279 .84661 .52857 .85738 .52544 .85299 .51964 Mtetra
.85299 .51964 .85738 .52544 .86819 .52231 .86383 .51649 Mtetra
.86383 .51649 .86819 .52231 .87903 .51916 .8747 .51332 Mtetra
.8747 .51332 .87903 .51916 .88992 .516 .88562 .51014 Mtetra
.88562 .51014 .88992 .516 .90085 .51283 .89658 .50694 Mtetra
.89658 .50694 .90085 .51283 .91182 .50965 .90758 .50374 Mtetra
.90758 .50374 .91182 .50965 .92283 .50645 .91862 .50052 Mtetra
.91862 .50052 .92283 .50645 .93388 .50324 .9297 .49729 Mtetra
.9297 .49729 .93388 .50324 .94497 .50003 .94082 .49405 Mtetra
.94082 .49405 .94497 .50003 .9561 .4968 .95198 .4908 Mtetra
.35253 .65894 .35813 .66383 .3672 .66119 .36162 .65628 Mtetra
.36162 .65628 .3672 .66119 .3763 .65854 .37074 .65361 Mtetra
.37074 .65361 .3763 .65854 .38544 .65587 .3799 .65094 Mtetra
.3799 .65094 .38544 .65587 .3946 .6532 .38908 .64825 Mtetra
.38908 .64825 .3946 .6532 .4038 .65052 .3983 .64555 Mtetra
.3983 .64555 .4038 .65052 .41303 .64783 .40755 .64285 Mtetra
.40755 .64285 .41303 .64783 .42229 .64514 .41683 .64013 Mtetra
.41683 .64013 .42229 .64514 .43158 .64243 .42614 .63741 Mtetra
.42614 .63741 .43158 .64243 .4409 .63971 .43548 .63467 Mtetra
.43548 .63467 .4409 .63971 .45026 .63699 .44486 .63193 Mtetra
.44486 .63193 .45026 .63699 .45965 .63425 .45427 .62918 Mtetra
.45427 .62918 .45965 .63425 .46907 .63151 .46371 .62641 Mtetra
.46371 .62641 .46907 .63151 .47853 .62875 .47319 .62364 Mtetra
.47319 .62364 .47853 .62875 .48801 .62599 .48269 .62086 Mtetra
.48269 .62086 .48801 .62599 .49753 .62321 .49224 .61807 Mtetra
.49224 .61807 .49753 .62321 .50709 .62043 .50181 .61527 Mtetra
.50181 .61527 .50709 .62043 .51667 .61764 .51142 .61245 Mtetra
.51142 .61245 .51667 .61764 .52629 .61483 .52106 .60963 Mtetra
.52106 .60963 .52629 .61483 .53595 .61202 .53074 .6068 Mtetra
.53074 .6068 .53595 .61202 .54563 .6092 .54045 .60396 Mtetra
.54045 .60396 .54563 .6092 .55536 .60636 .55019 .60111 Mtetra
.55019 .60111 .55536 .60636 .56511 .60352 .55997 .59825 Mtetra
.55997 .59825 .56511 .60352 .5749 .60067 .56978 .59538 Mtetra
.56978 .59538 .5749 .60067 .58473 .59781 .57963 .59249 Mtetra
.57963 .59249 .58473 .59781 .59459 .59493 .58952 .5896 Mtetra
.58952 .5896 .59459 .59493 .60448 .59205 .59944 .5867 Mtetra
.59944 .5867 .60448 .59205 .61441 .58916 .60939 .58379 Mtetra
.60939 .58379 .61441 .58916 .62438 .58625 .61938 .58087 Mtetra
.61938 .58087 .62438 .58625 .63438 .58334 .62941 .57793 Mtetra
.62941 .57793 .63438 .58334 .64442 .58041 .63947 .57499 Mtetra
.63947 .57499 .64442 .58041 .65449 .57748 .64957 .57203 Mtetra
.64957 .57203 .65449 .57748 .6646 .57453 .6597 .56907 Mtetra
.6597 .56907 .6646 .57453 .67475 .57158 .66987 .56609 Mtetra
.66987 .56609 .67475 .57158 .68493 .56861 .68008 .56311 Mtetra
.68008 .56311 .68493 .56861 .69515 .56563 .69032 .56011 Mtetra
.69032 .56011 .69515 .56563 .70541 .56264 .7006 .5571 Mtetra
.7006 .5571 .70541 .56264 .7157 .55965 .71092 .55408 Mtetra
.71092 .55408 .7157 .55965 .72603 .55664 .72128 .55105 Mtetra
.72128 .55105 .72603 .55664 .7364 .55361 .73168 .54801 Mtetra
.73168 .54801 .7364 .55361 .7468 .55058 .74211 .54496 Mtetra
.74211 .54496 .7468 .55058 .75725 .54754 .75258 .54189 Mtetra
.75258 .54189 .75725 .54754 .76773 .54449 .76309 .53882 Mtetra
.76309 .53882 .76773 .54449 .77825 .54142 .77364 .53573 Mtetra
.77364 .53573 .77825 .54142 .78881 .53834 .78422 .53263 Mtetra
.78422 .53263 .78881 .53834 .79941 .53526 .79485 .52952 Mtetra
.79485 .52952 .79941 .53526 .81005 .53216 .80551 .5264 Mtetra
.80551 .5264 .81005 .53216 .82072 .52905 .81622 .52327 Mtetra
.81622 .52327 .82072 .52905 .83144 .52592 .82696 .52013 Mtetra
.82696 .52013 .83144 .52592 .84219 .52279 .83775 .51697 Mtetra
.83775 .51697 .84219 .52279 .85299 .51964 .84857 .51381 Mtetra
.84857 .51381 .85299 .51964 .86383 .51649 .85944 .51063 Mtetra
.85944 .51063 .86383 .51649 .8747 .51332 .87034 .50744 Mtetra
.87034 .50744 .8747 .51332 .88562 .51014 .88129 .50423 Mtetra
.88129 .50423 .88562 .51014 .89658 .50694 .89227 .50102 Mtetra
.89227 .50102 .89658 .50694 .90758 .50374 .9033 .49779 Mtetra
.9033 .49779 .90758 .50374 .91862 .50052 .91437 .49455 Mtetra
.91437 .49455 .91862 .50052 .9297 .49729 .92549 .4913 Mtetra
.92549 .4913 .9297 .49729 .94082 .49405 .93664 .48804 Mtetra
.93664 .48804 .94082 .49405 .95198 .4908 .94784 .48476 Mtetra
.34689 .65403 .35253 .65894 .36162 .65628 .356 .65135 Mtetra
.356 .65135 .36162 .65628 .37074 .65361 .36515 .64866 Mtetra
.36515 .64866 .37074 .65361 .3799 .65094 .37432 .64597 Mtetra
.37432 .64597 .3799 .65094 .38908 .64825 .38352 .64326 Mtetra
.38352 .64326 .38908 .64825 .3983 .64555 .39276 .64055 Mtetra
.39276 .64055 .3983 .64555 .40755 .64285 .40203 .63783 Mtetra
.40203 .63783 .40755 .64285 .41683 .64013 .41133 .63509 Mtetra
.41133 .63509 .41683 .64013 .42614 .63741 .42066 .63235 Mtetra
.42066 .63235 .42614 .63741 .43548 .63467 .43003 .6296 Mtetra
.43003 .6296 .43548 .63467 .44486 .63193 .43942 .62684 Mtetra
.43942 .62684 .44486 .63193 .45427 .62918 .44885 .62407 Mtetra
.44885 .62407 .45427 .62918 .46371 .62641 .45832 .62129 Mtetra
.45832 .62129 .46371 .62641 .47319 .62364 .46781 .6185 Mtetra
.46781 .6185 .47319 .62364 .48269 .62086 .47734 .6157 Mtetra
.47734 .6157 .48269 .62086 .49224 .61807 .4869 .61289 Mtetra
.4869 .61289 .49224 .61807 .50181 .61527 .4965 .61007 Mtetra
.4965 .61007 .50181 .61527 .51142 .61245 .50613 .60724 Mtetra
.50613 .60724 .51142 .61245 .52106 .60963 .5158 .6044 Mtetra
.5158 .6044 .52106 .60963 .53074 .6068 .52549 .60155 Mtetra
.52549 .60155 .53074 .6068 .54045 .60396 .53523 .59869 Mtetra
.53523 .59869 .54045 .60396 .55019 .60111 .54499 .59582 Mtetra
.54499 .59582 .55019 .60111 .55997 .59825 .5548 .59294 Mtetra
.5548 .59294 .55997 .59825 .56978 .59538 .56463 .59005 Mtetra
.56463 .59005 .56978 .59538 .57963 .59249 .5745 .58715 Mtetra
.5745 .58715 .57963 .59249 .58952 .5896 .58441 .58424 Mtetra
.58441 .58424 .58952 .5896 .59944 .5867 .59435 .58132 Mtetra
.59435 .58132 .59944 .5867 .60939 .58379 .60433 .57838 Mtetra
.60433 .57838 .60939 .58379 .61938 .58087 .61435 .57544 Mtetra
.61435 .57544 .61938 .58087 .62941 .57793 .6244 .57249 Mtetra
.6244 .57249 .62941 .57793 .63947 .57499 .63448 .56952 Mtetra
.63448 .56952 .63947 .57499 .64957 .57203 .6446 .56655 Mtetra
.6446 .56655 .64957 .57203 .6597 .56907 .65476 .56357 Mtetra
.65476 .56357 .6597 .56907 .66987 .56609 .66496 .56057 Mtetra
.66496 .56057 .66987 .56609 .68008 .56311 .67519 .55756 Mtetra
.67519 .55756 .68008 .56311 .69032 .56011 .68546 .55455 Mtetra
.68546 .55455 .69032 .56011 .7006 .5571 .69577 .55152 Mtetra
.69577 .55152 .7006 .5571 .71092 .55408 .70612 .54848 Mtetra
.70612 .54848 .71092 .55408 .72128 .55105 .7165 .54543 Mtetra
.7165 .54543 .72128 .55105 .73168 .54801 .72692 .54236 Mtetra
.72692 .54236 .73168 .54801 .74211 .54496 .73738 .53929 Mtetra
.73738 .53929 .74211 .54496 .75258 .54189 .74788 .53621 Mtetra
.74788 .53621 .75258 .54189 .76309 .53882 .75841 .53311 Mtetra
.75841 .53311 .76309 .53882 .77364 .53573 .76899 .53 Mtetra
.76899 .53 .77364 .53573 .78422 .53263 .7796 .52688 Mtetra
.7796 .52688 .78422 .53263 .79485 .52952 .79026 .52375 Mtetra
.79026 .52375 .79485 .52952 .80551 .5264 .80095 .52061 Mtetra
.80095 .52061 .80551 .5264 .81622 .52327 .81168 .51746 Mtetra
.81168 .51746 .81622 .52327 .82696 .52013 .82245 .51429 Mtetra
.82245 .51429 .82696 .52013 .83775 .51697 .83327 .51112 Mtetra
.83327 .51112 .83775 .51697 .84857 .51381 .84412 .50793 Mtetra
.84412 .50793 .84857 .51381 .85944 .51063 .85501 .50473 Mtetra
.85501 .50473 .85944 .51063 .87034 .50744 .86595 .50151 Mtetra
.86595 .50151 .87034 .50744 .88129 .50423 .87693 .49829 Mtetra
.87693 .49829 .88129 .50423 .89227 .50102 .88794 .49505 Mtetra
.88794 .49505 .89227 .50102 .9033 .49779 .899 .4918 Mtetra
.899 .4918 .9033 .49779 .91437 .49455 .9101 .48854 Mtetra
.9101 .48854 .91437 .49455 .92549 .4913 .92125 .48527 Mtetra
.92125 .48527 .92549 .4913 .93664 .48804 .93243 .48198 Mtetra
.93243 .48198 .93664 .48804 .94784 .48476 .94366 .47868 Mtetra
.34122 .64908 .34689 .65403 .356 .65135 .35035 .64638 Mtetra
.35035 .64638 .356 .65135 .36515 .64866 .35951 .64368 Mtetra
.35951 .64368 .36515 .64866 .37432 .64597 .36871 .64097 Mtetra
.36871 .64097 .37432 .64597 .38352 .64326 .37793 .63825 Mtetra
.37793 .63825 .38352 .64326 .39276 .64055 .38719 .63551 Mtetra
.38719 .63551 .39276 .64055 .40203 .63783 .39647 .63277 Mtetra
.39647 .63277 .40203 .63783 .41133 .63509 .40579 .63002 Mtetra
.40579 .63002 .41133 .63509 .42066 .63235 .41515 .62726 Mtetra
.41515 .62726 .42066 .63235 .43003 .6296 .42453 .62449 Mtetra
.42453 .62449 .43003 .6296 .43942 .62684 .43395 .62172 Mtetra
.43395 .62172 .43942 .62684 .44885 .62407 .4434 .61893 Mtetra
.4434 .61893 .44885 .62407 .45832 .62129 .45289 .61613 Mtetra
.45289 .61613 .45832 .62129 .46781 .6185 .4624 .61332 Mtetra
.4624 .61332 .46781 .6185 .47734 .6157 .47195 .6105 Mtetra
.47195 .6105 .47734 .6157 .4869 .61289 .48154 .60767 Mtetra
.48154 .60767 .4869 .61289 .4965 .61007 .49116 .60484 Mtetra
.49116 .60484 .4965 .61007 .50613 .60724 .50081 .60199 Mtetra
.50081 .60199 .50613 .60724 .5158 .6044 .5105 .59913 Mtetra
.5105 .59913 .5158 .6044 .52549 .60155 .52022 .59626 Mtetra
.52022 .59626 .52549 .60155 .53523 .59869 .52997 .59338 Mtetra
.52997 .59338 .53523 .59869 .54499 .59582 .53976 .59049 Mtetra
.53976 .59049 .54499 .59582 .5548 .59294 .54959 .58759 Mtetra
.54959 .58759 .5548 .59294 .56463 .59005 .55945 .58469 Mtetra
.55945 .58469 .56463 .59005 .5745 .58715 .56934 .58177 Mtetra
.56934 .58177 .5745 .58715 .58441 .58424 .57927 .57884 Mtetra
.57927 .57884 .58441 .58424 .59435 .58132 .58924 .57589 Mtetra
.58924 .57589 .59435 .58132 .60433 .57838 .59924 .57294 Mtetra
.59924 .57294 .60433 .57838 .61435 .57544 .60928 .56998 Mtetra
.60928 .56998 .61435 .57544 .6244 .57249 .61935 .56701 Mtetra
.61935 .56701 .6244 .57249 .63448 .56952 .62946 .56403 Mtetra
.62946 .56403 .63448 .56952 .6446 .56655 .63961 .56103 Mtetra
.63961 .56103 .6446 .56655 .65476 .56357 .64979 .55803 Mtetra
.64979 .55803 .65476 .56357 .66496 .56057 .66002 .55501 Mtetra
.66002 .55501 .66496 .56057 .67519 .55756 .67027 .55198 Mtetra
.67027 .55198 .67519 .55756 .68546 .55455 .68057 .54895 Mtetra
.68057 .54895 .68546 .55455 .69577 .55152 .6909 .5459 Mtetra
.6909 .5459 .69577 .55152 .70612 .54848 .70127 .54284 Mtetra
.70127 .54284 .70612 .54848 .7165 .54543 .71168 .53976 Mtetra
.71168 .53976 .7165 .54543 .72692 .54236 .72213 .53668 Mtetra
.72213 .53668 .72692 .54236 .73738 .53929 .73262 .53359 Mtetra
.73262 .53359 .73738 .53929 .74788 .53621 .74314 .53048 Mtetra
.74314 .53048 .74788 .53621 .75841 .53311 .75371 .52737 Mtetra
.75371 .52737 .75841 .53311 .76899 .53 .76431 .52424 Mtetra
.76431 .52424 .76899 .53 .7796 .52688 .77495 .5211 Mtetra
.77495 .5211 .7796 .52688 .79026 .52375 .78563 .51794 Mtetra
.78563 .51794 .79026 .52375 .80095 .52061 .79635 .51478 Mtetra
.79635 .51478 .80095 .52061 .81168 .51746 .80711 .51161 Mtetra
.80711 .51161 .81168 .51746 .82245 .51429 .81792 .50842 Mtetra
.81792 .50842 .82245 .51429 .83327 .51112 .82876 .50522 Mtetra
.82876 .50522 .83327 .51112 .84412 .50793 .83964 .50201 Mtetra
.83964 .50201 .84412 .50793 .85501 .50473 .85056 .49879 Mtetra
.85056 .49879 .85501 .50473 .86595 .50151 .86153 .49555 Mtetra
.86153 .49555 .86595 .50151 .87693 .49829 .87253 .4923 Mtetra
.87253 .4923 .87693 .49829 .88794 .49505 .88358 .48904 Mtetra
.88358 .48904 .88794 .49505 .899 .4918 .89467 .48577 Mtetra
.89467 .48577 .899 .4918 .9101 .48854 .9058 .48249 Mtetra
.9058 .48249 .9101 .48854 .92125 .48527 .91698 .47919 Mtetra
.91698 .47919 .92125 .48527 .93243 .48198 .92819 .47588 Mtetra
.92819 .47588 .93243 .48198 .94366 .47868 .93945 .47256 Mtetra
.33552 .6441 .34122 .64908 .35035 .64638 .34467 .64139 Mtetra
.34467 .64139 .35035 .64638 .35951 .64368 .35385 .63866 Mtetra
.35385 .63866 .35951 .64368 .36871 .64097 .36306 .63594 Mtetra
.36306 .63594 .36871 .64097 .37793 .63825 .3723 .6332 Mtetra
.3723 .6332 .37793 .63825 .38719 .63551 .38158 .63045 Mtetra
.38158 .63045 .38719 .63551 .39647 .63277 .39089 .62769 Mtetra
.39089 .62769 .39647 .63277 .40579 .63002 .40023 .62492 Mtetra
.40023 .62492 .40579 .63002 .41515 .62726 .4096 .62214 Mtetra
.4096 .62214 .41515 .62726 .42453 .62449 .41901 .61936 Mtetra
.41901 .61936 .42453 .62449 .43395 .62172 .42844 .61656 Mtetra
.42844 .61656 .43395 .62172 .4434 .61893 .43792 .61375 Mtetra
.43792 .61375 .4434 .61893 .45289 .61613 .44742 .61094 Mtetra
.44742 .61094 .45289 .61613 .4624 .61332 .45696 .60811 Mtetra
.45696 .60811 .4624 .61332 .47195 .6105 .46653 .60527 Mtetra
.46653 .60527 .47195 .6105 .48154 .60767 .47614 .60243 Mtetra
.47614 .60243 .48154 .60767 .49116 .60484 .48578 .59957 Mtetra
.48578 .59957 .49116 .60484 .50081 .60199 .49545 .5967 Mtetra
.49545 .5967 .50081 .60199 .5105 .59913 .50516 .59383 Mtetra
.50516 .59383 .5105 .59913 .52022 .59626 .5149 .59094 Mtetra
.5149 .59094 .52022 .59626 .52997 .59338 .52468 .58804 Mtetra
.52468 .58804 .52997 .59338 .53976 .59049 .5345 .58513 Mtetra
.5345 .58513 .53976 .59049 .54959 .58759 .54434 .58222 Mtetra
.54434 .58222 .54959 .58759 .55945 .58469 .55423 .57929 Mtetra
.55423 .57929 .55945 .58469 .56934 .58177 .56414 .57635 Mtetra
.56414 .57635 .56934 .58177 .57927 .57884 .5741 .5734 Mtetra
.5741 .5734 .57927 .57884 .58924 .57589 .58409 .57044 Mtetra
.58409 .57044 .58924 .57589 .59924 .57294 .59412 .56747 Mtetra
.59412 .56747 .59924 .57294 .60928 .56998 .60418 .56449 Mtetra
.60418 .56449 .60928 .56998 .61935 .56701 .61428 .56149 Mtetra
.61428 .56149 .61935 .56701 .62946 .56403 .62441 .55849 Mtetra
.62441 .55849 .62946 .56403 .63961 .56103 .63458 .55547 Mtetra
.63458 .55547 .63961 .56103 .64979 .55803 .64479 .55245 Mtetra
.64479 .55245 .64979 .55803 .66002 .55501 .65504 .54941 Mtetra
.65504 .54941 .66002 .55501 .67027 .55198 .66532 .54637 Mtetra
.66532 .54637 .67027 .55198 .68057 .54895 .67564 .54331 Mtetra
.67564 .54331 .68057 .54895 .6909 .5459 .686 .54024 Mtetra
.686 .54024 .6909 .5459 .70127 .54284 .6964 .53716 Mtetra
.6964 .53716 .70127 .54284 .71168 .53976 .70684 .53406 Mtetra
.70684 .53406 .71168 .53976 .72213 .53668 .71731 .53096 Mtetra
.71731 .53096 .72213 .53668 .73262 .53359 .72782 .52785 Mtetra
.72782 .52785 .73262 .53359 .74314 .53048 .73838 .52472 Mtetra
.73838 .52472 .74314 .53048 .75371 .52737 .74897 .52158 Mtetra
.74897 .52158 .75371 .52737 .76431 .52424 .7596 .51843 Mtetra
.7596 .51843 .76431 .52424 .77495 .5211 .77027 .51527 Mtetra
.77027 .51527 .77495 .5211 .78563 .51794 .78098 .5121 Mtetra
.78098 .5121 .78563 .51794 .79635 .51478 .79173 .50891 Mtetra
.79173 .50891 .79635 .51478 .80711 .51161 .80251 .50571 Mtetra
.80251 .50571 .80711 .51161 .81792 .50842 .81335 .5025 Mtetra
.81335 .5025 .81792 .50842 .82876 .50522 .82422 .49928 Mtetra
.82422 .49928 .82876 .50522 .83964 .50201 .83513 .49605 Mtetra
.83513 .49605 .83964 .50201 .85056 .49879 .84608 .4928 Mtetra
.84608 .4928 .85056 .49879 .86153 .49555 .85707 .48955 Mtetra
.85707 .48955 .86153 .49555 .87253 .4923 .86811 .48627 Mtetra
.86811 .48627 .87253 .4923 .88358 .48904 .87919 .48299 Mtetra
.87919 .48299 .88358 .48904 .89467 .48577 .89031 .4797 Mtetra
.89031 .4797 .89467 .48577 .9058 .48249 .90147 .47639 Mtetra
.90147 .47639 .9058 .48249 .91698 .47919 .91268 .47307 Mtetra
.91268 .47307 .91698 .47919 .92819 .47588 .92392 .46974 Mtetra
.92392 .46974 .92819 .47588 .93945 .47256 .93521 .46639 Mtetra
.32977 .63908 .33552 .6441 .34467 .64139 .33894 .63636 Mtetra
.33894 .63636 .34467 .64139 .35385 .63866 .34814 .63362 Mtetra
.34814 .63362 .35385 .63866 .36306 .63594 .35737 .63087 Mtetra
.35737 .63087 .36306 .63594 .3723 .6332 .36664 .62811 Mtetra
.36664 .62811 .3723 .6332 .38158 .63045 .37593 .62535 Mtetra
.37593 .62535 .38158 .63045 .39089 .62769 .38526 .62257 Mtetra
.38526 .62257 .39089 .62769 .40023 .62492 .39462 .61979 Mtetra
.39462 .61979 .40023 .62492 .4096 .62214 .40402 .61699 Mtetra
.40402 .61699 .4096 .62214 .41901 .61936 .41344 .61418 Mtetra
.41344 .61418 .41901 .61936 .42844 .61656 .4229 .61137 Mtetra
.4229 .61137 .42844 .61656 .43792 .61375 .43239 .60854 Mtetra
.43239 .60854 .43792 .61375 .44742 .61094 .44192 .60571 Mtetra
.44192 .60571 .44742 .61094 .45696 .60811 .45148 .60286 Mtetra
.45148 .60286 .45696 .60811 .46653 .60527 .46108 .60001 Mtetra
.46108 .60001 .46653 .60527 .47614 .60243 .4707 .59714 Mtetra
.4707 .59714 .47614 .60243 .48578 .59957 .48037 .59427 Mtetra
.48037 .59427 .48578 .59957 .49545 .5967 .49006 .59138 Mtetra
.49006 .59138 .49545 .5967 .50516 .59383 .49979 .58849 Mtetra
.49979 .58849 .50516 .59383 .5149 .59094 .50956 .58558 Mtetra
.50956 .58558 .5149 .59094 .52468 .58804 .51936 .58267 Mtetra
.51936 .58267 .52468 .58804 .5345 .58513 .52919 .57974 Mtetra
.52919 .57974 .5345 .58513 .54434 .58222 .53907 .5768 Mtetra
.53907 .5768 .54434 .58222 .55423 .57929 .54897 .57385 Mtetra
.54897 .57385 .55423 .57929 .56414 .57635 .55891 .57089 Mtetra
.55891 .57089 .56414 .57635 .5741 .5734 .56889 .56792 Mtetra
.56889 .56792 .5741 .5734 .58409 .57044 .57891 .56494 Mtetra
.57891 .56494 .58409 .57044 .59412 .56747 .58896 .56195 Mtetra
.58896 .56195 .59412 .56747 .60418 .56449 .59904 .55895 Mtetra
.59904 .55895 .60418 .56449 .61428 .56149 .60917 .55594 Mtetra
.60917 .55594 .61428 .56149 .62441 .55849 .61933 .55292 Mtetra
.61933 .55292 .62441 .55849 .63458 .55547 .62952 .54988 Mtetra
.62952 .54988 .63458 .55547 .64479 .55245 .63976 .54684 Mtetra
.63976 .54684 .64479 .55245 .65504 .54941 .65003 .54378 Mtetra
.65003 .54378 .65504 .54941 .66532 .54637 .66034 .54071 Mtetra
.66034 .54071 .66532 .54637 .67564 .54331 .67069 .53763 Mtetra
.67069 .53763 .67564 .54331 .686 .54024 .68107 .53454 Mtetra
.68107 .53454 .686 .54024 .6964 .53716 .69149 .53144 Mtetra
.69149 .53144 .6964 .53716 .70684 .53406 .70196 .52833 Mtetra
.70196 .52833 .70684 .53406 .71731 .53096 .71246 .5252 Mtetra
.71246 .5252 .71731 .53096 .72782 .52785 .723 .52206 Mtetra
.723 .52206 .72782 .52785 .73838 .52472 .73358 .51892 Mtetra
.73358 .51892 .73838 .52472 .74897 .52158 .74419 .51576 Mtetra
.74419 .51576 .74897 .52158 .7596 .51843 .75485 .51258 Mtetra
.75485 .51258 .7596 .51843 .77027 .51527 .76555 .5094 Mtetra
.76555 .5094 .77027 .51527 .78098 .5121 .77629 .50621 Mtetra
.77629 .50621 .78098 .5121 .79173 .50891 .78707 .503 Mtetra
.78707 .503 .79173 .50891 .80251 .50571 .79788 .49978 Mtetra
.79788 .49978 .80251 .50571 .81335 .5025 .80874 .49655 Mtetra
.80874 .49655 .81335 .5025 .82422 .49928 .81964 .4933 Mtetra
.81964 .4933 .82422 .49928 .83513 .49605 .83058 .49005 Mtetra
.83058 .49005 .83513 .49605 .84608 .4928 .84157 .48678 Mtetra
.84157 .48678 .84608 .4928 .85707 .48955 .85259 .4835 Mtetra
.85259 .4835 .85707 .48955 .86811 .48627 .86366 .4802 Mtetra
.86366 .4802 .86811 .48627 .87919 .48299 .87477 .4769 Mtetra
.87477 .4769 .87919 .48299 .89031 .4797 .88592 .47358 Mtetra
.88592 .47358 .89031 .4797 .90147 .47639 .89711 .47025 Mtetra
.89711 .47025 .90147 .47639 .91268 .47307 .90834 .46691 Mtetra
.90834 .46691 .91268 .47307 .92392 .46974 .91962 .46355 Mtetra
.91962 .46355 .92392 .46974 .93521 .46639 .93095 .46018 Mtetra
.32399 .63404 .32977 .63908 .33894 .63636 .33318 .63129 Mtetra
.33318 .63129 .33894 .63636 .34814 .63362 .3424 .62854 Mtetra
.3424 .62854 .34814 .63362 .35737 .63087 .35165 .62577 Mtetra
.35165 .62577 .35737 .63087 .36664 .62811 .36094 .623 Mtetra
.36094 .623 .36664 .62811 .37593 .62535 .37025 .62021 Mtetra
.37025 .62021 .37593 .62535 .38526 .62257 .3796 .61742 Mtetra
.3796 .61742 .38526 .62257 .39462 .61979 .38898 .61462 Mtetra
.38898 .61462 .39462 .61979 .40402 .61699 .3984 .6118 Mtetra
.3984 .6118 .40402 .61699 .41344 .61418 .40784 .60898 Mtetra
.40784 .60898 .41344 .61418 .4229 .61137 .41732 .60615 Mtetra
.41732 .60615 .4229 .61137 .43239 .60854 .42684 .6033 Mtetra
.42684 .6033 .43239 .60854 .44192 .60571 .43639 .60045 Mtetra
.43639 .60045 .44192 .60571 .45148 .60286 .44597 .59759 Mtetra
.44597 .59759 .45148 .60286 .46108 .60001 .45558 .59471 Mtetra
.45558 .59471 .46108 .60001 .4707 .59714 .46523 .59183 Mtetra
.46523 .59183 .4707 .59714 .48037 .59427 .47492 .58893 Mtetra
.47492 .58893 .48037 .59427 .49006 .59138 .48463 .58603 Mtetra
.48463 .58603 .49006 .59138 .49979 .58849 .49439 .58311 Mtetra
.49439 .58311 .49979 .58849 .50956 .58558 .50418 .58019 Mtetra
.50418 .58019 .50956 .58558 .51936 .58267 .514 .57725 Mtetra
.514 .57725 .51936 .58267 .52919 .57974 .52386 .57431 Mtetra
.52386 .57431 .52919 .57974 .53907 .5768 .53375 .57135 Mtetra
.53375 .57135 .53907 .5768 .54897 .57385 .54368 .56838 Mtetra
.54368 .56838 .54897 .57385 .55891 .57089 .55365 .5654 Mtetra
.55365 .5654 .55891 .57089 .56889 .56792 .56365 .56241 Mtetra
.56365 .56241 .56889 .56792 .57891 .56494 .57369 .55941 Mtetra
.57369 .55941 .57891 .56494 .58896 .56195 .58376 .5564 Mtetra
.58376 .5564 .58896 .56195 .59904 .55895 .59387 .55338 Mtetra
.59387 .55338 .59904 .55895 .60917 .55594 .60402 .55035 Mtetra
.60402 .55035 .60917 .55594 .61933 .55292 .61421 .5473 Mtetra
.61421 .5473 .61933 .55292 .62952 .54988 .62443 .54425 Mtetra
.62443 .54425 .62952 .54988 .63976 .54684 .63469 .54118 Mtetra
.63469 .54118 .63976 .54684 .65003 .54378 .64498 .53811 Mtetra
.64498 .53811 .65003 .54378 .66034 .54071 .65532 .53502 Mtetra
.65532 .53502 .66034 .54071 .67069 .53763 .66569 .53192 Mtetra
.66569 .53192 .67069 .53763 .68107 .53454 .6761 .52881 Mtetra
.6761 .52881 .68107 .53454 .69149 .53144 .68655 .52568 Mtetra
.68655 .52568 .69149 .53144 .70196 .52833 .69704 .52255 Mtetra
.69704 .52255 .70196 .52833 .71246 .5252 .70757 .5194 Mtetra
.70757 .5194 .71246 .5252 .723 .52206 .71814 .51624 Mtetra
.71814 .51624 .723 .52206 .73358 .51892 .72874 .51307 Mtetra
.72874 .51307 .73358 .51892 .74419 .51576 .73939 .50989 Mtetra
.73939 .50989 .74419 .51576 .75485 .51258 .75008 .5067 Mtetra
.75008 .5067 .75485 .51258 .76555 .5094 .7608 .50349 Mtetra
.7608 .50349 .76555 .5094 .77629 .50621 .77157 .50027 Mtetra
.77157 .50027 .77629 .50621 .78707 .503 .78237 .49704 Mtetra
.78237 .49704 .78707 .503 .79788 .49978 .79322 .4938 Mtetra
.79322 .4938 .79788 .49978 .80874 .49655 .80411 .49055 Mtetra
.80411 .49055 .80874 .49655 .81964 .4933 .81504 .48728 Mtetra
.81504 .48728 .81964 .4933 .83058 .49005 .82601 .484 Mtetra
.82601 .484 .83058 .49005 .84157 .48678 .83702 .48071 Mtetra
.83702 .48071 .84157 .48678 .85259 .4835 .84808 .47741 Mtetra
.84808 .47741 .85259 .4835 .86366 .4802 .85917 .47409 Mtetra
.85917 .47409 .86366 .4802 .87477 .4769 .87031 .47076 Mtetra
.87031 .47076 .87477 .4769 .88592 .47358 .88149 .46742 Mtetra
.88149 .46742 .88592 .47358 .89711 .47025 .89272 .46407 Mtetra
.89272 .46407 .89711 .47025 .90834 .46691 .90398 .4607 Mtetra
.90398 .4607 .90834 .46691 .91962 .46355 .91529 .45732 Mtetra
.91529 .45732 .91962 .46355 .93095 .46018 .92665 .45393 Mtetra
.31818 .62896 .32399 .63404 .33318 .63129 .32738 .6262 Mtetra
.32738 .6262 .33318 .63129 .3424 .62854 .33662 .62343 Mtetra
.33662 .62343 .3424 .62854 .35165 .62577 .34589 .62064 Mtetra
.34589 .62064 .35165 .62577 .36094 .623 .3552 .61785 Mtetra
.3552 .61785 .36094 .623 .37025 .62021 .36453 .61505 Mtetra
.36453 .61505 .37025 .62021 .3796 .61742 .3739 .61224 Mtetra
.3739 .61224 .3796 .61742 .38898 .61462 .3833 .60942 Mtetra
.3833 .60942 .38898 .61462 .3984 .6118 .39274 .60658 Mtetra
.39274 .60658 .3984 .6118 .40784 .60898 .40221 .60374 Mtetra
.40221 .60374 .40784 .60898 .41732 .60615 .41171 .60089 Mtetra
.41171 .60089 .41732 .60615 .42684 .6033 .42124 .59803 Mtetra
.42124 .59803 .42684 .6033 .43639 .60045 .43081 .59516 Mtetra
.43081 .59516 .43639 .60045 .44597 .59759 .44042 .59227 Mtetra
.44042 .59227 .44597 .59759 .45558 .59471 .45005 .58938 Mtetra
.45005 .58938 .45558 .59471 .46523 .59183 .45972 .58648 Mtetra
.45972 .58648 .46523 .59183 .47492 .58893 .46943 .58356 Mtetra
.46943 .58356 .47492 .58893 .48463 .58603 .47917 .58064 Mtetra
.47917 .58064 .48463 .58603 .49439 .58311 .48895 .57771 Mtetra
.48895 .57771 .49439 .58311 .50418 .58019 .49876 .57476 Mtetra
.49876 .57476 .50418 .58019 .514 .57725 .5086 .57181 Mtetra
.5086 .57181 .514 .57725 .52386 .57431 .51849 .56884 Mtetra
.51849 .56884 .52386 .57431 .53375 .57135 .5284 .56586 Mtetra
.5284 .56586 .53375 .57135 .54368 .56838 .53836 .56288 Mtetra
.53836 .56288 .54368 .56838 .55365 .5654 .54835 .55988 Mtetra
.54835 .55988 .55365 .5654 .56365 .56241 .55837 .55687 Mtetra
.55837 .55687 .56365 .56241 .57369 .55941 .56843 .55385 Mtetra
.56843 .55385 .57369 .55941 .58376 .5564 .57853 .55082 Mtetra
.57853 .55082 .58376 .5564 .59387 .55338 .58867 .54777 Mtetra
.58867 .54777 .59387 .55338 .60402 .55035 .59884 .54472 Mtetra
.59884 .54472 .60402 .55035 .61421 .5473 .60905 .54166 Mtetra
.60905 .54166 .61421 .5473 .62443 .54425 .6193 .53858 Mtetra
.6193 .53858 .62443 .54425 .63469 .54118 .62958 .53549 Mtetra
.62958 .53549 .63469 .54118 .64498 .53811 .63991 .53239 Mtetra
.63991 .53239 .64498 .53811 .65532 .53502 .65027 .52928 Mtetra
.65027 .52928 .65532 .53502 .66569 .53192 .66067 .52616 Mtetra
.66067 .52616 .66569 .53192 .6761 .52881 .6711 .52303 Mtetra
.6711 .52303 .6761 .52881 .68655 .52568 .68158 .51989 Mtetra
.68158 .51989 .68655 .52568 .69704 .52255 .6921 .51673 Mtetra
.6921 .51673 .69704 .52255 .70757 .5194 .70265 .51356 Mtetra
.70265 .51356 .70757 .5194 .71814 .51624 .71324 .51038 Mtetra
.71324 .51038 .71814 .51624 .72874 .51307 .72388 .50719 Mtetra
.72388 .50719 .72874 .51307 .73939 .50989 .73455 .50399 Mtetra
.73455 .50399 .73939 .50989 .75008 .5067 .74527 .50077 Mtetra
.74527 .50077 .75008 .5067 .7608 .50349 .75602 .49754 Mtetra
.75602 .49754 .7608 .50349 .77157 .50027 .76681 .4943 Mtetra
.76681 .4943 .77157 .50027 .78237 .49704 .77765 .49105 Mtetra
.77765 .49105 .78237 .49704 .79322 .4938 .78852 .48779 Mtetra
.78852 .48779 .79322 .4938 .80411 .49055 .79944 .48451 Mtetra
.79944 .48451 .80411 .49055 .81504 .48728 .8104 .48122 Mtetra
.8104 .48122 .81504 .48728 .82601 .484 .8214 .47792 Mtetra
.8214 .47792 .82601 .484 .83702 .48071 .83244 .4746 Mtetra
.83244 .4746 .83702 .48071 .84808 .47741 .84353 .47128 Mtetra
.84353 .47128 .84808 .47741 .85917 .47409 .85465 .46794 Mtetra
.85465 .46794 .85917 .47409 .87031 .47076 .86582 .46458 Mtetra
.86582 .46458 .87031 .47076 .88149 .46742 .87704 .46122 Mtetra
.87704 .46122 .88149 .46742 .89272 .46407 .88829 .45784 Mtetra
.88829 .45784 .89272 .46407 .90398 .4607 .89959 .45445 Mtetra
.89959 .45445 .90398 .4607 .91529 .45732 .91093 .45104 Mtetra
.91093 .45104 .91529 .45732 .92665 .45393 .92232 .44763 Mtetra
.31232 .62385 .31818 .62896 .32738 .6262 .32155 .62107 Mtetra
.32155 .62107 .32738 .6262 .33662 .62343 .33081 .61828 Mtetra
.33081 .61828 .33662 .62343 .34589 .62064 .3401 .61548 Mtetra
.3401 .61548 .34589 .62064 .3552 .61785 .34942 .61267 Mtetra
.34942 .61267 .3552 .61785 .36453 .61505 .35878 .60985 Mtetra
.35878 .60985 .36453 .61505 .3739 .61224 .36817 .60702 Mtetra
.36817 .60702 .3739 .61224 .3833 .60942 .37759 .60418 Mtetra
.37759 .60418 .3833 .60942 .39274 .60658 .38704 .60133 Mtetra
.38704 .60133 .39274 .60658 .40221 .60374 .39653 .59847 Mtetra
.39653 .59847 .40221 .60374 .41171 .60089 .40606 .5956 Mtetra
.40606 .5956 .41171 .60089 .42124 .59803 .41561 .59272 Mtetra
.41561 .59272 .42124 .59803 .43081 .59516 .4252 .58983 Mtetra
.4252 .58983 .43081 .59516 .44042 .59227 .43483 .58692 Mtetra
.43483 .58692 .44042 .59227 .45005 .58938 .44449 .58401 Mtetra
.44449 .58401 .45005 .58938 .45972 .58648 .45418 .58109 Mtetra
.45418 .58109 .45972 .58648 .46943 .58356 .46391 .57816 Mtetra
.46391 .57816 .46943 .58356 .47917 .58064 .47367 .57521 Mtetra
.47367 .57521 .47917 .58064 .48895 .57771 .48347 .57226 Mtetra
.48347 .57226 .48895 .57771 .49876 .57476 .4933 .5693 Mtetra
.4933 .5693 .49876 .57476 .5086 .57181 .50317 .56632 Mtetra
.50317 .56632 .5086 .57181 .51849 .56884 .51308 .56334 Mtetra
.51308 .56334 .51849 .56884 .5284 .56586 .52302 .56034 Mtetra
.52302 .56034 .5284 .56586 .53836 .56288 .533 .55733 Mtetra
.533 .55733 .53836 .56288 .54835 .55988 .54301 .55431 Mtetra
.54301 .55431 .54835 .55988 .55837 .55687 .55306 .55128 Mtetra
.55306 .55128 .55837 .55687 .56843 .55385 .56314 .54824 Mtetra
.56314 .54824 .56843 .55385 .57853 .55082 .57327 .54519 Mtetra
.57327 .54519 .57853 .55082 .58867 .54777 .58343 .54213 Mtetra
.58343 .54213 .58867 .54777 .59884 .54472 .59363 .53905 Mtetra
.59363 .53905 .59884 .54472 .60905 .54166 .60386 .53597 Mtetra
.60386 .53597 .60905 .54166 .6193 .53858 .61413 .53287 Mtetra
.61413 .53287 .6193 .53858 .62958 .53549 .62444 .52976 Mtetra
.62444 .52976 .62958 .53549 .63991 .53239 .63479 .52664 Mtetra
.63479 .52664 .63991 .53239 .65027 .52928 .64518 .52351 Mtetra
.64518 .52351 .65027 .52928 .66067 .52616 .6556 .52037 Mtetra
.6556 .52037 .66067 .52616 .6711 .52303 .66607 .51722 Mtetra
.66607 .51722 .6711 .52303 .68158 .51989 .67657 .51405 Mtetra
.67657 .51405 .68158 .51989 .6921 .51673 .68711 .51087 Mtetra
.68711 .51087 .6921 .51673 .70265 .51356 .6977 .50768 Mtetra
.6977 .50768 .70265 .51356 .71324 .51038 .70832 .50448 Mtetra
.70832 .50448 .71324 .51038 .72388 .50719 .71898 .50127 Mtetra
.71898 .50127 .72388 .50719 .73455 .50399 .72968 .49804 Mtetra
.72968 .49804 .73455 .50399 .74527 .50077 .74042 .4948 Mtetra
.74042 .4948 .74527 .50077 .75602 .49754 .7512 .49155 Mtetra
.7512 .49155 .75602 .49754 .76681 .4943 .76203 .48829 Mtetra
.76203 .48829 .76681 .4943 .77765 .49105 .77289 .48501 Mtetra
.77289 .48501 .77765 .49105 .78852 .48779 .7838 .48173 Mtetra
.7838 .48173 .78852 .48779 .79944 .48451 .79474 .47843 Mtetra
.79474 .47843 .79944 .48451 .8104 .48122 .80573 .47511 Mtetra
.80573 .47511 .8104 .48122 .8214 .47792 .81676 .47179 Mtetra
.81676 .47179 .8214 .47792 .83244 .4746 .82783 .46845 Mtetra
.82783 .46845 .83244 .4746 .84353 .47128 .83895 .4651 Mtetra
.83895 .4651 .84353 .47128 .85465 .46794 .85011 .46174 Mtetra
.85011 .46174 .85465 .46794 .86582 .46458 .86131 .45836 Mtetra
.86131 .45836 .86582 .46458 .87704 .46122 .87255 .45497 Mtetra
.87255 .45497 .87704 .46122 .88829 .45784 .88384 .45157 Mtetra
.88384 .45157 .88829 .45784 .89959 .45445 .89517 .44815 Mtetra
.89517 .44815 .89959 .45445 .91093 .45104 .90654 .44472 Mtetra
.90654 .44472 .91093 .45104 .92232 .44763 .91796 .44128 Mtetra
.30643 .61871 .31232 .62385 .32155 .62107 .31568 .61591 Mtetra
.31568 .61591 .32155 .62107 .33081 .61828 .32495 .6131 Mtetra
.32495 .6131 .33081 .61828 .3401 .61548 .33427 .61028 Mtetra
.33427 .61028 .3401 .61548 .34942 .61267 .34361 .60746 Mtetra
.34361 .60746 .34942 .61267 .35878 .60985 .35299 .60462 Mtetra
.35299 .60462 .35878 .60985 .36817 .60702 .36239 .60177 Mtetra
.36239 .60177 .36817 .60702 .37759 .60418 .37184 .59891 Mtetra
.37184 .59891 .37759 .60418 .38704 .60133 .38131 .59604 Mtetra
.38131 .59604 .38704 .60133 .39653 .59847 .39082 .59316 Mtetra
.39082 .59316 .39653 .59847 .40606 .5956 .40037 .59027 Mtetra
.40037 .59027 .40606 .5956 .41561 .59272 .40995 .58737 Mtetra
.40995 .58737 .41561 .59272 .4252 .58983 .41956 .58446 Mtetra
.41956 .58446 .4252 .58983 .43483 .58692 .4292 .58154 Mtetra
.4292 .58154 .43483 .58692 .44449 .58401 .43888 .57861 Mtetra
.43888 .57861 .44449 .58401 .45418 .58109 .4486 .57567 Mtetra
.4486 .57567 .45418 .58109 .46391 .57816 .45835 .57272 Mtetra
.45835 .57272 .46391 .57816 .47367 .57521 .46814 .56975 Mtetra
.46814 .56975 .47367 .57521 .48347 .57226 .47796 .56678 Mtetra
.47796 .56678 .48347 .57226 .4933 .5693 .48781 .5638 Mtetra
.48781 .5638 .4933 .5693 .50317 .56632 .49771 .5608 Mtetra
.49771 .5608 .50317 .56632 .51308 .56334 .50763 .55779 Mtetra
.50763 .55779 .51308 .56334 .52302 .56034 .5176 .55478 Mtetra
.5176 .55478 .52302 .56034 .533 .55733 .5276 .55175 Mtetra
.5276 .55175 .533 .55733 .54301 .55431 .53764 .54871 Mtetra
.53764 .54871 .54301 .55431 .55306 .55128 .54771 .54566 Mtetra
.54771 .54566 .55306 .55128 .56314 .54824 .55782 .5426 Mtetra
.55782 .5426 .56314 .54824 .57327 .54519 .56797 .53953 Mtetra
.56797 .53953 .57327 .54519 .58343 .54213 .57815 .53644 Mtetra
.57815 .53644 .58343 .54213 .59363 .53905 .58837 .53335 Mtetra
.58837 .53335 .59363 .53905 .60386 .53597 .59864 .53024 Mtetra
.59864 .53024 .60386 .53597 .61413 .53287 .60893 .52712 Mtetra
.60893 .52712 .61413 .53287 .62444 .52976 .61927 .524 Mtetra
.61927 .524 .62444 .52976 .63479 .52664 .62964 .52085 Mtetra
.62964 .52085 .63479 .52664 .64518 .52351 .64006 .5177 Mtetra
.64006 .5177 .64518 .52351 .6556 .52037 .65051 .51454 Mtetra
.65051 .51454 .6556 .52037 .66607 .51722 .661 .51136 Mtetra
.661 .51136 .66607 .51722 .67657 .51405 .67153 .50817 Mtetra
.67153 .50817 .67657 .51405 .68711 .51087 .6821 .50497 Mtetra
.6821 .50497 .68711 .51087 .6977 .50768 .69271 .50176 Mtetra
.69271 .50176 .6977 .50768 .70832 .50448 .70336 .49854 Mtetra
.70336 .49854 .70832 .50448 .71898 .50127 .71405 .4953 Mtetra
.71405 .4953 .71898 .50127 .72968 .49804 .72477 .49205 Mtetra
.72477 .49205 .72968 .49804 .74042 .4948 .73554 .48879 Mtetra
.73554 .48879 .74042 .4948 .7512 .49155 .74636 .48552 Mtetra
.74636 .48552 .7512 .49155 .76203 .48829 .75721 .48223 Mtetra
.75721 .48223 .76203 .48829 .77289 .48501 .7681 .47893 Mtetra
.7681 .47893 .77289 .48501 .7838 .48173 .77903 .47562 Mtetra
.77903 .47562 .7838 .48173 .79474 .47843 .79001 .4723 Mtetra
.79001 .4723 .79474 .47843 .80573 .47511 .80103 .46897 Mtetra
.80103 .46897 .80573 .47511 .81676 .47179 .81209 .46562 Mtetra
.81209 .46562 .81676 .47179 .82783 .46845 .82319 .46226 Mtetra
.82319 .46226 .82783 .46845 .83895 .4651 .83434 .45888 Mtetra
.83434 .45888 .83895 .4651 .85011 .46174 .84552 .45549 Mtetra
.84552 .45549 .85011 .46174 .86131 .45836 .85676 .45209 Mtetra
.85676 .45209 .86131 .45836 .87255 .45497 .86803 .44868 Mtetra
.86803 .44868 .87255 .45497 .88384 .45157 .87935 .44525 Mtetra
.87935 .44525 .88384 .45157 .89517 .44815 .89071 .44181 Mtetra
.89071 .44181 .89517 .44815 .90654 .44472 .90212 .43836 Mtetra
.90212 .43836 .90654 .44472 .91796 .44128 .91357 .43489 Mtetra
.3005 .61354 .30643 .61871 .31568 .61591 .30977 .61072 Mtetra
.30977 .61072 .31568 .61591 .32495 .6131 .31906 .60789 Mtetra
.31906 .60789 .32495 .6131 .33427 .61028 .32839 .60505 Mtetra
.32839 .60505 .33427 .61028 .34361 .60746 .33776 .60221 Mtetra
.33776 .60221 .34361 .60746 .35299 .60462 .34715 .59935 Mtetra
.34715 .59935 .35299 .60462 .36239 .60177 .35658 .59648 Mtetra
.35658 .59648 .36239 .60177 .37184 .59891 .36605 .5936 Mtetra
.36605 .5936 .37184 .59891 .38131 .59604 .37555 .59072 Mtetra
.37555 .59072 .38131 .59604 .39082 .59316 .38508 .58782 Mtetra
.38508 .58782 .39082 .59316 .40037 .59027 .39464 .58491 Mtetra
.39464 .58491 .40037 .59027 .40995 .58737 .40424 .58199 Mtetra
.40424 .58199 .40995 .58737 .41956 .58446 .41387 .57906 Mtetra
.41387 .57906 .41956 .58446 .4292 .58154 .42354 .57612 Mtetra
.42354 .57612 .4292 .58154 .43888 .57861 .43324 .57317 Mtetra
.43324 .57317 .43888 .57861 .4486 .57567 .44298 .57021 Mtetra
.44298 .57021 .4486 .57567 .45835 .57272 .45276 .56724 Mtetra
.45276 .56724 .45835 .57272 .46814 .56975 .46256 .56426 Mtetra
.46256 .56426 .46814 .56975 .47796 .56678 .47241 .56126 Mtetra
.47241 .56126 .47796 .56678 .48781 .5638 .48229 .55826 Mtetra
.48229 .55826 .48781 .5638 .49771 .5608 .4922 .55524 Mtetra
.4922 .55524 .49771 .5608 .50763 .55779 .50215 .55222 Mtetra
.50215 .55222 .50763 .55779 .5176 .55478 .51214 .54918 Mtetra
.51214 .54918 .5176 .55478 .5276 .55175 .52217 .54613 Mtetra
.52217 .54613 .5276 .55175 .53764 .54871 .53223 .54307 Mtetra
.53223 .54307 .53764 .54871 .54771 .54566 .54232 .54 Mtetra
.54232 .54 .54771 .54566 .55782 .5426 .55246 .53692 Mtetra
.55246 .53692 .55782 .5426 .56797 .53953 .56263 .53383 Mtetra
.56263 .53383 .56797 .53953 .57815 .53644 .57284 .53072 Mtetra
.57284 .53072 .57815 .53644 .58837 .53335 .58309 .52761 Mtetra
.58309 .52761 .58837 .53335 .59864 .53024 .59337 .52448 Mtetra
.59337 .52448 .59864 .53024 .60893 .52712 .6037 .52134 Mtetra
.6037 .52134 .60893 .52712 .61927 .524 .61406 .51819 Mtetra
.61406 .51819 .61927 .524 .62964 .52085 .62446 .51503 Mtetra
.62446 .51503 .62964 .52085 .64006 .5177 .6349 .51185 Mtetra
.6349 .51185 .64006 .5177 .65051 .51454 .64538 .50866 Mtetra
.64538 .50866 .65051 .51454 .661 .51136 .65589 .50547 Mtetra
.65589 .50547 .661 .51136 .67153 .50817 .66645 .50226 Mtetra
.66645 .50226 .67153 .50817 .6821 .50497 .67705 .49903 Mtetra
.67705 .49903 .6821 .50497 .69271 .50176 .68768 .4958 Mtetra
.68768 .4958 .69271 .50176 .70336 .49854 .69836 .49255 Mtetra
.69836 .49255 .70336 .49854 .71405 .4953 .70908 .48929 Mtetra
.70908 .48929 .71405 .4953 .72477 .49205 .71984 .48602 Mtetra
.71984 .48602 .72477 .49205 .73554 .48879 .73063 .48274 Mtetra
.73063 .48274 .73554 .48879 .74636 .48552 .74147 .47944 Mtetra
.74147 .47944 .74636 .48552 .75721 .48223 .75235 .47613 Mtetra
.75235 .47613 .75721 .48223 .7681 .47893 .76328 .47281 Mtetra
.76328 .47281 .7681 .47893 .77903 .47562 .77424 .46948 Mtetra
.77424 .46948 .77903 .47562 .79001 .4723 .78524 .46613 Mtetra
.78524 .46613 .79001 .4723 .80103 .46897 .79629 .46277 Mtetra
.79629 .46277 .80103 .46897 .81209 .46562 .80738 .4594 Mtetra
.80738 .4594 .81209 .46562 .82319 .46226 .81852 .45602 Mtetra
.81852 .45602 .82319 .46226 .83434 .45888 .82969 .45262 Mtetra
.82969 .45262 .83434 .45888 .84552 .45549 .84091 .44921 Mtetra
.84091 .44921 .84552 .45549 .85676 .45209 .85217 .44578 Mtetra
.85217 .44578 .85676 .45209 .86803 .44868 .86348 .44234 Mtetra
.86348 .44234 .86803 .44868 .87935 .44525 .87483 .43889 Mtetra
.87483 .43889 .87935 .44525 .89071 .44181 .88623 .43543 Mtetra
.88623 .43543 .89071 .44181 .90212 .43836 .89766 .43195 Mtetra
.89766 .43195 .90212 .43836 .91357 .43489 .90915 .42846 Mtetra
.29453 .60833 .3005 .61354 .30977 .61072 .30382 .60549 Mtetra
.30382 .60549 .30977 .61072 .31906 .60789 .31314 .60265 Mtetra
.31314 .60265 .31906 .60789 .32839 .60505 .32249 .59979 Mtetra
.32249 .59979 .32839 .60505 .33776 .60221 .33187 .59692 Mtetra
.33187 .59692 .33776 .60221 .34715 .59935 .34129 .59405 Mtetra
.34129 .59405 .34715 .59935 .35658 .59648 .35074 .59116 Mtetra
.35074 .59116 .35658 .59648 .36605 .5936 .36022 .58826 Mtetra
.36022 .58826 .36605 .5936 .37555 .59072 .36974 .58536 Mtetra
.36974 .58536 .37555 .59072 .38508 .58782 .37929 .58244 Mtetra
.37929 .58244 .38508 .58782 .39464 .58491 .38888 .57951 Mtetra
.38888 .57951 .39464 .58491 .40424 .58199 .3985 .57657 Mtetra
.3985 .57657 .40424 .58199 .41387 .57906 .40815 .57363 Mtetra
.40815 .57363 .41387 .57906 .42354 .57612 .41784 .57067 Mtetra
.41784 .57067 .42354 .57612 .43324 .57317 .42757 .5677 Mtetra
.42757 .5677 .43324 .57317 .44298 .57021 .43733 .56471 Mtetra
.43733 .56471 .44298 .57021 .45276 .56724 .44712 .56172 Mtetra
.44712 .56172 .45276 .56724 .46256 .56426 .45695 .55872 Mtetra
.45695 .55872 .46256 .56426 .47241 .56126 .46682 .55571 Mtetra
.46682 .55571 .47241 .56126 .48229 .55826 .47672 .55268 Mtetra
.47672 .55268 .48229 .55826 .4922 .55524 .48666 .54965 Mtetra
.48666 .54965 .4922 .55524 .50215 .55222 .49664 .5466 Mtetra
.49664 .5466 .50215 .55222 .51214 .54918 .50665 .54354 Mtetra
.50665 .54354 .51214 .54918 .52217 .54613 .5167 .54047 Mtetra
.5167 .54047 .52217 .54613 .53223 .54307 .52678 .53739 Mtetra
.52678 .53739 .53223 .54307 .54232 .54 .5369 .5343 Mtetra
.5369 .5343 .54232 .54 .55246 .53692 .54706 .5312 Mtetra
.54706 .5312 .55246 .53692 .56263 .53383 .55726 .52809 Mtetra
.55726 .52809 .56263 .53383 .57284 .53072 .56749 .52496 Mtetra
.56749 .52496 .57284 .53072 .58309 .52761 .57777 .52182 Mtetra
.57777 .52182 .58309 .52761 .59337 .52448 .58808 .51867 Mtetra
.58808 .51867 .59337 .52448 .6037 .52134 .59843 .51551 Mtetra
.59843 .51551 .6037 .52134 .61406 .51819 .60881 .51234 Mtetra
.60881 .51234 .61406 .51819 .62446 .51503 .61924 .50916 Mtetra
.61924 .50916 .62446 .51503 .6349 .51185 .62971 .50596 Mtetra
.62971 .50596 .6349 .51185 .64538 .50866 .64021 .50275 Mtetra
.64021 .50275 .64538 .50866 .65589 .50547 .65075 .49953 Mtetra
.65075 .49953 .65589 .50547 .66645 .50226 .66134 .4963 Mtetra
.66134 .4963 .66645 .50226 .67705 .49903 .67196 .49305 Mtetra
.67196 .49305 .67705 .49903 .68768 .4958 .68263 .4898 Mtetra
.68263 .4898 .68768 .4958 .69836 .49255 .69333 .48653 Mtetra
.69333 .48653 .69836 .49255 .70908 .48929 .70408 .48325 Mtetra
.70408 .48325 .70908 .48929 .71984 .48602 .71486 .47995 Mtetra
.71486 .47995 .71984 .48602 .73063 .48274 .72569 .47664 Mtetra
.72569 .47664 .73063 .48274 .74147 .47944 .73656 .47333 Mtetra
.73656 .47333 .74147 .47944 .75235 .47613 .74746 .46999 Mtetra
.74746 .46999 .75235 .47613 .76328 .47281 .75842 .46665 Mtetra
.75842 .46665 .76328 .47281 .77424 .46948 .76941 .46329 Mtetra
.76941 .46329 .77424 .46948 .78524 .46613 .78044 .45992 Mtetra
.78044 .45992 .78524 .46613 .79629 .46277 .79152 .45654 Mtetra
.79152 .45654 .79629 .46277 .80738 .4594 .80264 .45314 Mtetra
.80264 .45314 .80738 .4594 .81852 .45602 .81381 .44973 Mtetra
.81381 .44973 .81852 .45602 .82969 .45262 .82501 .44631 Mtetra
.82501 .44631 .82969 .45262 .84091 .44921 .83626 .44287 Mtetra
.83626 .44287 .84091 .44921 .85217 .44578 .84756 .43942 Mtetra
.84756 .43942 .85217 .44578 .86348 .44234 .8589 .43596 Mtetra
.8589 .43596 .86348 .44234 .87483 .43889 .87028 .43248 Mtetra
.87028 .43248 .87483 .43889 .88623 .43543 .88171 .42899 Mtetra
.88171 .42899 .88623 .43543 .89766 .43195 .89318 .42549 Mtetra
.89318 .42549 .89766 .43195 .90915 .42846 .90469 .42197 Mtetra
.28853 .60308 .29453 .60833 .30382 .60549 .29783 .60023 Mtetra
.29783 .60023 .30382 .60549 .31314 .60265 .30717 .59737 Mtetra
.30717 .59737 .31314 .60265 .32249 .59979 .31654 .59449 Mtetra
.31654 .59449 .32249 .59979 .33187 .59692 .32594 .59161 Mtetra
.32594 .59161 .33187 .59692 .34129 .59405 .33538 .58871 Mtetra
.33538 .58871 .34129 .59405 .35074 .59116 .34485 .58581 Mtetra
.34485 .58581 .35074 .59116 .36022 .58826 .35435 .58289 Mtetra
.35435 .58289 .36022 .58826 .36974 .58536 .36389 .57996 Mtetra
.36389 .57996 .36974 .58536 .37929 .58244 .37347 .57703 Mtetra
.37347 .57703 .37929 .58244 .38888 .57951 .38307 .57408 Mtetra
.38307 .57408 .38888 .57951 .3985 .57657 .39272 .57112 Mtetra
.39272 .57112 .3985 .57657 .40815 .57363 .40239 .56815 Mtetra
.40239 .56815 .40815 .57363 .41784 .57067 .41211 .56517 Mtetra
.41211 .56517 .41784 .57067 .42757 .5677 .42185 .56218 Mtetra
.42185 .56218 .42757 .5677 .43733 .56471 .43163 .55918 Mtetra
.43163 .55918 .43733 .56471 .44712 .56172 .44145 .55617 Mtetra
.44145 .55617 .44712 .56172 .45695 .55872 .45131 .55315 Mtetra
.45131 .55315 .45695 .55872 .46682 .55571 .4612 .55012 Mtetra
.4612 .55012 .46682 .55571 .47672 .55268 .47112 .54707 Mtetra
.47112 .54707 .47672 .55268 .48666 .54965 .48108 .54401 Mtetra
.48108 .54401 .48666 .54965 .49664 .5466 .49108 .54095 Mtetra
.49108 .54095 .49664 .5466 .50665 .54354 .50112 .53787 Mtetra
.50112 .53787 .50665 .54354 .5167 .54047 .51119 .53478 Mtetra
.51119 .53478 .5167 .54047 .52678 .53739 .5213 .53168 Mtetra
.5213 .53168 .52678 .53739 .5369 .5343 .53144 .52857 Mtetra
.53144 .52857 .5369 .5343 .54706 .5312 .54163 .52544 Mtetra
.54163 .52544 .54706 .5312 .55726 .52809 .55185 .52231 Mtetra
.55185 .52231 .55726 .52809 .56749 .52496 .56211 .51916 Mtetra
.56211 .51916 .56749 .52496 .57777 .52182 .57241 .516 Mtetra
.57241 .516 .57777 .52182 .58808 .51867 .58274 .51283 Mtetra
.58274 .51283 .58808 .51867 .59843 .51551 .59312 .50965 Mtetra
.59312 .50965 .59843 .51551 .60881 .51234 .60353 .50645 Mtetra
.60353 .50645 .60881 .51234 .61924 .50916 .61398 .50324 Mtetra
.61398 .50324 .61924 .50916 .62971 .50596 .62448 .50003 Mtetra
.62448 .50003 .62971 .50596 .64021 .50275 .63501 .4968 Mtetra
.63501 .4968 .64021 .50275 .65075 .49953 .64558 .49355 Mtetra
.64558 .49355 .65075 .49953 .66134 .4963 .65619 .4903 Mtetra
.65619 .4903 .66134 .4963 .67196 .49305 .66684 .48703 Mtetra
.66684 .48703 .67196 .49305 .68263 .4898 .67753 .48375 Mtetra
.67753 .48375 .68263 .4898 .69333 .48653 .68826 .48046 Mtetra
.68826 .48046 .69333 .48653 .70408 .48325 .69904 .47715 Mtetra
.69904 .47715 .70408 .48325 .71486 .47995 .70985 .47384 Mtetra
.70985 .47384 .71486 .47995 .72569 .47664 .72071 .47051 Mtetra
.72071 .47051 .72569 .47664 .73656 .47333 .7316 .46716 Mtetra
.7316 .46716 .73656 .47333 .74746 .46999 .74254 .46381 Mtetra
.74254 .46381 .74746 .46999 .75842 .46665 .75352 .46044 Mtetra
.75352 .46044 .75842 .46665 .76941 .46329 .76455 .45706 Mtetra
.76455 .45706 .76941 .46329 .78044 .45992 .77561 .45366 Mtetra
.77561 .45366 .78044 .45992 .79152 .45654 .78672 .45026 Mtetra
.78672 .45026 .79152 .45654 .80264 .45314 .79787 .44684 Mtetra
.79787 .44684 .80264 .45314 .81381 .44973 .80906 .4434 Mtetra
.80906 .4434 .81381 .44973 .82501 .44631 .8203 .43995 Mtetra
.8203 .43995 .82501 .44631 .83626 .44287 .83158 .43649 Mtetra
.83158 .43649 .83626 .44287 .84756 .43942 .84291 .43302 Mtetra
.84291 .43302 .84756 .43942 .8589 .43596 .85428 .42953 Mtetra
.85428 .42953 .8589 .43596 .87028 .43248 .86569 .42603 Mtetra
.86569 .42603 .87028 .43248 .88171 .42899 .87715 .42251 Mtetra
.87715 .42251 .88171 .42899 .89318 .42549 .88866 .41899 Mtetra
.88866 .41899 .89318 .42549 .90469 .42197 .90021 .41544 Mtetra
.28248 .59781 .28853 .60308 .29783 .60023 .2918 .59493 Mtetra
.2918 .59493 .29783 .60023 .30717 .59737 .30116 .59205 Mtetra
.30116 .59205 .30717 .59737 .31654 .59449 .31055 .58916 Mtetra
.31055 .58916 .31654 .59449 .32594 .59161 .31998 .58625 Mtetra
.31998 .58625 .32594 .59161 .33538 .58871 .32943 .58334 Mtetra
.32943 .58334 .33538 .58871 .34485 .58581 .33892 .58041 Mtetra
.33892 .58041 .34485 .58581 .35435 .58289 .34845 .57748 Mtetra
.34845 .57748 .35435 .58289 .36389 .57996 .35801 .57453 Mtetra
.35801 .57453 .36389 .57996 .37347 .57703 .3676 .57158 Mtetra
.3676 .57158 .37347 .57703 .38307 .57408 .37723 .56861 Mtetra
.37723 .56861 .38307 .57408 .39272 .57112 .3869 .56563 Mtetra
.3869 .56563 .39272 .57112 .40239 .56815 .3966 .56264 Mtetra
.3966 .56264 .40239 .56815 .41211 .56517 .40633 .55965 Mtetra
.40633 .55965 .41211 .56517 .42185 .56218 .4161 .55664 Mtetra
.4161 .55664 .42185 .56218 .43163 .55918 .4259 .55361 Mtetra
.4259 .55361 .43163 .55918 .44145 .55617 .43574 .55058 Mtetra
.43574 .55058 .44145 .55617 .45131 .55315 .44562 .54754 Mtetra
.44562 .54754 .45131 .55315 .4612 .55012 .45553 .54449 Mtetra
.45553 .54449 .4612 .55012 .47112 .54707 .46548 .54142 Mtetra
.46548 .54142 .47112 .54707 .48108 .54401 .47547 .53834 Mtetra
.47547 .53834 .48108 .54401 .49108 .54095 .48549 .53526 Mtetra
.48549 .53526 .49108 .54095 .50112 .53787 .49555 .53216 Mtetra
.49555 .53216 .50112 .53787 .51119 .53478 .50564 .52905 Mtetra
.50564 .52905 .51119 .53478 .5213 .53168 .51578 .52592 Mtetra
.51578 .52592 .5213 .53168 .53144 .52857 .52595 .52279 Mtetra
.52595 .52279 .53144 .52857 .54163 .52544 .53616 .51964 Mtetra
.53616 .51964 .54163 .52544 .55185 .52231 .5464 .51649 Mtetra
.5464 .51649 .55185 .52231 .56211 .51916 .55669 .51332 Mtetra
.55669 .51332 .56211 .51916 .57241 .516 .56701 .51014 Mtetra
.56701 .51014 .57241 .516 .58274 .51283 .57737 .50694 Mtetra
.57737 .50694 .58274 .51283 .59312 .50965 .58777 .50374 Mtetra
.58777 .50374 .59312 .50965 .60353 .50645 .59821 .50052 Mtetra
.59821 .50052 .60353 .50645 .61398 .50324 .60869 .49729 Mtetra
.60869 .49729 .61398 .50324 .62448 .50003 .61921 .49405 Mtetra
.61921 .49405 .62448 .50003 .63501 .4968 .62977 .4908 Mtetra
.62977 .4908 .63501 .4968 .64558 .49355 .64037 .48753 Mtetra
.64037 .48753 .64558 .49355 .65619 .4903 .65101 .48426 Mtetra
.65101 .48426 .65619 .4903 .66684 .48703 .66168 .48097 Mtetra
.66168 .48097 .66684 .48703 .67753 .48375 .6724 .47766 Mtetra
.6724 .47766 .67753 .48375 .68826 .48046 .68316 .47435 Mtetra
.68316 .47435 .68826 .48046 .69904 .47715 .69396 .47102 Mtetra
.69396 .47102 .69904 .47715 .70985 .47384 .70481 .46768 Mtetra
.70481 .46768 .70985 .47384 .72071 .47051 .71569 .46433 Mtetra
.71569 .46433 .72071 .47051 .7316 .46716 .72662 .46096 Mtetra
.72662 .46096 .7316 .46716 .74254 .46381 .73758 .45758 Mtetra
.73758 .45758 .74254 .46381 .75352 .46044 .74859 .45419 Mtetra
.74859 .45419 .75352 .46044 .76455 .45706 .75965 .45078 Mtetra
.75965 .45078 .76455 .45706 .77561 .45366 .77074 .44736 Mtetra
.77074 .44736 .77561 .45366 .78672 .45026 .78188 .44393 Mtetra
.78188 .44393 .78672 .45026 .79787 .44684 .79306 .44049 Mtetra
.79306 .44049 .79787 .44684 .80906 .4434 .80429 .43703 Mtetra
.80429 .43703 .80906 .4434 .8203 .43995 .81556 .43355 Mtetra
.81556 .43355 .8203 .43995 .83158 .43649 .82687 .43007 Mtetra
.82687 .43007 .83158 .43649 .84291 .43302 .83823 .42657 Mtetra
.83823 .42657 .84291 .43302 .85428 .42953 .84963 .42306 Mtetra
.84963 .42306 .85428 .42953 .86569 .42603 .86108 .41953 Mtetra
.86108 .41953 .86569 .42603 .87715 .42251 .87257 .41599 Mtetra
.87257 .41599 .87715 .42251 .88866 .41899 .8841 .41243 Mtetra
.8841 .41243 .88866 .41899 .90021 .41544 .89569 .40886 Mtetra
.27639 .59249 .28248 .59781 .2918 .59493 .28574 .5896 Mtetra
.28574 .5896 .2918 .59493 .30116 .59205 .29511 .5867 Mtetra
.29511 .5867 .30116 .59205 .31055 .58916 .30452 .58379 Mtetra
.30452 .58379 .31055 .58916 .31998 .58625 .31397 .58087 Mtetra
.31397 .58087 .31998 .58625 .32943 .58334 .32345 .57793 Mtetra
.32345 .57793 .32943 .58334 .33892 .58041 .33296 .57499 Mtetra
.33296 .57499 .33892 .58041 .34845 .57748 .34251 .57203 Mtetra
.34251 .57203 .34845 .57748 .35801 .57453 .35209 .56907 Mtetra
.35209 .56907 .35801 .57453 .3676 .57158 .3617 .56609 Mtetra
.3617 .56609 .3676 .57158 .37723 .56861 .37135 .56311 Mtetra
.37135 .56311 .37723 .56861 .3869 .56563 .38104 .56011 Mtetra
.38104 .56011 .3869 .56563 .3966 .56264 .39076 .5571 Mtetra
.39076 .5571 .3966 .56264 .40633 .55965 .40052 .55408 Mtetra
.40052 .55408 .40633 .55965 .4161 .55664 .41031 .55105 Mtetra
.41031 .55105 .4161 .55664 .4259 .55361 .42013 .54801 Mtetra
.42013 .54801 .4259 .55361 .43574 .55058 .43 .54496 Mtetra
.43 .54496 .43574 .55058 .44562 .54754 .4399 .54189 Mtetra
.4399 .54189 .44562 .54754 .45553 .54449 .44983 .53882 Mtetra
.44983 .53882 .45553 .54449 .46548 .54142 .4598 .53573 Mtetra
.4598 .53573 .46548 .54142 .47547 .53834 .46981 .53263 Mtetra
.46981 .53263 .47547 .53834 .48549 .53526 .47986 .52952 Mtetra
.47986 .52952 .48549 .53526 .49555 .53216 .48994 .5264 Mtetra
.48994 .5264 .49555 .53216 .50564 .52905 .50006 .52327 Mtetra
.50006 .52327 .50564 .52905 .51578 .52592 .51022 .52013 Mtetra
.51022 .52013 .51578 .52592 .52595 .52279 .52041 .51697 Mtetra
.52041 .51697 .52595 .52279 .53616 .51964 .53065 .51381 Mtetra
.53065 .51381 .53616 .51964 .5464 .51649 .54092 .51063 Mtetra
.54092 .51063 .5464 .51649 .55669 .51332 .55123 .50744 Mtetra
.55123 .50744 .55669 .51332 .56701 .51014 .56158 .50423 Mtetra
.56158 .50423 .56701 .51014 .57737 .50694 .57197 .50102 Mtetra
.57197 .50102 .57737 .50694 .58777 .50374 .58239 .49779 Mtetra
.58239 .49779 .58777 .50374 .59821 .50052 .59286 .49455 Mtetra
.59286 .49455 .59821 .50052 .60869 .49729 .60336 .4913 Mtetra
.60336 .4913 .60869 .49729 .61921 .49405 .61391 .48804 Mtetra
.61391 .48804 .61921 .49405 .62977 .4908 .62449 .48476 Mtetra
.62449 .48476 .62977 .4908 .64037 .48753 .63512 .48147 Mtetra
.63512 .48147 .64037 .48753 .65101 .48426 .64578 .47817 Mtetra
.64578 .47817 .65101 .48426 .66168 .48097 .65649 .47486 Mtetra
.65649 .47486 .66168 .48097 .6724 .47766 .66724 .47153 Mtetra
.66724 .47153 .6724 .47766 .68316 .47435 .67803 .46819 Mtetra
.67803 .46819 .68316 .47435 .69396 .47102 .68886 .46484 Mtetra
.68886 .46484 .69396 .47102 .70481 .46768 .69973 .46148 Mtetra
.69973 .46148 .70481 .46768 .71569 .46433 .71064 .4581 Mtetra
.71064 .4581 .71569 .46433 .72662 .46096 .72159 .45471 Mtetra
.72159 .45471 .72662 .46096 .73758 .45758 .73259 .45131 Mtetra
.73259 .45131 .73758 .45758 .74859 .45419 .74363 .44789 Mtetra
.74363 .44789 .74859 .45419 .75965 .45078 .75471 .44446 Mtetra
.75471 .44446 .75965 .45078 .77074 .44736 .76584 .44102 Mtetra
.76584 .44102 .77074 .44736 .78188 .44393 .77701 .43756 Mtetra
.77701 .43756 .78188 .44393 .79306 .44049 .78822 .43409 Mtetra
.78822 .43409 .79306 .44049 .80429 .43703 .79948 .43061 Mtetra
.79948 .43061 .80429 .43703 .81556 .43355 .81078 .42711 Mtetra
.81078 .42711 .81556 .43355 .82687 .43007 .82212 .4236 Mtetra
.82212 .4236 .82687 .43007 .83823 .42657 .83351 .42007 Mtetra
.83351 .42007 .83823 .42657 .84963 .42306 .84494 .41653 Mtetra
.84494 .41653 .84963 .42306 .86108 .41953 .85642 .41298 Mtetra
.85642 .41298 .86108 .41953 .87257 .41599 .86795 .40941 Mtetra
.86795 .40941 .87257 .41599 .8841 .41243 .87952 .40583 Mtetra
.87952 .40583 .8841 .41243 .89569 .40886 .89113 .40224 Mtetra
.27027 .58715 .27639 .59249 .28574 .5896 .27963 .58424 Mtetra
.27963 .58424 .28574 .5896 .29511 .5867 .28903 .58132 Mtetra
.28903 .58132 .29511 .5867 .30452 .58379 .29846 .57838 Mtetra
.29846 .57838 .30452 .58379 .31397 .58087 .30792 .57544 Mtetra
.30792 .57544 .31397 .58087 .32345 .57793 .31742 .57249 Mtetra
.31742 .57249 .32345 .57793 .33296 .57499 .32696 .56952 Mtetra
.32696 .56952 .33296 .57499 .34251 .57203 .33652 .56655 Mtetra
.33652 .56655 .34251 .57203 .35209 .56907 .34613 .56357 Mtetra
.34613 .56357 .35209 .56907 .3617 .56609 .35576 .56057 Mtetra
.35576 .56057 .3617 .56609 .37135 .56311 .36543 .55756 Mtetra
.36543 .55756 .37135 .56311 .38104 .56011 .37514 .55455 Mtetra
.37514 .55455 .38104 .56011 .39076 .5571 .38488 .55152 Mtetra
.38488 .55152 .39076 .5571 .40052 .55408 .39466 .54848 Mtetra
.39466 .54848 .40052 .55408 .41031 .55105 .40448 .54543 Mtetra
.40448 .54543 .41031 .55105 .42013 .54801 .41432 .54236 Mtetra
.41432 .54236 .42013 .54801 .43 .54496 .42421 .53929 Mtetra
.42421 .53929 .43 .54496 .4399 .54189 .43413 .53621 Mtetra
.43413 .53621 .4399 .54189 .44983 .53882 .44409 .53311 Mtetra
.44409 .53311 .44983 .53882 .4598 .53573 .45409 .53 Mtetra
.45409 .53 .4598 .53573 .46981 .53263 .46412 .52688 Mtetra
.46412 .52688 .46981 .53263 .47986 .52952 .47419 .52375 Mtetra
.47419 .52375 .47986 .52952 .48994 .5264 .4843 .52061 Mtetra
.4843 .52061 .48994 .5264 .50006 .52327 .49444 .51746 Mtetra
.49444 .51746 .50006 .52327 .51022 .52013 .50462 .51429 Mtetra
.50462 .51429 .51022 .52013 .52041 .51697 .51484 .51112 Mtetra
.51484 .51112 .52041 .51697 .53065 .51381 .5251 .50793 Mtetra
.5251 .50793 .53065 .51381 .54092 .51063 .5354 .50473 Mtetra
.5354 .50473 .54092 .51063 .55123 .50744 .54573 .50151 Mtetra
.54573 .50151 .55123 .50744 .56158 .50423 .55611 .49829 Mtetra
.55611 .49829 .56158 .50423 .57197 .50102 .56652 .49505 Mtetra
.56652 .49505 .57197 .50102 .58239 .49779 .57697 .4918 Mtetra
.57697 .4918 .58239 .49779 .59286 .49455 .58747 .48854 Mtetra
.58747 .48854 .59286 .49455 .60336 .4913 .598 .48527 Mtetra
.598 .48527 .60336 .4913 .61391 .48804 .60857 .48198 Mtetra
.60857 .48198 .61391 .48804 .62449 .48476 .61918 .47868 Mtetra
.61918 .47868 .62449 .48476 .63512 .48147 .62983 .47537 Mtetra
.62983 .47537 .63512 .48147 .64578 .47817 .64053 .47205 Mtetra
.64053 .47205 .64578 .47817 .65649 .47486 .65126 .46871 Mtetra
.65126 .46871 .65649 .47486 .66724 .47153 .66204 .46536 Mtetra
.66204 .46536 .66724 .47153 .67803 .46819 .67285 .462 Mtetra
.67285 .462 .67803 .46819 .68886 .46484 .68371 .45862 Mtetra
.68371 .45862 .68886 .46484 .69973 .46148 .69461 .45523 Mtetra
.69461 .45523 .69973 .46148 .71064 .4581 .70555 .45183 Mtetra
.70555 .45183 .71064 .4581 .72159 .45471 .71654 .44842 Mtetra
.71654 .44842 .72159 .45471 .73259 .45131 .72756 .44499 Mtetra
.72756 .44499 .73259 .45131 .74363 .44789 .73863 .44155 Mtetra
.73863 .44155 .74363 .44789 .75471 .44446 .74974 .43809 Mtetra
.74974 .43809 .75471 .44446 .76584 .44102 .7609 .43462 Mtetra
.7609 .43462 .76584 .44102 .77701 .43756 .7721 .43114 Mtetra
.7721 .43114 .77701 .43756 .78822 .43409 .78334 .42765 Mtetra
.78334 .42765 .78822 .43409 .79948 .43061 .79463 .42414 Mtetra
.79463 .42414 .79948 .43061 .81078 .42711 .80596 .42062 Mtetra
.80596 .42062 .81078 .42711 .82212 .4236 .81734 .41708 Mtetra
.81734 .41708 .82212 .4236 .83351 .42007 .82876 .41353 Mtetra
.82876 .41353 .83351 .42007 .84494 .41653 .84023 .40996 Mtetra
.84023 .40996 .84494 .41653 .85642 .41298 .85174 .40639 Mtetra
.85174 .40639 .85642 .41298 .86795 .40941 .8633 .40279 Mtetra
.8633 .40279 .86795 .40941 .87952 .40583 .8749 .39919 Mtetra
.8749 .39919 .87952 .40583 .89113 .40224 .88655 .39556 Mtetra
.2641 .58177 .27027 .58715 .27963 .58424 .27348 .57884 Mtetra
.27348 .57884 .27963 .58424 .28903 .58132 .2829 .57589 Mtetra
.2829 .57589 .28903 .58132 .29846 .57838 .29235 .57294 Mtetra
.29235 .57294 .29846 .57838 .30792 .57544 .30184 .56998 Mtetra
.30184 .56998 .30792 .57544 .31742 .57249 .31136 .56701 Mtetra
.31136 .56701 .31742 .57249 .32696 .56952 .32091 .56403 Mtetra
.32091 .56403 .32696 .56952 .33652 .56655 .3305 .56103 Mtetra
.3305 .56103 .33652 .56655 .34613 .56357 .34012 .55803 Mtetra
.34012 .55803 .34613 .56357 .35576 .56057 .34978 .55501 Mtetra
.34978 .55501 .35576 .56057 .36543 .55756 .35947 .55198 Mtetra
.35947 .55198 .36543 .55756 .37514 .55455 .3692 .54895 Mtetra
.3692 .54895 .37514 .55455 .38488 .55152 .37897 .5459 Mtetra
.37897 .5459 .38488 .55152 .39466 .54848 .38877 .54284 Mtetra
.38877 .54284 .39466 .54848 .40448 .54543 .3986 .53976 Mtetra
.3986 .53976 .40448 .54543 .41432 .54236 .40848 .53668 Mtetra
.40848 .53668 .41432 .54236 .42421 .53929 .41839 .53359 Mtetra
.41839 .53359 .42421 .53929 .43413 .53621 .42833 .53048 Mtetra
.42833 .53048 .43413 .53621 .44409 .53311 .43831 .52737 Mtetra
.43831 .52737 .44409 .53311 .45409 .53 .44833 .52424 Mtetra
.44833 .52424 .45409 .53 .46412 .52688 .45839 .5211 Mtetra
.45839 .5211 .46412 .52688 .47419 .52375 .46848 .51794 Mtetra
.46848 .51794 .47419 .52375 .4843 .52061 .47861 .51478 Mtetra
.47861 .51478 .4843 .52061 .49444 .51746 .48878 .51161 Mtetra
.48878 .51161 .49444 .51746 .50462 .51429 .49899 .50842 Mtetra
.49899 .50842 .50462 .51429 .51484 .51112 .50923 .50522 Mtetra
.50923 .50522 .51484 .51112 .5251 .50793 .51952 .50201 Mtetra
.51952 .50201 .5251 .50793 .5354 .50473 .52984 .49879 Mtetra
.52984 .49879 .5354 .50473 .54573 .50151 .5402 .49555 Mtetra
.5402 .49555 .54573 .50151 .55611 .49829 .5506 .4923 Mtetra
.5506 .4923 .55611 .49829 .56652 .49505 .56104 .48904 Mtetra
.56104 .48904 .56652 .49505 .57697 .4918 .57152 .48577 Mtetra
.57152 .48577 .57697 .4918 .58747 .48854 .58203 .48249 Mtetra
.58203 .48249 .58747 .48854 .598 .48527 .59259 .47919 Mtetra
.59259 .47919 .598 .48527 .60857 .48198 .60319 .47588 Mtetra
.60319 .47588 .60857 .48198 .61918 .47868 .61383 .47256 Mtetra
.61383 .47256 .61918 .47868 .62983 .47537 .62451 .46922 Mtetra
.62451 .46922 .62983 .47537 .64053 .47205 .63523 .46587 Mtetra
.63523 .46587 .64053 .47205 .65126 .46871 .64599 .46251 Mtetra
.64599 .46251 .65126 .46871 .66204 .46536 .6568 .45914 Mtetra
.6568 .45914 .66204 .46536 .67285 .462 .66764 .45575 Mtetra
.66764 .45575 .67285 .462 .68371 .45862 .67853 .45235 Mtetra
.67853 .45235 .68371 .45862 .69461 .45523 .68946 .44894 Mtetra
.68946 .44894 .69461 .45523 .70555 .45183 .70043 .44552 Mtetra
.70043 .44552 .70555 .45183 .71654 .44842 .71144 .44208 Mtetra
.71144 .44208 .71654 .44842 .72756 .44499 .7225 .43862 Mtetra
.7225 .43862 .72756 .44499 .73863 .44155 .7336 .43516 Mtetra
.7336 .43516 .73863 .44155 .74974 .43809 .74474 .43168 Mtetra
.74474 .43168 .74974 .43809 .7609 .43462 .75593 .42819 Mtetra
.75593 .42819 .7609 .43462 .7721 .43114 .76716 .42468 Mtetra
.76716 .42468 .7721 .43114 .78334 .42765 .77843 .42116 Mtetra
.77843 .42116 .78334 .42765 .79463 .42414 .78975 .41762 Mtetra
.78975 .41762 .79463 .42414 .80596 .42062 .80111 .41408 Mtetra
.80111 .41408 .80596 .42062 .81734 .41708 .81252 .41051 Mtetra
.81252 .41051 .81734 .41708 .82876 .41353 .82397 .40694 Mtetra
.82397 .40694 .82876 .41353 .84023 .40996 .83547 .40335 Mtetra
.83547 .40335 .84023 .40996 .85174 .40639 .84702 .39974 Mtetra
.84702 .39974 .85174 .40639 .8633 .40279 .85861 .39612 Mtetra
.85861 .39612 .8633 .40279 .8749 .39919 .87025 .39249 Mtetra
.87025 .39249 .8749 .39919 .88655 .39556 .88193 .38884 Mtetra
.25789 .57635 .2641 .58177 .27348 .57884 .2673 .5734 Mtetra
.2673 .5734 .27348 .57884 .2829 .57589 .27673 .57044 Mtetra
.27673 .57044 .2829 .57589 .29235 .57294 .2862 .56747 Mtetra
.2862 .56747 .29235 .57294 .30184 .56998 .29571 .56449 Mtetra
.29571 .56449 .30184 .56998 .31136 .56701 .30525 .56149 Mtetra
.30525 .56149 .31136 .56701 .32091 .56403 .31483 .55849 Mtetra
.31483 .55849 .32091 .56403 .3305 .56103 .32444 .55547 Mtetra
.32444 .55547 .3305 .56103 .34012 .55803 .33408 .55245 Mtetra
.33408 .55245 .34012 .55803 .34978 .55501 .34376 .54941 Mtetra
.34376 .54941 .34978 .55501 .35947 .55198 .35348 .54637 Mtetra
.35348 .54637 .35947 .55198 .3692 .54895 .36323 .54331 Mtetra
.36323 .54331 .3692 .54895 .37897 .5459 .37301 .54024 Mtetra
.37301 .54024 .37897 .5459 .38877 .54284 .38284 .53716 Mtetra
.38284 .53716 .38877 .54284 .3986 .53976 .39269 .53406 Mtetra
.39269 .53406 .3986 .53976 .40848 .53668 .40259 .53096 Mtetra
.40259 .53096 .40848 .53668 .41839 .53359 .41252 .52785 Mtetra
.41252 .52785 .41839 .53359 .42833 .53048 .42249 .52472 Mtetra
.42249 .52472 .42833 .53048 .43831 .52737 .43249 .52158 Mtetra
.43249 .52158 .43831 .52737 .44833 .52424 .44254 .51843 Mtetra
.44254 .51843 .44833 .52424 .45839 .5211 .45262 .51527 Mtetra
.45262 .51527 .45839 .5211 .46848 .51794 .46273 .5121 Mtetra
.46273 .5121 .46848 .51794 .47861 .51478 .47289 .50891 Mtetra
.47289 .50891 .47861 .51478 .48878 .51161 .48308 .50571 Mtetra
.48308 .50571 .48878 .51161 .49899 .50842 .49331 .5025 Mtetra
.49331 .5025 .49899 .50842 .50923 .50522 .50358 .49928 Mtetra
.50358 .49928 .50923 .50522 .51952 .50201 .51389 .49605 Mtetra
.51389 .49605 .51952 .50201 .52984 .49879 .52424 .4928 Mtetra
.52424 .4928 .52984 .49879 .5402 .49555 .53463 .48955 Mtetra
.53463 .48955 .5402 .49555 .5506 .4923 .54505 .48627 Mtetra
.54505 .48627 .5506 .4923 .56104 .48904 .55552 .48299 Mtetra
.55552 .48299 .56104 .48904 .57152 .48577 .56602 .4797 Mtetra
.56602 .4797 .57152 .48577 .58203 .48249 .57657 .47639 Mtetra
.57657 .47639 .58203 .48249 .59259 .47919 .58715 .47307 Mtetra
.58715 .47307 .59259 .47919 .60319 .47588 .59778 .46974 Mtetra
.59778 .46974 .60319 .47588 .61383 .47256 .60844 .46639 Mtetra
.60844 .46639 .61383 .47256 .62451 .46922 .61915 .46303 Mtetra
.61915 .46303 .62451 .46922 .63523 .46587 .6299 .45966 Mtetra
.6299 .45966 .63523 .46587 .64599 .46251 .64069 .45628 Mtetra
.64069 .45628 .64599 .46251 .6568 .45914 .65152 .45288 Mtetra
.65152 .45288 .6568 .45914 .66764 .45575 .66239 .44947 Mtetra
.66239 .44947 .66764 .45575 .67853 .45235 .67331 .44604 Mtetra
.67331 .44604 .67853 .45235 .68946 .44894 .68427 .44261 Mtetra
.68427 .44261 .68946 .44894 .70043 .44552 .69527 .43916 Mtetra
.69527 .43916 .70043 .44552 .71144 .44208 .70631 .43569 Mtetra
.70631 .43569 .71144 .44208 .7225 .43862 .7174 .43222 Mtetra
.7174 .43222 .7225 .43862 .7336 .43516 .72853 .42872 Mtetra
.72853 .42872 .7336 .43516 .74474 .43168 .7397 .42522 Mtetra
.7397 .42522 .74474 .43168 .75593 .42819 .75092 .4217 Mtetra
.75092 .4217 .75593 .42819 .76716 .42468 .76218 .41817 Mtetra
.76218 .41817 .76716 .42468 .77843 .42116 .77348 .41462 Mtetra
.77348 .41462 .77843 .42116 .78975 .41762 .78483 .41106 Mtetra
.78483 .41106 .78975 .41762 .80111 .41408 .79623 .40749 Mtetra
.79623 .40749 .80111 .41408 .81252 .41051 .80767 .4039 Mtetra
.80767 .4039 .81252 .41051 .82397 .40694 .81915 .4003 Mtetra
.81915 .4003 .82397 .40694 .83547 .40335 .83069 .39668 Mtetra
.83069 .39668 .83547 .40335 .84702 .39974 .84226 .39305 Mtetra
.84226 .39305 .84702 .39974 .85861 .39612 .85389 .3894 Mtetra
.85389 .3894 .85861 .39612 .87025 .39249 .86556 .38574 Mtetra
.86556 .38574 .87025 .39249 .88193 .38884 .87727 .38207 Mtetra
.25164 .57089 .25789 .57635 .2673 .5734 .26107 .56792 Mtetra
.26107 .56792 .2673 .5734 .27673 .57044 .27052 .56494 Mtetra
.27052 .56494 .27673 .57044 .2862 .56747 .28002 .56195 Mtetra
.28002 .56195 .2862 .56747 .29571 .56449 .28954 .55895 Mtetra
.28954 .55895 .29571 .56449 .30525 .56149 .2991 .55594 Mtetra
.2991 .55594 .30525 .56149 .31483 .55849 .3087 .55292 Mtetra
.3087 .55292 .31483 .55849 .32444 .55547 .31833 .54988 Mtetra
.31833 .54988 .32444 .55547 .33408 .55245 .328 .54684 Mtetra
.328 .54684 .33408 .55245 .34376 .54941 .3377 .54378 Mtetra
.3377 .54378 .34376 .54941 .35348 .54637 .34744 .54071 Mtetra
.34744 .54071 .35348 .54637 .36323 .54331 .35721 .53763 Mtetra
.35721 .53763 .36323 .54331 .37301 .54024 .36702 .53454 Mtetra
.36702 .53454 .37301 .54024 .38284 .53716 .37686 .53144 Mtetra
.37686 .53144 .38284 .53716 .39269 .53406 .38674 .52833 Mtetra
.38674 .52833 .39269 .53406 .40259 .53096 .39666 .5252 Mtetra
.39666 .5252 .40259 .53096 .41252 .52785 .40662 .52206 Mtetra
.40662 .52206 .41252 .52785 .42249 .52472 .41661 .51892 Mtetra
.41661 .51892 .42249 .52472 .43249 .52158 .42664 .51576 Mtetra
.42664 .51576 .43249 .52158 .44254 .51843 .4367 .51258 Mtetra
.4367 .51258 .44254 .51843 .45262 .51527 .44681 .5094 Mtetra
.44681 .5094 .45262 .51527 .46273 .5121 .45695 .50621 Mtetra
.45695 .50621 .46273 .5121 .47289 .50891 .46713 .503 Mtetra
.46713 .503 .47289 .50891 .48308 .50571 .47734 .49978 Mtetra
.47734 .49978 .48308 .50571 .49331 .5025 .4876 .49655 Mtetra
.4876 .49655 .49331 .5025 .50358 .49928 .49789 .4933 Mtetra
.49789 .4933 .50358 .49928 .51389 .49605 .50823 .49005 Mtetra
.50823 .49005 .51389 .49605 .52424 .4928 .5186 .48678 Mtetra
.5186 .48678 .52424 .4928 .53463 .48955 .52901 .4835 Mtetra
.52901 .4835 .53463 .48955 .54505 .48627 .53946 .4802 Mtetra
.53946 .4802 .54505 .48627 .55552 .48299 .54996 .4769 Mtetra
.54996 .4769 .55552 .48299 .56602 .4797 .56049 .47358 Mtetra
.56049 .47358 .56602 .4797 .57657 .47639 .57106 .47025 Mtetra
.57106 .47025 .57657 .47639 .58715 .47307 .58167 .46691 Mtetra
.58167 .46691 .58715 .47307 .59778 .46974 .59232 .46355 Mtetra
.59232 .46355 .59778 .46974 .60844 .46639 .60302 .46018 Mtetra
.60302 .46018 .60844 .46639 .61915 .46303 .61375 .4568 Mtetra
.61375 .4568 .61915 .46303 .6299 .45966 .62453 .4534 Mtetra
.62453 .4534 .6299 .45966 .64069 .45628 .63535 .44999 Mtetra
.63535 .44999 .64069 .45628 .65152 .45288 .64621 .44657 Mtetra
.64621 .44657 .65152 .45288 .66239 .44947 .65711 .44314 Mtetra
.65711 .44314 .66239 .44947 .67331 .44604 .66805 .43969 Mtetra
.66805 .43969 .67331 .44604 .68427 .44261 .67904 .43623 Mtetra
.67904 .43623 .68427 .44261 .69527 .43916 .69007 .43275 Mtetra
.69007 .43275 .69527 .43916 .70631 .43569 .70114 .42926 Mtetra
.70114 .42926 .70631 .43569 .7174 .43222 .71226 .42576 Mtetra
.71226 .42576 .7174 .43222 .72853 .42872 .72342 .42224 Mtetra
.72342 .42224 .72853 .42872 .7397 .42522 .73462 .41871 Mtetra
.73462 .41871 .7397 .42522 .75092 .4217 .74587 .41517 Mtetra
.74587 .41517 .75092 .4217 .76218 .41817 .75716 .41161 Mtetra
.75716 .41161 .76218 .41817 .77348 .41462 .7685 .40804 Mtetra
.7685 .40804 .77348 .41462 .78483 .41106 .77988 .40445 Mtetra
.77988 .40445 .78483 .41106 .79623 .40749 .79131 .40085 Mtetra
.79131 .40085 .79623 .40749 .80767 .4039 .80278 .39724 Mtetra
.80278 .39724 .80767 .4039 .81915 .4003 .8143 .39361 Mtetra
.8143 .39361 .81915 .4003 .83069 .39668 .82586 .38996 Mtetra
.82586 .38996 .83069 .39668 .84226 .39305 .83747 .38631 Mtetra
.83747 .38631 .84226 .39305 .85389 .3894 .84913 .38263 Mtetra
.84913 .38263 .85389 .3894 .86556 .38574 .86083 .37895 Mtetra
.86083 .37895 .86556 .38574 .87727 .38207 .87259 .37524 Mtetra
.24535 .5654 .25164 .57089 .26107 .56792 .2548 .56241 Mtetra
.2548 .56241 .26107 .56792 .27052 .56494 .26427 .55941 Mtetra
.26427 .55941 .27052 .56494 .28002 .56195 .27379 .5564 Mtetra
.27379 .5564 .28002 .56195 .28954 .55895 .28333 .55338 Mtetra
.28333 .55338 .28954 .55895 .2991 .55594 .29292 .55035 Mtetra
.29292 .55035 .2991 .55594 .3087 .55292 .30253 .5473 Mtetra
.30253 .5473 .3087 .55292 .31833 .54988 .31218 .54425 Mtetra
.31218 .54425 .31833 .54988 .328 .54684 .32187 .54118 Mtetra
.32187 .54118 .328 .54684 .3377 .54378 .3316 .53811 Mtetra
.3316 .53811 .3377 .54378 .34744 .54071 .34135 .53502 Mtetra
.34135 .53502 .34744 .54071 .35721 .53763 .35115 .53192 Mtetra
.35115 .53192 .35721 .53763 .36702 .53454 .36098 .52881 Mtetra
.36098 .52881 .36702 .53454 .37686 .53144 .37085 .52568 Mtetra
.37085 .52568 .37686 .53144 .38674 .52833 .38075 .52255 Mtetra
.38075 .52255 .38674 .52833 .39666 .5252 .39069 .5194 Mtetra
.39069 .5194 .39666 .5252 .40662 .52206 .40067 .51624 Mtetra
.40067 .51624 .40662 .52206 .41661 .51892 .41068 .51307 Mtetra
.41068 .51307 .41661 .51892 .42664 .51576 .42074 .50989 Mtetra
.42074 .50989 .42664 .51576 .4367 .51258 .43083 .5067 Mtetra
.43083 .5067 .4367 .51258 .44681 .5094 .44095 .50349 Mtetra
.44095 .50349 .44681 .5094 .45695 .50621 .45112 .50027 Mtetra
.45112 .50027 .45695 .50621 .46713 .503 .46132 .49704 Mtetra
.46132 .49704 .46713 .503 .47734 .49978 .47157 .4938 Mtetra
.47157 .4938 .47734 .49978 .4876 .49655 .48185 .49055 Mtetra
.48185 .49055 .4876 .49655 .49789 .4933 .49217 .48728 Mtetra
.49217 .48728 .49789 .4933 .50823 .49005 .50253 .484 Mtetra
.50253 .484 .50823 .49005 .5186 .48678 .51292 .48071 Mtetra
.51292 .48071 .5186 .48678 .52901 .4835 .52336 .47741 Mtetra
.52336 .47741 .52901 .4835 .53946 .4802 .53384 .47409 Mtetra
.53384 .47409 .53946 .4802 .54996 .4769 .54436 .47076 Mtetra
.54436 .47076 .54996 .4769 .56049 .47358 .55491 .46742 Mtetra
.55491 .46742 .56049 .47358 .57106 .47025 .56551 .46407 Mtetra
.56551 .46407 .57106 .47025 .58167 .46691 .57615 .4607 Mtetra
.57615 .4607 .58167 .46691 .59232 .46355 .58683 .45732 Mtetra
.58683 .45732 .59232 .46355 .60302 .46018 .59755 .45393 Mtetra
.59755 .45393 .60302 .46018 .61375 .4568 .60832 .45052 Mtetra
.60832 .45052 .61375 .4568 .62453 .4534 .61912 .4471 Mtetra
.61912 .4471 .62453 .4534 .63535 .44999 .62997 .44367 Mtetra
.62997 .44367 .63535 .44999 .64621 .44657 .64085 .44022 Mtetra
.64085 .44022 .64621 .44657 .65711 .44314 .65178 .43676 Mtetra
.65178 .43676 .65711 .44314 .66805 .43969 .66276 .43329 Mtetra
.66276 .43329 .66805 .43969 .67904 .43623 .67377 .4298 Mtetra
.67377 .4298 .67904 .43623 .69007 .43275 .68483 .4263 Mtetra
.68483 .4263 .69007 .43275 .70114 .42926 .69594 .42279 Mtetra
.69594 .42279 .70114 .42926 .71226 .42576 .70708 .41926 Mtetra
.70708 .41926 .71226 .42576 .72342 .42224 .71827 .41572 Mtetra
.71827 .41572 .72342 .42224 .73462 .41871 .72951 .41216 Mtetra
.72951 .41216 .73462 .41871 .74587 .41517 .74079 .40859 Mtetra
.74079 .40859 .74587 .41517 .75716 .41161 .75211 .40501 Mtetra
.75211 .40501 .75716 .41161 .7685 .40804 .76348 .40141 Mtetra
.76348 .40141 .7685 .40804 .77988 .40445 .77489 .39779 Mtetra
.77489 .39779 .77988 .40445 .79131 .40085 .78635 .39417 Mtetra
.78635 .39417 .79131 .40085 .80278 .39724 .79786 .39053 Mtetra
.79786 .39053 .80278 .39724 .8143 .39361 .80941 .38687 Mtetra
.80941 .38687 .8143 .39361 .82586 .38996 .821 .3832 Mtetra
.821 .3832 .82586 .38996 .83747 .38631 .83265 .37951 Mtetra
.83265 .37951 .83747 .38631 .84913 .38263 .84434 .37581 Mtetra
.84434 .37581 .84913 .38263 .86083 .37895 .85608 .3721 Mtetra
.85608 .3721 .86083 .37895 .87259 .37524 .86786 .36837 Mtetra
.23902 .55988 .24535 .5654 .2548 .56241 .24848 .55687 Mtetra
.24848 .55687 .2548 .56241 .26427 .55941 .25798 .55385 Mtetra
.25798 .55385 .26427 .55941 .27379 .5564 .26751 .55082 Mtetra
.26751 .55082 .27379 .5564 .28333 .55338 .27708 .54777 Mtetra
.27708 .54777 .28333 .55338 .29292 .55035 .28669 .54472 Mtetra
.28669 .54472 .29292 .55035 .30253 .5473 .29632 .54166 Mtetra
.29632 .54166 .30253 .5473 .31218 .54425 .306 .53858 Mtetra
.306 .53858 .31218 .54425 .32187 .54118 .31571 .53549 Mtetra
.31571 .53549 .32187 .54118 .3316 .53811 .32545 .53239 Mtetra
.32545 .53239 .3316 .53811 .34135 .53502 .33523 .52928 Mtetra
.33523 .52928 .34135 .53502 .35115 .53192 .34505 .52616 Mtetra
.34505 .52616 .35115 .53192 .36098 .52881 .3549 .52303 Mtetra
.3549 .52303 .36098 .52881 .37085 .52568 .36479 .51989 Mtetra
.36479 .51989 .37085 .52568 .38075 .52255 .37472 .51673 Mtetra
.37472 .51673 .38075 .52255 .39069 .5194 .38468 .51356 Mtetra
.38468 .51356 .39069 .5194 .40067 .51624 .39468 .51038 Mtetra
.39468 .51038 .40067 .51624 .41068 .51307 .40472 .50719 Mtetra
.40472 .50719 .41068 .51307 .42074 .50989 .4148 .50399 Mtetra
.4148 .50399 .42074 .50989 .43083 .5067 .42491 .50077 Mtetra
.42491 .50077 .43083 .5067 .44095 .50349 .43506 .49754 Mtetra
.43506 .49754 .44095 .50349 .45112 .50027 .44525 .4943 Mtetra
.44525 .4943 .45112 .50027 .46132 .49704 .45548 .49105 Mtetra
.45548 .49105 .46132 .49704 .47157 .4938 .46575 .48779 Mtetra
.46575 .48779 .47157 .4938 .48185 .49055 .47605 .48451 Mtetra
.47605 .48451 .48185 .49055 .49217 .48728 .4864 .48122 Mtetra
.4864 .48122 .49217 .48728 .50253 .484 .49678 .47792 Mtetra
.49678 .47792 .50253 .484 .51292 .48071 .50721 .4746 Mtetra
.50721 .4746 .51292 .48071 .52336 .47741 .51767 .47128 Mtetra
.51767 .47128 .52336 .47741 .53384 .47409 .52817 .46794 Mtetra
.52817 .46794 .53384 .47409 .54436 .47076 .53872 .46458 Mtetra
.53872 .46458 .54436 .47076 .55491 .46742 .5493 .46122 Mtetra
.5493 .46122 .55491 .46742 .56551 .46407 .55993 .45784 Mtetra
.55993 .45784 .56551 .46407 .57615 .4607 .57059 .45445 Mtetra
.57059 .45445 .57615 .4607 .58683 .45732 .5813 .45104 Mtetra
.5813 .45104 .58683 .45732 .59755 .45393 .59205 .44763 Mtetra
.59205 .44763 .59755 .45393 .60832 .45052 .60284 .4442 Mtetra
.60284 .4442 .60832 .45052 .61912 .4471 .61367 .44075 Mtetra
.61367 .44075 .61912 .4471 .62997 .44367 .62455 .43729 Mtetra
.62455 .43729 .62997 .44367 .64085 .44022 .63546 .43382 Mtetra
.63546 .43382 .64085 .44022 .65178 .43676 .64642 .43034 Mtetra
.64642 .43034 .65178 .43676 .66276 .43329 .65743 .42684 Mtetra
.65743 .42684 .66276 .43329 .67377 .4298 .66847 .42333 Mtetra
.66847 .42333 .67377 .4298 .68483 .4263 .67956 .4198 Mtetra
.67956 .4198 .68483 .4263 .69594 .42279 .69069 .41626 Mtetra
.69069 .41626 .69594 .42279 .70708 .41926 .70187 .41271 Mtetra
.70187 .41271 .70708 .41926 .71827 .41572 .71309 .40914 Mtetra
.71309 .40914 .71827 .41572 .72951 .41216 .72436 .40556 Mtetra
.72436 .40556 .72951 .41216 .74079 .40859 .73566 .40196 Mtetra
.73566 .40196 .74079 .40859 .75211 .40501 .74702 .39835 Mtetra
.74702 .39835 .75211 .40501 .76348 .40141 .75842 .39473 Mtetra
.75842 .39473 .76348 .40141 .77489 .39779 .76987 .39109 Mtetra
.76987 .39109 .77489 .39779 .78635 .39417 .78136 .38743 Mtetra
.78136 .38743 .78635 .39417 .79786 .39053 .79289 .38376 Mtetra
.79289 .38376 .79786 .39053 .80941 .38687 .80448 .38008 Mtetra
.80448 .38008 .80941 .38687 .821 .3832 .81611 .37638 Mtetra
.81611 .37638 .821 .3832 .83265 .37951 .82779 .37267 Mtetra
.82779 .37267 .83265 .37951 .84434 .37581 .83951 .36894 Mtetra
.83951 .36894 .84434 .37581 .85608 .3721 .85128 .3652 Mtetra
.85128 .3652 .85608 .3721 .86786 .36837 .8631 .36144 Mtetra
.23264 .55431 .23902 .55988 .24848 .55687 .24213 .55128 Mtetra
.24213 .55128 .24848 .55687 .25798 .55385 .25165 .54824 Mtetra
.25165 .54824 .25798 .55385 .26751 .55082 .2612 .54519 Mtetra
.2612 .54519 .26751 .55082 .27708 .54777 .27079 .54213 Mtetra
.27079 .54213 .27708 .54777 .28669 .54472 .28041 .53905 Mtetra
.28041 .53905 .28669 .54472 .29632 .54166 .29007 .53597 Mtetra
.29007 .53597 .29632 .54166 .306 .53858 .29977 .53287 Mtetra
.29977 .53287 .306 .53858 .31571 .53549 .3095 .52976 Mtetra
.3095 .52976 .31571 .53549 .32545 .53239 .31926 .52664 Mtetra
.31926 .52664 .32545 .53239 .33523 .52928 .32907 .52351 Mtetra
.32907 .52351 .33523 .52928 .34505 .52616 .33891 .52037 Mtetra
.33891 .52037 .34505 .52616 .3549 .52303 .34878 .51722 Mtetra
.34878 .51722 .3549 .52303 .36479 .51989 .35869 .51405 Mtetra
.35869 .51405 .36479 .51989 .37472 .51673 .36864 .51087 Mtetra
.36864 .51087 .37472 .51673 .38468 .51356 .37863 .50768 Mtetra
.37863 .50768 .38468 .51356 .39468 .51038 .38865 .50448 Mtetra
.38865 .50448 .39468 .51038 .40472 .50719 .39872 .50127 Mtetra
.39872 .50127 .40472 .50719 .4148 .50399 .40882 .49804 Mtetra
.40882 .49804 .4148 .50399 .42491 .50077 .41895 .4948 Mtetra
.41895 .4948 .42491 .50077 .43506 .49754 .42913 .49155 Mtetra
.42913 .49155 .43506 .49754 .44525 .4943 .43934 .48829 Mtetra
.43934 .48829 .44525 .4943 .45548 .49105 .4496 .48501 Mtetra
.4496 .48501 .45548 .49105 .46575 .48779 .45989 .48173 Mtetra
.45989 .48173 .46575 .48779 .47605 .48451 .47022 .47843 Mtetra
.47022 .47843 .47605 .48451 .4864 .48122 .48059 .47511 Mtetra
.48059 .47511 .4864 .48122 .49678 .47792 .491 .47179 Mtetra
.491 .47179 .49678 .47792 .50721 .4746 .50145 .46845 Mtetra
.50145 .46845 .50721 .4746 .51767 .47128 .51194 .4651 Mtetra
.51194 .4651 .51767 .47128 .52817 .46794 .52247 .46174 Mtetra
.52247 .46174 .52817 .46794 .53872 .46458 .53304 .45836 Mtetra
.53304 .45836 .53872 .46458 .5493 .46122 .54365 .45497 Mtetra
.54365 .45497 .5493 .46122 .55993 .45784 .5543 .45157 Mtetra
.5543 .45157 .55993 .45784 .57059 .45445 .565 .44815 Mtetra
.565 .44815 .57059 .45445 .5813 .45104 .57573 .44472 Mtetra
.57573 .44472 .5813 .45104 .59205 .44763 .58651 .44128 Mtetra
.58651 .44128 .59205 .44763 .60284 .4442 .59732 .43783 Mtetra
.59732 .43783 .60284 .4442 .61367 .44075 .60819 .43436 Mtetra
.60819 .43436 .61367 .44075 .62455 .43729 .61909 .43087 Mtetra
.61909 .43087 .62455 .43729 .63546 .43382 .63003 .42738 Mtetra
.63003 .42738 .63546 .43382 .64642 .43034 .64102 .42387 Mtetra
.64102 .42387 .64642 .43034 .65743 .42684 .65205 .42034 Mtetra
.65205 .42034 .65743 .42684 .66847 .42333 .66313 .41681 Mtetra
.66313 .41681 .66847 .42333 .67956 .4198 .67425 .41326 Mtetra
.67425 .41326 .67956 .4198 .69069 .41626 .68541 .40969 Mtetra
.68541 .40969 .69069 .41626 .70187 .41271 .69662 .40611 Mtetra
.69662 .40611 .70187 .41271 .71309 .40914 .70787 .40252 Mtetra
.70787 .40252 .71309 .40914 .72436 .40556 .71917 .39891 Mtetra
.71917 .39891 .72436 .40556 .73566 .40196 .73051 .39529 Mtetra
.73051 .39529 .73566 .40196 .74702 .39835 .74189 .39165 Mtetra
.74189 .39165 .74702 .39835 .75842 .39473 .75332 .388 Mtetra
.75332 .388 .75842 .39473 .76987 .39109 .7648 .38433 Mtetra
.7648 .38433 .76987 .39109 .78136 .38743 .77633 .38065 Mtetra
.77633 .38065 .78136 .38743 .79289 .38376 .7879 .37695 Mtetra
.7879 .37695 .79289 .38376 .80448 .38008 .79951 .37324 Mtetra
.79951 .37324 .80448 .38008 .81611 .37638 .81118 .36952 Mtetra
.81118 .36952 .81611 .37638 .82779 .37267 .82289 .36578 Mtetra
.82289 .36578 .82779 .37267 .83951 .36894 .83465 .36202 Mtetra
.83465 .36202 .83951 .36894 .85128 .3652 .84645 .35825 Mtetra
.84645 .35825 .85128 .3652 .8631 .36144 .85831 .35446 Mtetra
.22623 .54871 .23264 .55431 .24213 .55128 .23573 .54566 Mtetra
.23573 .54566 .24213 .55128 .25165 .54824 .24527 .5426 Mtetra
.24527 .5426 .25165 .54824 .2612 .54519 .25484 .53953 Mtetra
.25484 .53953 .2612 .54519 .27079 .54213 .26445 .53644 Mtetra
.26445 .53644 .27079 .54213 .28041 .53905 .2741 .53335 Mtetra
.2741 .53335 .28041 .53905 .29007 .53597 .28378 .53024 Mtetra
.28378 .53024 .29007 .53597 .29977 .53287 .2935 .52712 Mtetra
.2935 .52712 .29977 .53287 .3095 .52976 .30325 .524 Mtetra
.30325 .524 .3095 .52976 .31926 .52664 .31304 .52085 Mtetra
.31304 .52085 .31926 .52664 .32907 .52351 .32286 .5177 Mtetra
.32286 .5177 .32907 .52351 .33891 .52037 .33272 .51454 Mtetra
.33272 .51454 .33891 .52037 .34878 .51722 .34262 .51136 Mtetra
.34262 .51136 .34878 .51722 .35869 .51405 .35256 .50817 Mtetra
.35256 .50817 .35869 .51405 .36864 .51087 .36253 .50497 Mtetra
.36253 .50497 .36864 .51087 .37863 .50768 .37254 .50176 Mtetra
.37254 .50176 .37863 .50768 .38865 .50448 .38258 .49854 Mtetra
.38258 .49854 .38865 .50448 .39872 .50127 .39267 .4953 Mtetra
.39267 .4953 .39872 .50127 .40882 .49804 .40279 .49205 Mtetra
.40279 .49205 .40882 .49804 .41895 .4948 .41295 .48879 Mtetra
.41295 .48879 .41895 .4948 .42913 .49155 .42315 .48552 Mtetra
.42315 .48552 .42913 .49155 .43934 .48829 .43339 .48223 Mtetra
.43339 .48223 .43934 .48829 .4496 .48501 .44367 .47893 Mtetra
.44367 .47893 .4496 .48501 .45989 .48173 .45399 .47562 Mtetra
.45399 .47562 .45989 .48173 .47022 .47843 .46434 .4723 Mtetra
.46434 .4723 .47022 .47843 .48059 .47511 .47474 .46897 Mtetra
.47474 .46897 .48059 .47511 .491 .47179 .48517 .46562 Mtetra
.48517 .46562 .491 .47179 .50145 .46845 .49565 .46226 Mtetra
.49565 .46226 .50145 .46845 .51194 .4651 .50617 .45888 Mtetra
.50617 .45888 .51194 .4651 .52247 .46174 .51672 .45549 Mtetra
.51672 .45549 .52247 .46174 .53304 .45836 .52732 .45209 Mtetra
.52732 .45209 .53304 .45836 .54365 .45497 .53796 .44868 Mtetra
.53796 .44868 .54365 .45497 .5543 .45157 .54864 .44525 Mtetra
.54864 .44525 .5543 .45157 .565 .44815 .55936 .44181 Mtetra
.55936 .44181 .565 .44815 .57573 .44472 .57012 .43836 Mtetra
.57012 .43836 .57573 .44472 .58651 .44128 .58092 .43489 Mtetra
.58092 .43489 .58651 .44128 .59732 .43783 .59177 .43141 Mtetra
.59177 .43141 .59732 .43783 .60819 .43436 .60266 .42792 Mtetra
.60266 .42792 .60819 .43436 .61909 .43087 .61359 .42441 Mtetra
.61359 .42441 .61909 .43087 .63003 .42738 .62456 .42089 Mtetra
.62456 .42089 .63003 .42738 .64102 .42387 .63558 .41735 Mtetra
.63558 .41735 .64102 .42387 .65205 .42034 .64664 .4138 Mtetra
.64664 .4138 .65205 .42034 .66313 .41681 .65775 .41024 Mtetra
.65775 .41024 .66313 .41681 .67425 .41326 .6689 .40666 Mtetra
.6689 .40666 .67425 .41326 .68541 .40969 .68009 .40307 Mtetra
.68009 .40307 .68541 .40969 .69662 .40611 .69133 .39946 Mtetra
.69133 .39946 .69662 .40611 .70787 .40252 .70261 .39584 Mtetra
.70261 .39584 .70787 .40252 .71917 .39891 .71394 .39221 Mtetra
.71394 .39221 .71917 .39891 .73051 .39529 .72531 .38856 Mtetra
.72531 .38856 .73051 .39529 .74189 .39165 .73673 .3849 Mtetra
.73673 .3849 .74189 .39165 .75332 .388 .74819 .38122 Mtetra
.74819 .38122 .75332 .388 .7648 .38433 .7597 .37752 Mtetra
.7597 .37752 .7648 .38433 .77633 .38065 .77126 .37381 Mtetra
.77126 .37381 .77633 .38065 .7879 .37695 .78286 .37009 Mtetra
.78286 .37009 .7879 .37695 .79951 .37324 .79451 .36635 Mtetra
.79451 .36635 .79951 .37324 .81118 .36952 .80621 .3626 Mtetra
.80621 .3626 .81118 .36952 .82289 .36578 .81795 .35883 Mtetra
.81795 .35883 .82289 .36578 .83465 .36202 .82975 .35505 Mtetra
.82975 .35505 .83465 .36202 .84645 .35825 .84159 .35125 Mtetra
.84159 .35125 .84645 .35825 .85831 .35446 .85348 .34743 Mtetra
.21976 .54307 .22623 .54871 .23573 .54566 .22929 .54 Mtetra
.22929 .54 .23573 .54566 .24527 .5426 .23885 .53692 Mtetra
.23885 .53692 .24527 .5426 .25484 .53953 .24844 .53383 Mtetra
.24844 .53383 .25484 .53953 .26445 .53644 .25807 .53072 Mtetra
.25807 .53072 .26445 .53644 .2741 .53335 .26774 .52761 Mtetra
.26774 .52761 .2741 .53335 .28378 .53024 .27744 .52448 Mtetra
.27744 .52448 .28378 .53024 .2935 .52712 .28718 .52134 Mtetra
.28718 .52134 .2935 .52712 .30325 .524 .29695 .51819 Mtetra
.29695 .51819 .30325 .524 .31304 .52085 .30676 .51502 Mtetra
.30676 .51502 .31304 .52085 .32286 .5177 .31661 .51185 Mtetra
.31661 .51185 .32286 .5177 .33272 .51454 .3265 .50866 Mtetra
.3265 .50866 .33272 .51454 .34262 .51136 .33642 .50547 Mtetra
.33642 .50547 .34262 .51136 .35256 .50817 .34637 .50226 Mtetra
.34637 .50226 .35256 .50817 .36253 .50497 .35637 .49903 Mtetra
.35637 .49903 .36253 .50497 .37254 .50176 .3664 .4958 Mtetra
.3664 .4958 .37254 .50176 .38258 .49854 .37647 .49255 Mtetra
.37647 .49255 .38258 .49854 .39267 .4953 .38658 .48929 Mtetra
.38658 .48929 .39267 .4953 .40279 .49205 .39673 .48602 Mtetra
.39673 .48602 .40279 .49205 .41295 .48879 .40691 .48274 Mtetra
.40691 .48274 .41295 .48879 .42315 .48552 .41714 .47944 Mtetra
.41714 .47944 .42315 .48552 .43339 .48223 .4274 .47613 Mtetra
.4274 .47613 .43339 .48223 .44367 .47893 .4377 .47281 Mtetra
.4377 .47281 .44367 .47893 .45399 .47562 .44805 .46948 Mtetra
.44805 .46948 .45399 .47562 .46434 .4723 .45843 .46613 Mtetra
.45843 .46613 .46434 .4723 .47474 .46897 .46885 .46277 Mtetra
.46885 .46277 .47474 .46897 .48517 .46562 .47931 .4594 Mtetra
.47931 .4594 .48517 .46562 .49565 .46226 .48981 .45602 Mtetra
.48981 .45602 .49565 .46226 .50617 .45888 .50035 .45262 Mtetra
.50035 .45262 .50617 .45888 .51672 .45549 .51093 .44921 Mtetra
.51093 .44921 .51672 .45549 .52732 .45209 .52156 .44578 Mtetra
.52156 .44578 .52732 .45209 .53796 .44868 .53222 .44234 Mtetra
.53222 .44234 .53796 .44868 .54864 .44525 .54293 .43889 Mtetra
.54293 .43889 .54864 .44525 .55936 .44181 .55368 .43543 Mtetra
.55368 .43543 .55936 .44181 .57012 .43836 .56447 .43195 Mtetra
.56447 .43195 .57012 .43836 .58092 .43489 .5753 .42846 Mtetra
.5753 .42846 .58092 .43489 .59177 .43141 .58617 .42495 Mtetra
.58617 .42495 .59177 .43141 .60266 .42792 .59709 .42143 Mtetra
.59709 .42143 .60266 .42792 .61359 .42441 .60805 .4179 Mtetra
.60805 .4179 .61359 .42441 .62456 .42089 .61906 .41435 Mtetra
.61906 .41435 .62456 .42089 .63558 .41735 .6301 .41079 Mtetra
.6301 .41079 .63558 .41735 .64664 .4138 .64119 .40721 Mtetra
.64119 .40721 .64664 .4138 .65775 .41024 .65233 .40362 Mtetra
.65233 .40362 .65775 .41024 .6689 .40666 .66351 .40002 Mtetra
.66351 .40002 .6689 .40666 .68009 .40307 .67473 .3964 Mtetra
.67473 .3964 .68009 .40307 .69133 .39946 .686 .39277 Mtetra
.686 .39277 .69133 .39946 .70261 .39584 .69731 .38912 Mtetra
.69731 .38912 .70261 .39584 .71394 .39221 .70867 .38546 Mtetra
.70867 .38546 .71394 .39221 .72531 .38856 .72007 .38178 Mtetra
.72007 .38178 .72531 .38856 .73673 .3849 .73152 .37809 Mtetra
.73152 .37809 .73673 .3849 .74819 .38122 .74302 .37439 Mtetra
.74302 .37439 .74819 .38122 .7597 .37752 .75456 .37067 Mtetra
.75456 .37067 .7597 .37752 .77126 .37381 .76615 .36693 Mtetra
.76615 .36693 .77126 .37381 .78286 .37009 .77779 .36318 Mtetra
.77779 .36318 .78286 .37009 .79451 .36635 .78947 .35941 Mtetra
.78947 .35941 .79451 .36635 .80621 .3626 .8012 .35563 Mtetra
.8012 .35563 .80621 .3626 .81795 .35883 .81298 .35183 Mtetra
.81298 .35183 .81795 .35883 .82975 .35505 .82481 .34802 Mtetra
.82481 .34802 .82975 .35505 .84159 .35125 .83668 .34419 Mtetra
.83668 .34419 .84159 .35125 .85348 .34743 .84861 .34035 Mtetra
.21326 .53739 .21976 .54307 .22929 .54 .2228 .5343 Mtetra
.2228 .5343 .22929 .54 .23885 .53692 .23238 .5312 Mtetra
.23238 .5312 .23885 .53692 .24844 .53383 .242 .52809 Mtetra
.242 .52809 .24844 .53383 .25807 .53072 .25165 .52496 Mtetra
.25165 .52496 .25807 .53072 .26774 .52761 .26134 .52182 Mtetra
.26134 .52182 .26774 .52761 .27744 .52448 .27106 .51867 Mtetra
.27106 .51867 .27744 .52448 .28718 .52134 .28082 .51551 Mtetra
.28082 .51551 .28718 .52134 .29695 .51819 .29062 .51234 Mtetra
.29062 .51234 .29695 .51819 .30676 .51502 .30045 .50915 Mtetra
.30045 .50915 .30676 .51502 .31661 .51185 .31032 .50596 Mtetra
.31032 .50596 .31661 .51185 .3265 .50866 .32022 .50275 Mtetra
.32022 .50275 .3265 .50866 .33642 .50547 .33017 .49953 Mtetra
.33017 .49953 .33642 .50547 .34637 .50226 .34015 .4963 Mtetra
.34015 .4963 .34637 .50226 .35637 .49903 .35017 .49305 Mtetra
.35017 .49305 .35637 .49903 .3664 .4958 .36022 .4898 Mtetra
.36022 .4898 .3664 .4958 .37647 .49255 .37032 .48653 Mtetra
.37032 .48653 .37647 .49255 .38658 .48929 .38045 .48324 Mtetra
.38045 .48324 .38658 .48929 .39673 .48602 .39062 .47995 Mtetra
.39062 .47995 .39673 .48602 .40691 .48274 .40083 .47664 Mtetra
.40083 .47664 .40691 .48274 .41714 .47944 .41108 .47332 Mtetra
.41108 .47332 .41714 .47944 .4274 .47613 .42137 .46999 Mtetra
.42137 .46999 .4274 .47613 .4377 .47281 .43169 .46665 Mtetra
.43169 .46665 .4377 .47281 .44805 .46948 .44206 .46329 Mtetra
.44206 .46329 .44805 .46948 .45843 .46613 .45247 .45992 Mtetra
.45247 .45992 .45843 .46613 .46885 .46277 .46291 .45654 Mtetra
.46291 .45654 .46885 .46277 .47931 .4594 .4734 .45314 Mtetra
.4734 .45314 .47931 .4594 .48981 .45602 .48393 .44973 Mtetra
.48393 .44973 .48981 .45602 .50035 .45262 .4945 .44631 Mtetra
.4945 .44631 .50035 .45262 .51093 .44921 .50511 .44287 Mtetra
.50511 .44287 .51093 .44921 .52156 .44578 .51576 .43942 Mtetra
.51576 .43942 .52156 .44578 .53222 .44234 .52645 .43596 Mtetra
.52645 .43596 .53222 .44234 .54293 .43889 .53718 .43248 Mtetra
.53718 .43248 .54293 .43889 .55368 .43543 .54796 .42899 Mtetra
.54796 .42899 .55368 .43543 .56447 .43195 .55878 .42549 Mtetra
.55878 .42549 .56447 .43195 .5753 .42846 .56964 .42197 Mtetra
.56964 .42197 .5753 .42846 .58617 .42495 .58054 .41844 Mtetra
.58054 .41844 .58617 .42495 .59709 .42143 .59149 .4149 Mtetra
.59149 .4149 .59709 .42143 .60805 .4179 .60247 .41134 Mtetra
.60247 .41134 .60805 .4179 .61906 .41435 .61351 .40776 Mtetra
.61351 .40776 .61906 .41435 .6301 .41079 .62458 .40418 Mtetra
.62458 .40418 .6301 .41079 .64119 .40721 .6357 .40057 Mtetra
.6357 .40057 .64119 .40721 .65233 .40362 .64687 .39696 Mtetra
.64687 .39696 .65233 .40362 .66351 .40002 .65808 .39333 Mtetra
.65808 .39333 .66351 .40002 .67473 .3964 .66933 .38968 Mtetra
.66933 .38968 .67473 .3964 .686 .39277 .68063 .38602 Mtetra
.68063 .38602 .686 .39277 .69731 .38912 .69198 .38235 Mtetra
.69198 .38235 .69731 .38912 .70867 .38546 .70336 .37866 Mtetra
.70336 .37866 .70867 .38546 .72007 .38178 .7148 .37496 Mtetra
.7148 .37496 .72007 .38178 .73152 .37809 .72628 .37124 Mtetra
.72628 .37124 .73152 .37809 .74302 .37439 .73781 .3675 Mtetra
.73781 .3675 .74302 .37439 .75456 .37067 .74939 .36376 Mtetra
.74939 .36376 .75456 .37067 .76615 .36693 .76101 .35999 Mtetra
.76101 .35999 .76615 .36693 .77779 .36318 .77268 .35621 Mtetra
.77268 .35621 .77779 .36318 .78947 .35941 .78439 .35242 Mtetra
.78439 .35242 .78947 .35941 .8012 .35563 .79616 .34861 Mtetra
.79616 .34861 .8012 .35563 .81298 .35183 .80797 .34478 Mtetra
.80797 .34478 .81298 .35183 .82481 .34802 .81983 .34094 Mtetra
.81983 .34094 .82481 .34802 .83668 .34419 .83174 .33708 Mtetra
.83174 .33708 .83668 .34419 .84861 .34035 .8437 .33321 Mtetra
.20671 .53168 .21326 .53739 .2228 .5343 .21627 .52857 Mtetra
.21627 .52857 .2228 .5343 .23238 .5312 .22588 .52544 Mtetra
.22588 .52544 .23238 .5312 .242 .52809 .23551 .52231 Mtetra
.23551 .52231 .242 .52809 .25165 .52496 .24519 .51916 Mtetra
.24519 .51916 .25165 .52496 .26134 .52182 .25489 .516 Mtetra
.25489 .516 .26134 .52182 .27106 .51867 .26464 .51283 Mtetra
.26464 .51283 .27106 .51867 .28082 .51551 .27442 .50965 Mtetra
.27442 .50965 .28082 .51551 .29062 .51234 .28424 .50645 Mtetra
.28424 .50645 .29062 .51234 .30045 .50915 .29409 .50325 Mtetra
.29409 .50325 .30045 .50915 .31032 .50596 .30398 .50003 Mtetra
.30398 .50003 .31032 .50596 .32022 .50275 .31391 .4968 Mtetra
.31391 .4968 .32022 .50275 .33017 .49953 .32388 .49355 Mtetra
.32388 .49355 .33017 .49953 .34015 .4963 .33388 .4903 Mtetra
.33388 .4903 .34015 .4963 .35017 .49305 .34392 .48703 Mtetra
.34392 .48703 .35017 .49305 .36022 .4898 .354 .48375 Mtetra
.354 .48375 .36022 .4898 .37032 .48653 .36412 .48046 Mtetra
.36412 .48046 .37032 .48653 .38045 .48324 .37428 .47715 Mtetra
.37428 .47715 .38045 .48324 .39062 .47995 .38447 .47384 Mtetra
.38447 .47384 .39062 .47995 .40083 .47664 .3947 .47051 Mtetra
.3947 .47051 .40083 .47664 .41108 .47332 .40498 .46716 Mtetra
.40498 .46716 .41108 .47332 .42137 .46999 .41529 .46381 Mtetra
.41529 .46381 .42137 .46999 .43169 .46665 .42564 .46044 Mtetra
.42564 .46044 .43169 .46665 .44206 .46329 .43603 .45706 Mtetra
.43603 .45706 .44206 .46329 .45247 .45992 .44647 .45366 Mtetra
.44647 .45366 .45247 .45992 .46291 .45654 .45694 .45026 Mtetra
.45694 .45026 .46291 .45654 .4734 .45314 .46745 .44684 Mtetra
.46745 .44684 .4734 .45314 .48393 .44973 .47801 .4434 Mtetra
.47801 .4434 .48393 .44973 .4945 .44631 .4886 .43995 Mtetra
.4886 .43995 .4945 .44631 .50511 .44287 .49924 .43649 Mtetra
.49924 .43649 .50511 .44287 .51576 .43942 .50991 .43302 Mtetra
.50991 .43302 .51576 .43942 .52645 .43596 .52063 .42953 Mtetra
.52063 .42953 .52645 .43596 .53718 .43248 .53139 .42603 Mtetra
.53139 .42603 .53718 .43248 .54796 .42899 .5422 .42251 Mtetra
.5422 .42251 .54796 .42899 .55878 .42549 .55304 .41899 Mtetra
.55304 .41899 .55878 .42549 .56964 .42197 .56393 .41544 Mtetra
.56393 .41544 .56964 .42197 .58054 .41844 .57486 .41189 Mtetra
.57486 .41189 .58054 .41844 .59149 .4149 .58584 .40831 Mtetra
.58584 .40831 .59149 .4149 .60247 .41134 .59686 .40473 Mtetra
.59686 .40473 .60247 .41134 .61351 .40776 .60792 .40113 Mtetra
.60792 .40113 .61351 .40776 .62458 .40418 .61902 .39752 Mtetra
.61902 .39752 .62458 .40418 .6357 .40057 .63017 .39389 Mtetra
.63017 .39389 .6357 .40057 .64687 .39696 .64137 .39025 Mtetra
.64137 .39025 .64687 .39696 .65808 .39333 .65261 .38659 Mtetra
.65261 .38659 .65808 .39333 .66933 .38968 .66389 .38292 Mtetra
.66389 .38292 .66933 .38968 .68063 .38602 .67522 .37923 Mtetra
.67522 .37923 .68063 .38602 .69198 .38235 .6866 .37553 Mtetra
.6866 .37553 .69198 .38235 .70336 .37866 .69802 .37181 Mtetra
.69802 .37181 .70336 .37866 .7148 .37496 .70949 .36808 Mtetra
.70949 .36808 .7148 .37496 .72628 .37124 .721 .36433 Mtetra
.721 .36433 .72628 .37124 .73781 .3675 .73256 .36057 Mtetra
.73256 .36057 .73781 .3675 .74939 .36376 .74417 .3568 Mtetra
.74417 .3568 .74939 .36376 .76101 .35999 .75583 .353 Mtetra
.75583 .353 .76101 .35999 .77268 .35621 .76753 .3492 Mtetra
.76753 .3492 .77268 .35621 .78439 .35242 .77928 .34537 Mtetra
.77928 .34537 .78439 .35242 .79616 .34861 .79108 .34153 Mtetra
.79108 .34153 .79616 .34861 .80797 .34478 .80293 .33768 Mtetra
.80293 .33768 .80797 .34478 .81983 .34094 .81482 .33381 Mtetra
.81482 .33381 .81983 .34094 .83174 .33708 .82677 .32992 Mtetra
.82677 .32992 .83174 .33708 .8437 .33321 .83876 .32602 Mtetra
.20012 .52592 .20671 .53168 .21627 .52857 .2097 .52279 Mtetra
.2097 .52279 .21627 .52857 .22588 .52544 .21932 .51965 Mtetra
.21932 .51965 .22588 .52544 .23551 .52231 .22898 .51649 Mtetra
.656 .752 .92 r
.22898 .51649 .23551 .52231 .24519 .51916 .23867 .51332 Mtetra
.656 .751 .92 r
.23867 .51332 .24519 .51916 .25489 .516 .2484 .51014 Mtetra
.2484 .51014 .25489 .516 .26464 .51283 .25817 .50695 Mtetra
.25817 .50695 .26464 .51283 .27442 .50965 .26797 .50374 Mtetra
.26797 .50374 .27442 .50965 .28424 .50645 .27781 .50052 Mtetra
.27781 .50052 .28424 .50645 .29409 .50325 .28769 .49729 Mtetra
.28769 .49729 .29409 .50325 .30398 .50003 .2976 .49405 Mtetra
.2976 .49405 .30398 .50003 .31391 .4968 .30755 .4908 Mtetra
.30755 .4908 .31391 .4968 .32388 .49355 .31754 .48753 Mtetra
.31754 .48753 .32388 .49355 .33388 .4903 .32757 .48425 Mtetra
.32757 .48425 .33388 .4903 .34392 .48703 .33763 .48096 Mtetra
.33763 .48096 .34392 .48703 .354 .48375 .34774 .47766 Mtetra
.34774 .47766 .354 .48375 .36412 .48046 .35788 .47434 Mtetra
.35788 .47434 .36412 .48046 .37428 .47715 .36806 .47102 Mtetra
.36806 .47102 .37428 .47715 .38447 .47384 .37828 .46768 Mtetra
.37828 .46768 .38447 .47384 .3947 .47051 .38854 .46432 Mtetra
.38854 .46432 .3947 .47051 .40498 .46716 .39883 .46096 Mtetra
.39883 .46096 .40498 .46716 .41529 .46381 .40917 .45758 Mtetra
.40917 .45758 .41529 .46381 .42564 .46044 .41955 .45419 Mtetra
.41955 .45419 .42564 .46044 .43603 .45706 .42997 .45078 Mtetra
.42997 .45078 .43603 .45706 .44647 .45366 .44042 .44736 Mtetra
.44042 .44736 .44647 .45366 .45694 .45026 .45092 .44393 Mtetra
.45092 .44393 .45694 .45026 .46745 .44684 .46146 .44048 Mtetra
.46146 .44048 .46745 .44684 .47801 .4434 .47204 .43703 Mtetra
.47204 .43703 .47801 .4434 .4886 .43995 .48266 .43355 Mtetra
.48266 .43355 .4886 .43995 .49924 .43649 .49332 .43007 Mtetra
.49332 .43007 .49924 .43649 .50991 .43302 .50403 .42657 Mtetra
.50403 .42657 .50991 .43302 .52063 .42953 .51477 .42306 Mtetra
.51477 .42306 .52063 .42953 .53139 .42603 .52556 .41953 Mtetra
.52556 .41953 .53139 .42603 .5422 .42251 .53639 .41599 Mtetra
.53639 .41599 .5422 .42251 .55304 .41899 .54727 .41243 Mtetra
.54727 .41243 .55304 .41899 .56393 .41544 .55818 .40886 Mtetra
.55818 .40886 .56393 .41544 .57486 .41189 .56914 .40528 Mtetra
.56914 .40528 .57486 .41189 .58584 .40831 .58015 .40168 Mtetra
.58015 .40168 .58584 .40831 .59686 .40473 .5912 .39807 Mtetra
.5912 .39807 .59686 .40473 .60792 .40113 .60229 .39445 Mtetra
.60229 .39445 .60792 .40113 .61902 .39752 .61342 .3908 Mtetra
.61342 .3908 .61902 .39752 .63017 .39389 .6246 .38715 Mtetra
.6246 .38715 .63017 .39389 .64137 .39025 .63583 .38348 Mtetra
.63583 .38348 .64137 .39025 .65261 .38659 .6471 .37979 Mtetra
.6471 .37979 .65261 .38659 .66389 .38292 .65841 .3761 Mtetra
.65841 .3761 .66389 .38292 .67522 .37923 .66977 .37238 Mtetra
.66977 .37238 .67522 .37923 .6866 .37553 .68118 .36865 Mtetra
.68118 .36865 .6866 .37553 .69802 .37181 .69263 .36491 Mtetra
.69263 .36491 .69802 .37181 .70949 .36808 .70413 .36115 Mtetra
.70413 .36115 .70949 .36808 .721 .36433 .71568 .35737 Mtetra
.71568 .35737 .721 .36433 .73256 .36057 .72727 .35358 Mtetra
.72727 .35358 .73256 .36057 .74417 .3568 .73892 .34978 Mtetra
.73892 .34978 .74417 .3568 .75583 .353 .7506 .34596 Mtetra
.7506 .34596 .75583 .353 .76753 .3492 .76234 .34212 Mtetra
.76234 .34212 .76753 .3492 .77928 .34537 .77413 .33827 Mtetra
.77413 .33827 .77928 .34537 .79108 .34153 .78596 .33441 Mtetra
.78596 .33441 .79108 .34153 .80293 .33768 .79784 .33052 Mtetra
.656 .752 .92 r
.79784 .33052 .80293 .33768 .81482 .33381 .80977 .32662 Mtetra
.80977 .32662 .81482 .33381 .82677 .32992 .82175 .3227 Mtetra
.82175 .3227 .82677 .32992 .83876 .32602 .83378 .31877 Mtetra
.655 .751 .921 r
.19348 .52013 .20012 .52592 .2097 .52279 .20308 .51699 Mtetra
.655 .752 .921 r
.20308 .51699 .2097 .52279 .21932 .51965 .21272 .51383 Mtetra
.656 .752 .921 r
.21272 .51383 .21932 .51965 .22898 .51649 .2224 .51066 Mtetra
.2224 .51066 .22898 .51649 .23867 .51332 .23212 .50747 Mtetra
.23212 .50747 .23867 .51332 .2484 .51014 .24187 .50426 Mtetra
.24187 .50426 .2484 .51014 .25817 .50695 .25165 .50105 Mtetra
.25165 .50105 .25817 .50695 .26797 .50374 .26148 .49781 Mtetra
.26148 .49781 .26797 .50374 .27781 .50052 .27134 .49457 Mtetra
.27134 .49457 .27781 .50052 .28769 .49729 .28124 .49132 Mtetra
.28124 .49132 .28769 .49729 .2976 .49405 .29118 .48805 Mtetra
.29118 .48805 .2976 .49405 .30755 .4908 .30115 .48477 Mtetra
.30115 .48477 .30755 .4908 .31754 .48753 .31116 .48148 Mtetra
.656 .752 .92 r
.31116 .48148 .31754 .48753 .32757 .48425 .32121 .47818 Mtetra
.32121 .47818 .32757 .48425 .33763 .48096 .3313 .47486 Mtetra
.3313 .47486 .33763 .48096 .34774 .47766 .34143 .47153 Mtetra
.34143 .47153 .34774 .47766 .35788 .47434 .35159 .46819 Mtetra
.35159 .46819 .35788 .47434 .36806 .47102 .3618 .46484 Mtetra
.3618 .46484 .36806 .47102 .37828 .46768 .37204 .46148 Mtetra
.656 .751 .92 r
.37204 .46148 .37828 .46768 .38854 .46432 .38232 .4581 Mtetra
.38232 .4581 .38854 .46432 .39883 .46096 .39264 .45471 Mtetra
.39264 .45471 .39883 .46096 .40917 .45758 .40301 .45131 Mtetra
.40301 .45131 .40917 .45758 .41955 .45419 .41341 .44789 Mtetra
.41341 .44789 .41955 .45419 .42997 .45078 .42385 .44446 Mtetra
.42385 .44446 .42997 .45078 .44042 .44736 .43434 .44102 Mtetra
.43434 .44102 .44042 .44736 .45092 .44393 .44486 .43756 Mtetra
.44486 .43756 .45092 .44393 .46146 .44048 .45542 .43409 Mtetra
.45542 .43409 .46146 .44048 .47204 .43703 .46603 .43061 Mtetra
.46603 .43061 .47204 .43703 .48266 .43355 .47668 .42711 Mtetra
.47668 .42711 .48266 .43355 .49332 .43007 .48737 .4236 Mtetra
.48737 .4236 .49332 .43007 .50403 .42657 .4981 .42007 Mtetra
.4981 .42007 .50403 .42657 .51477 .42306 .50887 .41653 Mtetra
.50887 .41653 .51477 .42306 .52556 .41953 .51969 .41298 Mtetra
.51969 .41298 .52556 .41953 .53639 .41599 .53055 .40941 Mtetra
.53055 .40941 .53639 .41599 .54727 .41243 .54145 .40583 Mtetra
.54145 .40583 .54727 .41243 .55818 .40886 .5524 .40224 Mtetra
.5524 .40224 .55818 .40886 .56914 .40528 .56338 .39863 Mtetra
.56338 .39863 .56914 .40528 .58015 .40168 .57442 .39501 Mtetra
.57442 .39501 .58015 .40168 .5912 .39807 .58549 .39137 Mtetra
.58549 .39137 .5912 .39807 .60229 .39445 .59661 .38771 Mtetra
.59661 .38771 .60229 .39445 .61342 .3908 .60778 .38405 Mtetra
.60778 .38405 .61342 .3908 .6246 .38715 .61899 .38037 Mtetra
.61899 .38037 .6246 .38715 .63583 .38348 .63025 .37667 Mtetra
.63025 .37667 .63583 .38348 .6471 .37979 .64155 .37296 Mtetra
.656 .752 .92 r
.64155 .37296 .6471 .37979 .65841 .3761 .65289 .36923 Mtetra
.65289 .36923 .65841 .3761 .66977 .37238 .66429 .36549 Mtetra
.66429 .36549 .66977 .37238 .68118 .36865 .67572 .36174 Mtetra
.67572 .36174 .68118 .36865 .69263 .36491 .68721 .35797 Mtetra
.656 .752 .921 r
.68721 .35797 .69263 .36491 .70413 .36115 .69874 .35418 Mtetra
.69874 .35418 .70413 .36115 .71568 .35737 .71032 .35038 Mtetra
.71032 .35038 .71568 .35737 .72727 .35358 .72195 .34656 Mtetra
.72195 .34656 .72727 .35358 .73892 .34978 .73362 .34273 Mtetra
.73362 .34273 .73892 .34978 .7506 .34596 .74534 .33889 Mtetra
.74534 .33889 .7506 .34596 .76234 .34212 .75711 .33503 Mtetra
.75711 .33503 .76234 .34212 .77413 .33827 .76893 .33115 Mtetra
.76893 .33115 .77413 .33827 .78596 .33441 .7808 .32725 Mtetra
.7808 .32725 .78596 .33441 .79784 .33052 .79272 .32333 Mtetra
.79272 .32333 .79784 .33052 .80977 .32662 .80468 .3194 Mtetra
.80468 .3194 .80977 .32662 .82175 .3227 .8167 .31544 Mtetra
.656 .752 .92 r
.8167 .31544 .82175 .3227 .83378 .31877 .82876 .31146 Mtetra
.654 .751 .921 r
.18679 .51429 .19348 .52013 .20308 .51699 .19641 .51115 Mtetra
.655 .752 .921 r
.19641 .51115 .20308 .51699 .21272 .51383 .20607 .50799 Mtetra
.655 .753 .922 r
.20607 .50799 .21272 .51383 .2224 .51066 .21577 .50481 Mtetra
.21577 .50481 .2224 .51066 .23212 .50747 .22551 .50161 Mtetra
.656 .754 .922 r
.22551 .50161 .23212 .50747 .24187 .50426 .23528 .49838 Mtetra
.23528 .49838 .24187 .50426 .25165 .50105 .24509 .49514 Mtetra
.24509 .49514 .25165 .50105 .26148 .49781 .25494 .49188 Mtetra
.656 .753 .921 r
.25494 .49188 .26148 .49781 .27134 .49457 .26482 .4886 Mtetra
.26482 .4886 .27134 .49457 .28124 .49132 .27475 .48531 Mtetra
.27475 .48531 .28124 .49132 .29118 .48805 .28471 .48201 Mtetra
.656 .752 .921 r
.28471 .48201 .29118 .48805 .30115 .48477 .2947 .4787 Mtetra
.656 .752 .92 r
.2947 .4787 .30115 .48477 .31116 .48148 .30474 .47538 Mtetra
.30474 .47538 .31116 .48148 .32121 .47818 .31481 .47205 Mtetra
.656 .751 .92 r
.31481 .47205 .32121 .47818 .3313 .47486 .32492 .46871 Mtetra
.32492 .46871 .3313 .47486 .34143 .47153 .33507 .46535 Mtetra
.33507 .46535 .34143 .47153 .35159 .46819 .34526 .46199 Mtetra
.34526 .46199 .35159 .46819 .3618 .46484 .35549 .45861 Mtetra
.35549 .45861 .3618 .46484 .37204 .46148 .36576 .45522 Mtetra
.36576 .45522 .37204 .46148 .38232 .4581 .37607 .45182 Mtetra
.37607 .45182 .38232 .4581 .39264 .45471 .38641 .4484 Mtetra
.38641 .4484 .39264 .45471 .40301 .45131 .3968 .44498 Mtetra
.3968 .44498 .40301 .45131 .41341 .44789 .40723 .44153 Mtetra
.40723 .44153 .41341 .44789 .42385 .44446 .4177 .43808 Mtetra
.4177 .43808 .42385 .44446 .43434 .44102 .4282 .43461 Mtetra
.4282 .43461 .43434 .44102 .44486 .43756 .43875 .43113 Mtetra
.43875 .43113 .44486 .43756 .45542 .43409 .44935 .42764 Mtetra
.44935 .42764 .45542 .43409 .46603 .43061 .45998 .42413 Mtetra
.45998 .42413 .46603 .43061 .47668 .42711 .47065 .4206 Mtetra
.47065 .4206 .47668 .42711 .48737 .4236 .48137 .41707 Mtetra
.48137 .41707 .48737 .4236 .4981 .42007 .49213 .41352 Mtetra
.49213 .41352 .4981 .42007 .50887 .41653 .50293 .40995 Mtetra
.50293 .40995 .50887 .41653 .51969 .41298 .51377 .40637 Mtetra
.51377 .40637 .51969 .41298 .53055 .40941 .52466 .40278 Mtetra
.52466 .40278 .53055 .40941 .54145 .40583 .53559 .39917 Mtetra
.53559 .39917 .54145 .40583 .5524 .40224 .54656 .39555 Mtetra
.54656 .39555 .5524 .40224 .56338 .39863 .55758 .39192 Mtetra
.55758 .39192 .56338 .39863 .57442 .39501 .56864 .38826 Mtetra
.56864 .38826 .57442 .39501 .58549 .39137 .57975 .3846 Mtetra
.57975 .3846 .58549 .39137 .59661 .38771 .5909 .38092 Mtetra
.5909 .38092 .59661 .38771 .60778 .38405 .60209 .37723 Mtetra
.60209 .37723 .60778 .38405 .61899 .38037 .61334 .37352 Mtetra
.61334 .37352 .61899 .38037 .63025 .37667 .62462 .36979 Mtetra
.62462 .36979 .63025 .37667 .64155 .37296 .63595 .36606 Mtetra
.63595 .36606 .64155 .37296 .65289 .36923 .64733 .3623 Mtetra
.64733 .3623 .65289 .36923 .66429 .36549 .65875 .35854 Mtetra
.65875 .35854 .66429 .36549 .67572 .36174 .67023 .35476 Mtetra
.655 .751 .92 r
.67023 .35476 .67572 .36174 .68721 .35797 .68174 .35097 Mtetra
.655 .751 .921 r
.68174 .35097 .68721 .35797 .69874 .35418 .69331 .34716 Mtetra
.655 .752 .921 r
.69331 .34716 .69874 .35418 .71032 .35038 .70492 .34334 Mtetra
.70492 .34334 .71032 .35038 .72195 .34656 .71658 .3395 Mtetra
.71658 .3395 .72195 .34656 .73362 .34273 .72829 .33566 Mtetra
.655 .753 .921 r
.72829 .33566 .73362 .34273 .74534 .33889 .74005 .33179 Mtetra
.655 .753 .922 r
.74005 .33179 .74534 .33889 .75711 .33503 .75185 .32791 Mtetra
.75185 .32791 .75711 .33503 .76893 .33115 .76371 .32401 Mtetra
.656 .754 .922 r
.76371 .32401 .76893 .33115 .7808 .32725 .77561 .32008 Mtetra
.77561 .32008 .7808 .32725 .79272 .32333 .78756 .31613 Mtetra
.78756 .31613 .79272 .32333 .80468 .3194 .79956 .31215 Mtetra
.657 .753 .921 r
.79956 .31215 .80468 .3194 .8167 .31544 .81161 .30814 Mtetra
.657 .753 .92 r
.81161 .30814 .8167 .31544 .82876 .31146 .82371 .3041 Mtetra
.651 .75 .922 r
.18006 .50842 .18679 .51429 .19641 .51115 .1897 .50532 Mtetra
.652 .753 .923 r
.1897 .50532 .19641 .51115 .20607 .50799 .19937 .50219 Mtetra
.653 .755 .924 r
.19937 .50219 .20607 .50799 .21577 .50481 .20909 .49903 Mtetra
.654 .756 .925 r
.20909 .49903 .21577 .50481 .22551 .50161 .21884 .49584 Mtetra
.655 .758 .925 r
.21884 .49584 .22551 .50161 .23528 .49838 .22864 .4926 Mtetra
.656 .759 .925 r
.22864 .4926 .23528 .49838 .24509 .49514 .23847 .48934 Mtetra
.23847 .48934 .24509 .49514 .25494 .49188 .24834 .48605 Mtetra
.657 .759 .925 r
.24834 .48605 .25494 .49188 .26482 .4886 .25825 .48274 Mtetra
.657 .758 .925 r
.25825 .48274 .26482 .4886 .27475 .48531 .26819 .47942 Mtetra
.657 .758 .924 r
.26819 .47942 .27475 .48531 .28471 .48201 .27818 .47608 Mtetra
.657 .757 .924 r
.27818 .47608 .28471 .48201 .2947 .4787 .2882 .47272 Mtetra
.657 .757 .923 r
.2882 .47272 .2947 .4787 .30474 .47538 .29826 .46936 Mtetra
.657 .756 .923 r
.29826 .46936 .30474 .47538 .31481 .47205 .30836 .46599 Mtetra
.657 .755 .923 r
.30836 .46599 .31481 .47205 .32492 .46871 .31849 .46261 Mtetra
.656 .755 .922 r
.31849 .46261 .32492 .46871 .33507 .46535 .32867 .45922 Mtetra
.656 .754 .922 r
.32867 .45922 .33507 .46535 .34526 .46199 .33888 .45582 Mtetra
.33888 .45582 .34526 .46199 .35549 .45861 .34914 .45241 Mtetra
.34914 .45241 .35549 .45861 .36576 .45522 .35943 .44898 Mtetra
.656 .753 .921 r
.35943 .44898 .36576 .45522 .37607 .45182 .36976 .44555 Mtetra
.36976 .44555 .37607 .45182 .38641 .4484 .38013 .4421 Mtetra
.38013 .4421 .38641 .4484 .3968 .44498 .39055 .43865 Mtetra
.39055 .43865 .3968 .44498 .40723 .44153 .401 .43518 Mtetra
.656 .752 .921 r
.401 .43518 .40723 .44153 .4177 .43808 .41149 .43169 Mtetra
.41149 .43169 .4177 .43808 .4282 .43461 .42203 .4282 Mtetra
.42203 .4282 .4282 .43461 .43875 .43113 .4326 .42469 Mtetra
.4326 .42469 .43875 .43113 .44935 .42764 .44322 .42117 Mtetra
.44322 .42117 .44935 .42764 .45998 .42413 .45388 .41763 Mtetra
.45388 .41763 .45998 .42413 .47065 .4206 .46458 .41408 Mtetra
.46458 .41408 .47065 .4206 .48137 .41707 .47533 .41052 Mtetra
.47533 .41052 .48137 .41707 .49213 .41352 .48611 .40695 Mtetra
.48611 .40695 .49213 .41352 .50293 .40995 .49694 .40336 Mtetra
.49694 .40336 .50293 .40995 .51377 .40637 .50781 .39975 Mtetra
.50781 .39975 .51377 .40637 .52466 .40278 .51873 .39613 Mtetra
.51873 .39613 .52466 .40278 .53559 .39917 .52969 .3925 Mtetra
.52969 .3925 .53559 .39917 .54656 .39555 .54069 .38885 Mtetra
.54069 .38885 .54656 .39555 .55758 .39192 .55174 .38519 Mtetra
.55174 .38519 .55758 .39192 .56864 .38826 .56283 .38152 Mtetra
.56283 .38152 .56864 .38826 .57975 .3846 .57396 .37783 Mtetra
.57396 .37783 .57975 .3846 .5909 .38092 .58514 .37413 Mtetra
.656 .753 .921 r
.58514 .37413 .5909 .38092 .60209 .37723 .59637 .37041 Mtetra
.655 .753 .921 r
.59637 .37041 .60209 .37723 .61334 .37352 .60764 .36668 Mtetra
.655 .753 .922 r
.60764 .36668 .61334 .37352 .62462 .36979 .61896 .36294 Mtetra
.61896 .36294 .62462 .36979 .63595 .36606 .63032 .35918 Mtetra
.655 .754 .922 r
.63032 .35918 .63595 .36606 .64733 .3623 .64173 .35542 Mtetra
.655 .754 .923 r
.64173 .35542 .64733 .3623 .65875 .35854 .65319 .35164 Mtetra
.65319 .35164 .65875 .35854 .67023 .35476 .66469 .34784 Mtetra
.655 .755 .923 r
.66469 .34784 .67023 .35476 .68174 .35097 .67624 .34404 Mtetra
.655 .755 .924 r
.67624 .34404 .68174 .35097 .69331 .34716 .68784 .34022 Mtetra
.654 .756 .924 r
.68784 .34022 .69331 .34716 .70492 .34334 .69949 .33639 Mtetra
.654 .756 .925 r
.69949 .33639 .70492 .34334 .71658 .3395 .71118 .33255 Mtetra
.654 .757 .925 r
.71118 .33255 .71658 .3395 .72829 .33566 .72293 .32869 Mtetra
.655 .758 .926 r
.72293 .32869 .72829 .33566 .74005 .33179 .73472 .3248 Mtetra
.73472 .3248 .74005 .33179 .75185 .32791 .74656 .3209 Mtetra
.655 .759 .926 r
.74656 .3209 .75185 .32791 .76371 .32401 .75845 .31696 Mtetra
.656 .759 .925 r
.75845 .31696 .76371 .32401 .77561 .32008 .77038 .31298 Mtetra
.657 .759 .925 r
.77038 .31298 .77561 .32008 .78756 .31613 .78237 .30897 Mtetra
.658 .758 .924 r
.78237 .30897 .78756 .31613 .79956 .31215 .7944 .30491 Mtetra
.659 .757 .922 r
.7944 .30491 .79956 .31215 .81161 .30814 .80648 .30082 Mtetra
.659 .755 .921 r
.80648 .30082 .81161 .30814 .82371 .3041 .81861 .29669 Mtetra
.645 .749 .925 r
.17328 .5025 .18006 .50842 .1897 .50532 .18293 .49952 Mtetra
.647 .754 .928 r
.18293 .49952 .1897 .50532 .19937 .50219 .19261 .4965 Mtetra
.648 .759 .93 r
.19261 .4965 .19937 .50219 .20909 .49903 .20234 .49342 Mtetra
.65 .763 .932 r
.20234 .49342 .20909 .49903 .21884 .49584 .21211 .49029 Mtetra
.652 .766 .933 r
.21211 .49029 .21884 .49584 .22864 .4926 .22192 .48709 Mtetra
.654 .769 .934 r
.22192 .48709 .22864 .4926 .23847 .48934 .23177 .48383 Mtetra
.656 .77 .934 r
.23177 .48383 .23847 .48934 .24834 .48605 .24166 .48052 Mtetra
.657 .77 .933 r
.24166 .48052 .24834 .48605 .25825 .48274 .2516 .47717 Mtetra
.658 .77 .932 r
.2516 .47717 .25825 .48274 .26819 .47942 .26157 .47378 Mtetra
.658 .769 .931 r
.26157 .47378 .26819 .47942 .27818 .47608 .27158 .47037 Mtetra
.659 .767 .93 r
.27158 .47037 .27818 .47608 .2882 .47272 .28163 .46694 Mtetra
.659 .765 .929 r
.28163 .46694 .2882 .47272 .29826 .46936 .29172 .4635 Mtetra
.658 .764 .927 r
.29172 .4635 .29826 .46936 .30836 .46599 .30185 .46006 Mtetra
.658 .762 .926 r
.30185 .46006 .30836 .46599 .31849 .46261 .31201 .45661 Mtetra
.658 .76 .925 r
.31201 .45661 .31849 .46261 .32867 .45922 .32221 .45315 Mtetra
.658 .758 .924 r
.32221 .45315 .32867 .45922 .33888 .45582 .33245 .44969 Mtetra
.657 .757 .923 r
.33245 .44969 .33888 .45582 .34914 .45241 .34273 .44622 Mtetra
.657 .756 .923 r
.34273 .44622 .34914 .45241 .35943 .44898 .35305 .44274 Mtetra
.657 .755 .922 r
.35305 .44274 .35943 .44898 .36976 .44555 .36341 .43926 Mtetra
.657 .754 .922 r
.36341 .43926 .36976 .44555 .38013 .4421 .37381 .43578 Mtetra
.657 .753 .921 r
.37381 .43578 .38013 .4421 .39055 .43865 .38425 .43228 Mtetra
.656 .753 .921 r
.38425 .43228 .39055 .43865 .401 .43518 .39473 .42877 Mtetra
.656 .752 .921 r
.39473 .42877 .401 .43518 .41149 .43169 .40525 .42525 Mtetra
.40525 .42525 .41149 .43169 .42203 .4282 .41581 .42173 Mtetra
.656 .752 .92 r
.41581 .42173 .42203 .4282 .4326 .42469 .42641 .41819 Mtetra
.42641 .41819 .4326 .42469 .44322 .42117 .43705 .41463 Mtetra
.656 .751 .92 r
.43705 .41463 .44322 .42117 .45388 .41763 .44774 .41107 Mtetra
.44774 .41107 .45388 .41763 .46458 .41408 .45847 .40749 Mtetra
.45847 .40749 .46458 .41408 .47533 .41052 .46924 .4039 Mtetra
.46924 .4039 .47533 .41052 .48611 .40695 .48005 .4003 Mtetra
.48005 .4003 .48611 .40695 .49694 .40336 .49091 .39668 Mtetra
.49091 .39668 .49694 .40336 .50781 .39975 .50181 .39306 Mtetra
.50181 .39306 .50781 .39975 .51873 .39613 .51275 .38941 Mtetra
.51275 .38941 .51873 .39613 .52969 .3925 .52374 .38576 Mtetra
.655 .751 .92 r
.52374 .38576 .52969 .3925 .54069 .38885 .53477 .38209 Mtetra
.655 .752 .921 r
.53477 .38209 .54069 .38885 .55174 .38519 .54585 .37841 Mtetra
.54585 .37841 .55174 .38519 .56283 .38152 .55697 .37472 Mtetra
.55697 .37472 .56283 .38152 .57396 .37783 .56813 .37102 Mtetra
.655 .752 .922 r
.56813 .37102 .57396 .37783 .58514 .37413 .57934 .3673 Mtetra
.655 .753 .922 r
.57934 .3673 .58514 .37413 .59637 .37041 .5906 .36358 Mtetra
.5906 .36358 .59637 .37041 .60764 .36668 .6019 .35984 Mtetra
.654 .754 .923 r
.6019 .35984 .60764 .36668 .61896 .36294 .61325 .3561 Mtetra
.654 .755 .924 r
.61325 .3561 .61896 .36294 .63032 .35918 .62465 .35235 Mtetra
.654 .756 .925 r
.62465 .35235 .63032 .35918 .64173 .35542 .63609 .34859 Mtetra
.653 .757 .926 r
.63609 .34859 .64173 .35542 .65319 .35164 .64758 .34482 Mtetra
.653 .758 .927 r
.64758 .34482 .65319 .35164 .66469 .34784 .65912 .34105 Mtetra
.652 .76 .928 r
.65912 .34105 .66469 .34784 .67624 .34404 .67071 .33727 Mtetra
.652 .761 .93 r
.67071 .33727 .67624 .34404 .68784 .34022 .68234 .33348 Mtetra
.652 .763 .931 r
.68234 .33348 .68784 .34022 .69949 .33639 .69403 .32967 Mtetra
.652 .765 .932 r
.69403 .32967 .69949 .33639 .71118 .33255 .70576 .32585 Mtetra
.652 .767 .933 r
.70576 .32585 .71118 .33255 .72293 .32869 .71754 .322 Mtetra
.653 .768 .934 r
.71754 .322 .72293 .32869 .73472 .3248 .72937 .31811 Mtetra
.654 .77 .934 r
.72937 .31811 .73472 .3248 .74656 .3209 .74125 .31417 Mtetra
.656 .77 .934 r
.74125 .31417 .74656 .3209 .75845 .31696 .75317 .31018 Mtetra
.658 .77 .932 r
.75317 .31018 .75845 .31696 .77038 .31298 .76514 .30611 Mtetra
.66 .769 .93 r
.76514 .30611 .77038 .31298 .78237 .30897 .77716 .30198 Mtetra
.662 .767 .928 r
.77716 .30198 .78237 .30897 .7944 .30491 .78922 .29778 Mtetra
.663 .764 .925 r
.78922 .29778 .7944 .30491 .80648 .30082 .80132 .29352 Mtetra
.665 .76 .921 r
.80132 .29352 .80648 .30082 .81861 .29669 .81347 .28921 Mtetra
.635 .746 .928 r
.16646 .49655 .17328 .5025 .18293 .49952 .1761 .49377 Mtetra
.636 .754 .934 r
.1761 .49377 .18293 .49952 .19261 .4965 .18578 .49095 Mtetra
.638 .763 .938 r
.18578 .49095 .19261 .4965 .20234 .49342 .19551 .48805 Mtetra
.641 .77 .942 r
.19551 .48805 .20234 .49342 .21211 .49029 .20528 .48507 Mtetra
.644 .778 .944 r
.20528 .48507 .21211 .49029 .22192 .48709 .21511 .48198 Mtetra
.648 .783 .946 r
.21511 .48198 .22192 .48709 .23177 .48383 .22497 .47879 Mtetra
.651 .788 .947 r
.22497 .47879 .23177 .48383 .24166 .48052 .23489 .47551 Mtetra
.654 .79 .947 r
.23489 .47551 .24166 .48052 .2516 .47717 .24485 .47216 Mtetra
.656 .792 .947 r
.24485 .47216 .2516 .47717 .26157 .47378 .25485 .46873 Mtetra
.658 .792 .946 r
.25485 .46873 .26157 .47378 .27158 .47037 .26489 .46526 Mtetra
.659 .79 .945 r
.26489 .46526 .27158 .47037 .28163 .46694 .27497 .46176 Mtetra
.66 .789 .943 r
.27497 .46176 .28163 .46694 .29172 .4635 .28509 .45824 Mtetra
.66 .786 .942 r
.28509 .45824 .29172 .4635 .30185 .46006 .29524 .4547 Mtetra
.66 .784 .94 r
.29524 .4547 .30185 .46006 .31201 .45661 .30544 .45115 Mtetra
.66 .781 .938 r
.30544 .45115 .31201 .45661 .32221 .45315 .31567 .4476 Mtetra
.659 .779 .937 r
.31567 .4476 .32221 .45315 .33245 .44969 .32594 .44404 Mtetra
.659 .776 .936 r
.32594 .44404 .33245 .44969 .34273 .44622 .33625 .44049 Mtetra
.659 .774 .934 r
.33625 .44049 .34273 .44622 .35305 .44274 .3466 .43694 Mtetra
.658 .772 .933 r
.3466 .43694 .35305 .44274 .36341 .43926 .35699 .43338 Mtetra
.658 .77 .932 r
.35699 .43338 .36341 .43926 .37381 .43578 .36742 .42982 Mtetra
.658 .768 .931 r
.36742 .42982 .37381 .43578 .38425 .43228 .37788 .42626 Mtetra
.657 .767 .93 r
.37788 .42626 .38425 .43228 .39473 .42877 .38839 .4227 Mtetra
.657 .766 .93 r
.38839 .4227 .39473 .42877 .40525 .42525 .39894 .41913 Mtetra
.657 .765 .929 r
.39894 .41913 .40525 .42525 .41581 .42173 .40953 .41555 Mtetra
.656 .764 .929 r
.40953 .41555 .41581 .42173 .42641 .41819 .42016 .41197 Mtetra
.656 .763 .928 r
.42016 .41197 .42641 .41819 .43705 .41463 .43083 .40837 Mtetra
.656 .762 .928 r
.43083 .40837 .43705 .41463 .44774 .41107 .44155 .40477 Mtetra
.44155 .40477 .44774 .41107 .45847 .40749 .4523 .40116 Mtetra
.4523 .40116 .45847 .40749 .46924 .4039 .4631 .39754 Mtetra
.655 .762 .928 r
.4631 .39754 .46924 .4039 .48005 .4003 .47394 .39392 Mtetra
.655 .761 .928 r
.47394 .39392 .48005 .4003 .49091 .39668 .48483 .39028 Mtetra
.655 .762 .928 r
.48483 .39028 .49091 .39668 .50181 .39306 .49576 .38663 Mtetra
.49576 .38663 .50181 .39306 .51275 .38941 .50673 .38297 Mtetra
.50673 .38297 .51275 .38941 .52374 .38576 .51775 .3793 Mtetra
.654 .762 .929 r
.51775 .3793 .52374 .38576 .53477 .38209 .52881 .37563 Mtetra
.654 .763 .929 r
.52881 .37563 .53477 .38209 .54585 .37841 .53992 .37194 Mtetra
.654 .764 .93 r
.53992 .37194 .54585 .37841 .55697 .37472 .55107 .36825 Mtetra
.653 .764 .931 r
.55107 .36825 .55697 .37472 .56813 .37102 .56226 .36456 Mtetra
.653 .765 .932 r
.56226 .36456 .56813 .37102 .57934 .3673 .57351 .36085 Mtetra
.652 .767 .933 r
.57351 .36085 .57934 .3673 .5906 .36358 .5848 .35714 Mtetra
.652 .768 .934 r
.5848 .35714 .5906 .36358 .6019 .35984 .59613 .35343 Mtetra
.651 .769 .936 r
.59613 .35343 .6019 .35984 .61325 .3561 .60752 .34972 Mtetra
.65 .771 .937 r
.60752 .34972 .61325 .3561 .62465 .35235 .61895 .346 Mtetra
.65 .773 .939 r
.61895 .346 .62465 .35235 .63609 .34859 .63043 .34229 Mtetra
.649 .775 .941 r
.63043 .34229 .63609 .34859 .64758 .34482 .64196 .33857 Mtetra
.648 .778 .942 r
.64196 .33857 .64758 .34482 .65912 .34105 .65353 .33484 Mtetra
.648 .78 .944 r
.65353 .33484 .65912 .34105 .67071 .33727 .66516 .3311 Mtetra
.647 .782 .946 r
.66516 .3311 .67071 .33727 .68234 .33348 .67683 .32735 Mtetra
.647 .785 .947 r
.67683 .32735 .68234 .33348 .69403 .32967 .68856 .32357 Mtetra
.648 .787 .948 r
.68856 .32357 .69403 .32967 .70576 .32585 .70033 .31975 Mtetra
.649 .789 .949 r
.70033 .31975 .70576 .32585 .71754 .322 .71215 .31588 Mtetra
.651 .79 .949 r
.71215 .31588 .71754 .322 .72937 .31811 .72402 .31195 Mtetra
.654 .791 .947 r
.72402 .31195 .72937 .31811 .74125 .31417 .73593 .30792 Mtetra
.658 .79 .945 r
.73593 .30792 .74125 .31417 .75317 .31018 .74789 .3038 Mtetra
.662 .788 .942 r
.74789 .3038 .75317 .31018 .76514 .30611 .75989 .29957 Mtetra
.666 .785 .937 r
.75989 .29957 .76514 .30611 .77716 .30198 .77192 .29522 Mtetra
.669 .78 .932 r
.77192 .29522 .77716 .30198 .78922 .29778 .78401 .29078 Mtetra
.671 .773 .927 r
.78401 .29078 .78922 .29778 .80132 .29352 .79613 .28626 Mtetra
.673 .766 .921 r
.79613 .28626 .80132 .29352 .81347 .28921 .8083 .28168 Mtetra
.617 .741 .935 r
.15958 .49055 .16646 .49655 .1761 .49377 .1692 .48813 Mtetra
.616 .754 .944 r
.1692 .48813 .1761 .49377 .18578 .49095 .17887 .48567 Mtetra
.617 .768 .952 r
.17887 .48567 .18578 .49095 .19551 .48805 .18858 .48312 Mtetra
.619 .783 .96 r
.18858 .48312 .19551 .48805 .20528 .48507 .19834 .48047 Mtetra
.622 .797 .966 r
.19834 .48047 .20528 .48507 .21511 .48198 .20816 .47769 Mtetra
.626 .81 .971 r
.20816 .47769 .21511 .48198 .22497 .47879 .21803 .47475 Mtetra
.63 .822 .974 r
.21803 .47475 .22497 .47879 .23489 .47551 .22795 .47166 Mtetra
.635 .831 .976 r
.22795 .47166 .23489 .47551 .24485 .47216 .23793 .46843 Mtetra
.64 .838 .976 r
.23793 .46843 .24485 .47216 .25485 .46873 .24795 .46506 Mtetra
.644 .842 .976 r
.24795 .46506 .25485 .46873 .26489 .46526 .25802 .46158 Mtetra
.648 .843 .975 r
.25802 .46158 .26489 .46526 .27497 .46176 .26814 .45802 Mtetra
.652 .842 .974 r
.26814 .45802 .27497 .46176 .28509 .45824 .27829 .45439 Mtetra
.654 .84 .972 r
.27829 .45439 .28509 .45824 .29524 .4547 .28849 .45072 Mtetra
.656 .836 .969 r
.28849 .45072 .29524 .4547 .30544 .45115 .29872 .44702 Mtetra
.658 .832 .967 r
.29872 .44702 .30544 .45115 .31567 .4476 .309 .4433 Mtetra
.659 .826 .964 r
.309 .4433 .31567 .4476 .32594 .44404 .31931 .43958 Mtetra
.659 .821 .961 r
.31931 .43958 .32594 .44404 .33625 .44049 .32966 .43586 Mtetra
.66 .816 .958 r
.32966 .43586 .33625 .44049 .3466 .43694 .34004 .43214 Mtetra
.659 .81 .956 r
.34004 .43214 .3466 .43694 .35699 .43338 .35047 .42843 Mtetra
.659 .806 .953 r
.35047 .42843 .35699 .43338 .36742 .42982 .36093 .42473 Mtetra
.659 .801 .951 r
.36093 .42473 .36742 .42982 .37788 .42626 .37143 .42104 Mtetra
.658 .797 .949 r
.37143 .42104 .37788 .42626 .38839 .4227 .38198 .41736 Mtetra
.658 .794 .947 r
.38198 .41736 .38839 .4227 .39894 .41913 .39256 .41368 Mtetra
.657 .79 .945 r
.39256 .41368 .39894 .41913 .40953 .41555 .40318 .41001 Mtetra
.657 .788 .944 r
.40318 .41001 .40953 .41555 .42016 .41197 .41384 .40634 Mtetra
.656 .786 .943 r
.41384 .40634 .42016 .41197 .43083 .40837 .42454 .40268 Mtetra
.656 .784 .942 r
.42454 .40268 .43083 .40837 .44155 .40477 .43529 .39902 Mtetra
.655 .782 .942 r
.43529 .39902 .44155 .40477 .4523 .40116 .44608 .39537 Mtetra
.655 .782 .941 r
.44608 .39537 .4523 .40116 .4631 .39754 .45691 .39171 Mtetra
.654 .781 .941 r
.45691 .39171 .4631 .39754 .47394 .39392 .46778 .38805 Mtetra
.653 .781 .942 r
.46778 .38805 .47394 .39392 .48483 .39028 .47869 .3844 Mtetra
.47869 .3844 .48483 .39028 .49576 .38663 .48965 .38075 Mtetra
.652 .781 .943 r
.48965 .38075 .49576 .38663 .50673 .38297 .50066 .3771 Mtetra
.651 .782 .944 r
.50066 .3771 .50673 .38297 .51775 .3793 .51171 .37345 Mtetra
.65 .784 .945 r
.51171 .37345 .51775 .3793 .52881 .37563 .5228 .3698 Mtetra
.649 .785 .947 r
.5228 .3698 .52881 .37563 .53992 .37194 .53394 .36616 Mtetra
.648 .787 .949 r
.53394 .36616 .53992 .37194 .55107 .36825 .54513 .36252 Mtetra
.646 .79 .951 r
.54513 .36252 .55107 .36825 .56226 .36456 .55636 .35889 Mtetra
.645 .793 .953 r
.55636 .35889 .56226 .36456 .57351 .36085 .56764 .35527 Mtetra
.643 .796 .956 r
.56764 .35527 .57351 .36085 .5848 .35714 .57897 .35166 Mtetra
.641 .8 .959 r
.57897 .35166 .5848 .35714 .59613 .35343 .59034 .34805 Mtetra
.638 .804 .962 r
.59034 .34805 .59613 .35343 .60752 .34972 .60177 .34445 Mtetra
.636 .809 .966 r
.60177 .34445 .60752 .34972 .61895 .346 .61324 .34086 Mtetra
.634 .814 .969 r
.61324 .34086 .61895 .346 .63043 .34229 .62476 .33726 Mtetra
.632 .819 .972 r
.62476 .33726 .63043 .34229 .64196 .33857 .63633 .33366 Mtetra
.63 .823 .975 r
.63633 .33366 .64196 .33857 .65353 .33484 .64796 .33004 Mtetra
.629 .828 .977 r
.64796 .33004 .65353 .33484 .66516 .3311 .65963 .32639 Mtetra
.628 .833 .979 r
.65963 .32639 .66516 .3311 .67683 .32735 .67135 .32269 Mtetra
.63 .836 .98 r
.67135 .32269 .67683 .32735 .68856 .32357 .68312 .31892 Mtetra
.633 .839 .979 r
.68312 .31892 .68856 .32357 .70033 .31975 .69494 .31506 Mtetra
.638 .84 .978 r
.69494 .31506 .70033 .31975 .71215 .31588 .7068 .31109 Mtetra
.645 .84 .975 r
.7068 .31109 .71215 .31588 .72402 .31195 .7187 .30697 Mtetra
.654 .837 .971 r
.7187 .30697 .72402 .31195 .73593 .30792 .73064 .3027 Mtetra
.663 .832 .965 r
.73064 .3027 .73593 .30792 .74789 .3038 .74262 .29826 Mtetra
.671 .824 .957 r
.74262 .29826 .74789 .3038 .75989 .29957 .75464 .29367 Mtetra
.678 .814 .948 r
.75464 .29367 .75989 .29957 .77192 .29522 .76669 .28892 Mtetra
.683 .803 .939 r
.76669 .28892 .77192 .29522 .78401 .29078 .77878 .28405 Mtetra
.686 .79 .929 r
.77878 .28405 .78401 .29078 .79613 .28626 .79091 .2791 Mtetra
.687 .777 .92 r
.79091 .2791 .79613 .28626 .8083 .28168 .80308 .27409 Mtetra
.596 .735 .941 r
.15266 .48451 .15958 .49055 .1692 .48813 .16226 .48248 Mtetra
.593 .748 .951 r
.16226 .48248 .1692 .48813 .17887 .48567 .1719 .48042 Mtetra
.591 .764 .962 r
.1719 .48042 .17887 .48567 .18858 .48312 .18158 .4783 Mtetra
.59 .78 .971 r
.18158 .4783 .18858 .48312 .19834 .48047 .19133 .47609 Mtetra
.591 .798 .979 r
.19133 .47609 .19834 .48047 .20816 .47769 .20112 .47373 Mtetra
.593 .816 .985 r
.20112 .47373 .20816 .47769 .21803 .47475 .21098 .4712 Mtetra
.597 .833 .989 r
.21098 .4712 .21803 .47475 .22795 .47166 .2209 .46846 Mtetra
.601 .849 .991 r
.2209 .46846 .22795 .47166 .23793 .46843 .23087 .46552 Mtetra
.606 .862 .992 r
.23087 .46552 .23793 .46843 .24795 .46506 .24091 .46238 Mtetra
.611 .872 .991 r
.24091 .46238 .24795 .46506 .25802 .46158 .251 .45905 Mtetra
.617 .879 .99 r
.251 .45905 .25802 .46158 .26814 .45802 .26114 .45556 Mtetra
.622 .884 .989 r
.26114 .45556 .26814 .45802 .27829 .45439 .27133 .45195 Mtetra
.627 .886 .988 r
.27133 .45195 .27829 .45439 .28849 .45072 .28156 .44823 Mtetra
.631 .887 .987 r
.28156 .44823 .28849 .45072 .29872 .44702 .29184 .44444 Mtetra
.635 .886 .986 r
.29184 .44444 .29872 .44702 .309 .4433 .30215 .44061 Mtetra
.639 .883 .986 r
.30215 .44061 .309 .4433 .31931 .43958 .31251 .43674 Mtetra
.641 .879 .985 r
.31251 .43674 .31931 .43958 .32966 .43586 .3229 .43287 Mtetra
.644 .875 .984 r
.3229 .43287 .32966 .43586 .34004 .43214 .33333 .42899 Mtetra
.645 .871 .983 r
.33333 .42899 .34004 .43214 .35047 .42843 .3438 .42512 Mtetra
.646 .866 .982 r
.3438 .42512 .35047 .42843 .36093 .42473 .35431 .42126 Mtetra
.647 .861 .981 r
.35431 .42126 .36093 .42473 .37143 .42104 .36485 .41742 Mtetra
.647 .856 .979 r
.36485 .41742 .37143 .42104 .38198 .41736 .37543 .41359 Mtetra
.647 .852 .978 r
.37543 .41359 .38198 .41736 .39256 .41368 .38605 .40979 Mtetra
.647 .848 .977 r
.38605 .40979 .39256 .41368 .40318 .41001 .39671 .406 Mtetra
.647 .844 .976 r
.39671 .406 .40318 .41001 .41384 .40634 .40741 .40224 Mtetra
.646 .841 .975 r
.40741 .40224 .41384 .40634 .42454 .40268 .41815 .39849 Mtetra
.645 .839 .975 r
.41815 .39849 .42454 .40268 .43529 .39902 .42894 .39476 Mtetra
.644 .837 .974 r
.42894 .39476 .43529 .39902 .44608 .39537 .43976 .39105 Mtetra
.643 .835 .974 r
.43976 .39105 .44608 .39537 .45691 .39171 .45063 .38735 Mtetra
.642 .834 .974 r
.45063 .38735 .45691 .39171 .46778 .38805 .46153 .38367 Mtetra
.64 .834 .975 r
.46153 .38367 .46778 .38805 .47869 .3844 .47249 .38001 Mtetra
.638 .834 .976 r
.47249 .38001 .47869 .3844 .48965 .38075 .48348 .37636 Mtetra
.636 .834 .977 r
.48348 .37636 .48965 .38075 .50066 .3771 .49452 .37273 Mtetra
.633 .835 .978 r
.49452 .37273 .50066 .3771 .51171 .37345 .50561 .36912 Mtetra
.631 .837 .979 r
.50561 .36912 .51171 .37345 .5228 .3698 .51674 .36552 Mtetra
.628 .839 .981 r
.51674 .36552 .5228 .3698 .53394 .36616 .52792 .36195 Mtetra
.624 .841 .983 r
.52792 .36195 .53394 .36616 .54513 .36252 .53914 .35839 Mtetra
.62 .844 .985 r
.53914 .35839 .54513 .36252 .55636 .35889 .55042 .35486 Mtetra
.616 .847 .987 r
.55042 .35486 .55636 .35889 .56764 .35527 .56174 .35134 Mtetra
.611 .85 .989 r
.56174 .35134 .56764 .35527 .57897 .35166 .57311 .34783 Mtetra
.606 .854 .991 r
.57311 .34783 .57897 .35166 .59034 .34805 .58453 .34434 Mtetra
.601 .857 .992 r
.58453 .34434 .59034 .34805 .60177 .34445 .596 .34086 Mtetra
.597 .861 .993 r
.596 .34086 .60177 .34445 .61324 .34086 .60752 .33737 Mtetra
.592 .864 .994 r
.60752 .33737 .61324 .34086 .62476 .33726 .61909 .33388 Mtetra
.589 .868 .994 r
.61909 .33388 .62476 .33726 .63633 .33366 .63072 .33034 Mtetra
.588 .871 .994 r
.63072 .33034 .63633 .33366 .64796 .33004 .64239 .32677 Mtetra
.59 .874 .994 r
.64239 .32677 .64796 .33004 .65963 .32639 .65411 .32311 Mtetra
.595 .876 .993 r
.65411 .32311 .65963 .32639 .67135 .32269 .66588 .31935 Mtetra
.603 .878 .992 r
.66588 .31935 .67135 .32269 .68312 .31892 .67769 .31546 Mtetra
.615 .879 .99 r
.67769 .31546 .68312 .31892 .69494 .31506 .68954 .31139 Mtetra
.63 .878 .988 r
.68954 .31139 .69494 .31506 .7068 .31109 .70144 .30714 Mtetra
.647 .875 .983 r
.70144 .30714 .7068 .31109 .7187 .30697 .71337 .30266 Mtetra
.662 .867 .977 r
.71337 .30266 .7187 .30697 .73064 .3027 .72533 .29797 Mtetra
.677 .857 .968 r
.72533 .29797 .73064 .3027 .74262 .29826 .73733 .29306 Mtetra
.687 .844 .958 r
.73733 .29306 .74262 .29826 .75464 .29367 .74936 .28796 Mtetra
.695 .829 .947 r
.74936 .28796 .75464 .29367 .76669 .28892 .76142 .28271 Mtetra
.699 .814 .936 r
.76142 .28271 .76669 .28892 .77878 .28405 .77352 .27735 Mtetra
.701 .798 .925 r
.77352 .27735 .77878 .28405 .79091 .2791 .78565 .27191 Mtetra
.701 .783 .915 r
.78565 .27191 .79091 .2791 .80308 .27409 .79782 .26643 Mtetra
.58 .73 .945 r
.14569 .47843 .15266 .48451 .16226 .48248 .15528 .47664 Mtetra
.575 .738 .953 r
.15528 .47664 .16226 .48248 .1719 .48042 .1649 .4749 Mtetra
.569 .748 .961 r
.1649 .4749 .1719 .48042 .18158 .4783 .17456 .47316 Mtetra
.564 .761 .971 r
.17456 .47316 .18158 .4783 .19133 .47609 .18428 .47139 Mtetra
.557 .777 .981 r
.18428 .47139 .19133 .47609 .20112 .47373 .19404 .46958 Mtetra
.551 .797 .99 r
.19404 .46958 .20112 .47373 .21098 .4712 .20386 .46767 Mtetra
.544 .819 .997 r
.20386 .46767 .21098 .4712 .2209 .46846 .21374 .4656 Mtetra
.534 .841 .999 r
.21374 .4656 .2209 .46846 .23087 .46552 .22369 .46333 Mtetra
.523 .86 .994 r
.22369 .46333 .23087 .46552 .24091 .46238 .2337 .46083 Mtetra
.509 .874 .982 r
.2337 .46083 .24091 .46238 .251 .45905 .24377 .45809 Mtetra
.494 .882 .964 r
.24377 .45809 .251 .45905 .26114 .45556 .25391 .45511 Mtetra
.479 .885 .942 r
.25391 .45511 .26114 .45556 .27133 .45195 .2641 .45191 Mtetra
.465 .885 .92 r
.2641 .45191 .27133 .45195 .28156 .44823 .27435 .44851 Mtetra
.455 .883 .902 r
.27435 .44851 .28156 .44823 .29184 .44444 .28466 .44494 Mtetra
.448 .88 .887 r
.28466 .44494 .29184 .44444 .30215 .44061 .29501 .44124 Mtetra
.444 .879 .878 r
.29501 .44124 .30215 .44061 .31251 .43674 .3054 .43744 Mtetra
.444 .879 .873 r
.3054 .43744 .31251 .43674 .3229 .43287 .31584 .43356 Mtetra
.447 .881 .873 r
.31584 .43356 .3229 .43287 .33333 .42899 .32633 .42963 Mtetra
.451 .883 .876 r
.32633 .42963 .33333 .42899 .3438 .42512 .33685 .42567 Mtetra
.458 .886 .881 r
.33685 .42567 .3438 .42512 .35431 .42126 .34741 .42169 Mtetra
.464 .889 .888 r
.34741 .42169 .35431 .42126 .36485 .41742 .358 .41771 Mtetra
.471 .892 .896 r
.358 .41771 .36485 .41742 .37543 .41359 .36864 .41375 Mtetra
.477 .894 .904 r
.36864 .41375 .37543 .41359 .38605 .40979 .37931 .4098 Mtetra
.483 .896 .911 r
.37931 .4098 .38605 .40979 .39671 .406 .39003 .40588 Mtetra
.487 .897 .918 r
.39003 .40588 .39671 .406 .40741 .40224 .40078 .40199 Mtetra
.49 .897 .923 r
.40078 .40199 .40741 .40224 .41815 .39849 .41157 .39813 Mtetra
.492 .897 .927 r
.41157 .39813 .41815 .39849 .42894 .39476 .4224 .39431 Mtetra
.491 .896 .93 r
.4224 .39431 .42894 .39476 .43976 .39105 .43328 .39053 Mtetra
.49 .894 .932 r
.43328 .39053 .43976 .39105 .45063 .38735 .44419 .38679 Mtetra
.486 .892 .933 r
.44419 .38679 .45063 .38735 .46153 .38367 .45515 .38309 Mtetra
.481 .89 .932 r
.45515 .38309 .46153 .38367 .47249 .38001 .46615 .37943 Mtetra
.474 .887 .93 r
.46615 .37943 .47249 .38001 .48348 .37636 .4772 .3758 Mtetra
.465 .883 .926 r
.4772 .3758 .48348 .37636 .49452 .37273 .48829 .37222 Mtetra
.455 .879 .921 r
.48829 .37222 .49452 .37273 .50561 .36912 .49942 .36867 Mtetra
.443 .874 .914 r
.49942 .36867 .50561 .36912 .51674 .36552 .51061 .36516 Mtetra
.43 .868 .906 r
.51061 .36516 .51674 .36552 .52792 .36195 .52184 .36168 Mtetra
.416 .861 .896 r
.52184 .36168 .52792 .36195 .53914 .35839 .53312 .35822 Mtetra
.402 .855 .886 r
.53312 .35822 .53914 .35839 .55042 .35486 .54444 .35478 Mtetra
.388 .848 .875 r
.54444 .35478 .55042 .35486 .56174 .35134 .55582 .35136 Mtetra
.376 .841 .865 r
.55582 .35136 .56174 .35134 .57311 .34783 .56725 .34793 Mtetra
.367 .836 .856 r
.56725 .34793 .57311 .34783 .58453 .34434 .57873 .34449 Mtetra
.362 .834 .85 r
.57873 .34449 .58453 .34434 .596 .34086 .59026 .34102 Mtetra
.363 .834 .849 r
.59026 .34102 .596 .34086 .60752 .33737 .60184 .3375 Mtetra
.371 .839 .852 r
.60184 .3375 .60752 .33737 .61909 .33388 .61347 .33389 Mtetra
.387 .848 .862 r
.61347 .33389 .61909 .33388 .63072 .33034 .62514 .33018 Mtetra
.413 .862 .878 r
.62514 .33018 .63072 .33034 .64239 .32677 .63686 .32633 Mtetra
.449 .88 .9 r
.63686 .32633 .64239 .32677 .65411 .32311 .64863 .3223 Mtetra
.493 .898 .924 r
.64863 .3223 .65411 .32311 .66588 .31935 .66044 .31807 Mtetra
.541 .913 .949 r
.66044 .31807 .66588 .31935 .67769 .31546 .67228 .31361 Mtetra
.59 .922 .967 r
.67228 .31361 .67769 .31546 .68954 .31139 .68416 .30889 Mtetra
.632 .92 .977 r
.68416 .30889 .68954 .31139 .70144 .30714 .69607 .30392 Mtetra
.666 .909 .978 r
.69607 .30392 .70144 .30714 .71337 .30266 .70801 .29869 Mtetra
.689 .89 .971 r
.70801 .29869 .71337 .30266 .72533 .29797 .71998 .29326 Mtetra
.704 .868 .959 r
.71998 .29326 .72533 .29797 .73733 .29306 .73198 .28765 Mtetra
.711 .846 .947 r
.73198 .28765 .73733 .29306 .74936 .28796 .74402 .28193 Mtetra
.713 .825 .934 r
.74402 .28193 .74936 .28796 .76142 .28271 .75608 .27615 Mtetra
.713 .808 .924 r
.75608 .27615 .76142 .28271 .77352 .27735 .76819 .27033 Mtetra
.712 .794 .915 r
.76819 .27033 .77352 .27735 .78565 .27191 .78034 .26451 Mtetra
.709 .782 .909 r
.78034 .26451 .78565 .27191 .79782 .26643 .79252 .25872 Mtetra
.583 .731 .945 r
.13868 .4723 .14569 .47843 .15528 .47664 .14828 .47045 Mtetra
.577 .727 .945 r
.14828 .47045 .15528 .47664 .1649 .4749 .15792 .4687 Mtetra
.571 .726 .947 r
.15792 .4687 .1649 .4749 .17456 .47316 .16759 .46705 Mtetra
.564 .727 .951 r
.16759 .46705 .17456 .47316 .18428 .47139 .1773 .4655 Mtetra
.553 .732 .958 r
.1773 .4655 .18428 .47139 .19404 .46958 .18704 .46405 Mtetra
.544 .743 .968 r
.18704 .46405 .19404 .46958 .20386 .46767 .19683 .46262 Mtetra
.535 .759 .979 r
.19683 .46262 .20386 .46767 .21374 .4656 .20667 .46118 Mtetra
.525 .78 .99 r
.20667 .46118 .21374 .4656 .22369 .46333 .21657 .45964 Mtetra
.515 .805 .998 r
.21657 .45964 .22369 .46333 .2337 .46083 .22654 .45791 Mtetra
.501 .829 .999 r
.22654 .45791 .2337 .46083 .24377 .45809 .23657 .45597 Mtetra
.485 .849 .99 r
.23657 .45597 .24377 .45809 .25391 .45511 .24668 .45375 Mtetra
.464 .861 .97 r
.24668 .45375 .25391 .45511 .2641 .45191 .25685 .45126 Mtetra
.441 .864 .941 r
.25685 .45126 .2641 .45191 .27435 .44851 .26709 .44848 Mtetra
.416 .86 .906 r
.26709 .44848 .27435 .44851 .28466 .44494 .27739 .44545 Mtetra
.392 .851 .869 r
.27739 .44545 .28466 .44494 .29501 .44124 .28776 .4422 Mtetra
.37 .839 .835 r
.28776 .4422 .29501 .44124 .3054 .43744 .29818 .43875 Mtetra
.352 .827 .804 r
.29818 .43875 .3054 .43744 .31584 .43356 .30865 .43515 Mtetra
.337 .816 .78 r
.30865 .43515 .31584 .43356 .32633 .42963 .31916 .43141 Mtetra
.325 .806 .76 r
.31916 .43141 .32633 .42963 .33685 .42567 .32973 .42758 Mtetra
.316 .799 .746 r
.32973 .42758 .33685 .42567 .34741 .42169 .34033 .42369 Mtetra
.309 .794 .736 r
.34033 .42369 .34741 .42169 .358 .41771 .35098 .41975 Mtetra
.304 .79 .73 r
.35098 .41975 .358 .41771 .36864 .41375 .36167 .41578 Mtetra
.3 .787 .727 r
.36167 .41578 .36864 .41375 .37931 .4098 .3724 .41182 Mtetra
.297 .785 .725 r
.3724 .41182 .37931 .4098 .39003 .40588 .38317 .40786 Mtetra
.294 .783 .725 r
.38317 .40786 .39003 .40588 .40078 .40199 .39398 .40393 Mtetra
.29 .781 .725 r
.39398 .40393 .40078 .40199 .41157 .39813 .40483 .40003 Mtetra
.287 .778 .725 r
.40483 .40003 .41157 .39813 .4224 .39431 .41572 .39617 Mtetra
.282 .775 .724 r
.41572 .39617 .4224 .39431 .43328 .39053 .42665 .39235 Mtetra
.276 .772 .723 r
.42665 .39235 .43328 .39053 .44419 .38679 .43762 .38858 Mtetra
.27 .768 .721 r
.43762 .38858 .44419 .38679 .45515 .38309 .44864 .38486 Mtetra
.263 .763 .718 r
.44864 .38486 .45515 .38309 .46615 .37943 .4597 .38119 Mtetra
.255 .757 .714 r
.4597 .38119 .46615 .37943 .4772 .3758 .4708 .37756 Mtetra
.247 .752 .709 r
.4708 .37756 .4772 .3758 .48829 .37222 .48195 .37398 Mtetra
.238 .746 .704 r
.48195 .37398 .48829 .37222 .49942 .36867 .49314 .37043 Mtetra
.231 .74 .699 r
.49314 .37043 .49942 .36867 .51061 .36516 .50439 .36692 Mtetra
.225 .735 .694 r
.50439 .36692 .51061 .36516 .52184 .36168 .51568 .36343 Mtetra
.22 .732 .692 r
.51568 .36343 .52184 .36168 .53312 .35822 .52702 .35995 Mtetra
.219 .732 .691 r
.52702 .35995 .53312 .35822 .54444 .35478 .53841 .35647 Mtetra
.223 .734 .695 r
.53841 .35647 .54444 .35478 .55582 .35136 .54985 .35297 Mtetra
.232 .741 .703 r
.54985 .35297 .55582 .35136 .56725 .34793 .56134 .34942 Mtetra
.248 .754 .717 r
.56134 .34942 .56725 .34793 .57873 .34449 .57287 .34581 Mtetra
.272 .771 .738 r
.57287 .34581 .57873 .34449 .59026 .34102 .58446 .34209 Mtetra
.305 .796 .767 r
.58446 .34209 .59026 .34102 .60184 .3375 .5961 .33824 Mtetra
.349 .825 .803 r
.5961 .33824 .60184 .3375 .61347 .33389 .60778 .33423 Mtetra
.403 .858 .844 r
.60778 .33423 .61347 .33389 .62514 .33018 .6195 .33002 Mtetra
.465 .89 .887 r
.6195 .33002 .62514 .33018 .63686 .32633 .63126 .32557 Mtetra
.529 .915 .926 r
.63126 .32557 .63686 .32633 .64863 .3223 .64306 .32085 Mtetra
.591 .93 .955 r
.64306 .32085 .64863 .3223 .66044 .31807 .65489 .31584 Mtetra
.643 .93 .971 r
.65489 .31584 .66044 .31807 .67228 .31361 .66676 .31054 Mtetra
.682 .918 .973 r
.66676 .31054 .67228 .31361 .68416 .30889 .67865 .30495 Mtetra
.707 .895 .965 r
.67865 .30495 .68416 .30889 .69607 .30392 .69057 .29912 Mtetra
.721 .869 .951 r
.69057 .29912 .69607 .30392 .70801 .29869 .70251 .29309 Mtetra
.726 .843 .936 r
.70251 .29309 .70801 .29869 .71998 .29326 .71448 .28695 Mtetra
.726 .819 .923 r
.71448 .28695 .71998 .29326 .73198 .28765 .72649 .28078 Mtetra
.723 .8 .912 r
.72649 .28078 .73198 .28765 .74402 .28193 .73854 .27462 Mtetra
.718 .786 .906 r
.73854 .27462 .74402 .28193 .75608 .27615 .75063 .26857 Mtetra
.714 .777 .902 r
.75063 .26857 .75608 .27615 .76819 .27033 .76277 .2626 Mtetra
.71 .772 .901 r
.76277 .2626 .76819 .27033 .78034 .26451 .77495 .25673 Mtetra
.706 .77 .902 r
.77495 .25673 .78034 .26451 .79252 .25872 .78718 .25095 Mtetra
.622 .743 .933 r
.13161 .46613 .13868 .4723 .14828 .47045 .14132 .46351 Mtetra
.619 .717 .916 r
.14132 .46351 .14828 .47045 .15792 .4687 .15105 .46102 Mtetra
.612 .693 .901 r
.15105 .46102 .15792 .4687 .16759 .46705 .16081 .45868 Mtetra
.604 .671 .887 r
.16081 .45868 .16759 .46705 .1773 .4655 .17059 .45655 Mtetra
.594 .652 .877 r
.17059 .45655 .1773 .4655 .18704 .46405 .18038 .45468 Mtetra
.585 .639 .871 r
.18038 .45468 .18704 .46405 .19683 .46262 .1902 .45303 Mtetra
.576 .63 .868 r
.1902 .45303 .19683 .46262 .20667 .46118 .20005 .45161 Mtetra
.57 .629 .871 r
.20005 .45161 .20667 .46118 .21657 .45964 .20993 .45032 Mtetra
.565 .634 .878 r
.20993 .45032 .21657 .45964 .22654 .45791 .21986 .4491 Mtetra
.564 .647 .891 r
.21986 .4491 .22654 .45791 .23657 .45597 .22984 .44786 Mtetra
.564 .668 .908 r
.22984 .44786 .23657 .45597 .24668 .45375 .23988 .44653 Mtetra
.565 .697 .93 r
.23988 .44653 .24668 .45375 .25685 .45126 .24998 .44504 Mtetra
.565 .732 .953 r
.24998 .44504 .25685 .45126 .26709 .44848 .26016 .44333 Mtetra
.561 .771 .976 r
.26016 .44333 .26709 .44848 .27739 .44545 .2704 .44141 Mtetra
.552 .81 .994 r
.2704 .44141 .27739 .44545 .28776 .4422 .28071 .43923 Mtetra
.532 .843 .999 r
.28071 .43923 .28776 .4422 .29818 .43875 .29109 .43683 Mtetra
.5 .864 .986 r
.29109 .43683 .29818 .43875 .30865 .43515 .30153 .43419 Mtetra
.455 .867 .952 r
.30153 .43419 .30865 .43515 .31916 .43141 .31203 .43136 Mtetra
.401 .852 .899 r
.31203 .43136 .31916 .43141 .32973 .42758 .32259 .42834 Mtetra
.342 .822 .833 r
.32259 .42834 .32973 .42758 .34033 .42369 .3332 .42516 Mtetra
.285 .783 .762 r
.3332 .42516 .34033 .42369 .35098 .41975 .34387 .42184 Mtetra
.233 .741 .695 r
.34387 .42184 .35098 .41975 .36167 .41578 .35459 .41842 Mtetra
0 0 0 r
.35459 .41842 .36167 .41578 .3724 .41182 .36535 .4149 Mtetra
.36535 .4149 .3724 .41182 .38317 .40786 .37616 .41131 Mtetra
.37616 .41131 .38317 .40786 .39398 .40393 .38702 .40767 Mtetra
.38702 .40767 .39398 .40393 .40483 .40003 .39792 .40399 Mtetra
.39792 .40399 .40483 .40003 .41572 .39617 .40887 .40029 Mtetra
.40887 .40029 .41572 .39617 .42665 .39235 .41986 .39657 Mtetra
.41986 .39657 .42665 .39235 .43762 .38858 .43089 .39283 Mtetra
.43089 .39283 .43762 .38858 .44864 .38486 .44198 .38909 Mtetra
.44198 .38909 .44864 .38486 .4597 .38119 .4531 .38534 Mtetra
.4531 .38534 .4597 .38119 .4708 .37756 .46428 .38158 Mtetra
.46428 .38158 .4708 .37756 .48195 .37398 .47549 .3778 Mtetra
.47549 .3778 .48195 .37398 .49314 .37043 .48676 .374 Mtetra
.48676 .374 .49314 .37043 .50439 .36692 .49807 .37016 Mtetra
.49807 .37016 .50439 .36692 .51568 .36343 .50943 .36626 Mtetra
.50943 .36626 .51568 .36343 .52702 .35995 .52084 .36229 Mtetra
.52084 .36229 .52702 .35995 .53841 .35647 .53229 .35823 Mtetra
.288 .778 .718 r
.53229 .35823 .53841 .35647 .54985 .35297 .54379 .35405 Mtetra
.364 .832 .792 r
.54379 .35405 .54985 .35297 .56134 .34942 .55533 .34972 Mtetra
.446 .881 .863 r
.55533 .34972 .56134 .34942 .57287 .34581 .56692 .34524 Mtetra
.528 .915 .923 r
.56692 .34524 .57287 .34581 .58446 .34209 .57854 .34056 Mtetra
.599 .928 .962 r
.57854 .34056 .58446 .34209 .5961 .33824 .59021 .33567 Mtetra
.653 .919 .977 r
.59021 .33567 .5961 .33824 .60778 .33423 .60192 .33054 Mtetra
.689 .893 .971 r
.60192 .33054 .60778 .33423 .6195 .33002 .61365 .32516 Mtetra
.71 .858 .952 r
.61365 .32516 .6195 .33002 .63126 .32557 .62542 .31953 Mtetra
.719 .82 .927 r
.62542 .31953 .63126 .32557 .64306 .32085 .63722 .31365 Mtetra
.722 .784 .901 r
.63722 .31365 .64306 .32085 .65489 .31584 .64905 .30755 Mtetra
.72 .752 .878 r
.64905 .30755 .65489 .31584 .66676 .31054 .66091 .30128 Mtetra
.716 .726 .859 r
.66091 .30128 .66676 .31054 .67865 .30495 .67279 .29489 Mtetra
.71 .706 .844 r
.67279 .29489 .67865 .30495 .69057 .29912 .68471 .28847 Mtetra
.704 .692 .836 r
.68471 .28847 .69057 .29912 .70251 .29309 .69666 .28212 Mtetra
.699 .683 .832 r
.69666 .28212 .70251 .29309 .71448 .28695 .70866 .2759 Mtetra
.693 .68 .833 r
.70866 .2759 .71448 .28695 .72649 .28078 .72071 .2699 Mtetra
.689 .682 .839 r
.72071 .2699 .72649 .28078 .73854 .27462 .73281 .26412 Mtetra
.684 .689 .849 r
.73281 .26412 .73854 .27462 .75063 .26857 .74497 .2586 Mtetra
.682 .701 .862 r
.74497 .2586 .75063 .26857 .76277 .2626 .75719 .25329 Mtetra
.681 .718 .877 r
.75719 .25329 .76277 .2626 .77495 .25673 .76946 .24814 Mtetra
.68 .738 .895 r
.76946 .24814 .77495 .25673 .78718 .25095 .7818 .24311 Mtetra
.673 .755 .913 r
.12449 .45992 .13161 .46613 .14132 .46351 .13436 .45611 Mtetra
.666 .718 .888 r
.13436 .45611 .14132 .46351 .15105 .46102 .14425 .45239 Mtetra
.655 .683 .864 r
.14425 .45239 .15105 .46102 .16081 .45868 .15415 .44885 Mtetra
.642 .65 .843 r
.15415 .44885 .16081 .45868 .17059 .45655 .16406 .44557 Mtetra
.626 .621 .826 r
.16406 .44557 .17059 .45655 .18038 .45468 .17397 .44265 Mtetra
.612 .596 .811 r
.17397 .44265 .18038 .45468 .1902 .45303 .18388 .44011 Mtetra
.596 .575 .8 r
.18388 .44011 .1902 .45303 .20005 .45161 .19379 .43801 Mtetra
.584 .558 .792 r
.19379 .43801 .20005 .45161 .20993 .45032 .20371 .4363 Mtetra
.572 .547 .788 r
.20371 .4363 .20993 .45032 .21986 .4491 .21364 .43495 Mtetra
.564 .541 .788 r
.21364 .43495 .21986 .4491 .22984 .44786 .2236 .43387 Mtetra
.559 .541 .791 r
.2236 .43387 .22984 .44786 .23988 .44653 .23359 .43297 Mtetra
.556 .547 .799 r
.23359 .43297 .23988 .44653 .24998 .44504 .24364 .43213 Mtetra
.557 .558 .811 r
.24364 .43213 .24998 .44504 .26016 .44333 .25374 .43126 Mtetra
.559 .575 .826 r
.25374 .43126 .26016 .44333 .2704 .44141 .26391 .43029 Mtetra
.563 .597 .845 r
.26391 .43029 .2704 .44141 .28071 .43923 .27415 .42916 Mtetra
.568 .623 .866 r
.27415 .42916 .28071 .43923 .29109 .43683 .28446 .42783 Mtetra
.574 .653 .89 r
.28446 .42783 .29109 .43683 .30153 .43419 .29483 .42627 Mtetra
.579 .687 .914 r
.29483 .42627 .30153 .43419 .31203 .43136 .30528 .42448 Mtetra
.583 .722 .939 r
.30528 .42448 .31203 .43136 .32259 .42834 .3158 .42246 Mtetra
.585 .758 .961 r
.3158 .42246 .32259 .42834 .3332 .42516 .32638 .42021 Mtetra
.583 .793 .979 r
.32638 .42021 .3332 .42516 .34387 .42184 .33703 .41774 Mtetra
.577 .823 .991 r
.33703 .41774 .34387 .42184 .35459 .41842 .34773 .41506 Mtetra
.567 .848 .997 r
.34773 .41506 .35459 .41842 .36535 .4149 .3585 .4122 Mtetra
.555 .867 .995 r
.3585 .4122 .36535 .4149 .37616 .41131 .36932 .40917 Mtetra
.54 .879 .988 r
.36932 .40917 .37616 .41131 .38702 .40767 .3802 .40599 Mtetra
.526 .887 .978 r
.3802 .40599 .38702 .40767 .39792 .40399 .39113 .40267 Mtetra
.513 .89 .966 r
.39113 .40267 .39792 .40399 .40887 .40029 .40211 .39923 Mtetra
.504 .892 .956 r
.40211 .39923 .40887 .40029 .41986 .39657 .41315 .39568 Mtetra
.5 .894 .948 r
.41315 .39568 .41986 .39657 .43089 .39283 .42423 .39202 Mtetra
.501 .896 .945 r
.42423 .39202 .43089 .39283 .44198 .38909 .43536 .38825 Mtetra
.509 .899 .946 r
.43536 .38825 .44198 .38909 .4531 .38534 .44654 .38438 Mtetra
.524 .904 .951 r
.44654 .38438 .4531 .38534 .46428 .38158 .45777 .38041 Mtetra
.544 .909 .959 r
.45777 .38041 .46428 .38158 .47549 .3778 .46904 .37632 Mtetra
.569 .913 .969 r
.46904 .37632 .47549 .3778 .48676 .374 .48036 .37211 Mtetra
.596 .913 .978 r
.48036 .37211 .48676 .374 .49807 .37016 .49173 .36775 Mtetra
.625 .909 .983 r
.49173 .36775 .49807 .37016 .50943 .36626 .50314 .36324 Mtetra
.651 .898 .982 r
.50314 .36324 .50943 .36626 .52084 .36229 .51459 .35855 Mtetra
.674 .881 .975 r
.51459 .35855 .52084 .36229 .53229 .35823 .52609 .35367 Mtetra
.692 .857 .961 r
.52609 .35367 .53229 .35823 .54379 .35405 .53762 .34858 Mtetra
.704 .829 .942 r
.53762 .34858 .54379 .35405 .55533 .34972 .5492 .34326 Mtetra
.711 .798 .919 r
.5492 .34326 .55533 .34972 .56692 .34524 .56081 .3377 Mtetra
.713 .766 .894 r
.56081 .3377 .56692 .34524 .57854 .34056 .57245 .3319 Mtetra
.713 .736 .869 r
.57245 .3319 .57854 .34056 .59021 .33567 .58413 .32584 Mtetra
.71 .707 .846 r
.58413 .32584 .59021 .33567 .60192 .33054 .59583 .31955 Mtetra
.706 .682 .825 r
.59583 .31955 .60192 .33054 .61365 .32516 .60756 .31304 Mtetra
.701 .66 .806 r
.60756 .31304 .61365 .32516 .62542 .31953 .61932 .30636 Mtetra
.695 .641 .791 r
.61932 .30636 .62542 .31953 .63722 .31365 .63111 .29956 Mtetra
.689 .625 .779 r
.63111 .29956 .63722 .31365 .64905 .30755 .64292 .29271 Mtetra
.683 .612 .77 r
.64292 .29271 .64905 .30755 .66091 .30128 .65476 .28592 Mtetra
.677 .603 .766 r
.65476 .28592 .66091 .30128 .67279 .29489 .66665 .2793 Mtetra
.671 .597 .765 r
.66665 .2793 .67279 .29489 .68471 .28847 .67858 .27294 Mtetra
.664 .595 .768 r
.67858 .27294 .68471 .28847 .69666 .28212 .69056 .26696 Mtetra
.659 .597 .775 r
.69056 .26696 .69666 .28212 .70866 .2759 .7026 .26137 Mtetra
.653 .603 .786 r
.7026 .26137 .70866 .2759 .72071 .2699 .71472 .25623 Mtetra
.649 .614 .801 r
.71472 .25623 .72071 .2699 .73281 .26412 .7269 .25147 Mtetra
.645 .629 .82 r
.7269 .25147 .73281 .26412 .74497 .2586 .73916 .24709 Mtetra
.642 .65 .843 r
.73916 .24709 .74497 .2586 .75719 .25329 .7515 .24298 Mtetra
.641 .677 .868 r
.7515 .24298 .75719 .25329 .76946 .24814 .7639 .23905 Mtetra
.64 .708 .896 r
.7639 .23905 .76946 .24814 .7818 .24311 .77637 .23521 Mtetra
.715 .763 .89 r
.11732 .45366 .12449 .45992 .13436 .45611 .12736 .44856 Mtetra
.706 .726 .865 r
.12736 .44856 .13436 .45611 .14425 .45239 .13743 .44348 Mtetra
.694 .69 .842 r
.13743 .44348 .14425 .45239 .15415 .44885 .14751 .43849 Mtetra
.68 .655 .819 r
.14751 .43849 .15415 .44885 .16406 .44557 .15761 .43368 Mtetra
.664 .623 .798 r
.15761 .43368 .16406 .44557 .17397 .44265 .1677 .42912 Mtetra
.648 .591 .777 r
.1677 .42912 .17397 .44265 .18388 .44011 .17779 .42488 Mtetra
.631 .562 .759 r
.17779 .42488 .18388 .44011 .19379 .43801 .18787 .42105 Mtetra
.615 .536 .741 r
.18787 .42105 .19379 .43801 .20371 .4363 .19794 .41763 Mtetra
.601 .512 .726 r
.19794 .41763 .20371 .4363 .21364 .43495 .20801 .41468 Mtetra
.588 .492 .713 r
.20801 .41468 .21364 .43495 .2236 .43387 .21808 .41214 Mtetra
.578 .476 .702 r
.21808 .41214 .2236 .43387 .23359 .43297 .22815 .41 Mtetra
.57 .464 .694 r
.22815 .41 .23359 .43297 .24364 .43213 .23825 .40817 Mtetra
.565 .455 .688 r
.23825 .40817 .24364 .43213 .25374 .43126 .24838 .40656 Mtetra
.561 .449 .683 r
.24838 .40656 .25374 .43126 .26391 .43029 .25855 .40511 Mtetra
.559 .446 .681 r
.25855 .40511 .26391 .43029 .27415 .42916 .26877 .40372 Mtetra
.559 .445 .68 r
.26877 .40372 .27415 .42916 .28446 .42783 .27903 .40234 Mtetra
.56 .445 .68 r
.27903 .40234 .28446 .42783 .29483 .42627 .28936 .40092 Mtetra
.561 .447 .681 r
.28936 .40092 .29483 .42627 .30528 .42448 .29975 .3994 Mtetra
.564 .451 .683 r
.29975 .3994 .30528 .42448 .3158 .42246 .3102 .39776 Mtetra
.566 .455 .686 r
.3102 .39776 .3158 .42246 .32638 .42021 .32072 .39597 Mtetra
.57 .46 .689 r
.32072 .39597 .32638 .42021 .33703 .41774 .3313 .39401 Mtetra
.574 .465 .693 r
.3313 .39401 .33703 .41774 .34773 .41506 .34195 .39187 Mtetra
.578 .471 .696 r
.34195 .39187 .34773 .41506 .3585 .4122 .35265 .38952 Mtetra
.582 .477 .7 r
.35265 .38952 .3585 .4122 .36932 .40917 .36342 .38697 Mtetra
.586 .483 .704 r
.36342 .38697 .36932 .40917 .3802 .40599 .37426 .38422 Mtetra
.591 .489 .707 r
.37426 .38422 .3802 .40599 .39113 .40267 .38515 .38125 Mtetra
.595 .495 .71 r
.38515 .38125 .39113 .40267 .40211 .39923 .3961 .37808 Mtetra
.599 .499 .712 r
.3961 .37808 .40211 .39923 .41315 .39568 .4071 .37469 Mtetra
.603 .503 .713 r
.4071 .37469 .41315 .39568 .42423 .39202 .41816 .3711 Mtetra
.607 .506 .714 r
.41816 .3711 .42423 .39202 .43536 .38825 .42927 .36729 Mtetra
.61 .508 .713 r
.42927 .36729 .43536 .38825 .44654 .38438 .44044 .36328 Mtetra
.613 .509 .712 r
.44044 .36328 .44654 .38438 .45777 .38041 .45165 .35905 Mtetra
.615 .509 .71 r
.45165 .35905 .45777 .38041 .46904 .37632 .46291 .35461 Mtetra
.617 .508 .707 r
.46291 .35461 .46904 .37632 .48036 .37211 .47421 .34996 Mtetra
.619 .507 .704 r
.47421 .34996 .48036 .37211 .49173 .36775 .48556 .34509 Mtetra
.62 .505 .7 r
.48556 .34509 .49173 .36775 .50314 .36324 .49696 .34 Mtetra
.621 .502 .696 r
.49696 .34 .50314 .36324 .51459 .35855 .50839 .33471 Mtetra
.622 .499 .692 r
.50839 .33471 .51459 .35855 .52609 .35367 .51986 .32921 Mtetra
.623 .496 .688 r
.51986 .32921 .52609 .35367 .53762 .34858 .53136 .32351 Mtetra
.623 .494 .684 r
.53136 .32351 .53762 .34858 .5492 .34326 .5429 .31763 Mtetra
.623 .491 .681 r
.5429 .31763 .5492 .34326 .56081 .3377 .55448 .31159 Mtetra
.623 .489 .678 r
.55448 .31159 .56081 .3377 .57245 .3319 .56608 .30541 Mtetra
.623 .487 .676 r
.56608 .30541 .57245 .3319 .58413 .32584 .57772 .29914 Mtetra
.623 .486 .675 r
.57772 .29914 .58413 .32584 .59583 .31955 .58939 .2928 Mtetra
.58939 .2928 .59583 .31955 .60756 .31304 .60109 .28647 Mtetra
.622 .487 .676 r
.60109 .28647 .60756 .31304 .61932 .30636 .61283 .28019 Mtetra
.622 .488 .679 r
.61283 .28019 .61932 .30636 .63111 .29956 .6246 .27406 Mtetra
.621 .491 .683 r
.6246 .27406 .63111 .29956 .64292 .29271 .63642 .26816 Mtetra
.62 .495 .689 r
.63642 .26816 .64292 .29271 .65476 .28592 .64829 .26256 Mtetra
.618 .501 .698 r
.64829 .26256 .65476 .28592 .66665 .2793 .66021 .25737 Mtetra
.616 .509 .71 r
.66021 .25737 .66665 .2793 .67858 .27294 .6722 .2526 Mtetra
.613 .52 .724 r
.6722 .2526 .67858 .27294 .69056 .26696 .68426 .2483 Mtetra
.611 .533 .742 r
.68426 .2483 .69056 .26696 .7026 .26137 .6964 .24444 Mtetra
.608 .549 .763 r
.6964 .24444 .7026 .26137 .71472 .25623 .70862 .24099 Mtetra
.605 .569 .787 r
.70862 .24099 .71472 .25623 .7269 .25147 .72092 .23788 Mtetra
.603 .593 .814 r
.72092 .23788 .7269 .25147 .73916 .24709 .7333 .23503 Mtetra
.6 .619 .842 r
.7333 .23503 .73916 .24709 .7515 .24298 .74576 .23236 Mtetra
.597 .65 .873 r
.74576 .23236 .7515 .24298 .7639 .23905 .75829 .22979 Mtetra
.594 .684 .904 r
.75829 .22979 .7639 .23905 .77637 .23521 .7709 .22725 Mtetra
.742 .767 .873 r
.1101 .44736 .11732 .45366 .12736 .44856 .12029 .44124 Mtetra
.735 .739 .854 r
.12029 .44124 .12736 .44856 .13743 .44348 .13051 .43506 Mtetra
.726 .711 .836 r
.13051 .43506 .13743 .44348 .14751 .43849 .14076 .42885 Mtetra
.715 .682 .817 r
.14076 .42885 .14751 .43849 .15761 .43368 .15102 .42267 Mtetra
.703 .653 .798 r
.15102 .42267 .15761 .43368 .1677 .42912 .1613 .41653 Mtetra
.689 .624 .778 r
.1613 .41653 .1677 .42912 .17779 .42488 .17158 .41054 Mtetra
.673 .594 .759 r
.17158 .41054 .17779 .42488 .18787 .42105 .18186 .40476 Mtetra
.657 .565 .74 r
.18186 .40476 .18787 .42105 .19794 .41763 .19214 .39929 Mtetra
.64 .538 .723 r
.19214 .39929 .19794 .41763 .20801 .41468 .2024 .39421 Mtetra
.624 .513 .707 r
.2024 .39421 .20801 .41468 .21808 .41214 .21265 .38956 Mtetra
.609 .491 .693 r
.21265 .38956 .21808 .41214 .22815 .41 .22289 .38541 Mtetra
.597 .472 .681 r
.22289 .38541 .22815 .41 .23825 .40817 .23312 .38171 Mtetra
.586 .457 .671 r
.23312 .38171 .23825 .40817 .24838 .40656 .24335 .37846 Mtetra
.578 .444 .663 r
.24335 .37846 .24838 .40656 .25855 .40511 .25359 .37558 Mtetra
.571 .435 .656 r
.25359 .37558 .25855 .40511 .26877 .40372 .26384 .37301 Mtetra
.566 .427 .651 r
.26384 .37301 .26877 .40372 .27903 .40234 .27413 .37068 Mtetra
.563 .422 .648 r
.27413 .37068 .27903 .40234 .28936 .40092 .28445 .36852 Mtetra
.56 .418 .645 r
.28445 .36852 .28936 .40092 .29975 .3994 .29482 .36647 Mtetra
.559 .416 .643 r
.29482 .36647 .29975 .3994 .3102 .39776 .30523 .36447 Mtetra
.559 .415 .642 r
.30523 .36447 .3102 .39776 .32072 .39597 .31569 .36248 Mtetra
.31569 .36248 .32072 .39597 .3313 .39401 .32621 .36043 Mtetra
.56 .416 .642 r
.32621 .36043 .3313 .39401 .34195 .39187 .33679 .35828 Mtetra
.562 .417 .642 r
.33679 .35828 .34195 .39187 .35265 .38952 .34743 .356 Mtetra
.564 .419 .642 r
.34743 .356 .35265 .38952 .36342 .38697 .35813 .35356 Mtetra
.566 .421 .643 r
.35813 .35356 .36342 .38697 .37426 .38422 .36889 .35091 Mtetra
.569 .423 .644 r
.36889 .35091 .37426 .38422 .38515 .38125 .37971 .34806 Mtetra
.572 .426 .644 r
.37971 .34806 .38515 .38125 .3961 .37808 .39059 .34496 Mtetra
.575 .428 .645 r
.39059 .34496 .3961 .37808 .4071 .37469 .40153 .34163 Mtetra
.578 .431 .645 r
.40153 .34163 .4071 .37469 .41816 .3711 .41253 .33803 Mtetra
.581 .433 .645 r
.41253 .33803 .41816 .3711 .42927 .36729 .42358 .33417 Mtetra
.583 .435 .645 r
.42358 .33417 .42927 .36729 .44044 .36328 .43469 .33006 Mtetra
.586 .436 .645 r
.43469 .33006 .44044 .36328 .45165 .35905 .44584 .32568 Mtetra
.589 .438 .644 r
.44584 .32568 .45165 .35905 .46291 .35461 .45704 .32106 Mtetra
.591 .439 .644 r
.45704 .32106 .46291 .35461 .47421 .34996 .46829 .31619 Mtetra
.593 .44 .643 r
.46829 .31619 .47421 .34996 .48556 .34509 .47958 .3111 Mtetra
.594 .44 .642 r
.47958 .3111 .48556 .34509 .49696 .34 .49091 .30581 Mtetra
.596 .441 .642 r
.49091 .30581 .49696 .34 .50839 .33471 .50228 .30035 Mtetra
.597 .441 .641 r
.50228 .30035 .50839 .33471 .51986 .32921 .51368 .29474 Mtetra
.51368 .29474 .51986 .32921 .53136 .32351 .52513 .28904 Mtetra
.598 .442 .641 r
.52513 .28904 .53136 .32351 .5429 .31763 .5366 .28327 Mtetra
.5366 .28327 .5429 .31763 .55448 .31159 .54811 .27749 Mtetra
.598 .443 .642 r
.54811 .27749 .55448 .31159 .56608 .30541 .55966 .27176 Mtetra
.597 .444 .644 r
.55966 .27176 .56608 .30541 .57772 .29914 .57125 .26613 Mtetra
.597 .445 .647 r
.57125 .26613 .57772 .29914 .58939 .2928 .58287 .26067 Mtetra
.596 .448 .65 r
.58287 .26067 .58939 .2928 .60109 .28647 .59454 .25545 Mtetra
.594 .451 .656 r
.59454 .25545 .60109 .28647 .61283 .28019 .60626 .25055 Mtetra
.593 .454 .662 r
.60626 .25055 .61283 .28019 .6246 .27406 .61804 .24601 Mtetra
.59 .459 .671 r
.61804 .24601 .6246 .27406 .63642 .26816 .62988 .24194 Mtetra
.587 .466 .682 r
.62988 .24194 .63642 .26816 .64829 .26256 .64179 .23833 Mtetra
.584 .475 .696 r
.64179 .23833 .64829 .26256 .66021 .25737 .65377 .23523 Mtetra
.581 .486 .712 r
.65377 .23523 .66021 .25737 .6722 .2526 .66584 .23258 Mtetra
.577 .501 .732 r
.66584 .23258 .6722 .2526 .68426 .2483 .67799 .23034 Mtetra
.573 .518 .755 r
.67799 .23034 .68426 .2483 .6964 .24444 .69023 .22842 Mtetra
.57 .539 .781 r
.69023 .22842 .6964 .24444 .70862 .24099 .70255 .22672 Mtetra
.567 .563 .808 r
.70255 .22672 .70862 .24099 .72092 .23788 .71496 .22518 Mtetra
.564 .589 .836 r
.71496 .22518 .72092 .23788 .7333 .23503 .72745 .2237 Mtetra
.561 .615 .864 r
.72745 .2237 .7333 .23503 .74576 .23236 .74002 .22224 Mtetra
.557 .643 .891 r
.74002 .22224 .74576 .23236 .75829 .22979 .75266 .22077 Mtetra
.552 .671 .917 r
.75266 .22077 .75829 .22979 .7709 .22725 .76539 .21923 Mtetra
.744 .767 .871 r
.10283 .44102 .1101 .44736 .12029 .44124 .11306 .43476 Mtetra
.745 .764 .868 r
.11306 .43476 .12029 .44124 .13051 .43506 .12333 .42841 Mtetra
.746 .76 .864 r
.12333 .42841 .13051 .43506 .14076 .42885 .13363 .42197 Mtetra
.745 .754 .86 r
.13363 .42197 .14076 .42885 .15102 .42267 .14395 .41545 Mtetra
.744 .746 .853 r
.14395 .41545 .15102 .42267 .1613 .41653 .1543 .40886 Mtetra
.741 .735 .846 r
.1543 .40886 .1613 .41653 .17158 .41054 .16468 .40224 Mtetra
.735 .719 .837 r
.16468 .40224 .17158 .41054 .18186 .40476 .17507 .39565 Mtetra
.725 .699 .825 r
.17507 .39565 .18186 .40476 .19214 .39929 .18547 .38916 Mtetra
.713 .676 .812 r
.18547 .38916 .19214 .39929 .2024 .39421 .19588 .38284 Mtetra
.699 .649 .796 r
.19588 .38284 .2024 .39421 .21265 .38956 .20628 .37675 Mtetra
.683 .62 .78 r
.20628 .37675 .21265 .38956 .22289 .38541 .21667 .37096 Mtetra
.666 .591 .762 r
.21667 .37096 .22289 .38541 .23312 .38171 .22707 .36548 Mtetra
.65 .564 .744 r
.22707 .36548 .23312 .38171 .24335 .37846 .23746 .36036 Mtetra
.635 .538 .728 r
.23746 .36036 .24335 .37846 .25359 .37558 .24785 .35555 Mtetra
.622 .516 .712 r
.24785 .35555 .25359 .37558 .26384 .37301 .25825 .35104 Mtetra
.611 .497 .698 r
.25825 .35104 .26384 .37301 .27413 .37068 .26866 .3468 Mtetra
.602 .48 .686 r
.26866 .3468 .27413 .37068 .28445 .36852 .27909 .34278 Mtetra
.594 .466 .675 r
.27909 .34278 .28445 .36852 .29482 .36647 .28954 .33895 Mtetra
.588 .454 .666 r
.28954 .33895 .29482 .36647 .30523 .36447 .30003 .33528 Mtetra
.583 .445 .658 r
.30003 .33528 .30523 .36447 .31569 .36248 .31054 .33172 Mtetra
.58 .437 .652 r
.31054 .33172 .31569 .36248 .32621 .36043 .3211 .32824 Mtetra
.577 .43 .646 r
.3211 .32824 .32621 .36043 .33679 .35828 .33169 .32481 Mtetra
.574 .425 .641 r
.33169 .32481 .33679 .35828 .34743 .356 .34233 .3214 Mtetra
.573 .421 .637 r
.34233 .3214 .34743 .356 .35813 .35356 .35301 .31798 Mtetra
.572 .418 .634 r
.35301 .31798 .35813 .35356 .36889 .35091 .36374 .31451 Mtetra
.572 .416 .632 r
.36374 .31451 .36889 .35091 .37971 .34806 .37452 .31099 Mtetra
.572 .415 .63 r
.37452 .31099 .37971 .34806 .39059 .34496 .38535 .30738 Mtetra
.572 .414 .628 r
.38535 .30738 .39059 .34496 .40153 .34163 .39623 .30369 Mtetra
.572 .413 .628 r
.39623 .30369 .40153 .34163 .41253 .33803 .40715 .29988 Mtetra
.573 .414 .627 r
.40715 .29988 .41253 .33803 .42358 .33417 .41812 .29597 Mtetra
.574 .414 .627 r
.41812 .29597 .42358 .33417 .43469 .33006 .42915 .29195 Mtetra
.575 .415 .628 r
.42915 .29195 .43469 .33006 .44584 .32568 .44021 .28783 Mtetra
.576 .417 .628 r
.44021 .28783 .44584 .32568 .45704 .32106 .45133 .28361 Mtetra
.578 .419 .63 r
.45133 .28361 .45704 .32106 .46829 .31619 .46249 .27931 Mtetra
.579 .421 .632 r
.46249 .27931 .46829 .31619 .47958 .3111 .47369 .27495 Mtetra
.58 .424 .634 r
.47369 .27495 .47958 .3111 .49091 .30581 .48494 .27054 Mtetra
.582 .427 .637 r
.48494 .27054 .49091 .30581 .50228 .30035 .49623 .26612 Mtetra
.583 .431 .641 r
.49623 .26612 .50228 .30035 .51368 .29474 .50756 .26172 Mtetra
.584 .436 .646 r
.50756 .26172 .51368 .29474 .52513 .28904 .51894 .25736 Mtetra
.586 .441 .651 r
.51894 .25736 .52513 .28904 .5366 .28327 .53037 .25308 Mtetra
.587 .447 .658 r
.53037 .25308 .5366 .28327 .54811 .27749 .54184 .24892 Mtetra
.588 .454 .666 r
.54184 .24892 .54811 .27749 .55966 .27176 .55336 .24491 Mtetra
.589 .462 .676 r
.55336 .24491 .55966 .27176 .57125 .26613 .56493 .24109 Mtetra
.589 .472 .687 r
.56493 .24109 .57125 .26613 .58287 .26067 .57656 .2375 Mtetra
.589 .483 .701 r
.57656 .2375 .58287 .26067 .59454 .25545 .58824 .23418 Mtetra
.588 .495 .717 r
.58824 .23418 .59454 .25545 .60626 .25055 .59999 .23117 Mtetra
.586 .51 .735 r
.59999 .23117 .60626 .25055 .61804 .24601 .61181 .22849 Mtetra
.582 .526 .757 r
.61181 .22849 .61804 .24601 .62988 .24194 .6237 .22617 Mtetra
.578 .544 .781 r
.6237 .22617 .62988 .24194 .64179 .23833 .63567 .22418 Mtetra
.571 .564 .807 r
.63567 .22418 .64179 .23833 .65377 .23523 .64772 .2225 Mtetra
.563 .585 .833 r
.64772 .2225 .65377 .23523 .66584 .23258 .65986 .22106 Mtetra
.555 .605 .859 r
.65986 .22106 .66584 .23258 .67799 .23034 .67208 .21981 Mtetra
.547 .625 .881 r
.67208 .21981 .67799 .23034 .69023 .22842 .68438 .21867 Mtetra
.541 .642 .899 r
.68438 .21867 .69023 .22842 .70255 .22672 .69676 .21756 Mtetra
.537 .657 .914 r
.69676 .21756 .70255 .22672 .71496 .22518 .70922 .21643 Mtetra
.536 .67 .924 r
.70922 .21643 .71496 .22518 .72745 .2237 .72176 .21523 Mtetra
.535 .68 .931 r
.72176 .21523 .72745 .2237 .74002 .22224 .73437 .21395 Mtetra
.537 .687 .936 r
.73437 .21395 .74002 .22224 .75266 .22077 .74706 .21259 Mtetra
.539 .693 .939 r
.74706 .21259 .75266 .22077 .76539 .21923 .75983 .21113 Mtetra
.73 .765 .881 r
.09551 .43462 .10283 .44102 .11306 .43476 .1057 .42889 Mtetra
.736 .782 .89 r
.1057 .42889 .11306 .43476 .12333 .42841 .11593 .42305 Mtetra
.742 .8 .898 r
.11593 .42305 .12333 .42841 .13363 .42197 .12619 .41711 Mtetra
.749 .817 .906 r
.12619 .41711 .13363 .42197 .14395 .41545 .13649 .41104 Mtetra
.755 .833 .912 r
.13649 .41104 .14395 .41545 .1543 .40886 .14684 .4048 Mtetra
.761 .846 .916 r
.14684 .4048 .1543 .40886 .16468 .40224 .15722 .39842 Mtetra
.765 .855 .917 r
.15722 .39842 .16468 .40224 .17507 .39565 .16764 .39191 Mtetra
.768 .859 .917 r
.16764 .39191 .17507 .39565 .18547 .38916 .17809 .38528 Mtetra
.77 .856 .914 r
.17809 .38528 .18547 .38916 .19588 .38284 .18857 .37857 Mtetra
.769 .844 .908 r
.18857 .37857 .19588 .38284 .20628 .37675 .19907 .37183 Mtetra
.765 .823 .898 r
.19907 .37183 .20628 .37675 .21667 .37096 .20959 .3651 Mtetra
.757 .794 .883 r
.20959 .3651 .21667 .37096 .22707 .36548 .22013 .35843 Mtetra
.744 .758 .864 r
.22013 .35843 .22707 .36548 .23746 .36036 .23067 .35187 Mtetra
.729 .719 .842 r
.23067 .35187 .23746 .36036 .24785 .35555 .24123 .34546 Mtetra
.711 .68 .818 r
.24123 .34546 .24785 .35555 .25825 .35104 .25179 .33923 Mtetra
.694 .644 .795 r
.25179 .33923 .25825 .35104 .26866 .3468 .26236 .33317 Mtetra
.678 .61 .772 r
.26236 .33317 .26866 .3468 .27909 .34278 .27294 .32729 Mtetra
.663 .58 .752 r
.27294 .32729 .27909 .34278 .28954 .33895 .28353 .3216 Mtetra
.65 .555 .734 r
.28353 .3216 .28954 .33895 .30003 .33528 .29414 .3161 Mtetra
.638 .533 .719 r
.29414 .3161 .30003 .33528 .31054 .33172 .30476 .31078 Mtetra
.628 .514 .705 r
.30476 .31078 .31054 .33172 .3211 .32824 .3154 .30563 Mtetra
.619 .499 .694 r
.3154 .30563 .3211 .32824 .33169 .32481 .32607 .30067 Mtetra
.611 .485 .684 r
.32607 .30067 .33169 .32481 .34233 .3214 .33676 .29586 Mtetra
.605 .475 .677 r
.33676 .29586 .34233 .3214 .35301 .31798 .34747 .29121 Mtetra
.6 .466 .67 r
.34747 .29121 .35301 .31798 .36374 .31451 .35822 .2867 Mtetra
.596 .459 .665 r
.35822 .2867 .36374 .31451 .37452 .31099 .36899 .28232 Mtetra
.592 .453 .661 r
.36899 .28232 .37452 .31099 .38535 .30738 .3798 .27805 Mtetra
.589 .449 .658 r
.3798 .27805 .38535 .30738 .39623 .30369 .39065 .27389 Mtetra
.587 .446 .656 r
.39065 .27389 .39623 .30369 .40715 .29988 .40153 .26984 Mtetra
.585 .444 .656 r
.40153 .26984 .40715 .29988 .41812 .29597 .41246 .26588 Mtetra
.583 .443 .656 r
.41246 .26588 .41812 .29597 .42915 .29195 .42342 .26202 Mtetra
.582 .443 .657 r
.42342 .26202 .42915 .29195 .44021 .28783 .43442 .25826 Mtetra
.581 .444 .659 r
.43442 .25826 .44021 .28783 .45133 .28361 .44547 .25462 Mtetra
.581 .446 .662 r
.44547 .25462 .45133 .28361 .46249 .27931 .45657 .25109 Mtetra
.58 .449 .666 r
.45657 .25109 .46249 .27931 .47369 .27495 .46771 .24769 Mtetra
.58 .453 .671 r
.46771 .24769 .47369 .27495 .48494 .27054 .4789 .24444 Mtetra
.58 .458 .679 r
.4789 .24444 .48494 .27054 .49623 .26612 .49013 .24133 Mtetra
.58 .465 .687 r
.49013 .24133 .49623 .26612 .50756 .26172 .50142 .2384 Mtetra
.58 .474 .698 r
.50142 .2384 .50756 .26172 .51894 .25736 .51277 .23565 Mtetra
.579 .485 .711 r
.51277 .23565 .51894 .25736 .53037 .25308 .52417 .23308 Mtetra
.579 .498 .727 r
.52417 .23308 .53037 .25308 .54184 .24892 .53563 .2307 Mtetra
.578 .514 .747 r
.53563 .2307 .54184 .24892 .55336 .24491 .54716 .22851 Mtetra
.577 .533 .77 r
.54716 .22851 .55336 .24491 .56493 .24109 .55875 .22652 Mtetra
.574 .557 .797 r
.55875 .22652 .56493 .24109 .57656 .2375 .57041 .22472 Mtetra
.569 .584 .829 r
.57041 .22472 .57656 .2375 .58824 .23418 .58214 .2231 Mtetra
.561 .615 .864 r
.58214 .2231 .58824 .23418 .59999 .23117 .59394 .22167 Mtetra
.548 .648 .9 r
.59394 .22167 .59999 .23117 .61181 .22849 .60582 .22039 Mtetra
.53 .682 .935 r
.60582 .22039 .61181 .22849 .6237 .22617 .61778 .21924 Mtetra
.508 .711 .963 r
.61778 .21924 .6237 .22617 .63567 .22418 .62982 .21816 Mtetra
.485 .735 .982 r
.62982 .21816 .63567 .22418 .64772 .2225 .64193 .21709 Mtetra
.468 .751 .991 r
.64193 .21709 .64772 .2225 .65986 .22106 .65412 .216 Mtetra
.46 .761 .995 r
.65412 .216 .65986 .22106 .67208 .21981 .66638 .21483 Mtetra
.463 .766 .996 r
.66638 .21483 .67208 .21981 .68438 .21867 .67872 .21356 Mtetra
.476 .769 .995 r
.67872 .21356 .68438 .21867 .69676 .21756 .69113 .21214 Mtetra
.494 .767 .992 r
.69113 .21214 .69676 .21756 .70922 .21643 .70361 .21058 Mtetra
.514 .761 .986 r
.70361 .21058 .70922 .21643 .72176 .21523 .71616 .20886 Mtetra
.531 .752 .977 r
.71616 .20886 .72176 .21523 .73437 .21395 .72878 .20701 Mtetra
.546 .739 .965 r
.72878 .20701 .73437 .21395 .74706 .21259 .74147 .20504 Mtetra
.557 .725 .952 r
.74147 .20504 .74706 .21259 .75983 .21113 .75422 .20298 Mtetra
.703 .761 .898 r
.08813 .42819 .09551 .43462 .1057 .42889 .09822 .42339 Mtetra
.709 .793 .916 r
.09822 .42339 .1057 .42889 .11593 .42305 .10836 .41849 Mtetra
.715 .826 .933 r
.10836 .41849 .11593 .42305 .12619 .41711 .11853 .41347 Mtetra
.72 .859 .948 r
.11853 .41347 .12619 .41711 .13649 .41104 .12876 .4083 Mtetra
.722 .891 .957 r
.12876 .4083 .13649 .41104 .14684 .4048 .13904 .40293 Mtetra
.72 .919 .961 r
.13904 .40293 .14684 .4048 .15722 .39842 .14936 .39737 Mtetra
.714 .943 .957 r
.14936 .39737 .15722 .39842 .16764 .39191 .15974 .39162 Mtetra
.7 .959 .947 r
.15974 .39162 .16764 .39191 .17809 .38528 .17016 .38571 Mtetra
.681 .967 .929 r
.17016 .38571 .17809 .38528 .18857 .37857 .18062 .37965 Mtetra
.655 .968 .905 r
.18062 .37965 .18857 .37857 .19907 .37183 .19111 .37348 Mtetra
.624 .96 .876 r
.19111 .37348 .19907 .37183 .20959 .3651 .20164 .36725 Mtetra
.588 .946 .843 r
.20164 .36725 .20959 .3651 .22013 .35843 .21219 .361 Mtetra
.55 .928 .81 r
.21219 .361 .22013 .35843 .23067 .35187 .22276 .35478 Mtetra
.515 .907 .779 r
.22276 .35478 .23067 .35187 .24123 .34546 .23335 .34861 Mtetra
.481 .887 .752 r
.23335 .34861 .24123 .34546 .25179 .33923 .24396 .34252 Mtetra
.454 .87 .731 r
.24396 .34252 .25179 .33923 .26236 .33317 .25458 .33653 Mtetra
.431 .856 .716 r
.25458 .33653 .26236 .33317 .27294 .32729 .26522 .33065 Mtetra
.415 .846 .708 r
.26522 .33065 .27294 .32729 .28353 .3216 .27588 .32488 Mtetra
.404 .84 .706 r
.27588 .32488 .28353 .3216 .29414 .3161 .28656 .31923 Mtetra
.398 .837 .711 r
.28656 .31923 .29414 .3161 .30476 .31078 .29726 .31371 Mtetra
.396 .838 .72 r
.29726 .31371 .30476 .31078 .3154 .30563 .30798 .30833 Mtetra
.397 .842 .733 r
.30798 .30833 .3154 .30563 .32607 .30067 .31872 .3031 Mtetra
.401 .846 .749 r
.31872 .3031 .32607 .30067 .33676 .29586 .32948 .29802 Mtetra
.405 .851 .766 r
.32948 .29802 .33676 .29586 .34747 .29121 .34027 .29309 Mtetra
.408 .856 .783 r
.34027 .29309 .34747 .29121 .35822 .2867 .35109 .28832 Mtetra
.41 .858 .798 r
.35109 .28832 .35822 .2867 .36899 .28232 .36193 .28371 Mtetra
.409 .859 .811 r
.36193 .28371 .36899 .28232 .3798 .27805 .37281 .27925 Mtetra
.405 .858 .819 r
.37281 .27925 .3798 .27805 .39065 .27389 .38371 .27495 Mtetra
.397 .853 .823 r
.38371 .27495 .39065 .27389 .40153 .26984 .39466 .27082 Mtetra
.383 .845 .823 r
.39466 .27082 .40153 .26984 .41246 .26588 .40564 .26683 Mtetra
.364 .834 .817 r
.40564 .26683 .41246 .26588 .42342 .26202 .41665 .26301 Mtetra
.34 .819 .804 r
.41665 .26301 .42342 .26202 .43442 .25826 .42771 .25935 Mtetra
.31 .8 .786 r
.42771 .25935 .43442 .25826 .44547 .25462 .43882 .25584 Mtetra
.275 .777 .762 r
.43882 .25584 .44547 .25462 .45657 .25109 .44996 .2525 Mtetra
.237 .749 .732 r
.44996 .2525 .45657 .25109 .46771 .24769 .46116 .24932 Mtetra
.196 .718 .698 r
.46116 .24932 .46771 .24769 .4789 .24444 .4724 .24629 Mtetra
0 0 0 r
.4724 .24629 .4789 .24444 .49013 .24133 .4837 .24343 Mtetra
.4837 .24343 .49013 .24133 .50142 .2384 .49505 .24072 Mtetra
.49505 .24072 .50142 .2384 .51277 .23565 .50646 .23816 Mtetra
.50646 .23816 .51277 .23565 .52417 .23308 .51793 .23574 Mtetra
.51793 .23574 .52417 .23308 .53563 .2307 .52946 .23346 Mtetra
.007 0 0 r
.52946 .23346 .53563 .2307 .54716 .22851 .54105 .23132 Mtetra
.022 0 0 r
.54105 .23132 .54716 .22851 .55875 .22652 .55271 .22929 Mtetra
.032 0 0 r
.55271 .22929 .55875 .22652 .57041 .22472 .56443 .22737 Mtetra
.034 0 0 r
.56443 .22737 .57041 .22472 .58214 .2231 .57623 .22556 Mtetra
.03 0 0 r
.57623 .22556 .58214 .2231 .59394 .22167 .5881 .22384 Mtetra
.015 0 0 r
.5881 .22384 .59394 .22167 .60582 .22039 .60003 .22218 Mtetra
0 0 0 r
.60003 .22218 .60582 .22039 .61778 .21924 .61204 .22055 Mtetra
.61204 .22055 .61778 .21924 .62982 .21816 .62413 .2189 Mtetra
.103 .656 .706 r
.62413 .2189 .62982 .21816 .64193 .21709 .63628 .21719 Mtetra
.169 .707 .778 r
.63628 .21719 .64193 .21709 .65412 .216 .64851 .21538 Mtetra
.244 .757 .85 r
.64851 .21538 .65412 .216 .66638 .21483 .6608 .21342 Mtetra
.323 .798 .914 r
.6608 .21342 .66638 .21483 .67872 .21356 .67316 .2113 Mtetra
.4 .827 .963 r
.67316 .2113 .67872 .21356 .69113 .21214 .68557 .20898 Mtetra
.467 .837 .991 r
.68557 .20898 .69113 .21214 .70361 .21058 .69805 .20646 Mtetra
.521 .832 1 r
.69805 .20646 .70361 .21058 .71616 .20886 .71059 .20375 Mtetra
.559 .813 .993 r
.71059 .20375 .71616 .20886 .72878 .20701 .72319 .20087 Mtetra
.584 .788 .977 r
.72319 .20087 .72878 .20701 .74147 .20504 .73585 .19786 Mtetra
.599 .759 .955 r
.73585 .19786 .74147 .20504 .75422 .20298 .74857 .19475 Mtetra
.658 .752 .919 r
.0807 .4217 .08813 .42819 .09822 .42339 .09065 .41811 Mtetra
.66 .793 .946 r
.09065 .41811 .09822 .42339 .10836 .41849 .10065 .41442 Mtetra
.658 .836 .968 r
.10065 .41442 .10836 .41849 .11853 .41347 .1107 .41062 Mtetra
.649 .878 .983 r
.1107 .41062 .11853 .41347 .12876 .4083 .12081 .40666 Mtetra
.63 .911 .982 r
.12081 .40666 .12876 .4083 .13904 .40293 .13098 .4025 Mtetra
.594 .929 .958 r
.13098 .4025 .13904 .40293 .14936 .39737 .14121 .39815 Mtetra
.538 .923 .907 r
.14121 .39815 .14936 .39737 .15974 .39162 .15149 .39361 Mtetra
.459 .886 .824 r
.15149 .39361 .15974 .39162 .17016 .38571 .16182 .38891 Mtetra
.363 .82 .714 r
.16182 .38891 .17016 .38571 .18062 .37965 .1722 .38408 Mtetra
0 0 0 r
.1722 .38408 .18062 .37965 .19111 .37348 .18263 .37916 Mtetra
.18263 .37916 .19111 .37348 .20164 .36725 .19309 .37418 Mtetra
.19309 .37418 .20164 .36725 .21219 .361 .20358 .36917 Mtetra
.015 0 0 r
.20358 .36917 .21219 .361 .22276 .35478 .21411 .36414 Mtetra
.079 0 0 r
.21411 .36414 .22276 .35478 .23335 .34861 .22467 .35912 Mtetra
.13 0 0 r
.22467 .35912 .23335 .34861 .24396 .34252 .23526 .35411 Mtetra
.17 0 0 r
.23526 .35411 .24396 .34252 .25458 .33653 .24589 .34912 Mtetra
.202 0 .012 r
.24589 .34912 .25458 .33653 .26522 .33065 .25654 .34415 Mtetra
.227 0 .047 r
.25654 .34415 .26522 .33065 .27588 .32488 .26723 .3392 Mtetra
.247 0 .075 r
.26723 .3392 .27588 .32488 .28656 .31923 .27795 .33426 Mtetra
.264 0 .098 r
.27795 .33426 .28656 .31923 .29726 .31371 .2887 .32936 Mtetra
.277 0 .116 r
.2887 .32936 .29726 .31371 .30798 .30833 .29949 .3245 Mtetra
.288 0 .13 r
.29949 .3245 .30798 .30833 .31872 .3031 .3103 .31968 Mtetra
.298 0 .142 r
.3103 .31968 .31872 .3031 .32948 .29802 .32115 .31493 Mtetra
.306 0 .151 r
.32115 .31493 .32948 .29802 .34027 .29309 .33203 .31025 Mtetra
.314 0 .159 r
.33203 .31025 .34027 .29309 .35109 .28832 .34295 .30566 Mtetra
.32 0 .165 r
.34295 .30566 .35109 .28832 .36193 .28371 .3539 .30118 Mtetra
.327 0 .17 r
.3539 .30118 .36193 .28371 .37281 .27925 .36488 .29681 Mtetra
.332 0 .174 r
.36488 .29681 .37281 .27925 .38371 .27495 .3759 .29256 Mtetra
.338 0 .177 r
.3759 .29256 .38371 .27495 .39466 .27082 .38696 .28844 Mtetra
.342 0 .18 r
.38696 .28844 .39466 .27082 .40564 .26683 .39805 .28445 Mtetra
.347 0 .182 r
.39805 .28445 .40564 .26683 .41665 .26301 .40918 .28059 Mtetra
.351 0 .183 r
.40918 .28059 .41665 .26301 .42771 .25935 .42036 .27685 Mtetra
.355 0 .184 r
.42036 .27685 .42771 .25935 .43882 .25584 .43158 .27324 Mtetra
.358 0 .184 r
.43158 .27324 .43882 .25584 .44996 .2525 .44285 .26974 Mtetra
.36 0 .183 r
.44285 .26974 .44996 .2525 .46116 .24932 .45417 .26635 Mtetra
.361 0 .18 r
.45417 .26635 .46116 .24932 .4724 .24629 .46554 .26305 Mtetra
.361 0 .176 r
.46554 .26305 .4724 .24629 .4837 .24343 .47696 .25983 Mtetra
.36 0 .171 r
.47696 .25983 .4837 .24343 .49505 .24072 .48843 .25668 Mtetra
.357 0 .163 r
.48843 .25668 .49505 .24072 .50646 .23816 .49996 .25357 Mtetra
.353 0 .152 r
.49996 .25357 .50646 .23816 .51793 .23574 .51154 .25051 Mtetra
.347 0 .138 r
.51154 .25051 .51793 .23574 .52946 .23346 .52318 .24747 Mtetra
.339 0 .12 r
.52318 .24747 .52946 .23346 .54105 .23132 .53488 .24446 Mtetra
.329 0 .098 r
.53488 .24446 .54105 .23132 .55271 .22929 .54664 .24148 Mtetra
.315 0 .07 r
.54664 .24148 .55271 .22929 .56443 .22737 .55846 .23851 Mtetra
.298 0 .035 r
.55846 .23851 .56443 .22737 .57623 .22556 .57035 .23556 Mtetra
.275 0 0 r
.57035 .23556 .57623 .22556 .5881 .22384 .58229 .23263 Mtetra
.245 0 0 r
.58229 .23263 .5881 .22384 .60003 .22218 .59429 .2297 Mtetra
.206 0 0 r
.59429 .2297 .60003 .22218 .61204 .22055 .60636 .22676 Mtetra
.153 0 0 r
.60636 .22676 .61204 .22055 .62413 .2189 .61849 .22378 Mtetra
.084 0 0 r
.61849 .22378 .62413 .2189 .63628 .21719 .63068 .22075 Mtetra
0 0 0 r
.63068 .22075 .63628 .21719 .64851 .21538 .64293 .21762 Mtetra
.64293 .21762 .64851 .21538 .6608 .21342 .65524 .21436 Mtetra
.242 .754 .745 r
.65524 .21436 .6608 .21342 .67316 .2113 .66761 .21093 Mtetra
.37 .837 .867 r
.66761 .21093 .67316 .2113 .68557 .20898 .68003 .2073 Mtetra
.479 .882 .95 r
.68003 .2073 .68557 .20898 .69805 .20646 .6925 .20347 Mtetra
.56 .888 .987 r
.6925 .20347 .69805 .20646 .71059 .20375 .70502 .19944 Mtetra
.611 .867 .991 r
.70502 .19944 .71059 .20375 .72319 .20087 .71759 .19523 Mtetra
.638 .831 .975 r
.71759 .19523 .72319 .20087 .73585 .19786 .73021 .1909 Mtetra
.651 .791 .949 r
.73021 .1909 .73585 .19786 .74857 .19475 .74288 .18646 Mtetra
.592 .734 .942 r
.07322 .41517 .0807 .4217 .09065 .41811 .083 .41296 Mtetra
.58 .779 .974 r
.083 .41296 .09065 .41811 .10065 .41442 .09283 .41069 Mtetra
.558 .824 .996 r
.09283 .41069 .10065 .41442 .1107 .41062 .10272 .40831 Mtetra
.517 .858 .994 r
.10272 .40831 .1107 .41062 .12081 .40666 .11268 .40579 Mtetra
.454 .866 .954 r
.11268 .40579 .12081 .40666 .13098 .4025 .12271 .40309 Mtetra
.364 .834 .866 r
.12271 .40309 .13098 .4025 .14121 .39815 .1328 .40018 Mtetra
.262 .766 .739 r
.1328 .40018 .14121 .39815 .15149 .39361 .14296 .39704 Mtetra
0 0 0 r
.14296 .39704 .15149 .39361 .16182 .38891 .15319 .3937 Mtetra
.15319 .3937 .16182 .38891 .1722 .38408 .16349 .39015 Mtetra
.002 0 0 r
.16349 .39015 .1722 .38408 .18263 .37916 .17384 .38643 Mtetra
.06 0 0 r
.17384 .38643 .18263 .37916 .19309 .37418 .18426 .38255 Mtetra
.106 0 0 r
.18426 .38255 .19309 .37418 .20358 .36917 .19472 .37855 Mtetra
.142 0 0 r
.19472 .37855 .20358 .36917 .21411 .36414 .20523 .37445 Mtetra
.172 0 0 r
.20523 .37445 .21411 .36414 .22467 .35912 .21579 .37028 Mtetra
.197 0 0 r
.21579 .37028 .22467 .35912 .23526 .35411 .22639 .36604 Mtetra
.217 0 0 r
.22639 .36604 .23526 .35411 .24589 .34912 .23704 .36177 Mtetra
.234 0 .026 r
.23704 .36177 .24589 .34912 .25654 .34415 .24772 .35745 Mtetra
.248 0 .049 r
.24772 .35745 .25654 .34415 .26723 .3392 .25845 .35311 Mtetra
.261 0 .069 r
.25845 .35311 .26723 .3392 .27795 .33426 .26922 .34875 Mtetra
.272 0 .086 r
.26922 .34875 .27795 .33426 .2887 .32936 .28003 .34437 Mtetra
.282 0 .101 r
.28003 .34437 .2887 .32936 .29949 .3245 .29088 .33998 Mtetra
.29 0 .115 r
.29088 .33998 .29949 .3245 .3103 .31968 .30177 .33559 Mtetra
.299 0 .126 r
.30177 .33559 .3103 .31968 .32115 .31493 .3127 .33123 Mtetra
.306 0 .136 r
.3127 .33123 .32115 .31493 .33203 .31025 .32366 .32688 Mtetra
.313 0 .145 r
.32366 .32688 .33203 .31025 .34295 .30566 .33467 .32258 Mtetra
.319 0 .152 r
.33467 .32258 .34295 .30566 .3539 .30118 .34572 .31832 Mtetra
.324 0 .158 r
.34572 .31832 .3539 .30118 .36488 .29681 .3568 .31412 Mtetra
.329 0 .163 r
.3568 .31412 .36488 .29681 .3759 .29256 .36793 .30998 Mtetra
.333 0 .167 r
.36793 .30998 .3759 .29256 .38696 .28844 .37909 .30591 Mtetra
.336 0 .169 r
.37909 .30591 .38696 .28844 .39805 .28445 .3903 .30191 Mtetra
.339 0 .171 r
.3903 .30191 .39805 .28445 .40918 .28059 .40156 .29798 Mtetra
.341 0 .171 r
.40156 .29798 .40918 .28059 .42036 .27685 .41286 .29411 Mtetra
.342 0 .169 r
.41286 .29411 .42036 .27685 .43158 .27324 .4242 .29031 Mtetra
.343 0 .167 r
.4242 .29031 .43158 .27324 .44285 .26974 .43559 .28656 Mtetra
.342 0 .163 r
.43559 .28656 .44285 .26974 .45417 .26635 .44703 .28286 Mtetra
.34 0 .158 r
.44703 .28286 .45417 .26635 .46554 .26305 .45853 .2792 Mtetra
.338 0 .151 r
.45853 .2792 .46554 .26305 .47696 .25983 .47007 .27556 Mtetra
.334 0 .143 r
.47007 .27556 .47696 .25983 .48843 .25668 .48166 .27195 Mtetra
.329 0 .133 r
.48166 .27195 .48843 .25668 .49996 .25357 .49331 .26833 Mtetra
.323 0 .121 r
.49331 .26833 .49996 .25357 .51154 .25051 .50502 .26471 Mtetra
.315 0 .108 r
.50502 .26471 .51154 .25051 .52318 .24747 .51677 .26108 Mtetra
.306 0 .092 r
.51677 .26108 .52318 .24747 .53488 .24446 .52858 .25741 Mtetra
.295 0 .073 r
.52858 .25741 .53488 .24446 .54664 .24148 .54045 .25372 Mtetra
.282 0 .051 r
.54045 .25372 .54664 .24148 .55846 .23851 .55237 .24999 Mtetra
.266 0 .024 r
.55237 .24999 .55846 .23851 .57035 .23556 .56435 .24622 Mtetra
.245 0 0 r
.56435 .24622 .57035 .23556 .58229 .23263 .57638 .24238 Mtetra
.219 0 0 r
.57638 .24238 .58229 .23263 .59429 .2297 .58847 .23847 Mtetra
.185 0 0 r
.58847 .23847 .59429 .2297 .60636 .22676 .60061 .23445 Mtetra
.14 0 0 r
.60061 .23445 .60636 .22676 .61849 .22378 .6128 .2303 Mtetra
.079 0 0 r
.6128 .2303 .61849 .22378 .63068 .22075 .62505 .22599 Mtetra
0 0 0 r
.62505 .22599 .63068 .22075 .64293 .21762 .63734 .2215 Mtetra
.63734 .2215 .64293 .21762 .65524 .21436 .64967 .21678 Mtetra
.64967 .21678 .65524 .21436 .66761 .21093 .66205 .21185 Mtetra
.392 .847 .787 r
.66205 .21185 .66761 .21093 .68003 .2073 .67447 .20667 Mtetra
.524 .918 .902 r
.67447 .20667 .68003 .2073 .6925 .20347 .68693 .20128 Mtetra
.62 .934 .963 r
.68693 .20128 .6925 .20347 .70502 .19944 .69942 .19568 Mtetra
.675 .91 .976 r
.69942 .19568 .70502 .19944 .71759 .19523 .71195 .18993 Mtetra
.699 .866 .961 r
.71195 .18993 .71759 .19523 .73021 .1909 .72452 .18405 Mtetra
.705 .817 .935 r
.72452 .18405 .73021 .1909 .74288 .18646 .73713 .1781 Mtetra
.514 .706 .958 r
.06568 .40859 .07322 .41517 .083 .41296 .0753 .40761 Mtetra
.489 .742 .984 r
.0753 .40761 .083 .41296 .09283 .41069 .08498 .4066 Mtetra
.452 .774 .997 r
.08498 .4066 .09283 .41069 .10272 .40831 .09472 .40553 Mtetra
.398 .793 .987 r
.09472 .40553 .10272 .40831 .11268 .40579 .10454 .40433 Mtetra
.327 .79 .939 r
.10454 .40433 .11268 .40579 .12271 .40309 .11442 .40296 Mtetra
.24 .754 .849 r
.11442 .40296 .12271 .40309 .1328 .40018 .12439 .4014 Mtetra
.151 .692 .729 r
.12439 .4014 .1328 .40018 .14296 .39704 .13443 .3996 Mtetra
0 0 0 r
.13443 .3996 .14296 .39704 .15319 .3937 .14456 .39754 Mtetra
.14456 .39754 .15319 .3937 .16349 .39015 .15477 .3952 Mtetra
.052 0 0 r
.15477 .3952 .16349 .39015 .17384 .38643 .16506 .3926 Mtetra
.093 0 0 r
.16506 .3926 .17384 .38643 .18426 .38255 .17542 .38975 Mtetra
.126 0 0 r
.17542 .38975 .18426 .38255 .19472 .37855 .18585 .38669 Mtetra
.153 0 0 r
.18585 .38669 .19472 .37855 .20523 .37445 .19634 .38345 Mtetra
.176 0 0 r
.19634 .38345 .20523 .37445 .21579 .37028 .2069 .38006 Mtetra
.196 0 0 r
.2069 .38006 .21579 .37028 .22639 .36604 .21751 .37656 Mtetra
.214 0 0 r
.21751 .37656 .22639 .36604 .23704 .36177 .22817 .37296 Mtetra
.229 0 0 r
.22817 .37296 .23704 .36177 .24772 .35745 .23888 .3693 Mtetra
.243 0 .007 r
.23888 .3693 .24772 .35745 .25845 .35311 .24964 .36557 Mtetra
.255 0 .029 r
.24964 .36557 .25845 .35311 .26922 .34875 .26045 .36179 Mtetra
.266 0 .048 r
.26045 .36179 .26922 .34875 .28003 .34437 .27131 .35797 Mtetra
.276 0 .066 r
.27131 .35797 .28003 .34437 .29088 .33998 .28221 .35411 Mtetra
.285 0 .082 r
.28221 .35411 .29088 .33998 .30177 .33559 .29316 .35023 Mtetra
.293 0 .095 r
.29316 .35023 .30177 .33559 .3127 .33123 .30416 .34631 Mtetra
.3 0 .108 r
.30416 .34631 .3127 .33123 .32366 .32688 .3152 .34238 Mtetra
.306 0 .118 r
.3152 .34238 .32366 .32688 .33467 .32258 .32629 .33843 Mtetra
.311 0 .127 r
.32629 .33843 .33467 .32258 .34572 .31832 .33742 .33447 Mtetra
.315 0 .133 r
.33742 .33447 .34572 .31832 .3568 .31412 .3486 .33049 Mtetra
.318 0 .139 r
.3486 .33049 .3568 .31412 .36793 .30998 .35983 .3265 Mtetra
.32 0 .142 r
.35983 .3265 .36793 .30998 .37909 .30591 .37111 .3225 Mtetra
.322 0 .144 r
.37111 .3225 .37909 .30591 .3903 .30191 .38243 .31848 Mtetra
.38243 .31848 .3903 .30191 .40156 .29798 .3938 .31446 Mtetra
.321 0 .142 r
.3938 .31446 .40156 .29798 .41286 .29411 .40522 .31042 Mtetra
.319 0 .139 r
.40522 .31042 .41286 .29411 .4242 .29031 .41669 .30637 Mtetra
.316 0 .134 r
.41669 .30637 .4242 .29031 .43559 .28656 .42821 .3023 Mtetra
.312 0 .127 r
.42821 .3023 .43559 .28656 .44703 .28286 .43977 .29822 Mtetra
.307 0 .119 r
.43977 .29822 .44703 .28286 .45853 .2792 .45139 .29412 Mtetra
.301 0 .108 r
.45139 .29412 .45853 .2792 .47007 .27556 .46305 .29 Mtetra
.294 0 .096 r
.46305 .29 .47007 .27556 .48166 .27195 .47477 .28585 Mtetra
.285 0 .081 r
.47477 .28585 .48166 .27195 .49331 .26833 .48654 .28167 Mtetra
.274 0 .065 r
.48654 .28167 .49331 .26833 .50502 .26471 .49836 .27745 Mtetra
.262 0 .046 r
.49836 .27745 .50502 .26471 .51677 .26108 .51023 .27319 Mtetra
.248 0 .025 r
.51023 .27319 .51677 .26108 .52858 .25741 .52215 .26887 Mtetra
.232 0 .001 r
.52215 .26887 .52858 .25741 .54045 .25372 .53412 .26449 Mtetra
.212 0 0 r
.53412 .26449 .54045 .25372 .55237 .24999 .54614 .26003 Mtetra
.188 0 0 r
.54614 .26003 .55237 .24999 .56435 .24622 .55822 .25547 Mtetra
.158 0 0 r
.55822 .25547 .56435 .24622 .57638 .24238 .57034 .25079 Mtetra
.12 0 0 r
.57034 .25079 .57638 .24238 .58847 .23847 .58251 .24596 Mtetra
.071 0 0 r
.58251 .24596 .58847 .23847 .60061 .23445 .59472 .24093 Mtetra
.007 0 0 r
.59472 .24093 .60061 .23445 .6128 .2303 .60698 .23568 Mtetra
0 0 0 r
.60698 .23568 .6128 .2303 .62505 .22599 .61928 .23017 Mtetra
.61928 .23017 .62505 .22599 .63734 .2215 .63161 .22437 Mtetra
.63161 .22437 .63734 .2215 .64967 .21678 .64398 .21828 Mtetra
.442 .87 .759 r
.64398 .21828 .64967 .21678 .66205 .21185 .65638 .21191 Mtetra
.565 .938 .865 r
.65638 .21191 .66205 .21185 .67447 .20667 .6688 .20529 Mtetra
.657 .961 .93 r
.6688 .20529 .67447 .20667 .68693 .20128 .68125 .19844 Mtetra
.713 .948 .955 r
.68125 .19844 .68693 .20128 .69942 .19568 .69373 .1914 Mtetra
.74 .913 .952 r
.69373 .1914 .69942 .19568 .71195 .18993 .70624 .18424 Mtetra
.748 .869 .936 r
.70624 .18424 .71195 .18993 .72452 .18405 .71877 .17698 Mtetra
.746 .825 .913 r
.71877 .17698 .72452 .18405 .73713 .1781 .73134 .16968 Mtetra
.465 .686 .962 r
.05808 .40196 .06568 .40859 .0753 .40761 .06763 .40162 Mtetra
.448 .703 .975 r
.06763 .40162 .0753 .40761 .08498 .4066 .07723 .40127 Mtetra
.43 .72 .986 r
.07723 .40127 .08498 .4066 .09472 .40553 .0869 .40087 Mtetra
.41 .737 .992 r
.0869 .40087 .09472 .40553 .10454 .40433 .09663 .4004 Mtetra
.387 .753 .992 r
.09663 .4004 .10454 .40433 .11442 .40296 .10644 .39981 Mtetra
.36 .765 .983 r
.10644 .39981 .11442 .40296 .12439 .4014 .11632 .39906 Mtetra
.328 .772 .962 r
.11632 .39906 .12439 .4014 .13443 .3996 .12629 .39813 Mtetra
.288 .768 .924 r
.12629 .39813 .13443 .3996 .14456 .39754 .13634 .397 Mtetra
.239 .751 .867 r
.13634 .397 .14456 .39754 .15477 .3952 .14647 .39565 Mtetra
.181 .716 .788 r
.14647 .39565 .15477 .3952 .16506 .3926 .15668 .39408 Mtetra
0 0 0 r
.15668 .39408 .16506 .3926 .17542 .38975 .16696 .3923 Mtetra
.16696 .3923 .17542 .38975 .18585 .38669 .17733 .39033 Mtetra
.01 0 0 r
.17733 .39033 .18585 .38669 .19634 .38345 .18776 .38818 Mtetra
.066 0 0 r
.18776 .38818 .19634 .38345 .2069 .38006 .19826 .38587 Mtetra
.114 0 0 r
.19826 .38587 .2069 .38006 .21751 .37656 .20883 .38343 Mtetra
.154 0 0 r
.20883 .38343 .21751 .37656 .22817 .37296 .21946 .38086 Mtetra
.187 0 0 r
.21946 .38086 .22817 .37296 .23888 .3693 .23016 .37817 Mtetra
.213 0 0 r
.23016 .37817 .23888 .3693 .24964 .36557 .24091 .37537 Mtetra
.234 0 0 r
.24091 .37537 .24964 .36557 .26045 .36179 .25173 .37245 Mtetra
.251 0 0 r
.25173 .37245 .26045 .36179 .27131 .35797 .2626 .36943 Mtetra
.264 0 .005 r
.2626 .36943 .27131 .35797 .28221 .35411 .27353 .36631 Mtetra
.275 0 .029 r
.27353 .36631 .28221 .35411 .29316 .35023 .28452 .36307 Mtetra
.283 0 .049 r
.28452 .36307 .29316 .35023 .30416 .34631 .29557 .35974 Mtetra
.289 0 .064 r
.29557 .35974 .30416 .34631 .3152 .34238 .30668 .3563 Mtetra
.294 0 .077 r
.30668 .3563 .3152 .34238 .32629 .33843 .31784 .35276 Mtetra
.297 0 .087 r
.31784 .35276 .32629 .33843 .33742 .33447 .32905 .34912 Mtetra
.299 0 .094 r
.32905 .34912 .33742 .33447 .3486 .33049 .34033 .34539 Mtetra
.3 0 .099 r
.34033 .34539 .3486 .33049 .35983 .3265 .35165 .34155 Mtetra
.299 0 .102 r
.35165 .34155 .35983 .3265 .37111 .3225 .36303 .33762 Mtetra
.297 0 .102 r
.36303 .33762 .37111 .3225 .38243 .31848 .37446 .3336 Mtetra
.294 0 .101 r
.37446 .3336 .38243 .31848 .3938 .31446 .38595 .32947 Mtetra
.29 0 .097 r
.38595 .32947 .3938 .31446 .40522 .31042 .39748 .32525 Mtetra
.284 0 .091 r
.39748 .32525 .40522 .31042 .41669 .30637 .40907 .32093 Mtetra
.277 0 .083 r
.40907 .32093 .41669 .30637 .42821 .3023 .42071 .31651 Mtetra
.268 0 .072 r
.42071 .31651 .42821 .3023 .43977 .29822 .4324 .31199 Mtetra
.257 0 .058 r
.4324 .31199 .43977 .29822 .45139 .29412 .44414 .30736 Mtetra
.243 0 .041 r
.44414 .30736 .45139 .29412 .46305 .29 .45593 .30263 Mtetra
.227 0 .02 r
.45593 .30263 .46305 .29 .47477 .28585 .46777 .29779 Mtetra
.207 0 0 r
.46777 .29779 .47477 .28585 .48654 .28167 .47965 .29284 Mtetra
.182 0 0 r
.47965 .29284 .48654 .28167 .49836 .27745 .49158 .28777 Mtetra
.152 0 0 r
.49158 .28777 .49836 .27745 .51023 .27319 .50356 .28259 Mtetra
.116 0 0 r
.50356 .28259 .51023 .27319 .52215 .26887 .51559 .27729 Mtetra
.071 0 0 r
.51559 .27729 .52215 .26887 .53412 .26449 .52766 .27187 Mtetra
.015 0 0 r
.52766 .27187 .53412 .26449 .54614 .26003 .53977 .26633 Mtetra
0 0 0 r
.53977 .26633 .54614 .26003 .55822 .25547 .55192 .26064 Mtetra
.55192 .26064 .55822 .25547 .57034 .25079 .56412 .25481 Mtetra
.56412 .25481 .57034 .25079 .58251 .24596 .57636 .2488 Mtetra
.34 .794 .656 r
.57636 .2488 .58251 .24596 .59472 .24093 .58863 .24261 Mtetra
.45 .874 .762 r
.58863 .24261 .59472 .24093 .60698 .23568 .60094 .23621 Mtetra
.55 .931 .848 r
.60094 .23621 .60698 .23568 .61928 .23017 .61328 .22957 Mtetra
.63 .959 .906 r
.61328 .22957 .61928 .23017 .63161 .22437 .62565 .2227 Mtetra
.688 .964 .938 r
.62565 .2227 .63161 .22437 .64398 .21828 .63805 .21559 Mtetra
.725 .952 .949 r
.63805 .21559 .64398 .21828 .65638 .21191 .65047 .20826 Mtetra
.748 .931 .948 r
.65047 .20826 .65638 .21191 .6688 .20529 .66291 .20072 Mtetra
.761 .907 .94 r
.66291 .20072 .6688 .20529 .68125 .19844 .67538 .19301 Mtetra
.766 .881 .929 r
.67538 .19301 .68125 .19844 .69373 .1914 .68788 .18516 Mtetra
.767 .856 .917 r
.68788 .18516 .69373 .1914 .70624 .18424 .70039 .17722 Mtetra
.765 .833 .904 r
.70039 .17722 .70624 .18424 .71877 .17698 .71293 .16921 Mtetra
.761 .81 .892 r
.71293 .16921 .71877 .17698 .73134 .16968 .7255 .16118 Mtetra
.454 .682 .963 r
.05043 .39529 .05808 .40196 .06763 .40162 .05997 .39505 Mtetra
.451 .685 .965 r
.05997 .39505 .06763 .40162 .07723 .40127 .06957 .39481 Mtetra
.449 .689 .968 r
.06957 .39481 .07723 .40127 .0869 .40087 .07922 .39456 Mtetra
.448 .694 .971 r
.07922 .39456 .0869 .40087 .09663 .4004 .08895 .39426 Mtetra
.448 .702 .975 r
.08895 .39426 .09663 .4004 .10644 .39981 .09874 .39389 Mtetra
.449 .711 .979 r
.09874 .39389 .10644 .39981 .11632 .39906 .1086 .39343 Mtetra
.449 .722 .984 r
.1086 .39343 .11632 .39906 .12629 .39813 .11854 .39286 Mtetra
.447 .735 .989 r
.11854 .39286 .12629 .39813 .13634 .397 .12855 .39217 Mtetra
.442 .749 .993 r
.12855 .39217 .13634 .397 .14647 .39565 .13864 .39135 Mtetra
.433 .765 .996 r
.13864 .39135 .14647 .39565 .15668 .39408 .1488 .3904 Mtetra
.417 .779 .995 r
.1488 .3904 .15668 .39408 .16696 .3923 .15903 .38932 Mtetra
.393 .79 .986 r
.15903 .38932 .16696 .3923 .17733 .39033 .16934 .3881 Mtetra
.361 .794 .966 r
.16934 .3881 .17733 .39033 .18776 .38818 .17972 .38674 Mtetra
.319 .788 .931 r
.17972 .38674 .18776 .38818 .19826 .38587 .19017 .38525 Mtetra
.271 .771 .882 r
.19017 .38525 .19826 .38587 .20883 .38343 .2007 .38361 Mtetra
.22 .742 .819 r
.2007 .38361 .20883 .38343 .21946 .38086 .2113 .38183 Mtetra
.168 .705 .749 r
.2113 .38183 .21946 .38086 .23016 .37817 .22197 .37991 Mtetra
0 0 0 r
.22197 .37991 .23016 .37817 .24091 .37537 .2327 .37784 Mtetra
.2327 .37784 .24091 .37537 .25173 .37245 .24351 .37561 Mtetra
.24351 .37561 .25173 .37245 .2626 .36943 .25439 .37322 Mtetra
.25439 .37322 .2626 .36943 .27353 .36631 .26534 .37065 Mtetra
.009 0 0 r
.26534 .37065 .27353 .36631 .28452 .36307 .27635 .36792 Mtetra
.026 0 0 r
.27635 .36792 .28452 .36307 .29557 .35974 .28743 .36502 Mtetra
.038 0 0 r
.28743 .36502 .29557 .35974 .30668 .3563 .29858 .36195 Mtetra
.047 0 0 r
.29858 .36195 .30668 .3563 .31784 .35276 .30979 .35872 Mtetra
.051 0 0 r
.30979 .35872 .31784 .35276 .32905 .34912 .32107 .35532 Mtetra
.052 0 0 r
.32107 .35532 .32905 .34912 .34033 .34539 .3324 .35175 Mtetra
.05 0 0 r
.3324 .35175 .34033 .34539 .35165 .34155 .3438 .34802 Mtetra
.045 0 0 r
.3438 .34802 .35165 .34155 .36303 .33762 .35525 .34414 Mtetra
.036 0 0 r
.35525 .34414 .36303 .33762 .37446 .3336 .36676 .34009 Mtetra
.025 0 0 r
.36676 .34009 .37446 .3336 .38595 .32947 .37833 .33588 Mtetra
.01 0 0 r
.37833 .33588 .38595 .32947 .39748 .32525 .38995 .33152 Mtetra
0 0 0 r
.38995 .33152 .39748 .32525 .40907 .32093 .40163 .32698 Mtetra
.40163 .32698 .40907 .32093 .42071 .31651 .41336 .32228 Mtetra
.41336 .32228 .42071 .31651 .4324 .31199 .42514 .31742 Mtetra
.42514 .31742 .4324 .31199 .44414 .30736 .43697 .31238 Mtetra
.43697 .31238 .44414 .30736 .45593 .30263 .44886 .30716 Mtetra
.44886 .30716 .45593 .30263 .46777 .29779 .46078 .30176 Mtetra
.46078 .30176 .46777 .29779 .47965 .29284 .47276 .29619 Mtetra
.47276 .29619 .47965 .29284 .49158 .28777 .48478 .29044 Mtetra
.368 .819 .698 r
.48478 .29044 .49158 .28777 .50356 .28259 .49684 .28452 Mtetra
.438 .868 .764 r
.49684 .28452 .50356 .28259 .51559 .27729 .50894 .27843 Mtetra
.508 .91 .825 r
.50894 .27843 .51559 .27729 .52766 .27187 .52108 .27217 Mtetra
.572 .941 .877 r
.52108 .27217 .52766 .27187 .53977 .26633 .53326 .26576 Mtetra
.628 .957 .917 r
.53326 .26576 .53977 .26633 .55192 .26064 .54548 .25919 Mtetra
.673 .959 .942 r
.54548 .25919 .55192 .26064 .56412 .25481 .55773 .25247 Mtetra
.706 .95 .954 r
.55773 .25247 .56412 .25481 .57636 .2488 .57002 .24559 Mtetra
.729 .933 .956 r
.57002 .24559 .57636 .2488 .58863 .24261 .58234 .23856 Mtetra
.743 .912 .951 r
.58234 .23856 .58863 .24261 .60094 .23621 .59469 .23138 Mtetra
.752 .891 .941 r
.59469 .23138 .60094 .23621 .61328 .22957 .60706 .22405 Mtetra
.756 .87 .931 r
.60706 .22405 .61328 .22957 .62565 .2227 .61947 .21657 Mtetra
.759 .853 .92 r
.61947 .21657 .62565 .2227 .63805 .21559 .6319 .20894 Mtetra
.761 .838 .911 r
.6319 .20894 .63805 .21559 .65047 .20826 .64436 .20117 Mtetra
.762 .826 .902 r
.64436 .20117 .65047 .20826 .66291 .20072 .65684 .19327 Mtetra
.762 .817 .896 r
.65684 .19327 .66291 .20072 .67538 .19301 .66935 .18526 Mtetra
.762 .809 .89 r
.66935 .18526 .67538 .19301 .68788 .18516 .68187 .17717 Mtetra
.762 .803 .886 r
.68187 .17717 .68788 .18516 .70039 .17722 .69443 .16901 Mtetra
.761 .798 .883 r
.69443 .16901 .70039 .17722 .71293 .16921 .70701 .16082 Mtetra
.76 .794 .881 r
.70701 .16082 .71293 .16921 .7255 .16118 .71961 .15261 Mtetra
.49 .697 .96 r
.04273 .38856 .05043 .39529 .05997 .39505 .05234 .38784 Mtetra
.498 .684 .95 r
.05234 .38784 .05997 .39505 .06957 .39481 .06201 .38714 Mtetra
.505 .672 .939 r
.06201 .38714 .06957 .39481 .07922 .39456 .07174 .38642 Mtetra
.512 .661 .928 r
.07174 .38642 .07922 .39456 .08895 .39426 .08153 .38567 Mtetra
.519 .652 .918 r
.08153 .38567 .08895 .39426 .09874 .39389 .09139 .38488 Mtetra
.525 .643 .908 r
.09139 .38488 .09874 .39389 .1086 .39343 .10131 .38403 Mtetra
.532 .636 .898 r
.10131 .38403 .1086 .39343 .11854 .39286 .11129 .38309 Mtetra
.539 .63 .89 r
.11129 .38309 .11854 .39286 .12855 .39217 .12135 .38205 Mtetra
.545 .624 .882 r
.12135 .38205 .12855 .39217 .13864 .39135 .13148 .3809 Mtetra
.551 .62 .874 r
.13148 .3809 .13864 .39135 .1488 .3904 .14168 .37964 Mtetra
.557 .616 .867 r
.14168 .37964 .1488 .3904 .15903 .38932 .15195 .37825 Mtetra
.562 .612 .86 r
.15195 .37825 .15903 .38932 .16934 .3881 .1623 .37674 Mtetra
.567 .609 .854 r
.1623 .37674 .16934 .3881 .17972 .38674 .17271 .37511 Mtetra
.571 .606 .849 r
.17271 .37511 .17972 .38674 .19017 .38525 .1832 .37335 Mtetra
.575 .603 .843 r
.1832 .37335 .19017 .38525 .2007 .38361 .19375 .37147 Mtetra
.579 .601 .838 r
.19375 .37147 .2007 .38361 .2113 .38183 .20437 .36946 Mtetra
.583 .599 .834 r
.20437 .36946 .2113 .38183 .22197 .37991 .21506 .36732 Mtetra
.587 .597 .83 r
.21506 .36732 .22197 .37991 .2327 .37784 .22582 .36504 Mtetra
.591 .596 .826 r
.22582 .36504 .2327 .37784 .24351 .37561 .23665 .36263 Mtetra
.594 .596 .823 r
.23665 .36263 .24351 .37561 .25439 .37322 .24754 .36008 Mtetra
.598 .595 .82 r
.24754 .36008 .25439 .37322 .26534 .37065 .2585 .35738 Mtetra
.602 .595 .817 r
.2585 .35738 .26534 .37065 .27635 .36792 .26953 .35453 Mtetra
.606 .596 .815 r
.26953 .35453 .27635 .36792 .28743 .36502 .28062 .35153 Mtetra
.609 .597 .813 r
.28062 .35153 .28743 .36502 .29858 .36195 .29177 .34837 Mtetra
.613 .598 .811 r
.29177 .34837 .29858 .36195 .30979 .35872 .30299 .34506 Mtetra
.617 .599 .81 r
.30299 .34506 .30979 .35872 .32107 .35532 .31428 .3416 Mtetra
.62 .6 .809 r
.31428 .3416 .32107 .35532 .3324 .35175 .32562 .33798 Mtetra
.624 .602 .808 r
.32562 .33798 .3324 .35175 .3438 .34802 .33702 .3342 Mtetra
.627 .603 .807 r
.33702 .3342 .3438 .34802 .35525 .34414 .34848 .33027 Mtetra
.63 .605 .806 r
.34848 .33027 .35525 .34414 .36676 .34009 .36 .32619 Mtetra
.634 .606 .805 r
.36 .32619 .36676 .34009 .37833 .33588 .37158 .32195 Mtetra
.637 .608 .804 r
.37158 .32195 .37833 .33588 .38995 .33152 .38321 .31755 Mtetra
.64 .61 .803 r
.38321 .31755 .38995 .33152 .40163 .32698 .3949 .313 Mtetra
.644 .612 .803 r
.3949 .313 .40163 .32698 .41336 .32228 .40664 .30829 Mtetra
.647 .614 .802 r
.40664 .30829 .41336 .32228 .42514 .31742 .41843 .30342 Mtetra
.651 .616 .802 r
.41843 .30342 .42514 .31742 .43697 .31238 .43027 .29839 Mtetra
.654 .618 .801 r
.43027 .29839 .43697 .31238 .44886 .30716 .44216 .2932 Mtetra
.657 .621 .801 r
.44216 .2932 .44886 .30716 .46078 .30176 .4541 .28785 Mtetra
.661 .624 .802 r
.4541 .28785 .46078 .30176 .47276 .29619 .46609 .28234 Mtetra
.664 .627 .802 r
.46609 .28234 .47276 .29619 .48478 .29044 .47812 .27668 Mtetra
.668 .631 .803 r
.47812 .27668 .48478 .29044 .49684 .28452 .49019 .27087 Mtetra
.672 .635 .804 r
.49019 .27087 .49684 .28452 .50894 .27843 .50231 .2649 Mtetra
.675 .639 .806 r
.50231 .2649 .50894 .27843 .52108 .27217 .51447 .2588 Mtetra
.679 .644 .808 r
.51447 .2588 .52108 .27217 .53326 .26576 .52667 .25255 Mtetra
.683 .649 .81 r
.52667 .25255 .53326 .26576 .54548 .25919 .53891 .24616 Mtetra
.687 .654 .812 r
.53891 .24616 .54548 .25919 .55773 .25247 .55118 .23964 Mtetra
.691 .66 .815 r
.55118 .23964 .55773 .25247 .57002 .24559 .56349 .23297 Mtetra
.696 .667 .818 r
.56349 .23297 .57002 .24559 .58234 .23856 .57584 .22617 Mtetra
.7 .673 .821 r
.57584 .22617 .58234 .23856 .59469 .23138 .58822 .21923 Mtetra
.705 .68 .824 r
.58822 .21923 .59469 .23138 .60706 .22405 .60063 .21215 Mtetra
.709 .688 .828 r
.60063 .21215 .60706 .22405 .61947 .21657 .61307 .20493 Mtetra
.714 .696 .831 r
.61307 .20493 .61947 .21657 .6319 .20894 .62555 .19759 Mtetra
.719 .704 .836 r
.62555 .19759 .6319 .20894 .64436 .20117 .63805 .19014 Mtetra
.723 .713 .841 r
.63805 .19014 .64436 .20117 .65684 .19327 .65058 .18258 Mtetra
.728 .724 .846 r
.65058 .18258 .65684 .19327 .66935 .18526 .66314 .17495 Mtetra
.732 .734 .853 r
.66314 .17495 .66935 .18526 .68187 .17717 .67573 .16725 Mtetra
.736 .746 .86 r
.67573 .16725 .68187 .17717 .69443 .16901 .68835 .15951 Mtetra
.74 .759 .868 r
.68835 .15951 .69443 .16901 .70701 .16082 .701 .15174 Mtetra
.744 .772 .876 r
.701 .15174 .70701 .16082 .71961 .15261 .71368 .14397 Mtetra
.552 .72 .952 r
.03496 .38178 .04273 .38856 .05234 .38784 .04473 .38014 Mtetra
.559 .694 .93 r
.04473 .38014 .05234 .38784 .06201 .38714 .05454 .37851 Mtetra
.564 .669 .909 r
.05454 .37851 .06201 .38714 .07174 .38642 .06441 .37687 Mtetra
.567 .646 .888 r
.06441 .37687 .07174 .38642 .08153 .38567 .07433 .37522 Mtetra
.57 .625 .868 r
.07433 .37522 .08153 .38567 .09139 .38488 .08431 .37353 Mtetra
.572 .607 .849 r
.08431 .37353 .09139 .38488 .10131 .38403 .09434 .3718 Mtetra
.574 .591 .832 r
.09434 .3718 .10131 .38403 .11129 .38309 .10444 .36999 Mtetra
.576 .577 .817 r
.10444 .36999 .11129 .38309 .12135 .38205 .1146 .3681 Mtetra
.578 .564 .803 r
.1146 .3681 .12135 .38205 .13148 .3809 .12483 .36611 Mtetra
.579 .553 .789 r
.12483 .36611 .13148 .3809 .14168 .37964 .13512 .36401 Mtetra
.58 .543 .777 r
.13512 .36401 .14168 .37964 .15195 .37825 .14548 .36179 Mtetra
.581 .533 .766 r
.14548 .36179 .15195 .37825 .1623 .37674 .1559 .35946 Mtetra
.582 .525 .756 r
.1559 .35946 .1623 .37674 .17271 .37511 .16639 .35702 Mtetra
.582 .517 .747 r
.16639 .35702 .17271 .37511 .1832 .37335 .17694 .35448 Mtetra
.582 .51 .739 r
.17694 .35448 .1832 .37335 .19375 .37147 .18755 .35184 Mtetra
.582 .503 .731 r
.18755 .35184 .19375 .37147 .20437 .36946 .19823 .34911 Mtetra
.582 .498 .725 r
.19823 .34911 .20437 .36946 .21506 .36732 .20896 .3463 Mtetra
.582 .492 .719 r
.20896 .3463 .21506 .36732 .22582 .36504 .21975 .34339 Mtetra
.582 .488 .713 r
.21975 .34339 .22582 .36504 .23665 .36263 .23061 .3404 Mtetra
.582 .484 .709 r
.23061 .3404 .23665 .36263 .24754 .36008 .24152 .33731 Mtetra
.582 .481 .705 r
.24152 .33731 .24754 .36008 .2585 .35738 .25249 .33413 Mtetra
.583 .479 .701 r
.25249 .33413 .2585 .35738 .26953 .35453 .26352 .33086 Mtetra
.583 .477 .698 r
.26352 .33086 .26953 .35453 .28062 .35153 .27461 .32749 Mtetra
.584 .475 .696 r
.27461 .32749 .28062 .35153 .29177 .34837 .28576 .32401 Mtetra
.585 .474 .694 r
.28576 .32401 .29177 .34837 .30299 .34506 .29696 .32043 Mtetra
.586 .473 .692 r
.29696 .32043 .30299 .34506 .31428 .3416 .30822 .31675 Mtetra
.587 .473 .691 r
.30822 .31675 .31428 .3416 .32562 .33798 .31954 .31295 Mtetra
.588 .473 .69 r
.31954 .31295 .32562 .33798 .33702 .3342 .33092 .30905 Mtetra
.589 .473 .689 r
.33092 .30905 .33702 .3342 .34848 .33027 .34235 .30503 Mtetra
.591 .474 .689 r
.34235 .30503 .34848 .33027 .36 .32619 .35384 .3009 Mtetra
.592 .475 .689 r
.35384 .3009 .36 .32619 .37158 .32195 .36538 .29665 Mtetra
.594 .476 .689 r
.36538 .29665 .37158 .32195 .38321 .31755 .37698 .29229 Mtetra
.595 .478 .689 r
.37698 .29229 .38321 .31755 .3949 .313 .38863 .28782 Mtetra
.597 .48 .69 r
.38863 .28782 .3949 .313 .40664 .30829 .40033 .28323 Mtetra
.599 .482 .691 r
.40033 .28323 .40664 .30829 .41843 .30342 .41208 .27854 Mtetra
.601 .484 .692 r
.41208 .27854 .41843 .30342 .43027 .29839 .42388 .27374 Mtetra
.603 .487 .694 r
.42388 .27374 .43027 .29839 .44216 .2932 .43574 .26883 Mtetra
.605 .491 .696 r
.43574 .26883 .44216 .2932 .4541 .28785 .44764 .26382 Mtetra
.608 .494 .699 r
.44764 .26382 .4541 .28785 .46609 .28234 .45959 .2587 Mtetra
.611 .499 .702 r
.45959 .2587 .46609 .28234 .47812 .27668 .47159 .25349 Mtetra
.613 .504 .705 r
.47159 .25349 .47812 .27668 .49019 .27087 .48364 .24818 Mtetra
.617 .509 .709 r
.48364 .24818 .49019 .27087 .50231 .2649 .49573 .24277 Mtetra
.62 .516 .714 r
.49573 .24277 .50231 .2649 .51447 .2588 .50787 .23727 Mtetra
.624 .523 .719 r
.50787 .23727 .51447 .2588 .52667 .25255 .52005 .23167 Mtetra
.628 .531 .725 r
.52005 .23167 .52667 .25255 .53891 .24616 .53228 .22596 Mtetra
.632 .539 .731 r
.53228 .22596 .53891 .24616 .55118 .23964 .54455 .22016 Mtetra
.637 .549 .738 r
.54455 .22016 .55118 .23964 .56349 .23297 .55687 .21424 Mtetra
.643 .559 .745 r
.55687 .21424 .56349 .23297 .57584 .22617 .56922 .2082 Mtetra
.649 .571 .753 r
.56922 .2082 .57584 .22617 .58822 .21923 .58162 .20204 Mtetra
.655 .583 .762 r
.58162 .20204 .58822 .21923 .60063 .21215 .59406 .19574 Mtetra
.662 .596 .771 r
.59406 .19574 .60063 .21215 .61307 .20493 .60653 .18933 Mtetra
.669 .611 .781 r
.60653 .18933 .61307 .20493 .62555 .19759 .61904 .18279 Mtetra
.676 .626 .792 r
.61904 .18279 .62555 .19759 .63805 .19014 .63159 .17616 Mtetra
.683 .642 .803 r
.63159 .17616 .63805 .19014 .65058 .18258 .64418 .16945 Mtetra
.69 .66 .816 r
.64418 .16945 .65058 .18258 .66314 .17495 .6568 .16267 Mtetra
.697 .68 .83 r
.6568 .16267 .66314 .17495 .67573 .16725 .66947 .15585 Mtetra
.704 .702 .845 r
.66947 .15585 .67573 .16725 .68835 .15951 .68217 .149 Mtetra
.71 .725 .861 r
.68217 .149 .68835 .15951 .701 .15174 .69491 .14213 Mtetra
.716 .75 .879 r
.69491 .14213 .701 .15174 .71368 .14397 .70769 .13525 Mtetra
.62 .742 .934 r
.02714 .37496 .03496 .38178 .04473 .38014 .03711 .37205 Mtetra
.621 .705 .905 r
.03711 .37205 .04473 .38014 .05454 .37851 .04713 .36914 Mtetra
.619 .671 .878 r
.04713 .36914 .05454 .37851 .06441 .37687 .05718 .36624 Mtetra
.616 .641 .853 r
.05718 .36624 .06441 .37687 .07433 .37522 .06729 .36333 Mtetra
.612 .615 .829 r
.06729 .36333 .07433 .37522 .08431 .37353 .07744 .3604 Mtetra
.609 .592 .808 r
.07744 .3604 .08431 .37353 .09434 .3718 .08763 .35744 Mtetra
.605 .572 .79 r
.08763 .35744 .09434 .3718 .10444 .36999 .09788 .35444 Mtetra
.602 .554 .773 r
.09788 .35444 .10444 .36999 .1146 .3681 .10819 .35138 Mtetra
.6 .54 .759 r
.10819 .35138 .1146 .3681 .12483 .36611 .11855 .34824 Mtetra
.598 .527 .745 r
.11855 .34824 .12483 .36611 .13512 .36401 .12896 .34503 Mtetra
.596 .515 .734 r
.12896 .34503 .13512 .36401 .14548 .36179 .13943 .34173 Mtetra
.594 .505 .724 r
.13943 .34173 .14548 .36179 .1559 .35946 .14995 .33836 Mtetra
.592 .496 .714 r
.14995 .33836 .1559 .35946 .16639 .35702 .16053 .33492 Mtetra
.59 .488 .706 r
.16053 .33492 .16639 .35702 .17694 .35448 .17115 .33142 Mtetra
.588 .481 .699 r
.17115 .33142 .17694 .35448 .18755 .35184 .18183 .32788 Mtetra
.586 .474 .693 r
.18183 .32788 .18755 .35184 .19823 .34911 .19256 .32428 Mtetra
.585 .468 .687 r
.19256 .32428 .19823 .34911 .20896 .3463 .20334 .32065 Mtetra
.583 .463 .682 r
.20334 .32065 .20896 .3463 .21975 .34339 .21417 .31697 Mtetra
.582 .458 .677 r
.21417 .31697 .21975 .34339 .23061 .3404 .22505 .31327 Mtetra
.58 .454 .673 r
.22505 .31327 .23061 .3404 .24152 .33731 .23598 .30953 Mtetra
.579 .451 .67 r
.23598 .30953 .24152 .33731 .25249 .33413 .24696 .30576 Mtetra
.578 .448 .667 r
.24696 .30576 .25249 .33413 .26352 .33086 .25798 .30195 Mtetra
.578 .445 .664 r
.25798 .30195 .26352 .33086 .27461 .32749 .26906 .2981 Mtetra
.577 .443 .662 r
.26906 .2981 .27461 .32749 .28576 .32401 .28019 .29422 Mtetra
.577 .441 .66 r
.28019 .29422 .28576 .32401 .29696 .32043 .29137 .29029 Mtetra
.576 .44 .658 r
.29137 .29029 .29696 .32043 .30822 .31675 .30259 .28631 Mtetra
.576 .439 .657 r
.30259 .28631 .30822 .31675 .31954 .31295 .31388 .28229 Mtetra
.577 .438 .656 r
.31388 .28229 .31954 .31295 .33092 .30905 .32521 .27821 Mtetra
.32521 .27821 .33092 .30905 .34235 .30503 .33659 .27408 Mtetra
.577 .438 .655 r
.33659 .27408 .34235 .30503 .35384 .3009 .34803 .2699 Mtetra
.578 .438 .655 r
.34803 .2699 .35384 .3009 .36538 .29665 .35951 .26566 Mtetra
.578 .439 .656 r
.35951 .26566 .36538 .29665 .37698 .29229 .37105 .26137 Mtetra
.579 .44 .656 r
.37105 .26137 .37698 .29229 .38863 .28782 .38264 .25702 Mtetra
.58 .441 .657 r
.38264 .25702 .38863 .28782 .40033 .28323 .39428 .25262 Mtetra
.581 .443 .658 r
.39428 .25262 .40033 .28323 .41208 .27854 .40597 .24818 Mtetra
.582 .445 .66 r
.40597 .24818 .41208 .27854 .42388 .27374 .41771 .24369 Mtetra
.583 .447 .661 r
.41771 .24369 .42388 .27374 .43574 .26883 .4295 .23916 Mtetra
.584 .449 .664 r
.4295 .23916 .43574 .26883 .44764 .26382 .44134 .23459 Mtetra
.585 .452 .666 r
.44134 .23459 .44764 .26382 .45959 .2587 .45323 .22997 Mtetra
.587 .456 .669 r
.45323 .22997 .45959 .2587 .47159 .25349 .46517 .22533 Mtetra
.589 .46 .673 r
.46517 .22533 .47159 .25349 .48364 .24818 .47717 .22064 Mtetra
.591 .464 .676 r
.47717 .22064 .48364 .24818 .49573 .24277 .48921 .21592 Mtetra
.593 .469 .681 r
.48921 .21592 .49573 .24277 .50787 .23727 .50131 .21115 Mtetra
.595 .475 .686 r
.50131 .21115 .50787 .23727 .52005 .23167 .51345 .20634 Mtetra
.598 .482 .691 r
.51345 .20634 .52005 .23167 .53228 .22596 .52565 .20148 Mtetra
.601 .489 .698 r
.52565 .20148 .53228 .22596 .54455 .22016 .5379 .19657 Mtetra
.605 .497 .705 r
.5379 .19657 .54455 .22016 .55687 .21424 .5502 .19159 Mtetra
.609 .507 .712 r
.5502 .19159 .55687 .21424 .56922 .2082 .56255 .18653 Mtetra
.614 .517 .721 r
.56255 .18653 .56922 .2082 .58162 .20204 .57495 .18139 Mtetra
.619 .529 .73 r
.57495 .18139 .58162 .20204 .59406 .19574 .5874 .17616 Mtetra
.625 .542 .741 r
.5874 .17616 .59406 .19574 .60653 .18933 .5999 .17084 Mtetra
.631 .557 .753 r
.5999 .17084 .60653 .18933 .61904 .18279 .61244 .16544 Mtetra
.638 .573 .766 r
.61244 .16544 .61904 .18279 .63159 .17616 .62504 .15997 Mtetra
.644 .592 .781 r
.62504 .15997 .63159 .17616 .64418 .16945 .63768 .15444 Mtetra
.651 .613 .798 r
.63768 .15444 .64418 .16945 .6568 .16267 .65037 .14888 Mtetra
.658 .636 .816 r
.65037 .14888 .6568 .16267 .66947 .15585 .66312 .1433 Mtetra
.666 .663 .837 r
.66312 .1433 .66947 .15585 .68217 .149 .67591 .13769 Mtetra
.673 .692 .86 r
.67591 .13769 .68217 .149 .69491 .14213 .68875 .13208 Mtetra
.679 .726 .885 r
.68875 .13208 .69491 .14213 .70769 .13525 .70165 .12647 Mtetra
.682 .757 .909 r
.01926 .36808 .02714 .37496 .03711 .37205 .02948 .36365 Mtetra
.674 .714 .878 r
.02948 .36365 .03711 .37205 .04713 .36914 .03974 .35923 Mtetra
.666 .676 .85 r
.03974 .35923 .04713 .36914 .05718 .36624 .05003 .35482 Mtetra
.657 .643 .824 r
.05003 .35482 .05718 .36624 .06729 .36333 .06035 .35042 Mtetra
.648 .614 .801 r
.06035 .35042 .06729 .36333 .07744 .3604 .07071 .34602 Mtetra
.64 .588 .781 r
.07071 .34602 .07744 .3604 .08763 .35744 .0811 .34163 Mtetra
.632 .567 .763 r
.0811 .34163 .08763 .35744 .09788 .35444 .09153 .33724 Mtetra
.625 .548 .748 r
.09153 .33724 .09788 .35444 .10819 .35138 .102 .33287 Mtetra
.619 .532 .734 r
.102 .33287 .10819 .35138 .11855 .34824 .1125 .3285 Mtetra
.614 .519 .723 r
.1125 .3285 .11855 .34824 .12896 .34503 .12304 .32413 Mtetra
.609 .507 .713 r
.12304 .32413 .12896 .34503 .13943 .34173 .13362 .31978 Mtetra
.605 .497 .705 r
.13362 .31978 .13943 .34173 .14995 .33836 .14423 .31543 Mtetra
.602 .489 .698 r
.14423 .31543 .14995 .33836 .16053 .33492 .15488 .31109 Mtetra
.599 .482 .691 r
.15488 .31109 .16053 .33492 .17115 .33142 .16557 .30675 Mtetra
.596 .475 .686 r
.16557 .30675 .17115 .33142 .18183 .32788 .1763 .30242 Mtetra
.593 .47 .681 r
.1763 .30242 .18183 .32788 .19256 .32428 .18707 .2981 Mtetra
.591 .465 .677 r
.18707 .2981 .19256 .32428 .20334 .32065 .19788 .29379 Mtetra
.589 .46 .673 r
.19788 .29379 .20334 .32065 .21417 .31697 .20873 .28948 Mtetra
.587 .456 .669 r
.20873 .28948 .21417 .31697 .22505 .31327 .21963 .28517 Mtetra
.585 .453 .666 r
.21963 .28517 .22505 .31327 .23598 .30953 .23056 .28088 Mtetra
.584 .449 .664 r
.23056 .28088 .23598 .30953 .24696 .30576 .24154 .27659 Mtetra
.582 .446 .661 r
.24154 .27659 .24696 .30576 .25798 .30195 .25256 .2723 Mtetra
.581 .444 .659 r
.25256 .2723 .25798 .30195 .26906 .2981 .26362 .26803 Mtetra
.58 .441 .657 r
.26362 .26803 .26906 .2981 .28019 .29422 .27472 .26375 Mtetra
.579 .439 .655 r
.27472 .26375 .28019 .29422 .29137 .29029 .28587 .25949 Mtetra
.578 .438 .654 r
.28587 .25949 .29137 .29029 .30259 .28631 .29707 .25523 Mtetra
.577 .436 .653 r
.29707 .25523 .30259 .28631 .31388 .28229 .30831 .25098 Mtetra
.576 .435 .652 r
.30831 .25098 .31388 .28229 .32521 .27821 .31959 .24673 Mtetra
.576 .434 .651 r
.31959 .24673 .32521 .27821 .33659 .27408 .33093 .24249 Mtetra
.575 .434 .651 r
.33093 .24249 .33659 .27408 .34803 .2699 .34231 .23825 Mtetra
.575 .433 .651 r
.34231 .23825 .34803 .2699 .35951 .26566 .35373 .23402 Mtetra
.575 .434 .651 r
.35373 .23402 .35951 .26566 .37105 .26137 .36521 .22979 Mtetra
.575 .434 .652 r
.36521 .22979 .37105 .26137 .38264 .25702 .37673 .22557 Mtetra
.575 .435 .653 r
.37673 .22557 .38264 .25702 .39428 .25262 .3883 .22136 Mtetra
.575 .436 .654 r
.3883 .22136 .39428 .25262 .40597 .24818 .39993 .21715 Mtetra
.575 .437 .655 r
.39993 .21715 .40597 .24818 .41771 .24369 .4116 .21295 Mtetra
.576 .438 .657 r
.4116 .21295 .41771 .24369 .4295 .23916 .42333 .20875 Mtetra
.576 .44 .659 r
.42333 .20875 .4295 .23916 .44134 .23459 .4351 .20456 Mtetra
.577 .443 .661 r
.4351 .20456 .44134 .23459 .45323 .22997 .44693 .20037 Mtetra
.577 .445 .664 r
.44693 .20037 .45323 .22997 .46517 .22533 .45881 .19619 Mtetra
.578 .448 .667 r
.45881 .19619 .46517 .22533 .47717 .22064 .47075 .19201 Mtetra
.579 .451 .67 r
.47075 .19201 .47717 .22064 .48921 .21592 .48274 .18784 Mtetra
.58 .454 .673 r
.48274 .18784 .48921 .21592 .50131 .21115 .49478 .18367 Mtetra
.581 .458 .677 r
.49478 .18367 .50131 .21115 .51345 .20634 .50688 .17951 Mtetra
.583 .463 .682 r
.50688 .17951 .51345 .20634 .52565 .20148 .51904 .17535 Mtetra
.584 .468 .687 r
.51904 .17535 .52565 .20148 .5379 .19657 .53126 .1712 Mtetra
.586 .474 .692 r
.53126 .1712 .5379 .19657 .5502 .19159 .54353 .16705 Mtetra
.588 .48 .699 r
.54353 .16705 .5502 .19159 .56255 .18653 .55586 .16291 Mtetra
.59 .488 .706 r
.55586 .16291 .56255 .18653 .57495 .18139 .56825 .15877 Mtetra
.593 .497 .715 r
.56825 .15877 .57495 .18139 .5874 .17616 .5807 .15463 Mtetra
.596 .508 .725 r
.5807 .15463 .5874 .17616 .5999 .17084 .59321 .1505 Mtetra
.599 .521 .738 r
.59321 .1505 .5999 .17084 .61244 .16544 .60578 .14638 Mtetra
.603 .536 .752 r
.60578 .14638 .61244 .16544 .62504 .15997 .61841 .14225 Mtetra
.608 .554 .768 r
.61841 .14225 .62504 .15997 .63768 .15444 .63111 .13814 Mtetra
.612 .574 .787 r
.63111 .13814 .63768 .15444 .65037 .14888 .64387 .13402 Mtetra
.617 .599 .809 r
.64387 .13402 .65037 .14888 .66312 .1433 .65669 .12991 Mtetra
.622 .627 .834 r
.65669 .12991 .66312 .1433 .67591 .13769 .66958 .12581 Mtetra
.627 .66 .863 r
.66958 .12581 .67591 .13769 .68875 .13208 .68254 .12171 Mtetra
.63 .698 .894 r
.68254 .12171 .68875 .13208 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Rooooo`;oXK;T00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`1Aooooo`00H?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B47ooooo`03o`000?oooooooooo01gooooo0ol00002ooooo`03o`000?oooooooooo05cooooo0_nP
Z=`4oj6bi003o`000?nQ/^Cooooo01Gooooo00?o0000ooooooooool0D?ooool0063ooooo00Go410@
oooooooooooooooooa0@400;ooooo`Go00007?ooool2o`00063ooooo0_nOX=D5oj2Xg0?oXK;T00?o
0000ojfih_ooool05?ooool00ol0003oooooo`00001Aooooo`00H?ooool01Ol0003ooooooooooooo
oooo000000_ooooo00CoA4A4omgMgOoooooo00006_ooool3o`0005oooooo00?oWIW?oinPeOnOX=D0
0onOX=D5oj2Xg003oj6bi?n]^N;o000000;o[KWR5_ooool00ol0003oooooooooo`1?ooooo`00H?oo
ool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00006?ooool2o`0005oo
oooo1OnMVLl4oinPe@CoX:SL00Co[;7Lojfih_n]^N;o00000on]^N8Fooooo`03o`000?oooooooooo
04kooooo001Pooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Eoooo
o`?o00000_ooool00ol0003oooooooooo`1Iooooo`;oW9;91_nMVLl5oinPe@03oj2Xg?n//Mco[;7L
00;o[;7L00Go[KWRo`000?n]^N;o[KWRokNoh@0Fooooo`03o`000?oooooooooo04kooooo001Poooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000Cooooo`;o0000GOooool2
oi^=a0GoW9;91OnMVLl4oinPe@03ojZYe_n//Mco[;7L00Co[;7L00?o0000okNohOng_n400_ng_n4F
ooooo`03o`000?oooooooooo04gooooo001Pooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`0?ooooo`?o0000G?ooool00onJRL3oVhg4oi^=a003oi^=a0GoW9;91OnMVLl0
0onOX=GoZZWFojZYeP02ojZYePCo[;7L00?o]KWLo`000?ng_n401?ng_n4Fooooo`03o`000?oooooo
oooo04cooooo0022ooooo`;o0000GOooool4oiZ9`0CoVhg41OnLT/T4oifIc`03ojRRd?nZZMKoZZWF
00?oZZWF0on//M`2okFig003o`000?ng_n7o]koQ00;o]koQ00?o_/GPooooooooool05?ooool00ol0
003oooooooooo`1<ooooo`00Ooooool3o`0000;ooooo00?o0000ooooooooool0Eoooool2oiV5_0Go
VXW01?nKSL@6oibBb@03oifIconXX]3oZ:;@00;oZ:;@1OnZZMH01on//Mco]KWLokFig?ne^Mco0000
okFig?ng_n401?nnaN0Dooooo`?o0000COooool007cooooo0ol0001Kooooo`;oV8:i1OnIQK`4oiZ9
`0GoVhg40onLT/T2ojJLc0GoZ:;@1?nZZMH00ond/mSo]KWLokFig002okFig003o`000?nm`]ko_/GP
00Co_/GP5oooool00ol0003oooooooooo`1:ooooo`00N_ooool2o`0005_ooooo00?oUgngoiR2^OnH
P[T00onHP[T4oiV5_0GoVXW00onKSL@00onTUlOoYYc<ojJLc004ojJLc0GoZ:;@00?oZZWFokBcf?nd
/mP00_nd/mP3okFig003okg2g_l0003o_L;N00?o_/GP0_o2bn4Fooooo`03o`000?oooooooooo04[o
oooo001gooooo`?o0000Foooool4oiMo]`CoV8:i1?nIQK`5oiZ9`003oi^=a?nTUlOoY9O700;oY9O7
1OnVW<`4ojRRd003ok:^e?nd/mSo];?H00Co];?H00Ko]KWLokg2g_nm`]ko0000okg2g_nnaN05ol;;
hAKooooo00?o0000ooooooooool0BOooool007Gooooo0_l00002ooooo`03o`000?oooooooooo05Oo
oooo00?oUgbdoiMo]onGOkL00onGOkL5oiR2^@CoVHFl0onJRL000onST/CoY9O7ojBGa`04ojBGa`Go
YYc<00?oZ:;@ok:^e?nb[]@00_nb[]@4okBcf006okbng?nm`]ko_L;Nokg2g_l0003o`/cR1Oo2bn40
0oo2cnCoooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo001booooo`?o00001Oooool00ol0
003oooooooooo`1Booooo`;oUWZb1?nGO;@5oiMo]`CoV8:i1?nIQK`00onJRL3oXi;4oj>Ba002oj>B
a0GoY9O71?nVW<`00on`Z=3o/ZkDok:^e004ok:^e003okBcf?nl_]co_;kL00;o_;kL0_nm`]h00ol0
003o`/cRol;<hP03ol;;h@?o`/oT5_ooool00ol0003oooooooooo`18ooooo`00L?ooool2o`0005[o
oooo00?oUWVaoiIj/_nFN[800_nFN[84oiMl]0GoUgng1OnHP[T2oiV5_003oj6>`?nST/CoXi;400Co
Xi;41OnTUlL00onVW<co/:S@ok2Xd002ok2Xd0Co/ZkD00?o^k_Jokbng?nl_]`00onl_]`00onm`]ko
`/cRo`000003ol;<hP03ol;;hOo2cnCo`/oT00?o`/oT5_ooool00ol0003oooooooooo`17ooooo`00
>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00008?ooool3o`0005[o
oooo0onFNK45oiIj/PCoUgbd1?nGOkL4oiR2^@03oin:_OnQS/3oXHk000;oXHk01OnST/@4ojBGa`03
ojjTcOn`Z=3o/:S@00?o/:S@0onb[]@3ok^kfP?o_;kL0_o3cN801?o2c>;o0000ol;<h_o2c>82ol?E
i`Co`/oT00?o_]?Yooooooooool04oooool3o`0004Sooooo000hooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Nooooo`;o00000oooool0
0ol0003oooooooooo`1Dooooo`;oUGN_1OnFNK44oiIj/PCoUgbd1OnGOkL00onHP[WoWhZmoin:_@02
oin:_@CoXHk01OnST/@00onTUlOo[ZC=ojjTc@02ojjTc@Go/:S@00?o/ZkDok^kf_nk^mX00onk^mX0
0onl_]co`lgRol?=hP02ol?=hP03o`000?o3eNOo`mGW00?o`mGW00?o`/oTokkCjOnndnT00_nndnTF
ooooo`03o`000?oooooooooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo02Wooooo000hooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP0Looooo`?o0000F?ooool2oiEf[PCoUGN_1OnFNK44oiIj/PCoUgbd1?nG
OkL00onNQk[oWhZmoin:_@03oin:_@CoXHk01?nST/@00on]X<[o[ZC=ojjTc@03ojjTc@Co/:S@00?o
^[WHok^kf_nk^mX00onk^mX00oo3cn?o`lgRol?=hP02ol?=hP03olCKj_l0003o`mGW00?o`mGW00?o
_mk_okkCjOnndnT01?nndnTFooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Zooooo`00>?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h06?ooool3o`0005Sooooo00?oU7F]oiEf[_nEMZh0
0_nEMZh5oiEg[`CoUWVa1OnFN[84oiMl]003oiMo]onNQk[oWXNj00;oWXNj1?nOR[d5oj6>`003oj>B
a?n]X<[o[J3:00;o[J3:1On^Y<d00on`Z=3o^[WHokZif002okZif0?o^k_J0oo3cn<2ol?=hP;oa=_Z
00Co0000ol?Eioo3eNOo`mGW0onog^l4okkCj@;o]=7_5_ooool00ol0003oooooooooo`04ooooo`05
oa0@4?ooooooooooooooool@41002oooool5o`0002_ooooo000hooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0Eooooo`?o0000F?ooool3oiAe[@GoUGJ^1?nEMjl4oiIi
/@GoUWZb0_nGO;@2oif4^0GoWXNj1OnOR[d3oj6>`003oj^Laon]X<[o[J3:00?o[J3:1?n^Y<d00oni
]]Oo^[WHokZif004okZif003ok^kf_o3cn?o`loS00;o`loS00Oo`lgRolCKj_o4fn[oa=_Zo`000?o4
fn[o`mGW00Go_mk_00?o_]?YokCAkonddNl00onddNlEooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002cooooo000hooooo`05oa0@
4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Aooooo`?o00000oooool00ol0003o
ooooooooo`1Booooo`;oU7B/1OnDMJd4oiEf[PCoUGN_1OnFNK43oiIj/P03oi^1]_nMQ;SoWHBh00?o
WHBh1?nNQkX5oin:_@03oj6>`?n[W<OoZic700;oZic71?n]X<X3ojjTc@?o^KKG1?nj^MP00oo3dNGo
`loSol??h`02ol??h`;oa>7]0oo4fnX00ol0003o_NWcokgYl`04okoNk`;o/]gf1?nddNl00onVb_;o
ooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`04omgMgOmEEEGoooooo`0002cooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[ZjoooooonHV9So410@017ooooo0_l0001Hooooo`03oiAcZonDM:coU7B/00;oU7B/1OnD
MJd4oiEf[PCoUGN_1OnFNK401?nFN[;oVh6foi^1]_nKPKH5oif4^0GoWXNj0onOR[d00onYV<GoZic7
oj^La`03oj^La`Go[J3:00?o[ZC=okVfeoni]]L00_ni]]L3okZif0?o`m7U0_o3cn<4olCQk@03olCK
j_nmjO?o000000?o_NWc00?o_mk_ok;Mm_nbgOH00onbgOH00onddNooY/[bojK:lP02ojK:lQKooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l0
0000;?ooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`03_ooool3o`0005Oooooo00CoTg:ZoiAcZonDLj_oU7>[1OnDM:`4oiAe[@CoUGJ^1OnEMjl3
oiIi/@03oiYo]?nKPKKoVh6f00?oVh6f1?nMQ;P5oij7^P03oin:_OnYV<GoZIS500;oZIS51?n[W<L4
ojfPbP03okRde_ni]]Oo^KKG00Co^KKG00?o^[WHol?AiOo3dND00_o3dND00oo3cn?oa>7]olCQk@02
olCQk@?o]_;d00?o0000okgYlon/j?T00on/j?T2ok;MmP?oXmCi1OnVb_8Dooooo`;o00001?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000;?ooool005Wooooo0ol0001G
ooooo`?oTg:Z1?nDLj/4oiAd[0CoU7F]1OnEMZh4oiEg[`04oiIi/OnJOkCoVWndoiYo]0GoVh6f1OnM
Q;P3oij7^P03ojNE`onYV<GoZIS500?oZIS51On[W<L00on]X<[o^;CFokRdeP02okRdePCo^KKG00?o
`m?Vol?AiOo3dND00_o3dND3ol;Xl003olCQkOnfl_Co]_;d00;o]_;d00?oW^ofo`000?n/j?T00on/
j?T2oicMo@GoXmCi0_nVb_82oiW2m1?ooooo00Co0000oooooooooooo00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0:oooool005Kooooo0ol00003ooooo`03o`00
0?oooooooooo057ooooo0_nCLJT5oi=bZP?oU7>[1?nDM:`4oiAe[@GoUGJ^0_nEMjl2oiUm/PGoVWnd
1?nKPKH5oif4^003oij7^_nWUL?oYiG300;oYiG31?nYV<D4oj^La`03okJbe?nh]=Ko^;CF00Co^;CF
00?o^KKGol?Ci_o3dnH00_o3dnH00oo3dNGo`^S`ol;Xl002ol;Xl0?oZ?K^00Oo]_;doik_m_nNkoKo
W^ofo`000?nNkoKo[>Si00GoW=gm0_nSe?T2oiG9nPGoVL;d5_ooool00ol0003oooooooooo`10oooo
o`00E?ooool2o`0005Kooooo1_nCLJT5oi=bZP?oU7>[1?nDM:`5oiAe[@?oUGJ^00?oVG^`oiUm/_nI
OK800_nIOK85oiYo]0GoVh6f0onMQ;P00onVT/3oYiG3ojNE``03ojNE``GoZIS500?oZic7okJbe?nf
/]@00_nf/]@4okRdeP;o`]KY0oo3dnH3oko^lP03ol;Xl?nXm^koZ?K^00;oZ?K^0on6jnH2oik_mP04
o`000?n?hocoSn?lohoSo0;oW=gm0_n?d?h5oiG9nPCoVL;d5_ooool00ol0003oooooooooo`10oooo
o`00DOooool3o`0005Gooooo00?oTg2Xoi=aZOnCLJT01onCLJT4oi=bZP?oU7>[1OnDM:`4oiAe[@04
oiEf[_nINk3oVG^`oiUk/0GoVGfb1?nJOk@5oi^1]P03oif4^?nVT/3oYY;000;oYY;01?nWUL<4ojVH
a@03okF`donf/]Co][;D00?o][;D0onh]=H4ol;Fj@04ol?Ci_nok_;o_nkboko^lP?oT?3M00CoZ?K^
ohK[i_n6jnKoQ^_V1?mjhO<01?l0003oSn?lohGDoon5e?l5oho@oP;oULWj0_n;_OL5ohjilaKooooo
00?o0000ooooooooool0?oooool004kooooo1Ol0001Cooooo`CoTg2X2OnCLJT4oi=bZP?oU7>[1OnD
M:`2oiAe[@;oV7V_1OnINk04oiUm/PGoVWnd0onKPKH00onTSkkoYY;0ojJB`003ojJB`0GoYiG30_nY
V<D3okF`d`Go][;D00?o^;CFol;FjOo2e^T00_o2e^T2okWclP04oko^l_n@l=goT?3Moi3`g@;oI=S9
1?mNe]d2og[Ql`;oMmKm00?o0000ohGDoon5e?l00_n5e?l2oho@oP?oQl3j1?n;_OL5ohjilaKooooo
00?o0000ooooooooool0?_ooool004cooooo0_l00005ooooo`03o`000?oooooooooo04kooooo1onC
L:P8oi=aZ@CoTg:Z1?nDLj/3oiAd[003oiMh[_nHNJooV7V_00;oV7V_1OnINk04oiUm/PGoVWnd00?o
Vh6fojB?__nTSkh00_nTSkh4ojJB`0GoYiG300?oZIS5okF`done/=<00_ne/=<4okJbe0;o`][[0oo2
e^T2okWclP;oLMk200?o0000ocg1__lm`Kh01?mBc>T3ofKCmP;oMmKm00?oO/Cmo`000?mna?d01?n3
`_`5ohO0nPCoRkgg0_n>^O<2ohVal1Kooooo00?o0000ooooooooool0?_ooool004Wooooo0ol0001E
ooooo`;oTfnW2?nCL:P8oi=aZ@GoTg:Z0onDLj/01?nDM:coUgR^oiMh[_nGN:h5oiQi[`CoVG^`1OnI
OK83oiYo]003oj><_?nTSkkoY8nn00?oY8nn1OnVT/03ojNE``03okB^d_ne/=?o]K3C00Co]K3C00?o
][;Dol;Jjoo2f^/00oo2f^/01Oo2e^Wo^O?bokWcl_mag/;o000000;o?/7I0_me`_h4ogK4oPGoNLCn
0_mna?d00ol0003oO/Cmoh?2o003oh?2o0;oQl3j0_n8[^h5ohV_k`CoRK7`5?ooool3o`0003oooooo
000Rooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08?ooool2o`0005Cooooo1_nCKjL8oi=`Z0SoTg6Y
1OnCLZX2oiAcZ`03oiMf[OnGN:koUgR^00?oUgR^1?nHNJl4oiUk/0GoVGfb00?oVWndoj><_?nSS;`0
0_nSS;`4ojB?_PGoYY;000?oYiG3okB^d_nd[]800_nd[]84okF`d`;o`Mk^1?o2f^/2ok3fl003okWc
l_mg`?goMl3m00?oMl3m0ome`_h4ogK4oP;oNLCn0_n:Y>H2ohVXj@03o`000?n9Z>WoRJ_/00CoRJ_/
1?n8[^h5ohV_k`CoRK7`5Oooool00ol0003oooooooooo`0mooooo`008_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01gooooo0ol00002ooooo`03o`000?oooooooooo04kooooo2_nCKjL7oi=`Z0WoTg6Y
0onCLZX01?nFMJcoUgJ]oiMf[OnGMZd5oiMh[PCoV7V_1OnINk03oiUm/P03oj69^onSS;coXhbl00?o
Xhbl1OnTSkh3ojJB`003ok>/d_nd[];o]:kB00Co]:kB00?o]K3Col7Nk_o1g^h00oo1g^h01?o2f^_o
/?K`ok3fl?n`m_03ogbln`;oMl3m0_n@UMD3ohjJf`CoS9oQ1On:Y>H01?n9Z>Wo0000ohVXjOn9Z>T5
ohV[k0CoR:k^0_n9[nl2ohjTi0GoSJ_Z5Oooool00ol0003oooooooooo`0looooo`008_ooool01Ol@
413ooooooooooooooooo410@01_ooooo0_l0001Eooooo`_oTfnW1onCL:P9oi=aZ@04oi=bZ_nFMJco
UWF/oiIe[0CoUgJ]1?nGN:h4oiQi[`GoVG^`00?oVGfboj69^onQRK/00_nQRK/4oj><_0GoY8nn00?o
YY;0ok>/d_nc[=800_nc[=84okB^dP;o`>C`1?o1g^h2oj7ei`;oTh_71?nBT<h4oi2Ee@CoSY[K1?n<
Wn45ohZTiP04o`000?n9Z>WoRJSYohVXj@;oRJ_/0_n@U]H4ohnMg@GoSZCT1On=ZnXEooooo`03o`00
0?oooooooooo03_ooooo000Rooooo`05o`000?ooooooooooooooool000006?ooool3o`0005Cooooo
0_nCKjH<oi=_Y`SoTg2X1_nCLJT2oiIdZ`GoUWF/0onGMZd4oiMh[PGoV7V_0onINk000onPQkWoXHVk
oj69^`03oj69^`GoXhbl0onTSkh00onbZ]7o/jcBok>/dP03ok>/dP?o]:kB1?o0i?000oo1g^koXOGW
oj7ei`05oi>;a`CoTY3>1?n@UMD4ohjJf`CoS9oQ0_n:Y>H2oi69a`04o`000?nAT<koTI3>oi6@cPGo
T9KF1?n?WMd5ohjTi0;oSJ_Z0_nH[nLEooooo`03o`000?oooooooooo03_ooooo000Rooooo`05o`00
0?ooooooooooooooool000005_ooool3o`0005?ooooo1OnCKjH<oi=_Y`SoTg2X0onCLJT00onELj[o
UWB[oiIdZ`02oiIdZ`GoUWF/0onGMZd4oiMh[PGoV7V_00?oVG^`oj27^OnPQkT00_nPQkT4oj69^`Go
Xhbl00?oY8nnok:ZdOnbZ]400_nbZ]45ok>/dP03okB^d_o0i?3o`>C`00;o`>C`0_n<k]T3oiB6`@Co
Th_71?nBT<h4oi2Ee@;oSY[K0_nCP;/4oi:4`@CoTHW700?o0000oi6@c_nAT<h00_nAT<h4oi2FePGo
SigM0_n>Y>@2oiRVg`GoV:oW5Oooool00ol0003oooooooooo`0jooooo`008_ooool01Ol@413ooooo
oooooooooooo410@01?ooooo0ol00002ooooo`03o`000?oooooooooo04oooooo2?nCKjH;oi=_Y`So
Tg2X00CoTg6YoiEcZ_nELj[oUG>Z1OnFM:/4oiIe[0?oUgJ]1OnGN:h3oiQi[`03oin5^?nPQkWoX8Ni
00?oX8Ni1OnQRK/3oj><_003ok2Xd?nbZ]7o/Z[A00?o/Z[A1?nc[=83okkYl`04ol3Tl?n<k]WoS>kI
oiJ2_0CoU8K11?nCRlL5oi:@cP;oT9GE00?oU7bfoi>0^onCP;/00onCP;/4oi:4`@?oTHW700?o0000
oi6@c_nAT<h00_nAT<h5oi2FeP;oSigM0_nIW]L5oiRVg`CoV:oW5_ooool00ol0003oooooooooo`0i
ooooo`008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg013ooooo0ol0001Eooooo`03oi=^Y_nCKjKo
TfnV00OoTfnV3?nCKjL5oi=`Z0;oUG:Y1OnELjX4oiIdZ`CoUWF/1?nGMZd4oiMh[P03oiQi[onOQKSo
WhFh00;oWhFh1?nPQkT5oj69^`03oj><_?n`Z=3o/:S@00;o/:S@1OnbZ]400onc[=;o_^WcokkYl`02
okkYl`;oLmo30onFP[`4oiB6`@GoTh_70_nBT<h2oiEi/PCoU7bf1?nCP;/4oi:4`@?oTHW700?o0000
oi6@c_nAT<h00onAT<h2oi2FeP;oVYO@1OnIW]L5oiRVg`;oV:oW0_nS]NDDooooo`;o0000>oooool0
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`;o0000E?ooool2oi=_YP?oTfjV2OnCKjH<
oi=_Y`;oTg2X1OnELZT5oiEcZPCoUWB[1?nFMJ`4oiMf[@;oUgR^0_nNQ;H5oin5^0GoX8Ni0onQRK/0
0on_Yloo/:S@ok2Xd003ok2Xd0Co/Z[A0onjk_@00onnjO?oLmo3og?O``02oiIn]`?oUX:l1OnDQ/42
oi>;a`;oUWN^1?nENK84oiAl]PCoTh2k1?nBQ<43oi69a`04o`000?nARLOoTI3>oi6@cP;oVY791OnJ
Um05oiVNe`;oV:KO0_nT[Mh5oj>eiAGooooo00?o0000ooooooooool0>?ooool003;ooooo1Ol0001A
ooooo`GoTfnV1?nCKZH8oi=_YPcoTfnW00?oTg2XoiEbZOnELZT01OnELZT4oiEcZPCoUWB[1OnFMJ`2
oiMf[@03oif2]OnNQ;KoWXBf00?oWXBf1?nOQKP5oj27^@03oj69^on_Yloo[jO?00;o[jO?1On`Z=00
0onbZ]7o^^kdok[^m002ok[^m003oeO;YonFNk?oUWjg00?oUWjg1?nFP[`2oiB6`@;oUgF[1?nFMjh5
oiEi/P?oU7bf1OnCP;/4oi:4`@04oi69aol0003o0000oi^<``GoVY791?nJUm04oiVNe`03ojBVeonT
[MkoY:gN00?oY:gN0onS]ND00on^_>Goooooooooo`0Dooooo`03o`000?oooooooooo03Oooooo000`
ooooo`;o0000EOooool7oi=_YP?oTfjV2?nCKjH:oi=_Y`;oU76X2?nELZT4oiEcZPCoUWB[1OnFMJ`0
1?nGMZgoWH:eoif2]OnMP[D4oij4]PGoWhFh0onPQkT00on^Y/oo[jO?ojnWc`03ojnWc`Co/:S@0ond
lo@00onjk_CoUW^coiIk/`02oiIk/`GoUWjg0_nFP[`00onGM:WoUgF[oiMeZ`02oiMeZ`GoUWN^1?nE
NK84oiAl]PCoTh2k0_nBQ<43o`000004oi^<`ol0003oVhc3oi^<``CoVY791OnJUm001?nIW]OoY:KG
ojBVeonTY]L5ojB]gP03oj>eiOn^_>Go[[cU00;o[[cU5Oooool00ol0003oooooooooo`0gooooo`00
;Oooool3o`0005Cooooo2_nCKjH3oi=^YPWoTfnV1OnCKjL6oiAaZ0SoUG:Y1?nELjX5oiIdZ`?oUWF/
00?oW86doif2]OnMP[D00_nMP[D4oij4]PGoWhFh00?oX8NiojjVcon^Y/l00_n^Y/l5ojnWc`03ok2X
d?ndloCo]??d00;o]??d0_nFN:l5oiIk/`CoUWjg00?oUX:loiMdZOnGM:T01OnGMJ/4oiIg[PCoUGVb
1?nDO;H2oi>0^`04oib5^Ol0003o0000o`0000?oW8Rm0_nKS<<00ol0003oVhc3oiZAb@04oiZAb@;o
VYO@0_nUXM45ojBVe`?oY:gN00?o[[OPojjliOn^_>D01?n^_>DEooooo`03o`000?oooooooooo03Ko
oooo000/ooooo`;o0000D_ooool2oi=_Y`coTfnV0onCKZH9oi=_YP;oTfnW00?oU72XoiAaZ?nDLJP0
1onDLJP7oiEbZ@GoUG>Z1?nFM:/01?nFMJcoW86doib1]?nLPK@5oif2]@CoWXBf0onOQKP00on]Y<ko
[ZK?ojjVc`03ojjVc`Co[jO?0on/mO400ondloCoUWR_oiIh[`02oiIh[`GoUW^c0_nFO[L2oiQcY`Co
UgBY1?nGMJ/4oiIg[PGoUGVb0_nDO;H01?nMP[Go0000o`000?l00002oib5^@CoW8Rm0onKS<<00ol0
003oVY79oiZAb@02oiZAb@03ojJMcOnUXM7oYJ7A00?oYJ7A1?nTY]L00onT[Mko[[OPojjgh002ojjg
h0Co[[cU0_ndaNHEooooo`03o`000?oooooooooo03Gooooo000/ooooo`?o0000C_ooool00onCL:Oo
TfnWoi=_Y`02oi=_Y`coTfnV0onCKZH9oi=_YP03oi=_YonDL:SoU72X00WoU76X1onELZT5oiEcZP;o
UWB[0_nLOk<5oib1]0CoWH:e1?nNQ;H00onOQKSo[JC>ojfTcP02ojfTcPGo[ZK?00?o[jO?ojcelOn/
mO400_n/mO42oiIf[@GoUWR_0onFNk<00onHLZKoV7>WoiQcY`02oiQcY`CoUgBY1?nGMJ/4oiIg[PGo
UGVb0ol00005oib5^@CoW8Rm1?nKS<<00ol0003oVY79ojJMc@03ojJMc@GoYJ7A0_nTY]L00on^/mco
[[OPojjgh004ojjgh003ojjliOndaNKo]<GV00?o]<GV5?ooool00ol0003oooooooooo`0eooooo`00
;?ooool01?l0003oooooo`000?l0001<ooooo`;oTg2W1OnCKjL;oi=_YPCoTfjV1_nCKjH2oiA`Y`Co
U72X2?nDLJP8oiEbZ@?oUG>Z00?oVgjboiao/onLOk<00_nLOk<5oib1]0CoWH:e0onNQ;H00on/Xlko
[JC>ojfTcP03ojfTcPCo[ZK?0onPm>X00on/mO7oUWBZoiIf[@02oiIf[@GoUWR_00CoUW^coiQbY_nH
LZKoV7:V1OnHLjL3oiMdZ@CoUgF[1OnFMjh01?nENK;o0000o`000?l00004oif2]@CoW8Fi1OnLR;d2
oi^<``03ojNJbOl0003oYYg=00CoYYg=1?nUXM400on_/=Wo[[?Lojjcg002ojjcg0Co[[OP0_neaNH4
okC5iP03okG8j?oooooooooo017ooooo00?o0000ooooool000002?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`06Oooool002cooooo0_l0
0002ooooo`03o`000?oooooooooo04Kooooo0_nDL:L4oi=`Y`CoTfnW3?nCKjH3oi=^YP?oTfnV00?o
Tg2WoiA`YonDL:L00_nDL:L4oiA`Z0SoU76X2?nELZT01?nELj[oVgjboi]n/_nKO[85oiao/`CoW86d
1OnMP[D01?nNQ;Ko[:?>ojbSc_n/Xlh4ojfTcP?o[ZK?0onPm>X3oiIdZPCoUWJ]0onFN:l00onHLJGo
V7:VoiQbYP03oiQbYPCoV7>W0onGM:T5oiMeZ`;oUWN^0ol00003oij0/PCoWH:e1OnLQKT3oib8_@03
ojRHa_nWV/WoYi[900;oYi[900?o0000ojJMcOnVWLd00onVWLd00onUXM7o[k3Iojn`f@02ojn`f@Co
[[?L00?o[[OPokG5i_neaNH00oneaNH00ondaNKo]LSXokG8j002okG8j1Gooooo00?o0000oooooooo
ool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B406Oooool002_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`12oooo
o`03oiA`Z?nDL:OoU72W00;oU72W1?nCL:L4oi=_Y`coTfnV0onCKZH01?nCKjKoTg2Woi=`YonCL:L5
oiA`Y`?oU72X2?nDLJP7oiEbZ@03oiYm/_nKO[;oVgjb00?oVgjb1?nLOk<5oib1]0?oWH:e00?o[:;=
ojbSc_n/Xlh00on/Xlh4ojfTcP04ojjVconPm>[oX?CZoiIbZ0GoUWBZ0onFMZd01?nFN:ooV76UoiQa
YOnHLJD5oiQbYPCoV7>W0onGM:T5oiMeZ`;o00000_nNO[05oij0/P?oWH:e1OnLQKT00onLR;goZ9S6
ojRHaP02ojRHaPCoYi[900Go0000ojJMcOnVWLgoYYg=ok2^eP05ojn`f@;o[[?L0onfa^H4okG5iP03
okK;j_neb>So]LSX00?o]LSX5Oooool00ol0003oooooooooo`05ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000001Wooooo000[ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0?_ooool01?nDLJSoU72XoiA`Z?nDL:P5oiA`Y`?oTg2W1?nCKjL<
oi=_YP;oTfjV1_nCL:L4oiA`Y`?oU72X2OnDLJP4oiEbZ@?oVWfb1OnKO[84oiao/`GoW86d00?oWH:e
ojbRcOn/X/d00_n/X/d4ojbScP?o[JC>0_nBl>03oiIbZ0GoUWBZ0_nFMZd00onHLJCoV76UoiQaY@03
oiQaY@CoV7:V1?nHLjL4oiMdZ@04oiMeZol0003o0000o`0000CoWWj`1OnNP;84oif2]@?oW8Fi00?o
ZIS4ojRHa_nXV<H00onXV<H4ojNJb@03o`000?nVWLgo/:kF00?o/:kF0on_/=T00ongbNOo]/KVokK6
iP04okK6iP03okG5i_nfbn[o]/_Z00;o]/_Z0oneb>P2ok?8jQGooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Iooooo`00
:oooool3o`0000Gooooo00?o0000ooooooooool0>oooool3oiAaZ0CoU72X1?nDL:L3oi=`Y`CoTfnW
2_nCKjH:oi=`Y`CoU72W0onDL:P9oiAaZ0;oUG:Y00?oVWbaoiYm/_nJOK800onJOK84oi]n/PGoW7nc
0onLPK@00on[XLgo[:;=ojbRc@03ojbRc@Go[:?>00?o[JC>oi;`h?nBl>001OnFLZP3oiIdZP04oiUa
Y?nHLJCoV76ToiQaY0GoV76U1?nHLZH4oiQcY`;oUgBY0ol00003oiim[PGoWWj`1?nNP;84oif2]@03
oib5^OnYV<CoZIS400;oZIS41?nXV<H4ojNJb@03ok6^eOl0003o/:kF00?o/:kF00?o[k3IokO9iong
bNL00_ngbNL4okK6iP;o]/k/1?nfbnX00oneb>So/lSZok?8jP03ok?8jQGooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00I
ooooo`00:oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Sooooo00?oU7:YoiAa
Z?nDLJP00onDLJP3oiA`Z0CoU72W0onCL:L5oi=_Y`KoTfnV3OnCL:L4oiA`Y`CoU72X1onDLJP01?nI
Nk7oVWbaoiYl/OnJO;45oiYm/PCoVgjb1OnLOk<00onLPKCoZj7=oj^Qc@02oj^Qc@Co[:;=1?n/Xlh0
1?n2j=?oUW2VoiI`Y_nFL:H5oiIbZ004oiIdZ_nILJCoVG6ToiUaY0CoV76T1?nHLJD4oiQbYP?oV7>W
0ol000000onGM:WoWgb]oiim[P04oiim[PCoWWj`1OnNP;82oif2]@03oj^H`onYV<CoZIS400?oZIS4
1OnXV<H00onWV/Wo/JkEok6^e@02ok6^e@04o`000?n`[]Ko/:kFokW<j@Ko]lWW00?o]/KVokK>k?nf
c^`00onfc^`2okK;jP;o/lc/1?ncb>X00on_a^_oooooooooo`0Cooooo`03o`000?oooooooooo00?o
oooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo01_ooooo000[ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0<oooool2oiEbZ@?oU7:Y1OnDLJP3oiA`Z0Co
U72W1?nCL:L4oi=_Y`CoTfnV3onCL:L4oiA`Y`CoU72X1OnDLJP3oiUk/@CoVWba1?nJOK85oi]n/P?o
W7nc00?oZJ3=oj^QcOn[XLd00on[XLd5ojbRc@04ojbSc_nEKjGoUFnUoiE_Y@CoUW2V0onFLZP5oiUa
Y0CoV76T1?nHLJD4oiQbYP?o00000_nHLjL00onGM:WoWgb]oiml[@05oiim[PCoWWj`1OnNP;801?nM
P[GoZiS3oj^H`on[V<<4ojVHa0CoZ9S600?o/ZkDok6^eOna[]D01?na[]D01?l0003o^LcYokW<jOni
c>T4okO9i`;o]]?_1?nfc^`00onbd>oo/lc/ok?<k003ok?<k003ok?8j_n_a^_o[lK[00;o[lK[4ooo
ool3o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01_ooooo
000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooo
ooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;oooool00onELj[oUG:Y
oiEbZ@02oiEbZ@CoU7:Y1?nDLJP3oiA`Z0CoU72W1?nCL:L4oi=_Y`;oTfnV4OnCL:L5oiA`Y`?oU72X
0_nDLJP2oiUk/0GoVG^a0onJO;44oiYm/PGoVgjb00?oW7ncojVPcOnYX<d00_nYX<d4oj^Qc@Co[:;=
00?oUFjToiE_YOnEKjD00onEKjD3oiI`YP03oiIbZ?nILJCoVG6T00KoVG6T0onHLJ@4oiQaY@05oiQb
Y_l0003o0000o`000?nHLZH00onHLjL5oiml[@CoWWf^1OnNO[03oij0/P03ojfJa?n[V<?oZiS300;o
ZiS31OnYV<@00onXV<Ko/ZkDok:^e002ok:^e0Co/JkE00?o^M7/o`000?nic>T00onic>T00ongbNOo
]]?_okKCk`03okKCk`03okK>k?nbd>oo/]3_00;o/]3_0_ncc>`3ojo:k@Go[lK[5Oooool02Ol0003o
ooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@41Wooooo
000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1?ooool3o`0000[ooooo00?o0000ooooooooool0;Oooool2oiEcZPGoUG:Y0onDLZT4oiAaZ0?oU72X
1OnDL:L3oi=`Y`;oTfnW0_nCL:PDoi=`Y`CoU72W0_nDL:P00onHN[3oVG^`oiUk/002oiUk/0GoVG^a
0onJO;45oiYm/P?oVgjb00?oZIo=ojVPcOnYX<d00onYX<d5oj^Qc@04ojbRcOnEKZCoUFjToiE^Y0Go
UFnU0_nFL:H:oiUaY0?oV76T0_nHLJD3o`0000CoV7:V00?oV7>Woiml[OnOO:d01OnOO:d4oiim[PGo
WWj`00?oWX2bojfJa?n]V/@00_n]V/@3oj^H``CoZIS400?o];7Fok:^e?nb[]@01?nb[]@00ona[]Go
^M7/okWAk002okWAk003o`000?nic>Wo^LcY00;o]]Sb1?nfdnl00onae?;o/]3_ok;@k`02ok;@k`03
ojk=l?n_b^go[l[]00Co[l[]0_n_a^/2ojc4jaGooooo00?o0000ooooooooool0;oooool000Sooooo
1_l00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Yooooo`;oUWB[1?nELjX4oiEbZ@?oU7:Y1?nDLJP4oiA`Z0Co
U72W0_nCL:L5oi=`Z1CoTg2W1?nDL:L00onDL:SoV7Z`oiQj/005oiUk/0CoVG^a1?nJO;44oiYm/P03
oi]n/_nYWlgoZIo=00;oZIo=1OnYX<d2oj^Qc@03oekA/_nDKJ?oU6fS00CoUFjT1?nEKjD00onFL:Ko
VG6ToiUaY009oiUaY0?oV76T0_l00003oiQaY@?oV7:V00?oWgb/oiml[OnOO:d01_nOO:d5oiim[P?o
WWj`00?o[Yc5ojfJa?n]V/@00on]V/@4oj^H``03ojVHa?nd/MKo];7F00;o];7F1?nb[]@2okWGk`Co
^M7/00?o^LcYo`000?nff?800onff?800onfdnoo/MCbok7DlP02ok7DlP03ok;@kon^cO3o[/g`00;o
[/g`1?n_b^d00on[aNgo[<C[ojc4j`03ojc4jaGooooo00?o0000ooooooooool0;_ooool0013ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Uooooo`03oiIe[?nFM:_oUWB[00;oUWB[1?nELjX4oiEb
Z@?oU7:Y1OnDLJP3oiA`Z0?oU72W2OnCL:PCoi=`Y`;oU72W1_nHN[04oiUk/0CoVG^a1?nJO;42oiYm
/P;oZ9k=1OnYWld4ojVPc@03o`000?nDK:;oU6fS00?oU6fS1?nEKZ@3oiE_Y@03oiQ`Y?nILJCoVG6T
00[oVG6T0ol000000onHLJCoV76UoiQaY@02oiQaY@04oiQbY_nOO:coWgb/oiml[0SoWgb]1OnNOJh0
0onNO[3o[Yc5ojjLa@02ojjLa@Co[I[40on[V<<00one]=So];7FokBaeP04okBaeP03ok:^e?nienoo
^MO_00?o^MO_0_nidN`2okCNm@03o`000?nff?;o]]Sb00Co[mSe0_nae?82ojg@lPGo[/g`00?o[l[]
oj_5kOn[aNd00_n[aNd2ojc4j`?oZ/;[5Oooool00ol0003oooooooooo`0]ooooo`004?ooool01Ol0
003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo027ooooo00CoUgN]oiIe[?nFMJcoUWF/1OnFM:/3oiEcZPCoUG:Y
0onDLZT5oiAaZ0?oU72X00?oU72Woi=`Z?nCL:P02OnCL:PAoi=`Y`;oV7V`2?nHN[04oiUk/0GoVG^a
0_nJO;400onWW/goZ9k=ojRNc@03ojRNc@GoZIo=00?oZJ3=oiA/X_nDK:800_nDK:85oiA]X`?oUFjT
00CoUFnUoiQ`Y?nHL:CoV72T2OnILJ@3o`0000CoV76T0onHLJD6oiml[0SoWgb]0onNOJh00on`WlOo
[Yc5ojjLa@03ojjLa@Go[I[400CoZiS3okFdf?ne]=So]KCH1?nd/MH2okSNl`Co^MO_00?o/>?hokCN
mOndg_D00_ndg_D00on]foOo0000ojoHm@03ojoHm@03oj_Bm?n]d?;o[M3b00?o[M3b0_n^cO03oj_7
kP?oZlG]00?oZL?/oj[2jonZ`^/01?nZ`^/Dooooo`03o`000?oooooooooo02gooooo000@ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`;o00003oooool2o`00
023ooooo0_nGMjd4oiIe[0CoUWB[0onELjX4oiEbZ@CoU7:Y1?nDLJP2oiA`Z003oi=aZOnCL:SoTg2X
00[oTg2X3_nCL:L00onGNK3oV7V`oiQi/002oiQi/0SoV7Z`1?nINk05oiUk/@04oiYl/OnWW/goYik=
ojNNc@CoZ9k=1?nYWld00ol0003oU6^QoiA/XP04oiA/XPCoU6fS0_nEKZ@5oiQ`Y0KoVG6T0ol00004
oiUaY0?oV76T00?oV76Uoiml[?nOO:`01_nOO:`8oiml[@03oiim[_n`WlOo/9o700;o/9o71?n^W<D4
ojfJa003okNifone]=So]KCH00?o]KCH00?o];7FokSNlonhg_<00onhg_<00onienoo/>?hok3Sn002
ok3Sn003okCNmOn]foOo[M_g00;o[M_g00?o0000ojoHmOn[d_@00on[d_@2ojg@lP?oZ/S_1On[anh0
1?n[aNgoZL?/ojW3k?nY`n`4oj[2j`03ojS1jooooooooooo01?ooooo00?o0000ooooooooool0;?oo
ool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Jooooo`;oUgR^1?nGMjd3oiIe[0CoUWB[0onE
LjX5oiEbZ@?oU7:Y0_nDLJP5oi=aZ@coTg2X3?nCL:L3oiMi/0GoV7V`1onHN[05oiUk/0?oVG^a00?o
YYg=ojNNcOnWW/d00onWW/d4ojRNc@03ojVOcOl0003oU6^Q00;oU6^Q1OnDK:84oiA]X`03oiE^Y?nH
L:CoV72T00GoV72T0_nILJ@3o`0000OoVG6T0_nHLJ@00onOO:goWgb/oiml[007oiml[0OoWgb]00?o
/JC:ok2Oaon`WlL00on`WlL5ojjLa@03ojfJa?ng^M_o]kWK00;o]kWK0one]=P2okCUm`Co^=kc0_nZ
j?X2ok3Sn0CoZMgj0_n]foL2ojWDm`04o`000?n[d_CoZm;doj_Bm0;oZLWa1OnZb>l2oj_7kP;oZLC]
1OnY`n`00onZ`^_oZ<7[ojS1j`02ojS1ja?ooooo0_l0000^ooooo`004?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01Kooooo00?oV7V_oiMh[_nGN:h00_nGN:h4oiMg[@?oUWF/1?nFM:/4oiEcZPCoUG:Y
0_nDLZT00onCLZ[oTg6Yoi=aZ@06oi=aZ@_oTg2X2_nCL:L6oiMi/0CoV7V`2?nHN[04oiUk/003oiUk
/OnVWLgoYYg=00;oYYg=1?nWW/d3ojRNc@?oTf^Q1?nDJj44oiA/XP;oU6fS2OnHL:@3o`0000[oVG6T
00CoV76Toiml[OnOO:goWgb]2?nOO:`6oiml[@?o/JC:1?n`WlL4ojjLa@03okS0h?ng^M_o]kWK00?o
]kWK00?o]KCHokCUmondiOL00ondiOL01?nhg_?oZ^Sjoj[Xn_nZj?X2ojGOn`CoZMgj0_nWe_P3ojWD
m`03o`000?n[d_CoZLWa00CoZLWa0_nZb>l2ojS4kPGoZLC]0_nY`n`3ojS1k0CoZ<7[5Oooool00ol0
003oooooooooo`0[ooooo`00:Oooool2o`0001Cooooo00?o0000ooooooooool05?ooool2oiQi[`Co
UgR^1?nGMjd3oiIe[0CoUWB[1?nELjX2oiEbZ@;oU7>[0onCLZX8oi=aZ@coTg2X1OnCL:L2oiIi/0So
UgV`1?nHNK08oiQj/0;oVG^`0_nUWLd5ojJMc@GoYik=00?oZ9k=oi=[XOnCJj400_nCJj44oiA[X@?o
U6bR2OnHL:@3o`000003oiQ`Y?nILJCoVG6T00WoVG6T00?oWgf]oiml[OnOO:d00_nOO:d8oiml[0Co
Wgb]00?o/jS>ok6Tb_naY<X00_naY<X5ok2Oa`03ojjLaOnh`>3o^<3P00;o^<3P0ong^M/3ojk[n@;o
]>Gg1?nQjoX00onZj?[oYMokojGOn`02ojGOn`03ojWMn_nWe_SoYmKh00?oYmKh0_nYe?L00onXb_7o
0000ojW9l@03ojW9l@03ojS5k_nXa>koZ<C^00?oZ<C^0_nYa>d3ojS2k0GoZ<7/0_nX`N/2ojS0jaGo
oooo00?o0000ooooooooool0:_ooool002Wooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0@ooooo`;oVG^`1?nHNJl3oiMh[PCoUgN]0onFMJ`5oiIdZ`;oUG>Z00?oU7B/oiAcZonDLj/0
0_nDLj/4oi=bZPOoTg6Y3?nCL:P2oi=`Y`GoUWV`2?nGNK04oiQi/0OoV7Z`00?oY9c=ojFMcOnUWLd0
0onUWLd5ojJMc@;oYik=0onCJZ05oi=[X@?oU6^Q00?oU6bRoiQ`Y?nHL:@01onHL:@2o`0000CoV72T
2OnILJ@3oimm[@CoWgb]2OnOO:`2oiml[@?o/jS>0onaY<X4ok2Oa`;o^<SV1Onh`>001?ng^M_o[^_i
ojk[nOn^joT3oiO/m`;oXN_j0onQh?`2ojGOn`CoYMOi0_nWe_P2ojO:lPCoZ<[a00?o0000ojW9lOnX
aNh00onXaNh3ojS4kPOoZ<;/0_nX`N`7ojS0jaCooooo00?o0000ooooooooool0:_ooool002Wooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0<ooooo`03oiYm/_nINk3oVG^`00;oVG^`
1?nHNJl4oiMh[P?oUgN]1?nFMJ`4oiIdZ`03oiEcZ_nDM:coU7B/00CoU7>[1?nCLZX7oi=aZ@coTg2X
00?oTg2WoiIi/?nFNK001OnFNK07oiMi/0GoV7V`1?nHN[04ojBLc@CoYIg=1?nVWLd7oi=ZX0CoTf^Q
0_nDJj400onGL:CoV72ToiQ`Y005oiQ`Y0?o00001_nHL:@7oiUaY003oimm[_nOOJgoWgf]00?oWgf]
1?nOO:d8oiml[003oiml[OncZ<ko/jS>00;o/jS>1?naY<X00on`WlOo^<SVokS8iP03okS8iP;o^<3P
0onTk_P01?n^joWoUncgoiO/monGk?L4oigQo@;oXN3l0onSeoX2ojGGn@?oY/[b1?nWb_82ojS:l@;o
YlG_00?o0000ojS5k_nXaNh00onXaNh00onXa>koZ<;/ojS2k005ojS2k003ojO1k?nX`>_oZ<3[00Go
Z<3[0onW`>/Dooooo`03o`000?oooooooooo02Wooooo000Yooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool02?ooool01?nJOkCoVWfboiYm/_nJOK85oiUk/0?oV7V_1?nGN:h4oiMg[@?o
UWF/0_nFM:/2oiAe[@CoU7B/0onDLj/4oi=bZPOoTg6Y2_nCL:P:oiIi/0SoUgV`1?nHNK02oiQj/003
oj>LcOnTW<goY9c=00?oY9c=1OnUWLd00onVWLgoTVVPoi=ZX007oi=ZX0CoTf^Q00?oU6^QoiM`Y?nG
L:@01?nHL:@3o`0000[oV72T1?nILJ@3oimm[PGoWgf]1?nOO:d7oiml[003okB^doncZ<ko/jS>00?o
/jS>0onaY<X2okSAk@Co^<SV0onGk_@2ojC^n0;oR^Wb0onJh?d2oigQo@;oX]Kj1?nSeoX2ojK9lPGo
Y/[b0_nWb_85ojO5k`04o`000?nWaNooZ<G^ojS5kP;oYl;/1_nX`^`4ojO1k0?oZ<3[1onW`>/Doooo
o`03o`000?oooooooooo02Sooooo000Yooooo`?o00005oooool00ol0003oooooooooo`06ooooo`;o
VWnd1?nJOK84oiUk/0?oV7V_1?nGN:h4oiMg[@;oUWF/00?oUGJ^oiAe[OnDMJd00_nDMJd4oiAd[0Co
U7>[0onCLZX8oi=aZ@GoTg2X0_nFNK4<oiIi/0SoUgV`0_nHNK02oj>Kc@CoXic=1OnTW<d2ojFMc@Co
TVVP2?nCJZ02oi=[X@GoUg2T00CoV72To`000?l0003o00003OnHL:@2oiUaY003oimn[onOOJkoWgf^
00?oWgf^1?nOOJd4oiml[@GoWgb/1?nd[]<5ok>XcP03ok6Tb_nhdNgo^=7]00;o^=7]00?o^<SVoiO^
m?nGk_@00_nGk_@2ogkUk003oh[Yl_nJh?goV^3m00;oV^3m0_nQe_X4oj;FnP03oj?Gn_nVbO;oY/Wb
00?oY/Wb0_nVb_82ojO4k`OoYlG_00?oYl;]o`000?nW`^`01?nW`^`2ojS2k0OoYl7/00?oZ<3[ojO0
jonW`>/01onW`>/Cooooo`;o0000:_ooool002Wooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`02ooooo`;oVh6f1?nJOk@3oiYm/PCoVG^`1?nHNJl3oiMh[P;oUgN]0_nEMjl3oiEf[PCo
U7F]1?nDM:`4oiAcZ`?oTg:Z2?nCLJT2oi=`Z003oiEi/OnFNK7oUWVa00;oUWVa3?nFNK07oiMi/003
oj:Kc_nSVlgoXi_=00?oXi_=1?nSW<d3ojBLc@SoTVVP1_nCJZ000onFL:CoUg2ToiM`Y003oiM`Y0?o
00004?nHL:@00onILJCoWgj_oimn[`05oimm[PCoWgf]1OnOO:d2oiml[003okFdf?nd[]?o]:kC00Co
]:kC0_ncZ<h2okGKl`Co^=7]0on7j^d01?nGk_CoO^G/ogkUk?mniN`3oiSPoP03oi[PoOnQe_[oXMKj
00?oXMKj0_nRe_X2ojG9lPCoY/Wb00?oY/C^ojO4konWa>l00onWa>l2ojO5k`KoYl;]00?o0000ojO2
k?nW`^`02_nW`N`<ojO0jaCooooo00?o0000ooooooooool09oooool000kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool06_ooool00ol0
003oWHBioi^1]P03oi^1]PCoVWnd0onJOK85oiUk/0?oV7V_0_nGN:h00onFNK7oUGN_oiEg[`02oiEg
[`CoUGJ^0onDMJd4oiAd[0CoU7>[1?nCLZX5oi=aZ@;oUGVb0onENK45oiIi/@coUWV`1?nGNK04oj:K
cPCoXi_=1OnSW<d00onTW<goTVVPoi9YX007oi9YX0GoTfZP0_nFL:@2oiM`Y0?o00000onGL:@?oiQ`
Y003oimn/?nOOZooWgj_00;oWgj_1?nOOJh4oimm[@GoWgb]00CoWgb/okFdf?ne]=So]KCH1?nd[]<2
ok3Tn0Co]M_c00Co^=7]ohOZkOn7j^goQn[]0_mbhNH3oiOOoP;oV>3n1?nPeOX2oj7FnP;oYLSb1OnU
bO800onVbO;oY/C^ojK4kP02ojK4kP?oYlC_2OnW`^d00ol0003oYl3/ojO1k006ojO1k13oYl3[5Ooo
ool00ol0003oooooooooo`0Vooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003oooooooooo`0Hooooo`04oij8
^onMQ;WoWHBioif4^@CoVh6f1?nJOk@3oiYm/PGoVG^`0_nHNJl01?nFNk;oUWVaoiIi/OnFNK45oiEg
[`?oUGJ^1?nDMJd3oiAd[0CoU7>[1?nCLZX2oi=aZ@03oiEj/_nENK;oUGVb00;oUGVb1?nENK44oiIi
/@coUWV`0_nGNK000onQV/koXY_>oj:KcP03oj:KcPGoXi_=0_nSW<d<oi9YX0;oTfZP0_nFKjD2oiI`
Y0?o00001_nGL:@=oiQ`Y0?oWgj`1?nOOZl4oimm[PGoWgf]0onOO:d00onf_=ko]KCHokFdf003okFd
f003okB^don`i?So/>Ch00?o/>Ch0_nefo<2ogOSh`03ofWLh?nFg_koU]kn00;oU]kn0_nGgoh3oj7C
nP;oX=Gj1onUb?82ojG9lP?oY/?^1OnVa>h00onWa>ooYl;]ojO2k@05ojO2k@CoYl3/00Co0000ojO0
k?nW`NcoYl7/5OnW`>/Dooooo`03o`000?oooooooooo02Kooooo0006ooooo`Ko00000_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool2o`0001Sooooo0_nNR;/4
oif4^@CoVh6f0onJOk@4oiYm/P?oVG^`00CoUgbdoiIk/_nFNk;oUW^b1?nFNK44oiEg[`?oUGJ^1?nD
MJd4oiAd[0?oU7>[0_nCLZX2oiEj/`?oUGZb1OnENK83oiEi/@CoUWVa2_nFNK02oj2JcPCoXI[>1?nR
Vlh4oj>Kc@koTVVP00?oUFnUoiI_YOnFKjD00_nFKjD2o`0000;oUW2T1onGL:@:oiQ`Y0;oWgna1OnO
O[03oimn[`GoWgf^1?nOOJd00onOO:go][cNokJlgP02okJlgP?o]KCH0onWjoX2ok3Tn0;oIm_H0_mS
fM`5oiKNoPCoXM;i0_nQdoX2ojG7l@OoYLSb1onV`nh2ojK4kP;oYl7/1_nW`^d7ojO0k003o`000?nW
`>_oYl3[01KoYl3[5?ooool00ol0003oooooooooo`0Uooooo`003_ooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`0Dooooo`;oWhbo1?nN
R;/3oif4^@CoVh6f1?nJOk@3oiYm/P04oiUk/?nGO;CoUgbdoiMl]0CoUW^b0onFNK44oiEg[`?oUGJ^
1?nDMJd4oiAd[0;oU7>[00?oU7^doiEj/onEN[<00_nEN[<4oiEj/PCoUGVb0onENK44oiIi/@OoUWV`
00?oWi[>oj2Jc_nPV/h00onPV/h4oj6JcPCoXY_>00?oXi_=oi9ZXOnBJZ402_nBJJ02oiA^Y@?oUFnU
00CoUVnUo`000?l0003o00001?nFL:@7oiM`Y0OoV72T00?oWX2boimo/OnOOk400_nOOk45oimn/0?o
Wgj_1OnOOJh2oimm[@?o]/CT1?nf_=h00one]=SoYn_jojO[nP02ojO[nP03oeWCcOmNe][oG]KJ00?o
Umgn0_nFg_h3oj7An0CoXM;i1_nUao42ojG8lP;oY/;^1onV`nh7ojO1k0;oYl;]0onW`>/5ojO0k0?o
Yl3[00?o0000ojO0jonW`>/05OnW`>/Eooooo`03o`000?oooooooooo02Cooooo000>ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo017o
oooo00?oXI73oin<_onOS;l00onOS;l3oij8^`?oWHBi1?nKPKH4oiYo]0;oVWfb00?oUgjfoiMl]?nG
O;@00_nGO;@4oiIk/P?oUWVa1?nEMjl4oiEf[P?oU7F]0_nDM:`2oiAk]@?oU7^d1OnEN[<3oiEj/PCo
UGVb0onENK45oiIi/@?oUWV`00?oWYW?oinJc_nOV/h00_nOV/h4oj2JcPGoXI[>0_nRVlh5oi9ZX@Ko
TVVP00?oTfjUoiA^YOnDKZD00_nDKZD01?nEKjGo0000o`000?l00003oiI_Y@CoUW2T2?nGL:@5oiQ`
Y0;oWX2b1OnOOk44oimn/0CoWgj_0onOOJh00onfc>_o]/CTokK4i004okK4i0;o][cN0onIkOH00onW
jo[oG=GIoiSLoP03oiSLoP;oUmgn0_nRd?P5oj7An003oj7BnOnUao7oYLOa00CoYLOa0onV`^d4ojK2
kP;oY/?^2_nW`N`7ojO0j`;oYl3/1OnW`>/00ol0003oYl3[ojO0j`0FojO0ja?ooooo0_l00008oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<
c009ooooo`003_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00ooo
ool2o`00017ooooo0onQTL<4oin<_`?oWXRk1?nMQ;T3oi^1]P;oVWnd0_nHPKT3oiMn]PCoUgbd1?nF
Nk83oiIi/@GoUGN_0onEMZh2oiAe[@03oiAl]_nDNkGoU7^e00;oU7^e1?nDNk@4oiEj/`?oUGZb1?nE
NK84oiEi/@CoUWVa00?oUWV`oijIconNVLl00_nNVLl3oinJcPGoX9[>0_nQV/h2oi9[XPOoTVZQ1OnB
JJ02oi=^Y@;oU6jU0ol00003oiE_Y@?oUVnU1?nFL:@8oiM`Y0?oV72T00?oWX6coij0/_nNP;800_nN
P;84oimo/@CoWgj`1?nOOZl00onOOJko]/c[okK<j`02okK<j`Co]/CT0on7j^`2oiW]mP;oVM_m1?nH
g?h2oj;?m`CoX]3h0_nQdOP3ojK6l0?oYLOa00?oYl;]ojK2kOnV`^d01?nV`^d2ojK2kPWoYl7/4onW
`>/00ol0003oYl3[ojO0j`0FojO0jaCooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B402Oooool000kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool2o`00
013ooooo00?oXiK7oj6A`onQTL<00_nQTL<4oin<_`CoWXRk0onMQ;T2oi^1]P03oiR3^onHPKWoV86i
00?oV86i0onGO[H4oiMl]0?oUW^b1?nFNK44oiEg[`;oUGJ^00CoU7fhoiAl]_nDO;KoU7bf1OnDNkD3
oiAk]0CoUGZc0onEN[85oiEi/P?oUGVa0_nFNK42oifIc`GoWYW?0onOV/h4oj2JcP;oTV^S0onBJj87
oi9ZX@;oTVVP0_nCKJD2oi=^Y@?o00000_nDKZD4oiE_Y@CoUVnU0onFL:@8oiM`Y004oiQ`Y?nNPK?o
WX6coij1/`CoWX2b1?nOOk45oimn/0;oWgj_0_nde?45okK<j`06okK4i?n7j^coQn[/ohOZk?m5aKco
Vm[m1OnIfod00onHg?koX/ogoj;?m`03oj;?m`;oX]3h0_nVaO05ojK6l004ojG7lOnW`^goYl;]ojO2
k@CoY/;]2?nW`N`HojO0j`03o`000?nW`>_oYl3[01KoYl3[5?ooool00ol0003oooooooooo`04oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Wooooo000>
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo
00?o0000ooooooooool02oooool2ojFMc@CoXiK70onQTL<5oin<_`?oWXRk0_nMQ;T00onIQ[koV8>k
oiR3^`02oiR3^`CoV86i0onGO[H4oiMl]0CoUW^b0onFNK42oiEg[`;oU7ni0onDOKP4oiAl]PCoU7^e
0onDNk@4oiEj/`CoUGZb1?nENK82oiEi/@03oibIconMVLooWIW?00?oWIW?1?nNVLl4oinJcP03oj2J
c_nBJj?oTV^S00;oTV^S0onBJj86oi9ZX@04oi9]Y?nCKJGoTffUoi=]Y@?o00000_nCKZD3oiA^Y@Co
UFnU1?nFKjD4oiI`Y0KoUg2T00?oWX6doij1/onNPK<00onNPK<3oij0/PGoWgna1?nOO[000onOOZoo
]=CaokCDl@02okCDl@;o]/c[0_mbhM`2oco1]`03oegFfonKf_goVm[m00;oVm[m0_nIfod4oj?=mP;o
X/og0_nVaNl5ojK5l0;oY/K`0_nW`Nd5ojO2k@03ojK2kOnW`NcoYl7/00GoYl7/7?nW`>/00ol0003o
Yl3[ojO0j`0EojO0jaCooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P09ooooo`009oooool00ol0003oooooooooo`08oooo
o`03ojRTd_nUWLgoYIg=00?oYIg=0onSU/L4oj6A``CoWhbo0_nNR;/00onIR/;oVHJnoiV6_P02oiV6
_P?oV8>k1?nHPKT3oiMn]PCoUgbd1?nFNk82oiIi/@03oiB0^onDOkWoU7ni00;oU7ni1?nDOKP3oiAl
]PCoU7^e0onDNk@5oiEj/`?oUGZb0_nENK82oi^Hd0CoW9W?1?nMVLl5oijIc`;oWi[>0_nBK:@4oi9[
X`?oTV^R0_nBJZ42oi5/Y0?oTVfT0ol000000onCKJGoTfjUoi=^Y@02oi=^Y@CoU6jU0onEKjD4oiI_
Y@CoUW2T0onGL:@01?nMP[CoWX6doij1]?nNPK@5oij1/`?oWX2b1OnOOk42oimn/0?o/M_f0onde?42
oegDbP;o>kfc00?oH=OMoicIoOnLfOd00_nLfOd2oi_Jo@?oY<ce0_nScOH3ojK4k`CoY/G_0_nVaO03
ojO1k0CoYl7]0_nW`^d8ojO1k1koYl3[00?o0000ojO0jonW`>/05_nW`>/Dooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0
2Oooool002Oooooo0_l00008ooooo`?oZ:CB1?nUWLd3oj>Fa`CoXI730_nOS;l2oiZ=a@CoVH[20onI
Q[h3oiR3^`GoV86i0onGO[H3oiMl]0;oUW^b0_nDP[d4oiB0^`?oU7ni1?nDOKP3oiAl]PGoU7^e0onD
Nk@4oiEj/`;oUGZb1_nKV=04oibIc`CoWIW?0_nNVLl3oi=^Y@?oTVbT0_nBJj<5oi1[Y0CoTFbT00Co
TVfTo`000?l0003oTVfT0onCKJD4oi=^Y@CoU6jU0onEKjD4oiI_Y@CoUW2T00CoUg2Toif2]?nMP[Co
WH:d1?nNPK@4oij1/`CoWX2b0onOOk42ojcQn@Go/M_f00Co]=CaocVk/OmSfMooHmWO0onMf?`2oicI
o@?oY<_d0onTc?D7ojK4k`;oY/G_1onW`N`2ojO1k@WoYl7/8OnW`>/00ol0003oYl3[ojO0j`0EojO0
jaGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@
okZj^_oooooo^[Zjoa0@4009ooooo`009oooool00ol0003oooooooooo`05ooooo`03ojZ]fOnXY=;o
Z:CB00?oZ:CB0onUWLd4oj>Fa`;oXI7300?oVY;:oiZ=aOnJSLD00onJSLD3oiV:`P?oVHJn1?nHPk/4
oiR1^@?oUgjf0_nGO;@00onDQ;ooU8:moiB2_@03oiB2_@?oU82k1?nDOkT3oiAm^0CoU7bf1?nDNkD3
oiAk]0;oUGZc0_nJV=48oi^Hd0GoW9W?0_nMVLl3oiA_YP?oTfjU0_nBK:@00on?JZCoT6^Toi1[Y005
oi1[Y0;oTFbT0ol00003oi9]Y0?oTffU1?nCKZD4oiA^Y@CoUFnU0onFKjD2oiI`Y0;oWH:e1OnMP[@3
oij1]0GoWX6c0onNP;800onOOk7o[>7iojcQn@03ojcQn@;o/M_f0_mVf^84oikHo0;oWMSl0_nUbo<5
ojC;m003ojC<mOnVa>ooY/C_00CoY/C_4_nW`N`VojO0j`03o`000?nW`>_oYl3[01GoYl3[4_ooool3
o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000
2Oooool002Oooooo00?o0000ooooooooool00_ooool00on/]^3oZZgIojZ]f@02ojZ]f@CoZ:CB1?nU
WLd2oj>Fa`03oi^Gc_nJT/[oVY;:00;oVY;:1?nJSLD3oiV:`PCoVHJn0onHPk/2oiR1^@;oU8S40onD
Q/44oiB4_`CoU8:m0onDP;/4oiAo^@CoU7fh0onDO;H2oiAk]@;oV9SB0onIV=45oiZHd@SoViS@0_nL
VLl3oiEaZ0CoU6nV0_nCKZD4ohmZY0KoT6^T0ol00002oi5/Y0CoTVfT1?nCKJD3oi=^Y@CoU6jU1?nE
KjD2oiI_Y@03oib2]_nMP[GoWH:e00;oWH:e1OnMP[@3oij1]0GoWX6c0_nNP;83ojKUn`;o[>7i00?o
>;^aof[LiOmZg>D00onOeo/2oikHo0?oYL[c1?nUbo<2ojC;m0?oY/C^0onVa>l00onW`>coYl7/ojO1
k006ojO1k0;oYl3/1onW`N`YojO0j`03o`000?nW`>_oYl3[01KoYl3[5?ooool02Ol0003ooooooooo
ooooooook^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT02Oooool0
02Kooooo0ol00002ooooo`?o[;KP1?nZ[MT4ojRTdP;oYIg=00?oW9gDoi^Gc_nKUlh00_nKUlh3oiZB
bPCoVXg51?nIR/83oiV6_P;oV8>k00?oU8_6oiB8a?nDR<@00onDR<@3oiB6`@?oU8Bo1?nDP[d4oiB0
^`?oU7ni1?nDOKP2oiAl]P03oiNHdonHV=;oV9SB00?oV9SB0onIV=44oiZHd@KoViS@00CoV7N/oiId
Z_nFM:[oUWBZ0_nELJP;ohmZY0?oT6^T0ol00002oi1[Y0?oTFbT1?nBKJ@4oi=]Y@CoTfjU0onDKZD4
oiE_Y@03oiI_YOnLP[KoW8:f00GoWH:e1?nMP[@4oij1]0?oWX6c0onOj?/2ojKUn`03o`000?m^g^Oo
X=Kk00?oX=Kk0_nOeo/2ojG9lPGoYL[c0_nUbo<2ojO3kPGoY/C^00CoY/C_ojO0k?nW`>coYl3/1?nW
`N`6ojO0k0;oYl7/;_nW`>/00ol0003oYl3[ojO0j`0EojO0jaGooooo00?o0000ooooooooool07_oo
ool002Kooooo00?o0000oooooon^`NP00_n^`NP4ojbfh0;oZZgI00?oWZ_PoifTf_nMY=X00_nMY=X4
oibMe0?oViO>0onJT/X5oiZ=a@;oVH[200CoTi3=oiB=bOnDSLWoU8g91?nDRlH4oiB8a0?oU8K10onD
Q;l5oiB2_@?oU82k0onDOkT2oiAm^0;oUYSD1?nGV=<4oiRHdP?oVISA1OnJV=42oi^Hd0CoV7N/0_nF
M:X>ohmZY0?o00001On@Jj@4oi5/Y0?oTVfT1?nCKJD4oi=^Y@?oU6jU0_nEKjD6oib2]PCoWH:e1OnM
P[@3oij1]003oij1/onOj?_oWnSk00;oWnSk00Co0000og7OjOnQe_[oXMKj1?nPe_/00onVb?;oYLWb
ojG9lP03ojG9lP;oYL[c1onW`nh2ojK4kPOoYl3/00?oYl7/ojO0k?nW`>`01OnW`>`bojO0j`03o`00
0?nW`>_oYl3[01GoYl3[5?ooool00ol0003oooooooooo`0Nooooo`006oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000oooooon^`NP00on^`NP2ojbfh0;oW[CW0onNZn04oifTfP?oW9gD
1?nKUlh3oiZBbP;oVXg50_nCTm44oi>@c@?oU8g90onDRlH4oiB8a0?oU8K11?nDQ;l4oiB2_@;oU82k
00CoU9WFoiFIeOnEVMGoUIWE1OnFV=@3oiNHd`CoV9SB1?nIV=42oiZHd@04oiao/_nJNZooVWZ_oi1/
Y@CoSf^U3On?JZ@3o`000003ohmZY?n@JjCoT6^T00GoT6^T1?nAK:@4oi9]Y0?oTffU1?nCKZD2oiA^
Y@03oi^1]_nLP[KoW8:f00KoW8:f1?nMP[D5oif2]0;oWX6d0onHjOX01?nOj?_oX]Gjoj;En_nReOX4
oj7FnP03oj3FnonVb?;oY/Sb00;oY/Sb0_nUbO89ojO3kPWoYl3/0onW`>/5ojO0k3GoYl3[00?o0000
ojO0jonW`>/05OnW`>/Dooooo`03o`000?oooooooooo01gooooo000Kooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01_ooool00ol0003oooooooooo`02ojk1j003oijmkonN]>OoW[CW00?oW[CW0onNZn04
oifTfP?oW9gD0_nKUlh01?nBVmWoTYODoi:Ge?nBUm@5oi>Cd@?oTi3=0onDSLT3oiB;aPGoU8S40onD
Q/43oiB4_`;oU8:m0_nCV]L4oiBIeP?oUIWE1?nFV=@4oiNHd`CoV9SB0_nIV=401?nOQ;KoW7nboiao
/_n@KJH3oi1/Y@CoSf^U2_n?JZ@3o`0000CoSfZT1on@Jj@4oi5/Y0CoTVfT0onCKJD2oi=^Y@;oVX2f
1?nKPKH7oib2]PGoWH:e0onMP[@3oi7Yn0;oV>Wj1_nReOX2oj7FnP?oY/Sa0_nVb?82ojO3k@OoYl?^
0_nW`>/7ojO0k0OoYl3[0_nW`>`gojO0j`03o`000?nW`>_oYl3[01KoYl3[4oooool2o`0001kooooo
000Kooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0000;ooooo0onN_Nl5oijdi`?oWZ_P
0_nMY=X01?nAYN?oTIoNoi6Og_nAWmh4oi:Kf@?oTYOD1?nCTm43oi>@c@?oU8g91?nDRlH4oiB8a0;o
U8K100?oTI_Joi:KfOnBVmT00_nBVmT4oi>Je`?oU9WF1?nEVMD4oiJHe0;oUiSC00?oYY2noj:9^_nR
RKX00_nCLJT3oi9_Y`?oT6fV1?n@K:D3ohm[Y@OoSfZT0ol00007ohmZY0SoT6^T0onAK:@4oi9]Y0;o
TffU00?oVGnfoiZ0]_nJP;H00_nJP;H4oi^1]PSoW8:f1?nMP[D01_nMP[CoTNWhoi7Yn?nAjOSoNN?^
ogORk@KoX]Gj1_nVb?46ojO3k@;oYl?^1onW`>/2ojO0k4GoYl3[00?o0000ojO0jonW`>/05OnW`>/B
ooooo`03o`000?oooooo000001kooooo000Kooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`02ooooo`?oW[g_0_nN]>L2ohnakP?oT:_X1?nAYN<3oi6OgP?oTY_I1?nBUm@4
oi>Cd@?oTi3=0onDSLT2oiB;aP03ohjMgOn?W=coSicL00;oSicL1?nAVmX4oi:Kf@?oTi[G1?nDVMH4
oiFIe@;oUYSD00CoZYO3ojJ@__nVT;koUWB[1?nCLJT3oi9_Y`CoT6fV0on@K:D3ohm[Y@GoSfZT0_l0
000:ohmZY0SoT6^T0onAK:@2oi9]Y0;oV7je0onIOkH5oiZ0]P?oVh6f2?nLP[H2oif2]@;oRnSe0omi
hnh4oj?En@;oX]Gj0_nVao45ojK8l@OoYl?]D_nW`>/00ol0003oYl3[ojO0j`0EojO0jaCooooo00?o
0000ooooooooool06oooool001_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo00?ooooo1?n=^?<3ohnakP?oT:_X0onAYN<4oi6OgP?oTY_I1?nBUm@2oi>Cd@04ohVQhon;
Wn7oRioQoh^Oh@?oSIkO1?n>WMd4ohnLg0?oTI_J1OnBVmT3oi>Je`;oU9WF0_lh_M42ojjNa`?oZYO3
00CoV7R^oiIdZonFM:_oUWB[1?nCLJT3oi9_Y`CoT6fV0on@K:D3ohm[Y@;oSfZT0ol0000=ohmZY0Oo
T6^T0_nAK:@00onGOKCoV7jeoiQn]@02oiQn]@CoVGnf1?nJP;H4oi^1]PKoW8:f0_n6io<00om3`kOo
Nn?^og_SkP05oj?En@;oYlOa1OnVao42ojK8l@KoYl?]EOnW`>/00ol0003oYl3[ojO0j`0EojO0jaGo
oooo00?o0000ooooooooool06_ooool001_ooooo00Go410@oooooooooooooooooa0@4005ooooo`03
o`000?oooooooooo00Gooooo1?n=^?<3ohnakP?oT:_X0onAYN<2oi6OgP;oQ:K[0on6Y>P3ohRRi@Co
RJ7S0on;Wn43ohfNg`CoSYgM1?n?W=`3oi6KfP;oTY_I1?mAbNh2odG5h@;o/ZK;1?n^W/L00onZUl?o
V7R^oiQh[P04oiIdZ`?oTg6Y0onBKjL4oi1]YP?oT6bU0_n?JjD3o`00013oSfZT1_n@Jj@01?nFNkCo
UgfdoiMm]?nGOK@5oiQn]@?oVGnf1?nJP;H4oi^1]P;oW8:f0on2i_82ogcTkPCoY=Gi0_nSeOT6ojO7
l@;oY/Oa2?nW`neHojO0j`03o`000?nW`>_oYl3[01GoYl3[5?ooool00ol0003oooooooooo`0Joooo
o`006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00007ooooo`;oSKSc00CoOK;eogn_
lomo[o?oOjoc1?n1[?03oh>Yk@CoQ:K[0on6Y>P3ohRRi@?oRJ7S1?n;Wn43ohfNg`CoSYgM0_n?W=`3
ofC:o0;oG<_g00?oa=_ZolGKjOnf[Ll00_nf[Ll5ok:Vb`;o[Yk700?oVgfaoiQh[_nHN:h00_nHN:h3
oiIdZ`?oTg6Y1?nBKjL3oi1]YP;oT6bU0ol00002ohm[YA7oSfZT0_n@Jj@2oiAj/`?oUW^d1?nGOK@4
oiQn]@?oVGnf1OnJP;H2oi^1]P?oP>Ga00?oP^KboggTk_nTeOT01OnTeOT2ojO7l0KoYlOa2OnW`neK
ojO0j`03o`000?nW`>_oYl3[01GoYl3[5?ooool00ol0003oooooooooo`0Iooooo`006oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool01oooool3ogfbm@?oOjoc1?n1[?03
oh>Yk@CoQ:K[0on6Y>P3ohRRi@?oRJ7S0_n;Wn43og6ooPCoK/?n0omZaoh2ofC:o0?oa=_Z00?o^K;C
okJ]conf[Ll00onf[Ll2ok:Vb`;oWh>d0onKOK44oiQh[P?oUWB[1?nCLJT3oi9_Y`;oT6fV0ol00002
oi1/Y@?oSf^U4?n?JZ@00onCN;;oU7ZcoiAj/`02oiAj/`CoUW^d0onGOK@4oiQn]@CoVGnf1?nJP;H0
1?nKPKKoP>Gaoh3UlOn0iO42ojCFn@GoY=Gi1OnWao02ojO7l@;oYl;]1_nW`nePojO0j`03o`000?nW
`>_oYl3[01CoYl3[5?ooool00ol0003oooooooooo`0Iooooo`009Oooool00ol0003oooooooooo`08
ooooo`?oOK;e0omo[o<2oh6/l0?oL[3g0omb/OP3og:cn@?oL[Kj0omb^?/4og:lo@CoLKon0_m^`oh2
objgb@03okKam?o3f^[o`m[Z00;o`m[Z00Coa=_ZokVbdoni/]?o^K;C0onf[Ll00onSRKWoWh>doin3
]002oin3]0CoVgfa0onHN:h3oiIdZ`CoTg6Y0_nBKjL3o`0000;oT6fV0on@K:D3ohm[Y@WoSfZT00?o
TGF`oi9g/OnBMk400_nBMk43oi=h/PCoU7Zc1?nFNk@3oiMm]0GoV7je0onIOkH2oiZ0]P;oOnCb0_nU
e_T5ojCFn@;oY=Gi0onWb?02ojO7l0;oYl?]1OnW`^d2ojO3kF?oYl3[00?o0000ojO0jonW`>/05OnW
`>/Booooo`03o`000?oooooo000001[ooooo000Uooooo`03o`000?oooooooooo00[ooooo0omd[_H3
og>_m`CoL[3g0omb/OP3og:cn@?oL[Kj0omb^?/2og:lo@?oBLC/00?o@lBmohW/j?nhjoH00_nhjoH0
0onflOCo`m[Zol?JjP02ol?JjP03okbhe_ni/]?o^K;C00?o^K;C00?o]Zg?oj>9^OnSRKT01?nOPk@4
oi]m/@?oV7R^0onFM:/3oi=aZ@?o000000?oTVnWoi1]Y_n@KJH00_n@KJH3oi1/Y@?oSf^U0_n?JZ@2
oi1c[P?oT7B_0onAMK04oi9g/@CoTgRb1?nDN[<3oiIk]0CoUgfd1?nHO[D2oiUo]P;oPNCd0_mmiNd4
ojGFn@;oY=Ki0onWb?43ojO8l0KoYl?]0_nW`^eXojO0j`03o`000?nW`>_oYl3[01GoYl3[5?ooool0
0ol0003oooooooooo`0Gooooo`009Oooool2o`0000cooooo0omd[_H3og>_m`;oL[3g0_m^^?`3ofRl
o@GoHl3m0omL`o/2oe?5mP;oGMGM00?oV>geokS[m_nhjoH00_nhjoH3ol;HjP03ol?Jj_nl^=Ko_;SF
00;o_;SF0oni/]<00onXT;goXhVioj>9^@02oj>9^@CoWh>d0onKOK43oiQh[PCoUWB[0_l000001?nC
LJWoTVnWoi9_YonBKjL4oi1]YP;oT6bU00CoSg6^ohmb[_n?LZkoSg:^1?n@Ljh3oi1d[`CoTGF`1?nB
Mk43oi=h/PCoU7Zc1?nFNk@3oiMm]0;oV7je0_n3hoL00om:akWoONG/oggUk004ojGGn@;oYMKi1onW
b?400onWb?3oYl?]ojO3k@04ojO3kFcoYl3[00?o0000ojO0jonW`>/05OnW`>/Cooooo`03o`000?oo
oooooooo01Oooooo000Tooooo`03o`000?oooooooooo00gooooo0omg[oH4og:cn@?oK[Sl0omX_?d2
of?0o@?oDl[`0omdgO@2oj7Yn`Co^>Cd00Co^>_fol;Hj_o2f>[o`]SZ0onm_=P4okbheP04okVbdonX
T;goZ92mojR@_@?oXhVi1?nOPk@4oi]m/@?oV7R^0ol00003oi=aZ@;oTVnW00?oSg:^ohma[_n?LJh0
1On?LJh3ohmb[PCoT7>^1?n@M:l3oi5e/0CoTWNa0onCN;84oiAj/`CoUW^d0_nGOK@2ohKSnP03od_8
^OmliN_oO>G[00CoYMSi0_nUeoT2ojO9l@KoYlSa1_nW`ne`ojO0j`03o`000?nW`>_oYl3[01CoYl3[
5?ooool00ol0003oooooooooo`0Fooooo`009?ooool00ol0003oooooooooo`0>ooooo`?oMjof0_mb
/oT3ogfmn`CoLlKo0_mUbo`3ohCKoP?oY^3k00?oXNWkokSTm?nhi?@00_nhi?@3ol7Ej@03ol;Hj_nm
_=So_KcH00?o_KcH0_nl^=H00on/V<;oZ92mojR@_@02ojR@_@?oXhVi1?nOPk@4oi]m/@?o00000_nF
M:/00on@M;3oSg:^ohmb[P04ohmb[PSoSg6^0on?LZh3oi1c[PCoT7B_0onAMK04oi9g/@CoTgRb0onD
N[<2oiIk]0CoR^7l00?oQ^?jog_UjOnUfOX00_nUfOX2ojGHn@?oZ<Wa1?nWbO42ojO8l@SoYl?]LOnW
`>/00ol0003oYl3[ojO0j`0EojO0jaCooooo00?o0000ooooooooool05Oooool002Cooooo0ol0000?
ooooo`GoPkCe0omm_O/2og?6o`?oS];n00?oQ=_nojKPnonVh?/00_nVh?/4okSKlP04okSTm?o1eNWo
`MGYol7Ej@;o_[kJ1?nm_=P00on`WlOo[9S2ojbH`P02ojbH`P?oZ92m1?nSRKT3oin3]004oi]m/Ol0
003o0000o`0000?oTGJa0on@M;07ohmb[POoSg6^0on?LZh4oi1c[P?oT7B_0onAMK05oi9g/@?oTgRb
0_nDN[<4ohkMoP;oR^7l0onUf_X2ojGInP;oZ<[a1OnXbO42ojO9l@SoYl?]MOnW`>/00ol0003oYl3[
ojO0j`0EojO0ja;ooooo0_l00009ooooo`Co000000?o410@ooooooooool01oooool002Cooooo00?o
0000ooooooooool04?ooool2oh>dm@?oUk_a1?nDaoT2ohkBoP?oZ=Kg0_ngdnh4okSKlP?o_m7W00?o
`MGYokjnf_nn_]X00_nn_]X00onm_=So/9o7ok2Oa`02ok2Oa`?o[9S21?nXT;d3oj>9^@04oin3]?l0
003o0000o`0000?oTgVc0onAM[44oi1d/0KoSg:^1on?LJh3ohmb[PCoT7>^0on@M:l4oi5e/0CoTWNa
0_nCN;83oi7Io`;oS]gn0_nUfoX4ojGJnP;oZ<_b1?nXb_42ojS9l@WoYl?]NOnW`>/00ol0003oYl3[
ojO0j`0EojO0ja?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`002Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooo
ooooo`0Booooo`CoUk_a0_nDaoT4ojS;lP03ojSFmongdnko]m?^00;o]m?^00?o^=_bokoAionodNL0
0_nodNL2okk1g0?o_[kJ00?o/jO<ok2Oaon`WlL00on`WlL3ojbH`PCoZ92m00CoXhVio`000?l0003o
00000_nFOKH4oi=i/`CoTGJa0on@M;06ohmb[POoSg6^0on?LZh4oi1c[PCoT7B_0onAMK02oi9g/@Co
Tm;m0_nAfOl00om=b[[oN>CUojGKnP03ojGKnP03ojGJn_nXbo;oZ<_b00?oZ<_b0_nXb_42ojS3k@Ko
Yl?]OOnW`>/00ol0003oYl3[ojO0j`0EojO0jaCooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`09ooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0Cooooo`;oUk_a0_nX`>/4ojS;
lP?o]L_Z0_ngdnh4okg<i@03okoAionn`Mco_/7L00;o_/7L00Co_[kJok>Wc?ncYlco/jO<1?n`WlL4
ojbH`P04ojR@_Ol0003o0000o`0000?oVH>i0onFOKH3oi=i/`CoTGJa0on@M;06ohmb[PSoSg6^0on?
LZh3oi1c[PCoT7B_0_nAMK03oiG;nP;oTm;m00CoCl^logKShomfhn?oM^?S0onUg?/2ojGKnP?oZ<cb
0_nXbo83ojS4kPCoZ<?]0_nW`nf1ojO0j`03o`000?nW`>_oYl3[01GoYl3[4oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo01Gooooo1?nX`>/00onXbo;o]L_Z
okG;jP02okG;jP;o_<SS1?nmc>D2okk2g@?o_/7L00?o]jkAok>Wc?ncYl`00_ncYl`5ok2Oa`;o[9S2
0_l00003oif9_@?oVH>i0onFOKH4oi=i/`?oTGJa0on@M;07ohmb[POoSg6^0on?LZh2oi1c[P?oUKS`
1?nE`_H2oiG;nP03odS8`omeh^7oMN;Q00CoYMgk0_nUg?/3ojS=l`;oZ<cb1onXa>h2ojS3kHGoYl3[
00?o0000ojO0jonW`>/05OnW`>/Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2Oooool000Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo
0ol0000Fooooo`;oZ<3[1?nc`^D00onebn[o_<SSokc8h`02okc8h`03okg<iOnn`]go_/;M00?o_/;M
00Co_/7LokN^dOng[]7o]jkA1?ncYl`2ok2Oa`04ojFGa_l0003o0000o`0000;oXHo20onMRKd3oiV3
^@?oUWff1?nCNK<4oi5f/@?oT7B`1_n?LZh5ohma[P;oTZOS1?nD[nT5oiFhl0;oUL;f0_mGd]D01?mc
h^3oYMkkojGNnonUg_/2ojGMn`?oZ<kc0onXcO<8ojS4kX[oYl3[00?o0000ojO0jonW`>/05OnW`>/A
ooooo`?o00001oooool00ol0003oooooooooo`09ooooo`002Oooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`0Hooooo`?o/l;U0_nj`n43
okc8h`?o_/?N0onn`]d00oni]]Ko]jkAokN^d@02okN^d@?o/jO<00CoZIo<o`000?l0003o00000_nU
UlH3oj6?`P?oWHVm1?nIPkT3oiIm]P?oTgVc1?nAM[43oi1d/0GoSg:^00?oT9SHoi6OgOnAWmd00_nA
Wmd4oi:Wh`CoU:oY0_nE^?02ofKJiP;oDlk20onTgo/2ojGNn`;oZ<od1OnXc_<00onXcO?oZ<C^ojS4
kP04ojS4kXgoYl3[00?o0000ojO0jonW`>/05OnW`>/>ooooo`Co000000?oooooo`000?ooool01_oo
ool00ol0003oooooooooo`09ooooo`002Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03ok?2iOnj`n7o^/?Q00;o^/?Q00?o
_<SSokk3g_nn`mh00onn`mh01?nn`]go^KKFokVfe_ni]]H4okN^d@?o000000?oZIo<ojFGa_nUUlH0
0_nUUlH3oj6?`PCoWHVm0onIPkT3oiIm]P?oTgVc0_nAM[42ohj<c0?oSXk?0on?Tm<4oi2Hf0CoTIoM
1?nBYn<2oiB_j@;oM=gc0_mFd<L2og;Qg`?oY=ok0_nXd?D4ojS?m0;oZ<kc1?nXaNh2ojS4kP;oZ<3[
SonW`>/00ol0003oYl3[ojO0j`0EojO0j`[ooooo0ol00005ooooo`03o`000?oooooooooo00?ooooo
00?oEEEEofIVI_l000002oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001Oooool2o`0001_ooooo0onj`n42okk4gPCo_/?N00?o_;gJokVfe_ni
]]H00oni]]H3o`0000CoZIo<1?nUUlH4oj6?`P?oWHVm0_nIPkT01?nBS<WoT8[9oi2:bOn@R/T3ohn:
bPGoSXc<0on>S/l3ohnCd`?oT9SH1OnAWmd2oi:Wh`;oOmgl0_mJdld2og7Qg`CoY>7l00?oY=okojS@
mOnXd?D00_nXd?D2ojS?m0KoZ<G^0_nX`N`4ojS0jhooYl3[00?o0000ojO0jonW`>/05?nW`>/6oooo
o`Co00002?ooool00ol0003oooooooooo`0Aooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo01_ooooo00?o^/?Q
okk4g_nna=h00_nna=h00onn`mko_;gJokbmfP02okbmfP04okVfe_l0003o0000o`0000Co[ZOA0onY
Wl`5ojFGaP;oXHo200CoV9?<oiF>b_nES/[oUHk:1?nBS<T3oi2:b@?oSh[:1?n>S<`3ohj>c`CoSi?C
0on@V=P2oi6Og@?oR=Oo0_mNe]D2og7Qh0CoXn;l0_nThO`3ojSBmP;oZ=3e0_nXa^l6ojS5kPCoZ<7/
0_nX`>^@ojO0j`03o`000?nW`>_oYl3[01GoYl3[0_ooool3o`0000cooooo00?o0000ooooooooool0
4Oooool002;ooooo00?o0000ooooooooool07Oooool3okk4gP;o_LCO0_nl_MX3o`000004okVfe_na
/=Oo/K3Gok6`e`?o[ZOA1?nYWl`2ojFGaP;oW9S?1?nHTl`3oiF>bP?oTXc90on@R/T3ohn:bPGoSXc<
0on>S/l2ohnCd`;oSlGi1On=coh00on8eoooL^7Sog;Qh`03oj;Ro0;oXn;l1?nXdoH2ojSBmPKoZ<K_
0_nXaNh6ojS1k9CoYl3[00?o0000ojO0jonW`>/05OnW`>/00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo01kooooo00Co_/CNokg4gonma=oo_LCO
0_l00002okbmfP03okBigOna/=Oo/K3G00;o/K3G1?n^Ym42ojVOc003oj2NdonLV<ooW9S?00?oW9S?
0onHTl`3oiF>bP?oTXc91?n@R/T3ohn:bP;oSXc<0on@/^h3oi2kl`CoSlGi0_n=coh2ogCRiP?oXN?l
0_nRh_`3ojSDm`;oZ=?f0onXanl6ojS6k`SoZ<7/U_nW`>/00ol0003oYl3[ojO0j`0EojO0ja3ooooo
00?o0000ooooooooool04?ooool002;ooooo0_l0000Pooooo`?o00000_nma=l01?nl_M[o];WMokBi
gOnd^Md4ok6`e`;o[ZOA00?oY:KGoj2NdonPW]<00_nPW]<4oibHc`?oV9?<1?nES/X3oi:<b@;oT8[9
00?oT:GToi2[j?n@ZnP00_n@ZnP5oi2bkP?oT;_c0_n?aOT00omZg>OoM>;Voj3Ro002oj3Ro0;oXN?l
0onWe_P2ojSDm`;oZ<O`1OnXanl2ojS6k`SoZ<7/V_nW`>/00ol0003oYl3[ojO0j`0DojO0ja3ooooo
00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool07?ooool3o`000003oooooonm
a=oo_LCO00?o]l?S1?nd^Md2ok6`e`03ojN^gOnTY]OoY:KG00;oY:KG1?nPW]<4oibHc`?oV9?<0_nE
S/X01?nAXMkoT:;Poi2Rh?n@X^04oi2Ui0CoT:_X0_n@/^h4ogKLn0;oL=g`00?oMn;[oj3Ro?nPh_`0
0_nPh_`3ojOGn0;oYmKh0_nXb?04ojS7l0;oZ<O_0onX`^`6ojS1k0;oYl7/VonW`>/00ol0003oYl3[
ojO0j`0EojO0j`oooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool06Ooo
ool3o`0000Kooooo1?ng`n<2okBig@;oZ[OS0onW[]d4ojBVe`;oX9kC0_nHY^03oiFSgP?oTj7N1?nA
XMh3oi2Rh0CoT:GT0_n@ZnP4ogcIo@;oM]ch0_mjh_43oioRo@;oY]Oi0onWeoP2ojS9l@CoZ<S`0_nX
ao07ojS2k0;oZ<7/1_nW`NbKojO0j`03o`000?nW`>_oYl3[01CoYl3[3oooool00ol0003ooooooooo
o`0@ooooo`008_ooool00ol0003oooooooooo`0Fooooo`?o00002_ooool2okO3h`;o[<7Y1?nZ]n<3
ojN^g@;oY:KG00?oVZ_SoiRVh?nHY^000onHY^03oiFSgP?oTj7N1?nAXMh3oi2Rh0;oT:GT1?n0e?l2
ogcIo@;oO^7f0onMhOd00onOh_goY]OiojKGn@03ojKGn@03ojOGn?nXbO7oZ<Wa00;oZ<Wa0_nXb?02
ojS3k@KoZ<;/2OnW`NbMojO0j`03o`000?nW`>_oYl3[01CoYl3[3_ooool00ol0003oooooooooo`0@
ooooo`008_ooool2o`0001Cooooo0ol0000>ooooo`Co[<7Y0_nZ]n<00onN]n[oW;7VoibaiP02oiba
iP?oVZ_S1OnHY^03oiFSgP?oTj7N0_nAXMh3ohK7o@;oPlko1?n5g?h2oh;On`?oW=om0_nMhOd3ojGG
n@;oY]Oi1_nXbO46ojS3k@;oZ<;/2OnW`NbQojO0j`03o`000?nW`>_oYl3[01CoYl3[3Oooool00ol0
003oooooooooo`0@ooooo`008Oooool2o`0001;ooooo0ol0000Booooo`;o[<7Y0_nO_^h3oijgjPCo
W;7V0onJZn<2oiRVh0?oSK_e0on;__L4ohS2nP;oQ/Om0on8eol2ohGLoPCoVmcm0_nLgod3ojCGn@;o
YMOi1?nXb_42ojS9l@SoZ<?]0_nX`N`7ojO1k:CoYl3[00?o0000ojO0jonW`>/05OnW`>/<ooooo`03
o`000?oooooooooo013ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00oooooo0_l0000Fooooo`Co
Wkk^0onN]nX2oibaiP?oT[Wb0on@^_<4ohfkm@?oRkkg0_n8`_X3oh_Ao`;oR=Oo1?nIfOd2oi_Lo@?o
XmKi0_nTeoT3ojS:lP;oZ<[a0onXa>h6ojS3k@KoZ<7/0_nW`NbYojO0j`03o`000?nW`>_oYl3[01Co
Yl3[3Oooool00ol0003oooooooooo`0?ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool3o`0001Wo
oooo0_nO_^h3oiFkl@?oTk[a1?nB^O83oi2jl`;oSK_e0_n>a_/4ohg<o@;oRm7o1?nHeOd2oiWIo@?o
X]Ci0_nSe_T2ojO:lP?oZ<[b1onXa>h2ojS3k@SoZ<7/[OnW`>/00ol0003oYl3[ojO0j`0DojO0j`co
oooo00?o0000ooooooooool03oooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001Oooool2o`0000[ooooo0ol0000Mooooo`GoUK_a0onC^_42oi:ilP;oTKof1?n@`_P3ohk6n`;o
SLcm0onGd?`2oiSEo@CoXM;i0_nRe?T6ojO:lP03ojS:l_nXa>koZ<C^00CoZ<C^2OnX`Nb`ojO0j`03
o`000?nW`>_oYl3[01GoYl3[2oooool00ol0003oooooooooo`0?ooooo`001oooool01Ol0003ooooo
oooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001_ooool00ol0003oooooooooo`06oooo
o`?o00008Oooool2oiFkl@?oU;[a0onC_?<4oi6omP;oT<;h0_nGaoP4oiO<nP;oUm3l1?nPcoP2oj7B
n@;oY/Wb1_nWb_83ojS5kP;oZ<C^0onX`^`6ojS1k;CoYl3[00?o0000ojO0jonW`>/05OnW`>/:oooo
o`03o`000?oooooooooo00oooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01?oM
gMgoEEEEooooool00006ooooo`03o`000?oooooooooo00?ooooo0ol0000Vooooo`CoU;[a0onC_?<2
oi6omP;oUl?f1?nGaoP2oiO<nP?oWlcg0_nPcoP3ojG8lPCoY/Wb0_nWb_85ojS5kPOoZ<;/0_nX`Nbh
ojO0j`03o`000?nW`>_oYl3[01CoYl3[2_ooool00ol0003oooooooooo`0?ooooo`001oooool01Ol@
413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001Oooool01?l0003ooooooooooooo
ool3o`0002[ooooo0_nD^_42oiRll0CoUkoc0onG`oH2oiO7n0?oW/Se0_nOc?L3ojC7l@CoYLSb0_nV
bO83ojO5k`;oZ<G^2?nX`^bmojO0j`03o`000?nW`>_oYl3[01CoYl3[2Oooool00ol0003ooooooooo
o`0?ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001Ooo
ool4o`0002kooooo1?nH_?02oiNol`;oWL7a1?nMa?<2oik8m@?oY<Ga1?nTao42ojG8lP?oYlC_0_nW
aNl2ojO2k0KoZ<;/`?nW`>/00ol0003oYl3[ojO0j`0DojO0j`Wooooo00?o0000ooooooooool03ooo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Cooooo0_l0
000aooooo`;oV;c`0_nM_Nl4oig1l@;oWLCc0_nS`o05ojC5l@;oY<Oa0_nVa>h3ojO4k`KoYl;/0_nX
`^c4ojO0j`03o`000?nW`>_oYl3[01CoYl3[2?ooool00ol0003oooooooooo`0?ooooo`008_ooool0
0ol0003oooooooooo`0_ooooo`CoWKg_0_nM`O42oj;1k`CoXl?`0_nTaO43ojK3kPCoY/C^00?oYlC_
ojO2k?nW`^`01?nW`^`2ojO1k<KoYl3[00?o0000ojO0jonW`>/04onW`>/9ooooo`03o`000?oooooo
oooo00kooooo000Sooooo`03o`000?oooooooooo02oooooo0_nM_Nl2oj:nk@CoX/7_0_nS`o03ojG2
kPCoY/?^0_nVa>h5ojO2k0KoYl7/aOnW`>/00ol0003oYl3[ojO0j`0DojO0j`Sooooo00?o0000oooo
ooooool03_ooool002Cooooo00?o0000ooooooooool0;oooool4oj:nk@;oX/7_0_nU`Nd5ojG2kP;o
Y/?^0onW`N`2ojO2k0SoYl7/aonW`>/00ol0003oYl3[ojO0j`0DojO0j`Oooooo00?o0000oooooooo
ool03_ooool002Gooooo0_l0000`ooooo`;oX[k]0_nU_n`4ojG1k@;oYL;^1_nW`N`2ojO0k0KoYl7/
bonW`>/00ol0003oYl3[ojO0j`0DojO0j`Kooooo00?o0000ooooooooool03_ooool002Oooooo00?o
0000ooooooooool0;_ooool4ojFok0;oYL7]1?nV`>`2ojO1k0KoYl3/0_nW`Nc?ojO0j`03o`000?nW
`>_oYl3[01?oYl3[1_ooool00ol0003oooooooooo`0>ooooo`00:?ooool00ol0003oooooooooo`0^
ooooo`;oYKo/1?nV_n`2ojK0k0;oYl3[1_nW`>cBojO0j`03o`000?nW`>_oYl3[01CoYl3[1Oooool0
0ol0003oooooooooo`0>ooooo`00:Oooool00ol0003oooooooooo`0_ooooo`;oY[o/1onW`>/2ojO0
k=KoYl3[00?o0000ojO0jonW`>/05?nW`>/4ooooo`03o`000?oooooooooo00kooooo000Zooooo`;o
0000<OoooooPojO0j`03o`000?nW`>_oYl3[01CoYl3[0oooool00ol0003oooooooooo`0>ooooo`00
;?ooool00ol0003oooooooooo`0_ooooon3oYl3[00?o0000ojO0jonW`>/05?nW`>/3ooooo`03o`00
0?oooooooooo00gooooo000]ooooo`03o`000?oooooooooo02oooooogonW`>/00ol0003oYl3[ojO0
j`0DojO0j`?ooooo00?o0000ooooooooool03Oooool002kooooo00?o0000ooooooooool0;ooooooO
ojO0j`03o`000?nW`>_oYl3[01CoYl3[0_ooool00ol0003oooooooooo`0=ooooo`00;oooool00ol0
003oooooooooo`0_ooooomooYl3[00?o0000ojO0jonW`>/04onW`>/2ooooo`03o`000?oooooooooo
00gooooo000`ooooo`;o0000<?oooooNojO0j`03o`000?nW`>_oYl3[01CoYl3[00?oooooo`000?oo
ool03_ooool003;ooooo00?o0000ooooooooool0;_oooooNojO0j`03o`000?nW`>_oYl3[01?oYl3[
00?oooooo`000?ooool03_ooool003?ooooo00?o0000ooooooooool0;_oooooNojO0j`03o`000?nW
`>_oYl3[01?oYl3[00?o0000ooooooooool03Oooool003Cooooo00?o0000ooooooooool0;_oooooN
ojO0j`03o`000?nW`>_oYl3[017oYl3[00?oooooo`000?ooool03_ooool003Gooooo0_l0000_oooo
omgoYl3[00?o0000ojO0jonW`>/03OnW`>/6ooooo`03o`000?oooooooooo00cooooo000gooooo`03
o`000?oooooooooo02kooooog?nW`>/00ol0003oYl3[ojO0j`09ojO0j`Wooooo00?o0000oooooooo
ool03?ooool003Sooooo00?o0000ooooooooool0;_oooooLojO0j`03o`000?nW`>_oYl3[00GoYl3[
3?ooool00ol0003oooooooooo`0<ooooo`00>Oooool00ol0003oooooooooo`0^ooooomcoYl3[00?o
0000ojO0jonW`>/04?ooool00ol0003oooooooooo`0<ooooo`00>_ooool2o`0002oooooofonW`>/0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo000looooo`03o`000?oooooooooo
02goooooe_nW`>/5ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03?ooool003go
oooo00?o0000ooooooooool0;OoooooBojO0j`Wooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0<ooooo`00?_ooool00ol0003oooooooooo`0]oooool[oYl3[4?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00cooooo000oooooo`;o0000;oooooo5ojO0jaCooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`00@Oooool00ol0003oooooooooo`0]
oooool7oYl3[6?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0012oooo
o`03o`000?oooooooooo02gooooo_?nW`>/Mooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool004?ooooo00?o0000ooooooooool0;OoooonhojO0jb3ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`00A?ooool00ol0003oooooooooo`0]oooookCoYl3[
9?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0015ooooo`;o0000;ooo
oon^ojO0jbWooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`00Aoooool0
0ol0003oooooooooo`0]oooooj[oYl3[;?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00_ooooo0018ooooo`03o`000?oooooooooo02goooooY_nW`>/`ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02oooool004Wooooo00?o0000ooooooooool0;OoooonRojO0jcCo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00B_ooool2o`0002kooooo
WOnW`>/iooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool004cooooo00?o
0000ooooooooool0;?oooonIojO0jccooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0:ooooo`00COooool00ol0003oooooooooo`0/oooooi;oYl3[@oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00[ooooo001>ooooo`03o`000?oooooooooo02goooooSOnW`>]7oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool004oooooo0_l0000^ooooohSo
Yl3[C?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo001Aooooo`03o`00
0?oooooooooo02coooooQ?nW`>]?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2_ooool005;ooooo00?o0000ooooooooool0:ooooon1ojO0je?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0:ooooo`00Doooool00ol0003oooooooooo`0[oooooggoYl3[Eoooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo001Dooooo`;o0000;OoooomhojO0
je[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`00E_ooool00ol0003o
ooooooooo`0[ooooogCoYl3[G_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wo
oooo001Gooooo`03o`000?oooooooooo02_oooooK?nW`>]Vooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool02Oooool005Sooooo00?o0000ooooooooool0;?oooomWojO0jf[ooooo00Go
0000ooooooooooooooooo`00000;ooooo`00FOooool00ol0003oooooooooo`0/ooooof?oYl3[KOoo
ool01Ol0003ooooooooooooooooo000000_ooooo001Jooooo`;o0000;OoooomOojO0jg7ooooo00Co
0000oooooooooooo00002oooool005cooooo00?o0000ooooooooool0:ooooomKojO0jgGooooo00?o
0000ooooool000002oooool005gooooo00?o0000ooooooooool0:ooooomGojO0jgSooooo00Co0000
oooooooooooo00002_ooool005kooooo00?o0000ooooooooool0:ooooomCojO0jgcooooo00?o0000
ooooool000002_ooool005oooooo0_l0000/ooooodcoYl3[Poooool2o`0000[ooooo001Qooooo`03
o`000?oooooooooo02[oooooB?nW`>^5ooooo`?o00002_ooool006;ooooo00?o0000ooooooooool0
:ooooom3ojO0jhCooooo1?l0000=ooooo`00Hoooool00ol0003oooooooooo`0[ooooocooYl3[Pooo
ool4o`00017ooooo001Tooooo`;o0000;?oooolkojO0jh?ooooo0ol0000Eooooo`00I_ooool00ol0
003oooooooooo`0[oooooc?oYl3[QOooool4o`0001Sooooo001Wooooo`03o`000?oooooooooo02[o
oooo<?nW`>^4ooooo`Co00007?ooool006Sooooo00?o0000ooooooooool0:_ooool/ojO0jh?ooooo
1?l0000Pooooo`00JOooool2o`0002cooooo9onW`>^2ooooo`Co00009?ooool006_ooooo00?o0000
ooooooooool0:_oooolSojO0jh;ooooo0ol0000Xooooo`00K?ooool00ol0003oooooooooo`0Zoooo
oagoYl3[Poooool4o`0002_ooooo001]ooooo`03o`000?oooooooooo02_ooooo6?nW`>^2ooooo`Co
0000;oooool006kooooo00?o0000ooooooooool0:_oooolEojO0jh7ooooo1?l0000cooooo`00Kooo
ool2o`0002_ooooo4OnW`>^0ooooo`Co0000=oooool0077ooooo00?o0000ooooooooool0:_ooool9
ojO0jh;ooooo1?l0000kooooo`00L_ooool00ol0003oooooooooo`0Zooooo`GoYl3[P_ooool3o`00
03oooooo001cooooo`03o`000?oooooooooo02[ooooo00?oYl3[ooooooooool0Ooooool4o`0004;o
oooo001dooooo`;o0000:_ooool00ol0003oooooooooo`1kooooo`Co0000A_ooool007Kooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`1hooooo`Co0000B_ooool007Oooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1dooooo`Co0000C_ooool007Sooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`1aooooo`?o0000D_ooool007Wooooo0_l0000Tooooo`03
o`000?oooooooooo06gooooo1?l0001Eooooo`00Noooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo06Wooooo1?l0001Iooooo`00O?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo06Gooooo1?l0001Mooooo`00OOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo067ooooo1?l0001Qooooo`00O_ooool2o`0001oooooo00?o0000ooooooooool0GOooool4o`00
06Gooooo0020ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0F_ooool3o`0006Wo
oooo0021ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0E_ooool4o`0006cooooo
0022ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0D_ooool4o`00073ooooo0023
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0C_ooool4o`0007Cooooo0024oooo
o`;o00006Oooool00ol0003oooooooooo`1:ooooo`Co0000N?ooool008Kooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`16ooooo`Co0000O?ooool008Oooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`13ooooo`?o0000P?ooool008Sooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0oooooo`Co0000Poooool008Wooooo0_l0000Dooooo`03o`000?oooooo
oooo03_ooooo1?l00027ooooo`00Roooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
03Oooooo1?l0002;ooooo`00S?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03?o
oooo1?l0002?ooooo`00SOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo033ooooo
0ol0002Cooooo`00S_ooool2o`0000oooooo00?o0000ooooooooool0;?ooool4o`0009Kooooo002@
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:?ooool4o`0009[ooooo002Aoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09?ooool4o`0009kooooo002Booooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool4o`000:;ooooo002Cooooo`;o0000
2Oooool00ol0003oooooooooo`0Mooooo`Co0000Y_ooool009Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Jooooo`?o0000Z_ooool009Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Fooooo`Co0000[Oooool009Oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Booooo`Co0000/Oooool009Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0>ooooo`Co0000]Oooool009Wooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo
1?l0002iooooo`00Voooool01?l0003oooooooooool00009ooooo`?o0000_Oooool009cooooo00?o
0000ooooool000001Oooool4o`000<3ooooo002Mooooo`;o000000?oooooo`000?l000000_l00034
ooooo`00W_ooool2o`000<Sooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002^ooooo`05oiRHV?l0
003o0000odA4A?nj^[X02oooool2o`000003oa0@4?oooooooooo00?ooooo0_lQ8B44ooooo`05olc<
c?lQ8B7o0000ob4Q8Oo<c<`0Uoooool00:kooooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`Ko
00001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q
09Oooooo002^ooooo`03o`000?oooooooooo00_ooooo1Ol0000;ooooo`05o`000?oooooooooooooo
ool00000Uoooool00:kooooo00?o0000ooooooooool01?ooool6o`000005oooooom4A4CogMgMoooo
ool000003?ooool01Olb<S;oV9RHoooooonHV9So<S8b09Oooooo002^ooooo`03o`000?oooooooooo
00_ooooo00CogMgMoeEEEOoooooo00003?ooool01Oo<c<co0000o`000?l0003oc<c<09Oooooo002/
ooooo`03oa0@4?l0003o000000?o00002oooool00omgMgOoc<c<o`00000<ooooo`05oa0@4?nj^[[o
oooookZj^_l@4100Uoooool00:kooooo00?o0000ooooooooool03?ooool00oo^k^koA4A4o`00000<
ooooo`05o`000?nj^[[ooooookZj^_l00000Uoooool00:kooooo00?o0000ooooooooool03Oooool0
0omgMgOo0000ooooo`0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0Uoooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -17 0 ]
[.5 .82364 17 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.6) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69467 Mtetra
.4053 .69467 .41061 .69934 .41957 .69681 .41427 .69213 Mtetra
.41427 .69213 .41957 .69681 .42855 .69428 .42327 .68958 Mtetra
.42327 .68958 .42855 .69428 .43756 .69174 .43231 .68703 Mtetra
.43231 .68703 .43756 .69174 .4466 .68919 .44137 .68446 Mtetra
.44137 .68446 .4466 .68919 .45567 .68663 .45046 .68189 Mtetra
.45046 .68189 .45567 .68663 .46478 .68407 .45958 .67931 Mtetra
.45958 .67931 .46478 .68407 .47391 .68149 .46873 .67671 Mtetra
.46873 .67671 .47391 .68149 .48307 .67891 .47792 .67412 Mtetra
.47792 .67412 .48307 .67891 .49227 .67632 .48713 .67151 Mtetra
.48713 .67151 .49227 .67632 .50149 .67371 .49638 .66889 Mtetra
.49638 .66889 .50149 .67371 .51075 .6711 .50565 .66626 Mtetra
.50565 .66626 .51075 .6711 .52004 .66849 .51496 .66363 Mtetra
.51496 .66363 .52004 .66849 .52936 .66586 .5243 .66098 Mtetra
.5243 .66098 .52936 .66586 .53871 .66322 .53367 .65833 Mtetra
.53367 .65833 .53871 .66322 .54809 .66058 .54308 .65567 Mtetra
.54308 .65567 .54809 .66058 .55751 .65792 .55251 .653 Mtetra
.55251 .653 .55751 .65792 .56695 .65526 .56198 .65032 Mtetra
.56198 .65032 .56695 .65526 .57643 .65259 .57148 .64763 Mtetra
.57148 .64763 .57643 .65259 .58595 .6499 .58102 .64493 Mtetra
.58102 .64493 .58595 .6499 .59549 .64721 .59058 .64222 Mtetra
.59058 .64222 .59549 .64721 .60507 .64451 .60018 .6395 Mtetra
.60018 .6395 .60507 .64451 .61468 .6418 .60982 .63678 Mtetra
.60982 .63678 .61468 .6418 .62432 .63908 .61948 .63404 Mtetra
.61948 .63404 .62432 .63908 .634 .63636 .62918 .63129 Mtetra
.62918 .63129 .634 .63636 .64371 .63362 .63892 .62854 Mtetra
.63892 .62854 .64371 .63362 .65345 .63087 .64868 .62577 Mtetra
.64868 .62577 .65345 .63087 .66323 .62811 .65848 .623 Mtetra
.65848 .623 .66323 .62811 .67304 .62535 .66832 .62021 Mtetra
.66832 .62021 .67304 .62535 .68289 .62257 .67819 .61742 Mtetra
.67819 .61742 .68289 .62257 .69277 .61979 .68809 .61462 Mtetra
.68809 .61462 .69277 .61979 .70269 .61699 .69803 .6118 Mtetra
.69803 .6118 .70269 .61699 .71264 .61418 .70801 .60898 Mtetra
.70801 .60898 .71264 .61418 .72262 .61137 .71802 .60615 Mtetra
.71802 .60615 .72262 .61137 .73264 .60854 .72806 .6033 Mtetra
.72806 .6033 .73264 .60854 .7427 .60571 .73814 .60045 Mtetra
.73814 .60045 .7427 .60571 .75279 .60286 .74826 .59759 Mtetra
.74826 .59759 .75279 .60286 .76291 .60001 .75841 .59471 Mtetra
.75841 .59471 .76291 .60001 .77308 .59714 .7686 .59183 Mtetra
.7686 .59183 .77308 .59714 .78328 .59427 .77882 .58893 Mtetra
.77882 .58893 .78328 .59427 .79351 .59138 .78908 .58603 Mtetra
.78908 .58603 .79351 .59138 .80378 .58849 .79938 .58311 Mtetra
.79938 .58311 .80378 .58849 .81409 .58558 .80971 .58019 Mtetra
.80971 .58019 .81409 .58558 .82443 .58267 .82008 .57725 Mtetra
.82008 .57725 .82443 .58267 .83482 .57974 .83049 .57431 Mtetra
.83049 .57431 .83482 .57974 .84523 .5768 .84094 .57135 Mtetra
.84094 .57135 .84523 .5768 .85569 .57385 .85142 .56838 Mtetra
.85142 .56838 .85569 .57385 .86618 .57089 .86194 .5654 Mtetra
.86194 .5654 .86618 .57089 .87672 .56792 .8725 .56241 Mtetra
.8725 .56241 .87672 .56792 .88729 .56494 .8831 .55941 Mtetra
.8831 .55941 .88729 .56494 .89789 .56195 .89374 .5564 Mtetra
.89374 .5564 .89789 .56195 .90854 .55895 .90441 .55338 Mtetra
.90441 .55338 .90854 .55895 .91923 .55594 .91512 .55035 Mtetra
.91512 .55035 .91923 .55594 .92995 .55292 .92588 .5473 Mtetra
.92588 .5473 .92995 .55292 .94071 .54988 .93667 .54425 Mtetra
.93667 .54425 .94071 .54988 .95152 .54684 .9475 .54118 Mtetra
.9475 .54118 .95152 .54684 .96236 .54378 .95837 .53811 Mtetra
.95837 .53811 .96236 .54378 .97324 .54071 .96928 .53502 Mtetra
.96928 .53502 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.391 .69252 .39636 .6972 .4053 .69467 .39996 .68998 Mtetra
.39996 .68998 .4053 .69467 .41427 .69213 .40895 .68742 Mtetra
.40895 .68742 .41427 .69213 .42327 .68958 .41797 .68486 Mtetra
.41797 .68486 .42327 .68958 .43231 .68703 .42702 .68228 Mtetra
.42702 .68228 .43231 .68703 .44137 .68446 .4361 .6797 Mtetra
.4361 .6797 .44137 .68446 .45046 .68189 .44521 .67711 Mtetra
.44521 .67711 .45046 .68189 .45958 .67931 .45435 .67452 Mtetra
.45435 .67452 .45958 .67931 .46873 .67671 .46352 .67191 Mtetra
.46352 .67191 .46873 .67671 .47792 .67412 .47273 .66929 Mtetra
.47273 .66929 .47792 .67412 .48713 .67151 .48196 .66667 Mtetra
.48196 .66667 .48713 .67151 .49638 .66889 .49123 .66403 Mtetra
.49123 .66403 .49638 .66889 .50565 .66626 .50053 .66139 Mtetra
.50053 .66139 .50565 .66626 .51496 .66363 .50985 .65874 Mtetra
.50985 .65874 .51496 .66363 .5243 .66098 .51922 .65608 Mtetra
.51922 .65608 .5243 .66098 .53367 .65833 .52861 .65341 Mtetra
.52861 .65341 .53367 .65833 .54308 .65567 .53803 .65073 Mtetra
.53803 .65073 .54308 .65567 .55251 .653 .54749 .64804 Mtetra
.54749 .64804 .55251 .653 .56198 .65032 .55698 .64534 Mtetra
.55698 .64534 .56198 .65032 .57148 .64763 .5665 .64264 Mtetra
.5665 .64264 .57148 .64763 .58102 .64493 .57606 .63992 Mtetra
.57606 .63992 .58102 .64493 .59058 .64222 .58565 .6372 Mtetra
.58565 .6372 .59058 .64222 .60018 .6395 .59527 .63446 Mtetra
.59527 .63446 .60018 .6395 .60982 .63678 .60493 .63172 Mtetra
.60493 .63172 .60982 .63678 .61948 .63404 .61461 .62896 Mtetra
.61461 .62896 .61948 .63404 .62918 .63129 .62434 .6262 Mtetra
.62434 .6262 .62918 .63129 .63892 .62854 .63409 .62343 Mtetra
.63409 .62343 .63892 .62854 .64868 .62577 .64388 .62064 Mtetra
.64388 .62064 .64868 .62577 .65848 .623 .65371 .61785 Mtetra
.65371 .61785 .65848 .623 .66832 .62021 .66357 .61505 Mtetra
.66357 .61505 .66832 .62021 .67819 .61742 .67346 .61224 Mtetra
.67346 .61224 .67819 .61742 .68809 .61462 .68339 .60942 Mtetra
.68339 .60942 .68809 .61462 .69803 .6118 .69335 .60658 Mtetra
.69335 .60658 .69803 .6118 .70801 .60898 .70335 .60374 Mtetra
.70335 .60374 .70801 .60898 .71802 .60615 .71338 .60089 Mtetra
.71338 .60089 .71802 .60615 .72806 .6033 .72345 .59803 Mtetra
.72345 .59803 .72806 .6033 .73814 .60045 .73356 .59516 Mtetra
.73356 .59516 .73814 .60045 .74826 .59759 .7437 .59227 Mtetra
.7437 .59227 .74826 .59759 .75841 .59471 .75387 .58938 Mtetra
.75387 .58938 .75841 .59471 .7686 .59183 .76409 .58648 Mtetra
.76409 .58648 .7686 .59183 .77882 .58893 .77434 .58356 Mtetra
.77434 .58356 .77882 .58893 .78908 .58603 .78462 .58064 Mtetra
.78462 .58064 .78908 .58603 .79938 .58311 .79495 .57771 Mtetra
.79495 .57771 .79938 .58311 .80971 .58019 .80531 .57476 Mtetra
.80531 .57476 .80971 .58019 .82008 .57725 .81571 .57181 Mtetra
.81571 .57181 .82008 .57725 .83049 .57431 .82614 .56884 Mtetra
.82614 .56884 .83049 .57431 .84094 .57135 .83661 .56586 Mtetra
.83661 .56586 .84094 .57135 .85142 .56838 .84712 .56288 Mtetra
.84712 .56288 .85142 .56838 .86194 .5654 .85767 .55988 Mtetra
.85767 .55988 .86194 .5654 .8725 .56241 .86826 .55687 Mtetra
.86826 .55687 .8725 .56241 .8831 .55941 .87889 .55385 Mtetra
.87889 .55385 .8831 .55941 .89374 .5564 .88955 .55082 Mtetra
.88955 .55082 .89374 .5564 .90441 .55338 .90025 .54777 Mtetra
.90025 .54777 .90441 .55338 .91512 .55035 .911 .54472 Mtetra
.911 .54472 .91512 .55035 .92588 .5473 .92178 .54166 Mtetra
.92178 .54166 .92588 .5473 .93667 .54425 .9326 .53858 Mtetra
.9326 .53858 .93667 .54425 .9475 .54118 .94346 .53549 Mtetra
.94346 .53549 .9475 .54118 .95837 .53811 .95436 .53239 Mtetra
.95436 .53239 .95837 .53811 .96928 .53502 .9653 .52928 Mtetra
.9653 .52928 .96928 .53502 .98024 .53192 .97628 .52616 Mtetra
.38561 .68781 .391 .69252 .39996 .68998 .39459 .68525 Mtetra
.39459 .68525 .39996 .68998 .40895 .68742 .40359 .68268 Mtetra
.40359 .68268 .40895 .68742 .41797 .68486 .41263 .6801 Mtetra
.41263 .6801 .41797 .68486 .42702 .68228 .4217 .67751 Mtetra
.4217 .67751 .42702 .68228 .4361 .6797 .4308 .67492 Mtetra
.4308 .67492 .4361 .6797 .44521 .67711 .43993 .67231 Mtetra
.43993 .67231 .44521 .67711 .45435 .67452 .44909 .6697 Mtetra
.44909 .6697 .45435 .67452 .46352 .67191 .45828 .66707 Mtetra
.45828 .66707 .46352 .67191 .47273 .66929 .46751 .66444 Mtetra
.46751 .66444 .47273 .66929 .48196 .66667 .47676 .6618 Mtetra
.47676 .6618 .48196 .66667 .49123 .66403 .48605 .65915 Mtetra
.48605 .65915 .49123 .66403 .50053 .66139 .49537 .65649 Mtetra
.49537 .65649 .50053 .66139 .50985 .65874 .50472 .65382 Mtetra
.50472 .65382 .50985 .65874 .51922 .65608 .5141 .65114 Mtetra
.5141 .65114 .51922 .65608 .52861 .65341 .52351 .64846 Mtetra
.52351 .64846 .52861 .65341 .53803 .65073 .53296 .64576 Mtetra
.53296 .64576 .53803 .65073 .54749 .64804 .54244 .64305 Mtetra
.54244 .64305 .54749 .64804 .55698 .64534 .55195 .64034 Mtetra
.55195 .64034 .55698 .64534 .5665 .64264 .56149 .63762 Mtetra
.56149 .63762 .5665 .64264 .57606 .63992 .57107 .63488 Mtetra
.57107 .63488 .57606 .63992 .58565 .6372 .58068 .63214 Mtetra
.58068 .63214 .58565 .6372 .59527 .63446 .59032 .62939 Mtetra
.59032 .62939 .59527 .63446 .60493 .63172 .6 .62663 Mtetra
.6 .62663 .60493 .63172 .61461 .62896 .60971 .62385 Mtetra
.60971 .62385 .61461 .62896 .62434 .6262 .61946 .62107 Mtetra
.61946 .62107 .62434 .6262 .63409 .62343 .62924 .61828 Mtetra
.62924 .61828 .63409 .62343 .64388 .62064 .63905 .61548 Mtetra
.63905 .61548 .64388 .62064 .65371 .61785 .6489 .61267 Mtetra
.6489 .61267 .65371 .61785 .66357 .61505 .65878 .60985 Mtetra
.65878 .60985 .66357 .61505 .67346 .61224 .6687 .60702 Mtetra
.6687 .60702 .67346 .61224 .68339 .60942 .67865 .60418 Mtetra
.67865 .60418 .68339 .60942 .69335 .60658 .68864 .60133 Mtetra
.68864 .60133 .69335 .60658 .70335 .60374 .69866 .59847 Mtetra
.69866 .59847 .70335 .60374 .71338 .60089 .70872 .5956 Mtetra
.70872 .5956 .71338 .60089 .72345 .59803 .71881 .59272 Mtetra
.71881 .59272 .72345 .59803 .73356 .59516 .72894 .58983 Mtetra
.72894 .58983 .73356 .59516 .7437 .59227 .73911 .58692 Mtetra
.73911 .58692 .7437 .59227 .75387 .58938 .74931 .58401 Mtetra
.74931 .58401 .75387 .58938 .76409 .58648 .75955 .58109 Mtetra
.75955 .58109 .76409 .58648 .77434 .58356 .76982 .57816 Mtetra
.76982 .57816 .77434 .58356 .78462 .58064 .78014 .57521 Mtetra
.78014 .57521 .78462 .58064 .79495 .57771 .79049 .57226 Mtetra
.79049 .57226 .79495 .57771 .80531 .57476 .80087 .5693 Mtetra
.80087 .5693 .80531 .57476 .81571 .57181 .8113 .56632 Mtetra
.8113 .56632 .81571 .57181 .82614 .56884 .82176 .56334 Mtetra
.82176 .56334 .82614 .56884 .83661 .56586 .83226 .56034 Mtetra
.83226 .56034 .83661 .56586 .84712 .56288 .8428 .55733 Mtetra
.8428 .55733 .84712 .56288 .85767 .55988 .85337 .55431 Mtetra
.85337 .55431 .85767 .55988 .86826 .55687 .86399 .55128 Mtetra
.86399 .55128 .86826 .55687 .87889 .55385 .87464 .54824 Mtetra
.87464 .54824 .87889 .55385 .88955 .55082 .88533 .54519 Mtetra
.88533 .54519 .88955 .55082 .90025 .54777 .89607 .54213 Mtetra
.89607 .54213 .90025 .54777 .911 .54472 .90684 .53905 Mtetra
.90684 .53905 .911 .54472 .92178 .54166 .91765 .53597 Mtetra
.91765 .53597 .92178 .54166 .9326 .53858 .9285 .53287 Mtetra
.9285 .53287 .9326 .53858 .94346 .53549 .93939 .52976 Mtetra
.93939 .52976 .94346 .53549 .95436 .53239 .95032 .52664 Mtetra
.95032 .52664 .95436 .53239 .9653 .52928 .96129 .52351 Mtetra
.96129 .52351 .9653 .52928 .97628 .52616 .9723 .52037 Mtetra
.38018 .68308 .38561 .68781 .39459 .68525 .38918 .6805 Mtetra
.38918 .6805 .39459 .68525 .40359 .68268 .3982 .67791 Mtetra
.3982 .67791 .40359 .68268 .41263 .6801 .40726 .67532 Mtetra
.40726 .67532 .41263 .6801 .4217 .67751 .41635 .67271 Mtetra
.41635 .67271 .4217 .67751 .4308 .67492 .42547 .6701 Mtetra
.42547 .6701 .4308 .67492 .43993 .67231 .43462 .66748 Mtetra
.43462 .66748 .43993 .67231 .44909 .6697 .4438 .66485 Mtetra
.4438 .66485 .44909 .6697 .45828 .66707 .45301 .66221 Mtetra
.45301 .66221 .45828 .66707 .46751 .66444 .46225 .65956 Mtetra
.46225 .65956 .46751 .66444 .47676 .6618 .47153 .6569 Mtetra
.47153 .6569 .47676 .6618 .48605 .65915 .48083 .65423 Mtetra
.48083 .65423 .48605 .65915 .49537 .65649 .49017 .65156 Mtetra
.49017 .65156 .49537 .65649 .50472 .65382 .49954 .64887 Mtetra
.49954 .64887 .50472 .65382 .5141 .65114 .50895 .64618 Mtetra
.50895 .64618 .5141 .65114 .52351 .64846 .51838 .64347 Mtetra
.51838 .64347 .52351 .64846 .53296 .64576 .52785 .64076 Mtetra
.52785 .64076 .53296 .64576 .54244 .64305 .53735 .63804 Mtetra
.53735 .63804 .54244 .64305 .55195 .64034 .54688 .6353 Mtetra
.54688 .6353 .55195 .64034 .56149 .63762 .55645 .63256 Mtetra
.55645 .63256 .56149 .63762 .57107 .63488 .56605 .62981 Mtetra
.56605 .62981 .57107 .63488 .58068 .63214 .57568 .62705 Mtetra
.57568 .62705 .58068 .63214 .59032 .62939 .58535 .62428 Mtetra
.58535 .62428 .59032 .62939 .6 .62663 .59505 .6215 Mtetra
.59505 .6215 .6 .62663 .60971 .62385 .60478 .61871 Mtetra
.60478 .61871 .60971 .62385 .61946 .62107 .61455 .61591 Mtetra
.61455 .61591 .61946 .62107 .62924 .61828 .62435 .6131 Mtetra
.62435 .6131 .62924 .61828 .63905 .61548 .63419 .61028 Mtetra
.63419 .61028 .63905 .61548 .6489 .61267 .64406 .60746 Mtetra
.64406 .60746 .6489 .61267 .65878 .60985 .65396 .60462 Mtetra
.65396 .60462 .65878 .60985 .6687 .60702 .66391 .60177 Mtetra
.66391 .60177 .6687 .60702 .67865 .60418 .67388 .59891 Mtetra
.67388 .59891 .67865 .60418 .68864 .60133 .68389 .59604 Mtetra
.68389 .59604 .68864 .60133 .69866 .59847 .69394 .59316 Mtetra
.69394 .59316 .69866 .59847 .70872 .5956 .70402 .59027 Mtetra
.70402 .59027 .70872 .5956 .71881 .59272 .71414 .58737 Mtetra
.71414 .58737 .71881 .59272 .72894 .58983 .7243 .58446 Mtetra
.7243 .58446 .72894 .58983 .73911 .58692 .73449 .58154 Mtetra
.73449 .58154 .73911 .58692 .74931 .58401 .74472 .57861 Mtetra
.74472 .57861 .74931 .58401 .75955 .58109 .75498 .57567 Mtetra
.75498 .57567 .75955 .58109 .76982 .57816 .76528 .57272 Mtetra
.76528 .57272 .76982 .57816 .78014 .57521 .77562 .56975 Mtetra
.77562 .56975 .78014 .57521 .79049 .57226 .786 .56678 Mtetra
.786 .56678 .79049 .57226 .80087 .5693 .79641 .5638 Mtetra
.79641 .5638 .80087 .5693 .8113 .56632 .80686 .5608 Mtetra
.80686 .5608 .8113 .56632 .82176 .56334 .81735 .55779 Mtetra
.81735 .55779 .82176 .56334 .83226 .56034 .82788 .55478 Mtetra
.82788 .55478 .83226 .56034 .8428 .55733 .83844 .55175 Mtetra
.83844 .55175 .8428 .55733 .85337 .55431 .84905 .54871 Mtetra
.84905 .54871 .85337 .55431 .86399 .55128 .85969 .54566 Mtetra
.85969 .54566 .86399 .55128 .87464 .54824 .87037 .5426 Mtetra
.87037 .5426 .87464 .54824 .88533 .54519 .88109 .53953 Mtetra
.88109 .53953 .88533 .54519 .89607 .54213 .89185 .53644 Mtetra
.89185 .53644 .89607 .54213 .90684 .53905 .90265 .53335 Mtetra
.90265 .53335 .90684 .53905 .91765 .53597 .91349 .53024 Mtetra
.91349 .53024 .91765 .53597 .9285 .53287 .92437 .52712 Mtetra
.92437 .52712 .9285 .53287 .93939 .52976 .93529 .524 Mtetra
.93529 .524 .93939 .52976 .95032 .52664 .94625 .52085 Mtetra
.94625 .52085 .95032 .52664 .96129 .52351 .95725 .5177 Mtetra
.95725 .5177 .96129 .52351 .9723 .52037 .96829 .51454 Mtetra
.37472 .67831 .38018 .68308 .38918 .6805 .38373 .67572 Mtetra
.38373 .67572 .38918 .6805 .3982 .67791 .39278 .67311 Mtetra
.39278 .67311 .3982 .67791 .40726 .67532 .40186 .6705 Mtetra
.40186 .6705 .40726 .67532 .41635 .67271 .41096 .66788 Mtetra
.41096 .66788 .41635 .67271 .42547 .6701 .4201 .66525 Mtetra
.4201 .66525 .42547 .6701 .43462 .66748 .42927 .66261 Mtetra
.42927 .66261 .43462 .66748 .4438 .66485 .43847 .65996 Mtetra
.43847 .65996 .4438 .66485 .45301 .66221 .4477 .65731 Mtetra
.4477 .65731 .45301 .66221 .46225 .65956 .45697 .65464 Mtetra
.45697 .65464 .46225 .65956 .47153 .6569 .46626 .65197 Mtetra
.46626 .65197 .47153 .6569 .48083 .65423 .47559 .64928 Mtetra
.47559 .64928 .48083 .65423 .49017 .65156 .48495 .64659 Mtetra
.48495 .64659 .49017 .65156 .49954 .64887 .49434 .64389 Mtetra
.49434 .64389 .49954 .64887 .50895 .64618 .50376 .64118 Mtetra
.50376 .64118 .50895 .64618 .51838 .64347 .51322 .63846 Mtetra
.51322 .63846 .51838 .64347 .52785 .64076 .52271 .63572 Mtetra
.52271 .63572 .52785 .64076 .53735 .63804 .53223 .63298 Mtetra
.53223 .63298 .53735 .63804 .54688 .6353 .54178 .63024 Mtetra
.54178 .63024 .54688 .6353 .55645 .63256 .55137 .62748 Mtetra
.55137 .62748 .55645 .63256 .56605 .62981 .56099 .62471 Mtetra
.56099 .62471 .56605 .62981 .57568 .62705 .57065 .62193 Mtetra
.57065 .62193 .57568 .62705 .58535 .62428 .58034 .61914 Mtetra
.58034 .61914 .58535 .62428 .59505 .6215 .59006 .61634 Mtetra
.59006 .61634 .59505 .6215 .60478 .61871 .59982 .61354 Mtetra
.59982 .61354 .60478 .61871 .61455 .61591 .60961 .61072 Mtetra
.60961 .61072 .61455 .61591 .62435 .6131 .61943 .60789 Mtetra
.61943 .60789 .62435 .6131 .63419 .61028 .62929 .60505 Mtetra
.62929 .60505 .63419 .61028 .64406 .60746 .63919 .60221 Mtetra
.63919 .60221 .64406 .60746 .65396 .60462 .64912 .59935 Mtetra
.64912 .59935 .65396 .60462 .66391 .60177 .65908 .59648 Mtetra
.65908 .59648 .66391 .60177 .67388 .59891 .66908 .5936 Mtetra
.66908 .5936 .67388 .59891 .68389 .59604 .67912 .59072 Mtetra
.67912 .59072 .68389 .59604 .69394 .59316 .68919 .58782 Mtetra
.68919 .58782 .69394 .59316 .70402 .59027 .6993 .58491 Mtetra
.6993 .58491 .70402 .59027 .71414 .58737 .70944 .58199 Mtetra
.70944 .58199 .71414 .58737 .7243 .58446 .71962 .57906 Mtetra
.71962 .57906 .7243 .58446 .73449 .58154 .72984 .57612 Mtetra
.72984 .57612 .73449 .58154 .74472 .57861 .74009 .57317 Mtetra
.74009 .57317 .74472 .57861 .75498 .57567 .75038 .57021 Mtetra
.75038 .57021 .75498 .57567 .76528 .57272 .76071 .56724 Mtetra
.76071 .56724 .76528 .57272 .77562 .56975 .77107 .56426 Mtetra
.77107 .56426 .77562 .56975 .786 .56678 .78148 .56126 Mtetra
.78148 .56126 .786 .56678 .79641 .5638 .79192 .55826 Mtetra
.79192 .55826 .79641 .5638 .80686 .5608 .80239 .55524 Mtetra
.80239 .55524 .80686 .5608 .81735 .55779 .81291 .55222 Mtetra
.81291 .55222 .81735 .55779 .82788 .55478 .82346 .54918 Mtetra
.82346 .54918 .82788 .55478 .83844 .55175 .83406 .54613 Mtetra
.83406 .54613 .83844 .55175 .84905 .54871 .84469 .54307 Mtetra
.84469 .54307 .84905 .54871 .85969 .54566 .85536 .54 Mtetra
.85536 .54 .85969 .54566 .87037 .5426 .86607 .53692 Mtetra
.86607 .53692 .87037 .5426 .88109 .53953 .87682 .53383 Mtetra
.87682 .53383 .88109 .53953 .89185 .53644 .88761 .53072 Mtetra
.88761 .53072 .89185 .53644 .90265 .53335 .89844 .52761 Mtetra
.89844 .52761 .90265 .53335 .91349 .53024 .90931 .52448 Mtetra
.90931 .52448 .91349 .53024 .92437 .52712 .92022 .52134 Mtetra
.92022 .52134 .92437 .52712 .93529 .524 .93116 .51819 Mtetra
.93116 .51819 .93529 .524 .94625 .52085 .94216 .51503 Mtetra
.94216 .51503 .94625 .52085 .95725 .5177 .95319 .51185 Mtetra
.95319 .51185 .95725 .5177 .96829 .51454 .96426 .50866 Mtetra
.36922 .67351 .37472 .67831 .38373 .67572 .37826 .6709 Mtetra
.37826 .6709 .38373 .67572 .39278 .67311 .38732 .66828 Mtetra
.38732 .66828 .39278 .67311 .40186 .6705 .39642 .66566 Mtetra
.39642 .66566 .40186 .6705 .41096 .66788 .40554 .66302 Mtetra
.40554 .66302 .41096 .66788 .4201 .66525 .4147 .66037 Mtetra
.4147 .66037 .4201 .66525 .42927 .66261 .42389 .65772 Mtetra
.42389 .65772 .42927 .66261 .43847 .65996 .43311 .65505 Mtetra
.43311 .65505 .43847 .65996 .4477 .65731 .44236 .65238 Mtetra
.44236 .65238 .4477 .65731 .45697 .65464 .45165 .6497 Mtetra
.45165 .6497 .45697 .65464 .46626 .65197 .46096 .64701 Mtetra
.46096 .64701 .46626 .65197 .47559 .64928 .47031 .6443 Mtetra
.47031 .6443 .47559 .64928 .48495 .64659 .47969 .64159 Mtetra
.47969 .64159 .48495 .64659 .49434 .64389 .4891 .63887 Mtetra
.4891 .63887 .49434 .64389 .50376 .64118 .49855 .63615 Mtetra
.49855 .63615 .50376 .64118 .51322 .63846 .50802 .63341 Mtetra
.50802 .63341 .51322 .63846 .52271 .63572 .51753 .63066 Mtetra
.51753 .63066 .52271 .63572 .53223 .63298 .52708 .6279 Mtetra
.52708 .6279 .53223 .63298 .54178 .63024 .53665 .62513 Mtetra
.53665 .62513 .54178 .63024 .55137 .62748 .54626 .62236 Mtetra
.54626 .62236 .55137 .62748 .56099 .62471 .55591 .61957 Mtetra
.55591 .61957 .56099 .62471 .57065 .62193 .56558 .61677 Mtetra
.56558 .61677 .57065 .62193 .58034 .61914 .57529 .61397 Mtetra
.57529 .61397 .58034 .61914 .59006 .61634 .58504 .61115 Mtetra
.58504 .61115 .59006 .61634 .59982 .61354 .59482 .60833 Mtetra
.59482 .60833 .59982 .61354 .60961 .61072 .60463 .60549 Mtetra
.60463 .60549 .60961 .61072 .61943 .60789 .61448 .60265 Mtetra
.61448 .60265 .61943 .60789 .62929 .60505 .62437 .59979 Mtetra
.62437 .59979 .62929 .60505 .63919 .60221 .63428 .59692 Mtetra
.63428 .59692 .63919 .60221 .64912 .59935 .64424 .59405 Mtetra
.64424 .59405 .64912 .59935 .65908 .59648 .65423 .59116 Mtetra
.65423 .59116 .65908 .59648 .66908 .5936 .66425 .58826 Mtetra
.66425 .58826 .66908 .5936 .67912 .59072 .67431 .58536 Mtetra
.67431 .58536 .67912 .59072 .68919 .58782 .68441 .58244 Mtetra
.68441 .58244 .68919 .58782 .6993 .58491 .69454 .57951 Mtetra
.69454 .57951 .6993 .58491 .70944 .58199 .70471 .57657 Mtetra
.70471 .57657 .70944 .58199 .71962 .57906 .71491 .57363 Mtetra
.71491 .57363 .71962 .57906 .72984 .57612 .72516 .57067 Mtetra
.72516 .57067 .72984 .57612 .74009 .57317 .73544 .5677 Mtetra
.73544 .5677 .74009 .57317 .75038 .57021 .74575 .56471 Mtetra
.74575 .56471 .75038 .57021 .76071 .56724 .75611 .56172 Mtetra
.75611 .56172 .76071 .56724 .77107 .56426 .7665 .55872 Mtetra
.7665 .55872 .77107 .56426 .78148 .56126 .77693 .55571 Mtetra
.77693 .55571 .78148 .56126 .79192 .55826 .78739 .55268 Mtetra
.78739 .55268 .79192 .55826 .80239 .55524 .7979 .54965 Mtetra
.7979 .54965 .80239 .55524 .81291 .55222 .80844 .5466 Mtetra
.80844 .5466 .81291 .55222 .82346 .54918 .81902 .54354 Mtetra
.81902 .54354 .82346 .54918 .83406 .54613 .82964 .54047 Mtetra
.82964 .54047 .83406 .54613 .84469 .54307 .8403 .53739 Mtetra
.8403 .53739 .84469 .54307 .85536 .54 .851 .5343 Mtetra
.851 .5343 .85536 .54 .86607 .53692 .86174 .5312 Mtetra
.86174 .5312 .86607 .53692 .87682 .53383 .87252 .52809 Mtetra
.87252 .52809 .87682 .53383 .88761 .53072 .88334 .52496 Mtetra
.88334 .52496 .88761 .53072 .89844 .52761 .89419 .52182 Mtetra
.89419 .52182 .89844 .52761 .90931 .52448 .90509 .51867 Mtetra
.90509 .51867 .90931 .52448 .92022 .52134 .91603 .51551 Mtetra
.91603 .51551 .92022 .52134 .93116 .51819 .92701 .51234 Mtetra
.92701 .51234 .93116 .51819 .94216 .51503 .93803 .50916 Mtetra
.93803 .50916 .94216 .51503 .95319 .51185 .94909 .50596 Mtetra
.94909 .50596 .95319 .51185 .96426 .50866 .9602 .50275 Mtetra
.36369 .66869 .36922 .67351 .37826 .6709 .37275 .66606 Mtetra
.37275 .66606 .37826 .6709 .38732 .66828 .38183 .66342 Mtetra
.38183 .66342 .38732 .66828 .39642 .66566 .39094 .66078 Mtetra
.39094 .66078 .39642 .66566 .40554 .66302 .40009 .65813 Mtetra
.40009 .65813 .40554 .66302 .4147 .66037 .40927 .65546 Mtetra
.40927 .65546 .4147 .66037 .42389 .65772 .41848 .65279 Mtetra
.41848 .65279 .42389 .65772 .43311 .65505 .42772 .65011 Mtetra
.42772 .65011 .43311 .65505 .44236 .65238 .43699 .64742 Mtetra
.43699 .64742 .44236 .65238 .45165 .6497 .44629 .64472 Mtetra
.44629 .64472 .45165 .6497 .46096 .64701 .45563 .64201 Mtetra
.45563 .64201 .46096 .64701 .47031 .6443 .465 .63929 Mtetra
.465 .63929 .47031 .6443 .47969 .64159 .4744 .63657 Mtetra
.4744 .63657 .47969 .64159 .4891 .63887 .48383 .63383 Mtetra
.48383 .63383 .4891 .63887 .49855 .63615 .4933 .63108 Mtetra
.4933 .63108 .49855 .63615 .50802 .63341 .50279 .62833 Mtetra
.50279 .62833 .50802 .63341 .51753 .63066 .51233 .62556 Mtetra
.51233 .62556 .51753 .63066 .52708 .6279 .52189 .62279 Mtetra
.52189 .62279 .52708 .6279 .53665 .62513 .53149 .62 Mtetra
.53149 .62 .53665 .62513 .54626 .62236 .54112 .61721 Mtetra
.54112 .61721 .54626 .62236 .55591 .61957 .55079 .6144 Mtetra
.55079 .6144 .55591 .61957 .56558 .61677 .56049 .61159 Mtetra
.56049 .61159 .56558 .61677 .57529 .61397 .57022 .60876 Mtetra
.57022 .60876 .57529 .61397 .58504 .61115 .57999 .60593 Mtetra
.57999 .60593 .58504 .61115 .59482 .60833 .58979 .60308 Mtetra
.58979 .60308 .59482 .60833 .60463 .60549 .59963 .60023 Mtetra
.59963 .60023 .60463 .60549 .61448 .60265 .6095 .59737 Mtetra
.6095 .59737 .61448 .60265 .62437 .59979 .61941 .59449 Mtetra
.61941 .59449 .62437 .59979 .63428 .59692 .62935 .59161 Mtetra
.62935 .59161 .63428 .59692 .64424 .59405 .63933 .58871 Mtetra
.63933 .58871 .64424 .59405 .65423 .59116 .64934 .58581 Mtetra
.64934 .58581 .65423 .59116 .66425 .58826 .65939 .58289 Mtetra
.65939 .58289 .66425 .58826 .67431 .58536 .66947 .57996 Mtetra
.66947 .57996 .67431 .58536 .68441 .58244 .67959 .57703 Mtetra
.67959 .57703 .68441 .58244 .69454 .57951 .68975 .57408 Mtetra
.68975 .57408 .69454 .57951 .70471 .57657 .69995 .57112 Mtetra
.69995 .57112 .70471 .57657 .71491 .57363 .71018 .56815 Mtetra
.71018 .56815 .71491 .57363 .72516 .57067 .72044 .56517 Mtetra
.72044 .56517 .72516 .57067 .73544 .5677 .73075 .56218 Mtetra
.73075 .56218 .73544 .5677 .74575 .56471 .74109 .55918 Mtetra
.74109 .55918 .74575 .56471 .75611 .56172 .75147 .55617 Mtetra
.75147 .55617 .75611 .56172 .7665 .55872 .76189 .55315 Mtetra
.76189 .55315 .7665 .55872 .77693 .55571 .77234 .55012 Mtetra
.77234 .55012 .77693 .55571 .78739 .55268 .78284 .54707 Mtetra
.78284 .54707 .78739 .55268 .7979 .54965 .79337 .54401 Mtetra
.79337 .54401 .7979 .54965 .80844 .5466 .80394 .54095 Mtetra
.80394 .54095 .80844 .5466 .81902 .54354 .81455 .53787 Mtetra
.81455 .53787 .81902 .54354 .82964 .54047 .8252 .53478 Mtetra
.8252 .53478 .82964 .54047 .8403 .53739 .83589 .53168 Mtetra
.83589 .53168 .8403 .53739 .851 .5343 .84661 .52857 Mtetra
.84661 .52857 .851 .5343 .86174 .5312 .85738 .52544 Mtetra
.85738 .52544 .86174 .5312 .87252 .52809 .86819 .52231 Mtetra
.86819 .52231 .87252 .52809 .88334 .52496 .87903 .51916 Mtetra
.87903 .51916 .88334 .52496 .89419 .52182 .88992 .516 Mtetra
.88992 .516 .89419 .52182 .90509 .51867 .90085 .51283 Mtetra
.90085 .51283 .90509 .51867 .91603 .51551 .91182 .50965 Mtetra
.91182 .50965 .91603 .51551 .92701 .51234 .92283 .50645 Mtetra
.92283 .50645 .92701 .51234 .93803 .50916 .93388 .50324 Mtetra
.93388 .50324 .93803 .50916 .94909 .50596 .94497 .50003 Mtetra
.94497 .50003 .94909 .50596 .9602 .50275 .9561 .4968 Mtetra
.35813 .66383 .36369 .66869 .37275 .66606 .3672 .66119 Mtetra
.3672 .66119 .37275 .66606 .38183 .66342 .3763 .65854 Mtetra
.3763 .65854 .38183 .66342 .39094 .66078 .38544 .65587 Mtetra
.38544 .65587 .39094 .66078 .40009 .65813 .3946 .6532 Mtetra
.3946 .6532 .40009 .65813 .40927 .65546 .4038 .65052 Mtetra
.4038 .65052 .40927 .65546 .41848 .65279 .41303 .64783 Mtetra
.41303 .64783 .41848 .65279 .42772 .65011 .42229 .64514 Mtetra
.42229 .64514 .42772 .65011 .43699 .64742 .43158 .64243 Mtetra
.43158 .64243 .43699 .64742 .44629 .64472 .4409 .63971 Mtetra
.4409 .63971 .44629 .64472 .45563 .64201 .45026 .63699 Mtetra
.45026 .63699 .45563 .64201 .465 .63929 .45965 .63425 Mtetra
.45965 .63425 .465 .63929 .4744 .63657 .46907 .63151 Mtetra
.46907 .63151 .4744 .63657 .48383 .63383 .47853 .62875 Mtetra
.47853 .62875 .48383 .63383 .4933 .63108 .48801 .62599 Mtetra
.48801 .62599 .4933 .63108 .50279 .62833 .49753 .62321 Mtetra
.49753 .62321 .50279 .62833 .51233 .62556 .50709 .62043 Mtetra
.50709 .62043 .51233 .62556 .52189 .62279 .51667 .61764 Mtetra
.51667 .61764 .52189 .62279 .53149 .62 .52629 .61483 Mtetra
.52629 .61483 .53149 .62 .54112 .61721 .53595 .61202 Mtetra
.53595 .61202 .54112 .61721 .55079 .6144 .54563 .6092 Mtetra
.54563 .6092 .55079 .6144 .56049 .61159 .55536 .60636 Mtetra
.55536 .60636 .56049 .61159 .57022 .60876 .56511 .60352 Mtetra
.56511 .60352 .57022 .60876 .57999 .60593 .5749 .60067 Mtetra
.5749 .60067 .57999 .60593 .58979 .60308 .58473 .59781 Mtetra
.58473 .59781 .58979 .60308 .59963 .60023 .59459 .59493 Mtetra
.59459 .59493 .59963 .60023 .6095 .59737 .60448 .59205 Mtetra
.60448 .59205 .6095 .59737 .61941 .59449 .61441 .58916 Mtetra
.61441 .58916 .61941 .59449 .62935 .59161 .62438 .58625 Mtetra
.62438 .58625 .62935 .59161 .63933 .58871 .63438 .58334 Mtetra
.63438 .58334 .63933 .58871 .64934 .58581 .64442 .58041 Mtetra
.64442 .58041 .64934 .58581 .65939 .58289 .65449 .57748 Mtetra
.65449 .57748 .65939 .58289 .66947 .57996 .6646 .57453 Mtetra
.6646 .57453 .66947 .57996 .67959 .57703 .67475 .57158 Mtetra
.67475 .57158 .67959 .57703 .68975 .57408 .68493 .56861 Mtetra
.68493 .56861 .68975 .57408 .69995 .57112 .69515 .56563 Mtetra
.69515 .56563 .69995 .57112 .71018 .56815 .70541 .56264 Mtetra
.70541 .56264 .71018 .56815 .72044 .56517 .7157 .55965 Mtetra
.7157 .55965 .72044 .56517 .73075 .56218 .72603 .55664 Mtetra
.72603 .55664 .73075 .56218 .74109 .55918 .7364 .55361 Mtetra
.7364 .55361 .74109 .55918 .75147 .55617 .7468 .55058 Mtetra
.7468 .55058 .75147 .55617 .76189 .55315 .75725 .54754 Mtetra
.75725 .54754 .76189 .55315 .77234 .55012 .76773 .54449 Mtetra
.76773 .54449 .77234 .55012 .78284 .54707 .77825 .54142 Mtetra
.77825 .54142 .78284 .54707 .79337 .54401 .78881 .53834 Mtetra
.78881 .53834 .79337 .54401 .80394 .54095 .79941 .53526 Mtetra
.79941 .53526 .80394 .54095 .81455 .53787 .81005 .53216 Mtetra
.81005 .53216 .81455 .53787 .8252 .53478 .82072 .52905 Mtetra
.82072 .52905 .8252 .53478 .83589 .53168 .83144 .52592 Mtetra
.83144 .52592 .83589 .53168 .84661 .52857 .84219 .52279 Mtetra
.84219 .52279 .84661 .52857 .85738 .52544 .85299 .51964 Mtetra
.85299 .51964 .85738 .52544 .86819 .52231 .86383 .51649 Mtetra
.86383 .51649 .86819 .52231 .87903 .51916 .8747 .51332 Mtetra
.8747 .51332 .87903 .51916 .88992 .516 .88562 .51014 Mtetra
.88562 .51014 .88992 .516 .90085 .51283 .89658 .50694 Mtetra
.89658 .50694 .90085 .51283 .91182 .50965 .90758 .50374 Mtetra
.90758 .50374 .91182 .50965 .92283 .50645 .91862 .50052 Mtetra
.91862 .50052 .92283 .50645 .93388 .50324 .9297 .49729 Mtetra
.9297 .49729 .93388 .50324 .94497 .50003 .94082 .49405 Mtetra
.94082 .49405 .94497 .50003 .9561 .4968 .95198 .4908 Mtetra
.35253 .65894 .35813 .66383 .3672 .66119 .36162 .65628 Mtetra
.36162 .65628 .3672 .66119 .3763 .65854 .37074 .65361 Mtetra
.37074 .65361 .3763 .65854 .38544 .65587 .3799 .65094 Mtetra
.3799 .65094 .38544 .65587 .3946 .6532 .38908 .64825 Mtetra
.38908 .64825 .3946 .6532 .4038 .65052 .3983 .64555 Mtetra
.3983 .64555 .4038 .65052 .41303 .64783 .40755 .64285 Mtetra
.40755 .64285 .41303 .64783 .42229 .64514 .41683 .64013 Mtetra
.41683 .64013 .42229 .64514 .43158 .64243 .42614 .63741 Mtetra
.42614 .63741 .43158 .64243 .4409 .63971 .43548 .63467 Mtetra
.43548 .63467 .4409 .63971 .45026 .63699 .44486 .63193 Mtetra
.44486 .63193 .45026 .63699 .45965 .63425 .45427 .62918 Mtetra
.45427 .62918 .45965 .63425 .46907 .63151 .46371 .62641 Mtetra
.46371 .62641 .46907 .63151 .47853 .62875 .47319 .62364 Mtetra
.47319 .62364 .47853 .62875 .48801 .62599 .48269 .62086 Mtetra
.48269 .62086 .48801 .62599 .49753 .62321 .49224 .61807 Mtetra
.49224 .61807 .49753 .62321 .50709 .62043 .50181 .61527 Mtetra
.50181 .61527 .50709 .62043 .51667 .61764 .51142 .61245 Mtetra
.51142 .61245 .51667 .61764 .52629 .61483 .52106 .60963 Mtetra
.52106 .60963 .52629 .61483 .53595 .61202 .53074 .6068 Mtetra
.53074 .6068 .53595 .61202 .54563 .6092 .54045 .60396 Mtetra
.54045 .60396 .54563 .6092 .55536 .60636 .55019 .60111 Mtetra
.55019 .60111 .55536 .60636 .56511 .60352 .55997 .59825 Mtetra
.55997 .59825 .56511 .60352 .5749 .60067 .56978 .59538 Mtetra
.56978 .59538 .5749 .60067 .58473 .59781 .57963 .59249 Mtetra
.57963 .59249 .58473 .59781 .59459 .59493 .58952 .5896 Mtetra
.58952 .5896 .59459 .59493 .60448 .59205 .59944 .5867 Mtetra
.59944 .5867 .60448 .59205 .61441 .58916 .60939 .58379 Mtetra
.60939 .58379 .61441 .58916 .62438 .58625 .61938 .58087 Mtetra
.61938 .58087 .62438 .58625 .63438 .58334 .62941 .57793 Mtetra
.62941 .57793 .63438 .58334 .64442 .58041 .63947 .57499 Mtetra
.63947 .57499 .64442 .58041 .65449 .57748 .64957 .57203 Mtetra
.64957 .57203 .65449 .57748 .6646 .57453 .6597 .56907 Mtetra
.6597 .56907 .6646 .57453 .67475 .57158 .66987 .56609 Mtetra
.66987 .56609 .67475 .57158 .68493 .56861 .68008 .56311 Mtetra
.68008 .56311 .68493 .56861 .69515 .56563 .69032 .56011 Mtetra
.69032 .56011 .69515 .56563 .70541 .56264 .7006 .5571 Mtetra
.7006 .5571 .70541 .56264 .7157 .55965 .71092 .55408 Mtetra
.71092 .55408 .7157 .55965 .72603 .55664 .72128 .55105 Mtetra
.72128 .55105 .72603 .55664 .7364 .55361 .73168 .54801 Mtetra
.73168 .54801 .7364 .55361 .7468 .55058 .74211 .54496 Mtetra
.74211 .54496 .7468 .55058 .75725 .54754 .75258 .54189 Mtetra
.75258 .54189 .75725 .54754 .76773 .54449 .76309 .53882 Mtetra
.76309 .53882 .76773 .54449 .77825 .54142 .77364 .53573 Mtetra
.77364 .53573 .77825 .54142 .78881 .53834 .78422 .53263 Mtetra
.78422 .53263 .78881 .53834 .79941 .53526 .79485 .52952 Mtetra
.79485 .52952 .79941 .53526 .81005 .53216 .80551 .5264 Mtetra
.80551 .5264 .81005 .53216 .82072 .52905 .81622 .52327 Mtetra
.81622 .52327 .82072 .52905 .83144 .52592 .82696 .52013 Mtetra
.82696 .52013 .83144 .52592 .84219 .52279 .83775 .51697 Mtetra
.83775 .51697 .84219 .52279 .85299 .51964 .84857 .51381 Mtetra
.84857 .51381 .85299 .51964 .86383 .51649 .85944 .51063 Mtetra
.85944 .51063 .86383 .51649 .8747 .51332 .87034 .50744 Mtetra
.87034 .50744 .8747 .51332 .88562 .51014 .88129 .50423 Mtetra
.88129 .50423 .88562 .51014 .89658 .50694 .89227 .50102 Mtetra
.89227 .50102 .89658 .50694 .90758 .50374 .9033 .49779 Mtetra
.9033 .49779 .90758 .50374 .91862 .50052 .91437 .49455 Mtetra
.91437 .49455 .91862 .50052 .9297 .49729 .92549 .4913 Mtetra
.92549 .4913 .9297 .49729 .94082 .49405 .93664 .48804 Mtetra
.93664 .48804 .94082 .49405 .95198 .4908 .94784 .48476 Mtetra
.34689 .65403 .35253 .65894 .36162 .65628 .356 .65135 Mtetra
.356 .65135 .36162 .65628 .37074 .65361 .36515 .64866 Mtetra
.36515 .64866 .37074 .65361 .3799 .65094 .37432 .64597 Mtetra
.37432 .64597 .3799 .65094 .38908 .64825 .38352 .64326 Mtetra
.38352 .64326 .38908 .64825 .3983 .64555 .39276 .64055 Mtetra
.39276 .64055 .3983 .64555 .40755 .64285 .40203 .63783 Mtetra
.40203 .63783 .40755 .64285 .41683 .64013 .41133 .63509 Mtetra
.41133 .63509 .41683 .64013 .42614 .63741 .42066 .63235 Mtetra
.42066 .63235 .42614 .63741 .43548 .63467 .43003 .6296 Mtetra
.43003 .6296 .43548 .63467 .44486 .63193 .43942 .62684 Mtetra
.43942 .62684 .44486 .63193 .45427 .62918 .44885 .62407 Mtetra
.44885 .62407 .45427 .62918 .46371 .62641 .45832 .62129 Mtetra
.45832 .62129 .46371 .62641 .47319 .62364 .46781 .6185 Mtetra
.46781 .6185 .47319 .62364 .48269 .62086 .47734 .6157 Mtetra
.47734 .6157 .48269 .62086 .49224 .61807 .4869 .61289 Mtetra
.4869 .61289 .49224 .61807 .50181 .61527 .4965 .61007 Mtetra
.4965 .61007 .50181 .61527 .51142 .61245 .50613 .60724 Mtetra
.50613 .60724 .51142 .61245 .52106 .60963 .5158 .6044 Mtetra
.5158 .6044 .52106 .60963 .53074 .6068 .52549 .60155 Mtetra
.52549 .60155 .53074 .6068 .54045 .60396 .53523 .59869 Mtetra
.53523 .59869 .54045 .60396 .55019 .60111 .54499 .59582 Mtetra
.54499 .59582 .55019 .60111 .55997 .59825 .5548 .59294 Mtetra
.5548 .59294 .55997 .59825 .56978 .59538 .56463 .59005 Mtetra
.56463 .59005 .56978 .59538 .57963 .59249 .5745 .58715 Mtetra
.5745 .58715 .57963 .59249 .58952 .5896 .58441 .58424 Mtetra
.58441 .58424 .58952 .5896 .59944 .5867 .59435 .58132 Mtetra
.59435 .58132 .59944 .5867 .60939 .58379 .60433 .57838 Mtetra
.60433 .57838 .60939 .58379 .61938 .58087 .61435 .57544 Mtetra
.61435 .57544 .61938 .58087 .62941 .57793 .6244 .57249 Mtetra
.6244 .57249 .62941 .57793 .63947 .57499 .63448 .56952 Mtetra
.63448 .56952 .63947 .57499 .64957 .57203 .6446 .56655 Mtetra
.6446 .56655 .64957 .57203 .6597 .56907 .65476 .56357 Mtetra
.65476 .56357 .6597 .56907 .66987 .56609 .66496 .56057 Mtetra
.66496 .56057 .66987 .56609 .68008 .56311 .67519 .55756 Mtetra
.67519 .55756 .68008 .56311 .69032 .56011 .68546 .55455 Mtetra
.68546 .55455 .69032 .56011 .7006 .5571 .69577 .55152 Mtetra
.69577 .55152 .7006 .5571 .71092 .55408 .70612 .54848 Mtetra
.70612 .54848 .71092 .55408 .72128 .55105 .7165 .54543 Mtetra
.7165 .54543 .72128 .55105 .73168 .54801 .72692 .54236 Mtetra
.72692 .54236 .73168 .54801 .74211 .54496 .73738 .53929 Mtetra
.73738 .53929 .74211 .54496 .75258 .54189 .74788 .53621 Mtetra
.74788 .53621 .75258 .54189 .76309 .53882 .75841 .53311 Mtetra
.75841 .53311 .76309 .53882 .77364 .53573 .76899 .53 Mtetra
.76899 .53 .77364 .53573 .78422 .53263 .7796 .52688 Mtetra
.7796 .52688 .78422 .53263 .79485 .52952 .79026 .52375 Mtetra
.79026 .52375 .79485 .52952 .80551 .5264 .80095 .52061 Mtetra
.80095 .52061 .80551 .5264 .81622 .52327 .81168 .51746 Mtetra
.81168 .51746 .81622 .52327 .82696 .52013 .82245 .51429 Mtetra
.82245 .51429 .82696 .52013 .83775 .51697 .83327 .51112 Mtetra
.83327 .51112 .83775 .51697 .84857 .51381 .84412 .50793 Mtetra
.84412 .50793 .84857 .51381 .85944 .51063 .85501 .50473 Mtetra
.85501 .50473 .85944 .51063 .87034 .50744 .86595 .50151 Mtetra
.86595 .50151 .87034 .50744 .88129 .50423 .87693 .49829 Mtetra
.87693 .49829 .88129 .50423 .89227 .50102 .88794 .49505 Mtetra
.88794 .49505 .89227 .50102 .9033 .49779 .899 .4918 Mtetra
.899 .4918 .9033 .49779 .91437 .49455 .9101 .48854 Mtetra
.9101 .48854 .91437 .49455 .92549 .4913 .92125 .48527 Mtetra
.92125 .48527 .92549 .4913 .93664 .48804 .93243 .48198 Mtetra
.93243 .48198 .93664 .48804 .94784 .48476 .94366 .47868 Mtetra
.34122 .64908 .34689 .65403 .356 .65135 .35035 .64638 Mtetra
.35035 .64638 .356 .65135 .36515 .64866 .35951 .64368 Mtetra
.35951 .64368 .36515 .64866 .37432 .64597 .36871 .64097 Mtetra
.36871 .64097 .37432 .64597 .38352 .64326 .37793 .63825 Mtetra
.37793 .63825 .38352 .64326 .39276 .64055 .38719 .63551 Mtetra
.38719 .63551 .39276 .64055 .40203 .63783 .39647 .63277 Mtetra
.39647 .63277 .40203 .63783 .41133 .63509 .40579 .63002 Mtetra
.40579 .63002 .41133 .63509 .42066 .63235 .41515 .62726 Mtetra
.41515 .62726 .42066 .63235 .43003 .6296 .42453 .62449 Mtetra
.42453 .62449 .43003 .6296 .43942 .62684 .43395 .62172 Mtetra
.43395 .62172 .43942 .62684 .44885 .62407 .4434 .61893 Mtetra
.4434 .61893 .44885 .62407 .45832 .62129 .45289 .61613 Mtetra
.45289 .61613 .45832 .62129 .46781 .6185 .4624 .61332 Mtetra
.4624 .61332 .46781 .6185 .47734 .6157 .47195 .6105 Mtetra
.47195 .6105 .47734 .6157 .4869 .61289 .48154 .60767 Mtetra
.48154 .60767 .4869 .61289 .4965 .61007 .49116 .60484 Mtetra
.49116 .60484 .4965 .61007 .50613 .60724 .50081 .60199 Mtetra
.50081 .60199 .50613 .60724 .5158 .6044 .5105 .59913 Mtetra
.5105 .59913 .5158 .6044 .52549 .60155 .52022 .59626 Mtetra
.52022 .59626 .52549 .60155 .53523 .59869 .52997 .59338 Mtetra
.52997 .59338 .53523 .59869 .54499 .59582 .53976 .59049 Mtetra
.53976 .59049 .54499 .59582 .5548 .59294 .54959 .58759 Mtetra
.54959 .58759 .5548 .59294 .56463 .59005 .55945 .58469 Mtetra
.55945 .58469 .56463 .59005 .5745 .58715 .56934 .58177 Mtetra
.56934 .58177 .5745 .58715 .58441 .58424 .57927 .57884 Mtetra
.57927 .57884 .58441 .58424 .59435 .58132 .58924 .57589 Mtetra
.58924 .57589 .59435 .58132 .60433 .57838 .59924 .57294 Mtetra
.59924 .57294 .60433 .57838 .61435 .57544 .60928 .56998 Mtetra
.60928 .56998 .61435 .57544 .6244 .57249 .61935 .56701 Mtetra
.61935 .56701 .6244 .57249 .63448 .56952 .62946 .56403 Mtetra
.62946 .56403 .63448 .56952 .6446 .56655 .63961 .56103 Mtetra
.63961 .56103 .6446 .56655 .65476 .56357 .64979 .55803 Mtetra
.64979 .55803 .65476 .56357 .66496 .56057 .66002 .55501 Mtetra
.66002 .55501 .66496 .56057 .67519 .55756 .67027 .55198 Mtetra
.67027 .55198 .67519 .55756 .68546 .55455 .68057 .54895 Mtetra
.68057 .54895 .68546 .55455 .69577 .55152 .6909 .5459 Mtetra
.6909 .5459 .69577 .55152 .70612 .54848 .70127 .54284 Mtetra
.70127 .54284 .70612 .54848 .7165 .54543 .71168 .53976 Mtetra
.71168 .53976 .7165 .54543 .72692 .54236 .72213 .53668 Mtetra
.72213 .53668 .72692 .54236 .73738 .53929 .73262 .53359 Mtetra
.73262 .53359 .73738 .53929 .74788 .53621 .74314 .53048 Mtetra
.74314 .53048 .74788 .53621 .75841 .53311 .75371 .52737 Mtetra
.75371 .52737 .75841 .53311 .76899 .53 .76431 .52424 Mtetra
.76431 .52424 .76899 .53 .7796 .52688 .77495 .5211 Mtetra
.77495 .5211 .7796 .52688 .79026 .52375 .78563 .51794 Mtetra
.78563 .51794 .79026 .52375 .80095 .52061 .79635 .51478 Mtetra
.79635 .51478 .80095 .52061 .81168 .51746 .80711 .51161 Mtetra
.80711 .51161 .81168 .51746 .82245 .51429 .81792 .50842 Mtetra
.81792 .50842 .82245 .51429 .83327 .51112 .82876 .50522 Mtetra
.82876 .50522 .83327 .51112 .84412 .50793 .83964 .50201 Mtetra
.83964 .50201 .84412 .50793 .85501 .50473 .85056 .49879 Mtetra
.85056 .49879 .85501 .50473 .86595 .50151 .86153 .49555 Mtetra
.86153 .49555 .86595 .50151 .87693 .49829 .87253 .4923 Mtetra
.87253 .4923 .87693 .49829 .88794 .49505 .88358 .48904 Mtetra
.88358 .48904 .88794 .49505 .899 .4918 .89467 .48577 Mtetra
.89467 .48577 .899 .4918 .9101 .48854 .9058 .48249 Mtetra
.9058 .48249 .9101 .48854 .92125 .48527 .91698 .47919 Mtetra
.91698 .47919 .92125 .48527 .93243 .48198 .92819 .47588 Mtetra
.92819 .47588 .93243 .48198 .94366 .47868 .93945 .47256 Mtetra
.33552 .6441 .34122 .64908 .35035 .64638 .34467 .64139 Mtetra
.34467 .64139 .35035 .64638 .35951 .64368 .35385 .63866 Mtetra
.35385 .63866 .35951 .64368 .36871 .64097 .36306 .63594 Mtetra
.36306 .63594 .36871 .64097 .37793 .63825 .3723 .6332 Mtetra
.3723 .6332 .37793 .63825 .38719 .63551 .38158 .63045 Mtetra
.38158 .63045 .38719 .63551 .39647 .63277 .39089 .62769 Mtetra
.39089 .62769 .39647 .63277 .40579 .63002 .40023 .62492 Mtetra
.40023 .62492 .40579 .63002 .41515 .62726 .4096 .62214 Mtetra
.4096 .62214 .41515 .62726 .42453 .62449 .41901 .61936 Mtetra
.41901 .61936 .42453 .62449 .43395 .62172 .42844 .61656 Mtetra
.42844 .61656 .43395 .62172 .4434 .61893 .43792 .61375 Mtetra
.43792 .61375 .4434 .61893 .45289 .61613 .44742 .61094 Mtetra
.44742 .61094 .45289 .61613 .4624 .61332 .45696 .60811 Mtetra
.45696 .60811 .4624 .61332 .47195 .6105 .46653 .60527 Mtetra
.46653 .60527 .47195 .6105 .48154 .60767 .47614 .60243 Mtetra
.47614 .60243 .48154 .60767 .49116 .60484 .48578 .59957 Mtetra
.48578 .59957 .49116 .60484 .50081 .60199 .49545 .5967 Mtetra
.49545 .5967 .50081 .60199 .5105 .59913 .50516 .59383 Mtetra
.50516 .59383 .5105 .59913 .52022 .59626 .5149 .59094 Mtetra
.5149 .59094 .52022 .59626 .52997 .59338 .52468 .58804 Mtetra
.52468 .58804 .52997 .59338 .53976 .59049 .5345 .58513 Mtetra
.5345 .58513 .53976 .59049 .54959 .58759 .54434 .58222 Mtetra
.54434 .58222 .54959 .58759 .55945 .58469 .55423 .57929 Mtetra
.55423 .57929 .55945 .58469 .56934 .58177 .56414 .57635 Mtetra
.56414 .57635 .56934 .58177 .57927 .57884 .5741 .5734 Mtetra
.5741 .5734 .57927 .57884 .58924 .57589 .58409 .57044 Mtetra
.58409 .57044 .58924 .57589 .59924 .57294 .59412 .56747 Mtetra
.59412 .56747 .59924 .57294 .60928 .56998 .60418 .56449 Mtetra
.60418 .56449 .60928 .56998 .61935 .56701 .61428 .56149 Mtetra
.61428 .56149 .61935 .56701 .62946 .56403 .62441 .55849 Mtetra
.62441 .55849 .62946 .56403 .63961 .56103 .63458 .55547 Mtetra
.63458 .55547 .63961 .56103 .64979 .55803 .64479 .55245 Mtetra
.64479 .55245 .64979 .55803 .66002 .55501 .65504 .54941 Mtetra
.65504 .54941 .66002 .55501 .67027 .55198 .66532 .54637 Mtetra
.66532 .54637 .67027 .55198 .68057 .54895 .67564 .54331 Mtetra
.67564 .54331 .68057 .54895 .6909 .5459 .686 .54024 Mtetra
.686 .54024 .6909 .5459 .70127 .54284 .6964 .53716 Mtetra
.6964 .53716 .70127 .54284 .71168 .53976 .70684 .53406 Mtetra
.70684 .53406 .71168 .53976 .72213 .53668 .71731 .53096 Mtetra
.71731 .53096 .72213 .53668 .73262 .53359 .72782 .52785 Mtetra
.72782 .52785 .73262 .53359 .74314 .53048 .73838 .52472 Mtetra
.73838 .52472 .74314 .53048 .75371 .52737 .74897 .52158 Mtetra
.74897 .52158 .75371 .52737 .76431 .52424 .7596 .51843 Mtetra
.7596 .51843 .76431 .52424 .77495 .5211 .77027 .51527 Mtetra
.77027 .51527 .77495 .5211 .78563 .51794 .78098 .5121 Mtetra
.78098 .5121 .78563 .51794 .79635 .51478 .79173 .50891 Mtetra
.79173 .50891 .79635 .51478 .80711 .51161 .80251 .50571 Mtetra
.80251 .50571 .80711 .51161 .81792 .50842 .81335 .5025 Mtetra
.81335 .5025 .81792 .50842 .82876 .50522 .82422 .49928 Mtetra
.82422 .49928 .82876 .50522 .83964 .50201 .83513 .49605 Mtetra
.83513 .49605 .83964 .50201 .85056 .49879 .84608 .4928 Mtetra
.84608 .4928 .85056 .49879 .86153 .49555 .85707 .48955 Mtetra
.85707 .48955 .86153 .49555 .87253 .4923 .86811 .48627 Mtetra
.86811 .48627 .87253 .4923 .88358 .48904 .87919 .48299 Mtetra
.87919 .48299 .88358 .48904 .89467 .48577 .89031 .4797 Mtetra
.89031 .4797 .89467 .48577 .9058 .48249 .90147 .47639 Mtetra
.90147 .47639 .9058 .48249 .91698 .47919 .91268 .47307 Mtetra
.91268 .47307 .91698 .47919 .92819 .47588 .92392 .46974 Mtetra
.92392 .46974 .92819 .47588 .93945 .47256 .93521 .46639 Mtetra
.32977 .63908 .33552 .6441 .34467 .64139 .33894 .63636 Mtetra
.33894 .63636 .34467 .64139 .35385 .63866 .34814 .63362 Mtetra
.34814 .63362 .35385 .63866 .36306 .63594 .35737 .63087 Mtetra
.35737 .63087 .36306 .63594 .3723 .6332 .36664 .62811 Mtetra
.36664 .62811 .3723 .6332 .38158 .63045 .37593 .62535 Mtetra
.37593 .62535 .38158 .63045 .39089 .62769 .38526 .62257 Mtetra
.38526 .62257 .39089 .62769 .40023 .62492 .39462 .61979 Mtetra
.39462 .61979 .40023 .62492 .4096 .62214 .40402 .61699 Mtetra
.40402 .61699 .4096 .62214 .41901 .61936 .41344 .61418 Mtetra
.41344 .61418 .41901 .61936 .42844 .61656 .4229 .61137 Mtetra
.4229 .61137 .42844 .61656 .43792 .61375 .43239 .60854 Mtetra
.43239 .60854 .43792 .61375 .44742 .61094 .44192 .60571 Mtetra
.44192 .60571 .44742 .61094 .45696 .60811 .45148 .60286 Mtetra
.45148 .60286 .45696 .60811 .46653 .60527 .46108 .60001 Mtetra
.46108 .60001 .46653 .60527 .47614 .60243 .4707 .59714 Mtetra
.4707 .59714 .47614 .60243 .48578 .59957 .48037 .59427 Mtetra
.48037 .59427 .48578 .59957 .49545 .5967 .49006 .59138 Mtetra
.49006 .59138 .49545 .5967 .50516 .59383 .49979 .58849 Mtetra
.49979 .58849 .50516 .59383 .5149 .59094 .50956 .58558 Mtetra
.50956 .58558 .5149 .59094 .52468 .58804 .51936 .58267 Mtetra
.51936 .58267 .52468 .58804 .5345 .58513 .52919 .57974 Mtetra
.52919 .57974 .5345 .58513 .54434 .58222 .53907 .5768 Mtetra
.53907 .5768 .54434 .58222 .55423 .57929 .54897 .57385 Mtetra
.54897 .57385 .55423 .57929 .56414 .57635 .55891 .57089 Mtetra
.55891 .57089 .56414 .57635 .5741 .5734 .56889 .56792 Mtetra
.56889 .56792 .5741 .5734 .58409 .57044 .57891 .56494 Mtetra
.57891 .56494 .58409 .57044 .59412 .56747 .58896 .56195 Mtetra
.58896 .56195 .59412 .56747 .60418 .56449 .59904 .55895 Mtetra
.59904 .55895 .60418 .56449 .61428 .56149 .60917 .55594 Mtetra
.60917 .55594 .61428 .56149 .62441 .55849 .61933 .55292 Mtetra
.61933 .55292 .62441 .55849 .63458 .55547 .62952 .54988 Mtetra
.62952 .54988 .63458 .55547 .64479 .55245 .63976 .54684 Mtetra
.63976 .54684 .64479 .55245 .65504 .54941 .65003 .54378 Mtetra
.65003 .54378 .65504 .54941 .66532 .54637 .66034 .54071 Mtetra
.66034 .54071 .66532 .54637 .67564 .54331 .67069 .53763 Mtetra
.67069 .53763 .67564 .54331 .686 .54024 .68107 .53454 Mtetra
.68107 .53454 .686 .54024 .6964 .53716 .69149 .53144 Mtetra
.69149 .53144 .6964 .53716 .70684 .53406 .70196 .52833 Mtetra
.70196 .52833 .70684 .53406 .71731 .53096 .71246 .5252 Mtetra
.71246 .5252 .71731 .53096 .72782 .52785 .723 .52206 Mtetra
.723 .52206 .72782 .52785 .73838 .52472 .73358 .51892 Mtetra
.73358 .51892 .73838 .52472 .74897 .52158 .74419 .51576 Mtetra
.74419 .51576 .74897 .52158 .7596 .51843 .75485 .51258 Mtetra
.75485 .51258 .7596 .51843 .77027 .51527 .76555 .5094 Mtetra
.76555 .5094 .77027 .51527 .78098 .5121 .77629 .50621 Mtetra
.77629 .50621 .78098 .5121 .79173 .50891 .78707 .503 Mtetra
.78707 .503 .79173 .50891 .80251 .50571 .79788 .49978 Mtetra
.79788 .49978 .80251 .50571 .81335 .5025 .80874 .49655 Mtetra
.80874 .49655 .81335 .5025 .82422 .49928 .81964 .4933 Mtetra
.81964 .4933 .82422 .49928 .83513 .49605 .83058 .49005 Mtetra
.83058 .49005 .83513 .49605 .84608 .4928 .84157 .48678 Mtetra
.84157 .48678 .84608 .4928 .85707 .48955 .85259 .4835 Mtetra
.85259 .4835 .85707 .48955 .86811 .48627 .86366 .4802 Mtetra
.86366 .4802 .86811 .48627 .87919 .48299 .87477 .4769 Mtetra
.87477 .4769 .87919 .48299 .89031 .4797 .88592 .47358 Mtetra
.88592 .47358 .89031 .4797 .90147 .47639 .89711 .47025 Mtetra
.89711 .47025 .90147 .47639 .91268 .47307 .90834 .46691 Mtetra
.90834 .46691 .91268 .47307 .92392 .46974 .91962 .46355 Mtetra
.91962 .46355 .92392 .46974 .93521 .46639 .93095 .46018 Mtetra
.32399 .63404 .32977 .63908 .33894 .63636 .33318 .63129 Mtetra
.33318 .63129 .33894 .63636 .34814 .63362 .3424 .62854 Mtetra
.3424 .62854 .34814 .63362 .35737 .63087 .35165 .62577 Mtetra
.35165 .62577 .35737 .63087 .36664 .62811 .36094 .623 Mtetra
.36094 .623 .36664 .62811 .37593 .62535 .37025 .62021 Mtetra
.37025 .62021 .37593 .62535 .38526 .62257 .3796 .61742 Mtetra
.3796 .61742 .38526 .62257 .39462 .61979 .38898 .61462 Mtetra
.38898 .61462 .39462 .61979 .40402 .61699 .3984 .6118 Mtetra
.3984 .6118 .40402 .61699 .41344 .61418 .40784 .60898 Mtetra
.40784 .60898 .41344 .61418 .4229 .61137 .41732 .60615 Mtetra
.41732 .60615 .4229 .61137 .43239 .60854 .42684 .6033 Mtetra
.42684 .6033 .43239 .60854 .44192 .60571 .43639 .60045 Mtetra
.43639 .60045 .44192 .60571 .45148 .60286 .44597 .59759 Mtetra
.44597 .59759 .45148 .60286 .46108 .60001 .45558 .59471 Mtetra
.45558 .59471 .46108 .60001 .4707 .59714 .46523 .59183 Mtetra
.46523 .59183 .4707 .59714 .48037 .59427 .47492 .58893 Mtetra
.47492 .58893 .48037 .59427 .49006 .59138 .48463 .58603 Mtetra
.48463 .58603 .49006 .59138 .49979 .58849 .49439 .58311 Mtetra
.49439 .58311 .49979 .58849 .50956 .58558 .50418 .58019 Mtetra
.50418 .58019 .50956 .58558 .51936 .58267 .514 .57725 Mtetra
.514 .57725 .51936 .58267 .52919 .57974 .52386 .57431 Mtetra
.52386 .57431 .52919 .57974 .53907 .5768 .53375 .57135 Mtetra
.53375 .57135 .53907 .5768 .54897 .57385 .54368 .56838 Mtetra
.54368 .56838 .54897 .57385 .55891 .57089 .55365 .5654 Mtetra
.55365 .5654 .55891 .57089 .56889 .56792 .56365 .56241 Mtetra
.56365 .56241 .56889 .56792 .57891 .56494 .57369 .55941 Mtetra
.57369 .55941 .57891 .56494 .58896 .56195 .58376 .5564 Mtetra
.58376 .5564 .58896 .56195 .59904 .55895 .59387 .55338 Mtetra
.59387 .55338 .59904 .55895 .60917 .55594 .60402 .55035 Mtetra
.60402 .55035 .60917 .55594 .61933 .55292 .61421 .5473 Mtetra
.61421 .5473 .61933 .55292 .62952 .54988 .62443 .54425 Mtetra
.62443 .54425 .62952 .54988 .63976 .54684 .63469 .54118 Mtetra
.63469 .54118 .63976 .54684 .65003 .54378 .64498 .53811 Mtetra
.64498 .53811 .65003 .54378 .66034 .54071 .65532 .53502 Mtetra
.65532 .53502 .66034 .54071 .67069 .53763 .66569 .53192 Mtetra
.66569 .53192 .67069 .53763 .68107 .53454 .6761 .52881 Mtetra
.6761 .52881 .68107 .53454 .69149 .53144 .68655 .52568 Mtetra
.68655 .52568 .69149 .53144 .70196 .52833 .69704 .52255 Mtetra
.69704 .52255 .70196 .52833 .71246 .5252 .70757 .5194 Mtetra
.70757 .5194 .71246 .5252 .723 .52206 .71814 .51624 Mtetra
.71814 .51624 .723 .52206 .73358 .51892 .72874 .51307 Mtetra
.72874 .51307 .73358 .51892 .74419 .51576 .73939 .50989 Mtetra
.73939 .50989 .74419 .51576 .75485 .51258 .75008 .5067 Mtetra
.75008 .5067 .75485 .51258 .76555 .5094 .7608 .50349 Mtetra
.7608 .50349 .76555 .5094 .77629 .50621 .77157 .50027 Mtetra
.77157 .50027 .77629 .50621 .78707 .503 .78237 .49704 Mtetra
.78237 .49704 .78707 .503 .79788 .49978 .79322 .4938 Mtetra
.79322 .4938 .79788 .49978 .80874 .49655 .80411 .49055 Mtetra
.80411 .49055 .80874 .49655 .81964 .4933 .81504 .48728 Mtetra
.81504 .48728 .81964 .4933 .83058 .49005 .82601 .484 Mtetra
.82601 .484 .83058 .49005 .84157 .48678 .83702 .48071 Mtetra
.83702 .48071 .84157 .48678 .85259 .4835 .84808 .47741 Mtetra
.84808 .47741 .85259 .4835 .86366 .4802 .85917 .47409 Mtetra
.85917 .47409 .86366 .4802 .87477 .4769 .87031 .47076 Mtetra
.87031 .47076 .87477 .4769 .88592 .47358 .88149 .46742 Mtetra
.88149 .46742 .88592 .47358 .89711 .47025 .89272 .46407 Mtetra
.89272 .46407 .89711 .47025 .90834 .46691 .90398 .4607 Mtetra
.90398 .4607 .90834 .46691 .91962 .46355 .91529 .45732 Mtetra
.91529 .45732 .91962 .46355 .93095 .46018 .92665 .45393 Mtetra
.31818 .62896 .32399 .63404 .33318 .63129 .32738 .6262 Mtetra
.32738 .6262 .33318 .63129 .3424 .62854 .33662 .62343 Mtetra
.33662 .62343 .3424 .62854 .35165 .62577 .34589 .62064 Mtetra
.34589 .62064 .35165 .62577 .36094 .623 .3552 .61785 Mtetra
.3552 .61785 .36094 .623 .37025 .62021 .36453 .61505 Mtetra
.36453 .61505 .37025 .62021 .3796 .61742 .3739 .61224 Mtetra
.3739 .61224 .3796 .61742 .38898 .61462 .3833 .60942 Mtetra
.3833 .60942 .38898 .61462 .3984 .6118 .39274 .60658 Mtetra
.39274 .60658 .3984 .6118 .40784 .60898 .40221 .60374 Mtetra
.40221 .60374 .40784 .60898 .41732 .60615 .41171 .60089 Mtetra
.41171 .60089 .41732 .60615 .42684 .6033 .42124 .59803 Mtetra
.42124 .59803 .42684 .6033 .43639 .60045 .43081 .59516 Mtetra
.43081 .59516 .43639 .60045 .44597 .59759 .44042 .59227 Mtetra
.44042 .59227 .44597 .59759 .45558 .59471 .45005 .58938 Mtetra
.45005 .58938 .45558 .59471 .46523 .59183 .45972 .58648 Mtetra
.45972 .58648 .46523 .59183 .47492 .58893 .46943 .58356 Mtetra
.46943 .58356 .47492 .58893 .48463 .58603 .47917 .58064 Mtetra
.47917 .58064 .48463 .58603 .49439 .58311 .48895 .57771 Mtetra
.48895 .57771 .49439 .58311 .50418 .58019 .49876 .57476 Mtetra
.49876 .57476 .50418 .58019 .514 .57725 .5086 .57181 Mtetra
.5086 .57181 .514 .57725 .52386 .57431 .51849 .56884 Mtetra
.51849 .56884 .52386 .57431 .53375 .57135 .5284 .56586 Mtetra
.5284 .56586 .53375 .57135 .54368 .56838 .53836 .56288 Mtetra
.53836 .56288 .54368 .56838 .55365 .5654 .54835 .55988 Mtetra
.54835 .55988 .55365 .5654 .56365 .56241 .55837 .55687 Mtetra
.55837 .55687 .56365 .56241 .57369 .55941 .56843 .55385 Mtetra
.56843 .55385 .57369 .55941 .58376 .5564 .57853 .55082 Mtetra
.57853 .55082 .58376 .5564 .59387 .55338 .58867 .54777 Mtetra
.58867 .54777 .59387 .55338 .60402 .55035 .59884 .54472 Mtetra
.59884 .54472 .60402 .55035 .61421 .5473 .60905 .54166 Mtetra
.60905 .54166 .61421 .5473 .62443 .54425 .6193 .53858 Mtetra
.6193 .53858 .62443 .54425 .63469 .54118 .62958 .53549 Mtetra
.62958 .53549 .63469 .54118 .64498 .53811 .63991 .53239 Mtetra
.63991 .53239 .64498 .53811 .65532 .53502 .65027 .52928 Mtetra
.65027 .52928 .65532 .53502 .66569 .53192 .66067 .52616 Mtetra
.66067 .52616 .66569 .53192 .6761 .52881 .6711 .52303 Mtetra
.6711 .52303 .6761 .52881 .68655 .52568 .68158 .51989 Mtetra
.68158 .51989 .68655 .52568 .69704 .52255 .6921 .51673 Mtetra
.6921 .51673 .69704 .52255 .70757 .5194 .70265 .51356 Mtetra
.70265 .51356 .70757 .5194 .71814 .51624 .71324 .51038 Mtetra
.71324 .51038 .71814 .51624 .72874 .51307 .72388 .50719 Mtetra
.72388 .50719 .72874 .51307 .73939 .50989 .73455 .50399 Mtetra
.73455 .50399 .73939 .50989 .75008 .5067 .74527 .50077 Mtetra
.74527 .50077 .75008 .5067 .7608 .50349 .75602 .49754 Mtetra
.75602 .49754 .7608 .50349 .77157 .50027 .76681 .4943 Mtetra
.76681 .4943 .77157 .50027 .78237 .49704 .77765 .49105 Mtetra
.77765 .49105 .78237 .49704 .79322 .4938 .78852 .48779 Mtetra
.78852 .48779 .79322 .4938 .80411 .49055 .79944 .48451 Mtetra
.79944 .48451 .80411 .49055 .81504 .48728 .8104 .48122 Mtetra
.8104 .48122 .81504 .48728 .82601 .484 .8214 .47792 Mtetra
.8214 .47792 .82601 .484 .83702 .48071 .83244 .4746 Mtetra
.83244 .4746 .83702 .48071 .84808 .47741 .84353 .47128 Mtetra
.84353 .47128 .84808 .47741 .85917 .47409 .85465 .46794 Mtetra
.85465 .46794 .85917 .47409 .87031 .47076 .86582 .46458 Mtetra
.86582 .46458 .87031 .47076 .88149 .46742 .87704 .46122 Mtetra
.87704 .46122 .88149 .46742 .89272 .46407 .88829 .45784 Mtetra
.88829 .45784 .89272 .46407 .90398 .4607 .89959 .45445 Mtetra
.89959 .45445 .90398 .4607 .91529 .45732 .91093 .45104 Mtetra
.91093 .45104 .91529 .45732 .92665 .45393 .92232 .44763 Mtetra
.31232 .62385 .31818 .62896 .32738 .6262 .32155 .62107 Mtetra
.32155 .62107 .32738 .6262 .33662 .62343 .33081 .61828 Mtetra
.33081 .61828 .33662 .62343 .34589 .62064 .3401 .61548 Mtetra
.3401 .61548 .34589 .62064 .3552 .61785 .34942 .61267 Mtetra
.34942 .61267 .3552 .61785 .36453 .61505 .35878 .60985 Mtetra
.35878 .60985 .36453 .61505 .3739 .61224 .36817 .60702 Mtetra
.36817 .60702 .3739 .61224 .3833 .60942 .37759 .60418 Mtetra
.37759 .60418 .3833 .60942 .39274 .60658 .38704 .60133 Mtetra
.38704 .60133 .39274 .60658 .40221 .60374 .39653 .59847 Mtetra
.39653 .59847 .40221 .60374 .41171 .60089 .40606 .5956 Mtetra
.40606 .5956 .41171 .60089 .42124 .59803 .41561 .59272 Mtetra
.41561 .59272 .42124 .59803 .43081 .59516 .4252 .58983 Mtetra
.4252 .58983 .43081 .59516 .44042 .59227 .43483 .58692 Mtetra
.43483 .58692 .44042 .59227 .45005 .58938 .44449 .58401 Mtetra
.44449 .58401 .45005 .58938 .45972 .58648 .45418 .58109 Mtetra
.45418 .58109 .45972 .58648 .46943 .58356 .46391 .57816 Mtetra
.46391 .57816 .46943 .58356 .47917 .58064 .47367 .57521 Mtetra
.47367 .57521 .47917 .58064 .48895 .57771 .48347 .57226 Mtetra
.48347 .57226 .48895 .57771 .49876 .57476 .4933 .5693 Mtetra
.4933 .5693 .49876 .57476 .5086 .57181 .50317 .56632 Mtetra
.50317 .56632 .5086 .57181 .51849 .56884 .51308 .56334 Mtetra
.51308 .56334 .51849 .56884 .5284 .56586 .52302 .56034 Mtetra
.52302 .56034 .5284 .56586 .53836 .56288 .533 .55733 Mtetra
.533 .55733 .53836 .56288 .54835 .55988 .54301 .55431 Mtetra
.54301 .55431 .54835 .55988 .55837 .55687 .55306 .55128 Mtetra
.55306 .55128 .55837 .55687 .56843 .55385 .56314 .54824 Mtetra
.56314 .54824 .56843 .55385 .57853 .55082 .57327 .54519 Mtetra
.57327 .54519 .57853 .55082 .58867 .54777 .58343 .54213 Mtetra
.58343 .54213 .58867 .54777 .59884 .54472 .59363 .53905 Mtetra
.59363 .53905 .59884 .54472 .60905 .54166 .60386 .53597 Mtetra
.60386 .53597 .60905 .54166 .6193 .53858 .61413 .53287 Mtetra
.61413 .53287 .6193 .53858 .62958 .53549 .62444 .52976 Mtetra
.62444 .52976 .62958 .53549 .63991 .53239 .63479 .52664 Mtetra
.63479 .52664 .63991 .53239 .65027 .52928 .64518 .52351 Mtetra
.64518 .52351 .65027 .52928 .66067 .52616 .6556 .52037 Mtetra
.6556 .52037 .66067 .52616 .6711 .52303 .66607 .51722 Mtetra
.66607 .51722 .6711 .52303 .68158 .51989 .67657 .51405 Mtetra
.67657 .51405 .68158 .51989 .6921 .51673 .68711 .51087 Mtetra
.68711 .51087 .6921 .51673 .70265 .51356 .6977 .50768 Mtetra
.6977 .50768 .70265 .51356 .71324 .51038 .70832 .50448 Mtetra
.70832 .50448 .71324 .51038 .72388 .50719 .71898 .50127 Mtetra
.71898 .50127 .72388 .50719 .73455 .50399 .72968 .49804 Mtetra
.72968 .49804 .73455 .50399 .74527 .50077 .74042 .4948 Mtetra
.74042 .4948 .74527 .50077 .75602 .49754 .7512 .49155 Mtetra
.7512 .49155 .75602 .49754 .76681 .4943 .76203 .48829 Mtetra
.76203 .48829 .76681 .4943 .77765 .49105 .77289 .48501 Mtetra
.77289 .48501 .77765 .49105 .78852 .48779 .7838 .48173 Mtetra
.7838 .48173 .78852 .48779 .79944 .48451 .79474 .47843 Mtetra
.79474 .47843 .79944 .48451 .8104 .48122 .80573 .47511 Mtetra
.80573 .47511 .8104 .48122 .8214 .47792 .81676 .47179 Mtetra
.81676 .47179 .8214 .47792 .83244 .4746 .82783 .46845 Mtetra
.82783 .46845 .83244 .4746 .84353 .47128 .83895 .4651 Mtetra
.83895 .4651 .84353 .47128 .85465 .46794 .85011 .46174 Mtetra
.85011 .46174 .85465 .46794 .86582 .46458 .86131 .45836 Mtetra
.86131 .45836 .86582 .46458 .87704 .46122 .87255 .45497 Mtetra
.87255 .45497 .87704 .46122 .88829 .45784 .88384 .45157 Mtetra
.88384 .45157 .88829 .45784 .89959 .45445 .89517 .44815 Mtetra
.89517 .44815 .89959 .45445 .91093 .45104 .90654 .44472 Mtetra
.90654 .44472 .91093 .45104 .92232 .44763 .91796 .44128 Mtetra
.30643 .61871 .31232 .62385 .32155 .62107 .31568 .61591 Mtetra
.31568 .61591 .32155 .62107 .33081 .61828 .32495 .6131 Mtetra
.32495 .6131 .33081 .61828 .3401 .61548 .33427 .61028 Mtetra
.33427 .61028 .3401 .61548 .34942 .61267 .34361 .60746 Mtetra
.34361 .60746 .34942 .61267 .35878 .60985 .35299 .60462 Mtetra
.35299 .60462 .35878 .60985 .36817 .60702 .36239 .60177 Mtetra
.36239 .60177 .36817 .60702 .37759 .60418 .37184 .59891 Mtetra
.37184 .59891 .37759 .60418 .38704 .60133 .38131 .59604 Mtetra
.38131 .59604 .38704 .60133 .39653 .59847 .39082 .59316 Mtetra
.39082 .59316 .39653 .59847 .40606 .5956 .40037 .59027 Mtetra
.40037 .59027 .40606 .5956 .41561 .59272 .40995 .58737 Mtetra
.40995 .58737 .41561 .59272 .4252 .58983 .41956 .58446 Mtetra
.41956 .58446 .4252 .58983 .43483 .58692 .4292 .58154 Mtetra
.4292 .58154 .43483 .58692 .44449 .58401 .43888 .57861 Mtetra
.43888 .57861 .44449 .58401 .45418 .58109 .4486 .57567 Mtetra
.4486 .57567 .45418 .58109 .46391 .57816 .45835 .57272 Mtetra
.45835 .57272 .46391 .57816 .47367 .57521 .46814 .56975 Mtetra
.46814 .56975 .47367 .57521 .48347 .57226 .47796 .56678 Mtetra
.47796 .56678 .48347 .57226 .4933 .5693 .48781 .5638 Mtetra
.48781 .5638 .4933 .5693 .50317 .56632 .49771 .5608 Mtetra
.49771 .5608 .50317 .56632 .51308 .56334 .50763 .55779 Mtetra
.50763 .55779 .51308 .56334 .52302 .56034 .5176 .55478 Mtetra
.5176 .55478 .52302 .56034 .533 .55733 .5276 .55175 Mtetra
.5276 .55175 .533 .55733 .54301 .55431 .53764 .54871 Mtetra
.53764 .54871 .54301 .55431 .55306 .55128 .54771 .54566 Mtetra
.54771 .54566 .55306 .55128 .56314 .54824 .55782 .5426 Mtetra
.55782 .5426 .56314 .54824 .57327 .54519 .56797 .53953 Mtetra
.56797 .53953 .57327 .54519 .58343 .54213 .57815 .53644 Mtetra
.57815 .53644 .58343 .54213 .59363 .53905 .58837 .53335 Mtetra
.58837 .53335 .59363 .53905 .60386 .53597 .59864 .53024 Mtetra
.59864 .53024 .60386 .53597 .61413 .53287 .60893 .52712 Mtetra
.60893 .52712 .61413 .53287 .62444 .52976 .61927 .524 Mtetra
.61927 .524 .62444 .52976 .63479 .52664 .62964 .52085 Mtetra
.62964 .52085 .63479 .52664 .64518 .52351 .64006 .5177 Mtetra
.64006 .5177 .64518 .52351 .6556 .52037 .65051 .51454 Mtetra
.65051 .51454 .6556 .52037 .66607 .51722 .661 .51136 Mtetra
.661 .51136 .66607 .51722 .67657 .51405 .67153 .50817 Mtetra
.67153 .50817 .67657 .51405 .68711 .51087 .6821 .50497 Mtetra
.6821 .50497 .68711 .51087 .6977 .50768 .69271 .50176 Mtetra
.69271 .50176 .6977 .50768 .70832 .50448 .70336 .49854 Mtetra
.70336 .49854 .70832 .50448 .71898 .50127 .71405 .4953 Mtetra
.71405 .4953 .71898 .50127 .72968 .49804 .72477 .49205 Mtetra
.72477 .49205 .72968 .49804 .74042 .4948 .73554 .48879 Mtetra
.73554 .48879 .74042 .4948 .7512 .49155 .74636 .48552 Mtetra
.74636 .48552 .7512 .49155 .76203 .48829 .75721 .48223 Mtetra
.75721 .48223 .76203 .48829 .77289 .48501 .7681 .47893 Mtetra
.7681 .47893 .77289 .48501 .7838 .48173 .77903 .47562 Mtetra
.77903 .47562 .7838 .48173 .79474 .47843 .79001 .4723 Mtetra
.79001 .4723 .79474 .47843 .80573 .47511 .80103 .46897 Mtetra
.80103 .46897 .80573 .47511 .81676 .47179 .81209 .46562 Mtetra
.81209 .46562 .81676 .47179 .82783 .46845 .82319 .46226 Mtetra
.82319 .46226 .82783 .46845 .83895 .4651 .83434 .45888 Mtetra
.83434 .45888 .83895 .4651 .85011 .46174 .84552 .45549 Mtetra
.84552 .45549 .85011 .46174 .86131 .45836 .85676 .45209 Mtetra
.85676 .45209 .86131 .45836 .87255 .45497 .86803 .44868 Mtetra
.86803 .44868 .87255 .45497 .88384 .45157 .87935 .44525 Mtetra
.87935 .44525 .88384 .45157 .89517 .44815 .89071 .44181 Mtetra
.89071 .44181 .89517 .44815 .90654 .44472 .90212 .43836 Mtetra
.90212 .43836 .90654 .44472 .91796 .44128 .91357 .43489 Mtetra
.3005 .61354 .30643 .61871 .31568 .61591 .30977 .61072 Mtetra
.30977 .61072 .31568 .61591 .32495 .6131 .31906 .60789 Mtetra
.31906 .60789 .32495 .6131 .33427 .61028 .32839 .60505 Mtetra
.32839 .60505 .33427 .61028 .34361 .60746 .33776 .60221 Mtetra
.33776 .60221 .34361 .60746 .35299 .60462 .34715 .59935 Mtetra
.34715 .59935 .35299 .60462 .36239 .60177 .35658 .59648 Mtetra
.35658 .59648 .36239 .60177 .37184 .59891 .36605 .5936 Mtetra
.36605 .5936 .37184 .59891 .38131 .59604 .37555 .59072 Mtetra
.37555 .59072 .38131 .59604 .39082 .59316 .38508 .58782 Mtetra
.38508 .58782 .39082 .59316 .40037 .59027 .39464 .58491 Mtetra
.39464 .58491 .40037 .59027 .40995 .58737 .40424 .58199 Mtetra
.40424 .58199 .40995 .58737 .41956 .58446 .41387 .57906 Mtetra
.41387 .57906 .41956 .58446 .4292 .58154 .42354 .57612 Mtetra
.42354 .57612 .4292 .58154 .43888 .57861 .43324 .57317 Mtetra
.43324 .57317 .43888 .57861 .4486 .57567 .44298 .57021 Mtetra
.44298 .57021 .4486 .57567 .45835 .57272 .45276 .56724 Mtetra
.45276 .56724 .45835 .57272 .46814 .56975 .46256 .56426 Mtetra
.46256 .56426 .46814 .56975 .47796 .56678 .47241 .56126 Mtetra
.47241 .56126 .47796 .56678 .48781 .5638 .48229 .55826 Mtetra
.48229 .55826 .48781 .5638 .49771 .5608 .4922 .55524 Mtetra
.4922 .55524 .49771 .5608 .50763 .55779 .50215 .55222 Mtetra
.50215 .55222 .50763 .55779 .5176 .55478 .51214 .54918 Mtetra
.51214 .54918 .5176 .55478 .5276 .55175 .52217 .54613 Mtetra
.52217 .54613 .5276 .55175 .53764 .54871 .53223 .54307 Mtetra
.53223 .54307 .53764 .54871 .54771 .54566 .54232 .54 Mtetra
.54232 .54 .54771 .54566 .55782 .5426 .55246 .53692 Mtetra
.55246 .53692 .55782 .5426 .56797 .53953 .56263 .53383 Mtetra
.56263 .53383 .56797 .53953 .57815 .53644 .57284 .53072 Mtetra
.57284 .53072 .57815 .53644 .58837 .53335 .58309 .52761 Mtetra
.58309 .52761 .58837 .53335 .59864 .53024 .59337 .52448 Mtetra
.59337 .52448 .59864 .53024 .60893 .52712 .6037 .52134 Mtetra
.6037 .52134 .60893 .52712 .61927 .524 .61406 .51819 Mtetra
.61406 .51819 .61927 .524 .62964 .52085 .62446 .51503 Mtetra
.62446 .51503 .62964 .52085 .64006 .5177 .6349 .51185 Mtetra
.6349 .51185 .64006 .5177 .65051 .51454 .64538 .50866 Mtetra
.64538 .50866 .65051 .51454 .661 .51136 .65589 .50547 Mtetra
.65589 .50547 .661 .51136 .67153 .50817 .66645 .50226 Mtetra
.66645 .50226 .67153 .50817 .6821 .50497 .67705 .49903 Mtetra
.67705 .49903 .6821 .50497 .69271 .50176 .68768 .4958 Mtetra
.68768 .4958 .69271 .50176 .70336 .49854 .69836 .49255 Mtetra
.69836 .49255 .70336 .49854 .71405 .4953 .70908 .48929 Mtetra
.70908 .48929 .71405 .4953 .72477 .49205 .71984 .48602 Mtetra
.71984 .48602 .72477 .49205 .73554 .48879 .73063 .48274 Mtetra
.73063 .48274 .73554 .48879 .74636 .48552 .74147 .47944 Mtetra
.74147 .47944 .74636 .48552 .75721 .48223 .75235 .47613 Mtetra
.75235 .47613 .75721 .48223 .7681 .47893 .76328 .47281 Mtetra
.76328 .47281 .7681 .47893 .77903 .47562 .77424 .46948 Mtetra
.77424 .46948 .77903 .47562 .79001 .4723 .78524 .46613 Mtetra
.78524 .46613 .79001 .4723 .80103 .46897 .79629 .46277 Mtetra
.79629 .46277 .80103 .46897 .81209 .46562 .80738 .4594 Mtetra
.80738 .4594 .81209 .46562 .82319 .46226 .81852 .45602 Mtetra
.81852 .45602 .82319 .46226 .83434 .45888 .82969 .45262 Mtetra
.82969 .45262 .83434 .45888 .84552 .45549 .84091 .44921 Mtetra
.84091 .44921 .84552 .45549 .85676 .45209 .85217 .44578 Mtetra
.85217 .44578 .85676 .45209 .86803 .44868 .86348 .44234 Mtetra
.86348 .44234 .86803 .44868 .87935 .44525 .87483 .43889 Mtetra
.87483 .43889 .87935 .44525 .89071 .44181 .88623 .43543 Mtetra
.88623 .43543 .89071 .44181 .90212 .43836 .89766 .43195 Mtetra
.89766 .43195 .90212 .43836 .91357 .43489 .90915 .42846 Mtetra
.29453 .60833 .3005 .61354 .30977 .61072 .30382 .60549 Mtetra
.30382 .60549 .30977 .61072 .31906 .60789 .31314 .60265 Mtetra
.31314 .60265 .31906 .60789 .32839 .60505 .32249 .59979 Mtetra
.32249 .59979 .32839 .60505 .33776 .60221 .33187 .59692 Mtetra
.33187 .59692 .33776 .60221 .34715 .59935 .34129 .59405 Mtetra
.34129 .59405 .34715 .59935 .35658 .59648 .35074 .59116 Mtetra
.35074 .59116 .35658 .59648 .36605 .5936 .36022 .58826 Mtetra
.36022 .58826 .36605 .5936 .37555 .59072 .36974 .58536 Mtetra
.36974 .58536 .37555 .59072 .38508 .58782 .37929 .58244 Mtetra
.37929 .58244 .38508 .58782 .39464 .58491 .38888 .57951 Mtetra
.38888 .57951 .39464 .58491 .40424 .58199 .3985 .57657 Mtetra
.3985 .57657 .40424 .58199 .41387 .57906 .40815 .57363 Mtetra
.40815 .57363 .41387 .57906 .42354 .57612 .41784 .57067 Mtetra
.41784 .57067 .42354 .57612 .43324 .57317 .42757 .5677 Mtetra
.42757 .5677 .43324 .57317 .44298 .57021 .43733 .56471 Mtetra
.43733 .56471 .44298 .57021 .45276 .56724 .44712 .56172 Mtetra
.44712 .56172 .45276 .56724 .46256 .56426 .45695 .55872 Mtetra
.45695 .55872 .46256 .56426 .47241 .56126 .46682 .55571 Mtetra
.46682 .55571 .47241 .56126 .48229 .55826 .47672 .55268 Mtetra
.47672 .55268 .48229 .55826 .4922 .55524 .48666 .54965 Mtetra
.48666 .54965 .4922 .55524 .50215 .55222 .49664 .5466 Mtetra
.49664 .5466 .50215 .55222 .51214 .54918 .50665 .54354 Mtetra
.50665 .54354 .51214 .54918 .52217 .54613 .5167 .54047 Mtetra
.5167 .54047 .52217 .54613 .53223 .54307 .52678 .53739 Mtetra
.52678 .53739 .53223 .54307 .54232 .54 .5369 .5343 Mtetra
.5369 .5343 .54232 .54 .55246 .53692 .54706 .5312 Mtetra
.54706 .5312 .55246 .53692 .56263 .53383 .55726 .52809 Mtetra
.55726 .52809 .56263 .53383 .57284 .53072 .56749 .52496 Mtetra
.56749 .52496 .57284 .53072 .58309 .52761 .57777 .52182 Mtetra
.57777 .52182 .58309 .52761 .59337 .52448 .58808 .51867 Mtetra
.58808 .51867 .59337 .52448 .6037 .52134 .59843 .51551 Mtetra
.59843 .51551 .6037 .52134 .61406 .51819 .60881 .51234 Mtetra
.60881 .51234 .61406 .51819 .62446 .51503 .61924 .50916 Mtetra
.61924 .50916 .62446 .51503 .6349 .51185 .62971 .50596 Mtetra
.62971 .50596 .6349 .51185 .64538 .50866 .64021 .50275 Mtetra
.64021 .50275 .64538 .50866 .65589 .50547 .65075 .49953 Mtetra
.65075 .49953 .65589 .50547 .66645 .50226 .66134 .4963 Mtetra
.66134 .4963 .66645 .50226 .67705 .49903 .67196 .49305 Mtetra
.67196 .49305 .67705 .49903 .68768 .4958 .68263 .4898 Mtetra
.68263 .4898 .68768 .4958 .69836 .49255 .69333 .48653 Mtetra
.69333 .48653 .69836 .49255 .70908 .48929 .70408 .48325 Mtetra
.70408 .48325 .70908 .48929 .71984 .48602 .71486 .47995 Mtetra
.71486 .47995 .71984 .48602 .73063 .48274 .72569 .47664 Mtetra
.72569 .47664 .73063 .48274 .74147 .47944 .73656 .47333 Mtetra
.73656 .47333 .74147 .47944 .75235 .47613 .74746 .46999 Mtetra
.74746 .46999 .75235 .47613 .76328 .47281 .75842 .46665 Mtetra
.75842 .46665 .76328 .47281 .77424 .46948 .76941 .46329 Mtetra
.76941 .46329 .77424 .46948 .78524 .46613 .78044 .45992 Mtetra
.78044 .45992 .78524 .46613 .79629 .46277 .79152 .45654 Mtetra
.79152 .45654 .79629 .46277 .80738 .4594 .80264 .45314 Mtetra
.80264 .45314 .80738 .4594 .81852 .45602 .81381 .44973 Mtetra
.81381 .44973 .81852 .45602 .82969 .45262 .82501 .44631 Mtetra
.82501 .44631 .82969 .45262 .84091 .44921 .83626 .44287 Mtetra
.83626 .44287 .84091 .44921 .85217 .44578 .84756 .43942 Mtetra
.84756 .43942 .85217 .44578 .86348 .44234 .8589 .43596 Mtetra
.8589 .43596 .86348 .44234 .87483 .43889 .87028 .43248 Mtetra
.87028 .43248 .87483 .43889 .88623 .43543 .88171 .42899 Mtetra
.88171 .42899 .88623 .43543 .89766 .43195 .89318 .42549 Mtetra
.89318 .42549 .89766 .43195 .90915 .42846 .90469 .42197 Mtetra
.28853 .60308 .29453 .60833 .30382 .60549 .29783 .60023 Mtetra
.29783 .60023 .30382 .60549 .31314 .60265 .30717 .59737 Mtetra
.30717 .59737 .31314 .60265 .32249 .59979 .31654 .59449 Mtetra
.31654 .59449 .32249 .59979 .33187 .59692 .32594 .59161 Mtetra
.32594 .59161 .33187 .59692 .34129 .59405 .33538 .58871 Mtetra
.33538 .58871 .34129 .59405 .35074 .59116 .34485 .58581 Mtetra
.34485 .58581 .35074 .59116 .36022 .58826 .35435 .58289 Mtetra
.35435 .58289 .36022 .58826 .36974 .58536 .36389 .57996 Mtetra
.36389 .57996 .36974 .58536 .37929 .58244 .37347 .57703 Mtetra
.37347 .57703 .37929 .58244 .38888 .57951 .38307 .57408 Mtetra
.38307 .57408 .38888 .57951 .3985 .57657 .39272 .57112 Mtetra
.39272 .57112 .3985 .57657 .40815 .57363 .40239 .56815 Mtetra
.40239 .56815 .40815 .57363 .41784 .57067 .41211 .56517 Mtetra
.41211 .56517 .41784 .57067 .42757 .5677 .42185 .56218 Mtetra
.42185 .56218 .42757 .5677 .43733 .56471 .43163 .55918 Mtetra
.43163 .55918 .43733 .56471 .44712 .56172 .44145 .55617 Mtetra
.44145 .55617 .44712 .56172 .45695 .55872 .45131 .55315 Mtetra
.45131 .55315 .45695 .55872 .46682 .55571 .4612 .55012 Mtetra
.4612 .55012 .46682 .55571 .47672 .55268 .47112 .54707 Mtetra
.47112 .54707 .47672 .55268 .48666 .54965 .48108 .54401 Mtetra
.48108 .54401 .48666 .54965 .49664 .5466 .49108 .54095 Mtetra
.49108 .54095 .49664 .5466 .50665 .54354 .50112 .53787 Mtetra
.50112 .53787 .50665 .54354 .5167 .54047 .51119 .53478 Mtetra
.51119 .53478 .5167 .54047 .52678 .53739 .5213 .53168 Mtetra
.5213 .53168 .52678 .53739 .5369 .5343 .53144 .52857 Mtetra
.53144 .52857 .5369 .5343 .54706 .5312 .54163 .52544 Mtetra
.54163 .52544 .54706 .5312 .55726 .52809 .55185 .52231 Mtetra
.55185 .52231 .55726 .52809 .56749 .52496 .56211 .51916 Mtetra
.56211 .51916 .56749 .52496 .57777 .52182 .57241 .516 Mtetra
.57241 .516 .57777 .52182 .58808 .51867 .58274 .51283 Mtetra
.58274 .51283 .58808 .51867 .59843 .51551 .59312 .50965 Mtetra
.59312 .50965 .59843 .51551 .60881 .51234 .60353 .50645 Mtetra
.60353 .50645 .60881 .51234 .61924 .50916 .61398 .50324 Mtetra
.61398 .50324 .61924 .50916 .62971 .50596 .62448 .50003 Mtetra
.62448 .50003 .62971 .50596 .64021 .50275 .63501 .4968 Mtetra
.63501 .4968 .64021 .50275 .65075 .49953 .64558 .49355 Mtetra
.64558 .49355 .65075 .49953 .66134 .4963 .65619 .4903 Mtetra
.65619 .4903 .66134 .4963 .67196 .49305 .66684 .48703 Mtetra
.66684 .48703 .67196 .49305 .68263 .4898 .67753 .48375 Mtetra
.67753 .48375 .68263 .4898 .69333 .48653 .68826 .48046 Mtetra
.68826 .48046 .69333 .48653 .70408 .48325 .69904 .47715 Mtetra
.69904 .47715 .70408 .48325 .71486 .47995 .70985 .47384 Mtetra
.70985 .47384 .71486 .47995 .72569 .47664 .72071 .47051 Mtetra
.72071 .47051 .72569 .47664 .73656 .47333 .7316 .46716 Mtetra
.7316 .46716 .73656 .47333 .74746 .46999 .74254 .46381 Mtetra
.74254 .46381 .74746 .46999 .75842 .46665 .75352 .46044 Mtetra
.75352 .46044 .75842 .46665 .76941 .46329 .76455 .45706 Mtetra
.76455 .45706 .76941 .46329 .78044 .45992 .77561 .45366 Mtetra
.77561 .45366 .78044 .45992 .79152 .45654 .78672 .45026 Mtetra
.78672 .45026 .79152 .45654 .80264 .45314 .79787 .44684 Mtetra
.79787 .44684 .80264 .45314 .81381 .44973 .80906 .4434 Mtetra
.80906 .4434 .81381 .44973 .82501 .44631 .8203 .43995 Mtetra
.8203 .43995 .82501 .44631 .83626 .44287 .83158 .43649 Mtetra
.83158 .43649 .83626 .44287 .84756 .43942 .84291 .43302 Mtetra
.84291 .43302 .84756 .43942 .8589 .43596 .85428 .42953 Mtetra
.85428 .42953 .8589 .43596 .87028 .43248 .86569 .42603 Mtetra
.86569 .42603 .87028 .43248 .88171 .42899 .87715 .42251 Mtetra
.87715 .42251 .88171 .42899 .89318 .42549 .88866 .41899 Mtetra
.88866 .41899 .89318 .42549 .90469 .42197 .90021 .41544 Mtetra
.28248 .59781 .28853 .60308 .29783 .60023 .2918 .59493 Mtetra
.2918 .59493 .29783 .60023 .30717 .59737 .30116 .59205 Mtetra
.30116 .59205 .30717 .59737 .31654 .59449 .31055 .58916 Mtetra
.31055 .58916 .31654 .59449 .32594 .59161 .31998 .58625 Mtetra
.31998 .58625 .32594 .59161 .33538 .58871 .32943 .58334 Mtetra
.32943 .58334 .33538 .58871 .34485 .58581 .33892 .58041 Mtetra
.33892 .58041 .34485 .58581 .35435 .58289 .34845 .57748 Mtetra
.34845 .57748 .35435 .58289 .36389 .57996 .35801 .57453 Mtetra
.35801 .57453 .36389 .57996 .37347 .57703 .3676 .57158 Mtetra
.3676 .57158 .37347 .57703 .38307 .57408 .37723 .56861 Mtetra
.37723 .56861 .38307 .57408 .39272 .57112 .3869 .56563 Mtetra
.3869 .56563 .39272 .57112 .40239 .56815 .3966 .56264 Mtetra
.3966 .56264 .40239 .56815 .41211 .56517 .40633 .55965 Mtetra
.40633 .55965 .41211 .56517 .42185 .56218 .4161 .55664 Mtetra
.4161 .55664 .42185 .56218 .43163 .55918 .4259 .55361 Mtetra
.4259 .55361 .43163 .55918 .44145 .55617 .43574 .55058 Mtetra
.43574 .55058 .44145 .55617 .45131 .55315 .44562 .54754 Mtetra
.44562 .54754 .45131 .55315 .4612 .55012 .45553 .54449 Mtetra
.45553 .54449 .4612 .55012 .47112 .54707 .46548 .54142 Mtetra
.46548 .54142 .47112 .54707 .48108 .54401 .47547 .53834 Mtetra
.47547 .53834 .48108 .54401 .49108 .54095 .48549 .53526 Mtetra
.48549 .53526 .49108 .54095 .50112 .53787 .49555 .53216 Mtetra
.49555 .53216 .50112 .53787 .51119 .53478 .50564 .52905 Mtetra
.50564 .52905 .51119 .53478 .5213 .53168 .51578 .52592 Mtetra
.51578 .52592 .5213 .53168 .53144 .52857 .52595 .52279 Mtetra
.52595 .52279 .53144 .52857 .54163 .52544 .53616 .51964 Mtetra
.53616 .51964 .54163 .52544 .55185 .52231 .5464 .51649 Mtetra
.5464 .51649 .55185 .52231 .56211 .51916 .55669 .51332 Mtetra
.55669 .51332 .56211 .51916 .57241 .516 .56701 .51014 Mtetra
.56701 .51014 .57241 .516 .58274 .51283 .57737 .50694 Mtetra
.57737 .50694 .58274 .51283 .59312 .50965 .58777 .50374 Mtetra
.58777 .50374 .59312 .50965 .60353 .50645 .59821 .50052 Mtetra
.59821 .50052 .60353 .50645 .61398 .50324 .60869 .49729 Mtetra
.60869 .49729 .61398 .50324 .62448 .50003 .61921 .49405 Mtetra
.61921 .49405 .62448 .50003 .63501 .4968 .62977 .4908 Mtetra
.62977 .4908 .63501 .4968 .64558 .49355 .64037 .48753 Mtetra
.64037 .48753 .64558 .49355 .65619 .4903 .65101 .48426 Mtetra
.65101 .48426 .65619 .4903 .66684 .48703 .66168 .48097 Mtetra
.66168 .48097 .66684 .48703 .67753 .48375 .6724 .47766 Mtetra
.6724 .47766 .67753 .48375 .68826 .48046 .68316 .47435 Mtetra
.68316 .47435 .68826 .48046 .69904 .47715 .69396 .47102 Mtetra
.69396 .47102 .69904 .47715 .70985 .47384 .70481 .46768 Mtetra
.70481 .46768 .70985 .47384 .72071 .47051 .71569 .46433 Mtetra
.71569 .46433 .72071 .47051 .7316 .46716 .72662 .46096 Mtetra
.72662 .46096 .7316 .46716 .74254 .46381 .73758 .45758 Mtetra
.73758 .45758 .74254 .46381 .75352 .46044 .74859 .45419 Mtetra
.74859 .45419 .75352 .46044 .76455 .45706 .75965 .45078 Mtetra
.75965 .45078 .76455 .45706 .77561 .45366 .77074 .44736 Mtetra
.77074 .44736 .77561 .45366 .78672 .45026 .78188 .44393 Mtetra
.78188 .44393 .78672 .45026 .79787 .44684 .79306 .44049 Mtetra
.79306 .44049 .79787 .44684 .80906 .4434 .80429 .43703 Mtetra
.80429 .43703 .80906 .4434 .8203 .43995 .81556 .43355 Mtetra
.81556 .43355 .8203 .43995 .83158 .43649 .82687 .43007 Mtetra
.82687 .43007 .83158 .43649 .84291 .43302 .83823 .42657 Mtetra
.83823 .42657 .84291 .43302 .85428 .42953 .84963 .42306 Mtetra
.84963 .42306 .85428 .42953 .86569 .42603 .86108 .41953 Mtetra
.86108 .41953 .86569 .42603 .87715 .42251 .87257 .41599 Mtetra
.87257 .41599 .87715 .42251 .88866 .41899 .8841 .41243 Mtetra
.8841 .41243 .88866 .41899 .90021 .41544 .89569 .40886 Mtetra
.27639 .59249 .28248 .59781 .2918 .59493 .28574 .5896 Mtetra
.28574 .5896 .2918 .59493 .30116 .59205 .29511 .5867 Mtetra
.29511 .5867 .30116 .59205 .31055 .58916 .30452 .58379 Mtetra
.30452 .58379 .31055 .58916 .31998 .58625 .31397 .58087 Mtetra
.31397 .58087 .31998 .58625 .32943 .58334 .32345 .57793 Mtetra
.32345 .57793 .32943 .58334 .33892 .58041 .33296 .57499 Mtetra
.33296 .57499 .33892 .58041 .34845 .57748 .34251 .57203 Mtetra
.34251 .57203 .34845 .57748 .35801 .57453 .35209 .56907 Mtetra
.35209 .56907 .35801 .57453 .3676 .57158 .3617 .56609 Mtetra
.3617 .56609 .3676 .57158 .37723 .56861 .37135 .56311 Mtetra
.37135 .56311 .37723 .56861 .3869 .56563 .38104 .56011 Mtetra
.38104 .56011 .3869 .56563 .3966 .56264 .39076 .5571 Mtetra
.39076 .5571 .3966 .56264 .40633 .55965 .40052 .55408 Mtetra
.40052 .55408 .40633 .55965 .4161 .55664 .41031 .55105 Mtetra
.41031 .55105 .4161 .55664 .4259 .55361 .42013 .54801 Mtetra
.42013 .54801 .4259 .55361 .43574 .55058 .43 .54496 Mtetra
.43 .54496 .43574 .55058 .44562 .54754 .4399 .54189 Mtetra
.4399 .54189 .44562 .54754 .45553 .54449 .44983 .53882 Mtetra
.44983 .53882 .45553 .54449 .46548 .54142 .4598 .53573 Mtetra
.4598 .53573 .46548 .54142 .47547 .53834 .46981 .53263 Mtetra
.46981 .53263 .47547 .53834 .48549 .53526 .47986 .52952 Mtetra
.47986 .52952 .48549 .53526 .49555 .53216 .48994 .5264 Mtetra
.48994 .5264 .49555 .53216 .50564 .52905 .50006 .52327 Mtetra
.50006 .52327 .50564 .52905 .51578 .52592 .51022 .52013 Mtetra
.51022 .52013 .51578 .52592 .52595 .52279 .52041 .51697 Mtetra
.52041 .51697 .52595 .52279 .53616 .51964 .53065 .51381 Mtetra
.53065 .51381 .53616 .51964 .5464 .51649 .54092 .51063 Mtetra
.54092 .51063 .5464 .51649 .55669 .51332 .55123 .50744 Mtetra
.55123 .50744 .55669 .51332 .56701 .51014 .56158 .50423 Mtetra
.56158 .50423 .56701 .51014 .57737 .50694 .57197 .50102 Mtetra
.57197 .50102 .57737 .50694 .58777 .50374 .58239 .49779 Mtetra
.58239 .49779 .58777 .50374 .59821 .50052 .59286 .49455 Mtetra
.59286 .49455 .59821 .50052 .60869 .49729 .60336 .4913 Mtetra
.60336 .4913 .60869 .49729 .61921 .49405 .61391 .48804 Mtetra
.61391 .48804 .61921 .49405 .62977 .4908 .62449 .48476 Mtetra
.62449 .48476 .62977 .4908 .64037 .48753 .63512 .48147 Mtetra
.63512 .48147 .64037 .48753 .65101 .48426 .64578 .47817 Mtetra
.64578 .47817 .65101 .48426 .66168 .48097 .65649 .47486 Mtetra
.65649 .47486 .66168 .48097 .6724 .47766 .66724 .47153 Mtetra
.66724 .47153 .6724 .47766 .68316 .47435 .67803 .46819 Mtetra
.67803 .46819 .68316 .47435 .69396 .47102 .68886 .46484 Mtetra
.68886 .46484 .69396 .47102 .70481 .46768 .69973 .46148 Mtetra
.69973 .46148 .70481 .46768 .71569 .46433 .71064 .4581 Mtetra
.71064 .4581 .71569 .46433 .72662 .46096 .72159 .45471 Mtetra
.72159 .45471 .72662 .46096 .73758 .45758 .73259 .45131 Mtetra
.73259 .45131 .73758 .45758 .74859 .45419 .74363 .44789 Mtetra
.74363 .44789 .74859 .45419 .75965 .45078 .75471 .44446 Mtetra
.75471 .44446 .75965 .45078 .77074 .44736 .76584 .44102 Mtetra
.76584 .44102 .77074 .44736 .78188 .44393 .77701 .43756 Mtetra
.77701 .43756 .78188 .44393 .79306 .44049 .78822 .43409 Mtetra
.78822 .43409 .79306 .44049 .80429 .43703 .79948 .43061 Mtetra
.79948 .43061 .80429 .43703 .81556 .43355 .81078 .42711 Mtetra
.81078 .42711 .81556 .43355 .82687 .43007 .82212 .4236 Mtetra
.82212 .4236 .82687 .43007 .83823 .42657 .83351 .42007 Mtetra
.83351 .42007 .83823 .42657 .84963 .42306 .84494 .41653 Mtetra
.84494 .41653 .84963 .42306 .86108 .41953 .85642 .41298 Mtetra
.85642 .41298 .86108 .41953 .87257 .41599 .86795 .40941 Mtetra
.86795 .40941 .87257 .41599 .8841 .41243 .87952 .40583 Mtetra
.87952 .40583 .8841 .41243 .89569 .40886 .89113 .40224 Mtetra
.27027 .58715 .27639 .59249 .28574 .5896 .27963 .58424 Mtetra
.27963 .58424 .28574 .5896 .29511 .5867 .28903 .58132 Mtetra
.28903 .58132 .29511 .5867 .30452 .58379 .29846 .57838 Mtetra
.29846 .57838 .30452 .58379 .31397 .58087 .30792 .57544 Mtetra
.30792 .57544 .31397 .58087 .32345 .57793 .31742 .57249 Mtetra
.31742 .57249 .32345 .57793 .33296 .57499 .32696 .56952 Mtetra
.32696 .56952 .33296 .57499 .34251 .57203 .33652 .56655 Mtetra
.33652 .56655 .34251 .57203 .35209 .56907 .34613 .56357 Mtetra
.34613 .56357 .35209 .56907 .3617 .56609 .35576 .56057 Mtetra
.35576 .56057 .3617 .56609 .37135 .56311 .36543 .55756 Mtetra
.36543 .55756 .37135 .56311 .38104 .56011 .37514 .55455 Mtetra
.37514 .55455 .38104 .56011 .39076 .5571 .38488 .55152 Mtetra
.38488 .55152 .39076 .5571 .40052 .55408 .39466 .54848 Mtetra
.39466 .54848 .40052 .55408 .41031 .55105 .40448 .54543 Mtetra
.40448 .54543 .41031 .55105 .42013 .54801 .41432 .54236 Mtetra
.41432 .54236 .42013 .54801 .43 .54496 .42421 .53929 Mtetra
.42421 .53929 .43 .54496 .4399 .54189 .43413 .53621 Mtetra
.43413 .53621 .4399 .54189 .44983 .53882 .44409 .53311 Mtetra
.44409 .53311 .44983 .53882 .4598 .53573 .45409 .53 Mtetra
.45409 .53 .4598 .53573 .46981 .53263 .46412 .52688 Mtetra
.46412 .52688 .46981 .53263 .47986 .52952 .47419 .52375 Mtetra
.47419 .52375 .47986 .52952 .48994 .5264 .4843 .52061 Mtetra
.4843 .52061 .48994 .5264 .50006 .52327 .49444 .51746 Mtetra
.49444 .51746 .50006 .52327 .51022 .52013 .50462 .51429 Mtetra
.50462 .51429 .51022 .52013 .52041 .51697 .51484 .51112 Mtetra
.51484 .51112 .52041 .51697 .53065 .51381 .5251 .50793 Mtetra
.5251 .50793 .53065 .51381 .54092 .51063 .5354 .50473 Mtetra
.5354 .50473 .54092 .51063 .55123 .50744 .54573 .50151 Mtetra
.54573 .50151 .55123 .50744 .56158 .50423 .55611 .49829 Mtetra
.55611 .49829 .56158 .50423 .57197 .50102 .56652 .49505 Mtetra
.56652 .49505 .57197 .50102 .58239 .49779 .57697 .4918 Mtetra
.57697 .4918 .58239 .49779 .59286 .49455 .58747 .48854 Mtetra
.58747 .48854 .59286 .49455 .60336 .4913 .598 .48527 Mtetra
.598 .48527 .60336 .4913 .61391 .48804 .60857 .48198 Mtetra
.60857 .48198 .61391 .48804 .62449 .48476 .61918 .47868 Mtetra
.61918 .47868 .62449 .48476 .63512 .48147 .62983 .47537 Mtetra
.62983 .47537 .63512 .48147 .64578 .47817 .64053 .47205 Mtetra
.64053 .47205 .64578 .47817 .65649 .47486 .65126 .46871 Mtetra
.65126 .46871 .65649 .47486 .66724 .47153 .66204 .46536 Mtetra
.66204 .46536 .66724 .47153 .67803 .46819 .67285 .462 Mtetra
.67285 .462 .67803 .46819 .68886 .46484 .68371 .45862 Mtetra
.68371 .45862 .68886 .46484 .69973 .46148 .69461 .45523 Mtetra
.69461 .45523 .69973 .46148 .71064 .4581 .70555 .45183 Mtetra
.70555 .45183 .71064 .4581 .72159 .45471 .71654 .44842 Mtetra
.71654 .44842 .72159 .45471 .73259 .45131 .72756 .44499 Mtetra
.72756 .44499 .73259 .45131 .74363 .44789 .73863 .44155 Mtetra
.73863 .44155 .74363 .44789 .75471 .44446 .74974 .43809 Mtetra
.74974 .43809 .75471 .44446 .76584 .44102 .7609 .43462 Mtetra
.7609 .43462 .76584 .44102 .77701 .43756 .7721 .43114 Mtetra
.7721 .43114 .77701 .43756 .78822 .43409 .78334 .42765 Mtetra
.78334 .42765 .78822 .43409 .79948 .43061 .79463 .42414 Mtetra
.79463 .42414 .79948 .43061 .81078 .42711 .80596 .42062 Mtetra
.80596 .42062 .81078 .42711 .82212 .4236 .81734 .41708 Mtetra
.81734 .41708 .82212 .4236 .83351 .42007 .82876 .41353 Mtetra
.82876 .41353 .83351 .42007 .84494 .41653 .84023 .40996 Mtetra
.84023 .40996 .84494 .41653 .85642 .41298 .85174 .40639 Mtetra
.85174 .40639 .85642 .41298 .86795 .40941 .8633 .40279 Mtetra
.8633 .40279 .86795 .40941 .87952 .40583 .8749 .39919 Mtetra
.8749 .39919 .87952 .40583 .89113 .40224 .88655 .39556 Mtetra
.2641 .58177 .27027 .58715 .27963 .58424 .27348 .57884 Mtetra
.27348 .57884 .27963 .58424 .28903 .58132 .2829 .57589 Mtetra
.2829 .57589 .28903 .58132 .29846 .57838 .29235 .57294 Mtetra
.29235 .57294 .29846 .57838 .30792 .57544 .30184 .56998 Mtetra
.30184 .56998 .30792 .57544 .31742 .57249 .31136 .56701 Mtetra
.31136 .56701 .31742 .57249 .32696 .56952 .32091 .56403 Mtetra
.32091 .56403 .32696 .56952 .33652 .56655 .3305 .56103 Mtetra
.3305 .56103 .33652 .56655 .34613 .56357 .34012 .55803 Mtetra
.34012 .55803 .34613 .56357 .35576 .56057 .34978 .55501 Mtetra
.34978 .55501 .35576 .56057 .36543 .55756 .35947 .55198 Mtetra
.35947 .55198 .36543 .55756 .37514 .55455 .3692 .54895 Mtetra
.3692 .54895 .37514 .55455 .38488 .55152 .37897 .5459 Mtetra
.37897 .5459 .38488 .55152 .39466 .54848 .38877 .54284 Mtetra
.38877 .54284 .39466 .54848 .40448 .54543 .3986 .53976 Mtetra
.3986 .53976 .40448 .54543 .41432 .54236 .40848 .53668 Mtetra
.40848 .53668 .41432 .54236 .42421 .53929 .41839 .53359 Mtetra
.41839 .53359 .42421 .53929 .43413 .53621 .42833 .53048 Mtetra
.42833 .53048 .43413 .53621 .44409 .53311 .43831 .52737 Mtetra
.43831 .52737 .44409 .53311 .45409 .53 .44833 .52424 Mtetra
.44833 .52424 .45409 .53 .46412 .52688 .45839 .5211 Mtetra
.45839 .5211 .46412 .52688 .47419 .52375 .46848 .51794 Mtetra
.46848 .51794 .47419 .52375 .4843 .52061 .47861 .51478 Mtetra
.47861 .51478 .4843 .52061 .49444 .51746 .48878 .51161 Mtetra
.48878 .51161 .49444 .51746 .50462 .51429 .49899 .50842 Mtetra
.49899 .50842 .50462 .51429 .51484 .51112 .50923 .50522 Mtetra
.50923 .50522 .51484 .51112 .5251 .50793 .51952 .50201 Mtetra
.51952 .50201 .5251 .50793 .5354 .50473 .52984 .49879 Mtetra
.52984 .49879 .5354 .50473 .54573 .50151 .5402 .49555 Mtetra
.5402 .49555 .54573 .50151 .55611 .49829 .5506 .4923 Mtetra
.5506 .4923 .55611 .49829 .56652 .49505 .56104 .48904 Mtetra
.56104 .48904 .56652 .49505 .57697 .4918 .57152 .48577 Mtetra
.57152 .48577 .57697 .4918 .58747 .48854 .58203 .48249 Mtetra
.58203 .48249 .58747 .48854 .598 .48527 .59259 .47919 Mtetra
.59259 .47919 .598 .48527 .60857 .48198 .60319 .47588 Mtetra
.60319 .47588 .60857 .48198 .61918 .47868 .61383 .47256 Mtetra
.61383 .47256 .61918 .47868 .62983 .47537 .62451 .46922 Mtetra
.62451 .46922 .62983 .47537 .64053 .47205 .63523 .46587 Mtetra
.63523 .46587 .64053 .47205 .65126 .46871 .64599 .46251 Mtetra
.64599 .46251 .65126 .46871 .66204 .46536 .6568 .45914 Mtetra
.6568 .45914 .66204 .46536 .67285 .462 .66764 .45575 Mtetra
.66764 .45575 .67285 .462 .68371 .45862 .67853 .45235 Mtetra
.67853 .45235 .68371 .45862 .69461 .45523 .68946 .44894 Mtetra
.68946 .44894 .69461 .45523 .70555 .45183 .70043 .44552 Mtetra
.70043 .44552 .70555 .45183 .71654 .44842 .71144 .44208 Mtetra
.71144 .44208 .71654 .44842 .72756 .44499 .7225 .43862 Mtetra
.7225 .43862 .72756 .44499 .73863 .44155 .7336 .43516 Mtetra
.7336 .43516 .73863 .44155 .74974 .43809 .74474 .43168 Mtetra
.74474 .43168 .74974 .43809 .7609 .43462 .75593 .42819 Mtetra
.75593 .42819 .7609 .43462 .7721 .43114 .76716 .42468 Mtetra
.76716 .42468 .7721 .43114 .78334 .42765 .77843 .42116 Mtetra
.77843 .42116 .78334 .42765 .79463 .42414 .78975 .41762 Mtetra
.78975 .41762 .79463 .42414 .80596 .42062 .80111 .41408 Mtetra
.80111 .41408 .80596 .42062 .81734 .41708 .81252 .41051 Mtetra
.81252 .41051 .81734 .41708 .82876 .41353 .82397 .40694 Mtetra
.82397 .40694 .82876 .41353 .84023 .40996 .83547 .40335 Mtetra
.83547 .40335 .84023 .40996 .85174 .40639 .84702 .39974 Mtetra
.84702 .39974 .85174 .40639 .8633 .40279 .85861 .39612 Mtetra
.85861 .39612 .8633 .40279 .8749 .39919 .87025 .39249 Mtetra
.87025 .39249 .8749 .39919 .88655 .39556 .88193 .38884 Mtetra
.25789 .57635 .2641 .58177 .27348 .57884 .2673 .5734 Mtetra
.2673 .5734 .27348 .57884 .2829 .57589 .27673 .57044 Mtetra
.27673 .57044 .2829 .57589 .29235 .57294 .2862 .56747 Mtetra
.2862 .56747 .29235 .57294 .30184 .56998 .29571 .56449 Mtetra
.29571 .56449 .30184 .56998 .31136 .56701 .30525 .56149 Mtetra
.30525 .56149 .31136 .56701 .32091 .56403 .31483 .55849 Mtetra
.31483 .55849 .32091 .56403 .3305 .56103 .32444 .55547 Mtetra
.32444 .55547 .3305 .56103 .34012 .55803 .33408 .55245 Mtetra
.33408 .55245 .34012 .55803 .34978 .55501 .34376 .54941 Mtetra
.34376 .54941 .34978 .55501 .35947 .55198 .35348 .54637 Mtetra
.35348 .54637 .35947 .55198 .3692 .54895 .36323 .54331 Mtetra
.36323 .54331 .3692 .54895 .37897 .5459 .37301 .54024 Mtetra
.37301 .54024 .37897 .5459 .38877 .54284 .38284 .53716 Mtetra
.38284 .53716 .38877 .54284 .3986 .53976 .39269 .53406 Mtetra
.39269 .53406 .3986 .53976 .40848 .53668 .40259 .53096 Mtetra
.40259 .53096 .40848 .53668 .41839 .53359 .41252 .52785 Mtetra
.41252 .52785 .41839 .53359 .42833 .53048 .42249 .52472 Mtetra
.42249 .52472 .42833 .53048 .43831 .52737 .43249 .52158 Mtetra
.43249 .52158 .43831 .52737 .44833 .52424 .44254 .51843 Mtetra
.44254 .51843 .44833 .52424 .45839 .5211 .45262 .51527 Mtetra
.45262 .51527 .45839 .5211 .46848 .51794 .46273 .5121 Mtetra
.46273 .5121 .46848 .51794 .47861 .51478 .47289 .50891 Mtetra
.47289 .50891 .47861 .51478 .48878 .51161 .48308 .50571 Mtetra
.48308 .50571 .48878 .51161 .49899 .50842 .49331 .5025 Mtetra
.49331 .5025 .49899 .50842 .50923 .50522 .50358 .49928 Mtetra
.50358 .49928 .50923 .50522 .51952 .50201 .51389 .49605 Mtetra
.51389 .49605 .51952 .50201 .52984 .49879 .52424 .4928 Mtetra
.52424 .4928 .52984 .49879 .5402 .49555 .53463 .48955 Mtetra
.53463 .48955 .5402 .49555 .5506 .4923 .54505 .48627 Mtetra
.54505 .48627 .5506 .4923 .56104 .48904 .55552 .48299 Mtetra
.55552 .48299 .56104 .48904 .57152 .48577 .56602 .4797 Mtetra
.56602 .4797 .57152 .48577 .58203 .48249 .57657 .47639 Mtetra
.57657 .47639 .58203 .48249 .59259 .47919 .58715 .47307 Mtetra
.58715 .47307 .59259 .47919 .60319 .47588 .59778 .46974 Mtetra
.59778 .46974 .60319 .47588 .61383 .47256 .60844 .46639 Mtetra
.60844 .46639 .61383 .47256 .62451 .46922 .61915 .46303 Mtetra
.61915 .46303 .62451 .46922 .63523 .46587 .6299 .45966 Mtetra
.6299 .45966 .63523 .46587 .64599 .46251 .64069 .45628 Mtetra
.64069 .45628 .64599 .46251 .6568 .45914 .65152 .45288 Mtetra
.65152 .45288 .6568 .45914 .66764 .45575 .66239 .44947 Mtetra
.66239 .44947 .66764 .45575 .67853 .45235 .67331 .44604 Mtetra
.67331 .44604 .67853 .45235 .68946 .44894 .68427 .44261 Mtetra
.68427 .44261 .68946 .44894 .70043 .44552 .69527 .43916 Mtetra
.69527 .43916 .70043 .44552 .71144 .44208 .70631 .43569 Mtetra
.70631 .43569 .71144 .44208 .7225 .43862 .7174 .43222 Mtetra
.7174 .43222 .7225 .43862 .7336 .43516 .72853 .42872 Mtetra
.72853 .42872 .7336 .43516 .74474 .43168 .7397 .42522 Mtetra
.7397 .42522 .74474 .43168 .75593 .42819 .75092 .4217 Mtetra
.75092 .4217 .75593 .42819 .76716 .42468 .76218 .41817 Mtetra
.76218 .41817 .76716 .42468 .77843 .42116 .77348 .41462 Mtetra
.77348 .41462 .77843 .42116 .78975 .41762 .78483 .41106 Mtetra
.78483 .41106 .78975 .41762 .80111 .41408 .79623 .40749 Mtetra
.79623 .40749 .80111 .41408 .81252 .41051 .80767 .4039 Mtetra
.80767 .4039 .81252 .41051 .82397 .40694 .81915 .4003 Mtetra
.81915 .4003 .82397 .40694 .83547 .40335 .83069 .39668 Mtetra
.83069 .39668 .83547 .40335 .84702 .39974 .84226 .39305 Mtetra
.84226 .39305 .84702 .39974 .85861 .39612 .85389 .3894 Mtetra
.85389 .3894 .85861 .39612 .87025 .39249 .86556 .38574 Mtetra
.86556 .38574 .87025 .39249 .88193 .38884 .87727 .38207 Mtetra
.25164 .57089 .25789 .57635 .2673 .5734 .26107 .56792 Mtetra
.26107 .56792 .2673 .5734 .27673 .57044 .27052 .56494 Mtetra
.27052 .56494 .27673 .57044 .2862 .56747 .28002 .56195 Mtetra
.28002 .56195 .2862 .56747 .29571 .56449 .28954 .55895 Mtetra
.28954 .55895 .29571 .56449 .30525 .56149 .2991 .55594 Mtetra
.2991 .55594 .30525 .56149 .31483 .55849 .3087 .55292 Mtetra
.3087 .55292 .31483 .55849 .32444 .55547 .31833 .54988 Mtetra
.31833 .54988 .32444 .55547 .33408 .55245 .328 .54684 Mtetra
.328 .54684 .33408 .55245 .34376 .54941 .3377 .54378 Mtetra
.3377 .54378 .34376 .54941 .35348 .54637 .34744 .54071 Mtetra
.34744 .54071 .35348 .54637 .36323 .54331 .35721 .53763 Mtetra
.35721 .53763 .36323 .54331 .37301 .54024 .36702 .53454 Mtetra
.36702 .53454 .37301 .54024 .38284 .53716 .37686 .53144 Mtetra
.37686 .53144 .38284 .53716 .39269 .53406 .38674 .52833 Mtetra
.38674 .52833 .39269 .53406 .40259 .53096 .39666 .5252 Mtetra
.39666 .5252 .40259 .53096 .41252 .52785 .40662 .52206 Mtetra
.40662 .52206 .41252 .52785 .42249 .52472 .41661 .51892 Mtetra
.41661 .51892 .42249 .52472 .43249 .52158 .42664 .51576 Mtetra
.42664 .51576 .43249 .52158 .44254 .51843 .4367 .51258 Mtetra
.4367 .51258 .44254 .51843 .45262 .51527 .44681 .5094 Mtetra
.44681 .5094 .45262 .51527 .46273 .5121 .45695 .50621 Mtetra
.45695 .50621 .46273 .5121 .47289 .50891 .46713 .503 Mtetra
.46713 .503 .47289 .50891 .48308 .50571 .47734 .49978 Mtetra
.47734 .49978 .48308 .50571 .49331 .5025 .4876 .49655 Mtetra
.4876 .49655 .49331 .5025 .50358 .49928 .49789 .4933 Mtetra
.49789 .4933 .50358 .49928 .51389 .49605 .50823 .49005 Mtetra
.50823 .49005 .51389 .49605 .52424 .4928 .5186 .48678 Mtetra
.5186 .48678 .52424 .4928 .53463 .48955 .52901 .4835 Mtetra
.52901 .4835 .53463 .48955 .54505 .48627 .53946 .4802 Mtetra
.53946 .4802 .54505 .48627 .55552 .48299 .54996 .4769 Mtetra
.54996 .4769 .55552 .48299 .56602 .4797 .56049 .47358 Mtetra
.56049 .47358 .56602 .4797 .57657 .47639 .57106 .47025 Mtetra
.57106 .47025 .57657 .47639 .58715 .47307 .58167 .46691 Mtetra
.58167 .46691 .58715 .47307 .59778 .46974 .59232 .46355 Mtetra
.59232 .46355 .59778 .46974 .60844 .46639 .60302 .46018 Mtetra
.60302 .46018 .60844 .46639 .61915 .46303 .61375 .4568 Mtetra
.61375 .4568 .61915 .46303 .6299 .45966 .62453 .4534 Mtetra
.62453 .4534 .6299 .45966 .64069 .45628 .63535 .44999 Mtetra
.63535 .44999 .64069 .45628 .65152 .45288 .64621 .44657 Mtetra
.64621 .44657 .65152 .45288 .66239 .44947 .65711 .44314 Mtetra
.65711 .44314 .66239 .44947 .67331 .44604 .66805 .43969 Mtetra
.66805 .43969 .67331 .44604 .68427 .44261 .67904 .43623 Mtetra
.67904 .43623 .68427 .44261 .69527 .43916 .69007 .43275 Mtetra
.69007 .43275 .69527 .43916 .70631 .43569 .70114 .42926 Mtetra
.70114 .42926 .70631 .43569 .7174 .43222 .71226 .42576 Mtetra
.71226 .42576 .7174 .43222 .72853 .42872 .72342 .42224 Mtetra
.72342 .42224 .72853 .42872 .7397 .42522 .73462 .41871 Mtetra
.73462 .41871 .7397 .42522 .75092 .4217 .74587 .41517 Mtetra
.74587 .41517 .75092 .4217 .76218 .41817 .75716 .41161 Mtetra
.75716 .41161 .76218 .41817 .77348 .41462 .7685 .40804 Mtetra
.7685 .40804 .77348 .41462 .78483 .41106 .77988 .40445 Mtetra
.77988 .40445 .78483 .41106 .79623 .40749 .79131 .40085 Mtetra
.79131 .40085 .79623 .40749 .80767 .4039 .80278 .39724 Mtetra
.80278 .39724 .80767 .4039 .81915 .4003 .8143 .39361 Mtetra
.8143 .39361 .81915 .4003 .83069 .39668 .82586 .38996 Mtetra
.82586 .38996 .83069 .39668 .84226 .39305 .83747 .38631 Mtetra
.83747 .38631 .84226 .39305 .85389 .3894 .84913 .38263 Mtetra
.84913 .38263 .85389 .3894 .86556 .38574 .86083 .37895 Mtetra
.86083 .37895 .86556 .38574 .87727 .38207 .87259 .37524 Mtetra
.24535 .5654 .25164 .57089 .26107 .56792 .2548 .56241 Mtetra
.2548 .56241 .26107 .56792 .27052 .56494 .26427 .55941 Mtetra
.26427 .55941 .27052 .56494 .28002 .56195 .27379 .5564 Mtetra
.27379 .5564 .28002 .56195 .28954 .55895 .28333 .55338 Mtetra
.28333 .55338 .28954 .55895 .2991 .55594 .29292 .55035 Mtetra
.29292 .55035 .2991 .55594 .3087 .55292 .30253 .5473 Mtetra
.30253 .5473 .3087 .55292 .31833 .54988 .31218 .54425 Mtetra
.31218 .54425 .31833 .54988 .328 .54684 .32187 .54118 Mtetra
.32187 .54118 .328 .54684 .3377 .54378 .3316 .53811 Mtetra
.3316 .53811 .3377 .54378 .34744 .54071 .34135 .53502 Mtetra
.34135 .53502 .34744 .54071 .35721 .53763 .35115 .53192 Mtetra
.35115 .53192 .35721 .53763 .36702 .53454 .36098 .52881 Mtetra
.36098 .52881 .36702 .53454 .37686 .53144 .37085 .52568 Mtetra
.37085 .52568 .37686 .53144 .38674 .52833 .38075 .52255 Mtetra
.38075 .52255 .38674 .52833 .39666 .5252 .39069 .5194 Mtetra
.39069 .5194 .39666 .5252 .40662 .52206 .40067 .51624 Mtetra
.40067 .51624 .40662 .52206 .41661 .51892 .41068 .51307 Mtetra
.41068 .51307 .41661 .51892 .42664 .51576 .42074 .50989 Mtetra
.42074 .50989 .42664 .51576 .4367 .51258 .43083 .5067 Mtetra
.43083 .5067 .4367 .51258 .44681 .5094 .44095 .50349 Mtetra
.44095 .50349 .44681 .5094 .45695 .50621 .45112 .50027 Mtetra
.45112 .50027 .45695 .50621 .46713 .503 .46132 .49704 Mtetra
.46132 .49704 .46713 .503 .47734 .49978 .47157 .4938 Mtetra
.47157 .4938 .47734 .49978 .4876 .49655 .48185 .49055 Mtetra
.48185 .49055 .4876 .49655 .49789 .4933 .49217 .48728 Mtetra
.49217 .48728 .49789 .4933 .50823 .49005 .50253 .484 Mtetra
.50253 .484 .50823 .49005 .5186 .48678 .51292 .48071 Mtetra
.51292 .48071 .5186 .48678 .52901 .4835 .52336 .47741 Mtetra
.52336 .47741 .52901 .4835 .53946 .4802 .53384 .47409 Mtetra
.53384 .47409 .53946 .4802 .54996 .4769 .54436 .47076 Mtetra
.54436 .47076 .54996 .4769 .56049 .47358 .55491 .46742 Mtetra
.55491 .46742 .56049 .47358 .57106 .47025 .56551 .46407 Mtetra
.56551 .46407 .57106 .47025 .58167 .46691 .57615 .4607 Mtetra
.57615 .4607 .58167 .46691 .59232 .46355 .58683 .45732 Mtetra
.58683 .45732 .59232 .46355 .60302 .46018 .59755 .45393 Mtetra
.59755 .45393 .60302 .46018 .61375 .4568 .60832 .45052 Mtetra
.60832 .45052 .61375 .4568 .62453 .4534 .61912 .4471 Mtetra
.61912 .4471 .62453 .4534 .63535 .44999 .62997 .44367 Mtetra
.62997 .44367 .63535 .44999 .64621 .44657 .64085 .44022 Mtetra
.64085 .44022 .64621 .44657 .65711 .44314 .65178 .43676 Mtetra
.65178 .43676 .65711 .44314 .66805 .43969 .66276 .43329 Mtetra
.66276 .43329 .66805 .43969 .67904 .43623 .67377 .4298 Mtetra
.67377 .4298 .67904 .43623 .69007 .43275 .68483 .4263 Mtetra
.68483 .4263 .69007 .43275 .70114 .42926 .69594 .42279 Mtetra
.69594 .42279 .70114 .42926 .71226 .42576 .70708 .41926 Mtetra
.70708 .41926 .71226 .42576 .72342 .42224 .71827 .41572 Mtetra
.71827 .41572 .72342 .42224 .73462 .41871 .72951 .41216 Mtetra
.72951 .41216 .73462 .41871 .74587 .41517 .74079 .40859 Mtetra
.74079 .40859 .74587 .41517 .75716 .41161 .75211 .40501 Mtetra
.75211 .40501 .75716 .41161 .7685 .40804 .76348 .40141 Mtetra
.76348 .40141 .7685 .40804 .77988 .40445 .77489 .39779 Mtetra
.77489 .39779 .77988 .40445 .79131 .40085 .78635 .39417 Mtetra
.78635 .39417 .79131 .40085 .80278 .39724 .79786 .39053 Mtetra
.79786 .39053 .80278 .39724 .8143 .39361 .80941 .38687 Mtetra
.80941 .38687 .8143 .39361 .82586 .38996 .821 .3832 Mtetra
.821 .3832 .82586 .38996 .83747 .38631 .83265 .37951 Mtetra
.83265 .37951 .83747 .38631 .84913 .38263 .84434 .37581 Mtetra
.84434 .37581 .84913 .38263 .86083 .37895 .85608 .3721 Mtetra
.85608 .3721 .86083 .37895 .87259 .37524 .86786 .36837 Mtetra
.23902 .55988 .24535 .5654 .2548 .56241 .24848 .55687 Mtetra
.24848 .55687 .2548 .56241 .26427 .55941 .25798 .55385 Mtetra
.25798 .55385 .26427 .55941 .27379 .5564 .26751 .55082 Mtetra
.26751 .55082 .27379 .5564 .28333 .55338 .27708 .54777 Mtetra
.27708 .54777 .28333 .55338 .29292 .55035 .28669 .54472 Mtetra
.28669 .54472 .29292 .55035 .30253 .5473 .29632 .54166 Mtetra
.29632 .54166 .30253 .5473 .31218 .54425 .306 .53858 Mtetra
.306 .53858 .31218 .54425 .32187 .54118 .31571 .53549 Mtetra
.31571 .53549 .32187 .54118 .3316 .53811 .32545 .53239 Mtetra
.32545 .53239 .3316 .53811 .34135 .53502 .33523 .52928 Mtetra
.33523 .52928 .34135 .53502 .35115 .53192 .34505 .52616 Mtetra
.34505 .52616 .35115 .53192 .36098 .52881 .3549 .52303 Mtetra
.3549 .52303 .36098 .52881 .37085 .52568 .36479 .51989 Mtetra
.36479 .51989 .37085 .52568 .38075 .52255 .37472 .51673 Mtetra
.37472 .51673 .38075 .52255 .39069 .5194 .38468 .51356 Mtetra
.38468 .51356 .39069 .5194 .40067 .51624 .39468 .51038 Mtetra
.39468 .51038 .40067 .51624 .41068 .51307 .40472 .50719 Mtetra
.40472 .50719 .41068 .51307 .42074 .50989 .4148 .50399 Mtetra
.4148 .50399 .42074 .50989 .43083 .5067 .42491 .50077 Mtetra
.42491 .50077 .43083 .5067 .44095 .50349 .43506 .49754 Mtetra
.43506 .49754 .44095 .50349 .45112 .50027 .44525 .4943 Mtetra
.44525 .4943 .45112 .50027 .46132 .49704 .45548 .49105 Mtetra
.45548 .49105 .46132 .49704 .47157 .4938 .46575 .48779 Mtetra
.46575 .48779 .47157 .4938 .48185 .49055 .47605 .48451 Mtetra
.47605 .48451 .48185 .49055 .49217 .48728 .4864 .48122 Mtetra
.4864 .48122 .49217 .48728 .50253 .484 .49678 .47792 Mtetra
.49678 .47792 .50253 .484 .51292 .48071 .50721 .4746 Mtetra
.50721 .4746 .51292 .48071 .52336 .47741 .51767 .47128 Mtetra
.51767 .47128 .52336 .47741 .53384 .47409 .52817 .46794 Mtetra
.52817 .46794 .53384 .47409 .54436 .47076 .53872 .46458 Mtetra
.53872 .46458 .54436 .47076 .55491 .46742 .5493 .46122 Mtetra
.5493 .46122 .55491 .46742 .56551 .46407 .55993 .45784 Mtetra
.55993 .45784 .56551 .46407 .57615 .4607 .57059 .45445 Mtetra
.57059 .45445 .57615 .4607 .58683 .45732 .5813 .45104 Mtetra
.5813 .45104 .58683 .45732 .59755 .45393 .59205 .44763 Mtetra
.59205 .44763 .59755 .45393 .60832 .45052 .60284 .4442 Mtetra
.60284 .4442 .60832 .45052 .61912 .4471 .61367 .44075 Mtetra
.61367 .44075 .61912 .4471 .62997 .44367 .62455 .43729 Mtetra
.62455 .43729 .62997 .44367 .64085 .44022 .63546 .43382 Mtetra
.63546 .43382 .64085 .44022 .65178 .43676 .64642 .43034 Mtetra
.64642 .43034 .65178 .43676 .66276 .43329 .65743 .42684 Mtetra
.65743 .42684 .66276 .43329 .67377 .4298 .66847 .42333 Mtetra
.66847 .42333 .67377 .4298 .68483 .4263 .67956 .4198 Mtetra
.67956 .4198 .68483 .4263 .69594 .42279 .69069 .41626 Mtetra
.69069 .41626 .69594 .42279 .70708 .41926 .70187 .41271 Mtetra
.70187 .41271 .70708 .41926 .71827 .41572 .71309 .40914 Mtetra
.71309 .40914 .71827 .41572 .72951 .41216 .72436 .40556 Mtetra
.72436 .40556 .72951 .41216 .74079 .40859 .73566 .40196 Mtetra
.73566 .40196 .74079 .40859 .75211 .40501 .74702 .39835 Mtetra
.74702 .39835 .75211 .40501 .76348 .40141 .75842 .39473 Mtetra
.75842 .39473 .76348 .40141 .77489 .39779 .76987 .39109 Mtetra
.76987 .39109 .77489 .39779 .78635 .39417 .78136 .38743 Mtetra
.78136 .38743 .78635 .39417 .79786 .39053 .79289 .38376 Mtetra
.79289 .38376 .79786 .39053 .80941 .38687 .80448 .38008 Mtetra
.80448 .38008 .80941 .38687 .821 .3832 .81611 .37638 Mtetra
.81611 .37638 .821 .3832 .83265 .37951 .82779 .37267 Mtetra
.82779 .37267 .83265 .37951 .84434 .37581 .83951 .36894 Mtetra
.83951 .36894 .84434 .37581 .85608 .3721 .85128 .3652 Mtetra
.85128 .3652 .85608 .3721 .86786 .36837 .8631 .36144 Mtetra
.23264 .55431 .23902 .55988 .24848 .55687 .24213 .55128 Mtetra
.24213 .55128 .24848 .55687 .25798 .55385 .25165 .54824 Mtetra
.25165 .54824 .25798 .55385 .26751 .55082 .2612 .54519 Mtetra
.2612 .54519 .26751 .55082 .27708 .54777 .27079 .54213 Mtetra
.27079 .54213 .27708 .54777 .28669 .54472 .28041 .53905 Mtetra
.28041 .53905 .28669 .54472 .29632 .54166 .29007 .53597 Mtetra
.29007 .53597 .29632 .54166 .306 .53858 .29977 .53287 Mtetra
.29977 .53287 .306 .53858 .31571 .53549 .3095 .52976 Mtetra
.3095 .52976 .31571 .53549 .32545 .53239 .31926 .52664 Mtetra
.31926 .52664 .32545 .53239 .33523 .52928 .32907 .52351 Mtetra
.32907 .52351 .33523 .52928 .34505 .52616 .33891 .52037 Mtetra
.33891 .52037 .34505 .52616 .3549 .52303 .34878 .51722 Mtetra
.34878 .51722 .3549 .52303 .36479 .51989 .35869 .51405 Mtetra
.35869 .51405 .36479 .51989 .37472 .51673 .36864 .51087 Mtetra
.36864 .51087 .37472 .51673 .38468 .51356 .37863 .50768 Mtetra
.37863 .50768 .38468 .51356 .39468 .51038 .38865 .50448 Mtetra
.38865 .50448 .39468 .51038 .40472 .50719 .39872 .50127 Mtetra
.39872 .50127 .40472 .50719 .4148 .50399 .40882 .49804 Mtetra
.40882 .49804 .4148 .50399 .42491 .50077 .41895 .4948 Mtetra
.41895 .4948 .42491 .50077 .43506 .49754 .42913 .49155 Mtetra
.42913 .49155 .43506 .49754 .44525 .4943 .43934 .48829 Mtetra
.43934 .48829 .44525 .4943 .45548 .49105 .4496 .48501 Mtetra
.4496 .48501 .45548 .49105 .46575 .48779 .45989 .48173 Mtetra
.45989 .48173 .46575 .48779 .47605 .48451 .47022 .47843 Mtetra
.47022 .47843 .47605 .48451 .4864 .48122 .48059 .47511 Mtetra
.48059 .47511 .4864 .48122 .49678 .47792 .491 .47179 Mtetra
.491 .47179 .49678 .47792 .50721 .4746 .50145 .46845 Mtetra
.50145 .46845 .50721 .4746 .51767 .47128 .51194 .4651 Mtetra
.51194 .4651 .51767 .47128 .52817 .46794 .52247 .46174 Mtetra
.52247 .46174 .52817 .46794 .53872 .46458 .53304 .45836 Mtetra
.53304 .45836 .53872 .46458 .5493 .46122 .54365 .45497 Mtetra
.54365 .45497 .5493 .46122 .55993 .45784 .5543 .45157 Mtetra
.5543 .45157 .55993 .45784 .57059 .45445 .565 .44815 Mtetra
.565 .44815 .57059 .45445 .5813 .45104 .57573 .44472 Mtetra
.57573 .44472 .5813 .45104 .59205 .44763 .58651 .44128 Mtetra
.58651 .44128 .59205 .44763 .60284 .4442 .59732 .43783 Mtetra
.59732 .43783 .60284 .4442 .61367 .44075 .60819 .43436 Mtetra
.60819 .43436 .61367 .44075 .62455 .43729 .61909 .43087 Mtetra
.61909 .43087 .62455 .43729 .63546 .43382 .63003 .42738 Mtetra
.63003 .42738 .63546 .43382 .64642 .43034 .64102 .42387 Mtetra
.64102 .42387 .64642 .43034 .65743 .42684 .65205 .42034 Mtetra
.65205 .42034 .65743 .42684 .66847 .42333 .66313 .41681 Mtetra
.66313 .41681 .66847 .42333 .67956 .4198 .67425 .41326 Mtetra
.67425 .41326 .67956 .4198 .69069 .41626 .68541 .40969 Mtetra
.68541 .40969 .69069 .41626 .70187 .41271 .69662 .40611 Mtetra
.69662 .40611 .70187 .41271 .71309 .40914 .70787 .40252 Mtetra
.70787 .40252 .71309 .40914 .72436 .40556 .71917 .39891 Mtetra
.71917 .39891 .72436 .40556 .73566 .40196 .73051 .39529 Mtetra
.73051 .39529 .73566 .40196 .74702 .39835 .74189 .39165 Mtetra
.74189 .39165 .74702 .39835 .75842 .39473 .75332 .388 Mtetra
.75332 .388 .75842 .39473 .76987 .39109 .7648 .38433 Mtetra
.7648 .38433 .76987 .39109 .78136 .38743 .77633 .38065 Mtetra
.77633 .38065 .78136 .38743 .79289 .38376 .7879 .37695 Mtetra
.7879 .37695 .79289 .38376 .80448 .38008 .79951 .37324 Mtetra
.79951 .37324 .80448 .38008 .81611 .37638 .81118 .36952 Mtetra
.81118 .36952 .81611 .37638 .82779 .37267 .82289 .36578 Mtetra
.82289 .36578 .82779 .37267 .83951 .36894 .83465 .36202 Mtetra
.83465 .36202 .83951 .36894 .85128 .3652 .84645 .35825 Mtetra
.84645 .35825 .85128 .3652 .8631 .36144 .85831 .35446 Mtetra
.22623 .54871 .23264 .55431 .24213 .55128 .23573 .54566 Mtetra
.23573 .54566 .24213 .55128 .25165 .54824 .24527 .5426 Mtetra
.24527 .5426 .25165 .54824 .2612 .54519 .25484 .53953 Mtetra
.25484 .53953 .2612 .54519 .27079 .54213 .26445 .53644 Mtetra
.26445 .53644 .27079 .54213 .28041 .53905 .2741 .53335 Mtetra
.2741 .53335 .28041 .53905 .29007 .53597 .28378 .53024 Mtetra
.28378 .53024 .29007 .53597 .29977 .53287 .2935 .52712 Mtetra
.2935 .52712 .29977 .53287 .3095 .52976 .30325 .52399 Mtetra
.30325 .52399 .3095 .52976 .31926 .52664 .31304 .52085 Mtetra
.31304 .52085 .31926 .52664 .32907 .52351 .32286 .5177 Mtetra
.32286 .5177 .32907 .52351 .33891 .52037 .33272 .51454 Mtetra
.33272 .51454 .33891 .52037 .34878 .51722 .34262 .51136 Mtetra
.34262 .51136 .34878 .51722 .35869 .51405 .35256 .50817 Mtetra
.35256 .50817 .35869 .51405 .36864 .51087 .36253 .50497 Mtetra
.36253 .50497 .36864 .51087 .37863 .50768 .37254 .50176 Mtetra
.37254 .50176 .37863 .50768 .38865 .50448 .38258 .49854 Mtetra
.38258 .49854 .38865 .50448 .39872 .50127 .39267 .4953 Mtetra
.39267 .4953 .39872 .50127 .40882 .49804 .40279 .49205 Mtetra
.40279 .49205 .40882 .49804 .41895 .4948 .41295 .48879 Mtetra
.41295 .48879 .41895 .4948 .42913 .49155 .42315 .48552 Mtetra
.42315 .48552 .42913 .49155 .43934 .48829 .43339 .48223 Mtetra
.43339 .48223 .43934 .48829 .4496 .48501 .44367 .47893 Mtetra
.44367 .47893 .4496 .48501 .45989 .48173 .45399 .47562 Mtetra
.45399 .47562 .45989 .48173 .47022 .47843 .46434 .4723 Mtetra
.46434 .4723 .47022 .47843 .48059 .47511 .47474 .46897 Mtetra
.47474 .46897 .48059 .47511 .491 .47179 .48517 .46562 Mtetra
.48517 .46562 .491 .47179 .50145 .46845 .49565 .46226 Mtetra
.49565 .46226 .50145 .46845 .51194 .4651 .50617 .45888 Mtetra
.50617 .45888 .51194 .4651 .52247 .46174 .51672 .45549 Mtetra
.51672 .45549 .52247 .46174 .53304 .45836 .52732 .45209 Mtetra
.52732 .45209 .53304 .45836 .54365 .45497 .53796 .44868 Mtetra
.53796 .44868 .54365 .45497 .5543 .45157 .54864 .44525 Mtetra
.54864 .44525 .5543 .45157 .565 .44815 .55936 .44181 Mtetra
.55936 .44181 .565 .44815 .57573 .44472 .57012 .43836 Mtetra
.57012 .43836 .57573 .44472 .58651 .44128 .58092 .43489 Mtetra
.58092 .43489 .58651 .44128 .59732 .43783 .59177 .43141 Mtetra
.59177 .43141 .59732 .43783 .60819 .43436 .60266 .42792 Mtetra
.60266 .42792 .60819 .43436 .61909 .43087 .61359 .42441 Mtetra
.61359 .42441 .61909 .43087 .63003 .42738 .62456 .42089 Mtetra
.62456 .42089 .63003 .42738 .64102 .42387 .63558 .41735 Mtetra
.63558 .41735 .64102 .42387 .65205 .42034 .64664 .4138 Mtetra
.64664 .4138 .65205 .42034 .66313 .41681 .65775 .41024 Mtetra
.65775 .41024 .66313 .41681 .67425 .41326 .6689 .40666 Mtetra
.6689 .40666 .67425 .41326 .68541 .40969 .68009 .40307 Mtetra
.68009 .40307 .68541 .40969 .69662 .40611 .69133 .39946 Mtetra
.69133 .39946 .69662 .40611 .70787 .40252 .70261 .39584 Mtetra
.70261 .39584 .70787 .40252 .71917 .39891 .71394 .39221 Mtetra
.71394 .39221 .71917 .39891 .73051 .39529 .72531 .38856 Mtetra
.72531 .38856 .73051 .39529 .74189 .39165 .73673 .38489 Mtetra
.73673 .38489 .74189 .39165 .75332 .388 .74819 .38122 Mtetra
.74819 .38122 .75332 .388 .7648 .38433 .7597 .37752 Mtetra
.7597 .37752 .7648 .38433 .77633 .38065 .77126 .37381 Mtetra
.77126 .37381 .77633 .38065 .7879 .37695 .78286 .37009 Mtetra
.78286 .37009 .7879 .37695 .79951 .37324 .79451 .36635 Mtetra
.79451 .36635 .79951 .37324 .81118 .36952 .80621 .3626 Mtetra
.80621 .3626 .81118 .36952 .82289 .36578 .81795 .35883 Mtetra
.81795 .35883 .82289 .36578 .83465 .36202 .82975 .35505 Mtetra
.82975 .35505 .83465 .36202 .84645 .35825 .84159 .35125 Mtetra
.84159 .35125 .84645 .35825 .85831 .35446 .85348 .34743 Mtetra
.21976 .54307 .22623 .54871 .23573 .54566 .22929 .54 Mtetra
.22929 .54 .23573 .54566 .24527 .5426 .23885 .53693 Mtetra
.656 .752 .92 r
.23885 .53693 .24527 .5426 .25484 .53953 .24844 .53383 Mtetra
.24844 .53383 .25484 .53953 .26445 .53644 .25807 .53073 Mtetra
.25807 .53073 .26445 .53644 .2741 .53335 .26774 .52761 Mtetra
.26774 .52761 .2741 .53335 .28378 .53024 .27744 .52448 Mtetra
.27744 .52448 .28378 .53024 .2935 .52712 .28718 .52134 Mtetra
.28718 .52134 .2935 .52712 .30325 .52399 .29695 .51819 Mtetra
.29695 .51819 .30325 .52399 .31304 .52085 .30676 .51503 Mtetra
.656 .751 .92 r
.30676 .51503 .31304 .52085 .32286 .5177 .31661 .51185 Mtetra
.31661 .51185 .32286 .5177 .33272 .51454 .3265 .50867 Mtetra
.3265 .50867 .33272 .51454 .34262 .51136 .33642 .50547 Mtetra
.33642 .50547 .34262 .51136 .35256 .50817 .34637 .50226 Mtetra
.34637 .50226 .35256 .50817 .36253 .50497 .35637 .49903 Mtetra
.35637 .49903 .36253 .50497 .37254 .50176 .3664 .4958 Mtetra
.3664 .4958 .37254 .50176 .38258 .49854 .37647 .49255 Mtetra
.37647 .49255 .38258 .49854 .39267 .4953 .38658 .48929 Mtetra
.38658 .48929 .39267 .4953 .40279 .49205 .39673 .48602 Mtetra
.39673 .48602 .40279 .49205 .41295 .48879 .40691 .48274 Mtetra
.40691 .48274 .41295 .48879 .42315 .48552 .41714 .47944 Mtetra
.41714 .47944 .42315 .48552 .43339 .48223 .4274 .47613 Mtetra
.4274 .47613 .43339 .48223 .44367 .47893 .4377 .47281 Mtetra
.4377 .47281 .44367 .47893 .45399 .47562 .44805 .46948 Mtetra
.44805 .46948 .45399 .47562 .46434 .4723 .45843 .46613 Mtetra
.45843 .46613 .46434 .4723 .47474 .46897 .46885 .46277 Mtetra
.46885 .46277 .47474 .46897 .48517 .46562 .47931 .4594 Mtetra
.47931 .4594 .48517 .46562 .49565 .46226 .48981 .45602 Mtetra
.48981 .45602 .49565 .46226 .50617 .45888 .50035 .45262 Mtetra
.50035 .45262 .50617 .45888 .51672 .45549 .51093 .44921 Mtetra
.51093 .44921 .51672 .45549 .52732 .45209 .52156 .44578 Mtetra
.52156 .44578 .52732 .45209 .53796 .44868 .53222 .44234 Mtetra
.53222 .44234 .53796 .44868 .54864 .44525 .54293 .43889 Mtetra
.54293 .43889 .54864 .44525 .55936 .44181 .55368 .43543 Mtetra
.55368 .43543 .55936 .44181 .57012 .43836 .56447 .43195 Mtetra
.56447 .43195 .57012 .43836 .58092 .43489 .5753 .42846 Mtetra
.5753 .42846 .58092 .43489 .59177 .43141 .58617 .42495 Mtetra
.58617 .42495 .59177 .43141 .60266 .42792 .59709 .42143 Mtetra
.59709 .42143 .60266 .42792 .61359 .42441 .60805 .4179 Mtetra
.60805 .4179 .61359 .42441 .62456 .42089 .61906 .41435 Mtetra
.61906 .41435 .62456 .42089 .63558 .41735 .6301 .41079 Mtetra
.6301 .41079 .63558 .41735 .64664 .4138 .64119 .40721 Mtetra
.64119 .40721 .64664 .4138 .65775 .41024 .65233 .40362 Mtetra
.65233 .40362 .65775 .41024 .6689 .40666 .66351 .40002 Mtetra
.66351 .40002 .6689 .40666 .68009 .40307 .67473 .3964 Mtetra
.67473 .3964 .68009 .40307 .69133 .39946 .686 .39277 Mtetra
.686 .39277 .69133 .39946 .70261 .39584 .69731 .38912 Mtetra
.69731 .38912 .70261 .39584 .71394 .39221 .70867 .38546 Mtetra
.70867 .38546 .71394 .39221 .72531 .38856 .72007 .38178 Mtetra
.72007 .38178 .72531 .38856 .73673 .38489 .73152 .37809 Mtetra
.73152 .37809 .73673 .38489 .74819 .38122 .74302 .37439 Mtetra
.74302 .37439 .74819 .38122 .7597 .37752 .75456 .37067 Mtetra
.75456 .37067 .7597 .37752 .77126 .37381 .76615 .36693 Mtetra
.656 .752 .92 r
.76615 .36693 .77126 .37381 .78286 .37009 .77779 .36318 Mtetra
.77779 .36318 .78286 .37009 .79451 .36635 .78947 .35942 Mtetra
.78947 .35942 .79451 .36635 .80621 .3626 .8012 .35564 Mtetra
.8012 .35564 .80621 .3626 .81795 .35883 .81298 .35184 Mtetra
.81298 .35184 .81795 .35883 .82975 .35505 .82481 .34803 Mtetra
.82481 .34803 .82975 .35505 .84159 .35125 .83668 .3442 Mtetra
.83668 .3442 .84159 .35125 .85348 .34743 .84861 .34035 Mtetra
.655 .751 .92 r
.21326 .53739 .21976 .54307 .22929 .54 .2228 .53431 Mtetra
.655 .752 .921 r
.2228 .53431 .22929 .54 .23885 .53693 .23238 .53122 Mtetra
.656 .752 .921 r
.23238 .53122 .23885 .53693 .24844 .53383 .242 .52811 Mtetra
.242 .52811 .24844 .53383 .25807 .53073 .25165 .52498 Mtetra
.25165 .52498 .25807 .53073 .26774 .52761 .26134 .52184 Mtetra
.26134 .52184 .26774 .52761 .27744 .52448 .27106 .51869 Mtetra
.656 .752 .92 r
.27106 .51869 .27744 .52448 .28718 .52134 .28082 .51552 Mtetra
.28082 .51552 .28718 .52134 .29695 .51819 .29062 .51235 Mtetra
.29062 .51235 .29695 .51819 .30676 .51503 .30045 .50916 Mtetra
.656 .751 .92 r
.30045 .50916 .30676 .51503 .31661 .51185 .31032 .50596 Mtetra
.31032 .50596 .31661 .51185 .3265 .50867 .32023 .50275 Mtetra
.32023 .50275 .3265 .50867 .33642 .50547 .33017 .49953 Mtetra
.33017 .49953 .33642 .50547 .34637 .50226 .34015 .49629 Mtetra
.34015 .49629 .34637 .50226 .35637 .49903 .35017 .49305 Mtetra
.35017 .49305 .35637 .49903 .3664 .4958 .36022 .48979 Mtetra
.36022 .48979 .3664 .4958 .37647 .49255 .37032 .48652 Mtetra
.37032 .48652 .37647 .49255 .38658 .48929 .38045 .48324 Mtetra
.38045 .48324 .38658 .48929 .39673 .48602 .39062 .47995 Mtetra
.39062 .47995 .39673 .48602 .40691 .48274 .40083 .47664 Mtetra
.40083 .47664 .40691 .48274 .41714 .47944 .41108 .47332 Mtetra
.41108 .47332 .41714 .47944 .4274 .47613 .42137 .46999 Mtetra
.42137 .46999 .4274 .47613 .4377 .47281 .43169 .46665 Mtetra
.43169 .46665 .4377 .47281 .44805 .46948 .44206 .46329 Mtetra
.44206 .46329 .44805 .46948 .45843 .46613 .45247 .45992 Mtetra
.45247 .45992 .45843 .46613 .46885 .46277 .46291 .45654 Mtetra
.46291 .45654 .46885 .46277 .47931 .4594 .4734 .45314 Mtetra
.4734 .45314 .47931 .4594 .48981 .45602 .48393 .44973 Mtetra
.48393 .44973 .48981 .45602 .50035 .45262 .4945 .44631 Mtetra
.4945 .44631 .50035 .45262 .51093 .44921 .50511 .44287 Mtetra
.50511 .44287 .51093 .44921 .52156 .44578 .51576 .43942 Mtetra
.51576 .43942 .52156 .44578 .53222 .44234 .52645 .43596 Mtetra
.52645 .43596 .53222 .44234 .54293 .43889 .53718 .43248 Mtetra
.53718 .43248 .54293 .43889 .55368 .43543 .54796 .42899 Mtetra
.54796 .42899 .55368 .43543 .56447 .43195 .55878 .42549 Mtetra
.55878 .42549 .56447 .43195 .5753 .42846 .56964 .42197 Mtetra
.56964 .42197 .5753 .42846 .58617 .42495 .58054 .41844 Mtetra
.58054 .41844 .58617 .42495 .59709 .42143 .59149 .41489 Mtetra
.59149 .41489 .59709 .42143 .60805 .4179 .60247 .41134 Mtetra
.60247 .41134 .60805 .4179 .61906 .41435 .61351 .40776 Mtetra
.61351 .40776 .61906 .41435 .6301 .41079 .62458 .40417 Mtetra
.62458 .40417 .6301 .41079 .64119 .40721 .6357 .40057 Mtetra
.6357 .40057 .64119 .40721 .65233 .40362 .64687 .39696 Mtetra
.64687 .39696 .65233 .40362 .66351 .40002 .65808 .39333 Mtetra
.65808 .39333 .66351 .40002 .67473 .3964 .66933 .38968 Mtetra
.66933 .38968 .67473 .3964 .686 .39277 .68063 .38602 Mtetra
.68063 .38602 .686 .39277 .69731 .38912 .69197 .38235 Mtetra
.69197 .38235 .69731 .38912 .70867 .38546 .70336 .37866 Mtetra
.70336 .37866 .70867 .38546 .72007 .38178 .7148 .37496 Mtetra
.7148 .37496 .72007 .38178 .73152 .37809 .72628 .37124 Mtetra
.72628 .37124 .73152 .37809 .74302 .37439 .73781 .36751 Mtetra
.73781 .36751 .74302 .37439 .75456 .37067 .74939 .36376 Mtetra
.74939 .36376 .75456 .37067 .76615 .36693 .76101 .36 Mtetra
.656 .752 .92 r
.76101 .36 .76615 .36693 .77779 .36318 .77268 .35623 Mtetra
.656 .752 .921 r
.77268 .35623 .77779 .36318 .78947 .35942 .7844 .35244 Mtetra
.7844 .35244 .78947 .35942 .8012 .35564 .79616 .34863 Mtetra
.79616 .34863 .8012 .35564 .81298 .35184 .80797 .3448 Mtetra
.80797 .3448 .81298 .35184 .82481 .34803 .81984 .34096 Mtetra
.656 .752 .92 r
.81984 .34096 .82481 .34803 .83668 .3442 .83175 .33709 Mtetra
.83175 .33709 .83668 .3442 .84861 .34035 .8437 .33321 Mtetra
.655 .751 .921 r
.20671 .53168 .21326 .53739 .2228 .53431 .21627 .5286 Mtetra
.655 .752 .921 r
.21627 .5286 .2228 .53431 .23238 .53122 .22587 .52549 Mtetra
.22587 .52549 .23238 .53122 .242 .52811 .23551 .52237 Mtetra
.655 .753 .922 r
.23551 .52237 .242 .52811 .25165 .52498 .24518 .51923 Mtetra
.656 .753 .922 r
.24518 .51923 .25165 .52498 .26134 .52184 .25489 .51607 Mtetra
.25489 .51607 .26134 .52184 .27106 .51869 .26463 .51289 Mtetra
.656 .753 .921 r
.26463 .51289 .27106 .51869 .28082 .51552 .27442 .5097 Mtetra
.27442 .5097 .28082 .51552 .29062 .51235 .28423 .5065 Mtetra
.28423 .5065 .29062 .51235 .30045 .50916 .29409 .50328 Mtetra
.29409 .50328 .30045 .50916 .31032 .50596 .30398 .50005 Mtetra
.656 .752 .921 r
.30398 .50005 .31032 .50596 .32023 .50275 .31391 .49682 Mtetra
.31391 .49682 .32023 .50275 .33017 .49953 .32388 .49357 Mtetra
.32388 .49357 .33017 .49953 .34015 .49629 .33388 .49031 Mtetra
.33388 .49031 .34015 .49629 .35017 .49305 .34392 .48704 Mtetra
.34392 .48704 .35017 .49305 .36022 .48979 .354 .48376 Mtetra
.656 .752 .92 r
.354 .48376 .36022 .48979 .37032 .48652 .36412 .48046 Mtetra
.36412 .48046 .37032 .48652 .38045 .48324 .37428 .47716 Mtetra
.37428 .47716 .38045 .48324 .39062 .47995 .38447 .47384 Mtetra
.38447 .47384 .39062 .47995 .40083 .47664 .3947 .47051 Mtetra
.3947 .47051 .40083 .47664 .41108 .47332 .40498 .46716 Mtetra
.656 .751 .92 r
.40498 .46716 .41108 .47332 .42137 .46999 .41529 .46381 Mtetra
.41529 .46381 .42137 .46999 .43169 .46665 .42564 .46044 Mtetra
.42564 .46044 .43169 .46665 .44206 .46329 .43603 .45706 Mtetra
.43603 .45706 .44206 .46329 .45247 .45992 .44647 .45366 Mtetra
.44647 .45366 .45247 .45992 .46291 .45654 .45694 .45026 Mtetra
.45694 .45026 .46291 .45654 .4734 .45314 .46745 .44684 Mtetra
.46745 .44684 .4734 .45314 .48393 .44973 .47801 .4434 Mtetra
.47801 .4434 .48393 .44973 .4945 .44631 .4886 .43995 Mtetra
.4886 .43995 .4945 .44631 .50511 .44287 .49924 .43649 Mtetra
.49924 .43649 .50511 .44287 .51576 .43942 .50991 .43302 Mtetra
.50991 .43302 .51576 .43942 .52645 .43596 .52063 .42953 Mtetra
.52063 .42953 .52645 .43596 .53718 .43248 .53139 .42603 Mtetra
.53139 .42603 .53718 .43248 .54796 .42899 .5422 .42251 Mtetra
.5422 .42251 .54796 .42899 .55878 .42549 .55304 .41899 Mtetra
.55304 .41899 .55878 .42549 .56964 .42197 .56393 .41544 Mtetra
.56393 .41544 .56964 .42197 .58054 .41844 .57486 .41189 Mtetra
.57486 .41189 .58054 .41844 .59149 .41489 .58584 .40831 Mtetra
.58584 .40831 .59149 .41489 .60247 .41134 .59686 .40473 Mtetra
.59686 .40473 .60247 .41134 .61351 .40776 .60792 .40113 Mtetra
.60792 .40113 .61351 .40776 .62458 .40417 .61902 .39752 Mtetra
.61902 .39752 .62458 .40417 .6357 .40057 .63017 .39389 Mtetra
.656 .752 .92 r
.63017 .39389 .6357 .40057 .64687 .39696 .64137 .39025 Mtetra
.64137 .39025 .64687 .39696 .65808 .39333 .65261 .38659 Mtetra
.65261 .38659 .65808 .39333 .66933 .38968 .66389 .38292 Mtetra
.656 .752 .921 r
.66389 .38292 .66933 .38968 .68063 .38602 .67522 .37924 Mtetra
.67522 .37924 .68063 .38602 .69197 .38235 .6866 .37554 Mtetra
.6866 .37554 .69197 .38235 .70336 .37866 .69802 .37183 Mtetra
.69802 .37183 .70336 .37866 .7148 .37496 .70949 .3681 Mtetra
.655 .752 .921 r
.70949 .3681 .7148 .37496 .72628 .37124 .721 .36436 Mtetra
.721 .36436 .72628 .37124 .73781 .36751 .73257 .36061 Mtetra
.73257 .36061 .73781 .36751 .74939 .36376 .74417 .35684 Mtetra
.655 .753 .921 r
.74417 .35684 .74939 .36376 .76101 .36 .75583 .35306 Mtetra
.655 .753 .922 r
.75583 .35306 .76101 .36 .77268 .35623 .76753 .34926 Mtetra
.76753 .34926 .77268 .35623 .7844 .35244 .77929 .34545 Mtetra
.656 .753 .922 r
.77929 .34545 .7844 .35244 .79616 .34863 .79108 .34161 Mtetra
.79108 .34161 .79616 .34863 .80797 .3448 .80293 .33775 Mtetra
.656 .753 .921 r
.80293 .33775 .80797 .3448 .81984 .34096 .81483 .33386 Mtetra
.657 .753 .921 r
.81483 .33386 .81984 .34096 .83175 .33709 .82677 .32995 Mtetra
.657 .753 .92 r
.82677 .32995 .83175 .33709 .8437 .33321 .83876 .32602 Mtetra
.653 .751 .922 r
.20012 .52592 .20671 .53168 .21627 .5286 .20969 .52287 Mtetra
.653 .752 .923 r
.20969 .52287 .21627 .5286 .22587 .52549 .21931 .51978 Mtetra
.654 .754 .923 r
.21931 .51978 .22587 .52549 .23551 .52237 .22896 .51667 Mtetra
.655 .755 .924 r
.22896 .51667 .23551 .52237 .24518 .51923 .23866 .51352 Mtetra
.655 .756 .924 r
.23866 .51352 .24518 .51923 .25489 .51607 .24839 .51035 Mtetra
.656 .756 .924 r
.24839 .51035 .25489 .51607 .26463 .51289 .25815 .50714 Mtetra
.657 .756 .923 r
.25815 .50714 .26463 .51289 .27442 .5097 .26796 .50391 Mtetra
.26796 .50391 .27442 .5097 .28423 .5065 .2778 .50067 Mtetra
.657 .755 .922 r
.2778 .50067 .28423 .5065 .29409 .50328 .28768 .49741 Mtetra
.28768 .49741 .29409 .50328 .30398 .50005 .2976 .49414 Mtetra
.657 .754 .921 r
.2976 .49414 .30398 .50005 .31391 .49682 .30755 .49087 Mtetra
.657 .753 .921 r
.30755 .49087 .31391 .49682 .32388 .49357 .31754 .48758 Mtetra
.656 .753 .921 r
.31754 .48758 .32388 .49357 .33388 .49031 .32757 .48429 Mtetra
.656 .752 .921 r
.32757 .48429 .33388 .49031 .34392 .48704 .33763 .48098 Mtetra
.656 .752 .92 r
.33763 .48098 .34392 .48704 .354 .48376 .34774 .47767 Mtetra
.34774 .47767 .354 .48376 .36412 .48046 .35788 .47435 Mtetra
.656 .751 .92 r
.35788 .47435 .36412 .48046 .37428 .47716 .36806 .47102 Mtetra
.36806 .47102 .37428 .47716 .38447 .47384 .37828 .46767 Mtetra
.37828 .46767 .38447 .47384 .3947 .47051 .38854 .46432 Mtetra
.38854 .46432 .3947 .47051 .40498 .46716 .39883 .46095 Mtetra
.39883 .46095 .40498 .46716 .41529 .46381 .40917 .45757 Mtetra
.40917 .45757 .41529 .46381 .42564 .46044 .41955 .45418 Mtetra
.41955 .45418 .42564 .46044 .43603 .45706 .42997 .45077 Mtetra
.42997 .45077 .43603 .45706 .44647 .45366 .44042 .44735 Mtetra
.44042 .44735 .44647 .45366 .45694 .45026 .45092 .44392 Mtetra
.45092 .44392 .45694 .45026 .46745 .44684 .46146 .44047 Mtetra
.46146 .44047 .46745 .44684 .47801 .4434 .47204 .43702 Mtetra
.47204 .43702 .47801 .4434 .4886 .43995 .48266 .43354 Mtetra
.48266 .43354 .4886 .43995 .49924 .43649 .49332 .43006 Mtetra
.49332 .43006 .49924 .43649 .50991 .43302 .50403 .42656 Mtetra
.50403 .42656 .50991 .43302 .52063 .42953 .51477 .42305 Mtetra
.51477 .42305 .52063 .42953 .53139 .42603 .52556 .41952 Mtetra
.52556 .41952 .53139 .42603 .5422 .42251 .53639 .41598 Mtetra
.53639 .41598 .5422 .42251 .55304 .41899 .54727 .41242 Mtetra
.54727 .41242 .55304 .41899 .56393 .41544 .55818 .40885 Mtetra
.55818 .40885 .56393 .41544 .57486 .41189 .56914 .40527 Mtetra
.56914 .40527 .57486 .41189 .58584 .40831 .58015 .40167 Mtetra
.58015 .40167 .58584 .40831 .59686 .40473 .59119 .39806 Mtetra
.59119 .39806 .59686 .40473 .60792 .40113 .60229 .39444 Mtetra
.60229 .39444 .60792 .40113 .61902 .39752 .61342 .3908 Mtetra
.61342 .3908 .61902 .39752 .63017 .39389 .6246 .38715 Mtetra
.6246 .38715 .63017 .39389 .64137 .39025 .63583 .38348 Mtetra
.63583 .38348 .64137 .39025 .65261 .38659 .6471 .3798 Mtetra
.6471 .3798 .65261 .38659 .66389 .38292 .65841 .37611 Mtetra
.655 .751 .92 r
.65841 .37611 .66389 .38292 .67522 .37924 .66978 .3724 Mtetra
.655 .752 .921 r
.66978 .3724 .67522 .37924 .6866 .37554 .68118 .36869 Mtetra
.68118 .36869 .6866 .37554 .69802 .37183 .69264 .36496 Mtetra
.69264 .36496 .69802 .37183 .70949 .3681 .70414 .36122 Mtetra
.655 .753 .922 r
.70414 .36122 .70949 .3681 .721 .36436 .71569 .35747 Mtetra
.71569 .35747 .721 .36436 .73257 .36061 .72728 .35371 Mtetra
.655 .754 .923 r
.72728 .35371 .73257 .36061 .74417 .35684 .73893 .34993 Mtetra
.73893 .34993 .74417 .35684 .75583 .35306 .75062 .34614 Mtetra
.655 .755 .924 r
.75062 .34614 .75583 .35306 .76753 .34926 .76236 .34233 Mtetra
.655 .756 .924 r
.76236 .34233 .76753 .34926 .77929 .34545 .77414 .33849 Mtetra
.656 .756 .924 r
.77414 .33849 .77929 .34545 .79108 .34161 .78598 .33462 Mtetra
.657 .756 .923 r
.78598 .33462 .79108 .34161 .80293 .33775 .79786 .33071 Mtetra
.79786 .33071 .80293 .33775 .81483 .33386 .80978 .32676 Mtetra
.658 .755 .922 r
.80978 .32676 .81483 .33386 .82677 .32995 .82176 .32278 Mtetra
.659 .754 .921 r
.82176 .32278 .82677 .32995 .83876 .32602 .83378 .31877 Mtetra
.648 .75 .923 r
.19348 .52013 .20012 .52592 .20969 .52287 .20307 .51714 Mtetra
.65 .753 .925 r
.20307 .51714 .20969 .52287 .21931 .51978 .2127 .51412 Mtetra
.651 .756 .927 r
.2127 .51412 .21931 .51978 .22896 .51667 .22236 .51105 Mtetra
.652 .759 .928 r
.22236 .51105 .22896 .51667 .23866 .51352 .23207 .50794 Mtetra
.654 .761 .928 r
.23207 .50794 .23866 .51352 .24839 .51035 .24182 .50477 Mtetra
.655 .763 .929 r
.24182 .50477 .24839 .51035 .25815 .50714 .25161 .50155 Mtetra
.656 .763 .928 r
.25161 .50155 .25815 .50714 .26796 .50391 .26144 .4983 Mtetra
.657 .763 .928 r
.26144 .4983 .26796 .50391 .2778 .50067 .27131 .49501 Mtetra
.658 .763 .927 r
.27131 .49501 .2778 .50067 .28768 .49741 .28121 .49171 Mtetra
.658 .762 .927 r
.28121 .49171 .28768 .49741 .2976 .49414 .29115 .48838 Mtetra
.658 .761 .926 r
.29115 .48838 .2976 .49414 .30755 .49087 .30113 .48505 Mtetra
.658 .76 .925 r
.30113 .48505 .30755 .49087 .31754 .48758 .31115 .48171 Mtetra
.657 .758 .924 r
.31115 .48171 .31754 .48758 .32757 .48429 .3212 .47836 Mtetra
.657 .757 .924 r
.3212 .47836 .32757 .48429 .33763 .48098 .33129 .47501 Mtetra
.657 .756 .923 r
.33129 .47501 .33763 .48098 .34774 .47767 .34142 .47165 Mtetra
.34142 .47165 .34774 .47767 .35788 .47435 .35159 .46829 Mtetra
.657 .755 .922 r
.35159 .46829 .35788 .47435 .36806 .47102 .36179 .46492 Mtetra
.656 .754 .922 r
.36179 .46492 .36806 .47102 .37828 .46767 .37204 .46154 Mtetra
.37204 .46154 .37828 .46767 .38854 .46432 .38232 .45815 Mtetra
.656 .753 .922 r
.38232 .45815 .38854 .46432 .39883 .46095 .39264 .45475 Mtetra
.656 .753 .921 r
.39264 .45475 .39883 .46095 .40917 .45757 .40301 .45134 Mtetra
.40301 .45134 .40917 .45757 .41955 .45418 .41341 .44791 Mtetra
.41341 .44791 .41955 .45418 .42997 .45077 .42385 .44448 Mtetra
.656 .752 .921 r
.42385 .44448 .42997 .45077 .44042 .44735 .43433 .44103 Mtetra
.43433 .44103 .44042 .44735 .45092 .44392 .44486 .43757 Mtetra
.44486 .43757 .45092 .44392 .46146 .44047 .45542 .4341 Mtetra
.45542 .4341 .46146 .44047 .47204 .43702 .46603 .43062 Mtetra
.46603 .43062 .47204 .43702 .48266 .43354 .47668 .42712 Mtetra
.47668 .42712 .48266 .43354 .49332 .43006 .48737 .42361 Mtetra
.48737 .42361 .49332 .43006 .50403 .42656 .4981 .42008 Mtetra
.4981 .42008 .50403 .42656 .51477 .42305 .50887 .41654 Mtetra
.50887 .41654 .51477 .42305 .52556 .41952 .51969 .41299 Mtetra
.51969 .41299 .52556 .41952 .53639 .41598 .53055 .40943 Mtetra
.53055 .40943 .53639 .41598 .54727 .41242 .54145 .40585 Mtetra
.54145 .40585 .54727 .41242 .55818 .40885 .5524 .40226 Mtetra
.5524 .40226 .55818 .40885 .56914 .40527 .56338 .39865 Mtetra
.56338 .39865 .56914 .40527 .58015 .40167 .57442 .39503 Mtetra
.57442 .39503 .58015 .40167 .59119 .39806 .58549 .3914 Mtetra
.655 .753 .921 r
.58549 .3914 .59119 .39806 .60229 .39444 .59661 .38775 Mtetra
.655 .753 .922 r
.59661 .38775 .60229 .39444 .61342 .3908 .60778 .3841 Mtetra
.60778 .3841 .61342 .3908 .6246 .38715 .61899 .38043 Mtetra
.61899 .38043 .6246 .38715 .63583 .38348 .63025 .37675 Mtetra
.655 .754 .923 r
.63025 .37675 .63583 .38348 .6471 .3798 .64155 .37305 Mtetra
.64155 .37305 .6471 .3798 .65841 .37611 .6529 .36935 Mtetra
.654 .755 .924 r
.6529 .36935 .65841 .37611 .66978 .3724 .66429 .36565 Mtetra
.66429 .36565 .66978 .3724 .68118 .36869 .67573 .36193 Mtetra
.654 .756 .925 r
.67573 .36193 .68118 .36869 .69264 .36496 .68722 .3582 Mtetra
.653 .757 .926 r
.68722 .3582 .69264 .36496 .70414 .36122 .69876 .35447 Mtetra
.653 .758 .927 r
.69876 .35447 .70414 .36122 .71569 .35747 .71034 .35073 Mtetra
.653 .759 .927 r
.71034 .35073 .71569 .35747 .72728 .35371 .72197 .34697 Mtetra
.653 .76 .928 r
.72197 .34697 .72728 .35371 .73893 .34993 .73365 .34319 Mtetra
.653 .761 .929 r
.73365 .34319 .73893 .34993 .75062 .34614 .74538 .33939 Mtetra
.654 .762 .929 r
.74538 .33939 .75062 .34614 .76236 .34233 .75715 .33556 Mtetra
.655 .763 .929 r
.75715 .33556 .76236 .34233 .77414 .33849 .76897 .33167 Mtetra
.657 .763 .928 r
.76897 .33167 .77414 .33849 .78598 .33462 .78084 .32774 Mtetra
.658 .763 .927 r
.78084 .32774 .78598 .33462 .79786 .33071 .79275 .32375 Mtetra
.66 .762 .925 r
.79275 .32375 .79786 .33071 .80978 .32676 .80471 .3197 Mtetra
.661 .76 .923 r
.80471 .3197 .80978 .32676 .82176 .32278 .81671 .31561 Mtetra
.662 .757 .921 r
.81671 .31561 .82176 .32278 .83378 .31877 .82876 .31146 Mtetra
.64 .748 .926 r
.18679 .51429 .19348 .52013 .20307 .51714 .19638 .51147 Mtetra
.642 .754 .931 r
.19638 .51147 .20307 .51714 .2127 .51412 .20602 .5086 Mtetra
.643 .761 .934 r
.20602 .5086 .2127 .51412 .22236 .51105 .21569 .50566 Mtetra
.645 .767 .937 r
.21569 .50566 .22236 .51105 .23207 .50794 .22541 .50265 Mtetra
.649 .772 .939 r
.22541 .50265 .23207 .50794 .24182 .50477 .23518 .49955 Mtetra
.652 .776 .94 r
.23518 .49955 .24182 .50477 .25161 .50155 .24499 .49637 Mtetra
.654 .779 .94 r
.24499 .49637 .25161 .50155 .26144 .4983 .25484 .49311 Mtetra
.657 .78 .939 r
.25484 .49311 .26144 .4983 .27131 .49501 .26473 .48978 Mtetra
.659 .78 .938 r
.26473 .48978 .27131 .49501 .28121 .49171 .27466 .48641 Mtetra
.66 .778 .937 r
.27466 .48641 .28121 .49171 .29115 .48838 .28463 .483 Mtetra
.66 .776 .935 r
.28463 .483 .29115 .48838 .30113 .48505 .29464 .47957 Mtetra
.66 .774 .933 r
.29464 .47957 .30113 .48505 .31115 .48171 .30469 .47612 Mtetra
.66 .771 .931 r
.30469 .47612 .31115 .48171 .3212 .47836 .31477 .47268 Mtetra
.66 .768 .929 r
.31477 .47268 .3212 .47836 .33129 .47501 .32489 .46923 Mtetra
.659 .765 .928 r
.32489 .46923 .33129 .47501 .34142 .47165 .33505 .46578 Mtetra
.659 .763 .927 r
.33505 .46578 .34142 .47165 .35159 .46829 .34524 .46233 Mtetra
.658 .76 .925 r
.34524 .46233 .35159 .46829 .36179 .46492 .35548 .45889 Mtetra
.658 .759 .924 r
.35548 .45889 .36179 .46492 .37204 .46154 .36575 .45545 Mtetra
.657 .757 .923 r
.36575 .45545 .37204 .46154 .38232 .45815 .37606 .452 Mtetra
.657 .756 .923 r
.37606 .452 .38232 .45815 .39264 .45475 .38641 .44855 Mtetra
.657 .755 .922 r
.38641 .44855 .39264 .45475 .40301 .45134 .3968 .44509 Mtetra
.657 .754 .922 r
.3968 .44509 .40301 .45134 .41341 .44791 .40722 .44162 Mtetra
.656 .753 .921 r
.40722 .44162 .41341 .44791 .42385 .44448 .41769 .43815 Mtetra
.41769 .43815 .42385 .44448 .43433 .44103 .4282 .43467 Mtetra
.656 .752 .921 r
.4282 .43467 .43433 .44103 .44486 .43757 .43875 .43118 Mtetra
.43875 .43118 .44486 .43757 .45542 .4341 .44934 .42767 Mtetra
.44934 .42767 .45542 .4341 .46603 .43062 .45998 .42416 Mtetra
.656 .752 .92 r
.45998 .42416 .46603 .43062 .47668 .42712 .47065 .42063 Mtetra
.47065 .42063 .47668 .42712 .48737 .42361 .48137 .4171 Mtetra
.48137 .4171 .48737 .42361 .4981 .42008 .49213 .41355 Mtetra
.49213 .41355 .4981 .42008 .50887 .41654 .50293 .40998 Mtetra
.656 .752 .921 r
.50293 .40998 .50887 .41654 .51969 .41299 .51377 .40641 Mtetra
.51377 .40641 .51969 .41299 .53055 .40943 .52466 .40282 Mtetra
.655 .752 .921 r
.52466 .40282 .53055 .40943 .54145 .40585 .53559 .39922 Mtetra
.53559 .39922 .54145 .40585 .5524 .40226 .54656 .39561 Mtetra
.54656 .39561 .5524 .40226 .56338 .39865 .55758 .39199 Mtetra
.55758 .39199 .56338 .39865 .57442 .39503 .56864 .38836 Mtetra
.655 .753 .922 r
.56864 .38836 .57442 .39503 .58549 .3914 .57975 .38471 Mtetra
.57975 .38471 .58549 .3914 .59661 .38775 .5909 .38106 Mtetra
.654 .754 .923 r
.5909 .38106 .59661 .38775 .60778 .3841 .6021 .37741 Mtetra
.654 .755 .924 r
.6021 .37741 .60778 .3841 .61899 .38043 .61334 .37375 Mtetra
.653 .756 .925 r
.61334 .37375 .61899 .38043 .63025 .37675 .62463 .37008 Mtetra
.653 .757 .926 r
.62463 .37008 .63025 .37675 .64155 .37305 .63597 .36641 Mtetra
.652 .758 .927 r
.63597 .36641 .64155 .37305 .6529 .36935 .64735 .36274 Mtetra
.651 .76 .929 r
.64735 .36274 .6529 .36935 .66429 .36565 .65878 .35907 Mtetra
.651 .762 .931 r
.65878 .35907 .66429 .36565 .67573 .36193 .67025 .3554 Mtetra
.65 .765 .933 r
.67025 .3554 .67573 .36193 .68722 .3582 .68178 .35173 Mtetra
.649 .767 .935 r
.68178 .35173 .68722 .3582 .69876 .35447 .69336 .34805 Mtetra
.649 .77 .937 r
.69336 .34805 .69876 .35447 .71034 .35073 .70498 .34436 Mtetra
.649 .773 .939 r
.70498 .34436 .71034 .35073 .72197 .34697 .71665 .34064 Mtetra
.65 .775 .94 r
.71665 .34064 .72197 .34697 .73365 .34319 .72837 .33689 Mtetra
.651 .778 .941 r
.72837 .33689 .73365 .34319 .74538 .33939 .74013 .33307 Mtetra
.653 .779 .941 r
.74013 .33307 .74538 .33939 .75715 .33556 .75194 .3292 Mtetra
.656 .78 .94 r
.75194 .3292 .75715 .33556 .76897 .33167 .7638 .32523 Mtetra
.659 .779 .937 r
.7638 .32523 .76897 .33167 .78084 .32774 .77569 .32117 Mtetra
.663 .777 .934 r
.77569 .32117 .78084 .32774 .79275 .32375 .78763 .31701 Mtetra
.665 .773 .93 r
.78763 .31701 .79275 .32375 .80471 .3197 .79961 .31278 Mtetra
.667 .769 .926 r
.79961 .31278 .80471 .3197 .81671 .31561 .81164 .30847 Mtetra
.669 .763 .921 r
.81164 .30847 .81671 .31561 .82876 .31146 .82371 .3041 Mtetra
.628 .744 .931 r
.18006 .50842 .18679 .51429 .19638 .51147 .18965 .50583 Mtetra
.629 .754 .937 r
.18965 .50583 .19638 .51147 .20602 .5086 .19928 .50319 Mtetra
.631 .763 .942 r
.19928 .50319 .20602 .5086 .21569 .50566 .20895 .50047 Mtetra
.634 .773 .947 r
.20895 .50047 .21569 .50566 .22541 .50265 .21867 .49766 Mtetra
.638 .782 .95 r
.21867 .49766 .22541 .50265 .23518 .49955 .22845 .49472 Mtetra
.642 .79 .953 r
.22845 .49472 .23518 .49955 .24499 .49637 .23827 .49166 Mtetra
.647 .797 .954 r
.23827 .49166 .24499 .49637 .25484 .49311 .24814 .48847 Mtetra
.652 .801 .954 r
.24814 .48847 .25484 .49311 .26473 .48978 .25805 .48516 Mtetra
.656 .803 .954 r
.25805 .48516 .26473 .48978 .27466 .48641 .26801 .48176 Mtetra
.659 .804 .953 r
.26801 .48176 .27466 .48641 .28463 .483 .27801 .47828 Mtetra
.66 .803 .951 r
.27801 .47828 .28463 .483 .29464 .47957 .28805 .47475 Mtetra
.662 .8 .949 r
.28805 .47475 .29464 .47957 .30469 .47612 .29813 .4712 Mtetra
.662 .797 .947 r
.29813 .4712 .30469 .47612 .31477 .47268 .30825 .46763 Mtetra
.662 .793 .944 r
.30825 .46763 .31477 .47268 .32489 .46923 .3184 .46405 Mtetra
.662 .789 .942 r
.3184 .46405 .32489 .46923 .33505 .46578 .32859 .46048 Mtetra
.661 .785 .94 r
.32859 .46048 .33505 .46578 .34524 .46233 .33882 .45691 Mtetra
.661 .782 .938 r
.33882 .45691 .34524 .46233 .35548 .45889 .34909 .45336 Mtetra
.66 .778 .936 r
.34909 .45336 .35548 .45889 .36575 .45545 .35939 .44981 Mtetra
.659 .775 .935 r
.35939 .44981 .36575 .45545 .37606 .452 .36973 .44627 Mtetra
.659 .772 .933 r
.36973 .44627 .37606 .452 .38641 .44855 .38011 .44273 Mtetra
.658 .77 .932 r
.38011 .44273 .38641 .44855 .3968 .44509 .39052 .4392 Mtetra
.658 .768 .931 r
.39052 .4392 .3968 .44509 .40722 .44162 .40098 .43566 Mtetra
.657 .767 .93 r
.40098 .43566 .40722 .44162 .41769 .43815 .41148 .43213 Mtetra
.657 .765 .929 r
.41148 .43213 .41769 .43815 .4282 .43467 .42202 .42859 Mtetra
.657 .764 .929 r
.42202 .42859 .4282 .43467 .43875 .43118 .43259 .42505 Mtetra
.656 .763 .928 r
.43259 .42505 .43875 .43118 .44934 .42767 .44321 .42151 Mtetra
.656 .762 .928 r
.44321 .42151 .44934 .42767 .45998 .42416 .45387 .41795 Mtetra
.45387 .41795 .45998 .42416 .47065 .42063 .46458 .41439 Mtetra
.46458 .41439 .47065 .42063 .48137 .4171 .47532 .41083 Mtetra
.655 .761 .928 r
.47532 .41083 .48137 .4171 .49213 .41355 .48611 .40725 Mtetra
.48611 .40725 .49213 .41355 .50293 .40998 .49694 .40367 Mtetra
.49694 .40367 .50293 .40998 .51377 .40641 .50781 .40007 Mtetra
.655 .762 .928 r
.50781 .40007 .51377 .40641 .52466 .40282 .51873 .39647 Mtetra
.654 .762 .929 r
.51873 .39647 .52466 .40282 .53559 .39922 .52969 .39287 Mtetra
.52969 .39287 .53559 .39922 .54656 .39561 .54069 .38925 Mtetra
.654 .763 .93 r
.54069 .38925 .54656 .39561 .55758 .39199 .55174 .38563 Mtetra
.653 .764 .931 r
.55174 .38563 .55758 .39199 .56864 .38836 .56283 .38201 Mtetra
.652 .765 .932 r
.56283 .38201 .56864 .38836 .57975 .38471 .57397 .37839 Mtetra
.652 .766 .933 r
.57397 .37839 .57975 .38471 .5909 .38106 .58516 .37476 Mtetra
.651 .768 .935 r
.58516 .37476 .5909 .38106 .6021 .37741 .59639 .37114 Mtetra
.65 .77 .936 r
.59639 .37114 .6021 .37741 .61334 .37375 .60766 .36752 Mtetra
.649 .772 .938 r
.60766 .36752 .61334 .37375 .62463 .37008 .61899 .36391 Mtetra
.648 .774 .941 r
.61899 .36391 .62463 .37008 .63597 .36641 .63036 .36031 Mtetra
.646 .777 .943 r
.63036 .36031 .63597 .36641 .64735 .36274 .64178 .35671 Mtetra
.645 .78 .946 r
.64178 .35671 .64735 .36274 .65878 .35907 .65325 .35312 Mtetra
.643 .783 .948 r
.65325 .35312 .65878 .35907 .67025 .3554 .66476 .34953 Mtetra
.642 .787 .951 r
.66476 .34953 .67025 .3554 .68178 .35173 .67633 .34593 Mtetra
.642 .791 .954 r
.67633 .34593 .68178 .35173 .69336 .34805 .68795 .34232 Mtetra
.642 .794 .956 r
.68795 .34232 .69336 .34805 .70498 .34436 .69961 .33867 Mtetra
.643 .797 .957 r
.69961 .33867 .70498 .34436 .71665 .34064 .71133 .33497 Mtetra
.645 .8 .957 r
.71133 .33497 .71665 .34064 .72837 .33689 .72308 .3312 Mtetra
.649 .802 .956 r
.72308 .3312 .72837 .33689 .74013 .33307 .73489 .32732 Mtetra
.654 .802 .954 r
.73489 .32732 .74013 .33307 .75194 .3292 .74673 .32332 Mtetra
.66 .801 .95 r
.74673 .32332 .75194 .3292 .7638 .32523 .75861 .31917 Mtetra
.665 .797 .945 r
.75861 .31917 .7638 .32523 .77569 .32117 .77053 .31489 Mtetra
.67 .792 .94 r
.77053 .31489 .77569 .32117 .78763 .31701 .78249 .31048 Mtetra
.674 .786 .933 r
.78249 .31048 .78763 .31701 .79961 .31278 .79449 .30596 Mtetra
.677 .778 .926 r
.79449 .30596 .79961 .31278 .81164 .30847 .80653 .30135 Mtetra
.678 .769 .92 r
.80653 .30135 .81164 .30847 .82371 .3041 .81861 .29669 Mtetra
.612 .74 .936 r
.17328 .5025 .18006 .50842 .18965 .50583 .18285 .50022 Mtetra
.61 .751 .945 r
.18285 .50022 .18965 .50583 .19928 .50319 .19247 .49792 Mtetra
.61 .764 .953 r
.19247 .49792 .19928 .50319 .20895 .50047 .20213 .49555 Mtetra
.611 .778 .961 r
.20213 .49555 .20895 .50047 .21867 .49766 .21184 .4931 Mtetra
.613 .793 .968 r
.21184 .4931 .21867 .49766 .22845 .49472 .2216 .49052 Mtetra
.616 .809 .974 r
.2216 .49052 .22845 .49472 .23827 .49166 .23142 .48778 Mtetra
.621 .824 .978 r
.23142 .48778 .23827 .49166 .24814 .48847 .24129 .48486 Mtetra
.626 .836 .981 r
.24129 .48486 .24814 .48847 .25805 .48516 .25122 .48176 Mtetra
.632 .847 .982 r
.25122 .48176 .25805 .48516 .26801 .48176 .2612 .47848 Mtetra
.638 .854 .982 r
.2612 .47848 .26801 .48176 .27801 .47828 .27122 .47506 Mtetra
.643 .858 .981 r
.27122 .47506 .27801 .47828 .28805 .47475 .2813 .4715 Mtetra
.648 .858 .98 r
.2813 .4715 .28805 .47475 .29813 .4712 .29141 .46785 Mtetra
.652 .857 .978 r
.29141 .46785 .29813 .4712 .30825 .46763 .30157 .46413 Mtetra
.656 .853 .975 r
.30157 .46413 .30825 .46763 .3184 .46405 .31177 .46038 Mtetra
.658 .847 .973 r
.31177 .46038 .3184 .46405 .32859 .46048 .322 .45661 Mtetra
.66 .841 .97 r
.322 .45661 .32859 .46048 .33882 .45691 .33227 .45283 Mtetra
.661 .834 .966 r
.33227 .45283 .33882 .45691 .34909 .45336 .34257 .44907 Mtetra
.661 .827 .963 r
.34257 .44907 .34909 .45336 .35939 .44981 .35292 .44532 Mtetra
.661 .82 .96 r
.35292 .44532 .35939 .44981 .36973 .44627 .3633 .44159 Mtetra
.661 .813 .957 r
.3633 .44159 .36973 .44627 .38011 .44273 .37371 .43787 Mtetra
.66 .807 .954 r
.37371 .43787 .38011 .44273 .39052 .4392 .38417 .43418 Mtetra
.659 .802 .951 r
.38417 .43418 .39052 .4392 .40098 .43566 .39466 .4305 Mtetra
.659 .797 .949 r
.39466 .4305 .40098 .43566 .41148 .43213 .40519 .42684 Mtetra
.658 .793 .947 r
.40519 .42684 .41148 .43213 .42202 .42859 .41576 .4232 Mtetra
.657 .79 .945 r
.41576 .4232 .42202 .42859 .43259 .42505 .42637 .41956 Mtetra
.657 .787 .944 r
.42637 .41956 .43259 .42505 .44321 .42151 .43702 .41594 Mtetra
.656 .785 .943 r
.43702 .41594 .44321 .42151 .45387 .41795 .44771 .41232 Mtetra
.655 .784 .942 r
.44771 .41232 .45387 .41795 .46458 .41439 .45844 .40871 Mtetra
.654 .782 .942 r
.45844 .40871 .46458 .41439 .47532 .41083 .46922 .4051 Mtetra
.46922 .4051 .47532 .41083 .48611 .40725 .48004 .4015 Mtetra
.653 .781 .942 r
.48004 .4015 .48611 .40725 .49694 .40367 .4909 .3979 Mtetra
.652 .782 .943 r
.4909 .3979 .49694 .40367 .50781 .40007 .5018 .39431 Mtetra
.651 .782 .944 r
.5018 .39431 .50781 .40007 .51873 .39647 .51275 .39072 Mtetra
.65 .783 .945 r
.51275 .39072 .51873 .39647 .52969 .39287 .52374 .38715 Mtetra
.649 .785 .947 r
.52374 .38715 .52969 .39287 .54069 .38925 .53478 .38358 Mtetra
.647 .787 .949 r
.53478 .38358 .54069 .38925 .55174 .38563 .54586 .38002 Mtetra
.645 .79 .951 r
.54586 .38002 .55174 .38563 .56283 .38201 .55699 .37647 Mtetra
.643 .793 .954 r
.55699 .37647 .56283 .38201 .57397 .37839 .56816 .37295 Mtetra
.641 .796 .957 r
.56816 .37295 .57397 .37839 .58516 .37476 .57938 .36943 Mtetra
.638 .801 .961 r
.57938 .36943 .58516 .37476 .59639 .37114 .59065 .36594 Mtetra
.635 .806 .965 r
.59065 .36594 .59639 .37114 .60766 .36752 .60197 .36247 Mtetra
.631 .811 .969 r
.60197 .36247 .60766 .36752 .61899 .36391 .61333 .35901 Mtetra
.628 .817 .973 r
.61333 .35901 .61899 .36391 .63036 .36031 .62475 .35557 Mtetra
.624 .823 .977 r
.62475 .35557 .63036 .36031 .64178 .35671 .63622 .35214 Mtetra
.62 .829 .981 r
.63622 .35214 .64178 .35671 .65325 .35312 .64773 .3487 Mtetra
.617 .835 .984 r
.64773 .3487 .65325 .35312 .66476 .34953 .6593 .34525 Mtetra
.615 .841 .986 r
.6593 .34525 .66476 .34953 .67633 .34593 .67091 .34175 Mtetra
.615 .846 .987 r
.67091 .34175 .67633 .34593 .68795 .34232 .68258 .33819 Mtetra
.618 .85 .987 r
.68258 .33819 .68795 .34232 .69961 .33867 .69429 .33452 Mtetra
.624 .852 .986 r
.69429 .33452 .69961 .33867 .71133 .33497 .70604 .33072 Mtetra
.633 .853 .983 r
.70604 .33072 .71133 .33497 .72308 .3312 .71783 .32677 Mtetra
.645 .851 .979 r
.71783 .32677 .72308 .3312 .73489 .32732 .72966 .32262 Mtetra
.657 .846 .973 r
.72966 .32262 .73489 .32732 .74673 .32332 .74153 .31828 Mtetra
.668 .838 .965 r
.74153 .31828 .74673 .32332 .75861 .31917 .75343 .31375 Mtetra
.677 .827 .955 r
.75343 .31375 .75861 .31917 .77053 .31489 .76537 .30905 Mtetra
.684 .815 .945 r
.76537 .30905 .77053 .31489 .78249 .31048 .77734 .30421 Mtetra
.688 .802 .936 r
.77734 .30421 .78249 .31048 .79449 .30596 .78934 .29927 Mtetra
.69 .789 .926 r
.78934 .29927 .79449 .30596 .80653 .30135 .80139 .29426 Mtetra
.69 .777 .918 r
.80139 .29426 .80653 .30135 .81861 .29669 .81347 .28921 Mtetra
.598 .736 .941 r
.16646 .49655 .17328 .5025 .18285 .50022 .17602 .49451 Mtetra
.594 .744 .948 r
.17602 .49451 .18285 .50022 .19247 .49792 .18562 .4925 Mtetra
.59 .754 .956 r
.18562 .4925 .19247 .49792 .20213 .49555 .19527 .49048 Mtetra
.588 .767 .965 r
.19527 .49048 .20213 .49555 .21184 .4931 .20496 .48841 Mtetra
.586 .782 .973 r
.20496 .48841 .21184 .4931 .2216 .49052 .2147 .48626 Mtetra
.586 .8 .981 r
.2147 .48626 .2216 .49052 .23142 .48778 .2245 .48397 Mtetra
.589 .819 .987 r
.2245 .48397 .23142 .48778 .24129 .48486 .23436 .48149 Mtetra
.592 .838 .991 r
.23436 .48149 .24129 .48486 .25122 .48176 .24428 .47879 Mtetra
.597 .855 .993 r
.24428 .47879 .25122 .48176 .2612 .47848 .25426 .47585 Mtetra
.602 .87 .992 r
.25426 .47585 .2612 .47848 .27122 .47506 .2643 .47267 Mtetra
.609 .881 .991 r
.2643 .47267 .27122 .47506 .2813 .4715 .2744 .46927 Mtetra
.616 .889 .989 r
.2744 .46927 .2813 .4715 .29141 .46785 .28454 .46569 Mtetra
.622 .894 .988 r
.28454 .46569 .29141 .46785 .30157 .46413 .29474 .46196 Mtetra
.628 .895 .987 r
.29474 .46196 .30157 .46413 .31177 .46038 .30497 .45813 Mtetra
.634 .895 .986 r
.30497 .45813 .31177 .46038 .322 .45661 .31525 .45423 Mtetra
.638 .893 .985 r
.31525 .45423 .322 .45661 .33227 .45283 .32556 .4503 Mtetra
.642 .889 .985 r
.32556 .4503 .33227 .45283 .34257 .44907 .33592 .44634 Mtetra
.645 .884 .984 r
.33592 .44634 .34257 .44907 .35292 .44532 .3463 .4424 Mtetra
.647 .878 .983 r
.3463 .4424 .35292 .44532 .3633 .44159 .35673 .43846 Mtetra
.649 .872 .982 r
.35673 .43846 .3633 .44159 .37371 .43787 .36719 .43456 Mtetra
.65 .865 .981 r
.36719 .43456 .37371 .43787 .38417 .43418 .37768 .43068 Mtetra
.65 .859 .979 r
.37768 .43068 .38417 .43418 .39466 .4305 .38822 .42683 Mtetra
.65 .854 .978 r
.38822 .42683 .39466 .4305 .40519 .42684 .39879 .42302 Mtetra
.649 .848 .976 r
.39879 .42302 .40519 .42684 .41576 .4232 .4094 .41923 Mtetra
.649 .844 .975 r
.4094 .41923 .41576 .4232 .42637 .41956 .42005 .41548 Mtetra
.648 .84 .974 r
.42005 .41548 .42637 .41956 .43702 .41594 .43073 .41175 Mtetra
.647 .837 .973 r
.43073 .41175 .43702 .41594 .44771 .41232 .44146 .40805 Mtetra
.645 .834 .973 r
.44146 .40805 .44771 .41232 .45844 .40871 .45223 .40438 Mtetra
.644 .832 .973 r
.45223 .40438 .45844 .40871 .46922 .4051 .46304 .40073 Mtetra
.642 .831 .973 r
.46304 .40073 .46922 .4051 .48004 .4015 .47389 .3971 Mtetra
.64 .83 .974 r
.47389 .3971 .48004 .4015 .4909 .3979 .48479 .3935 Mtetra
.638 .83 .974 r
.48479 .3935 .4909 .3979 .5018 .39431 .49573 .38992 Mtetra
.635 .831 .976 r
.49573 .38992 .5018 .39431 .51275 .39072 .50671 .38637 Mtetra
.632 .832 .977 r
.50671 .38637 .51275 .39072 .52374 .38715 .51774 .38284 Mtetra
.629 .834 .979 r
.51774 .38284 .52374 .38715 .53478 .38358 .52881 .37934 Mtetra
.625 .837 .982 r
.52881 .37934 .53478 .38358 .54586 .38002 .53993 .37588 Mtetra
.62 .84 .984 r
.53993 .37588 .54586 .38002 .55699 .37647 .5511 .37244 Mtetra
.614 .843 .986 r
.5511 .37244 .55699 .37647 .56816 .37295 .56232 .36904 Mtetra
.608 .847 .989 r
.56232 .36904 .56816 .37295 .57938 .36943 .57358 .36566 Mtetra
.602 .851 .991 r
.57358 .36566 .57938 .36943 .59065 .36594 .5849 .36232 Mtetra
.594 .855 .993 r
.5849 .36232 .59065 .36594 .60197 .36247 .59626 .359 Mtetra
.587 .859 .995 r
.59626 .359 .60197 .36247 .61333 .35901 .60767 .3557 Mtetra
.58 .863 .995 r
.60767 .3557 .61333 .35901 .62475 .35557 .61914 .3524 Mtetra
.574 .867 .995 r
.61914 .3524 .62475 .35557 .63622 .35214 .63066 .34909 Mtetra
.57 .871 .995 r
.63066 .34909 .63622 .35214 .64773 .3487 .64222 .34574 Mtetra
.569 .874 .994 r
.64222 .34574 .64773 .3487 .6593 .34525 .65384 .34232 Mtetra
.574 .878 .993 r
.65384 .34232 .6593 .34525 .67091 .34175 .6655 .33879 Mtetra
.583 .881 .992 r
.6655 .33879 .67091 .34175 .68258 .33819 .67721 .3351 Mtetra
.598 .884 .992 r
.67721 .3351 .68258 .33819 .69429 .33452 .68896 .33123 Mtetra
.617 .884 .99 r
.68896 .33123 .69429 .33452 .70604 .33072 .70074 .32712 Mtetra
.638 .881 .986 r
.70074 .32712 .70604 .33072 .71783 .32677 .71256 .32277 Mtetra
.658 .874 .98 r
.71256 .32277 .71783 .32677 .72966 .32262 .72441 .31816 Mtetra
.675 .863 .971 r
.72441 .31816 .72966 .32262 .74153 .31828 .73629 .31331 Mtetra
.688 .849 .96 r
.73629 .31331 .74153 .31828 .75343 .31375 .74821 .30826 Mtetra
.696 .833 .949 r
.74821 .30826 .75343 .31375 .76537 .30905 .76015 .30306 Mtetra
.7 .817 .938 r
.76015 .30306 .76537 .30905 .77734 .30421 .77213 .29776 Mtetra
.701 .802 .928 r
.77213 .29776 .77734 .30421 .78934 .29927 .78414 .29241 Mtetra
.701 .789 .92 r
.78414 .29241 .78934 .29927 .80139 .29426 .7962 .28704 Mtetra
.699 .778 .913 r
.7962 .28704 .80139 .29426 .81347 .28921 .8083 .28168 Mtetra
.6 .736 .94 r
.15958 .49055 .16646 .49655 .17602 .49451 .16917 .48845 Mtetra
.596 .733 .94 r
.16917 .48845 .17602 .49451 .18562 .4925 .17879 .48644 Mtetra
.591 .732 .942 r
.17879 .48644 .18562 .4925 .19527 .49048 .18844 .4845 Mtetra
.586 .734 .946 r
.18844 .4845 .19527 .49048 .20496 .48841 .19813 .48263 Mtetra
.578 .74 .953 r
.19813 .48263 .20496 .48841 .2147 .48626 .20786 .48083 Mtetra
.573 .752 .962 r
.20786 .48083 .2147 .48626 .2245 .48397 .21763 .47903 Mtetra
.568 .77 .974 r
.21763 .47903 .2245 .48397 .23436 .48149 .22746 .47717 Mtetra
.562 .793 .986 r
.22746 .47717 .23436 .48149 .24428 .47879 .23734 .47519 Mtetra
.557 .82 .995 r
.23734 .47519 .24428 .47879 .25426 .47585 .24728 .47299 Mtetra
.548 .846 .998 r
.24728 .47299 .25426 .47585 .2643 .47267 .25729 .47057 Mtetra
.538 .869 .993 r
.25729 .47057 .2643 .47267 .2744 .46927 .26737 .46786 Mtetra
.523 .884 .98 r
.26737 .46786 .2744 .46927 .28454 .46569 .2775 .46489 Mtetra
.508 .892 .96 r
.2775 .46489 .28454 .46569 .29474 .46196 .2877 .46165 Mtetra
.493 .894 .938 r
.2877 .46165 .29474 .46196 .30497 .45813 .29795 .4582 Mtetra
.481 .894 .917 r
.29795 .4582 .30497 .45813 .31525 .45423 .30825 .45455 Mtetra
.472 .892 .902 r
.30825 .45455 .31525 .45423 .32556 .4503 .3186 .45076 Mtetra
.468 .891 .891 r
.3186 .45076 .32556 .4503 .33592 .44634 .329 .44687 Mtetra
.468 .891 .887 r
.329 .44687 .33592 .44634 .3463 .4424 .33943 .4429 Mtetra
.47 .892 .888 r
.33943 .4429 .3463 .4424 .35673 .43846 .34991 .43889 Mtetra
.475 .895 .892 r
.34991 .43889 .35673 .43846 .36719 .43456 .36042 .43486 Mtetra
.482 .897 .899 r
.36042 .43486 .36719 .43456 .37768 .43068 .37097 .43084 Mtetra
.489 .9 .907 r
.37097 .43084 .37768 .43068 .38822 .42683 .38156 .42683 Mtetra
.495 .901 .915 r
.38156 .42683 .38822 .42683 .39879 .42302 .39218 .42286 Mtetra
.501 .903 .923 r
.39218 .42286 .39879 .42302 .4094 .41923 .40284 .41892 Mtetra
.506 .903 .93 r
.40284 .41892 .4094 .41923 .42005 .41548 .41354 .41502 Mtetra
.509 .903 .936 r
.41354 .41502 .42005 .41548 .43073 .41175 .42428 .41117 Mtetra
.51 .902 .941 r
.42428 .41117 .43073 .41175 .44146 .40805 .43506 .40736 Mtetra
.51 .9 .944 r
.43506 .40736 .44146 .40805 .45223 .40438 .44587 .40361 Mtetra
.508 .899 .946 r
.44587 .40361 .45223 .40438 .46304 .40073 .45673 .39991 Mtetra
.504 .896 .947 r
.45673 .39991 .46304 .40073 .47389 .3971 .46763 .39627 Mtetra
.497 .893 .946 r
.46763 .39627 .47389 .3971 .48479 .3935 .47858 .39267 Mtetra
.489 .89 .944 r
.47858 .39267 .48479 .3935 .49573 .38992 .48956 .38913 Mtetra
.479 .886 .94 r
.48956 .38913 .49573 .38992 .50671 .38637 .50059 .38563 Mtetra
.466 .881 .934 r
.50059 .38563 .50671 .38637 .51774 .38284 .51167 .38219 Mtetra
.452 .876 .927 r
.51167 .38219 .51774 .38284 .52881 .37934 .5228 .37879 Mtetra
.436 .869 .917 r
.5228 .37879 .52881 .37934 .53993 .37588 .53397 .37544 Mtetra
.419 .862 .907 r
.53397 .37544 .53993 .37588 .5511 .37244 .54519 .37212 Mtetra
.402 .854 .895 r
.54519 .37212 .5511 .37244 .56232 .36904 .55646 .36884 Mtetra
.386 .846 .883 r
.55646 .36884 .56232 .36904 .57358 .36566 .56778 .36557 Mtetra
.372 .839 .871 r
.56778 .36557 .57358 .36566 .5849 .36232 .57915 .36231 Mtetra
.364 .834 .863 r
.57915 .36231 .5849 .36232 .59626 .359 .59057 .35903 Mtetra
.361 .833 .858 r
.59057 .35903 .59626 .359 .60767 .3557 .60204 .35571 Mtetra
.367 .836 .86 r
.60204 .35571 .60767 .3557 .61914 .3524 .61356 .35231 Mtetra
.384 .846 .87 r
.61356 .35231 .61914 .3524 .63066 .34909 .62513 .3488 Mtetra
.413 .861 .887 r
.62513 .3488 .63066 .34909 .64222 .34574 .63674 .34514 Mtetra
.454 .88 .911 r
.63674 .34514 .64222 .34574 .65384 .34232 .6484 .34129 Mtetra
.504 .9 .938 r
.6484 .34129 .65384 .34232 .6655 .33879 .66009 .33721 Mtetra
.559 .914 .962 r
.66009 .33721 .6655 .33879 .67721 .3351 .67182 .33285 Mtetra
.61 .917 .978 r
.67182 .33285 .67721 .3351 .68896 .33123 .68359 .32822 Mtetra
.653 .908 .981 r
.68359 .32822 .68896 .33123 .70074 .32712 .69538 .32329 Mtetra
.682 .888 .973 r
.69538 .32329 .70074 .32712 .71256 .32277 .7072 .3181 Mtetra
.7 .863 .959 r
.7072 .3181 .71256 .32277 .72441 .31816 .71905 .3127 Mtetra
.709 .837 .944 r
.71905 .3127 .72441 .31816 .73629 .31331 .73093 .30716 Mtetra
.711 .814 .929 r
.73093 .30716 .73629 .31331 .74821 .30826 .74285 .30154 Mtetra
.71 .796 .918 r
.74285 .30154 .74821 .30826 .76015 .30306 .7548 .29592 Mtetra
.706 .781 .911 r
.7548 .29592 .76015 .30306 .77213 .29776 .7668 .29036 Mtetra
.703 .773 .906 r
.7668 .29036 .77213 .29776 .78414 .29241 .77885 .28486 Mtetra
.699 .768 .905 r
.77885 .28486 .78414 .29241 .7962 .28704 .79094 .27943 Mtetra
.696 .766 .906 r
.79094 .27943 .7962 .28704 .8083 .28168 .80308 .27409 Mtetra
.622 .743 .933 r
.15266 .48451 .15958 .49055 .16917 .48845 .16231 .48197 Mtetra
.617 .727 .925 r
.16231 .48197 .16917 .48845 .17879 .48644 .17199 .47956 Mtetra
.61 .713 .918 r
.17199 .47956 .17879 .48644 .18844 .4845 .18169 .47732 Mtetra
.601 .701 .914 r
.18169 .47732 .18844 .4845 .19813 .48263 .19141 .47529 Mtetra
.589 .692 .913 r
.19141 .47529 .19813 .48263 .20786 .48083 .20114 .47351 Mtetra
.578 .69 .917 r
.20114 .47351 .20786 .48083 .21763 .47903 .21091 .47193 Mtetra
.567 .693 .926 r
.21091 .47193 .21763 .47903 .22746 .47717 .22071 .47052 Mtetra
.559 .706 .939 r
.22071 .47052 .22746 .47717 .23734 .47519 .23055 .46916 Mtetra
.553 .727 .955 r
.23055 .46916 .23734 .47519 .24728 .47299 .24044 .46777 Mtetra
.547 .755 .974 r
.24044 .46777 .24728 .47299 .25729 .47057 .2504 .46624 Mtetra
.542 .789 .99 r
.2504 .46624 .25729 .47057 .26737 .46786 .26042 .46447 Mtetra
.532 .822 .999 r
.26042 .46447 .26737 .46786 .2775 .46489 .27052 .46242 Mtetra
.52 .852 .997 r
.27052 .46242 .2775 .46489 .2877 .46165 .28068 .46003 Mtetra
.501 .871 .982 r
.28068 .46003 .2877 .46165 .29795 .4582 .29092 .45734 Mtetra
.48 .879 .956 r
.29092 .45734 .29795 .4582 .30825 .45455 .30122 .45434 Mtetra
.456 .879 .924 r
.30122 .45434 .30825 .45455 .3186 .45076 .31157 .45108 Mtetra
.433 .872 .891 r
.31157 .45108 .3186 .45076 .329 .44687 .32199 .44759 Mtetra
.413 .863 .86 r
.32199 .44759 .329 .44687 .33943 .4429 .33245 .44393 Mtetra
.396 .853 .835 r
.33245 .44393 .33943 .4429 .34991 .43889 .34296 .44013 Mtetra
.383 .845 .816 r
.34296 .44013 .34991 .43889 .36042 .43486 .35352 .43623 Mtetra
.373 .838 .802 r
.35352 .43623 .36042 .43486 .37097 .43084 .36412 .43228 Mtetra
.366 .834 .793 r
.36412 .43228 .37097 .43084 .38156 .42683 .37475 .4283 Mtetra
.36 .83 .788 r
.37475 .4283 .38156 .42683 .39218 .42286 .38543 .42431 Mtetra
.356 .827 .786 r
.38543 .42431 .39218 .42286 .40284 .41892 .39614 .42034 Mtetra
.352 .825 .785 r
.39614 .42034 .40284 .41892 .41354 .41502 .4069 .41639 Mtetra
.348 .822 .785 r
.4069 .41639 .41354 .41502 .42428 .41117 .41769 .41249 Mtetra
.343 .82 .785 r
.41769 .41249 .42428 .41117 .43506 .40736 .42852 .40864 Mtetra
.337 .816 .785 r
.42852 .40864 .43506 .40736 .44587 .40361 .43939 .40485 Mtetra
.331 .812 .784 r
.43939 .40485 .44587 .40361 .45673 .39991 .45031 .40112 Mtetra
.323 .808 .782 r
.45031 .40112 .45673 .39991 .46763 .39627 .46126 .39745 Mtetra
.314 .802 .779 r
.46126 .39745 .46763 .39627 .47858 .39267 .47226 .39384 Mtetra
.304 .796 .774 r
.47226 .39384 .47858 .39267 .48956 .38913 .4833 .3903 Mtetra
.294 .789 .769 r
.4833 .3903 .48956 .38913 .50059 .38563 .49439 .38681 Mtetra
.284 .782 .763 r
.49439 .38681 .50059 .38563 .51167 .38219 .50552 .38338 Mtetra
.274 .775 .757 r
.50552 .38338 .51167 .38219 .5228 .37879 .5167 .37999 Mtetra
.267 .77 .752 r
.5167 .37999 .5228 .37879 .53397 .37544 .52793 .37663 Mtetra
.262 .767 .749 r
.52793 .37663 .53397 .37544 .54519 .37212 .53921 .37329 Mtetra
.262 .767 .75 r
.53921 .37329 .54519 .37212 .55646 .36884 .55054 .36994 Mtetra
.269 .772 .756 r
.55054 .36994 .55646 .36884 .56778 .36557 .56192 .36656 Mtetra
.283 .782 .768 r
.56192 .36656 .56778 .36557 .57915 .36231 .57334 .36312 Mtetra
.308 .799 .788 r
.57334 .36312 .57915 .36231 .59057 .35903 .58482 .35958 Mtetra
.344 .822 .817 r
.58482 .35958 .59057 .35903 .60204 .35571 .59634 .35591 Mtetra
.392 .851 .854 r
.59634 .35591 .60204 .35571 .61356 .35231 .60791 .35205 Mtetra
.452 .882 .894 r
.60791 .35205 .61356 .35231 .62513 .3488 .61951 .34796 Mtetra
.518 .908 .933 r
.61951 .34796 .62513 .3488 .63674 .34514 .63116 .34359 Mtetra
.584 .923 .962 r
.63116 .34359 .63674 .34514 .6484 .34129 .64284 .33891 Mtetra
.64 .922 .976 r
.64284 .33891 .6484 .34129 .66009 .33721 .65455 .33391 Mtetra
.683 .905 .974 r
.65455 .33391 .66009 .33721 .67182 .33285 .66629 .32855 Mtetra
.709 .877 .96 r
.66629 .32855 .67182 .33285 .68359 .32822 .67805 .32289 Mtetra
.723 .844 .939 r
.67805 .32289 .68359 .32822 .69538 .32329 .68984 .31698 Mtetra
.726 .812 .918 r
.68984 .31698 .69538 .32329 .7072 .3181 .70165 .31092 Mtetra
.723 .783 .9 r
.70165 .31092 .7072 .3181 .71905 .3127 .7135 .3048 Mtetra
.717 .761 .887 r
.7135 .3048 .71905 .3127 .73093 .30716 .72538 .29874 Mtetra
.709 .744 .879 r
.72538 .29874 .73093 .30716 .74285 .30154 .73732 .29284 Mtetra
.702 .735 .876 r
.73732 .29284 .74285 .30154 .7548 .29592 .7493 .28713 Mtetra
.694 .73 .878 r
.7493 .28713 .7548 .29592 .7668 .29036 .76134 .28169 Mtetra
.689 .732 .884 r
.76134 .28169 .7668 .29036 .77885 .28486 .77344 .27645 Mtetra
.685 .739 .892 r
.77344 .27645 .77885 .28486 .79094 .27943 .78561 .27137 Mtetra
.681 .749 .902 r
.78561 .27137 .79094 .27943 .80308 .27409 .79782 .26643 Mtetra
.665 .754 .916 r
.14569 .47843 .15266 .48451 .16231 .48197 .15547 .47488 Mtetra
.659 .721 .895 r
.15547 .47488 .16231 .48197 .17199 .47956 .16527 .47145 Mtetra
.65 .69 .874 r
.16527 .47145 .17199 .47956 .18169 .47732 .17509 .46819 Mtetra
.637 .661 .856 r
.17509 .46819 .18169 .47732 .19141 .47529 .18492 .46519 Mtetra
.623 .634 .841 r
.18492 .46519 .19141 .47529 .20114 .47351 .19475 .46254 Mtetra
.609 .611 .828 r
.19475 .46254 .20114 .47351 .21091 .47193 .20459 .46025 Mtetra
.595 .592 .818 r
.20459 .46025 .21091 .47193 .22071 .47052 .21443 .45836 Mtetra
.584 .579 .813 r
.21443 .45836 .22071 .47052 .23055 .46916 .22429 .45679 Mtetra
.575 .571 .811 r
.22429 .45679 .23055 .46916 .24044 .46777 .23417 .45551 Mtetra
.569 .57 .815 r
.23417 .45551 .24044 .46777 .2504 .46624 .24409 .4544 Mtetra
.566 .577 .824 r
.24409 .4544 .2504 .46624 .26042 .46447 .25405 .45335 Mtetra
.567 .592 .838 r
.25405 .45335 .26042 .46447 .27052 .46242 .26408 .45225 Mtetra
.571 .615 .858 r
.26408 .45225 .27052 .46242 .28068 .46003 .27416 .451 Mtetra
.576 .646 .883 r
.27416 .451 .28068 .46003 .29092 .45734 .28432 .44954 Mtetra
.582 .684 .911 r
.28432 .44954 .29092 .45734 .30122 .45434 .29455 .44782 Mtetra
.586 .728 .941 r
.29455 .44782 .30122 .45434 .31157 .45108 .30484 .44583 Mtetra
.586 .774 .969 r
.30484 .44583 .31157 .45108 .32199 .44759 .3152 .44356 Mtetra
.578 .819 .99 r
.3152 .44356 .32199 .44759 .33245 .44393 .32563 .44102 Mtetra
.559 .855 .997 r
.32563 .44102 .33245 .44393 .34296 .44013 .33612 .43825 Mtetra
.528 .878 .986 r
.33612 .43825 .34296 .44013 .35352 .43623 .34666 .43527 Mtetra
.486 .882 .956 r
.34666 .43527 .35352 .43623 .36412 .43228 .35726 .43212 Mtetra
.437 .871 .912 r
.35726 .43212 .36412 .43228 .37475 .4283 .36791 .42881 Mtetra
.386 .848 .859 r
.36791 .42881 .37475 .4283 .38543 .42431 .37861 .42539 Mtetra
.339 .819 .805 r
.37861 .42539 .38543 .42431 .39614 .42034 .38936 .42187 Mtetra
.296 .789 .756 r
.38936 .42187 .39614 .42034 .4069 .41639 .40015 .41829 Mtetra
.261 .761 .713 r
.40015 .41829 .4069 .41639 .41769 .41249 .41099 .41467 Mtetra
.233 .737 .679 r
.41099 .41467 .41769 .41249 .42852 .40864 .42187 .41101 Mtetra
0 0 0 r
.42187 .41101 .42852 .40864 .43939 .40485 .4328 .40734 Mtetra
.4328 .40734 .43939 .40485 .45031 .40112 .44377 .40366 Mtetra
.44377 .40366 .45031 .40112 .46126 .39745 .45478 .39997 Mtetra
.45478 .39997 .46126 .39745 .47226 .39384 .46584 .39628 Mtetra
.46584 .39628 .47226 .39384 .4833 .3903 .47695 .39258 Mtetra
.47695 .39258 .4833 .3903 .49439 .38681 .4881 .38885 Mtetra
.231 .737 .679 r
.4881 .38885 .49439 .38681 .50552 .38338 .49929 .3851 Mtetra
.265 .764 .715 r
.49929 .3851 .50552 .38338 .5167 .37999 .51053 .38131 Mtetra
.31 .797 .761 r
.51053 .38131 .5167 .37999 .52793 .37663 .52182 .37744 Mtetra
.366 .835 .815 r
.52182 .37744 .52793 .37663 .53921 .37329 .53316 .37348 Mtetra
.431 .873 .871 r
.53316 .37348 .53921 .37329 .55054 .36994 .54453 .3694 Mtetra
.502 .903 .924 r
.54453 .3694 .55054 .36994 .56192 .36656 .55596 .36517 Mtetra
.57 .918 .962 r
.55596 .36517 .56192 .36656 .57334 .36312 .56742 .36075 Mtetra
.628 .914 .981 r
.56742 .36075 .57334 .36312 .58482 .35958 .57893 .35612 Mtetra
.67 .89 .978 r
.57893 .35612 .58482 .35958 .59634 .35591 .59047 .35124 Mtetra
.696 .854 .958 r
.59047 .35124 .59634 .35591 .60791 .35205 .60205 .34609 Mtetra
.709 .812 .929 r
.60205 .34609 .60791 .35205 .61951 .34796 .61365 .34064 Mtetra
.713 .77 .897 r
.61365 .34064 .61951 .34796 .63116 .34359 .62529 .33491 Mtetra
.712 .732 .867 r
.62529 .33491 .63116 .34359 .64284 .33891 .63695 .32889 Mtetra
.708 .7 .84 r
.63695 .32889 .64284 .33891 .65455 .33391 .64864 .32265 Mtetra
.702 .673 .819 r
.64864 .32265 .65455 .33391 .66629 .32855 .66036 .31625 Mtetra
.695 .652 .803 r
.66036 .31625 .66629 .32855 .67805 .32289 .6721 .30979 Mtetra
.689 .636 .792 r
.6721 .30979 .67805 .32289 .68984 .31698 .68388 .30338 Mtetra
.682 .626 .787 r
.68388 .30338 .68984 .31698 .70165 .31092 .6957 .29713 Mtetra
.675 .621 .786 r
.6957 .29713 .70165 .31092 .7135 .3048 .70757 .29117 Mtetra
.669 .62 .791 r
.70757 .29117 .7135 .3048 .72538 .29874 .7195 .28554 Mtetra
.663 .624 .8 r
.7195 .28554 .72538 .29874 .73732 .29284 .73149 .28031 Mtetra
.659 .634 .814 r
.73149 .28031 .73732 .29284 .7493 .28713 .74356 .27545 Mtetra
.654 .648 .831 r
.74356 .27545 .7493 .28713 .76134 .28169 .7557 .27095 Mtetra
.651 .666 .852 r
.7557 .27095 .76134 .28169 .77344 .27645 .7679 .26672 Mtetra
.649 .689 .874 r
.7679 .26672 .77344 .27645 .78561 .27137 .78018 .26267 Mtetra
.647 .717 .899 r
.78018 .26267 .78561 .27137 .79782 .26643 .79252 .25872 Mtetra
.707 .762 .895 r
.13868 .4723 .14569 .47843 .15547 .47488 .14861 .46755 Mtetra
.699 .726 .871 r
.14861 .46755 .15547 .47488 .16527 .47145 .15857 .46283 Mtetra
.687 .69 .848 r
.15857 .46283 .16527 .47145 .17509 .46819 .16855 .45823 Mtetra
.673 .657 .826 r
.16855 .45823 .17509 .46819 .18492 .46519 .17853 .45385 Mtetra
.657 .625 .807 r
.17853 .45385 .18492 .46519 .19475 .46254 .1885 .4498 Mtetra
.639 .595 .789 r
.1885 .4498 .19475 .46254 .20459 .46025 .19847 .44616 Mtetra
.621 .568 .774 r
.19847 .44616 .20459 .46025 .21443 .45836 .20843 .44306 Mtetra
.604 .545 .761 r
.20843 .44306 .21443 .45836 .22429 .45679 .21837 .44049 Mtetra
.588 .525 .752 r
.21837 .44049 .22429 .45679 .23417 .45551 .2283 .43851 Mtetra
.575 .511 .746 r
.2283 .43851 .23417 .45551 .24409 .4544 .23824 .43704 Mtetra
.564 .501 .743 r
.23824 .43704 .24409 .4544 .25405 .45335 .24818 .43601 Mtetra
.556 .497 .745 r
.24818 .43601 .25405 .45335 .26408 .45225 .25816 .43528 Mtetra
.552 .499 .75 r
.25816 .43528 .26408 .45225 .27416 .451 .26817 .43471 Mtetra
.551 .506 .759 r
.26817 .43471 .27416 .451 .28432 .44954 .27825 .43419 Mtetra
.553 .519 .772 r
.27825 .43419 .28432 .44954 .29455 .44782 .28838 .43358 Mtetra
.557 .537 .788 r
.28838 .43358 .29455 .44782 .30484 .44583 .29859 .43281 Mtetra
.563 .559 .808 r
.29859 .43281 .30484 .44583 .3152 .44356 .30887 .43181 Mtetra
.571 .586 .83 r
.30887 .43181 .3152 .44356 .32563 .44102 .31922 .43055 Mtetra
.579 .617 .854 r
.31922 .43055 .32563 .44102 .33612 .43825 .32964 .429 Mtetra
.588 .651 .88 r
.32964 .429 .33612 .43825 .34666 .43527 .34014 .42718 Mtetra
.596 .686 .905 r
.34014 .42718 .34666 .43527 .35726 .43212 .3507 .42508 Mtetra
.602 .722 .929 r
.3507 .42508 .35726 .43212 .36791 .42881 .36132 .42272 Mtetra
.606 .757 .951 r
.36132 .42272 .36791 .42881 .37861 .42539 .37201 .42012 Mtetra
.608 .788 .968 r
.37201 .42012 .37861 .42539 .38936 .42187 .38276 .41731 Mtetra
.607 .816 .98 r
.38276 .41731 .38936 .42187 .40015 .41829 .39356 .41431 Mtetra
.605 .838 .988 r
.39356 .41431 .40015 .41829 .41099 .41467 .40442 .41114 Mtetra
.603 .854 .992 r
.40442 .41114 .41099 .41467 .42187 .41101 .41532 .40781 Mtetra
.601 .867 .993 r
.41532 .40781 .42187 .41101 .4328 .40734 .42628 .40435 Mtetra
.602 .875 .992 r
.42628 .40435 .4328 .40734 .44377 .40366 .43729 .40076 Mtetra
.605 .88 .991 r
.43729 .40076 .44377 .40366 .45478 .39997 .44835 .39705 Mtetra
.612 .883 .99 r
.44835 .39705 .45478 .39997 .46584 .39628 .45945 .39321 Mtetra
.623 .882 .989 r
.45945 .39321 .46584 .39628 .47695 .39258 .4706 .38925 Mtetra
.636 .878 .986 r
.4706 .38925 .47695 .39258 .4881 .38885 .4818 .38515 Mtetra
.651 .869 .981 r
.4818 .38515 .4881 .38885 .49929 .3851 .49304 .38089 Mtetra
.666 .855 .972 r
.49304 .38089 .49929 .3851 .51053 .38131 .50432 .37646 Mtetra
.68 .837 .959 r
.50432 .37646 .51053 .38131 .52182 .37744 .51565 .37183 Mtetra
.691 .813 .941 r
.51565 .37183 .52182 .37744 .53316 .37348 .52702 .36698 Mtetra
.699 .786 .919 r
.52702 .36698 .53316 .37348 .54453 .3694 .53843 .36189 Mtetra
.703 .757 .894 r
.53843 .36189 .54453 .3694 .55596 .36517 .54987 .35652 Mtetra
.704 .727 .868 r
.54987 .35652 .55596 .36517 .56742 .36075 .56135 .35087 Mtetra
.703 .698 .842 r
.56135 .35087 .56742 .36075 .57893 .35612 .57286 .34493 Mtetra
.7 .67 .818 r
.57286 .34493 .57893 .35612 .59047 .35124 .5844 .33868 Mtetra
.695 .645 .796 r
.5844 .33868 .59047 .35124 .60205 .34609 .59596 .33216 Mtetra
.69 .623 .776 r
.59596 .33216 .60205 .34609 .61365 .34064 .60754 .32539 Mtetra
.684 .604 .76 r
.60754 .32539 .61365 .34064 .62529 .33491 .61915 .31845 Mtetra
.678 .588 .747 r
.61915 .31845 .62529 .33491 .63695 .32889 .63078 .3114 Mtetra
.672 .574 .737 r
.63078 .3114 .63695 .32889 .64864 .32265 .64244 .30438 Mtetra
.665 .564 .731 r
.64244 .30438 .64864 .32265 .66036 .31625 .65414 .29753 Mtetra
.658 .556 .729 r
.65414 .29753 .66036 .31625 .6721 .30979 .66587 .29097 Mtetra
.65 .551 .729 r
.66587 .29097 .6721 .30979 .68388 .30338 .67766 .28486 Mtetra
.643 .55 .734 r
.67766 .28486 .68388 .30338 .6957 .29713 .68951 .27926 Mtetra
.636 .552 .743 r
.68951 .27926 .6957 .29713 .70757 .29117 .70144 .27426 Mtetra
.63 .559 .756 r
.70144 .27426 .70757 .29117 .7195 .28554 .71344 .26982 Mtetra
.624 .569 .773 r
.71344 .26982 .7195 .28554 .73149 .28031 .72553 .26593 Mtetra
.619 .585 .794 r
.72553 .26593 .73149 .28031 .74356 .27545 .7377 .26246 Mtetra
.614 .605 .818 r
.7377 .26246 .74356 .27545 .7557 .27095 .74996 .25934 Mtetra
.61 .629 .845 r
.74996 .25934 .7557 .27095 .7679 .26672 .76229 .25644 Mtetra
.607 .658 .874 r
.76229 .25644 .7679 .26672 .78018 .26267 .7747 .25368 Mtetra
.604 .691 .904 r
.7747 .25368 .78018 .26267 .79252 .25872 .78718 .25095 Mtetra
.73 .765 .881 r
.13161 .46613 .13868 .4723 .14861 .46755 .14166 .46056 Mtetra
.725 .742 .865 r
.14166 .46056 .14861 .46755 .15857 .46283 .15174 .45492 Mtetra
.718 .717 .848 r
.15174 .45492 .15857 .46283 .16855 .45823 .16185 .44929 Mtetra
.708 .691 .832 r
.16185 .44929 .16855 .45823 .17853 .45385 .17197 .44372 Mtetra
.697 .664 .814 r
.17197 .44372 .17853 .45385 .1885 .4498 .18211 .43825 Mtetra
.682 .634 .795 r
.18211 .43825 .1885 .4498 .19847 .44616 .19225 .43302 Mtetra
.665 .603 .776 r
.19225 .43302 .19847 .44616 .20843 .44306 .20238 .42811 Mtetra
.647 .572 .757 r
.20238 .42811 .20843 .44306 .21837 .44049 .2125 .42362 Mtetra
.628 .542 .739 r
.2125 .42362 .21837 .44049 .2283 .43851 .2226 .41965 Mtetra
.611 .515 .722 r
.2226 .41965 .2283 .43851 .23824 .43704 .23269 .41621 Mtetra
.595 .492 .707 r
.23269 .41621 .23824 .43704 .24818 .43601 .24277 .41335 Mtetra
.582 .473 .694 r
.24277 .41335 .24818 .43601 .25816 .43528 .25285 .41099 Mtetra
.572 .457 .684 r
.25285 .41099 .25816 .43528 .26817 .43471 .26293 .40908 Mtetra
.564 .446 .677 r
.26293 .40908 .26817 .43471 .27825 .43419 .27304 .40751 Mtetra
.559 .438 .671 r
.27304 .40751 .27825 .43419 .28838 .43358 .28319 .40619 Mtetra
.557 .434 .668 r
.28319 .40619 .28838 .43358 .29859 .43281 .29337 .405 Mtetra
.556 .431 .666 r
.29337 .405 .29859 .43281 .30887 .43181 .30361 .40385 Mtetra
.30361 .40385 .30887 .43181 .31922 .43055 .31391 .40268 Mtetra
.557 .433 .666 r
.31391 .40268 .31922 .43055 .32964 .429 .32427 .40141 Mtetra
.56 .436 .668 r
.32427 .40141 .32964 .429 .34014 .42718 .33469 .4 Mtetra
.563 .44 .671 r
.33469 .4 .34014 .42718 .3507 .42508 .34518 .3984 Mtetra
.566 .445 .674 r
.34518 .3984 .3507 .42508 .36132 .42272 .35573 .3966 Mtetra
.57 .45 .677 r
.35573 .3966 .36132 .42272 .37201 .42012 .36635 .39457 Mtetra
.575 .456 .68 r
.36635 .39457 .37201 .42012 .38276 .41731 .37703 .39231 Mtetra
.579 .462 .684 r
.37703 .39231 .38276 .41731 .39356 .41431 .38778 .3898 Mtetra
.584 .468 .687 r
.38778 .3898 .39356 .41431 .40442 .41114 .39859 .38704 Mtetra
.588 .473 .69 r
.39859 .38704 .40442 .41114 .41532 .40781 .40945 .38404 Mtetra
.593 .478 .692 r
.40945 .38404 .41532 .40781 .42628 .40435 .42037 .38078 Mtetra
.597 .482 .693 r
.42037 .38078 .42628 .40435 .43729 .40076 .43135 .37728 Mtetra
.601 .485 .694 r
.43135 .37728 .43729 .40076 .44835 .39705 .44238 .37352 Mtetra
.604 .487 .693 r
.44238 .37352 .44835 .39705 .45945 .39321 .45346 .36952 Mtetra
.607 .489 .692 r
.45346 .36952 .45945 .39321 .4706 .38925 .46458 .36526 Mtetra
.61 .489 .69 r
.46458 .36526 .4706 .38925 .4818 .38515 .47576 .36075 Mtetra
.612 .488 .687 r
.47576 .36075 .4818 .38515 .49304 .38089 .48697 .35599 Mtetra
.614 .487 .684 r
.48697 .35599 .49304 .38089 .50432 .37646 .49823 .35097 Mtetra
.616 .486 .681 r
.49823 .35097 .50432 .37646 .51565 .37183 .50953 .3457 Mtetra
.617 .484 .677 r
.50953 .3457 .51565 .37183 .52702 .36698 .52086 .34019 Mtetra
.618 .481 .673 r
.52086 .34019 .52702 .36698 .53843 .36189 .53223 .33443 Mtetra
.618 .479 .67 r
.53223 .33443 .53843 .36189 .54987 .35652 .54363 .32846 Mtetra
.619 .477 .667 r
.54363 .32846 .54987 .35652 .56135 .35087 .55507 .3223 Mtetra
.619 .475 .664 r
.55507 .3223 .56135 .35087 .57286 .34493 .56653 .31599 Mtetra
.619 .474 .663 r
.56653 .31599 .57286 .34493 .5844 .33868 .57802 .30956 Mtetra
.619 .473 .662 r
.57802 .30956 .5844 .33868 .59596 .33216 .58954 .3031 Mtetra
.58954 .3031 .59596 .33216 .60754 .32539 .60109 .29667 Mtetra
.618 .474 .664 r
.60109 .29667 .60754 .32539 .61915 .31845 .61267 .29036 Mtetra
.617 .476 .668 r
.61267 .29036 .61915 .31845 .63078 .3114 .6243 .2843 Mtetra
.615 .479 .673 r
.6243 .2843 .63078 .3114 .64244 .30438 .63597 .27858 Mtetra
.613 .484 .681 r
.63597 .27858 .64244 .30438 .65414 .29753 .64769 .27332 Mtetra
.61 .491 .692 r
.64769 .27332 .65414 .29753 .66587 .29097 .65948 .26857 Mtetra
.607 .499 .705 r
.65948 .26857 .66587 .29097 .67766 .28486 .67134 .26441 Mtetra
.603 .511 .723 r
.67134 .26441 .67766 .28486 .68951 .27926 .68329 .2608 Mtetra
.599 .525 .743 r
.68329 .2608 .68951 .27926 .70144 .27426 .69531 .25772 Mtetra
.594 .543 .767 r
.69531 .25772 .70144 .27426 .71344 .26982 .70742 .25508 Mtetra
.59 .564 .793 r
.70742 .25508 .71344 .26982 .72553 .26593 .71962 .25278 Mtetra
.585 .587 .821 r
.71962 .25278 .72553 .26593 .7377 .26246 .7319 .25072 Mtetra
.582 .612 .848 r
.7319 .25072 .7377 .26246 .74996 .25934 .74427 .24878 Mtetra
.577 .637 .873 r
.74427 .24878 .74996 .25934 .76229 .25644 .7567 .24691 Mtetra
.574 .661 .897 r
.7567 .24691 .76229 .25644 .7747 .25368 .76922 .24504 Mtetra
.571 .686 .919 r
.76922 .24504 .7747 .25368 .78718 .25095 .7818 .24311 Mtetra
.736 .766 .877 r
.12449 .45992 .13161 .46613 .14166 .46056 .1346 .45407 Mtetra
.737 .759 .87 r
.1346 .45407 .14166 .46056 .15174 .45492 .14475 .44809 Mtetra
.738 .75 .862 r
.14475 .44809 .15174 .45492 .16185 .44929 .15493 .44197 Mtetra
.737 .738 .852 r
.15493 .44197 .16185 .44929 .17197 .44372 .16515 .43571 Mtetra
.734 .721 .839 r
.16515 .43571 .17197 .44372 .18211 .43825 .17541 .42929 Mtetra
.727 .698 .823 r
.17541 .42929 .18211 .43825 .19225 .43302 .18569 .42279 Mtetra
.717 .671 .804 r
.18569 .42279 .19225 .43302 .20238 .42811 .196 .41627 Mtetra
.702 .639 .783 r
.196 .41627 .20238 .42811 .2125 .42362 .20632 .40986 Mtetra
.685 .606 .761 r
.20632 .40986 .2125 .42362 .2226 .41965 .21663 .40366 Mtetra
.665 .572 .74 r
.21663 .40366 .2226 .41965 .23269 .41621 .22694 .39781 Mtetra
.645 .54 .72 r
.22694 .39781 .23269 .41621 .24277 .41335 .23722 .39244 Mtetra
.627 .511 .702 r
.23722 .39244 .24277 .41335 .25285 .41099 .24749 .38759 Mtetra
.61 .486 .687 r
.24749 .38759 .25285 .41099 .26293 .40908 .25774 .38334 Mtetra
.596 .466 .674 r
.25774 .38334 .26293 .40908 .27304 .40751 .26798 .37964 Mtetra
.584 .449 .663 r
.26798 .37964 .27304 .40751 .28319 .40619 .27821 .37646 Mtetra
.575 .437 .655 r
.27821 .37646 .28319 .40619 .29337 .405 .28846 .37372 Mtetra
.568 .427 .649 r
.28846 .37372 .29337 .405 .30361 .40385 .29873 .37132 Mtetra
.564 .42 .644 r
.29873 .37132 .30361 .40385 .31391 .40268 .30902 .36919 Mtetra
.561 .415 .641 r
.30902 .36919 .31391 .40268 .32427 .40141 .31936 .36722 Mtetra
.559 .413 .639 r
.31936 .36722 .32427 .40141 .33469 .4 .32974 .36534 Mtetra
.558 .411 .637 r
.32974 .36534 .33469 .4 .34518 .3984 .34017 .36347 Mtetra
.559 .411 .637 r
.34017 .36347 .34518 .3984 .35573 .3966 .35066 .36154 Mtetra
.56 .412 .637 r
.35066 .36154 .35573 .3966 .36635 .39457 .36121 .3595 Mtetra
.562 .413 .637 r
.36121 .3595 .36635 .39457 .37703 .39231 .37182 .3573 Mtetra
.564 .415 .637 r
.37182 .3573 .37703 .39231 .38778 .3898 .38249 .35489 Mtetra
.567 .417 .638 r
.38249 .35489 .38778 .3898 .39859 .38704 .39322 .35224 Mtetra
.57 .42 .638 r
.39322 .35224 .39859 .38704 .40945 .38404 .40402 .34932 Mtetra
.573 .423 .639 r
.40402 .34932 .40945 .38404 .42037 .38078 .41487 .34612 Mtetra
.576 .425 .639 r
.41487 .34612 .42037 .38078 .43135 .37728 .42578 .34261 Mtetra
.58 .428 .639 r
.42578 .34261 .43135 .37728 .44238 .37352 .43674 .33881 Mtetra
.583 .43 .639 r
.43674 .33881 .44238 .37352 .45346 .36952 .44775 .3347 Mtetra
.586 .432 .639 r
.44775 .3347 .45346 .36952 .46458 .36526 .45882 .33028 Mtetra
.588 .433 .639 r
.45882 .33028 .46458 .36526 .47576 .36075 .46993 .32558 Mtetra
.591 .435 .638 r
.46993 .32558 .47576 .36075 .48697 .35599 .48108 .32061 Mtetra
.593 .435 .637 r
.48108 .32061 .48697 .35599 .49823 .35097 .49227 .31539 Mtetra
.595 .436 .637 r
.49227 .31539 .49823 .35097 .50953 .3457 .5035 .30995 Mtetra
.596 .437 .636 r
.5035 .30995 .50953 .3457 .52086 .34019 .51477 .30435 Mtetra
.597 .437 .636 r
.51477 .30435 .52086 .34019 .53223 .33443 .52607 .29862 Mtetra
.597 .438 .636 r
.52607 .29862 .53223 .33443 .54363 .32846 .5374 .29282 Mtetra
.597 .438 .637 r
.5374 .29282 .54363 .32846 .55507 .3223 .54877 .28703 Mtetra
.597 .439 .638 r
.54877 .28703 .55507 .3223 .56653 .31599 .56017 .28133 Mtetra
.596 .44 .64 r
.56017 .28133 .56653 .31599 .57802 .30956 .57161 .27578 Mtetra
.595 .442 .644 r
.57161 .27578 .57802 .30956 .58954 .3031 .58309 .2705 Mtetra
.594 .444 .648 r
.58309 .2705 .58954 .3031 .60109 .29667 .59461 .26556 Mtetra
.591 .448 .655 r
.59461 .26556 .60109 .29667 .61267 .29036 .60619 .26106 Mtetra
.588 .452 .663 r
.60619 .26106 .61267 .29036 .6243 .2843 .61783 .2571 Mtetra
.585 .459 .675 r
.61783 .2571 .6243 .2843 .63597 .27858 .62955 .2537 Mtetra
.58 .467 .69 r
.62955 .2537 .63597 .27858 .64769 .27332 .64134 .25092 Mtetra
.575 .48 .708 r
.64134 .25092 .64769 .27332 .65948 .26857 .65321 .24868 Mtetra
.57 .495 .731 r
.65321 .24868 .65948 .26857 .67134 .26441 .66517 .24693 Mtetra
.565 .515 .759 r
.66517 .24693 .67134 .26441 .68329 .2608 .67722 .24555 Mtetra
.56 .54 .789 r
.67722 .24555 .68329 .2608 .69531 .25772 .68935 .2444 Mtetra
.556 .568 .821 r
.68935 .2444 .69531 .25772 .70742 .25508 .70157 .24337 Mtetra
.553 .597 .852 r
.70157 .24337 .70742 .25508 .71962 .25278 .71386 .24231 Mtetra
.55 .625 .879 r
.71386 .24231 .71962 .25278 .7319 .25072 .72623 .24119 Mtetra
.551 .65 .9 r
.72623 .24119 .7319 .25072 .74427 .24878 .73866 .2399 Mtetra
.552 .669 .915 r
.73866 .2399 .74427 .24878 .7567 .24691 .75117 .23848 Mtetra
.553 .684 .926 r
.75117 .23848 .7567 .24691 .76922 .24504 .76374 .23691 Mtetra
.555 .696 .934 r
.76374 .23691 .76922 .24504 .7818 .24311 .77637 .23521 Mtetra
.72 .764 .887 r
.11732 .45366 .12449 .45992 .1346 .45407 .12739 .44838 Mtetra
.728 .783 .897 r
.12739 .44838 .1346 .45407 .14475 .44809 .13749 .44296 Mtetra
.736 .803 .906 r
.13749 .44296 .14475 .44809 .15493 .44197 .14765 .43736 Mtetra
.744 .822 .912 r
.14765 .43736 .15493 .44197 .16515 .43571 .15785 .43155 Mtetra
.754 .839 .916 r
.15785 .43155 .16515 .43571 .17541 .42929 .1681 .42547 Mtetra
.762 .851 .918 r
.1681 .42547 .17541 .42929 .18569 .42279 .1784 .41915 Mtetra
.769 .858 .917 r
.1784 .41915 .18569 .42279 .196 .41627 .18874 .4126 Mtetra
.773 .858 .914 r
.18874 .4126 .196 .41627 .20632 .40986 .19912 .40591 Mtetra
.774 .85 .908 r
.19912 .40591 .20632 .40986 .21663 .40366 .20953 .39913 Mtetra
.769 .831 .9 r
.20953 .39913 .21663 .40366 .22694 .39781 .21995 .39238 Mtetra
.76 .802 .887 r
.21995 .39238 .22694 .39781 .23722 .39244 .23038 .38576 Mtetra
.744 .764 .869 r
.23038 .38576 .23722 .39244 .24749 .38759 .24081 .37937 Mtetra
.724 .72 .846 r
.24081 .37937 .24749 .38759 .25774 .38334 .25123 .3733 Mtetra
.701 .674 .82 r
.25123 .3733 .25774 .38334 .26798 .37964 .26165 .36758 Mtetra
.678 .629 .793 r
.26165 .36758 .26798 .37964 .27821 .37646 .27206 .36226 Mtetra
.658 .59 .767 r
.27206 .36226 .27821 .37646 .28846 .37372 .28247 .3573 Mtetra
.64 .556 .744 r
.28247 .3573 .28846 .37372 .29873 .37132 .29289 .35268 Mtetra
.625 .528 .724 r
.29289 .35268 .29873 .37132 .30902 .36919 .30332 .34837 Mtetra
.613 .505 .707 r
.30332 .34837 .30902 .36919 .31936 .36722 .31377 .34431 Mtetra
.603 .486 .692 r
.31377 .34431 .31936 .36722 .32974 .36534 .32424 .34047 Mtetra
.596 .471 .68 r
.32424 .34047 .32974 .36534 .34017 .36347 .33474 .33678 Mtetra
.59 .459 .671 r
.33474 .33678 .34017 .36347 .35066 .36154 .34528 .33322 Mtetra
.586 .45 .663 r
.34528 .33322 .35066 .36154 .36121 .3595 .35586 .32972 Mtetra
.583 .443 .656 r
.35586 .32972 .36121 .3595 .37182 .3573 .36648 .32626 Mtetra
.581 .437 .651 r
.36648 .32626 .37182 .3573 .38249 .35489 .37714 .32279 Mtetra
.579 .433 .647 r
.37714 .32279 .38249 .35489 .39322 .35224 .38785 .31928 Mtetra
.579 .43 .644 r
.38785 .31928 .39322 .35224 .40402 .34932 .39861 .31571 Mtetra
.579 .429 .642 r
.39861 .31571 .40402 .34932 .41487 .34612 .40941 .31206 Mtetra
.579 .428 .64 r
.40941 .31206 .41487 .34612 .42578 .34261 .42026 .30831 Mtetra
.58 .428 .64 r
.42026 .30831 .42578 .34261 .43674 .33881 .43116 .30445 Mtetra
.581 .428 .639 r
.43116 .30445 .43674 .33881 .44775 .3347 .4421 .30049 Mtetra
.582 .43 .64 r
.4421 .30049 .44775 .3347 .45882 .33028 .45309 .29643 Mtetra
.583 .432 .642 r
.45309 .29643 .45882 .33028 .46993 .32558 .46412 .29228 Mtetra
.585 .435 .644 r
.46412 .29228 .46993 .32558 .48108 .32061 .4752 .28807 Mtetra
.586 .438 .647 r
.4752 .28807 .48108 .32061 .49227 .31539 .48632 .28382 Mtetra
.588 .442 .651 r
.48632 .28382 .49227 .31539 .5035 .30995 .49749 .27956 Mtetra
.59 .447 .656 r
.49749 .27956 .5035 .30995 .51477 .30435 .5087 .27533 Mtetra
.591 .454 .662 r
.5087 .27533 .51477 .30435 .52607 .29862 .51995 .27118 Mtetra
.593 .461 .67 r
.51995 .27118 .52607 .29862 .5374 .29282 .53125 .26713 Mtetra
.594 .47 .681 r
.53125 .26713 .5374 .29282 .54877 .28703 .54259 .26326 Mtetra
.595 .481 .693 r
.54259 .26326 .54877 .28703 .56017 .28133 .55399 .25959 Mtetra
.596 .494 .709 r
.55399 .25959 .56017 .28133 .57161 .27578 .56544 .25619 Mtetra
.596 .511 .728 r
.56544 .25619 .57161 .27578 .58309 .2705 .57694 .25309 Mtetra
.594 .53 .753 r
.57694 .25309 .58309 .2705 .59461 .26556 .58851 .25035 Mtetra
.591 .554 .782 r
.58851 .25035 .59461 .26556 .60619 .26106 .60015 .24799 Mtetra
.583 .583 .818 r
.60015 .24799 .60619 .26106 .61783 .2571 .61186 .24603 Mtetra
.57 .616 .859 r
.61186 .24603 .61783 .2571 .62955 .2537 .62365 .24443 Mtetra
.55 .651 .902 r
.62365 .24443 .62955 .2537 .64134 .25092 .63552 .24318 Mtetra
.524 .686 .94 r
.63552 .24318 .64134 .25092 .65321 .24868 .64747 .24216 Mtetra
.494 .715 .969 r
.64747 .24216 .65321 .24868 .66517 .24693 .6595 .24129 Mtetra
.467 .735 .986 r
.6595 .24129 .66517 .24693 .67722 .24555 .67162 .24045 Mtetra
.453 .75 .993 r
.67162 .24045 .67722 .24555 .68935 .2444 .68381 .23954 Mtetra
.453 .76 .995 r
.68381 .23954 .68935 .2444 .70157 .24337 .69606 .23848 Mtetra
.469 .769 .996 r
.69606 .23848 .70157 .24337 .71386 .24231 .70839 .23719 Mtetra
.491 .772 .994 r
.70839 .23719 .71386 .24231 .72623 .24119 .72077 .23565 Mtetra
.519 .77 .988 r
.72077 .23565 .72623 .24119 .73866 .2399 .73322 .23385 Mtetra
.542 .762 .979 r
.73322 .23385 .73866 .2399 .75117 .23848 .74572 .23182 Mtetra
.561 .75 .966 r
.74572 .23182 .75117 .23848 .76374 .23691 .75828 .22961 Mtetra
.574 .735 .951 r
.75828 .22961 .76374 .23691 .77637 .23521 .7709 .22725 Mtetra
.685 .758 .907 r
.1101 .44736 .11732 .45366 .12739 .44838 .12005 .44318 Mtetra
.69 .796 .93 r
.12005 .44318 .12739 .44838 .13749 .44296 .13005 .4389 Mtetra
.694 .837 .952 r
.13005 .4389 .13749 .44296 .14765 .43736 .14009 .43445 Mtetra
.694 .88 .967 r
.14009 .43445 .14765 .43736 .15785 .43155 .1502 .42981 Mtetra
.689 .918 .971 r
.1502 .42981 .15785 .43155 .1681 .42547 .16036 .4249 Mtetra
.672 .946 .959 r
.16036 .4249 .1681 .42547 .1784 .41915 .17058 .4197 Mtetra
.644 .959 .927 r
.17058 .4197 .1784 .41915 .18874 .4126 .18086 .41418 Mtetra
.607 .954 .879 r
.18086 .41418 .18874 .4126 .19912 .40591 .1912 .40835 Mtetra
.57 .938 .826 r
.1912 .40835 .19912 .40591 .20953 .39913 .2016 .4022 Mtetra
.543 .921 .782 r
.2016 .4022 .20953 .39913 .21995 .39238 .21205 .39577 Mtetra
.537 .914 .761 r
.21205 .39577 .21995 .39238 .23038 .38576 .22254 .38908 Mtetra
.555 .923 .768 r
.22254 .38908 .23038 .38576 .24081 .37937 .23307 .38221 Mtetra
.598 .946 .803 r
.23307 .38221 .24081 .37937 .25123 .3733 .24363 .37524 Mtetra
.657 .972 .858 r
.24363 .37524 .25123 .3733 .26165 .36758 .25421 .36825 Mtetra
.714 .98 .91 r
.25421 .36825 .26165 .36758 .27206 .36226 .2648 .36133 Mtetra
.754 .956 .939 r
.2648 .36133 .27206 .36226 .28247 .3573 .2754 .35453 Mtetra
.766 .902 .936 r
.2754 .35453 .28247 .3573 .29289 .35268 .28601 .34791 Mtetra
.757 .833 .91 r
.28601 .34791 .29289 .35268 .30332 .34837 .29662 .34148 Mtetra
.737 .765 .875 r
.29662 .34148 .30332 .34837 .31377 .34431 .30724 .33527 Mtetra
.714 .704 .84 r
.30724 .33527 .31377 .34431 .32424 .34047 .31787 .3293 Mtetra
.692 .654 .808 r
.31787 .3293 .32424 .34047 .33474 .33678 .32851 .32357 Mtetra
.673 .614 .781 r
.32851 .32357 .33474 .33678 .34528 .33322 .33917 .31808 Mtetra
.657 .581 .759 r
.33917 .31808 .34528 .33322 .35586 .32972 .34984 .31282 Mtetra
.643 .556 .741 r
.34984 .31282 .35586 .32972 .36648 .32626 .36053 .3078 Mtetra
.633 .536 .727 r
.36053 .3078 .36648 .32626 .37714 .32279 .37124 .30299 Mtetra
.624 .52 .716 r
.37124 .30299 .37714 .32279 .38785 .31928 .38198 .29839 Mtetra
.617 .508 .708 r
.38198 .29839 .38785 .31928 .39861 .31571 .39275 .29397 Mtetra
.611 .499 .702 r
.39275 .29397 .39861 .31571 .40941 .31206 .40356 .28974 Mtetra
.606 .493 .699 r
.40356 .28974 .40941 .31206 .42026 .30831 .41439 .28567 Mtetra
.603 .489 .697 r
.41439 .28567 .42026 .30831 .43116 .30445 .42526 .28178 Mtetra
.6 .487 .697 r
.42526 .28178 .43116 .30445 .4421 .30049 .43617 .27804 Mtetra
.597 .488 .7 r
.43617 .27804 .4421 .30049 .45309 .29643 .44713 .27449 Mtetra
.596 .49 .704 r
.44713 .27449 .45309 .29643 .46412 .29228 .45812 .27111 Mtetra
.594 .495 .711 r
.45812 .27111 .46412 .29228 .4752 .28807 .46916 .26792 Mtetra
.593 .502 .72 r
.46916 .26792 .4752 .28807 .48632 .28382 .48025 .26494 Mtetra
.591 .512 .733 r
.48025 .26494 .48632 .28382 .49749 .27956 .49138 .26219 Mtetra
.59 .526 .751 r
.49138 .26219 .49749 .27956 .5087 .27533 .50257 .25966 Mtetra
.588 .544 .773 r
.50257 .25966 .5087 .27533 .51995 .27118 .51382 .25738 Mtetra
.585 .569 .802 r
.51382 .25738 .51995 .27118 .53125 .26713 .52512 .25535 Mtetra
.578 .602 .84 r
.52512 .25535 .53125 .26713 .54259 .26326 .53649 .25357 Mtetra
.566 .644 .887 r
.53649 .25357 .54259 .26326 .55399 .25959 .54792 .25203 Mtetra
.539 .695 .94 r
.54792 .25203 .55399 .25959 .56544 .25619 .55943 .25073 Mtetra
.484 .747 .987 r
.55943 .25073 .56544 .25619 .57694 .25309 .571 .24963 Mtetra
.381 .771 .988 r
.571 .24963 .57694 .25309 .58851 .25035 .58265 .24872 Mtetra
.232 .733 .903 r
.58265 .24872 .58851 .25035 .60015 .24799 .59437 .24794 Mtetra
.077 .639 .75 r
.59437 .24794 .60015 .24799 .61186 .24603 .60618 .24724 Mtetra
.033 0 0 r
.60618 .24724 .61186 .24603 .62365 .24443 .61806 .24653 Mtetra
.092 0 0 r
.61806 .24653 .62365 .24443 .63552 .24318 .63001 .24572 Mtetra
.109 0 0 r
.63001 .24572 .63552 .24318 .64747 .24216 .64203 .24473 Mtetra
.09 0 0 r
.64203 .24473 .64747 .24216 .6595 .24129 .65412 .24349 Mtetra
.04 0 0 r
.65412 .24349 .6595 .24129 .67162 .24045 .66627 .24196 Mtetra
0 0 0 r
.66627 .24196 .67162 .24045 .68381 .23954 .67848 .24011 Mtetra
.158 .697 .738 r
.67848 .24011 .68381 .23954 .69606 .23848 .69075 .23793 Mtetra
.289 .787 .859 r
.69075 .23793 .69606 .23848 .70839 .23719 .70306 .23543 Mtetra
.412 .843 .948 r
.70306 .23543 .70839 .23719 .72077 .23565 .71543 .23263 Mtetra
.508 .86 .991 r
.71543 .23263 .72077 .23565 .73322 .23385 .72784 .22955 Mtetra
.569 .844 .996 r
.72784 .22955 .73322 .23385 .74572 .23182 .7403 .22625 Mtetra
.604 .812 .98 r
.7403 .22625 .74572 .23182 .75828 .22961 .75282 .2228 Mtetra
.622 .776 .955 r
.75282 .2228 .75828 .22961 .7709 .22725 .76539 .21923 Mtetra
.634 .746 .929 r
.10283 .44102 .1101 .44736 .12005 .44318 .11265 .43807 Mtetra
.631 .789 .958 r
.11265 .43807 .12005 .44318 .13005 .4389 .12251 .43504 Mtetra
.623 .833 .981 r
.12251 .43504 .13005 .4389 .14009 .43445 .13243 .43189 Mtetra
.606 .875 .992 r
.13243 .43189 .14009 .43445 .1502 .42981 .14241 .42854 Mtetra
.575 .905 .98 r
.14241 .42854 .1502 .42981 .16036 .4249 .15246 .42494 Mtetra
.525 .911 .935 r
.15246 .42494 .16036 .4249 .17058 .4197 .16258 .42107 Mtetra
.457 .887 .855 r
.16258 .42107 .17058 .4197 .18086 .41418 .17276 .41686 Mtetra
.375 .832 .747 r
.17276 .41686 .18086 .41418 .1912 .40835 .18302 .41233 Mtetra
0 0 0 r
.18302 .41233 .1912 .40835 .2016 .4022 .19335 .40745 Mtetra
.19335 .40745 .2016 .4022 .21205 .39577 .20374 .40224 Mtetra
.20374 .40224 .21205 .39577 .22254 .38908 .21419 .39673 Mtetra
.21419 .39673 .22254 .38908 .23307 .38221 .22469 .39097 Mtetra
.22469 .39097 .23307 .38221 .24363 .37524 .23523 .385 Mtetra
.028 0 0 r
.23523 .385 .24363 .37524 .25421 .36825 .24581 .3789 Mtetra
.069 0 0 r
.24581 .3789 .25421 .36825 .2648 .36133 .25642 .37273 Mtetra
.102 0 0 r
.25642 .37273 .2648 .36133 .2754 .35453 .26706 .36655 Mtetra
.13 0 0 r
.26706 .36655 .2754 .35453 .28601 .34791 .27772 .3604 Mtetra
.153 0 0 r
.27772 .3604 .28601 .34791 .29662 .34148 .2884 .35433 Mtetra
.171 0 .015 r
.2884 .35433 .29662 .34148 .30724 .33527 .2991 .34835 Mtetra
.187 0 .029 r
.2991 .34835 .30724 .33527 .31787 .3293 .30981 .34249 Mtetra
.199 0 .04 r
.30981 .34249 .31787 .3293 .32851 .32357 .32055 .33678 Mtetra
.21 0 .047 r
.32055 .33678 .32851 .32357 .33917 .31808 .3313 .33123 Mtetra
.219 0 .051 r
.3313 .33123 .33917 .31808 .34984 .31282 .34207 .32585 Mtetra
.227 0 .053 r
.34207 .32585 .34984 .31282 .36053 .3078 .35287 .32067 Mtetra
.234 0 .054 r
.35287 .32067 .36053 .3078 .37124 .30299 .36368 .31568 Mtetra
.242 0 .055 r
.36368 .31568 .37124 .30299 .38198 .29839 .37453 .3109 Mtetra
.249 0 .055 r
.37453 .3109 .38198 .29839 .39275 .29397 .3854 .30634 Mtetra
.258 0 .056 r
.3854 .30634 .39275 .29397 .40356 .28974 .3963 .30199 Mtetra
.266 0 .059 r
.3963 .30199 .40356 .28974 .41439 .28567 .40723 .29786 Mtetra
.276 0 .063 r
.40723 .29786 .41439 .28567 .42526 .28178 .41819 .29395 Mtetra
.287 0 .068 r
.41819 .29395 .42526 .28178 .43617 .27804 .4292 .29026 Mtetra
.298 0 .075 r
.4292 .29026 .43617 .27804 .44713 .27449 .44024 .28678 Mtetra
.31 0 .083 r
.44024 .28678 .44713 .27449 .45812 .27111 .45133 .28353 Mtetra
.321 0 .091 r
.45133 .28353 .45812 .27111 .46916 .26792 .46246 .28049 Mtetra
.333 0 .1 r
.46246 .28049 .46916 .26792 .48025 .26494 .47365 .27766 Mtetra
.343 0 .109 r
.47365 .27766 .48025 .26494 .49138 .26219 .48488 .27504 Mtetra
.353 0 .116 r
.48488 .27504 .49138 .26219 .50257 .25966 .49617 .27261 Mtetra
.361 0 .122 r
.49617 .27261 .50257 .25966 .51382 .25738 .50752 .27037 Mtetra
.368 0 .125 r
.50752 .27037 .51382 .25738 .52512 .25535 .51892 .26829 Mtetra
.372 0 .126 r
.51892 .26829 .52512 .25535 .53649 .25357 .53039 .26637 Mtetra
.375 0 .124 r
.53039 .26637 .53649 .25357 .54792 .25203 .54192 .26457 Mtetra
.376 0 .118 r
.54192 .26457 .54792 .25203 .55943 .25073 .55352 .26288 Mtetra
.374 0 .108 r
.55352 .26288 .55943 .25073 .571 .24963 .56519 .26126 Mtetra
.369 0 .093 r
.56519 .26126 .571 .24963 .58265 .24872 .57693 .25969 Mtetra
.359 0 .071 r
.57693 .25969 .58265 .24872 .59437 .24794 .58874 .25812 Mtetra
.344 0 .041 r
.58874 .25812 .59437 .24794 .60618 .24724 .60061 .25647 Mtetra
.321 0 0 r
.60061 .25647 .60618 .24724 .61806 .24653 .61256 .2547 Mtetra
.287 0 0 r
.61256 .2547 .61806 .24653 .63001 .24572 .62456 .25272 Mtetra
.239 0 0 r
.62456 .25272 .63001 .24572 .64203 .24473 .63663 .25049 Mtetra
.172 0 0 r
.63663 .25049 .64203 .24473 .65412 .24349 .64875 .24794 Mtetra
.081 0 0 r
.64875 .24794 .65412 .24349 .66627 .24196 .66092 .24506 Mtetra
0 0 0 r
.66092 .24506 .66627 .24196 .67848 .24011 .67314 .24181 Mtetra
.67314 .24181 .67848 .24011 .69075 .23793 .6854 .23823 Mtetra
.343 .822 .818 r
.6854 .23823 .69075 .23793 .70306 .23543 .69771 .2343 Mtetra
.48 .891 .927 r
.69771 .2343 .70306 .23543 .71543 .23263 .71005 .23008 Mtetra
.578 .906 .979 r
.71005 .23008 .71543 .23263 .72784 .22955 .72243 .22559 Mtetra
.635 .885 .986 r
.72243 .22559 .72784 .22955 .7403 .22625 .73485 .22089 Mtetra
.663 .846 .97 r
.73485 .22089 .7403 .22625 .75282 .2228 .74732 .21606 Mtetra
.674 .802 .943 r
.74732 .21606 .75282 .2228 .76539 .21923 .75983 .21113 Mtetra
.571 .727 .947 r
.09551 .43462 .10283 .44102 .11265 .43807 .10519 .43285 Mtetra
.558 .765 .975 r
.10519 .43285 .11265 .43807 .12251 .43504 .11492 .43102 Mtetra
.536 .803 .995 r
.11492 .43102 .12251 .43504 .13243 .43189 .12471 .4291 Mtetra
.504 .836 .999 r
.12471 .4291 .13243 .43189 .14241 .42854 .13457 .42702 Mtetra
.455 .852 .974 r
.13457 .42702 .14241 .42854 .15246 .42494 .1445 .42473 Mtetra
.385 .84 .911 r
.1445 .42473 .15246 .42494 .16258 .42107 .1545 .4222 Mtetra
.298 .794 .807 r
.1545 .4222 .16258 .42107 .17276 .41686 .16458 .4194 Mtetra
0 0 0 r
.16458 .4194 .17276 .41686 .18302 .41233 .17473 .41633 Mtetra
.17473 .41633 .18302 .41233 .19335 .40745 .18495 .41299 Mtetra
.18495 .41299 .19335 .40745 .20374 .40224 .19524 .40942 Mtetra
.078 0 0 r
.19524 .40942 .20374 .40224 .21419 .39673 .20558 .40565 Mtetra
.148 0 0 r
.20558 .40565 .21419 .39673 .22469 .39097 .21598 .40171 Mtetra
.204 0 0 r
.21598 .40171 .22469 .39097 .23523 .385 .22643 .39762 Mtetra
.248 0 .044 r
.22643 .39762 .23523 .385 .24581 .3789 .23693 .39342 Mtetra
.283 0 .103 r
.23693 .39342 .24581 .3789 .25642 .37273 .24748 .38912 Mtetra
.31 0 .149 r
.24748 .38912 .25642 .37273 .26706 .36655 .25807 .38474 Mtetra
.332 0 .185 r
.25807 .38474 .26706 .36655 .27772 .3604 .2687 .38029 Mtetra
.348 0 .213 r
.2687 .38029 .27772 .3604 .2884 .35433 .27937 .37579 Mtetra
.361 .015 .235 r
.27937 .37579 .2884 .35433 .2991 .34835 .29008 .37124 Mtetra
.372 .032 .253 r
.29008 .37124 .2991 .34835 .30981 .34249 .30084 .36666 Mtetra
.38 .045 .267 r
.30084 .36666 .30981 .34249 .32055 .33678 .31163 .36205 Mtetra
.387 .056 .278 r
.31163 .36205 .32055 .33678 .3313 .33123 .32246 .35743 Mtetra
.393 .066 .287 r
.32246 .35743 .3313 .33123 .34207 .32585 .33332 .35283 Mtetra
.398 .073 .294 r
.33332 .35283 .34207 .32585 .35287 .32067 .34422 .34827 Mtetra
.403 .08 .3 r
.34422 .34827 .35287 .32067 .36368 .31568 .35516 .34377 Mtetra
.407 .085 .304 r
.35516 .34377 .36368 .31568 .37453 .3109 .36613 .33936 Mtetra
.411 .09 .308 r
.36613 .33936 .37453 .3109 .3854 .30634 .37714 .33505 Mtetra
.414 .094 .311 r
.37714 .33505 .3854 .30634 .3963 .30199 .38818 .33086 Mtetra
.418 .098 .313 r
.38818 .33086 .3963 .30199 .40723 .29786 .39926 .32681 Mtetra
.421 .1 .315 r
.39926 .32681 .40723 .29786 .41819 .29395 .41038 .3229 Mtetra
.423 .103 .316 r
.41038 .3229 .41819 .29395 .4292 .29026 .42154 .31913 Mtetra
.426 .105 .316 r
.42154 .31913 .4292 .29026 .44024 .28678 .43274 .31549 Mtetra
.427 .106 .316 r
.43274 .31549 .44024 .28678 .45133 .28353 .44399 .31197 Mtetra
.429 .106 .314 r
.44399 .31197 .45133 .28353 .46246 .28049 .45529 .30856 Mtetra
.429 .105 .312 r
.45529 .30856 .46246 .28049 .47365 .27766 .46664 .30525 Mtetra
.429 .103 .309 r
.46664 .30525 .47365 .27766 .48488 .27504 .47803 .30199 Mtetra
.427 .099 .305 r
.47803 .30199 .48488 .27504 .49617 .27261 .48948 .29878 Mtetra
.425 .094 .299 r
.48948 .29878 .49617 .27261 .50752 .27037 .50099 .29558 Mtetra
.421 .087 .291 r
.50099 .29558 .50752 .27037 .51892 .26829 .51255 .29238 Mtetra
.416 .078 .281 r
.51255 .29238 .51892 .26829 .53039 .26637 .52416 .28915 Mtetra
.41 .066 .268 r
.52416 .28915 .53039 .26637 .54192 .26457 .53583 .28589 Mtetra
.401 .05 .252 r
.53583 .28589 .54192 .26457 .55352 .26288 .54755 .28258 Mtetra
.39 .031 .231 r
.54755 .28258 .55352 .26288 .56519 .26126 .55933 .27921 Mtetra
.375 .006 .204 r
.55933 .27921 .56519 .26126 .57693 .25969 .57117 .27578 Mtetra
.356 0 .17 r
.57117 .27578 .57693 .25969 .58874 .25812 .58306 .27227 Mtetra
.329 0 .125 r
.58306 .27227 .58874 .25812 .60061 .25647 .59501 .26865 Mtetra
.294 0 .068 r
.59501 .26865 .60061 .25647 .61256 .2547 .60701 .26491 Mtetra
.246 0 0 r
.60701 .26491 .61256 .2547 .62456 .25272 .61906 .26102 Mtetra
.18 0 0 r
.61906 .26102 .62456 .25272 .63663 .25049 .63115 .25696 Mtetra
.091 0 0 r
.63115 .25696 .63663 .25049 .64875 .24794 .6433 .25268 Mtetra
0 0 0 r
.6433 .25268 .64875 .24794 .66092 .24506 .65549 .24816 Mtetra
.65549 .24816 .66092 .24506 .67314 .24181 .66771 .24335 Mtetra
.335 .806 .726 r
.66771 .24335 .67314 .24181 .6854 .23823 .67998 .23827 Mtetra
.485 .901 .861 r
.67998 .23827 .6854 .23823 .69771 .2343 .69227 .23288 Mtetra
.596 .939 .941 r
.69227 .23288 .69771 .2343 .71005 .23008 .7046 .22724 Mtetra
.665 .932 .97 r
.7046 .22724 .71005 .23008 .72243 .22559 .71695 .22138 Mtetra
.701 .9 .968 r
.71695 .22138 .72243 .22559 .73485 .22089 .72934 .21534 Mtetra
.715 .858 .95 r
.72934 .21534 .73485 .22089 .74732 .21606 .74176 .20919 Mtetra
.717 .815 .926 r
.74176 .20919 .74732 .21606 .75983 .21113 .75422 .20298 Mtetra
.511 .705 .958 r
.08813 .42819 .09551 .43462 .10519 .43285 .0977 .42732 Mtetra
.49 .731 .979 r
.0977 .42732 .10519 .43285 .11492 .43102 .10733 .42646 Mtetra
.462 .757 .993 r
.10733 .42646 .11492 .43102 .12471 .4291 .11702 .42555 Mtetra
.425 .778 .996 r
.11702 .42555 .12471 .4291 .13457 .42702 .12677 .42456 Mtetra
.374 .789 .978 r
.12677 .42456 .13457 .42702 .1445 .42473 .13658 .42345 Mtetra
.305 .78 .926 r
.13658 .42345 .1445 .42473 .1545 .4222 .14647 .42217 Mtetra
.221 .742 .835 r
.14647 .42217 .1545 .4222 .16458 .4194 .15644 .42069 Mtetra
.128 .674 .709 r
.15644 .42069 .16458 .4194 .17473 .41633 .16648 .41898 Mtetra
0 0 0 r
.16648 .41898 .17473 .41633 .18495 .41299 .1766 .41701 Mtetra
.037 0 0 r
.1766 .41701 .18495 .41299 .19524 .40942 .1868 .4148 Mtetra
.098 0 0 r
.1868 .4148 .19524 .40942 .20558 .40565 .19707 .41233 Mtetra
.147 0 0 r
.19707 .41233 .20558 .40565 .21598 .40171 .20741 .40964 Mtetra
.184 0 0 r
.20741 .40964 .21598 .40171 .22643 .39762 .21782 .40672 Mtetra
.213 0 0 r
.21782 .40672 .22643 .39762 .23693 .39342 .22829 .40362 Mtetra
.236 0 0 r
.22829 .40362 .23693 .39342 .24748 .38912 .23882 .40034 Mtetra
.255 0 .009 r
.23882 .40034 .24748 .38912 .25807 .38474 .24941 .39692 Mtetra
.272 0 .043 r
.24941 .39692 .25807 .38474 .2687 .38029 .26006 .39338 Mtetra
.285 0 .071 r
.26006 .39338 .2687 .38029 .27937 .37579 .27075 .38973 Mtetra
.297 0 .095 r
.27075 .38973 .27937 .37579 .29008 .37124 .2815 .38599 Mtetra
.307 0 .116 r
.2815 .38599 .29008 .37124 .30084 .36666 .29229 .38217 Mtetra
.316 0 .134 r
.29229 .38217 .30084 .36666 .31163 .36205 .30313 .37827 Mtetra
.325 0 .15 r
.30313 .37827 .31163 .36205 .32246 .35743 .31402 .37431 Mtetra
.332 0 .163 r
.31402 .37431 .32246 .35743 .33332 .35283 .32496 .37031 Mtetra
.338 0 .175 r
.32496 .37031 .33332 .35283 .34422 .34827 .33593 .36628 Mtetra
.344 0 .185 r
.33593 .36628 .34422 .34827 .35516 .34377 .34696 .36223 Mtetra
.35 0 .193 r
.34696 .36223 .35516 .34377 .36613 .33936 .35802 .35819 Mtetra
.354 0 .2 r
.35802 .35819 .36613 .33936 .37714 .33505 .36913 .35417 Mtetra
.358 0 .205 r
.36913 .35417 .37714 .33505 .38818 .33086 .38029 .35017 Mtetra
.362 0 .209 r
.38029 .35017 .38818 .33086 .39926 .32681 .39148 .34621 Mtetra
.364 .003 .211 r
.39148 .34621 .39926 .32681 .41038 .3229 .40272 .34229 Mtetra
.365 .004 .212 r
.40272 .34229 .41038 .3229 .42154 .31913 .41401 .33841 Mtetra
.366 .004 .211 r
.41401 .33841 .42154 .31913 .43274 .31549 .42534 .33457 Mtetra
.366 .002 .209 r
.42534 .33457 .43274 .31549 .44399 .31197 .43672 .33075 Mtetra
.364 0 .204 r
.43672 .33075 .44399 .31197 .45529 .30856 .44815 .32695 Mtetra
.361 0 .198 r
.44815 .32695 .45529 .30856 .46664 .30525 .45963 .32316 Mtetra
.357 0 .191 r
.45963 .32316 .46664 .30525 .47803 .30199 .47115 .31935 Mtetra
.351 0 .181 r
.47115 .31935 .47803 .30199 .48948 .29878 .48273 .31551 Mtetra
.344 0 .169 r
.48273 .31551 .48948 .29878 .50099 .29558 .49436 .31162 Mtetra
.334 0 .154 r
.49436 .31162 .50099 .29558 .51255 .29238 .50604 .30768 Mtetra
.323 0 .137 r
.50604 .30768 .51255 .29238 .52416 .28915 .51777 .30365 Mtetra
.31 0 .117 r
.51777 .30365 .52416 .28915 .53583 .28589 .52956 .29955 Mtetra
.294 0 .094 r
.52956 .29955 .53583 .28589 .54755 .28258 .54139 .29534 Mtetra
.275 0 .066 r
.54139 .29534 .54755 .28258 .55933 .27921 .55327 .29102 Mtetra
.251 0 .032 r
.55327 .29102 .55933 .27921 .57117 .27578 .5652 .28658 Mtetra
.22 0 0 r
.5652 .28658 .57117 .27578 .58306 .27227 .57718 .28198 Mtetra
.181 0 0 r
.57718 .28198 .58306 .27227 .59501 .26865 .5892 .2772 Mtetra
.131 0 0 r
.5892 .2772 .59501 .26865 .60701 .26491 .60127 .27222 Mtetra
.064 0 0 r
.60127 .27222 .60701 .26491 .61906 .26102 .61338 .26701 Mtetra
0 0 0 r
.61338 .26701 .61906 .26102 .63115 .25696 .62552 .26156 Mtetra
.62552 .26156 .63115 .25696 .6433 .25268 .6377 .25584 Mtetra
.6377 .25584 .6433 .25268 .65549 .24816 .64991 .24985 Mtetra
.424 .857 .741 r
.64991 .24985 .65549 .24816 .66771 .24335 .66215 .24359 Mtetra
.555 .933 .857 r
.66215 .24359 .66771 .24335 .67998 .23827 .67442 .23708 Mtetra
.651 .961 .926 r
.67442 .23708 .67998 .23827 .69227 .23288 .68671 .23034 Mtetra
.708 .951 .953 r
.68671 .23034 .69227 .23288 .7046 .22724 .69902 .22342 Mtetra
.737 .922 .954 r
.69902 .22342 .7046 .22724 .71695 .22138 .71137 .21636 Mtetra
.748 .886 .942 r
.71137 .21636 .71695 .22138 .72934 .21534 .72374 .2092 Mtetra
.75 .849 .925 r
.72374 .2092 .72934 .21534 .74176 .20919 .73614 .20199 Mtetra
.746 .815 .907 r
.73614 .20199 .74176 .20919 .75422 .20298 .74857 .19475 Mtetra
.475 .691 .962 r
.0807 .4217 .08813 .42819 .0977 .42732 .09022 .4213 Mtetra
.459 .701 .972 r
.09022 .4213 .0977 .42732 .10733 .42646 .0998 .42093 Mtetra
.441 .713 .981 r
.0998 .42093 .10733 .42646 .11702 .42555 .10943 .42059 Mtetra
.419 .726 .989 r
.10943 .42059 .11702 .42555 .12677 .42456 .11911 .42024 Mtetra
.392 .737 .992 r
.11911 .42024 .12677 .42456 .13658 .42345 .12886 .41988 Mtetra
.359 .748 .987 r
.12886 .41988 .13658 .42345 .14647 .42217 .13867 .41943 Mtetra
.319 .754 .969 r
.13867 .41943 .14647 .42217 .15644 .42069 .14856 .41886 Mtetra
.273 .751 .932 r
.14856 .41886 .15644 .42069 .16648 .41898 .15852 .41811 Mtetra
.223 .736 .876 r
.15852 .41811 .16648 .41898 .1766 .41701 .16857 .41711 Mtetra
.173 .709 .803 r
.16857 .41711 .1766 .41701 .1868 .4148 .17871 .41584 Mtetra
.129 .676 .724 r
.17871 .41584 .1868 .4148 .19707 .41233 .18893 .41425 Mtetra
0 0 0 r
.18893 .41425 .19707 .41233 .20741 .40964 .19923 .41235 Mtetra
.19923 .41235 .20741 .40964 .21782 .40672 .20962 .41015 Mtetra
.20962 .41015 .21782 .40672 .22829 .40362 .22009 .40769 Mtetra
.22009 .40769 .22829 .40362 .23882 .40034 .23062 .405 Mtetra
.016 0 0 r
.23062 .405 .23882 .40034 .24941 .39692 .24122 .40212 Mtetra
.039 0 0 r
.24122 .40212 .24941 .39692 .26006 .39338 .25189 .39911 Mtetra
.061 0 0 r
.25189 .39911 .26006 .39338 .27075 .38973 .2626 .39597 Mtetra
.084 0 0 r
.2626 .39597 .27075 .38973 .2815 .38599 .27337 .39274 Mtetra
.105 0 0 r
.27337 .39274 .2815 .38599 .29229 .38217 .2842 .38943 Mtetra
.126 0 0 r
.2842 .38943 .29229 .38217 .30313 .37827 .29508 .38605 Mtetra
.146 0 0 r
.29508 .38605 .30313 .37827 .31402 .37431 .30601 .38261 Mtetra
.164 0 0 r
.30601 .38261 .31402 .37431 .32496 .37031 .31699 .3791 Mtetra
.18 0 0 r
.31699 .3791 .32496 .37031 .33593 .36628 .32802 .37554 Mtetra
.193 0 0 r
.32802 .37554 .33593 .36628 .34696 .36223 .3391 .37191 Mtetra
.204 0 0 r
.3391 .37191 .34696 .36223 .35802 .35819 .35023 .36822 Mtetra
.213 0 0 r
.35023 .36822 .35802 .35819 .36913 .35417 .36141 .36448 Mtetra
.219 0 0 r
.36141 .36448 .36913 .35417 .38029 .35017 .37264 .36067 Mtetra
.222 0 0 r
.37264 .36067 .38029 .35017 .39148 .34621 .38392 .3568 Mtetra
.38392 .3568 .39148 .34621 .40272 .34229 .39526 .35286 Mtetra
.219 0 0 r
.39526 .35286 .40272 .34229 .41401 .33841 .40664 .34886 Mtetra
.214 0 0 r
.40664 .34886 .41401 .33841 .42534 .33457 .41807 .3448 Mtetra
.206 0 0 r
.41807 .3448 .42534 .33457 .43672 .33075 .42955 .34067 Mtetra
.195 0 0 r
.42955 .34067 .43672 .33075 .44815 .32695 .44108 .33649 Mtetra
.18 0 0 r
.44108 .33649 .44815 .32695 .45963 .32316 .45266 .33224 Mtetra
.163 0 0 r
.45266 .33224 .45963 .32316 .47115 .31935 .46429 .32792 Mtetra
.142 0 0 r
.46429 .32792 .47115 .31935 .48273 .31551 .47597 .32355 Mtetra
.118 0 0 r
.47597 .32355 .48273 .31551 .49436 .31162 .48769 .31911 Mtetra
.09 0 0 r
.48769 .31911 .49436 .31162 .50604 .30768 .49946 .31459 Mtetra
.06 0 0 r
.49946 .31459 .50604 .30768 .51777 .30365 .51128 .31001 Mtetra
.025 0 0 r
.51128 .31001 .51777 .30365 .52956 .29955 .52315 .30534 Mtetra
0 0 0 r
.52315 .30534 .52956 .29955 .54139 .29534 .53507 .30058 Mtetra
.53507 .30058 .54139 .29534 .55327 .29102 .54703 .29568 Mtetra
.54703 .29568 .55327 .29102 .5652 .28658 .55904 .29064 Mtetra
.55904 .29064 .5652 .28658 .57718 .28198 .57109 .28539 Mtetra
.57109 .28539 .57718 .28198 .5892 .2772 .58318 .27991 Mtetra
.316 .78 .654 r
.58318 .27991 .5892 .2772 .60127 .27222 .5953 .27416 Mtetra
.407 .847 .733 r
.5953 .27416 .60127 .27222 .61338 .26701 .60746 .26808 Mtetra
.501 .906 .81 r
.60746 .26808 .61338 .26701 .62552 .26156 .61965 .26167 Mtetra
.59 .948 .874 r
.61965 .26167 .62552 .26156 .6377 .25584 .63187 .25492 Mtetra
.662 .967 .918 r
.63187 .25492 .6377 .25584 .64991 .24985 .64411 .24788 Mtetra
.714 .964 .941 r
.64411 .24788 .64991 .24985 .66215 .24359 .65637 .24057 Mtetra
.745 .945 .947 r
.65637 .24057 .66215 .24359 .67442 .23708 .66865 .23306 Mtetra
.761 .919 .942 r
.66865 .23306 .67442 .23708 .68671 .23034 .68096 .2254 Mtetra
.767 .891 .932 r
.68096 .2254 .68671 .23034 .69902 .22342 .69329 .21764 Mtetra
.767 .865 .921 r
.69329 .21764 .69902 .22342 .71137 .21636 .70564 .20985 Mtetra
.765 .842 .91 r
.70564 .20985 .71137 .21636 .72374 .2092 .71802 .20204 Mtetra
.761 .822 .9 r
.71802 .20204 .72374 .2092 .73614 .20199 .73043 .19424 Mtetra
.756 .804 .891 r
.73043 .19424 .73614 .20199 .74857 .19475 .74288 .18646 Mtetra
.501 .701 .959 r
.07322 .41517 .0807 .4217 .09022 .4213 .0828 .4144 Mtetra
.503 .69 .952 r
.0828 .4144 .09022 .4213 .0998 .42093 .09243 .41369 Mtetra
.505 .68 .944 r
.09243 .41369 .0998 .42093 .10943 .42059 .10211 .41302 Mtetra
.506 .67 .937 r
.10211 .41302 .10943 .42059 .11911 .42024 .11184 .41239 Mtetra
.507 .662 .931 r
.11184 .41239 .11911 .42024 .12886 .41988 .12162 .41181 Mtetra
.51 .657 .926 r
.12162 .41181 .12886 .41988 .13867 .41943 .13146 .41121 Mtetra
.513 .655 .923 r
.13146 .41121 .13867 .41943 .14856 .41886 .14136 .41059 Mtetra
.518 .656 .922 r
.14136 .41059 .14856 .41886 .15852 .41811 .15132 .40988 Mtetra
.524 .661 .922 r
.15132 .40988 .15852 .41811 .16857 .41711 .16136 .40905 Mtetra
.531 .669 .926 r
.16136 .40905 .16857 .41711 .17871 .41584 .17148 .40806 Mtetra
.538 .682 .932 r
.17148 .40806 .17871 .41584 .18893 .41425 .18167 .40688 Mtetra
.544 .698 .941 r
.18167 .40688 .18893 .41425 .19923 .41235 .19194 .40551 Mtetra
.549 .719 .952 r
.19194 .40551 .19923 .41235 .20962 .41015 .20228 .40394 Mtetra
.551 .742 .965 r
.20228 .40394 .20962 .41015 .22009 .40769 .2127 .40218 Mtetra
.549 .767 .979 r
.2127 .40218 .22009 .40769 .23062 .405 .22319 .40025 Mtetra
.542 .793 .991 r
.22319 .40025 .23062 .405 .24122 .40212 .23375 .39817 Mtetra
.53 .817 .998 r
.23375 .39817 .24122 .40212 .25189 .39911 .24437 .39595 Mtetra
.51 .837 .999 r
.24437 .39595 .25189 .39911 .2626 .39597 .25505 .3936 Mtetra
.482 .85 .989 r
.25505 .3936 .2626 .39597 .27337 .39274 .2658 .39113 Mtetra
.449 .854 .967 r
.2658 .39113 .27337 .39274 .2842 .38943 .27661 .38855 Mtetra
.41 .848 .935 r
.27661 .38855 .2842 .38943 .29508 .38605 .28749 .38584 Mtetra
.37 .834 .894 r
.28749 .38584 .29508 .38605 .30601 .38261 .29842 .38301 Mtetra
.331 .815 .849 r
.29842 .38301 .30601 .38261 .31699 .3791 .30941 .38005 Mtetra
.296 .793 .803 r
.30941 .38005 .31699 .3791 .32802 .37554 .32046 .37696 Mtetra
.268 .772 .762 r
.32046 .37696 .32802 .37554 .3391 .37191 .33158 .37372 Mtetra
.245 .754 .726 r
.33158 .37372 .3391 .37191 .35023 .36822 .34275 .37035 Mtetra
.231 .74 .698 r
.34275 .37035 .35023 .36822 .36141 .36448 .35398 .36683 Mtetra
.223 .732 .678 r
.35398 .36683 .36141 .36448 .37264 .36067 .36526 .36317 Mtetra
0 0 0 r
.36526 .36317 .37264 .36067 .38392 .3568 .3766 .35936 Mtetra
.3766 .35936 .38392 .3568 .39526 .35286 .388 .35541 Mtetra
.244 .743 .672 r
.388 .35541 .39526 .35286 .40664 .34886 .39945 .3513 Mtetra
.265 .758 .686 r
.39945 .3513 .40664 .34886 .41807 .3448 .41095 .34704 Mtetra
.293 .779 .709 r
.41095 .34704 .41807 .3448 .42955 .34067 .42251 .34264 Mtetra
.328 .805 .739 r
.42251 .34264 .42955 .34067 .44108 .33649 .43411 .33809 Mtetra
.37 .834 .775 r
.43411 .33809 .44108 .33649 .45266 .33224 .44577 .3334 Mtetra
.417 .864 .816 r
.44577 .3334 .45266 .33224 .46429 .32792 .45747 .32856 Mtetra
.468 .892 .857 r
.45747 .32856 .46429 .32792 .47597 .32355 .46922 .32358 Mtetra
.519 .916 .897 r
.46922 .32358 .47597 .32355 .48769 .31911 .48101 .31847 Mtetra
.568 .931 .931 r
.48101 .31847 .48769 .31911 .49946 .31459 .49285 .31323 Mtetra
.612 .937 .956 r
.49285 .31323 .49946 .31459 .51128 .31001 .50474 .30785 Mtetra
.648 .932 .97 r
.50474 .30785 .51128 .31001 .52315 .30534 .51666 .30236 Mtetra
.676 .918 .974 r
.51666 .30236 .52315 .30534 .53507 .30058 .52863 .29673 Mtetra
.696 .897 .969 r
.52863 .29673 .53507 .30058 .54703 .29568 .54064 .29096 Mtetra
.71 .872 .958 r
.54064 .29096 .54703 .29568 .55904 .29064 .55269 .28505 Mtetra
.718 .846 .943 r
.55269 .28505 .55904 .29064 .57109 .28539 .56477 .27897 Mtetra
.723 .821 .926 r
.56477 .27897 .57109 .28539 .58318 .27991 .57689 .2727 Mtetra
.726 .798 .909 r
.57689 .2727 .58318 .27991 .5953 .27416 .58905 .26623 Mtetra
.728 .779 .893 r
.58905 .26623 .5953 .27416 .60746 .26808 .60123 .25954 Mtetra
.729 .764 .88 r
.60123 .25954 .60746 .26808 .61965 .26167 .61345 .25265 Mtetra
.731 .753 .87 r
.61345 .25265 .61965 .26167 .63187 .25492 .62569 .24554 Mtetra
.732 .745 .862 r
.62569 .24554 .63187 .25492 .64411 .24788 .63796 .23826 Mtetra
.733 .741 .857 r
.63796 .23826 .64411 .24788 .65637 .24057 .65025 .23084 Mtetra
.735 .739 .855 r
.65025 .23084 .65637 .24057 .66865 .23306 .66257 .22332 Mtetra
.736 .74 .855 r
.66257 .22332 .66865 .23306 .68096 .2254 .67492 .21575 Mtetra
.737 .744 .857 r
.67492 .21575 .68096 .2254 .69329 .21764 .6873 .20816 Mtetra
.737 .749 .861 r
.6873 .20816 .69329 .21764 .70564 .20985 .6997 .2006 Mtetra
.738 .756 .867 r
.6997 .2006 .70564 .20985 .71802 .20204 .71215 .19306 Mtetra
.74 .765 .873 r
.71215 .19306 .71802 .20204 .73043 .19424 .72462 .18556 Mtetra
.741 .774 .88 r
.72462 .18556 .73043 .19424 .74288 .18646 .73713 .1781 Mtetra
.56 .723 .95 r
.06568 .40859 .07322 .41517 .0828 .4144 .0754 .40691 Mtetra
.565 .696 .929 r
.0754 .40691 .0828 .4144 .09243 .41369 .08516 .40528 Mtetra
.567 .669 .907 r
.08516 .40528 .09243 .41369 .10211 .41302 .09497 .4037 Mtetra
.567 .645 .887 r
.09497 .4037 .10211 .41302 .11184 .41239 .10482 .40219 Mtetra
.565 .623 .868 r
.10482 .40219 .11184 .41239 .12162 .41181 .11471 .40075 Mtetra
.564 .604 .851 r
.11471 .40075 .12162 .41181 .13146 .41121 .12464 .39936 Mtetra
.562 .587 .836 r
.12464 .39936 .13146 .41121 .14136 .41059 .13462 .39803 Mtetra
.561 .574 .824 r
.13462 .39803 .14136 .41059 .15132 .40988 .14466 .39672 Mtetra
.561 .564 .814 r
.14466 .39672 .15132 .40988 .16136 .40905 .15474 .39541 Mtetra
.561 .557 .806 r
.15474 .39541 .16136 .40905 .17148 .40806 .16489 .39411 Mtetra
.561 .552 .802 r
.16489 .39411 .17148 .40806 .18167 .40688 .17509 .39278 Mtetra
.562 .551 .8 r
.17509 .39278 .18167 .40688 .19194 .40551 .18535 .39143 Mtetra
.563 .553 .801 r
.18535 .39143 .19194 .40551 .20228 .40394 .19567 .39002 Mtetra
.565 .557 .804 r
.19567 .39002 .20228 .40394 .2127 .40218 .20605 .38856 Mtetra
.568 .564 .809 r
.20605 .38856 .2127 .40218 .22319 .40025 .2165 .387 Mtetra
.571 .572 .815 r
.2165 .387 .22319 .40025 .23375 .39817 .22702 .38535 Mtetra
.574 .582 .823 r
.22702 .38535 .23375 .39817 .24437 .39595 .2376 .38359 Mtetra
.578 .593 .832 r
.2376 .38359 .24437 .39595 .25505 .3936 .24825 .38172 Mtetra
.583 .605 .84 r
.24825 .38172 .25505 .3936 .2658 .39113 .25896 .3797 Mtetra
.588 .617 .849 r
.25896 .3797 .2658 .39113 .27661 .38855 .26975 .37755 Mtetra
.593 .63 .857 r
.26975 .37755 .27661 .38855 .28749 .38584 .2806 .37523 Mtetra
.599 .641 .864 r
.2806 .37523 .28749 .38584 .29842 .38301 .29152 .37274 Mtetra
.605 .653 .871 r
.29152 .37274 .29842 .38301 .30941 .38005 .3025 .37007 Mtetra
.611 .663 .876 r
.3025 .37007 .30941 .38005 .32046 .37696 .31355 .36722 Mtetra
.618 .673 .88 r
.31355 .36722 .32046 .37696 .33158 .37372 .32467 .36418 Mtetra
.624 .681 .883 r
.32467 .36418 .33158 .37372 .34275 .37035 .33585 .36095 Mtetra
.631 .688 .885 r
.33585 .36095 .34275 .37035 .35398 .36683 .34709 .35753 Mtetra
.637 .693 .886 r
.34709 .35753 .35398 .36683 .36526 .36317 .3584 .35391 Mtetra
.643 .698 .886 r
.3584 .35391 .36526 .36317 .3766 .35936 .36976 .35011 Mtetra
.649 .701 .884 r
.36976 .35011 .3766 .35936 .388 .35541 .38118 .34612 Mtetra
.654 .703 .883 r
.38118 .34612 .388 .35541 .39945 .3513 .39265 .34194 Mtetra
.66 .704 .88 r
.39265 .34194 .39945 .3513 .41095 .34704 .40418 .33757 Mtetra
.665 .704 .876 r
.40418 .33757 .41095 .34704 .42251 .34264 .41577 .33301 Mtetra
.669 .702 .872 r
.41577 .33301 .42251 .34264 .43411 .33809 .4274 .32825 Mtetra
.673 .7 .867 r
.4274 .32825 .43411 .33809 .44577 .3334 .43909 .3233 Mtetra
.677 .696 .86 r
.43909 .3233 .44577 .3334 .45747 .32856 .45082 .31815 Mtetra
.68 .691 .853 r
.45082 .31815 .45747 .32856 .46922 .32358 .4626 .31281 Mtetra
.682 .685 .846 r
.4626 .31281 .46922 .32358 .48101 .31847 .47443 .30728 Mtetra
.684 .678 .838 r
.47443 .30728 .48101 .31847 .49285 .31323 .48629 .30157 Mtetra
.685 .669 .829 r
.48629 .30157 .49285 .31323 .50474 .30785 .4982 .29569 Mtetra
.685 .661 .821 r
.4982 .29569 .50474 .30785 .51666 .30236 .51015 .28965 Mtetra
.684 .652 .812 r
.51015 .28965 .51666 .30236 .52863 .29673 .52213 .28348 Mtetra
.683 .642 .803 r
.52213 .28348 .52863 .29673 .54064 .29096 .53416 .27716 Mtetra
.681 .634 .795 r
.53416 .27716 .54064 .29096 .55269 .28505 .54622 .27073 Mtetra
.68 .626 .788 r
.54622 .27073 .55269 .28505 .56477 .27897 .55831 .26419 Mtetra
.679 .619 .782 r
.55831 .26419 .56477 .27897 .57689 .2727 .57044 .25755 Mtetra
.678 .614 .778 r
.57044 .25755 .57689 .2727 .58905 .26623 .5826 .25083 Mtetra
.677 .611 .775 r
.5826 .25083 .58905 .26623 .60123 .25954 .59479 .24406 Mtetra
.677 .611 .774 r
.59479 .24406 .60123 .25954 .61345 .25265 .60702 .23724 Mtetra
.678 .612 .775 r
.60702 .23724 .61345 .25265 .62569 .24554 .61929 .23039 Mtetra
.68 .617 .779 r
.61929 .23039 .62569 .24554 .63796 .23826 .63158 .22352 Mtetra
.682 .625 .784 r
.63158 .22352 .63796 .23826 .65025 .23084 .64392 .21665 Mtetra
.686 .635 .793 r
.64392 .21665 .65025 .23084 .66257 .22332 .65628 .20979 Mtetra
.69 .647 .803 r
.65628 .20979 .66257 .22332 .67492 .21575 .66869 .20298 Mtetra
.694 .663 .815 r
.66869 .20298 .67492 .21575 .6873 .20816 .68114 .19621 Mtetra
.698 .68 .829 r
.68114 .19621 .6873 .20816 .6997 .2006 .69362 .1895 Mtetra
.703 .701 .845 r
.69362 .1895 .6997 .2006 .71215 .19306 .70615 .18285 Mtetra
.708 .723 .862 r
.70615 .18285 .71215 .19306 .72462 .18556 .71873 .17624 Mtetra
.713 .749 .88 r
.71873 .17624 .72462 .18556 .73713 .1781 .73134 .16968 Mtetra
.626 .744 .932 r
.05808 .40196 .06568 .40859 .0754 .40691 .06799 .39903 Mtetra
.625 .706 .904 r
.06799 .39903 .0754 .40691 .08516 .40528 .07794 .39615 Mtetra
.62 .671 .877 r
.07794 .39615 .08516 .40528 .09497 .4037 .08792 .39333 Mtetra
.614 .64 .853 r
.08792 .39333 .09497 .4037 .10482 .40219 .09793 .39059 Mtetra
.607 .613 .831 r
.09793 .39059 .10482 .40219 .11471 .40075 .10798 .38796 Mtetra
.601 .589 .811 r
.10798 .38796 .11471 .40075 .12464 .39936 .11805 .38542 Mtetra
.595 .568 .794 r
.11805 .38542 .12464 .39936 .13462 .39803 .12817 .38296 Mtetra
.59 .551 .778 r
.12817 .38296 .13462 .39803 .14466 .39672 .13832 .38058 Mtetra
.586 .535 .765 r
.13832 .38058 .14466 .39672 .15474 .39541 .14851 .37824 Mtetra
.583 .522 .753 r
.14851 .37824 .15474 .39541 .16489 .39411 .15875 .37593 Mtetra
.58 .511 .742 r
.15875 .37593 .16489 .39411 .17509 .39278 .16904 .37362 Mtetra
.578 .501 .732 r
.16904 .37362 .17509 .39278 .18535 .39143 .17938 .3713 Mtetra
.577 .492 .723 r
.17938 .3713 .18535 .39143 .19567 .39002 .18978 .36894 Mtetra
.575 .484 .714 r
.18978 .36894 .19567 .39002 .20605 .38856 .20023 .36654 Mtetra
.574 .478 .707 r
.20023 .36654 .20605 .38856 .2165 .387 .21074 .36408 Mtetra
.574 .471 .7 r
.21074 .36408 .2165 .387 .22702 .38535 .2213 .36155 Mtetra
.573 .466 .694 r
.2213 .36155 .22702 .38535 .2376 .38359 .23192 .35896 Mtetra
.573 .461 .688 r
.23192 .35896 .2376 .38359 .24825 .38172 .24261 .35628 Mtetra
.573 .457 .683 r
.24261 .35628 .24825 .38172 .25896 .3797 .25334 .35352 Mtetra
.572 .453 .679 r
.25334 .35352 .25896 .3797 .26975 .37755 .26414 .35068 Mtetra
.573 .45 .675 r
.26414 .35068 .26975 .37755 .2806 .37523 .275 .34774 Mtetra
.573 .448 .672 r
.275 .34774 .2806 .37523 .29152 .37274 .28591 .34469 Mtetra
.574 .446 .669 r
.28591 .34469 .29152 .37274 .3025 .37007 .29688 .34153 Mtetra
.574 .445 .666 r
.29688 .34153 .3025 .37007 .31355 .36722 .30792 .33826 Mtetra
.575 .444 .664 r
.30792 .33826 .31355 .36722 .32467 .36418 .31901 .33486 Mtetra
.576 .443 .663 r
.31901 .33486 .32467 .36418 .33585 .36095 .33015 .33133 Mtetra
.577 .443 .662 r
.33015 .33133 .33585 .36095 .34709 .35753 .34136 .32768 Mtetra
.578 .443 .661 r
.34136 .32768 .34709 .35753 .3584 .35391 .35262 .3239 Mtetra
.58 .444 .66 r
.35262 .3239 .3584 .35391 .36976 .35011 .36393 .31999 Mtetra
.581 .444 .66 r
.36393 .31999 .36976 .35011 .38118 .34612 .3753 .31595 Mtetra
.583 .445 .66 r
.3753 .31595 .38118 .34612 .39265 .34194 .38673 .31178 Mtetra
.584 .447 .66 r
.38673 .31178 .39265 .34194 .40418 .33757 .3982 .30747 Mtetra
.586 .448 .66 r
.3982 .30747 .40418 .33757 .41577 .33301 .40973 .30304 Mtetra
.588 .45 .661 r
.40973 .30304 .41577 .33301 .4274 .32825 .42131 .29847 Mtetra
.59 .452 .662 r
.42131 .29847 .4274 .32825 .43909 .3233 .43294 .29378 Mtetra
.592 .455 .663 r
.43294 .29378 .43909 .3233 .45082 .31815 .44462 .28896 Mtetra
.594 .458 .665 r
.44462 .28896 .45082 .31815 .4626 .31281 .45634 .28401 Mtetra
.596 .461 .667 r
.45634 .28401 .4626 .31281 .47443 .30728 .46811 .27895 Mtetra
.599 .465 .67 r
.46811 .27895 .47443 .30728 .48629 .30157 .47993 .27378 Mtetra
.601 .469 .673 r
.47993 .27378 .48629 .30157 .4982 .29569 .49179 .2685 Mtetra
.604 .474 .677 r
.49179 .2685 .4982 .29569 .51015 .28965 .5037 .26313 Mtetra
.607 .479 .68 r
.5037 .26313 .51015 .28965 .52213 .28348 .51565 .25767 Mtetra
.61 .485 .685 r
.51565 .25767 .52213 .28348 .53416 .27716 .52764 .25213 Mtetra
.614 .492 .69 r
.52764 .25213 .53416 .27716 .54622 .27073 .53967 .2465 Mtetra
.617 .499 .696 r
.53967 .2465 .54622 .27073 .55831 .26419 .55175 .2408 Mtetra
.621 .506 .702 r
.55175 .2408 .55831 .26419 .57044 .25755 .56387 .23503 Mtetra
.625 .515 .708 r
.56387 .23503 .57044 .25755 .5826 .25083 .57603 .22921 Mtetra
.629 .524 .716 r
.57603 .22921 .5826 .25083 .59479 .24406 .58823 .22334 Mtetra
.633 .533 .724 r
.58823 .22334 .59479 .24406 .60702 .23724 .60047 .21745 Mtetra
.637 .544 .732 r
.60047 .21745 .60702 .23724 .61929 .23039 .61276 .21156 Mtetra
.641 .555 .742 r
.61276 .21156 .61929 .23039 .63158 .22352 .62508 .20569 Mtetra
.645 .568 .753 r
.62508 .20569 .63158 .22352 .64392 .21665 .63746 .19986 Mtetra
.649 .582 .766 r
.63746 .19986 .64392 .21665 .65628 .20979 .64988 .19408 Mtetra
.653 .598 .78 r
.64988 .19408 .65628 .20979 .66869 .20298 .66235 .1884 Mtetra
.657 .616 .797 r
.66235 .1884 .66869 .20298 .68114 .19621 .67487 .18279 Mtetra
.661 .638 .816 r
.67487 .18279 .68114 .19621 .69362 .1895 .68745 .17729 Mtetra
.666 .663 .837 r
.68745 .17729 .69362 .1895 .70615 .18285 .70008 .17187 Mtetra
.671 .691 .861 r
.70008 .17187 .70615 .18285 .71873 .17624 .71276 .1665 Mtetra
.675 .724 .886 r
.71276 .1665 .71873 .17624 .73134 .16968 .7255 .16118 Mtetra
.682 .757 .908 r
.05043 .39529 .05808 .40196 .06799 .39903 .06056 .39095 Mtetra
.674 .716 .88 r
.06056 .39095 .06799 .39903 .07794 .39615 .07072 .38667 Mtetra
.665 .68 .854 r
.07072 .38667 .07794 .39615 .08792 .39333 .0809 .38246 Mtetra
.654 .647 .83 r
.0809 .38246 .08792 .39333 .09793 .39059 .0911 .37833 Mtetra
.644 .618 .809 r
.0911 .37833 .09793 .39059 .10798 .38796 .10133 .37434 Mtetra
.634 .592 .79 r
.10133 .37434 .10798 .38796 .11805 .38542 .11158 .37045 Mtetra
.625 .57 .772 r
.11158 .37045 .11805 .38542 .12817 .38296 .12185 .36667 Mtetra
.617 .55 .757 r
.12185 .36667 .12817 .38296 .13832 .38058 .13215 .36298 Mtetra
.611 .533 .743 r
.13215 .36298 .13832 .38058 .14851 .37824 .14248 .35934 Mtetra
.605 .519 .73 r
.14248 .35934 .14851 .37824 .15875 .37593 .15285 .35572 Mtetra
.601 .506 .718 r
.15285 .35572 .15875 .37593 .16904 .37362 .16327 .3521 Mtetra
.597 .494 .707 r
.16327 .3521 .16904 .37362 .17938 .3713 .17373 .34845 Mtetra
.594 .484 .697 r
.17373 .34845 .17938 .3713 .18978 .36894 .18424 .34475 Mtetra
.591 .474 .688 r
.18424 .34475 .18978 .36894 .20023 .36654 .19479 .341 Mtetra
.588 .465 .68 r
.19479 .341 .20023 .36654 .21074 .36408 .20539 .33722 Mtetra
.586 .457 .672 r
.20539 .33722 .21074 .36408 .2213 .36155 .21604 .3334 Mtetra
.583 .45 .665 r
.21604 .3334 .2213 .36155 .23192 .35896 .22673 .32956 Mtetra
.58 .443 .659 r
.22673 .32956 .23192 .35896 .24261 .35628 .23746 .32571 Mtetra
.578 .437 .654 r
.23746 .32571 .24261 .35628 .25334 .35352 .24824 .32184 Mtetra
.576 .432 .649 r
.24824 .32184 .25334 .35352 .26414 .35068 .25907 .31797 Mtetra
.574 .428 .645 r
.25907 .31797 .26414 .35068 .275 .34774 .26993 .3141 Mtetra
.573 .424 .641 r
.26993 .3141 .275 .34774 .28591 .34469 .28085 .31022 Mtetra
.571 .421 .638 r
.28085 .31022 .28591 .34469 .29688 .34153 .29181 .30633 Mtetra
.57 .418 .636 r
.29181 .30633 .29688 .34153 .30792 .33826 .30281 .30243 Mtetra
.569 .416 .633 r
.30281 .30243 .30792 .33826 .31901 .33486 .31386 .2985 Mtetra
.569 .414 .632 r
.31386 .2985 .31901 .33486 .33015 .33133 .32496 .29455 Mtetra
.568 .413 .631 r
.32496 .29455 .33015 .33133 .34136 .32768 .33611 .29057 Mtetra
.568 .412 .63 r
.33611 .29057 .34136 .32768 .35262 .3239 .34731 .28655 Mtetra
.568 .412 .629 r
.34731 .28655 .35262 .3239 .36393 .31999 .35855 .28249 Mtetra
.568 .411 .629 r
.35855 .28249 .36393 .31999 .3753 .31595 .36985 .27839 Mtetra
.569 .412 .629 r
.36985 .27839 .3753 .31595 .38673 .31178 .38119 .27425 Mtetra
.38119 .27425 .38673 .31178 .3982 .30747 .39258 .27008 Mtetra
.569 .413 .63 r
.39258 .27008 .3982 .30747 .40973 .30304 .40402 .26586 Mtetra
.57 .414 .631 r
.40402 .26586 .40973 .30304 .42131 .29847 .41551 .26162 Mtetra
.571 .415 .632 r
.41551 .26162 .42131 .29847 .43294 .29378 .42705 .25734 Mtetra
.571 .417 .633 r
.42705 .25734 .43294 .29378 .44462 .28896 .43864 .25305 Mtetra
.572 .419 .636 r
.43864 .25305 .44462 .28896 .45634 .28401 .45028 .24873 Mtetra
.573 .422 .638 r
.45028 .24873 .45634 .28401 .46811 .27895 .46196 .24441 Mtetra
.575 .425 .641 r
.46196 .24441 .46811 .27895 .47993 .27378 .4737 .24007 Mtetra
.576 .429 .645 r
.4737 .24007 .47993 .27378 .49179 .2685 .48548 .23573 Mtetra
.578 .433 .649 r
.48548 .23573 .49179 .2685 .5037 .26313 .49732 .23138 Mtetra
.579 .438 .653 r
.49732 .23138 .5037 .26313 .51565 .25767 .50921 .22702 Mtetra
.582 .444 .659 r
.50921 .22702 .51565 .25767 .52764 .25213 .52115 .22265 Mtetra
.584 .451 .665 r
.52115 .22265 .52764 .25213 .53967 .2465 .53314 .21824 Mtetra
.587 .458 .672 r
.53314 .21824 .53967 .2465 .55175 .2408 .54518 .21381 Mtetra
.591 .467 .679 r
.54518 .21381 .55175 .2408 .56387 .23503 .55727 .20932 Mtetra
.595 .476 .688 r
.55727 .20932 .56387 .23503 .57603 .22921 .56942 .20479 Mtetra
.599 .486 .697 r
.56942 .20479 .57603 .22921 .58823 .22334 .58162 .2002 Mtetra
.603 .497 .707 r
.58162 .2002 .58823 .22334 .60047 .21745 .59387 .19558 Mtetra
.607 .509 .717 r
.59387 .19558 .60047 .21745 .61276 .21156 .60617 .19095 Mtetra
.611 .522 .729 r
.60617 .19095 .61276 .21156 .62508 .20569 .61853 .18634 Mtetra
.614 .535 .742 r
.61853 .18634 .62508 .20569 .63746 .19986 .63094 .18178 Mtetra
.617 .55 .757 r
.63094 .18178 .63746 .19986 .64988 .19408 .64342 .1773 Mtetra
.62 .567 .773 r
.64342 .1773 .64988 .19408 .66235 .1884 .65595 .17293 Mtetra
.623 .586 .792 r
.65595 .17293 .66235 .1884 .67487 .18279 .66855 .16868 Mtetra
.625 .608 .814 r
.66855 .16868 .67487 .18279 .68745 .17729 .68121 .16454 Mtetra
.627 .634 .838 r
.68121 .16454 .68745 .17729 .70008 .17187 .69395 .1605 Mtetra
.629 .665 .866 r
.69395 .1605 .70008 .17187 .71276 .1665 .70675 .15653 Mtetra
.63 .7 .896 r
.70675 .15653 .71276 .1665 .7255 .16118 .71961 .15261 Mtetra
.724 .765 .885 r
.04273 .38856 .05043 .39529 .06056 .39095 .05308 .38284 Mtetra
.713 .726 .861 r
.05308 .38284 .06056 .39095 .07072 .38667 .06345 .37717 Mtetra
.701 .692 .838 r
.06345 .37717 .07072 .38667 .0809 .38246 .07384 .37157 Mtetra
.689 .66 .817 r
.07384 .37157 .0809 .38246 .0911 .37833 .08425 .36606 Mtetra
.676 .632 .798 r
.08425 .36606 .0911 .37833 .10133 .37434 .09466 .36067 Mtetra
.664 .607 .78 r
.09466 .36067 .10133 .37434 .11158 .37045 .10509 .35541 Mtetra
.654 .584 .764 r
.10509 .35541 .11158 .37045 .12185 .36667 .11553 .35027 Mtetra
.644 .564 .75 r
.11553 .35027 .12185 .36667 .13215 .36298 .12599 .34524 Mtetra
.635 .546 .737 r
.12599 .34524 .13215 .36298 .14248 .35934 .13647 .3403 Mtetra
.628 .531 .725 r
.13647 .3403 .14248 .35934 .15285 .35572 .14697 .33544 Mtetra
.622 .517 .714 r
.14697 .33544 .15285 .35572 .16327 .3521 .1575 .33064 Mtetra
.616 .506 .705 r
.1575 .33064 .16327 .3521 .17373 .34845 .16806 .32589 Mtetra
.612 .496 .697 r
.16806 .32589 .17373 .34845 .18424 .34475 .17865 .32117 Mtetra
.607 .488 .69 r
.17865 .32117 .18424 .34475 .19479 .341 .18928 .31649 Mtetra
.604 .48 .685 r
.18928 .31649 .19479 .341 .20539 .33722 .19993 .31184 Mtetra
.601 .474 .679 r
.19993 .31184 .20539 .33722 .21604 .3334 .21062 .30723 Mtetra
.598 .468 .675 r
.21062 .30723 .21604 .3334 .22673 .32956 .22134 .30267 Mtetra
.595 .463 .671 r
.22134 .30267 .22673 .32956 .23746 .32571 .2321 .29815 Mtetra
.592 .458 .668 r
.2321 .29815 .23746 .32571 .24824 .32184 .24289 .29367 Mtetra
.59 .454 .665 r
.24289 .29367 .24824 .32184 .25907 .31797 .25371 .28925 Mtetra
.588 .451 .662 r
.25371 .28925 .25907 .31797 .26993 .3141 .26457 .28487 Mtetra
.586 .448 .66 r
.26457 .28487 .26993 .3141 .28085 .31022 .27547 .28054 Mtetra
.584 .445 .658 r
.27547 .28054 .28085 .31022 .29181 .30633 .28641 .27624 Mtetra
.583 .443 .656 r
.28641 .27624 .29181 .30633 .30281 .30243 .29739 .27197 Mtetra
.582 .441 .654 r
.29739 .27197 .30281 .30243 .31386 .2985 .30841 .26773 Mtetra
.581 .439 .653 r
.30841 .26773 .31386 .2985 .32496 .29455 .31947 .26352 Mtetra
.58 .437 .652 r
.31947 .26352 .32496 .29455 .33611 .29057 .33058 .25933 Mtetra
.579 .436 .651 r
.33058 .25933 .33611 .29057 .34731 .28655 .34173 .25515 Mtetra
.578 .435 .651 r
.34173 .25515 .34731 .28655 .35855 .28249 .35292 .25099 Mtetra
.35292 .25099 .35855 .28249 .36985 .27839 .36416 .24684 Mtetra
.577 .435 .651 r
.36416 .24684 .36985 .27839 .38119 .27425 .37544 .2427 Mtetra
.37544 .2427 .38119 .27425 .39258 .27008 .38677 .23858 Mtetra
.577 .435 .652 r
.38677 .23858 .39258 .27008 .40402 .26586 .39815 .23448 Mtetra
.39815 .23448 .40402 .26586 .41551 .26162 .40958 .23039 Mtetra
.576 .436 .653 r
.40958 .23039 .41551 .26162 .42705 .25734 .42105 .22633 Mtetra
.576 .437 .655 r
.42105 .22633 .42705 .25734 .43864 .25305 .43258 .2223 Mtetra
.576 .438 .656 r
.43258 .2223 .43864 .25305 .45028 .24873 .44415 .2183 Mtetra
.576 .44 .658 r
.44415 .2183 .45028 .24873 .46196 .24441 .45577 .21434 Mtetra
.576 .441 .66 r
.45577 .21434 .46196 .24441 .4737 .24007 .46745 .21042 Mtetra
.576 .443 .663 r
.46745 .21042 .4737 .24007 .48548 .23573 .47918 .20654 Mtetra
.576 .445 .665 r
.47918 .20654 .48548 .23573 .49732 .23138 .49096 .20272 Mtetra
.577 .448 .668 r
.49096 .20272 .49732 .23138 .50921 .22702 .50279 .19894 Mtetra
.577 .451 .672 r
.50279 .19894 .50921 .22702 .52115 .22265 .51468 .19521 Mtetra
.578 .455 .676 r
.51468 .19521 .52115 .22265 .53314 .21824 .52663 .19152 Mtetra
.578 .459 .681 r
.52663 .19152 .53314 .21824 .54518 .21381 .53864 .18787 Mtetra
.579 .464 .687 r
.53864 .18787 .54518 .21381 .55727 .20932 .55071 .18425 Mtetra
.581 .471 .693 r
.55071 .18425 .55727 .20932 .56942 .20479 .56283 .18067 Mtetra
.582 .478 .7 r
.56283 .18067 .56942 .20479 .58162 .2002 .57502 .17713 Mtetra
.584 .486 .709 r
.57502 .17713 .58162 .2002 .59387 .19558 .58727 .17364 Mtetra
.585 .495 .719 r
.58727 .17364 .59387 .19558 .60617 .19095 .59958 .1702 Mtetra
.587 .506 .731 r
.59958 .1702 .60617 .19095 .61853 .18634 .61196 .16684 Mtetra
.588 .519 .745 r
.61196 .16684 .61853 .18634 .63094 .18178 .62441 .16358 Mtetra
.589 .533 .76 r
.62441 .16358 .63094 .18178 .64342 .1773 .63693 .16044 Mtetra
.589 .549 .778 r
.63693 .16044 .64342 .1773 .65595 .17293 .64953 .15742 Mtetra
.589 .568 .798 r
.64953 .15742 .65595 .17293 .66855 .16868 .6622 .15453 Mtetra
.588 .59 .821 r
.6622 .15453 .66855 .16868 .68121 .16454 .67495 .15176 Mtetra
.587 .615 .847 r
.67495 .15176 .68121 .16454 .69395 .1605 .68778 .1491 Mtetra
.584 .643 .875 r
.68778 .1491 .69395 .1605 .70675 .15653 .70069 .14651 Mtetra
.58 .676 .906 r
.70069 .14651 .70675 .15653 .71961 .15261 .71368 .14397 Mtetra
.752 .767 .866 r
.03496 .38178 .04273 .38856 .05308 .38284 .04551 .37492 Mtetra
.741 .738 .849 r
.04551 .37492 .05308 .38284 .06345 .37717 .05607 .36811 Mtetra
.729 .71 .832 r
.05607 .36811 .06345 .37717 .07384 .37157 .06664 .36137 Mtetra
.718 .684 .817 r
.06664 .36137 .07384 .37157 .08425 .36606 .07722 .35472 Mtetra
.706 .66 .802 r
.07722 .35472 .08425 .36606 .09466 .36067 .0878 .3482 Mtetra
.695 .638 .788 r
.0878 .3482 .09466 .36067 .10509 .35541 .09839 .3418 Mtetra
.684 .618 .775 r
.09839 .3418 .10509 .35541 .11553 .35027 .10898 .33553 Mtetra
.674 .599 .763 r
.10898 .33553 .11553 .35027 .12599 .34524 .11958 .32939 Mtetra
.665 .582 .752 r
.11958 .32939 .12599 .34524 .13647 .3403 .13019 .32338 Mtetra
.656 .566 .741 r
.13019 .32338 .13647 .3403 .14697 .33544 .14081 .3175 Mtetra
.648 .552 .732 r
.14081 .3175 .14697 .33544 .1575 .33064 .15144 .31175 Mtetra
.641 .54 .724 r
.15144 .31175 .1575 .33064 .16806 .32589 .16209 .30612 Mtetra
.635 .53 .717 r
.16209 .30612 .16806 .32589 .17865 .32117 .17275 .30062 Mtetra
.629 .521 .712 r
.17275 .30062 .17865 .32117 .18928 .31649 .18343 .29524 Mtetra
.625 .513 .707 r
.18343 .29524 .18928 .31649 .19993 .31184 .19413 .28998 Mtetra
.62 .506 .702 r
.19413 .28998 .19993 .31184 .21062 .30723 .20485 .28481 Mtetra
.616 .501 .699 r
.20485 .28481 .21062 .30723 .22134 .30267 .2156 .27975 Mtetra
.613 .495 .695 r
.2156 .27975 .22134 .30267 .2321 .29815 .22637 .27478 Mtetra
.61 .491 .693 r
.22637 .27478 .2321 .29815 .24289 .29367 .23717 .2699 Mtetra
.607 .487 .69 r
.23717 .2699 .24289 .29367 .25371 .28925 .248 .2651 Mtetra
.604 .483 .688 r
.248 .2651 .25371 .28925 .26457 .28487 .25886 .26038 Mtetra
.602 .48 .686 r
.25886 .26038 .26457 .28487 .27547 .28054 .26975 .25573 Mtetra
.6 .477 .684 r
.26975 .25573 .27547 .28054 .28641 .27624 .28067 .25114 Mtetra
.598 .475 .683 r
.28067 .25114 .28641 .27624 .29739 .27197 .29164 .24662 Mtetra
.596 .472 .682 r
.29164 .24662 .29739 .27197 .30841 .26773 .30264 .24216 Mtetra
.595 .47 .681 r
.30264 .24216 .30841 .26773 .31947 .26352 .31368 .23775 Mtetra
.593 .468 .68 r
.31368 .23775 .31947 .26352 .33058 .25933 .32475 .23339 Mtetra
.592 .467 .679 r
.32475 .23339 .33058 .25933 .34173 .25515 .33587 .22909 Mtetra
.59 .466 .679 r
.33587 .22909 .34173 .25515 .35292 .25099 .34703 .22485 Mtetra
.589 .465 .678 r
.34703 .22485 .35292 .25099 .36416 .24684 .35823 .22065 Mtetra
.588 .464 .678 r
.35823 .22065 .36416 .24684 .37544 .2427 .36948 .21651 Mtetra
.587 .464 .679 r
.36948 .21651 .37544 .2427 .38677 .23858 .38077 .21242 Mtetra
.586 .463 .679 r
.38077 .21242 .38677 .23858 .39815 .23448 .39211 .20839 Mtetra
.585 .464 .68 r
.39211 .20839 .39815 .23448 .40958 .23039 .40349 .20441 Mtetra
.585 .464 .681 r
.40349 .20441 .40958 .23039 .42105 .22633 .41492 .20048 Mtetra
.584 .464 .683 r
.41492 .20048 .42105 .22633 .43258 .2223 .4264 .19662 Mtetra
.583 .465 .684 r
.4264 .19662 .43258 .2223 .44415 .2183 .43793 .19281 Mtetra
.582 .466 .686 r
.43793 .19281 .44415 .2183 .45577 .21434 .44951 .18908 Mtetra
.582 .467 .688 r
.44951 .18908 .45577 .21434 .46745 .21042 .46115 .18541 Mtetra
.581 .468 .69 r
.46115 .18541 .46745 .21042 .47918 .20654 .47283 .18183 Mtetra
.58 .47 .693 r
.47283 .18183 .47918 .20654 .49096 .20272 .48458 .17833 Mtetra
.579 .472 .696 r
.48458 .17833 .49096 .20272 .50279 .19894 .49638 .17492 Mtetra
.578 .474 .699 r
.49638 .17492 .50279 .19894 .51468 .19521 .50823 .1716 Mtetra
.577 .476 .703 r
.50823 .1716 .51468 .19521 .52663 .19152 .52015 .16839 Mtetra
.576 .479 .707 r
.52015 .16839 .52663 .19152 .53864 .18787 .53213 .16529 Mtetra
.575 .483 .712 r
.53213 .16529 .53864 .18787 .55071 .18425 .54418 .1623 Mtetra
.574 .487 .719 r
.54418 .1623 .55071 .18425 .56283 .18067 .55629 .15943 Mtetra
.573 .493 .726 r
.55629 .15943 .56283 .18067 .57502 .17713 .56847 .1567 Mtetra
.572 .5 .735 r
.56847 .1567 .57502 .17713 .58727 .17364 .58072 .15409 Mtetra
.571 .508 .745 r
.58072 .15409 .58727 .17364 .59958 .1702 .59304 .15163 Mtetra
.57 .517 .757 r
.59304 .15163 .59958 .1702 .61196 .16684 .60545 .1493 Mtetra
.568 .528 .771 r
.60545 .1493 .61196 .16684 .62441 .16358 .61793 .1471 Mtetra
.566 .541 .787 r
.61793 .1471 .62441 .16358 .63693 .16044 .63049 .14505 Mtetra
.563 .556 .804 r
.63049 .14505 .63693 .16044 .64953 .15742 .64313 .14313 Mtetra
.559 .572 .823 r
.64313 .14313 .64953 .15742 .6622 .15453 .65586 .14135 Mtetra
.555 .59 .844 r
.65586 .14135 .6622 .15453 .67495 .15176 .66868 .13969 Mtetra
.549 .611 .867 r
.66868 .13969 .67495 .15176 .68778 .1491 .68159 .13814 Mtetra
.542 .634 .891 r
.68159 .13814 .68778 .1491 .70069 .14651 .6946 .13667 Mtetra
.532 .659 .917 r
.6946 .13667 .70069 .14651 .71368 .14397 .70769 .13525 Mtetra
.765 .768 .855 r
.02714 .37496 .03496 .38178 .04551 .37492 .03782 .36741 Mtetra
.758 .751 .847 r
.03782 .36741 .04551 .37492 .05607 .36811 .04851 .35993 Mtetra
.75 .735 .838 r
.04851 .35993 .05607 .36811 .06664 .36137 .05919 .35254 Mtetra
.742 .72 .83 r
.05919 .35254 .06664 .36137 .07722 .35472 .06988 .34525 Mtetra
.734 .705 .823 r
.06988 .34525 .07722 .35472 .0878 .3482 .08057 .33807 Mtetra
.726 .69 .815 r
.08057 .33807 .0878 .3482 .09839 .3418 .09127 .33102 Mtetra
.718 .676 .808 r
.09127 .33102 .09839 .3418 .10898 .33553 .10196 .32409 Mtetra
.71 .662 .801 r
.10196 .32409 .10898 .33553 .11958 .32939 .11266 .3173 Mtetra
.702 .649 .794 r
.11266 .3173 .11958 .32939 .13019 .32338 .12336 .31066 Mtetra
.695 .637 .787 r
.12336 .31066 .13019 .32338 .14081 .3175 .13407 .30416 Mtetra
.687 .625 .781 r
.13407 .30416 .14081 .3175 .15144 .31175 .14478 .29783 Mtetra
.68 .614 .775 r
.14478 .29783 .15144 .31175 .16209 .30612 .15549 .29166 Mtetra
.673 .604 .77 r
.15549 .29166 .16209 .30612 .17275 .30062 .16621 .28566 Mtetra
.666 .595 .765 r
.16621 .28566 .17275 .30062 .18343 .29524 .17694 .27981 Mtetra
.66 .586 .761 r
.17694 .27981 .18343 .29524 .19413 .28998 .18769 .27412 Mtetra
.655 .579 .757 r
.18769 .27412 .19413 .28998 .20485 .28481 .19845 .26856 Mtetra
.65 .572 .754 r
.19845 .26856 .20485 .28481 .2156 .27975 .20923 .26313 Mtetra
.646 .566 .751 r
.20923 .26313 .2156 .27975 .22637 .27478 .22003 .25782 Mtetra
.642 .561 .748 r
.22003 .25782 .22637 .27478 .23717 .2699 .23085 .25263 Mtetra
.638 .556 .746 r
.23085 .25263 .23717 .2699 .248 .2651 .2417 .24753 Mtetra
.634 .551 .743 r
.2417 .24753 .248 .2651 .25886 .26038 .25257 .24254 Mtetra
.631 .547 .741 r
.25257 .24254 .25886 .26038 .26975 .25573 .26348 .23763 Mtetra
.628 .543 .739 r
.26348 .23763 .26975 .25573 .28067 .25114 .27441 .23281 Mtetra
.625 .54 .738 r
.27441 .23281 .28067 .25114 .29164 .24662 .28538 .22808 Mtetra
.622 .536 .736 r
.28538 .22808 .29164 .24662 .30264 .24216 .29638 .22343 Mtetra
.62 .533 .735 r
.29638 .22343 .30264 .24216 .31368 .23775 .30742 .21886 Mtetra
.617 .531 .734 r
.30742 .21886 .31368 .23775 .32475 .23339 .31849 .21437 Mtetra
.615 .529 .734 r
.31849 .21437 .32475 .23339 .33587 .22909 .3296 .20997 Mtetra
.613 .527 .733 r
.3296 .20997 .33587 .22909 .34703 .22485 .34075 .20565 Mtetra
.611 .525 .733 r
.34075 .20565 .34703 .22485 .35823 .22065 .35194 .20142 Mtetra
.609 .524 .734 r
.35194 .20142 .35823 .22065 .36948 .21651 .36317 .19726 Mtetra
.607 .523 .734 r
.36317 .19726 .36948 .21651 .38077 .21242 .37445 .1932 Mtetra
.605 .523 .735 r
.37445 .1932 .38077 .21242 .39211 .20839 .38577 .18921 Mtetra
.604 .523 .736 r
.38577 .18921 .39211 .20839 .40349 .20441 .39714 .18531 Mtetra
.602 .523 .738 r
.39714 .18531 .40349 .20441 .41492 .20048 .40855 .18149 Mtetra
.6 .524 .74 r
.40855 .18149 .41492 .20048 .4264 .19662 .42001 .17776 Mtetra
.599 .524 .742 r
.42001 .17776 .4264 .19662 .43793 .19281 .43152 .17411 Mtetra
.597 .526 .745 r
.43152 .17411 .43793 .19281 .44951 .18908 .44309 .17055 Mtetra
.596 .527 .747 r
.44309 .17055 .44951 .18908 .46115 .18541 .45471 .16708 Mtetra
.594 .528 .751 r
.45471 .16708 .46115 .18541 .47283 .18183 .46638 .16372 Mtetra
.592 .53 .754 r
.46638 .16372 .47283 .18183 .48458 .17833 .47811 .16046 Mtetra
.59 .532 .758 r
.47811 .16046 .48458 .17833 .49638 .17492 .4899 .15731 Mtetra
.588 .534 .762 r
.4899 .15731 .49638 .17492 .50823 .1716 .50175 .15429 Mtetra
.585 .537 .767 r
.50175 .15429 .50823 .1716 .52015 .16839 .51366 .1514 Mtetra
.583 .54 .772 r
.51366 .1514 .52015 .16839 .53213 .16529 .52564 .14865 Mtetra
.579 .543 .778 r
.52564 .14865 .53213 .16529 .54418 .1623 .53768 .14606 Mtetra
.576 .547 .785 r
.53768 .14606 .54418 .1623 .55629 .15943 .5498 .14363 Mtetra
.572 .551 .793 r
.5498 .14363 .55629 .15943 .56847 .1567 .56198 .14137 Mtetra
.568 .557 .801 r
.56198 .14137 .56847 .1567 .58072 .15409 .57425 .13929 Mtetra
.563 .563 .811 r
.57425 .13929 .58072 .15409 .59304 .15163 .58659 .13738 Mtetra
.558 .57 .822 r
.58659 .13738 .59304 .15163 .60545 .1493 .59901 .13563 Mtetra
.553 .578 .833 r
.59901 .13563 .60545 .1493 .61793 .1471 .61152 .13403 Mtetra
.548 .587 .846 r
.61152 .13403 .61793 .1471 .63049 .14505 .62412 .13258 Mtetra
.541 .597 .859 r
.62412 .13258 .63049 .14505 .64313 .14313 .6368 .13126 Mtetra
.534 .607 .872 r
.6368 .13126 .64313 .14313 .65586 .14135 .64958 .13008 Mtetra
.526 .618 .886 r
.64958 .13008 .65586 .14135 .66868 .13969 .66245 .12903 Mtetra
.518 .629 .9 r
.66245 .12903 .66868 .13969 .68159 .13814 .67542 .12808 Mtetra
.508 .641 .915 r
.67542 .12808 .68159 .13814 .6946 .13667 .68849 .12723 Mtetra
.498 .654 .929 r
.68849 .12723 .6946 .13667 .70769 .13525 .70165 .12647 Mtetra
.765 .768 .856 r
.01926 .36808 .02714 .37496 .03782 .36741 .02997 .36051 Mtetra
.762 .769 .858 r
.02997 .36051 .03782 .36741 .04851 .35993 .04068 .35307 Mtetra
.76 .77 .861 r
.04068 .35307 .04851 .35993 .05919 .35254 .05139 .34574 Mtetra
.758 .773 .865 r
.05139 .34574 .05919 .35254 .06988 .34525 .06209 .33853 Mtetra
.757 .776 .869 r
.06209 .33853 .06988 .34525 .08057 .33807 .0728 .33143 Mtetra
.755 .779 .873 r
.0728 .33143 .08057 .33807 .09127 .33102 .08351 .32446 Mtetra
.752 .782 .877 r
.08351 .32446 .09127 .33102 .10196 .32409 .09423 .3176 Mtetra
.75 .784 .881 r
.09423 .3176 .10196 .32409 .11266 .3173 .10495 .31085 Mtetra
.747 .786 .884 r
.10495 .31085 .11266 .3173 .12336 .31066 .11568 .30422 Mtetra
.744 .787 .887 r
.11568 .30422 .12336 .31066 .13407 .30416 .12642 .2977 Mtetra
.741 .787 .89 r
.12642 .2977 .13407 .30416 .14478 .29783 .13716 .2913 Mtetra
.738 .786 .891 r
.13716 .2913 .14478 .29783 .15549 .29166 .14792 .28501 Mtetra
.733 .783 .892 r
.14792 .28501 .15549 .29166 .16621 .28566 .15869 .27884 Mtetra
.729 .778 .892 r
.15869 .27884 .16621 .28566 .17694 .27981 .16947 .27278 Mtetra
.724 .772 .891 r
.16947 .27278 .17694 .27981 .18769 .27412 .18027 .26683 Mtetra
.719 .765 .888 r
.18027 .26683 .18769 .27412 .19845 .26856 .19109 .26099 Mtetra
.714 .757 .886 r
.19109 .26099 .19845 .26856 .20923 .26313 .20193 .25527 Mtetra
.709 .748 .883 r
.20193 .25527 .20923 .26313 .22003 .25782 .21278 .24966 Mtetra
.703 .74 .88 r
.21278 .24966 .22003 .25782 .23085 .25263 .22366 .24416 Mtetra
.698 .731 .876 r
.22366 .24416 .23085 .25263 .2417 .24753 .23455 .23878 Mtetra
.693 .723 .873 r
.23455 .23878 .2417 .24753 .25257 .24254 .24548 .2335 Mtetra
.687 .715 .87 r
.24548 .2335 .25257 .24254 .26348 .23763 .25642 .22834 Mtetra
.682 .708 .867 r
.25642 .22834 .26348 .23763 .27441 .23281 .2674 .22328 Mtetra
.677 .701 .865 r
.2674 .22328 .27441 .23281 .28538 .22808 .2784 .21834 Mtetra
.673 .696 .863 r
.2784 .21834 .28538 .22808 .29638 .22343 .28944 .21352 Mtetra
.668 .69 .862 r
.28944 .21352 .29638 .22343 .30742 .21886 .3005 .2088 Mtetra
.664 .686 .861 r
.3005 .2088 .30742 .21886 .31849 .21437 .3116 .20419 Mtetra
.66 .683 .861 r
.3116 .20419 .31849 .21437 .3296 .20997 .32274 .1997 Mtetra
.655 .68 .861 r
.32274 .1997 .3296 .20997 .34075 .20565 .33391 .19532 Mtetra
.651 .677 .862 r
.33391 .19532 .34075 .20565 .35194 .20142 .34512 .19105 Mtetra
.647 .676 .863 r
.34512 .19105 .35194 .20142 .36317 .19726 .35637 .18689 Mtetra
.643 .675 .865 r
.35637 .18689 .36317 .19726 .37445 .1932 .36766 .18284 Mtetra
.64 .674 .867 r
.36766 .18284 .37445 .1932 .38577 .18921 .379 .17891 Mtetra
.636 .675 .87 r
.379 .17891 .38577 .18921 .39714 .18531 .39038 .17509 Mtetra
.632 .676 .874 r
.39038 .17509 .39714 .18531 .40855 .18149 .40181 .17138 Mtetra
.628 .678 .878 r
.40181 .17138 .40855 .18149 .42001 .17776 .41329 .16778 Mtetra
.624 .68 .883 r
.41329 .16778 .42001 .17776 .43152 .17411 .42481 .1643 Mtetra
.619 .684 .889 r
.42481 .1643 .43152 .17411 .44309 .17055 .4364 .16093 Mtetra
.615 .688 .895 r
.4364 .16093 .44309 .17055 .45471 .16708 .44803 .15768 Mtetra
.61 .692 .902 r
.44803 .15768 .45471 .16708 .46638 .16372 .45972 .15454 Mtetra
.605 .697 .909 r
.45972 .15454 .46638 .16372 .47811 .16046 .47148 .15152 Mtetra
.599 .702 .916 r
.47148 .15152 .47811 .16046 .4899 .15731 .48329 .14861 Mtetra
.593 .708 .923 r
.48329 .14861 .4899 .15731 .50175 .15429 .49516 .14582 Mtetra
.586 .713 .931 r
.49516 .14582 .50175 .15429 .51366 .1514 .5071 .14315 Mtetra
.579 .717 .937 r
.5071 .14315 .51366 .1514 .52564 .14865 .51911 .14059 Mtetra
.571 .721 .943 r
.51911 .14059 .52564 .14865 .53768 .14606 .53119 .13815 Mtetra
.563 .723 .949 r
.53119 .13815 .53768 .14606 .5498 .14363 .54333 .13584 Mtetra
.556 .724 .953 r
.54333 .13584 .5498 .14363 .56198 .14137 .55555 .13364 Mtetra
.548 .724 .955 r
.55555 .13364 .56198 .14137 .57425 .13929 .56785 .13156 Mtetra
.541 .721 .957 r
.56785 .13156 .57425 .13929 .58659 .13738 .58023 .1296 Mtetra
.534 .718 .957 r
.58023 .1296 .58659 .13738 .59901 .13563 .59268 .12777 Mtetra
.528 .713 .957 r
.59268 .12777 .59901 .13563 .61152 .13403 .60522 .12605 Mtetra
.522 .708 .956 r
.60522 .12605 .61152 .13403 .62412 .13258 .61785 .12447 Mtetra
.517 .702 .954 r
.61785 .12447 .62412 .13258 .6368 .13126 .63057 .123 Mtetra
.511 .695 .952 r
.63057 .123 .6368 .13126 .64958 .13008 .64337 .12167 Mtetra
.506 .689 .95 r
.64337 .12167 .64958 .13008 .66245 .12903 .65627 .12046 Mtetra
.501 .682 .947 r
.65627 .12046 .66245 .12903 .67542 .12808 .66927 .11938 Mtetra
.496 .676 .946 r
.66927 .11938 .67542 .12808 .68849 .12723 .68236 .11843 Mtetra
.49 .671 .944 r
.68236 .11843 .68849 .12723 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Eooooo`;oPK3c1On0[_84ogj]lPCoOJ_a00?o
0000ooooooooool05?ooool00ol0003oooooooooo`1Aooooo`00H?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo01gooooo0ol00002ooooo`03o`000?oo
oooooooo04_ooooo0_n4/o@4oh:al`GoPK3c1On0[_84ogj]lP?oOJ_a00?o0000ogf[lOooool05Ooo
ool00ol0003oooooooooo`1@ooooo`00H?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Looooo`;o0000Boooool2ohNfm0GoQKGd1?n4/o@4oh:al`GoPK3c1?n0[_85ogj]lP;oOJ_a00?o
0000ognWkOooool05?ooool00ol0003oooooo`00001Aooooo`00H?ooool01Ol0003ooooooooooooo
oooo000000_ooooo00CoA4A4omgMgOoooooo00006_ooool3o`0004Gooooo0_n:^?@5ohRgm0CoQkKd
1On5]O@4ohBcm0CoP[7c0_n1/?<2ohJNhPCoQ:7V1On2Y>X2ognWk@03o`000?moYngoOjO]01Kooooo
00?o0000ooooooooool0Coooool0063ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgM
gOmEEEGoooooo`0001Sooooo0_l00014ooooo`?oS;Wd1?n:^?@5ohRgm0CoQkKd0_n5]O@2ohbFf0Co
RYSK1?n8Vml5ohJNhPCoQ:7V1On2Y>X00omoYngo0000ognWk@02ognWkAKooooo00?o0000oooooooo
ool0C_ooool0063ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001Go
oooo0ol00002ooooo`03o`000?oooooooooo03[ooooo0_n@^O84ohjil`GoS;Wd1?n:^?@2ohRgm0;o
SY7B1?n=TmD5ohbFf0CoRYSK1?n8Vml4ohJNhPGoQ:7V1On2Y>X01?l0003oOjO]ohRXj_n8Z>XFoooo
o`03o`000?oooooooooo04kooooo001Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^
k^koA4A4o`00000Cooooo`;o0000?_ooool2oi:hl@GoT;Wb1?n>^O<2ohbim0;oTHk=1?n@T<l5ohjA
dPCoSI?E1?n<U]P4ohZHf`GoR9_O1?n6W^82ohBQiP;oS9cM1On:X^@00ol0003oR:SZohRXjP02ohRX
jQKooooo00?o0000ooooooooool0COooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=oooo
o`03ogMgMol0003ooooo00oooooo0ol0000looooo`?oU;O_1?nB^?45oi2ilP;oS[Wc00?oTXg;oi6>
cOnAS/d00onAS/d4oi2@c`CoSY7B1?n=TmD5ohbFf0CoRYSK0_n8Vml2ohnBdPCoSYOH1On<W=d4ohZR
i003o`000?n8Z>[oR:SZ00?oR:SZ5_ooool00ol0003oooooooooo`1<ooooo`00P_ooool2o`0003_o
oooo0onF]^h5oiBgk`CoT[Sa0_n@^O82oi><b0CoTXg;1?nAS/d4oi2@c`CoSY7B1On=TmD2ohbFf0;o
T8[91?n@S/d5ohnBdPCoSYOH1?n<W=d4ohZRi004o`000?n8Z>[oR:SZohRXjP;oU:gW5_ooool00ol0
003oooooooooo`1<ooooo`00Ooooool3o`0000;ooooo00?o0000ooooooooool0<Oooool2oiVcjPCo
UkG/1OnF]^h2oiBgk`;oUH[51?nDRlL5oi><b0CoTXg;0onAS/d5oi2@c`CoSY7B0_n=TmD2oi67a@Go
T8[91?n@S/d4ohnBdPGoSYOH1?n<W=d2ohZRi003oiFTgol0003oU:gW00GoU:gW5?ooool3o`0004go
oooo001looooo`?o0000=Oooool2oiZbj0GoVK?Z1?nG]N`2oiJfkP;oUHW41OnER/D4oiB;a`CoThc8
1?nBSL/4oi6>c@;oT93?0_nBP[h4oi64`@GoTHO51?n@R/T4oi2>c@GoSi;B0_n>UmP2oiJGdPCoUYgH
0onEY=l00ol0003oUJCOoiB]i`04oiB]iaOooooo00?o0000ooooooooool0B_ooool007[ooooo0_l0
000dooooo`;oW;7V1OnJ/^P5oiVcjP;oUkG/00?oUXS3oiF9a?nERL@00onERL@4oiF:a@CoU8_71?nC
S<P5oi:=b`;oTHk=00?oTWnloi:2__nBP[h00onBP[h4oi64`@CoTHO51?n@R/T5oi2>c@;oSi;B0_nF
TL`5oiJGdPCoUYgH0onEY=l01?l0003oUJCOoiB]ionD[NL3oj6ciAKooooo00?o0000ooooooooool0
B_ooool007Oooooo0ol0000cooooo`03oif`iOnL/NKoW;7V00?oW;7V1OnJ/^P2oiVcjP;oUhS21?nF
R<<4oiF9a0CoUH[51?nDRlL5oi><b0;oTXg;0_nBO[T4oi9o_0CoTX:n1?nAQ<44oi67a@GoT8[90_n@
S/d2oiJ<a`GoUY7<1?nFUm85oiJMf0;oUJCO00?o0000oj6ZgOnQ/nD01OnQ/nDFooooo`03o`000?oo
oooooooo04Wooooo001eooooo`;o00000_ooool00ol0003oooooooooo`0]ooooo`;oWZoS1?nM/>D5
oibaiP;oV[;X0_nGQl45oiN8`P?oUXS31?nERL@5oiF:a@CoU8_70_nCS<P2oi9l^0GoTWji0onBOk`4
oi:2_PCoTHC11OnAQlD2oi2:b@;oUXS21OnFS<L4oiJAc0GoUYOB0_nFWMP2oj2ReP;oXJ[M00?o0000
oj6ZgOnQZ]d01?nQ/nD00on/^N;oooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo001boooo
o`?o00001Oooool00ol0003oooooooooo`0Yooooo`03oin^h_nN[n?oWZoS00?oWZoS1?nM/>D2oiba
iP;oV8O01OnGQl44oiN8`P?oUXS31OnERL@4oiF:a@;oU8_70_nCNkH4oi9l^0GoTWji1?nBOk`4oi:2
_PCoTHC10_nAQlD2oiJ4_PGoUXS21?nFS<L4oiJAc0CoUYOB00?oWi_@oj2Re_nPX]H00onPX]H00onQ
Z]go0000oj6Zg@02oj6Zg@03oj6ciOn/^N;o[;WR00;o[;WR5_ooool00ol0003oooooooooo`18oooo
o`00L?ooool2o`0003;ooooo1?nO[^85oij_h`;oWK3U00?oV8JooiR7`?nHQl000onHQl04oiN7`@Co
UhS21?nFR<<4oiF9a0;oUH[50_nCN[@4oi=k]PGoTWbh1?nBO[T4oi9o_0CoTX:n0_nAQ<42oiJ1^`Go
UXBn1?nFR<84oiJ<a`GoUY7<00?oUYOBoinKd?nOVm000_nOVm04oj2ReP05oj6ZgOl0003oXJ[Moj6Z
gOn[/=`01_n/^N8Fooooo`03o`000?oooooooooo04Oooooo000hooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000Pooooo`?o0000<_ooool00onP[N3oWjkRoin^hP03oin^
hPCoWZoS00?oV8JnoiR6_onHQ[l00_nHQ[l4oiR7`0CoUhO11OnGR<83oiJ8``;oUHW40_nCNK<4oi=j
]0GoTg^f1?nBO;P5oi9n^@CoTWnl0_nBP[h00onEO[SoUX6koiJ1^`03oiJ1^`CoUXBn1?nFR<85oiJ<
a`;oUY7<0_nOU/X5oinKd0GoX:;F00?o0000oj^`g?n[/=`00_n[/=`4ojbihP03okJohOoooooooooo
01?ooooo0ol00018ooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@07_ooool2o`0000?ooooo00?o0000ooooooooool0:oooool2
oj6]g`CoX:gP1OnO[^800onN[n?oV8JnoiR6_P02oiR6_P?oV8Jo1?nHQl05oiN7`@CoUhS20_nFR<<0
0onCNK;oTgVcoi=i/`02oi=i/`GoTgZd1?nCNkH4oi9l^0GoTWji0_nBOk`2oiEl]@?oUGjh1OnFPK/4
oiJ4_PGoUXS20onFS<L00onNTLGoWiK:oinFbP03oinFbPCoWi_@1?nPX]H00onZZMKo0000oj^`g004
oj^`g003ojbih_nf_n7o][oQ00;o][oQ5_ooool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`0Yooooo`00>?ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h07?ooool3o`0002oooooo0_nR
[=h5oj6]g`CoX:gP0_nO[^82oiV6_@GoV8Jn1?nHQ[l4oiR7`0CoUhO10_nGR<82oiAh/P?oTgVb1OnC
NK<4oi=j]0CoTg^f1OnBO;P3oi9n^@03oiAj/onEO;GoUGbe00;oUGbe1?nEO[P4oiJ1^`GoUXBn1?nF
R<800onFS<OoWY75oijAa@02oijAa@CoWiK:1OnOVm001OnPX]KoZZWFojZYe_nZZMKo000000CoZk3L
00?o]KWLokJohOnf_n401?nf_n4Fooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Zooooo`00>?ooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h06?ooool3o`0002oooooo0_nS[=d4oj:/gPGo
XJgO0_nP[N06oiV6_@CoV8Jn1?nHQ[l4oiR7`0;oUhO10_nDN;44oiAh/PCoTgVb1?nCNK<4oi=j]0Go
Tg^f1?nBO;P01?nBO[WoU7ZcoiAj/onDN[<5oiEl]@?oUGjh1OnFPK/4oiJ4_P;oUXS20_nMS<45oijA
a@GoWiK:0_nOVm02ojVSd0CoZZWF00?o0000ojZYe_n[/=`01?ne^M`4okJoh@;o_LKQ5_ooool00ol0
003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0002_ooooo000hoooo
o`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Eooooo`?o0000;_ooool0
0onT[=goXjcMoj>/g@03oj>/g@CoXZcN0_nQ[Ml2oiZ5_0SoVHJm1OnHQ[h4oiR6_`;oV8O000?oU7N`
oiAh/OnDN;400_nDN;45oiAh/P?oTgVb1?nCNK<5oi=j]0CoTg^f0_nBO;P2oiAh/@GoU7Zc1?nEO;D3
oiEn^0GoUX6k0_nFQ;h2oif8_@GoWHc11?nNTLD4oinFbP03ojRMc?nYXm3oZJ?@00?oZJ?@0onZZMH0
0ol0003o/k?HokFig005okFig003okJohOnma^7o_LKQ00?o_LKQ5Oooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0000/ooooo`00>?oo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool04Oooool3o`0000?ooooo
00?o0000ooooooooool0:Oooool4ojB/g@GoXjcM0_nR[=h6oiZ5_0OoVHJm1OnHQ[h2oiR6_`GoU7N`
1OnDN;44oiAh/P?oTgVb1OnCNK<4oi=j]0;oTg^f0_nDMZl4oiAh/@GoU7Zc1?nEO;D4oiEn^0?oUX6k
00?oW8Fjoif8_OnMR;d00onMR;d4oif<`@GoWY7500?oWiK:ojRMc?nXWL`00_nXWL`5ojVSd003ojZY
e_nc/mSo000000;o/k?H1?ne^M`00onm`moo_LKQokg6h@03okg6h@03ol7=i?oooooooooo01Cooooo
00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoo
oooo0000;?ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41004Oooool2o`00033ooooo00?oYJgLojB/gOnT[=d00onT[=d4oj>/g@WoVXFl2?nIQ[d2
oiR6_P;oU7N_2?nDMk04oiAh/@CoU7Rb1?nCNK84oi=i/`;oTgZd0_nCMJh4oiAf[`GoU7Ra1?nDN[<5
oiEl]@?oUGjh00CoUX6koib5^_nLQK[oW8Fj1OnMR;d4oif<`@CoWY7500?oYiW7ojRMc?nXWL`00onX
WL`4ojVSd004ok:^e?nc/mSo/k?Ho`0000;o/k?H0one^M`3okg3g`?o_LKQ0oo1cN@Fooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000002co
oooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00kooooo0ol0000^ooooo`;oYZgL1?nU[M`5ojB/g@03oj>/gOnJQKcoVXFl00WoVXFl1onIQ[d00onE
MjooU7N_oiAg[`02oiAg[`SoU7N`1?nDN;45oiAh/P?oTgVb0_nCNK<2oi=d[@CoTgF^1OnDMZl4oiAh
/@CoU7Zc1OnEO;D2oiEn^003oi^2]onLQK[oW8Fj00?oW8Fj1?nMR;d5oif<`@03oijAaOnWVLOoYiW7
00;oYiW71?nXWL`3ojVSd0?o/ZkD00?o/k?Ho`000?nc/mP00_nc/mP00one^Mco_L?Ookg3g`03okg3
g`03okg6hOo1cNCo`LgT00?o`LgT5?ooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03onk^k_m4A4Co000002cooooo001Iooooo`?o0000;Oooool00onW[]coYZgLojJ]g003ojJ]
g0CoYJgL0_nT[=d2oi^5^`goVXFl1?nIQ[d3oiEg[`GoU7N_1onDMk04oiAh/@GoU7Rb0_nCNK800onC
LjcoTgB]oi=d[@02oi=d[@GoTgF^1?nDMZl4oiAh/@GoU7Zc0onEO;D00onJOkCoVh:goi^2]`02oi^2
]`CoW8Fj1OnMR;d3oif<`@03ojJDa?nWVLOoYiW700?oYiW71OnXWL`00onYXm3o/ZkDok:^e002ok:^
e004ok>cf?l0003o/k?Hok>cf0;o_<7M1?nm`ml2ol;BiPCo`LgT00?o_]3Xooooooooool04Oooool0
1?l0003oooooooooool00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000
ooooo`0[ooooo`00E_ooool3o`0000?ooooo00?o0000ooooooooool0:Oooool3ojN^g0GoYZgL0_nU
[M`00onKQ[_oVhFkoi^5^`03oi^5^`coVXFl0_nIQ[d00onEMZkoUGN_oiEg[`03oiEg[`CoU7N_1onD
Mk05oiAh/@?oU7Rb00?oTg:[oi=c[?nCLj`00_nCLj`4oi=d[@CoTgF^1?nDMZl5oiAh/@CoU7Zc00Co
UGbeoiYo]?nJOkCoVWnd1?nKP[L4oib5^PGoWHRm00?oWHc1ojJDa?nVU<@00_nVU<@4ojNIa`CoZ9g<
00?o/JW@ok:^e?nb[]@01?nb[]@00ol0003o_<7Mokc1g@03okc1g@03okg3goo2d^Ko`];V00?o`];V
00?o`LgTokk@j?nnd>P00_nnd>PFooooo`03o`000?oooooooooo043ooooo001Dooooo`;o0000;ooo
ool2ojR^g0CoYjkL1?nV[M`00onLQ[_oVhJkoi^6^`02oi^6^`CoVhFk2_nJQK`5oiEf[PGoUGN_1?nD
Mjl8oiAg/0CoU7Ra00CoU7Rboi=bZonCLZ_oTg:[1?nCLj`4oi=d[@CoTgF^1?nDMZl5oiAh/@;oU7Zc
0_nIO;85oiYo]0CoVh:g1?nLQKX3oif8_@03ojFA`?nVU<CoYYC400?oYYC41OnWVLL00onXWLco/JW@
ok6Yd002ok6Yd0Co/ZkD00?o_;oLo`000?nl`Md00onl`Md00oo3enSo`];Vol;BiP03ol;BiP03okoI
k?nnd>So_]3X00?o_]3X5_ooool00ol0003oooooooooo`10ooooo`00DOooool3o`0002kooooo00?o
ZJoLojR^g?nX[]`00onX[]`4ojN^g003ojJ]g?nLQ[_oW8Jk00;oW8Jk0onKQ[/4oi^5^`OoVXFl2OnE
MZh4oiEg[`CoU7N_2?nDMk02oiAh/@;oTg6Z1OnCLZ/3oi=c[0CoTgB]1?nCMJh5oiAf[`?oU7Ra00?o
V7V`oiUl/_nIO;800_nIO;85oiYo]0CoVh:g1?nLQKX00onMR;goYI70ojFA`002ojFA`0CoYYC41?nW
VLL00on`YLgo/JW@ok6Yd004ok6Yd005ok:^e?nl_mco_;oLokbog?l000000onl`Md3ol?Gj0?o`];V
0onofN`3okk@j0;o]m3]5_ooool00ol0003oooooooooo`0oooooo`00C_ooool5o`0002kooooo0onY
[m`5ojR^g0;oYjkL1_nLQ[/3oi^6^`GoVhFk0onJQK`00onFMZgoUGJ^oiEf[P09oiEf[PCoUGN_1OnD
Mjl6oiAg/003oi=aZOnCLJ[oTg6Z00;oTg6Z1OnCLZ/4oi=c[0?oTgB]1OnCMJh4oiAf[`04oiAh/OnH
NK3oV7V`oiQi/0GoVGbb1?nJOk@5oi^2]`;oW8Fj00?oY8jmojFA`?nUTL000onUTL05ojJDa003ojNI
aon`YLgo/:G=00;o/:G=1?naZM000onl_]_o_;oLokbog002okbog003o`000?nl_mco_<7M00Go`mOX
00?o`];VokoIk?nofN`00_nofN`00onnd>So]m3]okO@k@03okO@kAKooooo00?o0000ooooooooool0
?_ooool004cooooo0_l00005ooooo`03o`000?oooooooooo02Sooooo0_n[/=`5ojV_g0;oZ:kL0_nM
Qk/8oib6^`CoVhJk1?nKQK/01?nJQKcoUWJ]oiIf[OnFMZd;oiEf[PCoUGN_1OnDMjl2oiAg/0;oTg2X
0onCLJT5oi=aZPCoTg:[1?nCLj`3oi=d[@GoTgF^0_nDMZl2oiMg[@GoV7V`1?nIO;85oiYo]0?oVh:g
00?oXh^kojB>_OnTS[d00_nTS[d4ojFA`0CoYYC400?o[j;;ok2UcOn`YLd00on`YLd3ok6Yd0?o_;kK
0onl_m`00ol0003oa=g[olCMj`04ol?Gj0;o_n;a0onofN`2okOKl`Co]m3]00?o[<gaooooooooool0
5?ooool00ol0003oooooooooo`0nooooo`00BOooool3o`0002oooooo00?o[;;Loj^`g?n[/=`00on[
/=`3ojV_g0KoWHNk2?nLQ[/3oi^6^`;oVhFk1onFMZd:oiEf[PGoUGN_0onDMjl5oi=`Z0CoTg6Y1?nC
LJX4oi=bZ`CoTg>/1?nCM:d3oi=e[P03oiIe[?nGMjgoUgN]00;oUgN]1OnHNK04oiUl/PGoVWnd00?o
Vh:goj>;^onSRk/00_nSRk/4ojB>_@CoYI7000?oYYC4ojnRbon_X//00_n_X//5ok2Uc@03ok6Yd?nl
_]_o_;kK00?o_;kK00Co_;oLolCMjoo4gN_o00000_o4gN/00oo3enSo_n;aokoRl@03okoRl@03okoI
k?ngfo?o]m_c00;o]m_c00?o]m3]ojc=lOn/cO400_n/cO4Dooooo`?o0000?oooool002;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Pooooo`;o0000<Oooool3ojbbg0GoZk3L00?oZJoLoif7^onMQk/0
1OnMQk/8oib6^`;oVhJk2_nFMZd;oiEf[PCoUGN_00?oU7N_oi=`Z?nCL:P01OnCL:P4oi=aZ@CoTg6Z
1?nCLZ/5oi=c[0?oTgB]00CoTgF^oiIe[?nFMJcoUWF/1OnGMjd4oiQi/0GoVGbb0onJOk@00onRR;Wo
Xh^koj>;^`03oj>;^`CoY8jm0onUTL000on^WlSo[j;;ojnRb`03ojnRb`Co/:G=00?o_;gJokbnfonl
_]/00onl_]/2olCTkP;oa=g[00Co0000olCMjonlk?Co_>cd1?noh_42ok?Vm`;o]m_c0onYf?P5ojc=
lAGooooo00?o0000ooooooooool0?Oooool002;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Moooo
o`?o00000_ooool00ol0003oooooooooo`0[ooooo`;o[K?M1On//]`2oj^`g0;oWXRl2?nMQk/7oib6
^`03oiIg[OnFMZgoUWJ]00[oUWJ]2onEMZh2oiEg[`;oTg2W2?nCL:P4oi=aZ@CoTg6Z1OnCLZ/4oi=c
[0;oTgB]00?oUG>ZoiIe[?nFMJ`00onFMJ`4oiMg[@CoV7V`1OnIO;801?nJOkCoXXRioj:8^OnRR;T5
oj>;^`GoY8jm00CoYI70ojjOb?n^WlSo[Yo81On_X//00on`YLgo_;gJokbmfP02okbmfP?o_;kK1?o4
i>h00oo4gN_o0000okc/m003okc/m004okoRlOnci_Oo/nKgok?Vm`;oX^;l1OnYf?P2ojc=l@?oWlKd
5Oooool00ol0003oooooooooo`0looooo`008_ooool01Ol@413ooooooooooooooooo410@01_ooooo
0_l0000`ooooo`03ojjegOn]/mgo[K?M00?o[K?M0on//]`00onORKcoWXRloij8_003oij8_0SoWHNk
1?nLQ[/3oiIg[@coUWJ]2_nEMZh00onCKjOoTg2Woi=`Y`02oi=`Y`WoTg2X0onCLJT4oi=aZPGoTg:[
0_nCLj`2oiAaZ0?oUG>Z1OnFMJ`4oiMg[@GoV7V`0onIO;800onQQ[OoXXRioj:8^@03oj:8^@GoXh^k
0onTS[d00on^WLOo[Yo8ojjOb002ojjOb0Co[j;;1onl_MX00onl_]_oa>C^olCTkP02olCTkP;o]O?c
00?o0000okc/m?nlk?@00onZk_P00onci_OoX^;loj;Ro003oj;Ro0;oZMSh0onJcoX5oio6m1Gooooo
00?o0000ooooooooool0>oooool002;ooooo00Go0000ooooooooooooooooo`00000Hooooo`?o0000
<Oooool3ojjeg@Go[K?M00Co[;;Loin9_?nORKcoWhVl1?nNR;`8oif7^`;oW8Jk00?oUgN]oiIg[OnF
Mjd00onFMjd;oiIf[@KoUGJ^1OnCKjL5oi=`Y`SoTg2X0onCLJT5oi=aZP?oTg:[00?oU72WoiAaZ?nD
LJP00_nDLJP4oiEcZPCoUWF/1?nGMjd5oiQi/004oiUl/_nQQ[OoXHJgoj66]`GoXXRi1OnSRk/00onT
S[go[Yg7ojjMa`02ojjMa`?o[Yo80on_X//7okbmfP?o`^_a00?oa>C^okGclonelo<00_nelo<01?l0
003oV?3`oj[^n?nZk_P4oi?WnP;oX^;l0onAf?h5oi[?nP;oWlKd0_nB_?<Eooooo`03o`000?oooooo
oooo03_ooooo000Rooooo`05o`000?ooooooooooooooool000005_ooool3o`00033ooooo0_n_]mh5
ojjeg@;o[K?M0_nOR[`4oin9_0CoWXRl1_nMQk/5oiMg[@GoUWN]3?nFMZd2oiEf[P03oi=_Y_nCKjOo
TfnW00KoTfnW1?nCL:L8oi=`Z0CoTg6Y1?nCLJX01?nCLZ_oU72WoiA`YonDL:L5oiAaZ0?oUG>Z1?nF
MJ`5oiMg[@?oV7V`00?oWh>eoj66]onQQ[L00onQQ[L4oj:8^@CoXh^k00?o[Ic6ojjMaon^WLL00on^
WLL4ojjOb003ojnRbonl_M[o_;gJ00Co_;gJ1?o2jo43ojKfk@04okGclonHl?3oV?3`o`0000?oN^C]
0_nCioX4oh;Lo@CoTMSn0_nJcoX2ohnom`GoT[cc5Oooool00ol0003oooooooooo`0jooooo`008_oo
ool01Ol@413ooooooooooooooooo410@01?ooooo0ol00002ooooo`03o`000?oooooooooo02_ooooo
00?o/KWOojngg_n_]mh00on_]mh3ojjeg@03oj2;_OnOR[coWhZl00?oWhZl0onORK`5oij8_0;oWHNk
00?oUgN^oiMg[OnGMjd01_nGMjd4oiIg[@coUWJ]00?oUGJ^oi=_Y_nCKjH02?nCKjL4oi=`Y`SoTg2X
1?nCLJT2oi=aZP;oTfjV1OnDL:L4oiAaZ0?oUG>Z1?nFMJ`5oiMg[@04oiQi/?nOPkGoWh>eoin3]@Go
XHJg1OnRR;T2oj>;^`?o[Ic61?n^WLL3ojjOb003ok^mfonl_M[o_;gJ00?o_;gJ0onnlO800oo2jo7o
Y_K]ojKfk@02ojKfk@?oO>KL00?oV?3`o`000?mji>d01?mYeo82oh;Lo@?oQ<Gl0on:`oX5ohnom`Co
T[cc5_ooool00ol0003oooooooooo`0iooooo`008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg013o
oooo0ol0000booooo`?o/KWO1On_]mh01?n^]MgoX8^moj2;_OnPRkd4oin:_0CoWhVl1?nNR;`00onM
Qk_oUgN^oiMg[P08oiMg[@CoUWN]2_nFMZd6oi=_YPOoTfnW1?nCL:L8oi=`Z0;oTg6Y0_nCKJD4oi=^
YPGoU72W1?nDLJP3oiEcZPGoUWF/0onGMjd00onNPK?oWh>eoin3]@03oin3]@CoXHJg1OnRR;T00onS
Rk_o[Ic6ojfLaP02ojfLaPGo[Yg700Co[Yo8ok^mfonk_M_o^kgK0onl_MX3okkalP?oS^kK00GoY_K]
ogcVg?mli]coO>KLoeOBd@02odW9f`04o`000?m9bM_oJMObofWGlP?oOLGn1On4aO`3oh[3nP;oSkog
0_n=[nd5ohjbkaCooooo0_l0000kooooo`008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo
0_l0000cooooo`03ok:kh?na^Moo/KWO00?o/KWO0_n_]mh2oj6<_@CoX8^m1?nOR[`4oin9_0;oWXRl
0_nHN:h4oiMg[POoUgN]1?nFMjd6oiIf[@[oTfnV1onCKjL4oi=`Y`OoTg2X00?oTfbToi=]YOnCKJD0
0_nCKJD5oi=^YPCoU72W1?nDLJP4oiEcZPCoUWF/00CoUgN]oij1/onNPK?oWX6c1OnOPkD5oj66]`?o
XXRi1_n]W<H4ojjMa`03ok^ng?nk_M_o^kgK00?o^kgK00Co_;gJokkal_nnlO;o__7b0_n>k]/2oeG>
^@;oLkon1Omc`_h01?l0003oN<CnogS4o_mha?h4ogg5oP;oQ<Gl0_n=Y^H3ohf[jPGoSJo]1On>/^lE
ooooo`03o`000?oooooooooo03Sooooo000booooo`Go0000<Oooool4ok:kh0?o/KWO00?oXXfnoj6<
_OnQS;d00onQS;d3oj2;_@GoWhZl0_nORK`5oiQh[PCoUgN^1onGMjd5oiIg[@;oUWJ]3OnCKjH7oi=_
Y`GoTg2W1OnCL:P2oi=/Y0GoTffU1?nCKZH4oiA`Y`CoU76X1?nELjX2oiIe[0;oWGnb1OnNPK<4oin3
]@GoXHJg00?oXXRiojfLa_n]W<H01on]W<H00on^WLOo^kkLok^ng002ok^ng0?o^kgK0onfm_000onn
lO;o0000ogNlo002ogNlo0CoLkon0_mc`_h00on>TM;o0000o`000003ohfHfPCoS9oQ1On=Y^H3ohf[
jPGoSJo]0_n>/^l2oi:_jaKooooo00?o0000ooooooooool0=oooool0033ooooo0_l0000dooooo`;o
/kgQ1Onb^n001?na^MooXXfnoj:=__nRSKh4oj6<_@CoX8^m1?nOR[`00onORKcoV7R^oiQh[P05oiQh
[P?oUgN^2?nGMjd4oiIg[@03oiIf[OnCKjKoTfnV00coTfnV2?nCKjL4oi=`Y`;oTg2X0_nBK:<3oi=/
Y0GoTffU1?nCKZH4oiA`Y`GoU76X0_nELjX00onMOK3oWGnboieo/P02oieo/PGoWX6c1OnOPkD3oj66
]`[o[Ic600?o^l3Nok^ng?nk_]`01?nk_]`01?nk_M_o]_K`okKfl?nfm_02ogjgn0;oMkcl0_n@Pl84
ohn:b@?o000000?oSY7Bo`000?n=V=X00on=V=X4ohbOh@CoSJKV1?n=ZnX2ohf_k@;oTZWU1OnB[n/E
ooooo`03o`000?oooooooooo03Oooooo000]ooooo`?o0000<oooool00one_n;o/kgQok>mh@03ok>m
h@;o/[_P0_nSS[h4oj:=_PCoXHbm1?nPRkd2oin:_0;oVGV^2?nHN:h3oiMg[PSoUgN]0_nFMjdAoi=_
YPSoTfnW0onCL:L00onBJj;oTVbSoi9/X`02oi9/X`CoTfbT1?nCKJD4oi=^YPGoU72W1?nDLJP00onE
Lj[oWGf`oiem/005oieo/PCoWX6c1OnOPkD00onQQ[Oo[Ic6ojfLaP08ojfLaPCo^l3N1?nk_]`2ojWg
j`03okKfl?nAO[_oTGjk00;oTGjk1On@Pl83o`000003ohn:bOn>TM;oSY7B00;oSY7B00Co0000ohfH
f_n=V=[oSISJ1?n<Wn42ohfViP;oU9cI1?nCXml5oi:Yi@GoTZo[5Oooool00ol0003oooooooooo`0f
ooooo`00;?ooool2o`0003?ooooo1?ne_n83ok>mh@03ojB?_onSS[koXhjn00?oXhjn0onRSKh5oj6<
_@;oX8^m00?oVGZ_oiUi[_nINJh00_nINJh8oiQh[P?oUgN^1onGMjdEoi=_YPOoTfnW00CoTg2Woi9[
X_nBJj;oTV^R1?nBK:<4oi=/Y0CoTffU1?nCKZH5oiA`Y`?oU76X00?oW7b_oiem/?nMOK000_nMOK04
oieo/PGoWX6c0onOPkD00on]WLOo[Ic6ojfLaP07ojfLaP03ok[3hOnk`=ko^l3N00Co^l3N00?o^kkL
ojWgjonYmn/01?nCN[D4oi5n^`04oi23`_l0003o0000o`0000CoSh[91On>TM800ol0003oSISJoiN@
b`04oiFFdPGoU9cI1?nCXml5oi:Yi@;oTZo[0onJ/>LEooooo`03o`000?oooooooooo03Gooooo000/
ooooo`?o0000<?ooool2okK1hPGo]KoR00Co/kgQojB?_onTSkooY8no1?nSS[h4oj:=_P?oXHbm00Co
VWZ_oiUj[onINZooVGZ_1OnINJh7oiQh[PCoUgN^0onGMjd00onDKjKoTfnVoi=_YP0Eoi=_YPKoTfnW
00?oTVZRoi9[X_nBJj800_nBJj85oi9/X`?oTfbT1?nCKJD5oi=^YPCoU72W00CoU76Xoial[onLO:oo
W7b_1?nMOK04oieo/PGoWX6c00?oWh>eojfMaon]WLL00_n]WLL7ojfLaP?o^/?Q1?nk`=h01?nGl]oo
U7N`oiAg/?nDMk04oi=j]@;oTGjk0ol00003oi23`PGoSh[90_n>TM82oiR;a004oiN@bol0003oUi3;
oiN@b`CoUIKB1?nDW=T5oi>Sg`;oTZWU0_nKZ=l6oiZ`iaCooooo00?o0000ooooooooool0=Oooool0
02cooooo00Co0000ooooool0003o0000;_ooool4okK1hP?o]KoR00?oYI30ojB?_onTSkl00_nTSkl4
oj>>_PCoXXfn00CoXHbmoiYj[onJNZooVWZ_1?nINZl4oiUi[PSoV7R^0onGMjh01?nGMjgoU6nVoiA_
Y_nDKjHGoi=_YP;oTfnW0_nBJZ43oi9ZXPGoTV^R1?nBK:<3oi=/Y0GoTffU1?nCKZH3oiA`Y`03oi]j
[_nLO:ooW7b_00?oW7b_0onMOK05oieo/P?oWX6c00?o[Ik8ojfMaon]WLL00on]WLL6ojfLaPGo^/?Q
00?o^l3NoiObgonGl]l01OnDMk02oi=j]@?o00000_nAO[/5oi23`P;oSh[90_nIQ[h5oiR;a003o`00
0?nGT<_oUi3;00CoUIKB1OnDW=T2oi>Sg`;oW:7H1OnKZ=l4oiZ`i`03ojFgi_oooooooooo017ooooo
00?o0000ooooool000002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`06Oooool002cooooo0_l00002ooooo`03o`000?oooooooooo02Wo
oooo0_nh`n<5okK1hP04okFoh_nUT<3oYI30ojF@`0?oY8no1OnSS[h2oj:=_P03oiYk/?nJNZooVWZ_
00?oVWZ_0onINZl4oiUi[PSoV7R^0_nGMjh5oiA_YQKoTfnV00?oTFVQoi9ZXOnBJZ400_nBJZ43oi9Z
XPGoTV^R1?nBK:<3oi=/Y0GoTffU1?nCKZH01?nDL:OoVgZ^oi]j[_nKNZh5oial[`?oWGf`1OnMOk80
0onNPK?o[Ik8ojfNb002ojfNb0Co[Ig71?n]W<H2ok[7i0Co^/?Q0_n0ill3oiEe[0?oU7N`0ol00002
oi=j]@CoTGjk0_n@Pl82oiZ2^@GoVHJn1?nHRl@00onGT<_o0000oiN@b`05oiFFdP;oU9cI0_nMV]45
oibQf0GoVjSO00?oV[3WojFgi_nU]nH00_nU]nHEooooo`03o`000?oooooooooo00Gooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q01Wooooo
000[ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09_ooool5okS3h`;o]/7R0_nV
T/44ojF@`0CoY8no0onSS[h01?nKO;3oVW^`oiYk/?nJNk05oiYj[`?oVGZ_1?nINJh6oiQh[P;oU72W
1onDKjHDoi=_YP?oTFVQ1?nBJZ44oi9ZXPCoTV^R1?nBK:<4oi=/Y0CoTffU0_nCKZH2oiYi[@GoVgZ^
1?nLO:l4oiem/0?oWGnb00?o[Z39ojfNb?n]W/P00on]W/P5ojfMa`03ojfLa_njanCo^/OT00?o^/OT
00Co^/?Qoh3Wcon0ilooUW>Y1?nEMJ`01?nDMk3o0000o`000?nDMk04oi=j]@;oTGjk0_nKOk@5oiZ2
^@CoVHJn1?nHRl@2oiN@b`04o`000?nGT<_oUIKBoiFFdP;oWYG;1OnMV]45oibQf0;oVjSO0_nV/=l5
ojFgiQGooooo00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00000Iooooo`00:oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo02?ooooo0oniaN@3okS3h`03ojND`OnVT/7oYY;100?oYY;10onUT<04ojB?_`04oj>>__nK
O;3oVgb`oi]l/0CoVW^`1?nJNZl3oiUj[`GoVGV^0_nHN:h5oiA`Y`OoU6nV4_nCKjH5oi5YX@GoTVZQ
0onBJZ84oi9[XPCoTVbS1?nCK:@3oi=]Y@03oiUh[?nJNJgoVWV]00;oVWV]1OnKNZh4oial[`CoWGf`
00?oWGnbojjPbOn^X<T00_n^X<T4ojfNb0Co[Ig70_nic>P4ok[7i0;oJ=Rk0onFLjT2oiEe[0?o0000
1?nDMk02oi=j]@03oiam/OnKOkCoVgnd00;oVgnd1OnJP[T4oiV6_PGoV8_400?oUi3;o`000?nOTLD0
1OnNUL/5oifJd@;oW:7H0_nVZ]X5ojJ`g`;oYKOV0on^_nHEooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B406Oooool002_o
oooo0ol00005ooooo`03o`000?oooooooooo027ooooo1OniaN@01?nh`n?oYiC1ojND`OnWU<44ojJB
`@CoYI300_nTSkl00onLOK7oVgb`oi]l/003oi]l/0?oVW^`1?nJNZl4oiUj[`CoVGV^00?oV7R^oiA`
YonDL:L01?nDL:L8oiA_YPgoTfnV2_nAJJ44oi9ZX@?oTVZR1?nBJj85oi9/X`?oTfbT00CoTffUoiUh
[?nIN:coVGR/1OnJNJd4oi]j[PGoW7b_0_nMOK000on^X/_o[Z39ojjPb@03ojjPb@Go[Ik800?o[Ig7
okW<j?nic>P00onic>P00onjanCoJ=RkofSH^`02oiMbY`;oUW>Y0ol00002oiEe[0GoU7N`00?oTgZe
oiam/OnLOK401OnKOk@4oiZ2^@GoVHJn0_nHRl@2oj6?`@;oWi7500?o0000oinAaOnNUL/00onNUL/4
oifJd@03ojNUe?nVZ][oYZ[J00?oYZ[J0onV/=l00on__NCo[[oVojjoiP04ojjoiQGooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@
olc<c00Iooooo`00:oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01kooooo0_nj
an@4okW5i003ojRF`_nWU<7oYiC100;oYiC11?nVT/43ojF@`004oian/OnLOK7oW7faoiam/@GoVgb`
0onJNk05oiYj[`?oVGZ_0_nINJh2oiEaY`OoU72W2?nDKjH:oi=_YPgoTFVQ1?nBJZ43oi9ZXPGoTV^R
1?nBK:<2oi=/Y003oiUgZonIN:coVGR/00?oVGR/1?nJNJd4oi]j[PGoW7b_00CoWGf`ojjRbon^X/_o
[Z;;1?n^X<T4ojfNb0;o^M;]1?nic>P00om@ajOoV76UoiMbY`02oiMbY`?o000000?oUW>YoiEe[?nE
MJ`00onEMJ`3oiAg/003oiak[_nLOK7oW7fa00;oW7fa1?nKOk@5oiZ2^@?oVHJn00?oXXfnoj6?`OnQ
Sl400_nQSl43oinAa@03o`000?nNUL_oWYG;00?oWYG;00?oWI[AojNUe?nWYM@00_nWYM@5ojJZfP04
ojJ`gon__NCo[kgTojnmi0Co[[oV00?o//CWooooooooool04oooool00ol0003oooooooooo`03oooo
o`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Kooooo`00:oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01cooooo1?njan@00oniaNCoZ9K2ojRF`P02ojRF
`P?oYiC11OnVT/400onUT<3oW7jaoian/@04oiam/@CoVgb`0onJNk05oiYj[`;oVGZ_00?oUG6XoiEa
YonELJL00_nELJL7oiA`Y`SoU6nV2OnCKjH>oi5YX@CoTVZQ0onBJZ85oi9[XPCoTVbS00?oTfbToiUg
ZonIMj/01OnIN:`4oiYi[@GoVgZ^0onLO:l00on^Y<go[Z;;ojjRb`03ojjRb`Co[Z3900?o[Ik8okWB
kOnid^d00onid^d00onic>SoV76UoiQaY@02oiQaY@?o000000?oUg:WoiIcZOnFLjT00_nFLjT4oiEe
[004oiAg/?nLNjkoW7^^oiak[PCoW7fa1?nKOk@5oiZ2^@03oiV6__nRSKkoXXfn00;oXXfn1?nQSl43
oinAa@03o`000?nNUL_oWYG;00;oZ:;@1OnWYM@4ojJZfP03ok2kh_n__NCo[kgT00?o[kgT00?o[[oV
ok;4ionba>L00_nba>LCooooo`?o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o
gMgMoa0@4?nHV9P06oooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Iooooo`;o^lST0onjan@00onZV<?oZ9K2ojRF`P03ojRF`PCoYiC10onVT/400onMP;;oW7jaoian
/@02oian/@?oW7fa1?nKO;04oiYk/0?oVWZ_00CoUW:XoiEaZ?nELJSoUG6X1?nELJL8oiA`Y`OoU6nV
1_nCKjHAoi5YX@CoTVZQ1?nBJZ84oi9[XP;oTVbS0_nHMZX4oiUgZ`CoVGR/1?nJNJd5oi]j[P03oial
[on^Y<go[ZC=00;o[ZC=1?n^X//3ojjPb@;o]mSa1?nid^d2oiQaY004oiQaYOl0003o0000o`0000Co
Ug:W1?nFLjT2oiEe[0;oWGZ/1OnLNjh3oiam/@GoVgnd0onJP[T00onTS;_oXXfnoj:=_P03oj:=_PCo
XHo10onOTLD00ol0003oZ:;@ojRRd003ojRRd0GoYjGD00?oYZ[Jok2kh_n`^n800_n`^n83ojnmi0Oo
//CW5Oooool02Ol0003oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4
A4Co0000oa0@41Wooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo
00?o0000ooooooooool01?ooool3o`0000[ooooo00?o0000ooooooooool05_ooool5ok_8i004ok[7
i?nZV<?oZYS3ojZH``CoZ9K21?nWU<401?nVT/7oWH2boif0/_nMP;84oian/@?oW7fa1OnKO;03oiYk
/004oiYj[onFLZSoUW:XoiIbZ0CoUG6X0onELJL8oiA`Y`OoU6nV0_nCKjHEoi5YX@GoTVZQ0onBJZ83
oi9[XP03oiQeZ_nHMZ[oV7JZ00;oV7JZ1?nIMj/4oiUh[0GoVWV]0onKNZh00on_Y/oo[ZC=ojjTc@03
ojjTc@Go[Z;;00?o[Z39okOHlOngf?400_ngf?400onid^goV72SoiQaY003o`0000?oV76U1OnGLZL2
oiIcZ@03oieiZonMNZcoWGZ/00;oWGZ/1OnLNjh3oiam/@GoVgnd00?oVX:iojB<^onTS;/00_nTS;/4
oj:=_PCoXHo100GoWi75ojVOc?nYWlcoZIo<o`000005ojRRd0;oYjGD0_na^^05ok2khP03ojnmi?nb
a>Oo//CW00Go//CW0_nbanTEooooo`03o`000?oooooooooo02oooooo0008ooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@00_ooooo1Ol00005ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool04oooool3okc9i0?o^lST00?o[9[5ojZH`onZV<<00_nZV<<5ojRF`P;oYiC100?o
WX6coif0/_nMP;800_nMP;84oian/@CoW7fa1?nKO;02oiYk/003oiIcZOnFLZSoUW:X00;oUW:X1?nE
LJP4oiEaY`OoU72W1_nDKjHHoi5YX@GoTVZQ0onBJZ801?nBJj;oV7FZoiQeZ_nHMJX5oiQfZP?oVGN[
1?nIN:`5oiYi[@03oi]j[_n_Y/oo[jK?00;o[jK?1?n^Y<d4ojjRb`?o]Moe0_ngf?42oiQ`X`;o0000
0_nHLJ@4oiQaY@GoUg:W00?oUW>YoieiZonMNJ/01OnMNZ`4oiak[PCoW7fa0onKOk@00onVSK[oY8bk
ojB<^`03ojB<^`GoXXfn0_nQSl400on[W/[oZIo<ojVOc003ojVOc005o`000?nXX]3oZ:;@ojRRd?nc
_>001Ona^^02ok2khP?o/lGW1?nba>L00oncbN_o//OYok;7j@03ok;7jAGooooo00?o0000oooooooo
ool0;_ooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`00
00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`Go_<WT00Co^lSTojbJ
aOn/V/Go[9[50onZV<<4ojRF`P04oin3]?nNPK?oWX6coij1/`GoWH2b0onLO[44oiam/@;oVgb`0_nG
M:X3oiIcZ@CoUW:X1?nELJP4oiEaY`OoU72W0onDKjHLoi5YX@CoTVZQ0_nBJZ800onGM:WoV7FZoiQe
ZP03oiQeZPCoV7JZ0onIMj/5oiUh[0?oVWV]00?o[jWBojnVcon_Y/l00on_Y/l5ojjTc@03ojjRbone
goGo]Moe00;o]Moe0_nHL:<3o`000004oiQ`XonHLJCoV76ToiQaY0GoV76U0onGLZL00onNNJWoWGV[
oieiZ`02oieiZ`CoWGZ/1?nLNjh4oiam/@03oi]o]?nVSK[oYXfj00;oYXfj1?nTS;/5oj:=_P04oj6?
`On[W/[oZik:oj^NbPCoZIo<00?o0000ojRRd?nc_>000onc_>03ok6jh003okC7jOncaNOo/lGW00Co
/lGW00?o//CWok?9joncbN/00_ncbN/3ok;7j@;o/<K[5Oooool00ol0003oooooooooo`0]ooooo`00
4?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo0_nmbN<4okc9i003ojjMa_n/V/Go[9[5
00;o[9[51?nZV<<01?nXU/;oWh>doin3]?nOPk@4oij1/`CoWH2b1?nLO[42oiam/@03oiMeZonGM:[o
UgBZ00;oUgBZ1?nFLjT3oiIbZ0CoUG6X1?nELJL7oiA`Y`03oiA_Y_nAJJ7oTFVQ01coTFVQ0onBJZ40
1?nGLjWoUgBYoiMdZOnGM:T5oiQeZPCoV7JZ0onIMj/5oiUh[003oiYi[On_ZM;o[jWB00;o[jWB1On_
Y/l2ojjTc@Co/^Gh00?o]MoeoiQ`Xol000000_l00004oiQ`X`CoV76T1?nHLJD01?nGLZOoWWVYoiii
ZOnNNJT4oieiZ`CoWGZ/1OnLNjh2oiam/@03ojR>^_nVSK[oYXfj00?oYXfj1OnTS;/3oj:=_P03ojbN
bOn[W/[oZik:00;oZik:1?nYWl`00one_^7o0000ok>lh004ok>lh004ok6jh?ndanWo]<OYokC7j@Co
/lGW0_nccNd4ok?9j`03ok;7jOn`a^_o/<K[00?o/<K[5?ooool00ol0003oooooooooo`0]ooooo`00
4?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool2o`0000oo
oooo0_l0000<ooooo`Go_LWS00?o_<WTojjMa_n^WLH00_n^WLH3ojbJa@?oZYS300?oXHFfoin3]?nO
Pk@00onOPk@3oij1/`CoWH2b1?nLO[400onLOK7oUgF[oiMeZ`04oiMdZPCoUW>Y1?nFLZP3oiEaZ0Co
UG6W1_nDL:LPoi5YX@04oi9ZXOnGLjWoUg>YoiMcZ@CoUgBY1?nHMJX4oiQfZPCoVGN[0onIN:`00on_
ZmCo[jWBojnYdP03ojnYdPCo[jK?0_n]joT4ok;Un0?o00001onHL:<4oiQaY0?oV76U1_nNNJT3oiei
Z`CoWGZ/1OnLNjh01?nLOK7oZ8jjojR>^_nXS[X4ojJ=^PGoY8bk00?oXXfnojbNbOn/W/T00_n/W/T4
oj^NbP03ojVOc?ne_^7o]KkQ00;o]KkQ00Go0000ok>lh?nc_>3o/kcPokG;j`05okC7j@03ok?5ionc
cNgo/lg]00?o/lg]0_ncbN/2ok39k@Co/<K[00?o[LC[ooooooooool04oooool00ol0003ooooooooo
o`0/ooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo0onnbN<3okg9h`03ojnOaon^
WLKo[Yg600?o[Yg61?n/V/D00onZV<?oXHFfoj65]P05oin3]0?oWX6c1?nMP;82oian/@;oV7J[1?nG
MJ/3oiMdZPCoUW>Y1?nFLZP4oiEaZ0?oUG6W0_nDL:L2oi5ZXR3oTFVQ0_nFLjT5oiMcZ@?oUgBY1?nH
MJX4oiQfZPCoVGN[00?oVGR/ojn[e?n_Zm@00_n_Zm@5ojnYdP03ojnVcon]joWo[N_i00?o[N_i0ol0
000;oiQ`X`?oV76T00?oV76UoiiiZOnNNJT01_nNNJT3oieiZ`GoWGZ/0onLNjh00onZT;_oZ8jjojR>
^P02ojR>^PGoYXfj0onTS;/00on^X<Wo[9k9ojbNb@03ojbNb@?oZik:00?o]l;SokFnhOne_^401?ne
_^400ol0003o]L_[okG;j`02okG;j`;o]<OY0oncdO04ok?=k@03ok3=kon`bNgo/<W]00?o/<W]00?o
/<K[ojg4jon]a>/00_n]a>/Cooooo`;o0000;_ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`05ooooo`Go_/WS00Co_LWSojnOaon_WlOo[io71On^WLH2ojbJa@03oj:7]onQQKKoXHFf00;oXHFf
1?nOPk@4oij1/`;oWH2b00?oVGN/oiQfZonHMZ/00_nHMZ/4oiMeZ`CoUgBZ0onFLjT4oiIbZ0CoUG6X
0_nELJL00onAJj;oTFZRoi5ZXP02oi5ZXQgoTFVQ00?oUW:XoiIcZOnFLjT00_nFLjT5oiMcZ@?oUgBY
1?nHMJX5oiQfZP;oVGN[00?o[jgFojn[e?n_Zm@00on_Zm@4ojnYdP?oYNkh00Co[N_io`000?l0003o
00000_nHL:8<oiQ`X`;oV76T2_nNNJT3oieiZ`GoWGZ/00?oW7^^ojZ@^onZT;/00_nZT;/3ojR>^PGo
YXfj00?oY8bkojjPbOn^X<T00_n^X<T5ojbNb@04oj^Nb_ng`^?o]l;SokO2h`Co]KkQ00?o]]3]o`00
0?nebn/00_nebn/2ok;ElPGo/m7`00?o/lg]ok3=kon`cNl00_n`cNl2ok39k@?o[LO]1?n]a>/Eoooo
o`03o`000?oooooooooo02_ooooo000Yooooo`;o00005?ooool00ol0003oooooooooo`02ooooo`;o
_lWR1?nnbN<00onaXlWo[io7ojnOa`02ojnOa`Co[Yg600?oY8Zioj:7]onRQkL00_nRQkL3oj65]PGo
Wh>d0onNPK<00onMP;;oVGN/oiUg[005oiQfZ`?oUgF[1?nGM:X3oiIcZ@CoUW:X0onELJP01?nBJj?o
TF^Roi5[X_nAJj84oi5ZXQcoTFVQ0_nFLZP5oiIcZ@CoUg>Y0onGM:T5oiQeZPCoV7JZ00CoVGN[ojn]
e_n_[MKo[jgF1On_Zm@01?n_ZM;oYNkhojG^n?nUk_P3o`0000GoV72R3?nHL:<00onHLJCoWWVYoiii
Z@09oiiiZ@CoWGV[0onMNZ`00on/T[coZY2kojZ@^`03ojZ@^`CoZ8jj0onVSKX00on`X/[o[Z39ojjP
b@03ojjPb@Co[9k900?o^LSVokO2hong`^<00ong`^<00one_^7o]]3]okK@k@02okK@k@03o`000?ne
bn_o/]Gb00?o/]Gb0_ncdO02ojo@l@Co/<g_0_n/bNh5ojg7k@;o[LC[0_n[`n/Eooooo`03o`000?oo
oooooooo02[ooooo000Yooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?nobN80
0onnbN?o/J?9ok6Sb@02ok6Sb@Co[io700Co[Yg6ojB:^OnTR[WoY8Zi1?nRQkL3oj65]PGoWh>d0_nN
PK<00onINJgoVGN/oiUg[002oiUg[0CoV7J[0onGMJ/4oiMdZPCoUW>Y0onFLZP01?nELJSoTV^Soi9[
XonBJj<3oi5[XPCoTFZR6OnAJJ42oiEbZ0CoUW:X1?nFLjT4oiMcZ@?oUgBY1OnHMJX2oiQfZP;o[ZoH
1On_[MH3ojn[e0?oW>od0_l00004oiQ_XPCoV72R2onHL:<=oiiiZ@CoWGV[00?oWGZ/ojbB_?n/T[`0
0_n/T[`4ojZ@^`CoZ8jj00?oYXfjok2Rb_n`X/X00_n`X/X5ojjPb@03ojbNbOnib>Ko^LSV00;o^LSV
0_ng`^<3okGFl@Co]]3]00?o/=Weo`000?nbeO800_nbeO82ojgCm0Co[m3a00?o/<g_ojc9k_n/bNh0
0on/bNh2ojg7k@;oZ/C]1On[`n/Dooooo`03o`000?oooooooooo02[ooooo000Yooooo`03o`000?oo
oooooooo01Gooooo0_nob>43oko9hP03ok>VbonaXlWo/J?900?o/J?90on_WlL00onUSK_oY8ZiojB:
^@03ojB:^@?oXXNg1?nQQKH3oin3]004oiYj[onINJgoVGV]oiUi[@CoVGN/1?nHMZ/3oiMeZ`CoUgBZ
1?nFLjT2oiIbZ003oi9/Y?nBJj?oTV^S00;oTV^S1?nAJj83oi5ZXQGoTFVQ0_nELJP4oiEbZ0CoUW:X
1?nFLjT4oiMcZ@CoUgBY0onHMJX00on^/=[o[ZoHojj_f003ojj_f0Go[jgF00?o[j_Doic_m?l00000
0_l00006oiQ_XPCoV72R2_nHL:<?oiiiZ@;oWGV[00?o[IJoojbB_?n/T[`00on/T[`5ojZ@^`;oZ8jj
00?o/JK=ok2Rb_n`X/X00on`X/X4ojjPb@;o^Lo[0onib>H2ok?Lm@Go]MKa00?o]]3]ok3ImOn`fOD0
0_n`fOD00ol0003o[M?dojgCm003ojgCm0;o[m3a0_n[b_04ojc9kP03oj[5k_nZa>goZ/C]00?oZ/C]
0_n[`n/3ojW1jaCooooo00?o0000ooooooooool0:Oooool002Wooooo00?o0000ooooooooool04ooo
ool5oko8h@04oko9h_ncY/_o/jK;ok>Vb`Go/J?900Co[io7ojF=^onUSK_oYHfk1?nTR[T4oj:7]`?o
XHFf00CoWh>doiYj[onJNZooVWZ_1?nINJd3oiUg[0CoV7J[1?nGMJ/3oiMdZP;oUW>Y0_nBKJD3oi9/
Y0CoTV^S1?nAJj84oi5ZXQ7oTFVQ00?oU76XoiEaZ?nELJP00_nELJP4oiEbZ0CoUW:X1?nFLjT5oiMc
Z@?oUgBY00?oV7FZojj`f_n^/=X00_n^/=X5ojj_f0;o[jgF00GoTNk^o`000?l0003o0000oiQ_X`08
oiQ_XPCoV72R2OnHL:<@oiiiZ@04oieiZon]U[oo[IJoojfF_`Co[9:l1OnZT;/01?nXS[[o/JK=ok6V
cOnaY/d5ok2RbP03ojjPbOnicn_o^Lo[00?o^Lo[00?o^LSVok?LmOncg?D00_ncg?D2okGFl@?o[=ch
0_n`fOD2oj_Fm`03o`000?n]doCo[M?d00;o[M?d00?oZ/caoj_:l?n[b_000on[b_000on/bNkoZ/G^
oj[5kP02oj[5kP?oZ/C]00?oZL;/ojW1jonY`N/01?nY`N/Dooooo`03o`000?oooooooooo02Sooooo
000Yooooo`?o00004Oooool3ol38h0?o_lSQ00?o]JW=ok>VboncY//00oncY//3ok6Sb@03ojN@_OnU
SK_oYHfk00;oYHfk1?nTR[T4oj:7]`;oXHFf00?oVgb`oiYj[onJNZl00_nJNZl4oiUi[@?oVGN/1?nH
MZ/4oiMeZ`;oUgBZ00?oTfjVoi9]YOnBKJD00_nBKJD3oi9/Y0CoTV^S1?nAJj84oi5ZXQ3oTFVQ0_nD
LJP5oiEaZ0?oUG:X1?nFLZP4oiIcZ@GoUg>Y0_nGM:T00on]/]co[[3Jojj`fP03ojj`fPCo[ZoH00Co
Q>[Uo`000?l0003o00001?nHKj<8oiQ_XPGoV72R1_nHL:<AoiiiZ@03ojnJ`_n]U[oo[IJo00;o[IJo
1On/T[`3ojZ@^`03ok>/dOnaY/go/JK=00;o/JK=1?n`X/X2okWHl0Co^Lo[00?o[^?iok?LmOncg?D0
0_ncg?D2ojSOnP?o[=ch0_nXf?T4oj_Fm`03o`000?n]doCoZ/ca00?oZ/ca0_n[b_03ojW6k`CoZ/G^
00?oZ/C]ojW2k?nY`^`00_nY`^`4ojW1j`03ojS1jooooooooooo017ooooo0_l0000Zooooo`00:Ooo
ool00ol0003oooooooooo`0@ooooo`Go`<SP00Co_lSQokFYcOneZLgo]JW=1OncY//01?naXlWoYi2m
ojN@_OnWT;d3ojF=^`GoY8Zi0_nRQkL01?nLO[;oVgb`oi]l/?nKO;04oiYj[`CoVGV]0onIMj`5oiQf
Z`;oUgF[00CoTfnWoi=^Y_nCKZKoTfjV1?nBKJD4oi9/Y0?oTV^S1?nAJj84oi5ZXPgoTFVQ1_nDLJP4
oiEaZ0CoUG:X0onFLZP5oiIcZ@CoUg>Y00CoUgBYojfbg?n]/]co[K;L1On^/=X01?n^[mSo0000o`00
0?l00003oiM_X`GoV6nS1onHKj85oiQ`XPCoV72S4OnNNJT4ojnJ`P?o[IJo1On/T[`00onZT;_o/jcA
ok>/d@02ok>/d@Co/JK=00?o/:;:okWHl?nif?000onif?000onicn_o[^?iojkSn@02ojkSn@03ok?L
mOnXgo[oZ=oj00?oZ=oj00?o[=chojSHnOnXf?T00_nXf?T2oj_Fm`;oZ<gc00?o0000oj[<lOnZc?40
0onXanl5ojW6k`;oZ/G^0_nX`n`5ojW2k003ojW1jonX`N_oZ<7[00;oZ<7[5?ooool00ol0003ooooo
ooooo`0Wooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
1Oooool00ol0003oooooooooo`0?ooooo`;o`LOO1?o0b>000ong[Lko]JW=okFYc@02okFYc@Co/jK;
00?oZYC0ojN@_OnWT;d00_nWT;d4ojF=^`CoY8Zi00?oXXNgoian/_nLO[801?nKO;04oiYj[`?oVGV]
1?nIMj`4oiQfZ`03oiMeZonCKjOoTfnW00?oTfjV1?nBKJD4oi9/Y0CoTV^S0onAJj84oi5ZXP[oTFVQ
00?oTg6YoiAaZ?nDLJP01_nDLJP4oiEaZ0CoUG:X1?nFLZP4oiIcZ@;oUg>Y0_n//md5ojfbg0;o[[3J
0ol00007oiM_X`CoV6nS2?nHKj84oiQ`XP;oV72S00?oWWZZoiiiZOnNNJT03_nNNJT00on`WlKo[i[2
ojnJ`P03ojnJ`PCo[IJo0on/T[`00one/mOo/jcAok>/d@04ok>/d@;o/JK=0oneh?D2okWHl0?oYnSk
0_n^hoT4oj?Qo0;oZ=oj0onUfOX2ojSHn@?oYlgd0onXcO<00ol0003oYlO`ojS7k`04ojS7k`;oZLK_
0_nX`nd5ojS3k0;oZL;/0_nX`N`5ojS1jaGooooo00?o0000ooooooooool09_ooool000kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Go
oooo00?o0000ooooooooool03Oooool5ol77g`03ol38h?ng[Lko]jg>00;o]jg>1?neZLd00oncY/_o
ZYC0ojZD`002ojZD`0?oYi2m1?nUSK/2ojB:^@;oWH6d1?nLO[83oi]l/0CoVWZ_1?nINJd3oiUg[0;o
V7J[0_nDLJP4oi=_Y`?oTfjV0onBKJD4oi9/Y0CoTV^S0onAJj84oi5ZXPKoTFVQ1OnCLJT8oiAaZ0Co
UG6X1?nELZP4oiIbZ0?oUW>Y00?oZk?OojbcgOn//md00on//md3ojfbg0?o000000?oUFjToiI^XonG
Kj<01onGKj<4oiQ_X`SoV6nR0onHL:801?nNNZ_oWWZZoiijZ_nNNZX?oiiiZ@?o/9o61?n_V/84ojfF
_`03ojbB_?ne/mOo]K?G00;o]K?G1?nc[=400on^ioWo]N3eokGPm@02okGPm@?oW>[j0_nWj?/3oigR
o@;oXn7l1?nRf_/2ojGInP;oY/gd1OnWcO@01OnXcO?oYlO`ojO7l?l0003oYlO`00;oZ<O_1onX`nd2
ojS3k0OoZ<7/0_nX`N/3ojS0jaCooooo00?o0000ooooooooool09_ooool000Kooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP06ooooo`;o00003Oooool0
0oo1a]ko`LOOol77g`03ol77g`Go]jg>0oneZLd00on/VL?oZYC0ojZD`003ojZD`0CoYi2m0_nUSK/0
0onOQ;KoWH6doif1]002oif1]0CoW7jb0onKO;04oiYj[`CoVGV]0_nIMj`00onELj[oU76XoiAaZ002
oiAaZ0CoTfnW0onCKZH4oi9]Y@?oTVbT1?nBJj<4oi5[XP?oTFZR0_nAJJ4:oi=aZ@OoU76X1?nELJP4
oiEbZ0CoUW:X00?oUW>Yoj^cgon[/ml00_n[/ml5ojbcg@;o000000?oJ]g@oiI^XonFKZ<00_nFKZ<8
oiM_X`CoV6nS2?nHKj801?nHL:;oWWZ[oiijZonNNZ/4oiijZPgoWWVY1?n`WlH5ojnJ`P;o[IJo00?o
][_MokFceone/mL01?ne/mL00onc[=7o[^OiojkWn@02ojkWn@03okGPmOnLj_[oW>[j00;oW>[j0_nI
h_d2oigRo@?oWm[l1?nRf_/00onUc?CoY/gdojK=m003ojK=m0;oYlgd1_nWao000ol0003oZ<?]ojS3
k@06ojS3k@WoZ<7/1onX`>/Dooooo`03o`000?oooooooooo02Gooooo000>ooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo00_ooooo0oo1
a]h3ol77g`;o^K3@1Ong[Lh01?neZLgo[9W3ojbI`on/VL<4ojZD`0CoYi2m00?oYHfkoin4]_nOQ;H0
1?nMPK@4oian/PCoVgb`0onJNZl2oiUi[@;oUWB/0onELjX4oiAaZ0CoTfnW0onCKZH4oi9]Y@?oTVbT
1?nBJj<4oi5[XP;oTFZR3OnCLJT7oiAaZ0GoUG6X0onELZP2oiIbZ0;oZ[CP1On[/ml2ojbcg@?o0000
1onFKZ<8oiM_X`CoV6nS1onHKj800onNNjcoWWZ[oiijZ`03oiijZ`?oWWZZ2onNNJT00onaYL_o/9o6
ok2OaP03ok2OaPGo[i[200Co[IJookJkgOnf^mgo][_M1?ne/mL3oj?/n@;o[^Oi0on?jOH01?nLj_[o
VN;moiWRoOnIh_d2oikIo0GoWm[l00?oX][kojG<m?nUc?@00_nUc?@2ojK=m0?oY/O`1OnWao03ojO3
k@03o`000?nX`ngoZ<?]00;oZ<?]00?oYl7/ojS1k?nX`N`01OnX`N`2ojO0j`OoZ<3[0_nW`>/Eoooo
o`03o`000?oooooooooo02Cooooo000>ooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOoIVIVooooo`04ooooo`03o`000?oooooooooo00[ooooo1Oo1a]h01?o1amoo^K3@okV`d?ni/=04
okN]cP03ojnNa_n/VL?o[9W300;o[9W31OnZU<02ojN@_@03oj27^OnOQ;KoWhBf00;oWhBf1?nMPK@3
oian/PCoVgb`0_nJNZl00onFMjkoUWB/oiId[002oiId[0CoUG>Z0onDLJP4oi=_Y`?oTfjV1?nBKJD4
oi9/Y0?oTV^S1?nAJj800onAJZ;oTg6Yoi=aZ@0<oi=aZ@SoU76X1?nELJP2oiEbZ0;oZ;CQ1?nZ]>03
oj^cg`?o000000?oU6fSoiE^XonEKZ<02?nFKZ<7oiM_X`GoV6nS1?nHKj83oiik[0GoWWZ[0onNNZX:
oiiiZ@?o/JG;1On`WlH2ojnJ`P;o]/GU1Onf^md00one/mOoXncioj?/n@02oj?/n@;oPNK`0_n?jOH4
oiGQo@03oiWRoOnNfOcoW]Wl00;oW]Wl0_nOf_`4ojC<m0;oYLcd0_nVa_05ojK7l0;oYlO`1OnW`nd0
0ol0003oYl?]ojS3k@04ojO1k0?oZ<7/00?oYl3/ojO0jonW`>/00onW`>/2ojS0j`OoYl3[4oooool2
o`0000Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`00
0?lQ8B7oc<c<00Wooooo000>ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`03ooooo`;o00002Oooool2ol;5g@Co`LKN00?o^kCBokV`d?ni/=000oni/=000ong[Lko[ik6
ojnNaP02ojnNaP?o[9W31?nZU<000onRRkcoX8Nioj27^@02oj27^@?oWhBf1?nMPK@4oian/P;oVgb`
00CoUgV`oiIg[_nFMjkoUWN^1?nFM:`4oiEcZPCoU76X0onCKjL3oi=^YPCoTVfU1?nBK:@3oi9[X`;o
TF^R0_nBLJX?oi=aZ@SoU76X1?nELJP00onELZSoZ;CQojRdh@02ojRdh@?oZ[CP0ol00003oiA]X`?o
UFjS2?nFKZ<7oiM_X`GoV6nS0_nHKj800onMNjgoWW^/oiik[003oiik[0CoWWZ[0onNNZX8oiiiZ@03
ok>[dOnaYL_o/JG;00;o/JG;1?n`WlH00onecngo]/GUokK5i@03okK5i@;o][_M1?nEk?H01?nSk?Wo
PNK`oh7Vl?n1i_03oi;PoP;oUN7m0onMf?`2oikIo0?oY<_d1?nTc?@00onVaO3oY/K`ojK6l003ojK6
l0;oY/O`0_nW`^d7ojO3k@03ojO1k?l0003oYl7/00CoYl7/00?oZ<7/ojO0k?nW`>`00_nW`>`>ojO0
jaCooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B402Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool2o`0000Wooooo1?o2aMd00oo1a]ko^kCB
ok^ddP02ok^ddP?o^K3@00?o/J?9ojnNa_n_W/H00on_W/H4ojbI``04ojZD`?nRRkcoXX^loj:;_0Co
X8Ni0onOQ;H4oif1]0CoW7jb00?oVgb`oiMi/?nGNK001?nFMjh3oiId[0CoUG>Z1?nDLJP4oi=_Y`?o
TfjV0onBKJD4oi9/Y0;oTV^S00?oTW:[oi9aZ_nBLJX00_nBLJX?oi=aZ@SoU76X0_nELJP2ojNchPGo
Z;CQ0ol000000om;akGoTfbSoiA]X`03oiA]X`CoUFjS1onFKZ<8oiM_X`CoV6nS00?oV6nRoiek[OnM
Njd01OnNNj`4oiijZ`?oWWZZ1_nNNJT4ok>[d@Co/JG;00?o/9o6okG?kOnecnd00_necnd3okK5i@?o
Q>S^0_nEk?H2ogCQj@?oTMon0_nBh?h4oigGo0;oWMSl0_nTb_@5ojC;m003ojC<m?nVaO3oY/G`00;o
Y/G`0_nVa_07ojO2k@;oYl?]1_nW`N`00ol0003oYl7/ojO1k007ojO0k0ooYl3[5?ooool00ol0003o
ooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo
000000Wooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo00?o0000ooooooooool01_ooool2ol;5g0?o`/GM0_nm^=@5ok^ddP04okV`d?na
XlWo/J?9ok6Sb@Go[ik60_n/VL<00onTT;ooXX^loj:;_002oj:;_0CoX8Ni1?nOQ;H3oif1]0;oW7jb
0_nHNk84oiMi/0?oUWN^1?nFM:`3oiEcZPCoU76X1?nCKjL3oi=^YP?oTVfU0_nBK:@2oi9b[0?oTW:[
1OnBLJX?oi=aZ@KoU76X00?oY[?RojNch_nW/n800onW/n801_nX]>7o0000o`000?l0003o@l:_oi9/
X`?oTfbS1?nDKJ<4oiE^X`OoUVjS2?nGKj<3oiQ_X`03oiel[_nMNjgoWG^]00;oWG^]1?nNNj`4oiij
Z`CoWWZZ0onNNJT00onc/]Oo/j_Aok>[d@03ok>[d@?o/JG;0_nbf_D5okG?k@05okK5iOn4j>koQ>S^
ohCXk_mYg><01?nAg_h2oi7OoP?oWMGk0_nMeo`2ojC9l`GoY<[d0_nTbo@3ojK5k`?oY/G`2OnW`^d9
ojO1k003ojO0k?l0003oYl3/00KoYl3/4?nW`>/Dooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S802Oooool002Oooooo00?o
0000ooooooooool01?ooool5ol;5g003ol;5gOnm^=Co_KSD00;o_KSD0onk]=800ondZ<go/J?9ok6S
b@03ok6Sb@?o[ik600?oYiG3ojB@_onTT;l00_nTT;l4oj:;_0CoX8Ni0onOQ;H2oif1]003oiQn]?nH
Nk;oV7^b00;oV7^b1?nGNK03oiIg[PCoUWB/0onELjX4oiAaZ0CoTfnW0onCKZH2oi9]Y@03oi9c[?nB
LZcoTW:/00;oTW:/1?nBLZ/4oi9aZPooTg6Y0onDLJP00onT/^;oY[?RojJchP02ojJchP;oYk?R0ol0
00000onX]>7oTVbSoi9/X`02oi9/X`?oTfbS1OnDKJ<3oiE^X`OoUVjS2?nGKj<01?nHKj?oWGb^oiel
[_nMO:h4oiek[@CoWW^/1OnNNZ/3oiijZP03oiiiZOnc/]Oo/k;G00;o/k;G1OncZm400onaYL_o/][e
ok;Jm@02ok;Jm@;o]Lo]0_mchN@2of;HgP?oT]gn0_nAg_h3oikDn`;oWMGk0onTb?84ojC9l`;oY<[d
0onVa>l5ojK5k`03ojK5l?nW`^goYl;]00CoYl;]2OnW`N`5ojO0k004o`000?nW`>coYl3/ojO0k1Go
Yl3[5?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000002oooool01Oo<
c<co0000o`000?l0003oc<c<00Wooooo000Wooooo`;o00001?ooool2ol?4f`?o`/GL00?o_kcFokfh
e?nm^=@01?nm^=@01?nk]=;o]:S=okBXcOndZ<d5ok6Sb@04ojnNa_nWUL?oYiG3ojNE``?oY92o1?nR
Rk`4oj27^@;oWhBf00CoVH6goiQn]?nHO[CoV7jd1?nHNk84oiMi/0?oUWN^1?nFM:`4oiEcZP?oU76X
0_nCKjL2oi9d[P?oTW>]0onBLj`5oi9b[0?oTW:[1?nBLJX?oi=aZ@03oiAaZ?nT/^;oY;;R00;oY;;R
0onV/n82o`000004ojNch_nAJj?oTF^Soi5[X`CoTVbS1?nCK:<4oiA]X`?oUFjS2?nFKZ<6oiM_X`03
oiel[onMO:koWGb^00?oWGb^0onMNjd4oiik[0GoWWZ[0_nNNZX00ond^]ko/k;Gok>be`04ok>be`;o
/j_A0on[hoX2ok;Jm@;oI=WJ0_mMe]`3oiCLoP;oT]gn1?nOd_X2oikDn`;oYLOb1OnTb?82ojC9l`;o
Y/?^1OnVa>l2ojK5k`KoYl;]00?oYl3/ojO1k?nW`N`01OnW`N`3ojO0j`KoYl3/00?oYl3[o`000?nW
`>/05_nW`>/Eooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?nj^[[ooooookZj^_l@41002Oooool002Oooooo00?o0000ooooooooool00_ooool4ol?4
f`04ol;5g?no_=Ko_kcFoknlePCo_KSD00?o]joAokBXcOndZ<d00_ndZ<d4ok6Sb@03ojVKaonWUL?o
YiG300;oYiG30onTT;l4oj:;_0;oX8Ni0_nJQ;X3oiV1]`CoV7jd1?nHNk83oiMi/0?oUWN^1?nFM:`4
oiEcZP;oU76X00?oTWJ`oi9d[_nBM:h00_nBM:h3oi9c[@CoTW>/1?nBLZ`3oi9bZ`CoTW6Z3OnCLJT3
oj>ahPCoY;;R0ol00003oi5ZX`?oTF^S1OnBK:<3oi=/X`CoU6fS0onEKZ<8oiI^X`?oUfnS00CoW7b_
oiel[onMO:ooWGb_1OnMO:h3oiek[@GoWW^/0onNNZ/00onc`NCo];[NokBjgP02okBjgPCo/k;G0onP
jO/2oj_SnP;oF=;A00?oG=GKoiKKo_nFfoh00_nFfoh2oiCLoP;oX=7i1?nOd_X2ojG6l@CoYLOb0_nT
b?87ojK3kP;oY/C_0onW`Nd5ojO2k@CoYl3/0onW`N`7ojO0j`;oYl3/1OnW`>/00ol0003oYl3[ojO0
j`0EojO0ja;ooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonj^[[o000000Wooooo000Wooooo`04o`000?ooooooooooooooo`Co`lCK00?o`/3Hoknle_no
_=H00ono_=H00onm^=Co]joAokN_d@02okN_d@Co]:S=00?o/J?9ojVKaonYVlL00_nYVlL3ojNE``Co
Y92o0_nRRk`00onLR;koVXBjoiZ4^P02oiZ4^PCoVH6g0onHO[@4oiQk/P?oUgV`1?nFMjh3oiId[0;o
UG>Z0_nBMk43oi9f/0CoTWB^1?nBLjd3oi9c[0CoTW:/0onBLZ/4oi9aZP[oTg6Y0_nQ/>85oj>ahP?o
00000on@JZ<3oi5ZX`CoTF^S1?nBK:<3oi=/X`CoU6fS1?nEKZ<7oiI^X`04oiM_XonLO:ooW7b_oial
[`CoWGb_1?nMO:h3oiek[@GoWW^/00?oWWZ[ok?1i?nc`N@00_nc`N@4okBjgP04ok>beonPjO_oX>Wk
oj3Yn`;oC/c90_mMeM`3oiSJoP;oU]_n0onQcoP4oj3An@03oioBn_nUa_7oYLKa00?oYLKa0_nUao82
ojK2k@OoY/?^0_nW`N`5ojO1k@;oYl;]1onW`>`00onW`NcoYl3[ojO0j`0=ojO0j`03o`000?nW`>_o
Yl3[01KoYl3[5?ooool02Ol0003oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
ojVYZOl@413o0000oa0@4?nYZJT02Oooool002Kooooo0ol00005ol?4f`?o`/3H0ono_=H2okZee0Go
]joA0_ndZ<d00on]XLcoZI_7ojVKa`03ojVKa`CoYiG30_nTT;l00onMS<7oW8Rnoib8_P02oib8_PCo
VXBj0onIPKL3oiQn]0CoV7^b1?nGNK03oiIg[P;oUWB/00?oTWRcoi9g/OnBMk400_nBMk44oi9f/0?o
TWB^1?nBLjd3oi9c[0CoTW:/0onBLZ/5oi9aZPGoTg6Y0_nO[^85oj6`hP06oj>ah_l0003o0000o`00
0?li^jgoSfVS1?n@JZ<4oi5ZX`?oTF^S1?nBK:<3oi=/X`CoU6fS1?nEKZ<6oiI^X`03oiam/?nLO:oo
W7b_00?oW7b_0onMO:l4oiel[PCoWG^]0onNNj`2ok;9j`Go/l7T0_nd^]h2oi7[mP03odS8a?mOe]ko
GmKN00CoV]Wm0_nHf_h2oj;>m`GoXLoh0_nPdOT3ojG6l0;oYLKa1onV`^d2ojK3kPOoYl7/0_nW`Nd2
ojO0j`OoYl3/4onW`>/00ol0003oYl3[ojO0j`0EojO0jaGooooo00?o0000ooooooooool07_ooool0
02Kooooo00?o0000ol?4foo3a=/01?o3a=/5ol;0f003oknle_nj]MCo^[GD00;o^[GD0ong[m400on`
Z=7o[J7<ojfQc002ojfQc0CoZI_71?nWUL<01?nTT;ooWHc1oif<`OnMS<43oib8_PCoVXBj0onIPKL4
oiQn]0?oV7^b1?nGNK02oiIg[P04oi9j]?nBN;?oTWRcoi9h/`GoTWNa0onBM[04oi9d[P?oTW>]0onB
Lj`4oi9b[0CoTW:[1?nBLJX2oi=aZ@03oij/hOnO[^;oWjkR00?oWjkR0_nQ/>83o`000003oj>ah_n?
JJ?oSfVS00;oSfVS1?n@JZ<4oi5ZX`?oTF^S1?nBK:<3oi=/X`GoU6fS0onEKZ<2oiI^X`;oVgfa0onL
OK05oial[`?oWGb_1OnMO:h3oiek[@03oiik[?nbbN_o//W[00?o//W[0_nc`N@3oh3Wk003oi7[m_mR
f>;oH]SR00?oVmSm0_nJfOd2oj?=mPGoX/kg0_nQcoP2ojK5l0CoYLK`00?oYl7]ojK2kOnV`^d01OnV
`^d9ojO1k0OoYl3[0_nW`>`HojO0j`03o`000?nW`>_oYl3[01GoYl3[5?ooool00ol0003ooooooooo
o`0Nooooo`006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooo3a=/00_o3
a=/3ol?4fP?o`/3H00?o_KcIokZee?nj]M@01?nj]M@01?ng[m7o/:SAok2XdOn`Z=43ojfQc0GoZI_7
0_nWUL<00onOTLGoWHc1oif<`@02oif<`@?oW8Rn1?nJQ;X4oiV1]`?oV7jd0_nHNk800onCOKWoTg^f
oi=k]P02oi=k]P?oTWZd1?nBN;<4oi9g/@?oTWJ`1?nBM:h3oi9c[@CoTW>/1?nBLZ`3oi9bZ`;oTW6Z
0_nLZN04oij/h@?oWjkR0ol000000onQ/>;oSfVSohmYX`06ohmYX`?oT6ZS1?nAJZ<3oi5[X`CoTVbS
1?nCK:<4oiA]X`;oUFjS00?oVWbaoi]m/OnKOK400_nKOK44oiam/0CoW7b_0onMO:l5oiel[P;oWG^]
0_n`d?04ok;9j`?oK]oN0_n0in`2oigGo0CoVmSm0_nTbo@4oj?=mP;oX/kg0onVaNl4ojK5l003ojG6
l?nW`NgoYl7]00;oYl7]0onV`^d9ojO1k2GoYl3[00?o0000ojO0jonW`>/05OnW`>/Dooooo`03o`00
0?oooooooooo01gooooo000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool01?l0003ooooo
ooooooo3a=/5ol?4fP04ol;0f?nm_=Wo_KcIokflf@Co^[GD00?o/k7Fok2XdOn`Z=400_n`Z=44ojfQ
c0;oZI_70_nRUlX4oinAa@?oWHc11?nLR;h4oiZ4^P?oVH6g0_nHO[@01?nCP;_oTgfioi=m^OnCOKT4
oi=k]PCoTWZd0onBN;<4oi9g/@?oTWJ`1?nBM:h4oi9c[@?oTW>/1?nBLZ`2oi9bZ`03oiZWg_nLZN3o
W:WP00?oW:WP0onN[>43o`000003ohiYXon?JJ?oSfVS00WoSfVS1?n@JZ<3oi5ZX`?oTF^S1OnBK:<3
oi=/X`CoU6fS00?oUFjSoiYl/OnJO;401OnKOK43oiam/0CoW7b_1?nMO:l3oiel[P;o[]Ke1?n`d?00
1?nbbN_oK]oNofkOg_m^gmh3oikGn`CoWMOl00?oVmSmojC;m?nTbo@00onTbo@2oj?=mP;oY/C_1OnV
aNl2ojK5l0;oYl7/1OnW`Nd00onV`^goYl7/ojO1k005ojO1k2SoYl3[00?o0000ojO0jonW`>/05_nW
`>/Cooooo`;o00007_ooool001_ooooo00Go410@oooooooooooooooooa0@4006ooooo`;o00000_oo
ool4ol?4fP03ol34gOnm_=Wo_KcI00?o_KcI00?o^[GDok>ae_nc/MH00_nc/MH4ok2Xd@;o[J7<00?o
Y9k?oj:Gb_nRUlX00onRUlX3oinAa@CoWHc10onLR;h4oiZ4^P;oVH6g00?oU8:moi>0^onCP;/00_nC
P;/3oi=m^@CoTg^f0onBN[@3oi9h/`CoTWNa1?nBM[03oi9d[PCoTW>]0_nBLj`00onGXM_oVJCMoiVT
g@02oiVTg@CoVZON1?nLZN03o`000003ohmYXon>JJ?oSVVS00;oSVVS2_n?JJ<4oi1ZX`?oTFZS1?nA
Jj<4oi9/X`?oTfbS0_nDKJ<2oiUl/@CoVWba1?nKOK43oiam/0GoW7b_0onMO:l00onMO:ko[]KeojkF
m@03ojkFm@;o/=3`0_mMeM02oioFn`GoW]Ok0_nMeo`5ojC;m0?oY/C^1?nVa>l2ojK5k`OoYl7/0_nW
`Nd8ojO1k2_oYl3[00?o0000ojO0jonW`>/05OnW`>/Booooo`03o`000?oooooo000001kooooo000K
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03ol?4f_o0
a=go`<CM00;o`<CM0onm_=T2okJig0Co/k7F0on`Z=400onWYMCoY9k?ojBNc`02ojBNc`CoXYO:0onO
TLD4oif<`@;oW8Rn00?oUXS3oiF5`?nEQL000_nEQL04oiB2_@?oTh2k0onCOKT4oi=k]P?oTWZd0onB
N;<5oi9g/@?oTWJ`0onBM:h2oi9c[@;oUYgI1?nGXM/4oiVTg@CoVZON00CoW:WPo`000?l0003oBl_=
0on?JJ<4ohiYX`[oSfVS1?n@JZ<4oi5ZX`?oTF^S1?nBK:<2oi=/X`03oiQk/OnIO;7oVGba00;oVGba
1?nJO;44oi]m/@CoW7f`1?nLO:l2oiel[`?oZ][h0_n^e_D2odo<`P;oLn3]00?oKmkZoioFnonOe_/0
0_nOe_/2oikGn`CoYL[c0_nTbo@2ojK3kPGoY/C^0_nVa>l9ojO1k0;oYl3/1_nW`N`_ojO0j`03o`00
0?nW`>_oYl3[01GoYl3[5?ooool00ol0003oooooooooo`0Kooooo`006oooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool00oooool5ol34g@03okflfOnf^Mco][WL00;o][WL
1?nc/MH01?n`Z=7oYjGDojNUe?nWYM@4ojBNc`?oXYO:1?nOTLD2oif<`@03oiN=aonFR<?oUXS300;o
UXS31?nEQL03oiB2_@?oTh2k0onCOKT4oi=k]PCoTWZd0onBN;<4oi9g/@;oTWJ`00?oTiODoiFJeonE
V]L00_nEV]L4oiJMf@?oUj7K1OnIY=d01?nJYmko0000o`000?l00003ohmZY0CoSfVS0on>JJ<:ohmY
X`CoT6ZS1?nAJZ<3oi5[X`;oTVbS0_nGN[43oiQk/@CoVGba1?nJO;44oi]m/@CoW7f`0_nLO:l4ojKN
n`;oZ][h0_m3`kL00omghNooLn3]og?Pk@04oj7EnP;oWmKk0_nUbO84ojG:l`;oYl?^1?nV`nh2ojK4
kP;oYl3/1onW`N`7ojO0k0;oYl7/<_nW`>/00ol0003oYl3[ojO0j`0EojO0jaGooooo00?o0000oooo
ooooool06_ooool001_ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo
00Gooooo0oo0a=d2okW3hPGo][WL0_nc/MH00onZ[][oYjGDojNUe002ojNUe0GoY9k?0onRUlX2oinA
a@03oiRAbonGSLOoUhg700;oUhg70onFR<<4oiF5`0?oU8:m1?nCP;/3oi=m^@CoTg^f0onBN[@3oi9h
/`;oTWNa0_nBU=84oi>Ge0CoUI[G0onFWMT4oiNQf`;oVJCM0ol00003oi1[Y0CoSfZT0on?JJ<3ohiY
X`_oSfVS0on@JZ<4oi5ZX`;oTF^S00?oUWV`oiMj/OnGN[400_nGN[44oiQk/@CoVGba0onJO;45oi]m
/@;oW7f`0_nRh?`4ojKNn`03oc^l[Om8b<?oMn7_00;oMn7_0onQe?X2oj7EnP?oY/Sb1?nUbO800onU
b_?oYl?^ojO3kP03ojO3kP;oY/?^1_nW`>`2ojO1k0WoYl3/=onW`>/00ol0003oYl3[ojO0j`0EojO0
jaCooooo00?o0000ooooooooool06_ooool001_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o00001oooool00oo0a=go^L?RokW3hP02okW3hP;o][WL0_n/]n44ojZ^fPCoYjGD0_nTW/l2oi^L
e0?oVIK?1?nHTL/3oiN=a`?oUXS31?nEQL04oiB2_@?oTh2k0onCOKT4oi=k]P;oTWZd00CoTI3?oi:B
d?nBT]3oTY;@1OnBU=83oi>Ge0GoUI[G0onFWMT2oiNQf`?o00000onAKJH3oi1[Y0CoSfZT0on?JJ<3
ohiYX`_oSfVS0on@JZ<2oi5ZX`;oUGN_0onFNK04oiMj/@CoV7^a1?nIO;44oiYl/@CoVgfa00?oW7f`
oj;Po?nRh?`00_nRh?`01?nVg__oBlW4od_9a?mjh_04oj;Dn@;oXMCj0_nVb?45ojK8lP;oYLWb1_nW
`nh00onW`>_oYl3/ojO0k005ojO0k0;oYl3[1onW`>`kojO0j`03o`000?nW`>_oYl3[01GoYl3[5?oo
ool00ol0003oooooooooo`0Iooooo`006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o
0000ooooooooool01oooool3okW3hP;o[/7X1?n/]n44ojZ^fP;oYjGD00?oWJ?Joi^Le?nKW=@00onK
W=@3oiVFc`?oV97;0onGSLL4oiJ8``CoUHG00onDP[d2oi>0^`04ohn=c?n@SLgoT8g=oi2=c@CoT8k=
1?nAT<l3oi:Bd0CoTYCB1?nCUm@2oiFJe`CoNmWm0ol00003oi=_Y`?oTFfV0on@Jj@4ohmZY0?oSfVS
1?n>JJ<:ohmYX`;oT6ZS00?oU7J_oiEg[onEMjl00_nEMjl4oiIi/0?oUgZa1?nHNk44oiUl/@CoVWba
0_nKOK44oioQo@;oX^3l0_mmho43oj?Dn@;oX]Ci1onVb?42ojK8lP?oYl?]1OnW`nh4ojO0j`?oYl3/
1_nW`>/2ojO0k43oYl3[00?o0000ojO0jonW`>/05?nW`>/Dooooo`03o`000?oooooooooo01Wooooo
000Uooooo`03o`000?oooooooooo00Sooooo00?o^L?Rojk1j?n^`NP00_n^`NP4ojbgh@;oZZkJ00?o
WZ_PoifSf_nMXmX00_nMXmX4oi^Le0?oVIK?0onHTL/4oiN=a`?oUXS30_nEQL02ohn>cP?oShg=1?n?
SL`3oi2=c@CoT8k=0onAT<l3oi:Bd0GoTYCB0_nCUm@4oh;Fo`?o00000_nELZT4oi=_Y`CoTFfV0on@
Jj@3ohmZY0?oSfVS1?n>JJ<5ohmYX`03oi5c[OnCM:koTgB^00;oTgB^0onDMZl5oiEg[`?oUWV`1?nG
N[44oiQk/@?oVGba0_nJO;44oicRo@;oWn7m00?oD<g7ogoTl_moi?801OnSe?T9ojK8l@OoYl?]0_nW
`nh6ojO0j`03ojO0k?nW`>_oYl3[04SoYl3[00?o0000ojO0jonW`>/05OnW`>/Booooo`03o`000?oo
oooo000001[ooooo000Uooooo`03o`000?oooooooooo00[ooooo1?n^`NP2ojbgh@03oindionNZn3o
WZ_P00;oWZ_P1?nMXmX4oi^Le0?oVIK?0onHTL/2oiN=a`04ohnBd_n?T=3oSi3@ohn@d0GoShk>0on?
SLd3ohn=c0?oT8g=1?n@S/d4oi6@c`?oTY;@0_nBU=84ohOAo`04oh;Fool0003o0000o`0000;oV7N/
0onELZT4oi=_Y`CoTFfV0on@Jj@3ohmZY0?oSfVS1?n>JJ<2ohmYX`04oi1a[?nALjgoTG>]oi5c[@Co
TgB^1?nDMZl4oiEg[`?oUWV`1?nGN[44oiQk/@;oVGba0onJhOd2oicRo@03oe;>b?n1iO;oPNGb00;o
Y=Ci1?nSe?T2ojO7l@KoY/Sa2OnW`neFojO0j`03o`000?nW`>_oYl3[01GoYl3[5?ooool00ol0003o
ooooooooo`0Gooooo`009Oooool2o`0000cooooo0_n^`NP2oj2nkP?oWkCW1?nNZn04oifSfP;oVicD
00CoT9oNoi2JfOn@V]WoT9[I0on?U]H4ohnBdP?oSi3@1?n?S/h3ohn=c@?oShg<1?n@SLd4oi2>c@;o
TI3?0_n<a?X5oh[;o@;oQm7o0_l00002oial[`?oV7N/1?nELZT3oi=_Y`CoTFfV0on@Jj@3ohmZY0;o
SfVS00?oSfn[oi1`Zon@L:/00_n@L:/3oi1a[0CoTG>]1?nCM:h3oiAf[`CoUGN_0onFNK04oiMj/@?o
V7^a0onJgod2oi[Qo@03o`000?n2i_;oP^Kb00KoY=Ci00?oXmCiojO7lOnWao400onWao42ojK8l@;o
Yl;]1onW`neJojO0j`03o`000?nW`>_oYl3[01GoYl3[4oooool00ol0003oooooooooo`0Gooooo`00
9?ooool00ol0003oooooooooo`0=ooooo`CoX;k^0onO]>L2oij[h0;oTJ_X0onAYN<4oi2OgP?oT9[I
0on?U]H3ohnBdP?oSi3@1?n?S/h4ohn=c@?oShg<0_n@SLd3ohbhl`?oSKgg1?n<a?X2oh[;o@05ojF:
^?l0003o0000o`000?nPP[<01?nLO:l3oiQg[0?oUG:Y0onCKjL2oi5]YPSoSVjZ0on?Kj/4oi1`Z`Co
T76/0onALjd4oi=d[P?oU7J_1?nEMjl4oiIi/0?oUgZa00?oV7^aoi[OoOnJgod00_nJgod2o`0000;o
P^Ka00?oP^KbojCDnOnTe?T01?nTe?T3ojO8l@;oYlOa1onW`^d2ojO3kEooYl3[00?o0000ojO0jonW
`>/05?nW`>/Dooooo`03o`000?oooooooooo01Kooooo000Tooooo`03o`000?oooooooooo00kooooo
0_nP_^h2ohnil`CoT;;]0onAZnP3oi6Uh`?oT9oN0on@V]T3ohnFePCoSi;B0on?T=04ohn>cP;oShg=
00?oRJk^oh^bl?n;/_000_n;/_05ohbhl`?oSKgg0_n<a?X01OnZT[go0000o`000?l0003oYHZh00?o
X8:c1?nLO:l3oiQg[0;oUG:Y00CoSg2[ohi_Zon>Kj_oSVn[2_n>KZX4ohm_Z`?oT72[1?n@LJ`3oi5c
[@CoTgB^0onDMZl5oiEg[`?oUWV`0_nGN[43oiWMoP03o`000?n2i_3oP^K`00;oP^Ka1?nUeOT2ojCD
n@GoYlSa2OnW`^eRojO0j`03o`000?nW`>_oYl3[01GoYl3[5?ooool00ol0003oooooooooo`0Eoooo
o`009?ooool3o`0000oooooo1?n?^O<4oi2bk@?oTJ_X0onAYN<3oi2OgP?oT9[I0on?U]H2ohnBdP;o
Q:O/0on6ZN`4ohN[k@?oRJk^1?n;/_02ohbhl`03ok>Sb?n_Vl;o[i_200;o[i_20ol000001?nZT[go
YHZhojF:^?nUR[P3oj22/`;oW7b_0_nBM:l3oi1b[@?oSg2[0on>Kj/;ohi^ZP?oSfn[0on@L:/4oi1a
[0?oTG>]1?nCM:h4oiAf[`CoUGN_0_nFNK03oi[Jo@03oiWMo_mGdLSoP^K`00;oP^K`0onUe_T2ojGE
n@SoYlSa1_nW`^eWojO0j`03o`000?nW`>_oYl3[01GoYl3[4_ooool2o`0000Wooooo1?l000000ol@
413oooooooooo`07ooooo`009?ooool00ol0003oooooooooo`0@ooooo`CoSkWc0_n@/^d01?n0/??o
PJkaoh6^lOn1[_43oh6[k`CoPJW^0on2Z>d3oh>Wk0CoQ:O/0on6ZN`4ohN[k@?oRJk^0_n;/_000oo5
fnWo/j?8ok>Sb002ok>Sb0?o00001?nZT[d2ojF:^004oiQm]?nDNK7oU7VaoiAi/@CoTWB_0on@LZd4
ohm`Z`?oSVn[2_n>KZX3ohm_Z`CoT72[0on@LJ`3oi5c[@GoTgB^0onDMZl2oiEg[`CoV]Kl0_nJf_d2
oh;Wk`CoYMOi0_nUe_T9ojO8l@;oYl?]0onW`^e[ojO0j`03o`000?nW`>_oYl3[01GoYl3[4oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo01;ooooo0on0/oD3
oh2`l`?oPJka0on1Znl4oh6YkP?oPZS]0on3Yn`4ohBWk0?oQZW/0_n7Znd2obbec@?oa=_Z00?o]j_=
ok>Sb?ncXlP00ol00004ojnK`P;oZY:m00CoW8>hoiQm]?nHOKCoV7fd0onDNK44oi9d[`CoT7:]0on?
L:/3ohi_Z`[oSVjZ0on?Kj/4oi1`Z`CoT76/0onALjd4oi=d[P;oU7J_0onKd?X2oi[Fo003oe[Cb?n1
inkoPNO^00?oY]Si0_nUeoT3ojS9l@KoYlSa1onW`nd00onW`^goYl3[ojO0j`1ZojO0j`03o`000?nW
`>_oYl3[01GoYl3[5?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo0009
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo01?ooooo0on0/oD3oh2`l`?oPJka0on1Znl2oh6YkP?oI;cm
1?mK_o`3oe71n0;oAL3^00CoC<_>ojcbmOn/l_Go[?;e0oo3fN/00oo4fn[o]j_=o`000002o`0000?o
/j?80on_Vl801?nPR[goW8>hoib3^?nLPkP4oiQm]0?oU7Va0onBM:l4oi1b[@?oSg2[0on>Kj/:ohi^
ZP?oSfn[1?n@L:/4oi1a[0?oTG>]0_nCM:h4oi_9m`;oVm3j00?oBlW1oh3Wk?n0in`00_nVfOT3ojKH
n@;oZ<[a1OnXbO42ojO8l@WoYl?]KonW`>/00ol0003oYl3[ojO0j`0EojO0ja?ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`09ooooo`002Oooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0Eooooo`?oNK3f0ome/oP4og2f
n`?oJkWm1?mT_?d2oe^oo0;oC/O]0omRenT01?n6jNoo[?;eojcbmOn/l_D3ol?Ij`03okZbd_l0003o
000000;o]j_=1OncXlP01?n_Vl;oX8Zmoj2:_OnPR[d3oib3^0?oV7fd0onDNK44oi9d[`?oT7:]0on?
L:/3ohi_Z`_oSVjZ0on?Kj/3oi1`Z`;oT76/0onJ^>d4oi_1l`;oVlWg0_mFdLh2ogkVjP;oY][j1?nV
fOT00onVf?WoZ<[aojS:l@02ojS:l@;oZ<Wa2OnW`nedojO0j`03o`000?nW`>_oYl3[01GoYl3[4ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP05ooooo`?o00005_ooool3ogV`mP?oMK?h0_m`
]_/4ogK1oP?oK<On0_mObOX2ogCJn@?oTnOj0on`joP3ol7FjP?o000000?o^[;BokN[cOngZld00_ng
Zld2ok>Sb0;oYI;11?nPR[d3oib3^0?oV7fd0onDNK44oi9d[`?oT7:]0on?L:/3ohi_Z`_oSVjZ0on?
Kj/2oi1`Z`?oV:oW1?nJ^>d2oi_1l`;oH]WK00?oG=C9ogkVj_mni^X01OnVf_X2ojKIn@?oZ<_b0_nX
b_42ojS3k@OoYl?]N?nW`>/00ol0003oYl3[ojO0j`0EojO0ja7ooooo0ol00007ooooo`03o`000?oo
oooooooo00Wooooo0009ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`04ooooo`03o`000?oooooooooo01Sooooo0on2]?D4ogfknP;oM/7n0on9cOh2oh7Fo`CoVmom00?o
TnOjok3[n?n`joP00_o1e^X3o`0000Co^[;B0ongZld00onZV/KoYI;1ojFB`@03ojFB`@?oX8Zm0onL
PkP3oiQm]0CoU7Va0onBM:l4oi1b[@?oSg2[0on>Kj/8ohi^ZP;oU9gJ1?nFY^45oiR_i`;oV[S]0_m_
g^T2oegEb`;oONKX0onVfoX2ojKJnPCoZ<cb0_nXbo86ojS3k@;oYl?]O?nW`>/00ol0003oYl3[ojO0
j`0EojO0j`kooooo1?l000000ooooooo0000ooooo`06ooooo`03o`000?oooooooooo00Wooooo0009
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01Wooooo0on2]?D2ogfknP?oS/?i0_n9cOh4oioEn`;oVmom0_nahOL01Onnd^Wo0000o`00
0?l0003o`MKZ00?o^kSF1?nj/]801?ngZlgoZY[6ojZJa_nZV/H4ojFB`@CoX8Zm0onLPkP3oiQm]0?o
U7Va0onBM:l4oi1b[@?oSg2[0on>Kj/2ohi^ZP03oi2?c_nBU]CoTYKD00;oTYKD1?nDWMX4oiJVh@;o
V:oW0omlhO@2oeoFc@;oNnGV0onVgO/2ojKKnP?oZ<gc0_nXc?83ojS4kPKoZ<?]P?nW`>/00ol0003o
Yl3[ojO0j`0EojO0j`[ooooo0ol00005ooooo`03o`000?oooooooooo00?ooooo00?oEEEEofIVI_l0
00002oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001Oooool2o`0001_ooooo1?nB^_82ohk3n@CoXLWe0_nOeO/3ok7Fl`?o00000_nnd^T00onl
_=[o^kSFok^heP03ok^heP;o^[;B00?o[Z;;ojZJa_nZV/H00_nZV/H4ojFB`@CoX8Zm0onLPkP3oiQm
]0;oU7Va00CoSWnnoheo_on=OkooSGno1?n=PL83ohf4a@?oSXW91?n@Slh4oi:Fe0CoU9gJ0_nFY^43
ohOPo003ogcQm?mOe/goNNGT00CoY]ok0_nVgO/2ojS>m0?oZ<gc1onXa>h2ojS3kHCoYl3[00?o0000
ojO0jonW`>/05?nW`>/6ooooo`Co00002?ooool00ol0003oooooooooo`0Aooooo`002Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oo
oooooooo01_ooooo0_nB^_82oj:nk@CoXLWe0_n`bnh01?nae_?o0000o`000?l00002okc=i`03okkB
jOnl_=[o_;cJ00;o_;cJ0onk^=H00onbZM3o[Z;;ojjRb`02ojjRb`?oZY[61OnUT/42oj2:_@04oiJ6
`?nCP[koTh:noi>2_P?oT82n1?n>Okh3oheo_`?oSH721?n=Q<D3ohj9b@?oT8o>1OnBU]@2oiBMfP?o
Sm[o0_n7h?`01?mhi>?oYN3kojGPnonUh?/2ojKOn`?oZM3d1?nXc_@00onXcO?oZ<C^ojS4kP04ojS4
kXSoYl3[00?o0000ojO0jonW`>/05OnW`>/2ooooo`?o00003?ooool00ol0003oooooooooo`0Aoooo
o`008_ooool00ol0003oooooooooo`0Mooooo`CoX[k]00?oXLWeok3;k_n`bnh00ol000001?nae_?o
_<gWokc=ionlcNL2okbog0Go_;cJ00Co^kSFok:Yd?nbZM3o/ZW@0on^X//4ojZJaP;oYI;10_nJRl84
oiJ6`0?oTh:n0on@P;h3ohio_P?oSGno1?n=PL83ohf4a@?oSXW91?n@Slh2oi:Fe0CoTm7m0_n?f_l0
0omUf]GoN>CSogSTh`03ojGPn`?oZM7e1?nYd?@2ojS>m0?oZ<G^0_nXa>h2ojS1k8[oYl3[00?o0000
ojO0jonW`>/05OnW`>/00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo013ooooo000Roooo
o`03o`000?oooooooooo01kooooo0_nR_^d2ojo2j0;o00000_n`bnh3ok[8i@03okc=ionl_mco_;oL
00;o_;oL0onl_=X00one/=Co/ZW@ok:Yd002ok:Yd0Co[Z;;0_nZV/H00onNTLKoVX_2oiZ;`P02oiZ;
`PCoUXK00onCP[h3oi20_P?oSWnn0on=Okl4ohf1`PCoSHC50on>RLT2oi2?cP?oU/Kh0_nCdOd3ofWL
g0;oMnCS0onUh_/00onUh?_oZM7eojWAm@03ojWAm@;oZM3d1OnXaNh6ojS1k8[oYl3[00?o0000ojO0
jonW`>/05OnW`>/@ooooo`03o`000?oooooooooo013ooooo000Rooooo`;o00008?ooool3o`000003
ojo2j?nh`n?o^<?S00?o^/SU00?o_<;Nokbog?nl_m`01?nl_m`01?nl_=[o]K3DokF`e?ne/=@4ok:Y
d0;o[Z;;00?oXiS9oijAa_nNTLH00_nNTLH4oiZ;`P?oUXK00onCP[h3oi20_PCoSWnn0on=Okl3ohf1
`P;oSHC50onD[nT4oiJjl0;oU/Kh0_m^gn@3ogOTi0?oY>?l0_nUh_/3ojWCmP;oZM7e0onXa^l5ojS5
kPKoZ<7/S?nW`>/00ol0003oYl3[ojO0j`0DojO0ja3ooooo00?o0000ooooooooool04?ooool002;o
oooo00?o0000ooooooooool07?ooool3o`000003oooooon_`^So^<?S00Co^<?S00Co^/SUokc2g_nl
`]ko_<;N1?nl_m`00ong]mWo]K3DokF`e003okF`e0;o/ZW@00?oZ9o>oj>HbOnSV<T00_nSV<T3oijA
aPCoVX_21?nFQ/03oi>2_P?oT82n0on>Okh2oheo_`03oi:MfonCYN;oTjGR00?oTjGR1?nD[nT2oiJj
l0;oM>7/0_mhi>H4oj?To0;oY>?l0onYeOL2ojWCmP;oZ<O_1OnXa^l2ojS5kPGoZ<7/SonW`>/00ol0
003oYl3[ojO0j`0EojO0j`oooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000oooooooo
ool06Oooool3o`0000Kooooo0onh`n<2okc4h0Co_<;N00?o_;oLokNgfOng]mT00_ng]mT3okF`e003
ojbXdonXWlkoZ9o>00;oZ9o>0onSV<T3oijAaPCoVX_21?nFQ/02oi>2_P04oi6Ad?n@Tm;oT9?Boi2C
dP?oTIOF1?nBWM/5oi>UhP;oU:oY0_mjhO@2og_TjP?oX^Gl0_nSi?`4ojSGn0;oZMGg0_nYb?04ojS7
k`;oZ<K_2?nX`NbAojO0j`03o`000?nW`>_oYl3[01CoYl3[3oooool00ol0003oooooooooo`0@oooo
o`008_ooool00ol0003oooooooooo`0Fooooo`?o00002_ooool00onh`n?o_<CPokc4h002okc4h0;o
_<;N0oni_Md4okNgf@04okF`e?n/Z=?o[:SCojbXd`?oZ9o>1?nSV<T3oijAaP;oVX_200?oUIC@oi>B
conCT/l00_nCT/l4oi6Ad0?oT9?B0onAUmH4oi:Mf`;oTjGR1?n0g_/00omjhOCoNnCZog_TjP03oj;U
o0?oZ=Si0_nXeoP7ojW8l0;oZ<O_0_nX`^`7ojS1k0?oYl3/TOnW`>/00ol0003oYl3[ojO0j`0DojO0
j`kooooo00?o0000ooooooooool04?ooool002;ooooo0_l0000Dooooo`?o00003_ooool3okc4h003
ok[3hOni_Mgo^KgM00Co^KgM0_ng]mT00on_/=Wo[:SCojbXd`02ojbXd`CoZ9o>0_nSV<T01?nKW=?o
V9OAoiRGdOnHUm44oiFDd0CoTi;?0onATM03oi2CdPCoTIOF0_nBWM/3ohGJo`;oP=kk0omni?02oj3U
o0?oYm[i0_nXf?T3ojW9l@KoZLS`1_nX`^`2ojS1k0;oYl7/1?nW`>bCojO0j`03o`000?nW`>_oYl3[
01CoYl3[3Oooool00ol0003oooooooooo`0@ooooo`008Oooool2o`0001;ooooo0ol0000Booooo`04
okc4h?nj`n7o^/?Qok[3h@Co^KgM00?o/[WNojn`fOn_/=T00_n_/=T4ojbXd`;oZ9o>00?oWj;Goi^L
donKW=<00_nKW=<3oiRGd@?oUIC@1?nCT/l4oi6Ad0?oT9?B0_nAUmH3ohSBo`;oQM[o0_n2i?D3oioT
o0;oY]_j0onWf_T2ojW;l@GoZLWa0_nYb?02ojS3k@KoZ<;/1_nW`N`00onW`>coYl3[ojO0j`2CojO0
j`03o`000?nW`>_oYl3[01GoYl3[3?ooool00ol0003oooooooooo`0@ooooo`001oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool00oooool00ol0
003oooooooooo`0?ooooo`;o00005_ooool4ok[3h@03okVmgOnb^Mko/[WN00;o/[WN1?n_/=T2ojbX
d`03oj>YfonOX]OoWj;G00;oWj;G0onKW=<3oiRGd@CoUIC@1?nCT/l2oi6Ad0;oS<7i1?n:bOd2ohSB
o`;oQN;j1?nMhod00onOi?coY]_jojKKnP02ojKKnP03ojOJnOnYbo7oZL_a00;oZL_a0_nYbO47ojS3
k@;oZ<;/0_nX`N`6ojO1k9SoYl3[00?o0000ojO0jonW`>/05?nW`>/=ooooo`03o`000?oooooooooo
00oooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0<ooooo`?o00006Oooool2ok[3h@?o]<?U1?nb^Mh2ojn`
f@03ojJ`gonSZM_oXjWK00;oXjWK1?nOX]L3oi^Ld`?oV9OA0_nEU=03ohndl0CoSK[d0on<`OT2oh[9
o@;oRMkn0onKhOd2oigSo@CoYM_j0_nVfoX3ojW<lP;oZL_a0_nXa>d7ojS3k@KoZ<7/0_nW`NbLojO0
j`03o`000?nW`>_oYl3[01CoYl3[3?ooool00ol0003oooooooooo`0?ooooo`001oooool01Ol@413o
oooooooooooooooo410@00_ooooo1Ol00005ooooo`;o00002_ooool3o`0001gooooo1Ond`nD2ok:i
gP;oZ;SU0onV/=l4oj>Yf`;oWj;G00?oU[7Yoi>`j_nC/>X00_nC/>X3oi6ak@GoSkC`0_n=^_@3ohkA
oP;oS=So0onJg_d2oi_Qo@CoY=_k0_nUfoX5ojW<lP;oZ<G^1?nXa>d2ojS3k@WoZ<7/WonW`>/00ol0
003oYl3[ojO0j`0EojO0j`_ooooo00?o0000ooooooooool03oooool000Oooooo00Go0000oooooooo
ooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000ooooooooool01_ooool3
o`00027ooooo0_nd`nD3oj[1jPCoZ;SU0onV/=l2oj>Yf`;oVK?Y0onF/NT4oi>`jP?oTK7]0_n?]?04
oho;o0;oS]7n0onHf_h2oi[No@?oXm[k0_nTfo/4ojS=l`;oZLcb0_nXa^h4ojS5kP;oZ<C]2OnX`NbS
ojO0j`03o`000?nW`>_oYl3[01GoYl3[2_ooool00ol0003oooooooooo`0?ooooo`001oooool01Ol0
003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003ooooooooo
o`03ooooo`?o00009_ooool4oj[1jP;oZ;SU00?oWK[/oibfjonL]^/00_nL]^/4oiVcj@?oU[7Y0_nC
/>X2oi;0mPGoTLGi0_n?bo`3oiOFo@;oV=[n0onQf?/2oj?Jn`KoZ<gc0_nXa^l4ojS6kP;oZ<G^0_nX
`^`6ojS1k:SoYl3[00?o0000ojO0jonW`>/05?nW`>/:ooooo`03o`000?oooooooooo00oooooo0007
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000005ooooo`04o`000?oo
ooooooooooooo`?o0000:_ooool2oj[1jP;oWkk^0onM^^`4oibfj`;oVK?Y0_nF^o83oi>ml`CoT/3f
0_nAaOT4oiKAo0;oUmKm0onPe_/2oj7Hn`;oYlgd1?nXcO<2ojS7k`CoZ<K_0_nXa^h6ojS2k0;oZ<7/
[?nW`>/00ol0003oYl3[ojO0j`0DojO0j`Wooooo00?o0000ooooooooool03oooool000Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Gooooo1?l0000^ooooo`CoWkk^
0onM^^`2oibfj`;oUk_a1?nF^o83oi>ml`;oT/3f1?nFc?/2oiKAo0?oW];j0_nPe_/2ojK=m0CoYlgd
00?oZ<gcojS7konXanl00onXanl2ojS6k`;oZ<;]1_nX`^b_ojO0j`03o`000?nW`>_oYl3[01CoYl3[
2Oooool00ol0003oooooooooo`0?ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo
00?oMgMgo`000?ooool01?ooool2o`00037ooooo0_nO_^h2oiVll0CoV;_`0onG^o42oiJklP;oU/Cg
1OnFb?T2oiK<n`?oWLoi0_nNd_X2ojG<m0CoY/gd0_nWcO@3ojS7l0;oZ<O_0onX`nd4ojS2k@;oZ<;/
0_nX`>^aojO0j`03o`000?nW`>_oYl3[01CoYl3[2?ooool00ol0003oooooooooo`0?ooooo`008_oo
ool00ol0003oooooooooo`0_ooooo`CoVKc`0_nH^o02oiRnlPCoUl7d0onFa?L2oiK8n@CoW<_g0_nM
coT2ojC:l`CoYLcd0_nVcO@5ojS7l0OoZ<?]0_nX`^d2ojS1j`CoZ<3[/OnW`>/00ol0003oYl3[ojO0
j`0CojO0j`Wooooo00?o0000ooooooooool03_ooool002?ooooo00?o0000ooooooooool0;oooool4
oiVll0CoV;kb0_nG`O@3oic3l`CoW<Of0_nLboL2oj?8l`CoY<[c0_nUc?@3ojO7l0;oZ<O`2?nX`nd3
ojS1k0CoZ<7[0_nX`>^bojO0j`03o`000?nW`>_oYl3[01CoYl3[2?ooool00ol0003oooooooooo`0>
ooooo`009?ooool00ol0003oooooooooo`0_ooooo`CoVKc`0_nH__82oic0l@GoW<?c0_nLaoH2oj;5
lPCoXlSc0_nTb_<3ojK6l0;oYlO`0_nW`nd6ojS3k@OoZ<7/0_nX`N^fojO0j`03o`000?nW`>_oYl3[
01CoYl3[1oooool00ol0003oooooooooo`0>ooooo`009Oooool2o`00033ooooo0_nI_?02oibmk`Co
W<3a0_nL`o<3oj73l@CoX/Gb0_nSb?<3ojK5l0;oY/K`1_nW`nd2ojS3k@WoZ<7/^_nW`>/00ol0003o
Yl3[ojO0j`0DojO0j`Kooooo00?o0000ooooooooool03_ooool002Oooooo00?o0000ooooooooool0
;_ooool4oibmk`;oW<3a0onQ`Nl4oj73l@;oX/Gb0onUa>l2ojK5l0;oYl;]1_nW`nd8ojS1k;ooYl3[
00?o0000ojO0jonW`>/04onW`>/6ooooo`03o`000?oooooooooo00kooooo000Xooooo`03o`000?oo
oooooooo02kooooo0_nL_Nl4oj2nkP?oXL7_0_nQ`o43ojC2k`;oYLC_0_nV`^d4ojO2k@;oYl?]0_nW
`N`6ojS1k<;oYl3[00?o0000ojO0jonW`>/05?nW`>/5ooooo`03o`000?oooooooooo00kooooo000Y
ooooo`03o`000?oooooooooo02oooooo0_nP_^h3oj>ok@CoY<7^0_nT`^l2ojK1k@CoY/;]0_nW`^d6
ojO1k0;oZ<7/a_nW`>/00ol0003oYl3[ojO0j`0DojO0j`Cooooo00?o0000ooooooooool03_ooool0
02[ooooo0_l0000aooooo`CoXko]0_nT`Nh2ojK0k0CoY/7]0_nV`^d8ojO1k0;oYl3/b?nW`>/00ol0
003oYl3[ojO0j`0DojO0j`?ooooo00?o0000ooooooooool03_ooool002cooooo00?o0000oooooooo
ool0;oooool2oj>ok@;oYKo/1?nV`>`2ojK1k@SoYl7/1_nW`>c8ojO0j`03o`000?nW`>_oYl3[01Co
Yl3[0oooool00ol0003oooooooooo`0=ooooo`00;Oooool00ol0003oooooooooo`0_ooooo`CoYKo/
0_nV`>`2ojO0k0KoYl7/2?nW`>c9ojO0j`03o`000?nW`>_oYl3[01CoYl3[0oooool00ol0003ooooo
ooooo`0=ooooo`00;_ooool00ol0003oooooooooo`0_ooooo`;oYKo/1_nW`>`2ojO1k0;oYl3[1_nW
`>c=ojO0j`03o`000?nW`>_oYl3[01CoYl3[0_ooool00ol0003oooooooooo`0=ooooo`00;oooool0
0ol0003oooooooooo`0_ooooo`KoYl3/1_nW`>/2ojO0k=7oYl3[00?o0000ojO0jonW`>/04onW`>/2
ooooo`03o`000?oooooooooo00gooooo000`ooooo`;o0000<?ooool2ojO0k=coYl3[00?o0000ojO0
jonW`>/05?nW`>/00ooooooo0000ooooo`0>ooooo`00<_ooool00ol0003oooooooooo`0^ooooomko
Yl3[00?o0000ojO0jonW`>/04onW`>/00ooooooo0000ooooo`0>ooooo`00<oooool00ol0003ooooo
ooooo`0^ooooomkoYl3[00?o0000ojO0jonW`>/04onW`>/00ol0003oooooooooo`0=ooooo`00=?oo
ool00ol0003oooooooooo`0^ooooomkoYl3[00?o0000ojO0jonW`>/04OnW`>/00ooooooo0000oooo
o`0>ooooo`00=Oooool2o`0002oooooogOnW`>/00ol0003oYl3[ojO0j`0=ojO0j`Kooooo00?o0000
ooooooooool03?ooool003Oooooo00?o0000ooooooooool0;_oooooLojO0j`03o`000?nW`>_oYl3[
00WoYl3[2Oooool00ol0003oooooooooo`0<ooooo`00>?ooool00ol0003oooooooooo`0^ooooomco
Yl3[00?o0000ojO0jonW`>/01OnW`>/<ooooo`03o`000?oooooooooo00cooooo000iooooo`03o`00
0?oooooooooo02kooooog?nW`>/00ol0003oYl3[ojO0j`0@ooooo`03o`000?oooooooooo00cooooo
000jooooo`;o0000;ooooooKojO0j`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?oo
ool003cooooo00?o0000ooooooooool0;OoooooFojO0j`Gooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0<ooooo`00?Oooool00ol0003oooooooooo`0]ooooom;oYl3[2Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo000nooooo`03o`000?oooooooooo02go
oooob_nW`>/@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool003oooooo
0_l0000_ooooolGoYl3[5?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo
0011ooooo`03o`000?oooooooooo02gooooo`OnW`>/Hooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02oooool004;ooooo00?o0000ooooooooool0;OoooonlojO0jagooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`00@oooool00ol0003oooooooooo`0]oooo
okSoYl3[8?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0014ooooo`03
o`000?oooooooooo02gooooo]?nW`>/Tooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool004Gooooo0_l0000_ooooojkoYl3[:Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00_ooooo0017ooooo`03o`000?oooooooooo02goooooZ_nW`>//ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02oooool004Sooooo00?o0000ooooooooool0;OoooonV
ojO0jc3ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`00BOooool00ol0
003oooooooooo`0]oooooj;oYl3[=?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo001:ooooo`;o0000;_oooonMojO0jcWooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0:ooooo`00C?ooool00ol0003oooooooooo`0/oooooiWoYl3[??ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00[ooooo001=ooooo`03o`000?oooooooooo02coooooT_nW
`>]3ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool004kooooo00?o0000
ooooooooool0;Ooooon=ojO0jdOooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:
ooooo`00Coooool2o`0002koooooR?nW`>]<ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02_ooool0057ooooo00?o0000ooooooooool0;?oooon4ojO0jdoooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0:ooooo`00D_ooool00ol0003oooooooooo`0[oooooh7oYl3[
Doooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo001Cooooo`03o`000?oo
oooooooo02_oooooOOnW`>]Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Ooo
ool005Cooooo0_l0000]ooooogSoYl3[F_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Wooooo001Fooooo`03o`000?oooooooooo02_oooooM?nW`>]Nooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02Oooool005Oooooo00?o0000ooooooooool0:ooooom/ojO0jfKo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`00F?ooool00ol0003ooooo
ooooo`0/ooooofOoYl3[J_ooool01Ol0003ooooooooooooooooo000000_ooooo001Iooooo`03o`00
0?oooooooooo02coooooHonW`>]]ooooo`05o`000?ooooooooooooooool000002oooool005[ooooo
0_l0000]oooooeooYl3[LOooool01?l0003oooooooooool0000;ooooo`00G?ooool00ol0003ooooo
ooooo`0[oooooe_oYl3[MOooool00ol0003oooooo`00000;ooooo`00GOooool00ol0003ooooooooo
o`0[oooooeOoYl3[N?ooool01?l0003oooooooooool0000:ooooo`00G_ooool00ol0003ooooooooo
o`0[oooooe?oYl3[O?ooool00ol0003oooooo`00000:ooooo`00Goooool2o`0002coooooC?nW`>^3
ooooo`;o00002_ooool0067ooooo00?o0000ooooooooool0:_oooom8ojO0jhGooooo0ol0000:oooo
o`00H_ooool00ol0003oooooooooo`0[oooood?oYl3[Q?ooool4o`0000gooooo001Sooooo`03o`00
0?oooooooooo02_ooooo?onW`>^3ooooo`Co00004Oooool006Cooooo0_l0000/oooooc_oYl3[Pooo
ool3o`0001Gooooo001Vooooo`03o`000?oooooooooo02_ooooo<onW`>^5ooooo`Co00006?ooool0
06Oooooo00?o0000ooooooooool0:_ooool`ojO0jhCooooo1?l0000Looooo`00J?ooool00ol0003o
ooooooooo`0ZooooobcoYl3[Poooool4o`00023ooooo001Yooooo`;o0000;?oooolWojO0jh;ooooo
1?l0000Tooooo`00Joooool00ol0003oooooooooo`0Zooooob?oYl3[P_ooool3o`0002Sooooo001/
ooooo`03o`000?oooooooooo02[ooooo7OnW`>^3ooooo`Co0000:oooool006gooooo00?o0000oooo
ooooool0:ooooolHojO0jh;ooooo1?l0000_ooooo`00K_ooool00ol0003oooooooooo`0ZoooooaGo
Yl3[POooool4o`0003?ooooo001_ooooo`;o0000:ooooolAojO0jh3ooooo1?l0000gooooo`00LOoo
ool00ol0003oooooooooo`0Zooooo`WoYl3[P_ooool4o`0003_ooooo001booooo`03o`000?oooooo
oooo02[ooooo1OnW`>^2ooooo`?o0000?oooool007?ooooo00?o0000ooooooooool0:_ooool00onW
`>_oooooooooo`1oooooo`Co0000@_ooool007Cooooo0_l0000Zooooo`03o`000?oooooooooo07_o
oooo1?l00016ooooo`00M_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07Sooooo
1?l0001:ooooo`00Moooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07Cooooo1?l0
001>ooooo`00N?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo077ooooo0ol0001B
ooooo`00NOooool2o`0002Cooooo00?o0000ooooooooool0KOooool4o`0005Gooooo001kooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0JOooool4o`0005Wooooo001looooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool0IOooool4o`0005gooooo001mooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0HOooool4o`00067ooooo001nooooo`;o00007oooool0
0ol0003oooooooooo`1Mooooo`Co0000IOooool0083ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`1Jooooo`?o0000JOooool0087ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`1Fooooo`Co0000K?ooool008;ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`1Booooo`Co0000L?ooool008?ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`1>ooooo`Co0000M?ooool008Cooooo0_l0000Iooooo`03o`000?oooooooooo04[ooooo1?l0001h
ooooo`00Q_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Kooooo1?l0001loooo
o`00Qoooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04?ooooo0ol00020ooooo`00
R?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03oooooo1?l00023ooooo`00ROoo
ool2o`0001Cooooo00?o0000ooooooooool0>oooool4o`0008Oooooo002;ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0=oooool4o`0008_ooooo002<ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0<oooool4o`0008oooooo002=ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0<?ooool3o`0009?ooooo002>ooooo`;o00003oooool00ol0003ooooo
ooooo`0/ooooo`Co0000U_ooool0093ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Xooooo`Co0000V_ooool0097ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0T
ooooo`Co0000W_ooool009;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qoooo
o`Co0000X_ooool009?ooooo0_l00009ooooo`03o`000?oooooooooo01gooooo1?l0002Vooooo`00
UOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo0ol0002Zooooo`00U_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo1?l0002]ooooo`00Uoooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo1?l0002aooooo`00V?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0002eooooo`00VOooool2o`0000?o
oooo00?o0000ooooooooool02_ooool4o`000;Wooooo002Kooooo`04o`000?ooooooooooo`0000Wo
oooo0ol0002mooooo`00W?ooool00ol0003oooooo`000005ooooo`Co0000`?ooool009gooooo0_l0
00000ooooooo0000o`000002o`000<Cooooo002Nooooo`;o0000b?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00:kooooo00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01?ooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c02Gooooo`00[_ooool01Ol@
413o^[Zjonk^k_mgMgOo410@00;ooooo1_l00005ooooo`03ogMgMolb<S;ooooo00?ooooo0_lQ8B44
ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40Uoooool00:kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000Uoooool00:kooooo00?o0000
ooooooooool01?ooool6o`0000Gooooo00?oMgMgoc8b<_ooool02Oooool01Ol0003oV9RHoooooonH
V9So8B4Q09Oooooo002^ooooo`03o`000?oooooooooo00cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00:ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0Uoooool00:cooooo00?o410@o`000?l000000ol0
000;ooooo`03o`000?oooooooooo00cooooo00?oEEEEohN7Qoooool0VOooool00:kooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03omgMgOl@413oV9RH09Wooooo002^oooo
o`03o`000?oooooooooo00cooooo1?l0000<ooooo`04olc<c?m4A4Co0000oa0@49Oooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -17 0 ]
[.5 .82364 17 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69467 Mtetra
.4053 .69467 .41061 .69934 .41957 .69681 .41427 .69213 Mtetra
.41427 .69213 .41957 .69681 .42855 .69428 .42327 .68958 Mtetra
.42327 .68958 .42855 .69428 .43756 .69174 .43231 .68703 Mtetra
.43231 .68703 .43756 .69174 .4466 .68919 .44137 .68446 Mtetra
.44137 .68446 .4466 .68919 .45567 .68663 .45046 .68189 Mtetra
.45046 .68189 .45567 .68663 .46478 .68407 .45958 .67931 Mtetra
.45958 .67931 .46478 .68407 .47391 .68149 .46873 .67671 Mtetra
.46873 .67671 .47391 .68149 .48307 .67891 .47792 .67412 Mtetra
.47792 .67412 .48307 .67891 .49227 .67632 .48713 .67151 Mtetra
.48713 .67151 .49227 .67632 .50149 .67371 .49638 .66889 Mtetra
.49638 .66889 .50149 .67371 .51075 .6711 .50565 .66626 Mtetra
.50565 .66626 .51075 .6711 .52004 .66849 .51496 .66363 Mtetra
.51496 .66363 .52004 .66849 .52936 .66586 .5243 .66098 Mtetra
.5243 .66098 .52936 .66586 .53871 .66322 .53367 .65833 Mtetra
.53367 .65833 .53871 .66322 .54809 .66058 .54308 .65567 Mtetra
.54308 .65567 .54809 .66058 .55751 .65792 .55251 .653 Mtetra
.55251 .653 .55751 .65792 .56695 .65526 .56198 .65032 Mtetra
.56198 .65032 .56695 .65526 .57643 .65259 .57148 .64763 Mtetra
.57148 .64763 .57643 .65259 .58595 .6499 .58102 .64493 Mtetra
.58102 .64493 .58595 .6499 .59549 .64721 .59058 .64222 Mtetra
.59058 .64222 .59549 .64721 .60507 .64451 .60018 .6395 Mtetra
.60018 .6395 .60507 .64451 .61468 .6418 .60982 .63678 Mtetra
.60982 .63678 .61468 .6418 .62432 .63908 .61948 .63404 Mtetra
.61948 .63404 .62432 .63908 .634 .63636 .62918 .63129 Mtetra
.62918 .63129 .634 .63636 .64371 .63362 .63892 .62854 Mtetra
.63892 .62854 .64371 .63362 .65345 .63087 .64868 .62577 Mtetra
.64868 .62577 .65345 .63087 .66323 .62811 .65848 .623 Mtetra
.65848 .623 .66323 .62811 .67304 .62535 .66832 .62021 Mtetra
.66832 .62021 .67304 .62535 .68289 .62257 .67819 .61742 Mtetra
.67819 .61742 .68289 .62257 .69277 .61979 .68809 .61462 Mtetra
.68809 .61462 .69277 .61979 .70269 .61699 .69803 .6118 Mtetra
.69803 .6118 .70269 .61699 .71264 .61418 .70801 .60898 Mtetra
.70801 .60898 .71264 .61418 .72262 .61137 .71802 .60615 Mtetra
.71802 .60615 .72262 .61137 .73264 .60854 .72806 .6033 Mtetra
.72806 .6033 .73264 .60854 .7427 .60571 .73814 .60045 Mtetra
.73814 .60045 .7427 .60571 .75279 .60286 .74826 .59759 Mtetra
.74826 .59759 .75279 .60286 .76291 .60001 .75841 .59471 Mtetra
.75841 .59471 .76291 .60001 .77308 .59714 .7686 .59183 Mtetra
.7686 .59183 .77308 .59714 .78328 .59427 .77882 .58893 Mtetra
.77882 .58893 .78328 .59427 .79351 .59138 .78908 .58603 Mtetra
.78908 .58603 .79351 .59138 .80378 .58849 .79938 .58311 Mtetra
.79938 .58311 .80378 .58849 .81409 .58558 .80971 .58019 Mtetra
.80971 .58019 .81409 .58558 .82443 .58267 .82008 .57725 Mtetra
.82008 .57725 .82443 .58267 .83482 .57974 .83049 .57431 Mtetra
.83049 .57431 .83482 .57974 .84523 .5768 .84094 .57135 Mtetra
.84094 .57135 .84523 .5768 .85569 .57385 .85142 .56838 Mtetra
.85142 .56838 .85569 .57385 .86618 .57089 .86194 .5654 Mtetra
.86194 .5654 .86618 .57089 .87672 .56792 .8725 .56241 Mtetra
.8725 .56241 .87672 .56792 .88729 .56494 .8831 .55941 Mtetra
.8831 .55941 .88729 .56494 .89789 .56195 .89374 .5564 Mtetra
.89374 .5564 .89789 .56195 .90854 .55895 .90441 .55338 Mtetra
.90441 .55338 .90854 .55895 .91923 .55594 .91512 .55035 Mtetra
.91512 .55035 .91923 .55594 .92995 .55292 .92588 .5473 Mtetra
.92588 .5473 .92995 .55292 .94071 .54988 .93667 .54425 Mtetra
.93667 .54425 .94071 .54988 .95152 .54684 .9475 .54118 Mtetra
.9475 .54118 .95152 .54684 .96236 .54378 .95837 .53811 Mtetra
.95837 .53811 .96236 .54378 .97324 .54071 .96928 .53502 Mtetra
.96928 .53502 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.391 .69252 .39636 .6972 .4053 .69467 .39996 .68998 Mtetra
.39996 .68998 .4053 .69467 .41427 .69213 .40895 .68742 Mtetra
.40895 .68742 .41427 .69213 .42327 .68958 .41797 .68486 Mtetra
.41797 .68486 .42327 .68958 .43231 .68703 .42702 .68228 Mtetra
.42702 .68228 .43231 .68703 .44137 .68446 .4361 .6797 Mtetra
.4361 .6797 .44137 .68446 .45046 .68189 .44521 .67711 Mtetra
.44521 .67711 .45046 .68189 .45958 .67931 .45435 .67452 Mtetra
.45435 .67452 .45958 .67931 .46873 .67671 .46352 .67191 Mtetra
.46352 .67191 .46873 .67671 .47792 .67412 .47273 .66929 Mtetra
.47273 .66929 .47792 .67412 .48713 .67151 .48196 .66667 Mtetra
.48196 .66667 .48713 .67151 .49638 .66889 .49123 .66403 Mtetra
.49123 .66403 .49638 .66889 .50565 .66626 .50053 .66139 Mtetra
.50053 .66139 .50565 .66626 .51496 .66363 .50985 .65874 Mtetra
.50985 .65874 .51496 .66363 .5243 .66098 .51922 .65608 Mtetra
.51922 .65608 .5243 .66098 .53367 .65833 .52861 .65341 Mtetra
.52861 .65341 .53367 .65833 .54308 .65567 .53803 .65073 Mtetra
.53803 .65073 .54308 .65567 .55251 .653 .54749 .64804 Mtetra
.54749 .64804 .55251 .653 .56198 .65032 .55698 .64534 Mtetra
.55698 .64534 .56198 .65032 .57148 .64763 .5665 .64264 Mtetra
.5665 .64264 .57148 .64763 .58102 .64493 .57606 .63992 Mtetra
.57606 .63992 .58102 .64493 .59058 .64222 .58565 .6372 Mtetra
.58565 .6372 .59058 .64222 .60018 .6395 .59527 .63446 Mtetra
.59527 .63446 .60018 .6395 .60982 .63678 .60493 .63172 Mtetra
.60493 .63172 .60982 .63678 .61948 .63404 .61461 .62896 Mtetra
.61461 .62896 .61948 .63404 .62918 .63129 .62434 .6262 Mtetra
.62434 .6262 .62918 .63129 .63892 .62854 .63409 .62343 Mtetra
.63409 .62343 .63892 .62854 .64868 .62577 .64388 .62064 Mtetra
.64388 .62064 .64868 .62577 .65848 .623 .65371 .61785 Mtetra
.65371 .61785 .65848 .623 .66832 .62021 .66357 .61505 Mtetra
.66357 .61505 .66832 .62021 .67819 .61742 .67346 .61224 Mtetra
.67346 .61224 .67819 .61742 .68809 .61462 .68339 .60942 Mtetra
.68339 .60942 .68809 .61462 .69803 .6118 .69335 .60658 Mtetra
.69335 .60658 .69803 .6118 .70801 .60898 .70335 .60374 Mtetra
.70335 .60374 .70801 .60898 .71802 .60615 .71338 .60089 Mtetra
.71338 .60089 .71802 .60615 .72806 .6033 .72345 .59803 Mtetra
.72345 .59803 .72806 .6033 .73814 .60045 .73356 .59516 Mtetra
.73356 .59516 .73814 .60045 .74826 .59759 .7437 .59227 Mtetra
.7437 .59227 .74826 .59759 .75841 .59471 .75387 .58938 Mtetra
.75387 .58938 .75841 .59471 .7686 .59183 .76409 .58648 Mtetra
.76409 .58648 .7686 .59183 .77882 .58893 .77434 .58356 Mtetra
.77434 .58356 .77882 .58893 .78908 .58603 .78462 .58064 Mtetra
.78462 .58064 .78908 .58603 .79938 .58311 .79495 .57771 Mtetra
.79495 .57771 .79938 .58311 .80971 .58019 .80531 .57476 Mtetra
.80531 .57476 .80971 .58019 .82008 .57725 .81571 .57181 Mtetra
.81571 .57181 .82008 .57725 .83049 .57431 .82614 .56884 Mtetra
.82614 .56884 .83049 .57431 .84094 .57135 .83661 .56586 Mtetra
.83661 .56586 .84094 .57135 .85142 .56838 .84712 .56288 Mtetra
.84712 .56288 .85142 .56838 .86194 .5654 .85767 .55988 Mtetra
.85767 .55988 .86194 .5654 .8725 .56241 .86826 .55687 Mtetra
.86826 .55687 .8725 .56241 .8831 .55941 .87889 .55385 Mtetra
.87889 .55385 .8831 .55941 .89374 .5564 .88955 .55082 Mtetra
.88955 .55082 .89374 .5564 .90441 .55338 .90025 .54777 Mtetra
.90025 .54777 .90441 .55338 .91512 .55035 .911 .54472 Mtetra
.911 .54472 .91512 .55035 .92588 .5473 .92178 .54166 Mtetra
.92178 .54166 .92588 .5473 .93667 .54425 .9326 .53858 Mtetra
.9326 .53858 .93667 .54425 .9475 .54118 .94346 .53549 Mtetra
.94346 .53549 .9475 .54118 .95837 .53811 .95436 .53239 Mtetra
.95436 .53239 .95837 .53811 .96928 .53502 .9653 .52928 Mtetra
.9653 .52928 .96928 .53502 .98024 .53192 .97628 .52616 Mtetra
.38561 .68781 .391 .69252 .39996 .68998 .39459 .68525 Mtetra
.39459 .68525 .39996 .68998 .40895 .68742 .40359 .68268 Mtetra
.40359 .68268 .40895 .68742 .41797 .68486 .41263 .6801 Mtetra
.41263 .6801 .41797 .68486 .42702 .68228 .4217 .67751 Mtetra
.4217 .67751 .42702 .68228 .4361 .6797 .4308 .67492 Mtetra
.4308 .67492 .4361 .6797 .44521 .67711 .43993 .67231 Mtetra
.43993 .67231 .44521 .67711 .45435 .67452 .44909 .6697 Mtetra
.44909 .6697 .45435 .67452 .46352 .67191 .45828 .66707 Mtetra
.45828 .66707 .46352 .67191 .47273 .66929 .46751 .66444 Mtetra
.46751 .66444 .47273 .66929 .48196 .66667 .47676 .6618 Mtetra
.47676 .6618 .48196 .66667 .49123 .66403 .48605 .65915 Mtetra
.48605 .65915 .49123 .66403 .50053 .66139 .49537 .65649 Mtetra
.49537 .65649 .50053 .66139 .50985 .65874 .50472 .65382 Mtetra
.50472 .65382 .50985 .65874 .51922 .65608 .5141 .65114 Mtetra
.5141 .65114 .51922 .65608 .52861 .65341 .52351 .64846 Mtetra
.52351 .64846 .52861 .65341 .53803 .65073 .53296 .64576 Mtetra
.53296 .64576 .53803 .65073 .54749 .64804 .54244 .64305 Mtetra
.54244 .64305 .54749 .64804 .55698 .64534 .55195 .64034 Mtetra
.55195 .64034 .55698 .64534 .5665 .64264 .56149 .63762 Mtetra
.56149 .63762 .5665 .64264 .57606 .63992 .57107 .63488 Mtetra
.57107 .63488 .57606 .63992 .58565 .6372 .58068 .63214 Mtetra
.58068 .63214 .58565 .6372 .59527 .63446 .59032 .62939 Mtetra
.59032 .62939 .59527 .63446 .60493 .63172 .6 .62663 Mtetra
.6 .62663 .60493 .63172 .61461 .62896 .60971 .62385 Mtetra
.60971 .62385 .61461 .62896 .62434 .6262 .61946 .62107 Mtetra
.61946 .62107 .62434 .6262 .63409 .62343 .62924 .61828 Mtetra
.62924 .61828 .63409 .62343 .64388 .62064 .63905 .61548 Mtetra
.63905 .61548 .64388 .62064 .65371 .61785 .6489 .61267 Mtetra
.6489 .61267 .65371 .61785 .66357 .61505 .65878 .60985 Mtetra
.65878 .60985 .66357 .61505 .67346 .61224 .6687 .60702 Mtetra
.6687 .60702 .67346 .61224 .68339 .60942 .67865 .60418 Mtetra
.67865 .60418 .68339 .60942 .69335 .60658 .68864 .60133 Mtetra
.68864 .60133 .69335 .60658 .70335 .60374 .69866 .59847 Mtetra
.69866 .59847 .70335 .60374 .71338 .60089 .70872 .5956 Mtetra
.70872 .5956 .71338 .60089 .72345 .59803 .71881 .59272 Mtetra
.71881 .59272 .72345 .59803 .73356 .59516 .72894 .58983 Mtetra
.72894 .58983 .73356 .59516 .7437 .59227 .73911 .58692 Mtetra
.73911 .58692 .7437 .59227 .75387 .58938 .74931 .58401 Mtetra
.74931 .58401 .75387 .58938 .76409 .58648 .75955 .58109 Mtetra
.75955 .58109 .76409 .58648 .77434 .58356 .76982 .57816 Mtetra
.76982 .57816 .77434 .58356 .78462 .58064 .78014 .57521 Mtetra
.78014 .57521 .78462 .58064 .79495 .57771 .79049 .57226 Mtetra
.79049 .57226 .79495 .57771 .80531 .57476 .80087 .5693 Mtetra
.80087 .5693 .80531 .57476 .81571 .57181 .8113 .56632 Mtetra
.8113 .56632 .81571 .57181 .82614 .56884 .82176 .56334 Mtetra
.82176 .56334 .82614 .56884 .83661 .56586 .83226 .56034 Mtetra
.83226 .56034 .83661 .56586 .84712 .56288 .8428 .55733 Mtetra
.8428 .55733 .84712 .56288 .85767 .55988 .85337 .55431 Mtetra
.85337 .55431 .85767 .55988 .86826 .55687 .86399 .55128 Mtetra
.86399 .55128 .86826 .55687 .87889 .55385 .87464 .54824 Mtetra
.87464 .54824 .87889 .55385 .88955 .55082 .88533 .54519 Mtetra
.88533 .54519 .88955 .55082 .90025 .54777 .89607 .54213 Mtetra
.89607 .54213 .90025 .54777 .911 .54472 .90684 .53905 Mtetra
.90684 .53905 .911 .54472 .92178 .54166 .91765 .53597 Mtetra
.91765 .53597 .92178 .54166 .9326 .53858 .9285 .53287 Mtetra
.9285 .53287 .9326 .53858 .94346 .53549 .93939 .52976 Mtetra
.93939 .52976 .94346 .53549 .95436 .53239 .95032 .52664 Mtetra
.95032 .52664 .95436 .53239 .9653 .52928 .96129 .52351 Mtetra
.96129 .52351 .9653 .52928 .97628 .52616 .9723 .52037 Mtetra
.38018 .68308 .38561 .68781 .39459 .68525 .38918 .6805 Mtetra
.38918 .6805 .39459 .68525 .40359 .68268 .3982 .67791 Mtetra
.3982 .67791 .40359 .68268 .41263 .6801 .40726 .67532 Mtetra
.40726 .67532 .41263 .6801 .4217 .67751 .41635 .67271 Mtetra
.41635 .67271 .4217 .67751 .4308 .67492 .42547 .6701 Mtetra
.42547 .6701 .4308 .67492 .43993 .67231 .43462 .66748 Mtetra
.43462 .66748 .43993 .67231 .44909 .6697 .4438 .66485 Mtetra
.4438 .66485 .44909 .6697 .45828 .66707 .45301 .66221 Mtetra
.45301 .66221 .45828 .66707 .46751 .66444 .46225 .65956 Mtetra
.46225 .65956 .46751 .66444 .47676 .6618 .47153 .6569 Mtetra
.47153 .6569 .47676 .6618 .48605 .65915 .48083 .65423 Mtetra
.48083 .65423 .48605 .65915 .49537 .65649 .49017 .65156 Mtetra
.49017 .65156 .49537 .65649 .50472 .65382 .49954 .64887 Mtetra
.49954 .64887 .50472 .65382 .5141 .65114 .50895 .64618 Mtetra
.50895 .64618 .5141 .65114 .52351 .64846 .51838 .64347 Mtetra
.51838 .64347 .52351 .64846 .53296 .64576 .52785 .64076 Mtetra
.52785 .64076 .53296 .64576 .54244 .64305 .53735 .63804 Mtetra
.53735 .63804 .54244 .64305 .55195 .64034 .54688 .6353 Mtetra
.54688 .6353 .55195 .64034 .56149 .63762 .55645 .63256 Mtetra
.55645 .63256 .56149 .63762 .57107 .63488 .56605 .62981 Mtetra
.56605 .62981 .57107 .63488 .58068 .63214 .57568 .62705 Mtetra
.57568 .62705 .58068 .63214 .59032 .62939 .58535 .62428 Mtetra
.58535 .62428 .59032 .62939 .6 .62663 .59505 .6215 Mtetra
.59505 .6215 .6 .62663 .60971 .62385 .60478 .61871 Mtetra
.60478 .61871 .60971 .62385 .61946 .62107 .61455 .61591 Mtetra
.61455 .61591 .61946 .62107 .62924 .61828 .62435 .6131 Mtetra
.62435 .6131 .62924 .61828 .63905 .61548 .63419 .61028 Mtetra
.63419 .61028 .63905 .61548 .6489 .61267 .64406 .60746 Mtetra
.64406 .60746 .6489 .61267 .65878 .60985 .65396 .60462 Mtetra
.65396 .60462 .65878 .60985 .6687 .60702 .66391 .60177 Mtetra
.66391 .60177 .6687 .60702 .67865 .60418 .67388 .59891 Mtetra
.67388 .59891 .67865 .60418 .68864 .60133 .68389 .59604 Mtetra
.68389 .59604 .68864 .60133 .69866 .59847 .69394 .59316 Mtetra
.69394 .59316 .69866 .59847 .70872 .5956 .70402 .59027 Mtetra
.70402 .59027 .70872 .5956 .71881 .59272 .71414 .58737 Mtetra
.71414 .58737 .71881 .59272 .72894 .58983 .7243 .58446 Mtetra
.7243 .58446 .72894 .58983 .73911 .58692 .73449 .58154 Mtetra
.73449 .58154 .73911 .58692 .74931 .58401 .74472 .57861 Mtetra
.74472 .57861 .74931 .58401 .75955 .58109 .75498 .57567 Mtetra
.75498 .57567 .75955 .58109 .76982 .57816 .76528 .57272 Mtetra
.76528 .57272 .76982 .57816 .78014 .57521 .77562 .56975 Mtetra
.77562 .56975 .78014 .57521 .79049 .57226 .786 .56678 Mtetra
.786 .56678 .79049 .57226 .80087 .5693 .79641 .5638 Mtetra
.79641 .5638 .80087 .5693 .8113 .56632 .80686 .5608 Mtetra
.80686 .5608 .8113 .56632 .82176 .56334 .81735 .55779 Mtetra
.81735 .55779 .82176 .56334 .83226 .56034 .82788 .55478 Mtetra
.82788 .55478 .83226 .56034 .8428 .55733 .83844 .55175 Mtetra
.83844 .55175 .8428 .55733 .85337 .55431 .84905 .54871 Mtetra
.84905 .54871 .85337 .55431 .86399 .55128 .85969 .54566 Mtetra
.85969 .54566 .86399 .55128 .87464 .54824 .87037 .5426 Mtetra
.87037 .5426 .87464 .54824 .88533 .54519 .88109 .53953 Mtetra
.88109 .53953 .88533 .54519 .89607 .54213 .89185 .53644 Mtetra
.89185 .53644 .89607 .54213 .90684 .53905 .90265 .53335 Mtetra
.90265 .53335 .90684 .53905 .91765 .53597 .91349 .53024 Mtetra
.91349 .53024 .91765 .53597 .9285 .53287 .92437 .52712 Mtetra
.92437 .52712 .9285 .53287 .93939 .52976 .93529 .524 Mtetra
.93529 .524 .93939 .52976 .95032 .52664 .94625 .52085 Mtetra
.94625 .52085 .95032 .52664 .96129 .52351 .95725 .5177 Mtetra
.95725 .5177 .96129 .52351 .9723 .52037 .96829 .51454 Mtetra
.37472 .67831 .38018 .68308 .38918 .6805 .38373 .67572 Mtetra
.38373 .67572 .38918 .6805 .3982 .67791 .39278 .67311 Mtetra
.39278 .67311 .3982 .67791 .40726 .67532 .40186 .6705 Mtetra
.40186 .6705 .40726 .67532 .41635 .67271 .41096 .66788 Mtetra
.41096 .66788 .41635 .67271 .42547 .6701 .4201 .66525 Mtetra
.4201 .66525 .42547 .6701 .43462 .66748 .42927 .66261 Mtetra
.42927 .66261 .43462 .66748 .4438 .66485 .43847 .65996 Mtetra
.43847 .65996 .4438 .66485 .45301 .66221 .4477 .65731 Mtetra
.4477 .65731 .45301 .66221 .46225 .65956 .45697 .65464 Mtetra
.45697 .65464 .46225 .65956 .47153 .6569 .46626 .65197 Mtetra
.46626 .65197 .47153 .6569 .48083 .65423 .47559 .64928 Mtetra
.47559 .64928 .48083 .65423 .49017 .65156 .48495 .64659 Mtetra
.48495 .64659 .49017 .65156 .49954 .64887 .49434 .64389 Mtetra
.49434 .64389 .49954 .64887 .50895 .64618 .50376 .64118 Mtetra
.50376 .64118 .50895 .64618 .51838 .64347 .51322 .63846 Mtetra
.51322 .63846 .51838 .64347 .52785 .64076 .52271 .63572 Mtetra
.52271 .63572 .52785 .64076 .53735 .63804 .53223 .63298 Mtetra
.53223 .63298 .53735 .63804 .54688 .6353 .54178 .63024 Mtetra
.54178 .63024 .54688 .6353 .55645 .63256 .55137 .62748 Mtetra
.55137 .62748 .55645 .63256 .56605 .62981 .56099 .62471 Mtetra
.56099 .62471 .56605 .62981 .57568 .62705 .57065 .62193 Mtetra
.57065 .62193 .57568 .62705 .58535 .62428 .58034 .61914 Mtetra
.58034 .61914 .58535 .62428 .59505 .6215 .59006 .61634 Mtetra
.59006 .61634 .59505 .6215 .60478 .61871 .59982 .61354 Mtetra
.59982 .61354 .60478 .61871 .61455 .61591 .60961 .61072 Mtetra
.60961 .61072 .61455 .61591 .62435 .6131 .61943 .60789 Mtetra
.61943 .60789 .62435 .6131 .63419 .61028 .62929 .60505 Mtetra
.62929 .60505 .63419 .61028 .64406 .60746 .63919 .60221 Mtetra
.63919 .60221 .64406 .60746 .65396 .60462 .64912 .59935 Mtetra
.64912 .59935 .65396 .60462 .66391 .60177 .65908 .59648 Mtetra
.65908 .59648 .66391 .60177 .67388 .59891 .66908 .5936 Mtetra
.66908 .5936 .67388 .59891 .68389 .59604 .67912 .59072 Mtetra
.67912 .59072 .68389 .59604 .69394 .59316 .68919 .58782 Mtetra
.68919 .58782 .69394 .59316 .70402 .59027 .6993 .58491 Mtetra
.6993 .58491 .70402 .59027 .71414 .58737 .70944 .58199 Mtetra
.70944 .58199 .71414 .58737 .7243 .58446 .71962 .57906 Mtetra
.71962 .57906 .7243 .58446 .73449 .58154 .72984 .57612 Mtetra
.72984 .57612 .73449 .58154 .74472 .57861 .74009 .57317 Mtetra
.74009 .57317 .74472 .57861 .75498 .57567 .75038 .57021 Mtetra
.75038 .57021 .75498 .57567 .76528 .57272 .76071 .56724 Mtetra
.76071 .56724 .76528 .57272 .77562 .56975 .77107 .56426 Mtetra
.77107 .56426 .77562 .56975 .786 .56678 .78148 .56126 Mtetra
.78148 .56126 .786 .56678 .79641 .5638 .79192 .55826 Mtetra
.79192 .55826 .79641 .5638 .80686 .5608 .80239 .55524 Mtetra
.80239 .55524 .80686 .5608 .81735 .55779 .81291 .55222 Mtetra
.81291 .55222 .81735 .55779 .82788 .55478 .82346 .54918 Mtetra
.82346 .54918 .82788 .55478 .83844 .55175 .83406 .54613 Mtetra
.83406 .54613 .83844 .55175 .84905 .54871 .84469 .54307 Mtetra
.84469 .54307 .84905 .54871 .85969 .54566 .85536 .54 Mtetra
.85536 .54 .85969 .54566 .87037 .5426 .86607 .53692 Mtetra
.86607 .53692 .87037 .5426 .88109 .53953 .87682 .53383 Mtetra
.87682 .53383 .88109 .53953 .89185 .53644 .88761 .53072 Mtetra
.88761 .53072 .89185 .53644 .90265 .53335 .89844 .52761 Mtetra
.89844 .52761 .90265 .53335 .91349 .53024 .90931 .52448 Mtetra
.90931 .52448 .91349 .53024 .92437 .52712 .92022 .52134 Mtetra
.92022 .52134 .92437 .52712 .93529 .524 .93116 .51819 Mtetra
.93116 .51819 .93529 .524 .94625 .52085 .94216 .51503 Mtetra
.94216 .51503 .94625 .52085 .95725 .5177 .95319 .51185 Mtetra
.95319 .51185 .95725 .5177 .96829 .51454 .96426 .50866 Mtetra
.36922 .67351 .37472 .67831 .38373 .67572 .37826 .6709 Mtetra
.37826 .6709 .38373 .67572 .39278 .67311 .38732 .66828 Mtetra
.38732 .66828 .39278 .67311 .40186 .6705 .39642 .66566 Mtetra
.39642 .66566 .40186 .6705 .41096 .66788 .40554 .66302 Mtetra
.40554 .66302 .41096 .66788 .4201 .66525 .4147 .66037 Mtetra
.4147 .66037 .4201 .66525 .42927 .66261 .42389 .65772 Mtetra
.42389 .65772 .42927 .66261 .43847 .65996 .43311 .65505 Mtetra
.43311 .65505 .43847 .65996 .4477 .65731 .44236 .65238 Mtetra
.44236 .65238 .4477 .65731 .45697 .65464 .45165 .6497 Mtetra
.45165 .6497 .45697 .65464 .46626 .65197 .46096 .64701 Mtetra
.46096 .64701 .46626 .65197 .47559 .64928 .47031 .6443 Mtetra
.47031 .6443 .47559 .64928 .48495 .64659 .47969 .64159 Mtetra
.47969 .64159 .48495 .64659 .49434 .64389 .4891 .63887 Mtetra
.4891 .63887 .49434 .64389 .50376 .64118 .49855 .63615 Mtetra
.49855 .63615 .50376 .64118 .51322 .63846 .50802 .63341 Mtetra
.50802 .63341 .51322 .63846 .52271 .63572 .51753 .63066 Mtetra
.51753 .63066 .52271 .63572 .53223 .63298 .52708 .6279 Mtetra
.52708 .6279 .53223 .63298 .54178 .63024 .53665 .62513 Mtetra
.53665 .62513 .54178 .63024 .55137 .62748 .54626 .62236 Mtetra
.54626 .62236 .55137 .62748 .56099 .62471 .55591 .61957 Mtetra
.55591 .61957 .56099 .62471 .57065 .62193 .56558 .61677 Mtetra
.56558 .61677 .57065 .62193 .58034 .61914 .57529 .61397 Mtetra
.57529 .61397 .58034 .61914 .59006 .61634 .58504 .61115 Mtetra
.58504 .61115 .59006 .61634 .59982 .61354 .59482 .60833 Mtetra
.59482 .60833 .59982 .61354 .60961 .61072 .60463 .60549 Mtetra
.60463 .60549 .60961 .61072 .61943 .60789 .61448 .60265 Mtetra
.61448 .60265 .61943 .60789 .62929 .60505 .62437 .59979 Mtetra
.62437 .59979 .62929 .60505 .63919 .60221 .63428 .59692 Mtetra
.63428 .59692 .63919 .60221 .64912 .59935 .64424 .59405 Mtetra
.64424 .59405 .64912 .59935 .65908 .59648 .65423 .59116 Mtetra
.65423 .59116 .65908 .59648 .66908 .5936 .66425 .58826 Mtetra
.66425 .58826 .66908 .5936 .67912 .59072 .67431 .58536 Mtetra
.67431 .58536 .67912 .59072 .68919 .58782 .68441 .58244 Mtetra
.68441 .58244 .68919 .58782 .6993 .58491 .69454 .57951 Mtetra
.69454 .57951 .6993 .58491 .70944 .58199 .70471 .57657 Mtetra
.70471 .57657 .70944 .58199 .71962 .57906 .71491 .57363 Mtetra
.71491 .57363 .71962 .57906 .72984 .57612 .72516 .57067 Mtetra
.72516 .57067 .72984 .57612 .74009 .57317 .73544 .5677 Mtetra
.73544 .5677 .74009 .57317 .75038 .57021 .74575 .56471 Mtetra
.74575 .56471 .75038 .57021 .76071 .56724 .75611 .56172 Mtetra
.75611 .56172 .76071 .56724 .77107 .56426 .7665 .55872 Mtetra
.7665 .55872 .77107 .56426 .78148 .56126 .77693 .55571 Mtetra
.77693 .55571 .78148 .56126 .79192 .55826 .78739 .55268 Mtetra
.78739 .55268 .79192 .55826 .80239 .55524 .7979 .54965 Mtetra
.7979 .54965 .80239 .55524 .81291 .55222 .80844 .5466 Mtetra
.80844 .5466 .81291 .55222 .82346 .54918 .81902 .54354 Mtetra
.81902 .54354 .82346 .54918 .83406 .54613 .82964 .54047 Mtetra
.82964 .54047 .83406 .54613 .84469 .54307 .8403 .53739 Mtetra
.8403 .53739 .84469 .54307 .85536 .54 .851 .5343 Mtetra
.851 .5343 .85536 .54 .86607 .53692 .86174 .5312 Mtetra
.86174 .5312 .86607 .53692 .87682 .53383 .87252 .52809 Mtetra
.87252 .52809 .87682 .53383 .88761 .53072 .88334 .52496 Mtetra
.88334 .52496 .88761 .53072 .89844 .52761 .89419 .52182 Mtetra
.89419 .52182 .89844 .52761 .90931 .52448 .90509 .51867 Mtetra
.90509 .51867 .90931 .52448 .92022 .52134 .91603 .51551 Mtetra
.91603 .51551 .92022 .52134 .93116 .51819 .92701 .51234 Mtetra
.92701 .51234 .93116 .51819 .94216 .51503 .93803 .50916 Mtetra
.93803 .50916 .94216 .51503 .95319 .51185 .94909 .50596 Mtetra
.94909 .50596 .95319 .51185 .96426 .50866 .9602 .50275 Mtetra
.36369 .66869 .36922 .67351 .37826 .6709 .37275 .66606 Mtetra
.37275 .66606 .37826 .6709 .38732 .66828 .38183 .66342 Mtetra
.38183 .66342 .38732 .66828 .39642 .66566 .39094 .66078 Mtetra
.39094 .66078 .39642 .66566 .40554 .66302 .40009 .65813 Mtetra
.40009 .65813 .40554 .66302 .4147 .66037 .40927 .65546 Mtetra
.40927 .65546 .4147 .66037 .42389 .65772 .41848 .65279 Mtetra
.41848 .65279 .42389 .65772 .43311 .65505 .42772 .65011 Mtetra
.42772 .65011 .43311 .65505 .44236 .65238 .43699 .64742 Mtetra
.43699 .64742 .44236 .65238 .45165 .6497 .44629 .64472 Mtetra
.44629 .64472 .45165 .6497 .46096 .64701 .45563 .64201 Mtetra
.45563 .64201 .46096 .64701 .47031 .6443 .465 .63929 Mtetra
.465 .63929 .47031 .6443 .47969 .64159 .4744 .63657 Mtetra
.4744 .63657 .47969 .64159 .4891 .63887 .48383 .63383 Mtetra
.48383 .63383 .4891 .63887 .49855 .63615 .4933 .63108 Mtetra
.4933 .63108 .49855 .63615 .50802 .63341 .50279 .62833 Mtetra
.50279 .62833 .50802 .63341 .51753 .63066 .51233 .62556 Mtetra
.51233 .62556 .51753 .63066 .52708 .6279 .52189 .62279 Mtetra
.52189 .62279 .52708 .6279 .53665 .62513 .53149 .62 Mtetra
.53149 .62 .53665 .62513 .54626 .62236 .54112 .61721 Mtetra
.54112 .61721 .54626 .62236 .55591 .61957 .55079 .6144 Mtetra
.55079 .6144 .55591 .61957 .56558 .61677 .56049 .61159 Mtetra
.56049 .61159 .56558 .61677 .57529 .61397 .57022 .60876 Mtetra
.57022 .60876 .57529 .61397 .58504 .61115 .57999 .60593 Mtetra
.57999 .60593 .58504 .61115 .59482 .60833 .58979 .60308 Mtetra
.58979 .60308 .59482 .60833 .60463 .60549 .59963 .60023 Mtetra
.59963 .60023 .60463 .60549 .61448 .60265 .6095 .59737 Mtetra
.6095 .59737 .61448 .60265 .62437 .59979 .61941 .59449 Mtetra
.61941 .59449 .62437 .59979 .63428 .59692 .62935 .59161 Mtetra
.62935 .59161 .63428 .59692 .64424 .59405 .63933 .58871 Mtetra
.63933 .58871 .64424 .59405 .65423 .59116 .64934 .58581 Mtetra
.64934 .58581 .65423 .59116 .66425 .58826 .65939 .58289 Mtetra
.65939 .58289 .66425 .58826 .67431 .58536 .66947 .57996 Mtetra
.66947 .57996 .67431 .58536 .68441 .58244 .67959 .57703 Mtetra
.67959 .57703 .68441 .58244 .69454 .57951 .68975 .57408 Mtetra
.68975 .57408 .69454 .57951 .70471 .57657 .69995 .57112 Mtetra
.69995 .57112 .70471 .57657 .71491 .57363 .71018 .56815 Mtetra
.71018 .56815 .71491 .57363 .72516 .57067 .72044 .56517 Mtetra
.72044 .56517 .72516 .57067 .73544 .5677 .73075 .56218 Mtetra
.73075 .56218 .73544 .5677 .74575 .56471 .74109 .55918 Mtetra
.74109 .55918 .74575 .56471 .75611 .56172 .75147 .55617 Mtetra
.75147 .55617 .75611 .56172 .7665 .55872 .76189 .55315 Mtetra
.76189 .55315 .7665 .55872 .77693 .55571 .77234 .55012 Mtetra
.77234 .55012 .77693 .55571 .78739 .55268 .78284 .54707 Mtetra
.78284 .54707 .78739 .55268 .7979 .54965 .79337 .54401 Mtetra
.79337 .54401 .7979 .54965 .80844 .5466 .80394 .54095 Mtetra
.80394 .54095 .80844 .5466 .81902 .54354 .81455 .53787 Mtetra
.81455 .53787 .81902 .54354 .82964 .54047 .8252 .53478 Mtetra
.8252 .53478 .82964 .54047 .8403 .53739 .83589 .53168 Mtetra
.83589 .53168 .8403 .53739 .851 .5343 .84661 .52857 Mtetra
.84661 .52857 .851 .5343 .86174 .5312 .85738 .52544 Mtetra
.85738 .52544 .86174 .5312 .87252 .52809 .86819 .52231 Mtetra
.86819 .52231 .87252 .52809 .88334 .52496 .87903 .51916 Mtetra
.87903 .51916 .88334 .52496 .89419 .52182 .88992 .516 Mtetra
.88992 .516 .89419 .52182 .90509 .51867 .90085 .51283 Mtetra
.90085 .51283 .90509 .51867 .91603 .51551 .91182 .50965 Mtetra
.91182 .50965 .91603 .51551 .92701 .51234 .92283 .50645 Mtetra
.92283 .50645 .92701 .51234 .93803 .50916 .93388 .50324 Mtetra
.93388 .50324 .93803 .50916 .94909 .50596 .94497 .50003 Mtetra
.94497 .50003 .94909 .50596 .9602 .50275 .9561 .4968 Mtetra
.35813 .66383 .36369 .66869 .37275 .66606 .3672 .66119 Mtetra
.3672 .66119 .37275 .66606 .38183 .66342 .3763 .65854 Mtetra
.3763 .65854 .38183 .66342 .39094 .66078 .38544 .65587 Mtetra
.38544 .65587 .39094 .66078 .40009 .65813 .3946 .6532 Mtetra
.3946 .6532 .40009 .65813 .40927 .65546 .4038 .65052 Mtetra
.4038 .65052 .40927 .65546 .41848 .65279 .41303 .64783 Mtetra
.41303 .64783 .41848 .65279 .42772 .65011 .42229 .64514 Mtetra
.42229 .64514 .42772 .65011 .43699 .64742 .43158 .64243 Mtetra
.43158 .64243 .43699 .64742 .44629 .64472 .4409 .63971 Mtetra
.4409 .63971 .44629 .64472 .45563 .64201 .45026 .63699 Mtetra
.45026 .63699 .45563 .64201 .465 .63929 .45965 .63425 Mtetra
.45965 .63425 .465 .63929 .4744 .63657 .46907 .63151 Mtetra
.46907 .63151 .4744 .63657 .48383 .63383 .47853 .62875 Mtetra
.47853 .62875 .48383 .63383 .4933 .63108 .48801 .62599 Mtetra
.48801 .62599 .4933 .63108 .50279 .62833 .49753 .62321 Mtetra
.49753 .62321 .50279 .62833 .51233 .62556 .50709 .62043 Mtetra
.50709 .62043 .51233 .62556 .52189 .62279 .51667 .61764 Mtetra
.51667 .61764 .52189 .62279 .53149 .62 .52629 .61483 Mtetra
.52629 .61483 .53149 .62 .54112 .61721 .53595 .61202 Mtetra
.53595 .61202 .54112 .61721 .55079 .6144 .54563 .6092 Mtetra
.54563 .6092 .55079 .6144 .56049 .61159 .55536 .60636 Mtetra
.55536 .60636 .56049 .61159 .57022 .60876 .56511 .60352 Mtetra
.56511 .60352 .57022 .60876 .57999 .60593 .5749 .60067 Mtetra
.5749 .60067 .57999 .60593 .58979 .60308 .58473 .59781 Mtetra
.58473 .59781 .58979 .60308 .59963 .60023 .59459 .59493 Mtetra
.59459 .59493 .59963 .60023 .6095 .59737 .60448 .59205 Mtetra
.60448 .59205 .6095 .59737 .61941 .59449 .61441 .58916 Mtetra
.61441 .58916 .61941 .59449 .62935 .59161 .62438 .58625 Mtetra
.62438 .58625 .62935 .59161 .63933 .58871 .63438 .58334 Mtetra
.63438 .58334 .63933 .58871 .64934 .58581 .64442 .58041 Mtetra
.64442 .58041 .64934 .58581 .65939 .58289 .65449 .57748 Mtetra
.65449 .57748 .65939 .58289 .66947 .57996 .6646 .57453 Mtetra
.6646 .57453 .66947 .57996 .67959 .57703 .67475 .57158 Mtetra
.67475 .57158 .67959 .57703 .68975 .57408 .68493 .56861 Mtetra
.68493 .56861 .68975 .57408 .69995 .57112 .69515 .56563 Mtetra
.69515 .56563 .69995 .57112 .71018 .56815 .70541 .56264 Mtetra
.70541 .56264 .71018 .56815 .72044 .56517 .7157 .55965 Mtetra
.7157 .55965 .72044 .56517 .73075 .56218 .72603 .55664 Mtetra
.72603 .55664 .73075 .56218 .74109 .55918 .7364 .55361 Mtetra
.7364 .55361 .74109 .55918 .75147 .55617 .7468 .55058 Mtetra
.7468 .55058 .75147 .55617 .76189 .55315 .75725 .54754 Mtetra
.75725 .54754 .76189 .55315 .77234 .55012 .76773 .54449 Mtetra
.76773 .54449 .77234 .55012 .78284 .54707 .77825 .54142 Mtetra
.77825 .54142 .78284 .54707 .79337 .54401 .78881 .53834 Mtetra
.78881 .53834 .79337 .54401 .80394 .54095 .79941 .53526 Mtetra
.79941 .53526 .80394 .54095 .81455 .53787 .81005 .53216 Mtetra
.81005 .53216 .81455 .53787 .8252 .53478 .82072 .52905 Mtetra
.82072 .52905 .8252 .53478 .83589 .53168 .83144 .52592 Mtetra
.83144 .52592 .83589 .53168 .84661 .52857 .84219 .52279 Mtetra
.84219 .52279 .84661 .52857 .85738 .52544 .85299 .51964 Mtetra
.85299 .51964 .85738 .52544 .86819 .52231 .86383 .51649 Mtetra
.86383 .51649 .86819 .52231 .87903 .51916 .8747 .51332 Mtetra
.8747 .51332 .87903 .51916 .88992 .516 .88562 .51014 Mtetra
.88562 .51014 .88992 .516 .90085 .51283 .89658 .50694 Mtetra
.89658 .50694 .90085 .51283 .91182 .50965 .90758 .50374 Mtetra
.90758 .50374 .91182 .50965 .92283 .50645 .91862 .50052 Mtetra
.91862 .50052 .92283 .50645 .93388 .50324 .9297 .49729 Mtetra
.9297 .49729 .93388 .50324 .94497 .50003 .94082 .49405 Mtetra
.94082 .49405 .94497 .50003 .9561 .4968 .95198 .4908 Mtetra
.35253 .65894 .35813 .66383 .3672 .66119 .36162 .65628 Mtetra
.36162 .65628 .3672 .66119 .3763 .65854 .37074 .65361 Mtetra
.37074 .65361 .3763 .65854 .38544 .65587 .3799 .65094 Mtetra
.3799 .65094 .38544 .65587 .3946 .6532 .38908 .64825 Mtetra
.38908 .64825 .3946 .6532 .4038 .65052 .3983 .64555 Mtetra
.3983 .64555 .4038 .65052 .41303 .64783 .40755 .64285 Mtetra
.40755 .64285 .41303 .64783 .42229 .64514 .41683 .64013 Mtetra
.41683 .64013 .42229 .64514 .43158 .64243 .42614 .63741 Mtetra
.42614 .63741 .43158 .64243 .4409 .63971 .43548 .63467 Mtetra
.43548 .63467 .4409 .63971 .45026 .63699 .44486 .63193 Mtetra
.44486 .63193 .45026 .63699 .45965 .63425 .45427 .62918 Mtetra
.45427 .62918 .45965 .63425 .46907 .63151 .46371 .62641 Mtetra
.46371 .62641 .46907 .63151 .47853 .62875 .47319 .62364 Mtetra
.47319 .62364 .47853 .62875 .48801 .62599 .48269 .62086 Mtetra
.48269 .62086 .48801 .62599 .49753 .62321 .49224 .61807 Mtetra
.49224 .61807 .49753 .62321 .50709 .62043 .50181 .61527 Mtetra
.50181 .61527 .50709 .62043 .51667 .61764 .51142 .61245 Mtetra
.51142 .61245 .51667 .61764 .52629 .61483 .52106 .60963 Mtetra
.52106 .60963 .52629 .61483 .53595 .61202 .53074 .6068 Mtetra
.53074 .6068 .53595 .61202 .54563 .6092 .54045 .60396 Mtetra
.54045 .60396 .54563 .6092 .55536 .60636 .55019 .60111 Mtetra
.55019 .60111 .55536 .60636 .56511 .60352 .55997 .59825 Mtetra
.55997 .59825 .56511 .60352 .5749 .60067 .56978 .59538 Mtetra
.56978 .59538 .5749 .60067 .58473 .59781 .57963 .59249 Mtetra
.57963 .59249 .58473 .59781 .59459 .59493 .58952 .5896 Mtetra
.58952 .5896 .59459 .59493 .60448 .59205 .59944 .5867 Mtetra
.59944 .5867 .60448 .59205 .61441 .58916 .60939 .58379 Mtetra
.60939 .58379 .61441 .58916 .62438 .58625 .61938 .58087 Mtetra
.61938 .58087 .62438 .58625 .63438 .58334 .62941 .57793 Mtetra
.62941 .57793 .63438 .58334 .64442 .58041 .63947 .57499 Mtetra
.63947 .57499 .64442 .58041 .65449 .57748 .64957 .57203 Mtetra
.64957 .57203 .65449 .57748 .6646 .57453 .6597 .56907 Mtetra
.6597 .56907 .6646 .57453 .67475 .57158 .66987 .56609 Mtetra
.66987 .56609 .67475 .57158 .68493 .56861 .68008 .56311 Mtetra
.68008 .56311 .68493 .56861 .69515 .56563 .69032 .56011 Mtetra
.69032 .56011 .69515 .56563 .70541 .56264 .7006 .5571 Mtetra
.7006 .5571 .70541 .56264 .7157 .55965 .71092 .55408 Mtetra
.71092 .55408 .7157 .55965 .72603 .55664 .72128 .55105 Mtetra
.72128 .55105 .72603 .55664 .7364 .55361 .73168 .54801 Mtetra
.73168 .54801 .7364 .55361 .7468 .55058 .74211 .54496 Mtetra
.74211 .54496 .7468 .55058 .75725 .54754 .75258 .54189 Mtetra
.75258 .54189 .75725 .54754 .76773 .54449 .76309 .53882 Mtetra
.76309 .53882 .76773 .54449 .77825 .54142 .77364 .53573 Mtetra
.77364 .53573 .77825 .54142 .78881 .53834 .78422 .53263 Mtetra
.78422 .53263 .78881 .53834 .79941 .53526 .79485 .52952 Mtetra
.79485 .52952 .79941 .53526 .81005 .53216 .80551 .5264 Mtetra
.80551 .5264 .81005 .53216 .82072 .52905 .81622 .52327 Mtetra
.81622 .52327 .82072 .52905 .83144 .52592 .82696 .52013 Mtetra
.82696 .52013 .83144 .52592 .84219 .52279 .83775 .51697 Mtetra
.83775 .51697 .84219 .52279 .85299 .51964 .84857 .51381 Mtetra
.84857 .51381 .85299 .51964 .86383 .51649 .85944 .51063 Mtetra
.85944 .51063 .86383 .51649 .8747 .51332 .87034 .50744 Mtetra
.87034 .50744 .8747 .51332 .88562 .51014 .88129 .50423 Mtetra
.88129 .50423 .88562 .51014 .89658 .50694 .89227 .50102 Mtetra
.89227 .50102 .89658 .50694 .90758 .50374 .9033 .49779 Mtetra
.9033 .49779 .90758 .50374 .91862 .50052 .91437 .49455 Mtetra
.91437 .49455 .91862 .50052 .9297 .49729 .92549 .4913 Mtetra
.92549 .4913 .9297 .49729 .94082 .49405 .93664 .48804 Mtetra
.93664 .48804 .94082 .49405 .95198 .4908 .94784 .48476 Mtetra
.34689 .65403 .35253 .65894 .36162 .65628 .356 .65135 Mtetra
.356 .65135 .36162 .65628 .37074 .65361 .36515 .64866 Mtetra
.36515 .64866 .37074 .65361 .3799 .65094 .37432 .64597 Mtetra
.37432 .64597 .3799 .65094 .38908 .64825 .38352 .64326 Mtetra
.38352 .64326 .38908 .64825 .3983 .64555 .39276 .64055 Mtetra
.39276 .64055 .3983 .64555 .40755 .64285 .40203 .63783 Mtetra
.40203 .63783 .40755 .64285 .41683 .64013 .41133 .63509 Mtetra
.41133 .63509 .41683 .64013 .42614 .63741 .42066 .63235 Mtetra
.42066 .63235 .42614 .63741 .43548 .63467 .43003 .6296 Mtetra
.43003 .6296 .43548 .63467 .44486 .63193 .43942 .62684 Mtetra
.43942 .62684 .44486 .63193 .45427 .62918 .44885 .62407 Mtetra
.44885 .62407 .45427 .62918 .46371 .62641 .45832 .62129 Mtetra
.45832 .62129 .46371 .62641 .47319 .62364 .46781 .6185 Mtetra
.46781 .6185 .47319 .62364 .48269 .62086 .47734 .6157 Mtetra
.47734 .6157 .48269 .62086 .49224 .61807 .4869 .61289 Mtetra
.4869 .61289 .49224 .61807 .50181 .61527 .4965 .61007 Mtetra
.4965 .61007 .50181 .61527 .51142 .61245 .50613 .60724 Mtetra
.50613 .60724 .51142 .61245 .52106 .60963 .5158 .6044 Mtetra
.5158 .6044 .52106 .60963 .53074 .6068 .52549 .60155 Mtetra
.52549 .60155 .53074 .6068 .54045 .60396 .53523 .59869 Mtetra
.53523 .59869 .54045 .60396 .55019 .60111 .54499 .59582 Mtetra
.54499 .59582 .55019 .60111 .55997 .59825 .5548 .59294 Mtetra
.5548 .59294 .55997 .59825 .56978 .59538 .56463 .59005 Mtetra
.56463 .59005 .56978 .59538 .57963 .59249 .5745 .58715 Mtetra
.5745 .58715 .57963 .59249 .58952 .5896 .58441 .58424 Mtetra
.58441 .58424 .58952 .5896 .59944 .5867 .59435 .58132 Mtetra
.59435 .58132 .59944 .5867 .60939 .58379 .60433 .57838 Mtetra
.60433 .57838 .60939 .58379 .61938 .58087 .61435 .57544 Mtetra
.61435 .57544 .61938 .58087 .62941 .57793 .6244 .57249 Mtetra
.6244 .57249 .62941 .57793 .63947 .57499 .63448 .56952 Mtetra
.63448 .56952 .63947 .57499 .64957 .57203 .6446 .56655 Mtetra
.6446 .56655 .64957 .57203 .6597 .56907 .65476 .56357 Mtetra
.65476 .56357 .6597 .56907 .66987 .56609 .66496 .56057 Mtetra
.66496 .56057 .66987 .56609 .68008 .56311 .67519 .55756 Mtetra
.67519 .55756 .68008 .56311 .69032 .56011 .68546 .55455 Mtetra
.68546 .55455 .69032 .56011 .7006 .5571 .69577 .55152 Mtetra
.69577 .55152 .7006 .5571 .71092 .55408 .70612 .54848 Mtetra
.70612 .54848 .71092 .55408 .72128 .55105 .7165 .54543 Mtetra
.7165 .54543 .72128 .55105 .73168 .54801 .72692 .54236 Mtetra
.72692 .54236 .73168 .54801 .74211 .54496 .73738 .53929 Mtetra
.73738 .53929 .74211 .54496 .75258 .54189 .74788 .53621 Mtetra
.74788 .53621 .75258 .54189 .76309 .53882 .75841 .53311 Mtetra
.75841 .53311 .76309 .53882 .77364 .53573 .76899 .53 Mtetra
.76899 .53 .77364 .53573 .78422 .53263 .7796 .52688 Mtetra
.7796 .52688 .78422 .53263 .79485 .52952 .79026 .52375 Mtetra
.79026 .52375 .79485 .52952 .80551 .5264 .80095 .52061 Mtetra
.80095 .52061 .80551 .5264 .81622 .52327 .81168 .51746 Mtetra
.81168 .51746 .81622 .52327 .82696 .52013 .82245 .51429 Mtetra
.82245 .51429 .82696 .52013 .83775 .51697 .83327 .51112 Mtetra
.83327 .51112 .83775 .51697 .84857 .51381 .84412 .50793 Mtetra
.84412 .50793 .84857 .51381 .85944 .51063 .85501 .50473 Mtetra
.85501 .50473 .85944 .51063 .87034 .50744 .86595 .50151 Mtetra
.86595 .50151 .87034 .50744 .88129 .50423 .87693 .49829 Mtetra
.87693 .49829 .88129 .50423 .89227 .50102 .88794 .49505 Mtetra
.88794 .49505 .89227 .50102 .9033 .49779 .899 .4918 Mtetra
.899 .4918 .9033 .49779 .91437 .49455 .9101 .48854 Mtetra
.9101 .48854 .91437 .49455 .92549 .4913 .92125 .48527 Mtetra
.92125 .48527 .92549 .4913 .93664 .48804 .93243 .48198 Mtetra
.93243 .48198 .93664 .48804 .94784 .48476 .94366 .47868 Mtetra
.34122 .64908 .34689 .65403 .356 .65135 .35035 .64638 Mtetra
.35035 .64638 .356 .65135 .36515 .64866 .35951 .64368 Mtetra
.35951 .64368 .36515 .64866 .37432 .64597 .36871 .64097 Mtetra
.36871 .64097 .37432 .64597 .38352 .64326 .37793 .63825 Mtetra
.37793 .63825 .38352 .64326 .39276 .64055 .38719 .63551 Mtetra
.38719 .63551 .39276 .64055 .40203 .63783 .39647 .63277 Mtetra
.39647 .63277 .40203 .63783 .41133 .63509 .40579 .63002 Mtetra
.40579 .63002 .41133 .63509 .42066 .63235 .41515 .62726 Mtetra
.41515 .62726 .42066 .63235 .43003 .6296 .42453 .62449 Mtetra
.42453 .62449 .43003 .6296 .43942 .62684 .43395 .62172 Mtetra
.43395 .62172 .43942 .62684 .44885 .62407 .4434 .61893 Mtetra
.4434 .61893 .44885 .62407 .45832 .62129 .45289 .61613 Mtetra
.45289 .61613 .45832 .62129 .46781 .6185 .4624 .61332 Mtetra
.4624 .61332 .46781 .6185 .47734 .6157 .47195 .6105 Mtetra
.47195 .6105 .47734 .6157 .4869 .61289 .48154 .60767 Mtetra
.48154 .60767 .4869 .61289 .4965 .61007 .49116 .60484 Mtetra
.49116 .60484 .4965 .61007 .50613 .60724 .50081 .60199 Mtetra
.50081 .60199 .50613 .60724 .5158 .6044 .5105 .59913 Mtetra
.5105 .59913 .5158 .6044 .52549 .60155 .52022 .59626 Mtetra
.52022 .59626 .52549 .60155 .53523 .59869 .52997 .59338 Mtetra
.52997 .59338 .53523 .59869 .54499 .59582 .53976 .59049 Mtetra
.53976 .59049 .54499 .59582 .5548 .59294 .54959 .58759 Mtetra
.54959 .58759 .5548 .59294 .56463 .59005 .55945 .58469 Mtetra
.55945 .58469 .56463 .59005 .5745 .58715 .56934 .58177 Mtetra
.56934 .58177 .5745 .58715 .58441 .58424 .57927 .57884 Mtetra
.57927 .57884 .58441 .58424 .59435 .58132 .58924 .57589 Mtetra
.58924 .57589 .59435 .58132 .60433 .57838 .59924 .57294 Mtetra
.59924 .57294 .60433 .57838 .61435 .57544 .60928 .56998 Mtetra
.60928 .56998 .61435 .57544 .6244 .57249 .61935 .56701 Mtetra
.61935 .56701 .6244 .57249 .63448 .56952 .62946 .56403 Mtetra
.62946 .56403 .63448 .56952 .6446 .56655 .63961 .56103 Mtetra
.63961 .56103 .6446 .56655 .65476 .56357 .64979 .55803 Mtetra
.64979 .55803 .65476 .56357 .66496 .56057 .66002 .55501 Mtetra
.66002 .55501 .66496 .56057 .67519 .55756 .67027 .55198 Mtetra
.67027 .55198 .67519 .55756 .68546 .55455 .68057 .54895 Mtetra
.68057 .54895 .68546 .55455 .69577 .55152 .6909 .5459 Mtetra
.6909 .5459 .69577 .55152 .70612 .54848 .70127 .54284 Mtetra
.70127 .54284 .70612 .54848 .7165 .54543 .71168 .53976 Mtetra
.71168 .53976 .7165 .54543 .72692 .54236 .72213 .53668 Mtetra
.72213 .53668 .72692 .54236 .73738 .53929 .73262 .53359 Mtetra
.73262 .53359 .73738 .53929 .74788 .53621 .74314 .53048 Mtetra
.74314 .53048 .74788 .53621 .75841 .53311 .75371 .52737 Mtetra
.75371 .52737 .75841 .53311 .76899 .53 .76431 .52424 Mtetra
.76431 .52424 .76899 .53 .7796 .52688 .77495 .5211 Mtetra
.77495 .5211 .7796 .52688 .79026 .52375 .78563 .51794 Mtetra
.78563 .51794 .79026 .52375 .80095 .52061 .79635 .51478 Mtetra
.79635 .51478 .80095 .52061 .81168 .51746 .80711 .51161 Mtetra
.80711 .51161 .81168 .51746 .82245 .51429 .81792 .50842 Mtetra
.81792 .50842 .82245 .51429 .83327 .51112 .82876 .50522 Mtetra
.82876 .50522 .83327 .51112 .84412 .50793 .83964 .50201 Mtetra
.83964 .50201 .84412 .50793 .85501 .50473 .85056 .49879 Mtetra
.85056 .49879 .85501 .50473 .86595 .50151 .86153 .49555 Mtetra
.86153 .49555 .86595 .50151 .87693 .49829 .87253 .4923 Mtetra
.87253 .4923 .87693 .49829 .88794 .49505 .88358 .48904 Mtetra
.88358 .48904 .88794 .49505 .899 .4918 .89467 .48577 Mtetra
.89467 .48577 .899 .4918 .9101 .48854 .9058 .48249 Mtetra
.9058 .48249 .9101 .48854 .92125 .48527 .91698 .47919 Mtetra
.91698 .47919 .92125 .48527 .93243 .48198 .92819 .47588 Mtetra
.92819 .47588 .93243 .48198 .94366 .47868 .93945 .47256 Mtetra
.33552 .6441 .34122 .64908 .35035 .64638 .34467 .64139 Mtetra
.34467 .64139 .35035 .64638 .35951 .64368 .35385 .63866 Mtetra
.35385 .63866 .35951 .64368 .36871 .64097 .36306 .63594 Mtetra
.36306 .63594 .36871 .64097 .37793 .63825 .3723 .6332 Mtetra
.3723 .6332 .37793 .63825 .38719 .63551 .38158 .63045 Mtetra
.38158 .63045 .38719 .63551 .39647 .63277 .39089 .62769 Mtetra
.39089 .62769 .39647 .63277 .40579 .63002 .40023 .62492 Mtetra
.40023 .62492 .40579 .63002 .41515 .62726 .4096 .62214 Mtetra
.4096 .62214 .41515 .62726 .42453 .62449 .41901 .61936 Mtetra
.41901 .61936 .42453 .62449 .43395 .62172 .42844 .61656 Mtetra
.42844 .61656 .43395 .62172 .4434 .61893 .43792 .61375 Mtetra
.43792 .61375 .4434 .61893 .45289 .61613 .44742 .61094 Mtetra
.44742 .61094 .45289 .61613 .4624 .61332 .45696 .60811 Mtetra
.45696 .60811 .4624 .61332 .47195 .6105 .46653 .60527 Mtetra
.46653 .60527 .47195 .6105 .48154 .60767 .47614 .60243 Mtetra
.47614 .60243 .48154 .60767 .49116 .60484 .48578 .59957 Mtetra
.48578 .59957 .49116 .60484 .50081 .60199 .49545 .5967 Mtetra
.49545 .5967 .50081 .60199 .5105 .59913 .50516 .59383 Mtetra
.50516 .59383 .5105 .59913 .52022 .59626 .5149 .59094 Mtetra
.5149 .59094 .52022 .59626 .52997 .59338 .52468 .58804 Mtetra
.52468 .58804 .52997 .59338 .53976 .59049 .5345 .58513 Mtetra
.5345 .58513 .53976 .59049 .54959 .58759 .54434 .58222 Mtetra
.54434 .58222 .54959 .58759 .55945 .58469 .55423 .57929 Mtetra
.55423 .57929 .55945 .58469 .56934 .58177 .56414 .57635 Mtetra
.56414 .57635 .56934 .58177 .57927 .57884 .5741 .5734 Mtetra
.5741 .5734 .57927 .57884 .58924 .57589 .58409 .57044 Mtetra
.58409 .57044 .58924 .57589 .59924 .57294 .59412 .56747 Mtetra
.59412 .56747 .59924 .57294 .60928 .56998 .60418 .56449 Mtetra
.60418 .56449 .60928 .56998 .61935 .56701 .61428 .56149 Mtetra
.61428 .56149 .61935 .56701 .62946 .56403 .62441 .55849 Mtetra
.62441 .55849 .62946 .56403 .63961 .56103 .63458 .55547 Mtetra
.63458 .55547 .63961 .56103 .64979 .55803 .64479 .55245 Mtetra
.64479 .55245 .64979 .55803 .66002 .55501 .65504 .54941 Mtetra
.65504 .54941 .66002 .55501 .67027 .55198 .66532 .54637 Mtetra
.66532 .54637 .67027 .55198 .68057 .54895 .67564 .54331 Mtetra
.67564 .54331 .68057 .54895 .6909 .5459 .686 .54024 Mtetra
.686 .54024 .6909 .5459 .70127 .54284 .6964 .53716 Mtetra
.6964 .53716 .70127 .54284 .71168 .53976 .70684 .53406 Mtetra
.70684 .53406 .71168 .53976 .72213 .53668 .71731 .53096 Mtetra
.71731 .53096 .72213 .53668 .73262 .53359 .72782 .52785 Mtetra
.72782 .52785 .73262 .53359 .74314 .53048 .73838 .52472 Mtetra
.73838 .52472 .74314 .53048 .75371 .52737 .74897 .52158 Mtetra
.74897 .52158 .75371 .52737 .76431 .52424 .7596 .51843 Mtetra
.7596 .51843 .76431 .52424 .77495 .5211 .77027 .51527 Mtetra
.77027 .51527 .77495 .5211 .78563 .51794 .78098 .5121 Mtetra
.78098 .5121 .78563 .51794 .79635 .51478 .79173 .50891 Mtetra
.79173 .50891 .79635 .51478 .80711 .51161 .80251 .50571 Mtetra
.80251 .50571 .80711 .51161 .81792 .50842 .81335 .5025 Mtetra
.81335 .5025 .81792 .50842 .82876 .50522 .82422 .49928 Mtetra
.82422 .49928 .82876 .50522 .83964 .50201 .83513 .49605 Mtetra
.83513 .49605 .83964 .50201 .85056 .49879 .84608 .4928 Mtetra
.84608 .4928 .85056 .49879 .86153 .49555 .85707 .48955 Mtetra
.85707 .48955 .86153 .49555 .87253 .4923 .86811 .48627 Mtetra
.86811 .48627 .87253 .4923 .88358 .48904 .87919 .48299 Mtetra
.87919 .48299 .88358 .48904 .89467 .48577 .89031 .4797 Mtetra
.89031 .4797 .89467 .48577 .9058 .48249 .90147 .47639 Mtetra
.90147 .47639 .9058 .48249 .91698 .47919 .91268 .47307 Mtetra
.91268 .47307 .91698 .47919 .92819 .47588 .92392 .46974 Mtetra
.92392 .46974 .92819 .47588 .93945 .47256 .93521 .46639 Mtetra
.32977 .63908 .33552 .6441 .34467 .64139 .33894 .63636 Mtetra
.33894 .63636 .34467 .64139 .35385 .63866 .34814 .63362 Mtetra
.34814 .63362 .35385 .63866 .36306 .63594 .35737 .63087 Mtetra
.35737 .63087 .36306 .63594 .3723 .6332 .36664 .62811 Mtetra
.36664 .62811 .3723 .6332 .38158 .63045 .37593 .62535 Mtetra
.37593 .62535 .38158 .63045 .39089 .62769 .38526 .62257 Mtetra
.38526 .62257 .39089 .62769 .40023 .62492 .39462 .61979 Mtetra
.39462 .61979 .40023 .62492 .4096 .62214 .40402 .61699 Mtetra
.40402 .61699 .4096 .62214 .41901 .61936 .41344 .61418 Mtetra
.41344 .61418 .41901 .61936 .42844 .61656 .4229 .61137 Mtetra
.4229 .61137 .42844 .61656 .43792 .61375 .43239 .60854 Mtetra
.43239 .60854 .43792 .61375 .44742 .61094 .44192 .60571 Mtetra
.44192 .60571 .44742 .61094 .45696 .60811 .45148 .60286 Mtetra
.45148 .60286 .45696 .60811 .46653 .60527 .46108 .60001 Mtetra
.46108 .60001 .46653 .60527 .47614 .60243 .4707 .59714 Mtetra
.4707 .59714 .47614 .60243 .48578 .59957 .48037 .59427 Mtetra
.48037 .59427 .48578 .59957 .49545 .5967 .49006 .59138 Mtetra
.49006 .59138 .49545 .5967 .50516 .59383 .49979 .58849 Mtetra
.49979 .58849 .50516 .59383 .5149 .59094 .50956 .58558 Mtetra
.50956 .58558 .5149 .59094 .52468 .58804 .51936 .58267 Mtetra
.51936 .58267 .52468 .58804 .5345 .58513 .52919 .57974 Mtetra
.52919 .57974 .5345 .58513 .54434 .58222 .53907 .5768 Mtetra
.53907 .5768 .54434 .58222 .55423 .57929 .54897 .57385 Mtetra
.54897 .57385 .55423 .57929 .56414 .57635 .55891 .57089 Mtetra
.55891 .57089 .56414 .57635 .5741 .5734 .56889 .56792 Mtetra
.56889 .56792 .5741 .5734 .58409 .57044 .57891 .56494 Mtetra
.57891 .56494 .58409 .57044 .59412 .56747 .58896 .56195 Mtetra
.58896 .56195 .59412 .56747 .60418 .56449 .59904 .55895 Mtetra
.59904 .55895 .60418 .56449 .61428 .56149 .60917 .55594 Mtetra
.60917 .55594 .61428 .56149 .62441 .55849 .61933 .55292 Mtetra
.61933 .55292 .62441 .55849 .63458 .55547 .62952 .54988 Mtetra
.62952 .54988 .63458 .55547 .64479 .55245 .63976 .54684 Mtetra
.63976 .54684 .64479 .55245 .65504 .54941 .65003 .54378 Mtetra
.65003 .54378 .65504 .54941 .66532 .54637 .66034 .54071 Mtetra
.66034 .54071 .66532 .54637 .67564 .54331 .67069 .53763 Mtetra
.67069 .53763 .67564 .54331 .686 .54024 .68107 .53454 Mtetra
.68107 .53454 .686 .54024 .6964 .53716 .69149 .53144 Mtetra
.69149 .53144 .6964 .53716 .70684 .53406 .70196 .52833 Mtetra
.70196 .52833 .70684 .53406 .71731 .53096 .71246 .5252 Mtetra
.71246 .5252 .71731 .53096 .72782 .52785 .723 .52206 Mtetra
.723 .52206 .72782 .52785 .73838 .52472 .73358 .51892 Mtetra
.73358 .51892 .73838 .52472 .74897 .52158 .74419 .51576 Mtetra
.74419 .51576 .74897 .52158 .7596 .51843 .75485 .51258 Mtetra
.75485 .51258 .7596 .51843 .77027 .51527 .76555 .5094 Mtetra
.76555 .5094 .77027 .51527 .78098 .5121 .77629 .50621 Mtetra
.77629 .50621 .78098 .5121 .79173 .50891 .78707 .503 Mtetra
.78707 .503 .79173 .50891 .80251 .50571 .79788 .49978 Mtetra
.79788 .49978 .80251 .50571 .81335 .5025 .80874 .49655 Mtetra
.80874 .49655 .81335 .5025 .82422 .49928 .81964 .4933 Mtetra
.81964 .4933 .82422 .49928 .83513 .49605 .83058 .49005 Mtetra
.83058 .49005 .83513 .49605 .84608 .4928 .84157 .48678 Mtetra
.84157 .48678 .84608 .4928 .85707 .48955 .85259 .4835 Mtetra
.85259 .4835 .85707 .48955 .86811 .48627 .86366 .4802 Mtetra
.86366 .4802 .86811 .48627 .87919 .48299 .87477 .4769 Mtetra
.87477 .4769 .87919 .48299 .89031 .4797 .88592 .47358 Mtetra
.88592 .47358 .89031 .4797 .90147 .47639 .89711 .47025 Mtetra
.89711 .47025 .90147 .47639 .91268 .47307 .90834 .46691 Mtetra
.90834 .46691 .91268 .47307 .92392 .46974 .91962 .46355 Mtetra
.91962 .46355 .92392 .46974 .93521 .46639 .93095 .46018 Mtetra
.32399 .63404 .32977 .63908 .33894 .63636 .33318 .63129 Mtetra
.33318 .63129 .33894 .63636 .34814 .63362 .3424 .62854 Mtetra
.3424 .62854 .34814 .63362 .35737 .63087 .35165 .62577 Mtetra
.35165 .62577 .35737 .63087 .36664 .62811 .36094 .623 Mtetra
.36094 .623 .36664 .62811 .37593 .62535 .37025 .62021 Mtetra
.37025 .62021 .37593 .62535 .38526 .62257 .3796 .61742 Mtetra
.3796 .61742 .38526 .62257 .39462 .61979 .38898 .61462 Mtetra
.38898 .61462 .39462 .61979 .40402 .61699 .3984 .6118 Mtetra
.3984 .6118 .40402 .61699 .41344 .61418 .40784 .60898 Mtetra
.40784 .60898 .41344 .61418 .4229 .61137 .41732 .60615 Mtetra
.41732 .60615 .4229 .61137 .43239 .60854 .42684 .6033 Mtetra
.42684 .6033 .43239 .60854 .44192 .60571 .43639 .60045 Mtetra
.43639 .60045 .44192 .60571 .45148 .60286 .44597 .59759 Mtetra
.44597 .59759 .45148 .60286 .46108 .60001 .45558 .59471 Mtetra
.45558 .59471 .46108 .60001 .4707 .59714 .46523 .59183 Mtetra
.46523 .59183 .4707 .59714 .48037 .59427 .47492 .58893 Mtetra
.47492 .58893 .48037 .59427 .49006 .59138 .48463 .58603 Mtetra
.48463 .58603 .49006 .59138 .49979 .58849 .49439 .58311 Mtetra
.49439 .58311 .49979 .58849 .50956 .58558 .50418 .58019 Mtetra
.50418 .58019 .50956 .58558 .51936 .58267 .514 .57725 Mtetra
.514 .57725 .51936 .58267 .52919 .57974 .52386 .57431 Mtetra
.52386 .57431 .52919 .57974 .53907 .5768 .53375 .57135 Mtetra
.53375 .57135 .53907 .5768 .54897 .57385 .54368 .56838 Mtetra
.54368 .56838 .54897 .57385 .55891 .57089 .55365 .5654 Mtetra
.55365 .5654 .55891 .57089 .56889 .56792 .56365 .56241 Mtetra
.56365 .56241 .56889 .56792 .57891 .56494 .57369 .55941 Mtetra
.57369 .55941 .57891 .56494 .58896 .56195 .58376 .5564 Mtetra
.58376 .5564 .58896 .56195 .59904 .55895 .59387 .55338 Mtetra
.59387 .55338 .59904 .55895 .60917 .55594 .60402 .55035 Mtetra
.60402 .55035 .60917 .55594 .61933 .55292 .61421 .5473 Mtetra
.61421 .5473 .61933 .55292 .62952 .54988 .62443 .54425 Mtetra
.62443 .54425 .62952 .54988 .63976 .54684 .63469 .54118 Mtetra
.63469 .54118 .63976 .54684 .65003 .54378 .64498 .53811 Mtetra
.64498 .53811 .65003 .54378 .66034 .54071 .65532 .53502 Mtetra
.65532 .53502 .66034 .54071 .67069 .53763 .66569 .53192 Mtetra
.66569 .53192 .67069 .53763 .68107 .53454 .6761 .52881 Mtetra
.6761 .52881 .68107 .53454 .69149 .53144 .68655 .52568 Mtetra
.68655 .52568 .69149 .53144 .70196 .52833 .69704 .52255 Mtetra
.69704 .52255 .70196 .52833 .71246 .5252 .70757 .5194 Mtetra
.70757 .5194 .71246 .5252 .723 .52206 .71814 .51624 Mtetra
.71814 .51624 .723 .52206 .73358 .51892 .72874 .51307 Mtetra
.72874 .51307 .73358 .51892 .74419 .51576 .73939 .50989 Mtetra
.73939 .50989 .74419 .51576 .75485 .51258 .75008 .5067 Mtetra
.75008 .5067 .75485 .51258 .76555 .5094 .7608 .50349 Mtetra
.7608 .50349 .76555 .5094 .77629 .50621 .77157 .50027 Mtetra
.77157 .50027 .77629 .50621 .78707 .503 .78237 .49704 Mtetra
.78237 .49704 .78707 .503 .79788 .49978 .79322 .4938 Mtetra
.79322 .4938 .79788 .49978 .80874 .49655 .80411 .49055 Mtetra
.80411 .49055 .80874 .49655 .81964 .4933 .81504 .48728 Mtetra
.81504 .48728 .81964 .4933 .83058 .49005 .82601 .484 Mtetra
.82601 .484 .83058 .49005 .84157 .48678 .83702 .48071 Mtetra
.83702 .48071 .84157 .48678 .85259 .4835 .84808 .47741 Mtetra
.84808 .47741 .85259 .4835 .86366 .4802 .85917 .47409 Mtetra
.85917 .47409 .86366 .4802 .87477 .4769 .87031 .47076 Mtetra
.87031 .47076 .87477 .4769 .88592 .47358 .88149 .46742 Mtetra
.88149 .46742 .88592 .47358 .89711 .47025 .89272 .46407 Mtetra
.89272 .46407 .89711 .47025 .90834 .46691 .90398 .4607 Mtetra
.90398 .4607 .90834 .46691 .91962 .46355 .91529 .45732 Mtetra
.91529 .45732 .91962 .46355 .93095 .46018 .92665 .45393 Mtetra
.31818 .62896 .32399 .63404 .33318 .63129 .32738 .6262 Mtetra
.32738 .6262 .33318 .63129 .3424 .62854 .33662 .62343 Mtetra
.33662 .62343 .3424 .62854 .35165 .62577 .34589 .62064 Mtetra
.34589 .62064 .35165 .62577 .36094 .623 .3552 .61785 Mtetra
.3552 .61785 .36094 .623 .37025 .62021 .36453 .61505 Mtetra
.36453 .61505 .37025 .62021 .3796 .61742 .3739 .61224 Mtetra
.3739 .61224 .3796 .61742 .38898 .61462 .3833 .60942 Mtetra
.3833 .60942 .38898 .61462 .3984 .6118 .39274 .60658 Mtetra
.39274 .60658 .3984 .6118 .40784 .60898 .40221 .60374 Mtetra
.40221 .60374 .40784 .60898 .41732 .60615 .41171 .60089 Mtetra
.41171 .60089 .41732 .60615 .42684 .6033 .42124 .59803 Mtetra
.42124 .59803 .42684 .6033 .43639 .60045 .43081 .59516 Mtetra
.43081 .59516 .43639 .60045 .44597 .59759 .44042 .59227 Mtetra
.44042 .59227 .44597 .59759 .45558 .59471 .45005 .58938 Mtetra
.45005 .58938 .45558 .59471 .46523 .59183 .45972 .58648 Mtetra
.45972 .58648 .46523 .59183 .47492 .58893 .46943 .58356 Mtetra
.46943 .58356 .47492 .58893 .48463 .58603 .47917 .58064 Mtetra
.47917 .58064 .48463 .58603 .49439 .58311 .48895 .57771 Mtetra
.48895 .57771 .49439 .58311 .50418 .58019 .49876 .57476 Mtetra
.49876 .57476 .50418 .58019 .514 .57725 .5086 .57181 Mtetra
.5086 .57181 .514 .57725 .52386 .57431 .51849 .56884 Mtetra
.51849 .56884 .52386 .57431 .53375 .57135 .5284 .56586 Mtetra
.5284 .56586 .53375 .57135 .54368 .56838 .53836 .56288 Mtetra
.53836 .56288 .54368 .56838 .55365 .5654 .54835 .55988 Mtetra
.54835 .55988 .55365 .5654 .56365 .56241 .55837 .55687 Mtetra
.55837 .55687 .56365 .56241 .57369 .55941 .56843 .55385 Mtetra
.56843 .55385 .57369 .55941 .58376 .5564 .57853 .55082 Mtetra
.57853 .55082 .58376 .5564 .59387 .55338 .58867 .54777 Mtetra
.58867 .54777 .59387 .55338 .60402 .55035 .59884 .54472 Mtetra
.59884 .54472 .60402 .55035 .61421 .5473 .60905 .54166 Mtetra
.60905 .54166 .61421 .5473 .62443 .54425 .6193 .53858 Mtetra
.6193 .53858 .62443 .54425 .63469 .54118 .62958 .53549 Mtetra
.62958 .53549 .63469 .54118 .64498 .53811 .63991 .53239 Mtetra
.63991 .53239 .64498 .53811 .65532 .53502 .65027 .52928 Mtetra
.65027 .52928 .65532 .53502 .66569 .53192 .66067 .52616 Mtetra
.66067 .52616 .66569 .53192 .6761 .52881 .6711 .52303 Mtetra
.6711 .52303 .6761 .52881 .68655 .52568 .68158 .51989 Mtetra
.68158 .51989 .68655 .52568 .69704 .52255 .6921 .51673 Mtetra
.6921 .51673 .69704 .52255 .70757 .5194 .70265 .51356 Mtetra
.70265 .51356 .70757 .5194 .71814 .51624 .71324 .51038 Mtetra
.71324 .51038 .71814 .51624 .72874 .51307 .72388 .50719 Mtetra
.72388 .50719 .72874 .51307 .73939 .50989 .73455 .50399 Mtetra
.73455 .50399 .73939 .50989 .75008 .5067 .74527 .50077 Mtetra
.74527 .50077 .75008 .5067 .7608 .50349 .75602 .49754 Mtetra
.75602 .49754 .7608 .50349 .77157 .50027 .76681 .4943 Mtetra
.76681 .4943 .77157 .50027 .78237 .49704 .77765 .49105 Mtetra
.77765 .49105 .78237 .49704 .79322 .4938 .78852 .48779 Mtetra
.78852 .48779 .79322 .4938 .80411 .49055 .79944 .48451 Mtetra
.79944 .48451 .80411 .49055 .81504 .48728 .8104 .48122 Mtetra
.8104 .48122 .81504 .48728 .82601 .484 .8214 .47792 Mtetra
.8214 .47792 .82601 .484 .83702 .48071 .83244 .4746 Mtetra
.83244 .4746 .83702 .48071 .84808 .47741 .84353 .47128 Mtetra
.84353 .47128 .84808 .47741 .85917 .47409 .85465 .46794 Mtetra
.85465 .46794 .85917 .47409 .87031 .47076 .86582 .46458 Mtetra
.86582 .46458 .87031 .47076 .88149 .46742 .87704 .46122 Mtetra
.87704 .46122 .88149 .46742 .89272 .46407 .88829 .45784 Mtetra
.88829 .45784 .89272 .46407 .90398 .4607 .89959 .45445 Mtetra
.89959 .45445 .90398 .4607 .91529 .45732 .91093 .45104 Mtetra
.91093 .45104 .91529 .45732 .92665 .45393 .92232 .44763 Mtetra
.31232 .62385 .31818 .62896 .32738 .6262 .32155 .62107 Mtetra
.32155 .62107 .32738 .6262 .33662 .62343 .33081 .61828 Mtetra
.33081 .61828 .33662 .62343 .34589 .62064 .3401 .61548 Mtetra
.3401 .61548 .34589 .62064 .3552 .61785 .34942 .61267 Mtetra
.34942 .61267 .3552 .61785 .36453 .61505 .35878 .60985 Mtetra
.35878 .60985 .36453 .61505 .3739 .61224 .36817 .60702 Mtetra
.36817 .60702 .3739 .61224 .3833 .60942 .37759 .60418 Mtetra
.37759 .60418 .3833 .60942 .39274 .60658 .38704 .60133 Mtetra
.38704 .60133 .39274 .60658 .40221 .60374 .39653 .59847 Mtetra
.39653 .59847 .40221 .60374 .41171 .60089 .40606 .5956 Mtetra
.40606 .5956 .41171 .60089 .42124 .59803 .41561 .59272 Mtetra
.41561 .59272 .42124 .59803 .43081 .59516 .4252 .58983 Mtetra
.4252 .58983 .43081 .59516 .44042 .59227 .43483 .58692 Mtetra
.43483 .58692 .44042 .59227 .45005 .58938 .44449 .58401 Mtetra
.44449 .58401 .45005 .58938 .45972 .58648 .45418 .58109 Mtetra
.45418 .58109 .45972 .58648 .46943 .58356 .46391 .57816 Mtetra
.46391 .57816 .46943 .58356 .47917 .58064 .47367 .57521 Mtetra
.47367 .57521 .47917 .58064 .48895 .57771 .48347 .57226 Mtetra
.48347 .57226 .48895 .57771 .49876 .57476 .4933 .5693 Mtetra
.4933 .5693 .49876 .57476 .5086 .57181 .50317 .56632 Mtetra
.50317 .56632 .5086 .57181 .51849 .56884 .51308 .56334 Mtetra
.51308 .56334 .51849 .56884 .5284 .56586 .52302 .56034 Mtetra
.52302 .56034 .5284 .56586 .53836 .56288 .533 .55733 Mtetra
.533 .55733 .53836 .56288 .54835 .55988 .54301 .55431 Mtetra
.54301 .55431 .54835 .55988 .55837 .55687 .55306 .55128 Mtetra
.55306 .55128 .55837 .55687 .56843 .55385 .56314 .54824 Mtetra
.56314 .54824 .56843 .55385 .57853 .55082 .57327 .54519 Mtetra
.57327 .54519 .57853 .55082 .58867 .54777 .58343 .54213 Mtetra
.58343 .54213 .58867 .54777 .59884 .54472 .59363 .53905 Mtetra
.59363 .53905 .59884 .54472 .60905 .54166 .60386 .53597 Mtetra
.60386 .53597 .60905 .54166 .6193 .53858 .61413 .53287 Mtetra
.61413 .53287 .6193 .53858 .62958 .53549 .62444 .52976 Mtetra
.62444 .52976 .62958 .53549 .63991 .53239 .63479 .52664 Mtetra
.63479 .52664 .63991 .53239 .65027 .52928 .64518 .52351 Mtetra
.64518 .52351 .65027 .52928 .66067 .52616 .6556 .52037 Mtetra
.6556 .52037 .66067 .52616 .6711 .52303 .66607 .51722 Mtetra
.66607 .51722 .6711 .52303 .68158 .51989 .67657 .51405 Mtetra
.67657 .51405 .68158 .51989 .6921 .51673 .68711 .51087 Mtetra
.68711 .51087 .6921 .51673 .70265 .51356 .6977 .50768 Mtetra
.6977 .50768 .70265 .51356 .71324 .51038 .70832 .50448 Mtetra
.70832 .50448 .71324 .51038 .72388 .50719 .71898 .50127 Mtetra
.71898 .50127 .72388 .50719 .73455 .50399 .72968 .49804 Mtetra
.72968 .49804 .73455 .50399 .74527 .50077 .74042 .4948 Mtetra
.74042 .4948 .74527 .50077 .75602 .49754 .7512 .49155 Mtetra
.7512 .49155 .75602 .49754 .76681 .4943 .76203 .48829 Mtetra
.76203 .48829 .76681 .4943 .77765 .49105 .77289 .48501 Mtetra
.77289 .48501 .77765 .49105 .78852 .48779 .7838 .48173 Mtetra
.7838 .48173 .78852 .48779 .79944 .48451 .79474 .47843 Mtetra
.79474 .47843 .79944 .48451 .8104 .48122 .80573 .47511 Mtetra
.80573 .47511 .8104 .48122 .8214 .47792 .81676 .47179 Mtetra
.81676 .47179 .8214 .47792 .83244 .4746 .82783 .46845 Mtetra
.82783 .46845 .83244 .4746 .84353 .47128 .83895 .4651 Mtetra
.83895 .4651 .84353 .47128 .85465 .46794 .85011 .46174 Mtetra
.85011 .46174 .85465 .46794 .86582 .46458 .86131 .45836 Mtetra
.86131 .45836 .86582 .46458 .87704 .46122 .87255 .45497 Mtetra
.87255 .45497 .87704 .46122 .88829 .45784 .88384 .45157 Mtetra
.88384 .45157 .88829 .45784 .89959 .45445 .89517 .44815 Mtetra
.89517 .44815 .89959 .45445 .91093 .45104 .90654 .44472 Mtetra
.90654 .44472 .91093 .45104 .92232 .44763 .91796 .44128 Mtetra
.30643 .61871 .31232 .62385 .32155 .62107 .31568 .61591 Mtetra
.31568 .61591 .32155 .62107 .33081 .61828 .32495 .6131 Mtetra
.32495 .6131 .33081 .61828 .3401 .61548 .33427 .61028 Mtetra
.33427 .61028 .3401 .61548 .34942 .61267 .34361 .60746 Mtetra
.34361 .60746 .34942 .61267 .35878 .60985 .35299 .60462 Mtetra
.35299 .60462 .35878 .60985 .36817 .60702 .36239 .60177 Mtetra
.36239 .60177 .36817 .60702 .37759 .60418 .37184 .59891 Mtetra
.37184 .59891 .37759 .60418 .38704 .60133 .38131 .59604 Mtetra
.38131 .59604 .38704 .60133 .39653 .59847 .39082 .59316 Mtetra
.39082 .59316 .39653 .59847 .40606 .5956 .40037 .59027 Mtetra
.40037 .59027 .40606 .5956 .41561 .59272 .40995 .58737 Mtetra
.40995 .58737 .41561 .59272 .4252 .58983 .41956 .58446 Mtetra
.41956 .58446 .4252 .58983 .43483 .58692 .4292 .58154 Mtetra
.4292 .58154 .43483 .58692 .44449 .58401 .43888 .57861 Mtetra
.43888 .57861 .44449 .58401 .45418 .58109 .4486 .57567 Mtetra
.4486 .57567 .45418 .58109 .46391 .57816 .45835 .57272 Mtetra
.45835 .57272 .46391 .57816 .47367 .57521 .46814 .56975 Mtetra
.46814 .56975 .47367 .57521 .48347 .57226 .47796 .56678 Mtetra
.47796 .56678 .48347 .57226 .4933 .5693 .48781 .5638 Mtetra
.48781 .5638 .4933 .5693 .50317 .56632 .49771 .5608 Mtetra
.49771 .5608 .50317 .56632 .51308 .56334 .50763 .55779 Mtetra
.50763 .55779 .51308 .56334 .52302 .56034 .5176 .55478 Mtetra
.5176 .55478 .52302 .56034 .533 .55733 .5276 .55175 Mtetra
.5276 .55175 .533 .55733 .54301 .55431 .53764 .54871 Mtetra
.53764 .54871 .54301 .55431 .55306 .55128 .54771 .54566 Mtetra
.54771 .54566 .55306 .55128 .56314 .54824 .55782 .5426 Mtetra
.55782 .5426 .56314 .54824 .57327 .54519 .56797 .53953 Mtetra
.56797 .53953 .57327 .54519 .58343 .54213 .57815 .53644 Mtetra
.57815 .53644 .58343 .54213 .59363 .53905 .58837 .53335 Mtetra
.58837 .53335 .59363 .53905 .60386 .53597 .59864 .53024 Mtetra
.59864 .53024 .60386 .53597 .61413 .53287 .60893 .52712 Mtetra
.60893 .52712 .61413 .53287 .62444 .52976 .61927 .524 Mtetra
.61927 .524 .62444 .52976 .63479 .52664 .62964 .52085 Mtetra
.62964 .52085 .63479 .52664 .64518 .52351 .64006 .5177 Mtetra
.64006 .5177 .64518 .52351 .6556 .52037 .65051 .51454 Mtetra
.65051 .51454 .6556 .52037 .66607 .51722 .661 .51136 Mtetra
.661 .51136 .66607 .51722 .67657 .51405 .67153 .50817 Mtetra
.67153 .50817 .67657 .51405 .68711 .51087 .6821 .50497 Mtetra
.6821 .50497 .68711 .51087 .6977 .50768 .69271 .50176 Mtetra
.69271 .50176 .6977 .50768 .70832 .50448 .70336 .49854 Mtetra
.70336 .49854 .70832 .50448 .71898 .50127 .71405 .4953 Mtetra
.71405 .4953 .71898 .50127 .72968 .49804 .72477 .49205 Mtetra
.72477 .49205 .72968 .49804 .74042 .4948 .73554 .48879 Mtetra
.73554 .48879 .74042 .4948 .7512 .49155 .74636 .48552 Mtetra
.74636 .48552 .7512 .49155 .76203 .48829 .75721 .48223 Mtetra
.75721 .48223 .76203 .48829 .77289 .48501 .7681 .47893 Mtetra
.7681 .47893 .77289 .48501 .7838 .48173 .77903 .47562 Mtetra
.77903 .47562 .7838 .48173 .79474 .47843 .79001 .4723 Mtetra
.79001 .4723 .79474 .47843 .80573 .47511 .80103 .46897 Mtetra
.80103 .46897 .80573 .47511 .81676 .47179 .81209 .46562 Mtetra
.81209 .46562 .81676 .47179 .82783 .46845 .82319 .46226 Mtetra
.82319 .46226 .82783 .46845 .83895 .4651 .83434 .45888 Mtetra
.83434 .45888 .83895 .4651 .85011 .46174 .84552 .45549 Mtetra
.84552 .45549 .85011 .46174 .86131 .45836 .85676 .45209 Mtetra
.85676 .45209 .86131 .45836 .87255 .45497 .86803 .44868 Mtetra
.86803 .44868 .87255 .45497 .88384 .45157 .87935 .44525 Mtetra
.87935 .44525 .88384 .45157 .89517 .44815 .89071 .44181 Mtetra
.89071 .44181 .89517 .44815 .90654 .44472 .90212 .43836 Mtetra
.90212 .43836 .90654 .44472 .91796 .44128 .91357 .43489 Mtetra
.3005 .61354 .30643 .61871 .31568 .61591 .30977 .61072 Mtetra
.30977 .61072 .31568 .61591 .32495 .6131 .31906 .60789 Mtetra
.31906 .60789 .32495 .6131 .33427 .61028 .32839 .60505 Mtetra
.32839 .60505 .33427 .61028 .34361 .60746 .33776 .60221 Mtetra
.33776 .60221 .34361 .60746 .35299 .60462 .34715 .59935 Mtetra
.34715 .59935 .35299 .60462 .36239 .60177 .35658 .59648 Mtetra
.35658 .59648 .36239 .60177 .37184 .59891 .36605 .5936 Mtetra
.36605 .5936 .37184 .59891 .38131 .59604 .37555 .59072 Mtetra
.37555 .59072 .38131 .59604 .39082 .59316 .38508 .58782 Mtetra
.38508 .58782 .39082 .59316 .40037 .59027 .39464 .58491 Mtetra
.39464 .58491 .40037 .59027 .40995 .58737 .40424 .58199 Mtetra
.40424 .58199 .40995 .58737 .41956 .58446 .41387 .57906 Mtetra
.41387 .57906 .41956 .58446 .4292 .58154 .42354 .57612 Mtetra
.42354 .57612 .4292 .58154 .43888 .57861 .43324 .57317 Mtetra
.43324 .57317 .43888 .57861 .4486 .57567 .44298 .57021 Mtetra
.44298 .57021 .4486 .57567 .45835 .57272 .45276 .56724 Mtetra
.45276 .56724 .45835 .57272 .46814 .56975 .46256 .56426 Mtetra
.46256 .56426 .46814 .56975 .47796 .56678 .47241 .56126 Mtetra
.47241 .56126 .47796 .56678 .48781 .5638 .48229 .55826 Mtetra
.48229 .55826 .48781 .5638 .49771 .5608 .4922 .55524 Mtetra
.4922 .55524 .49771 .5608 .50763 .55779 .50215 .55222 Mtetra
.50215 .55222 .50763 .55779 .5176 .55478 .51214 .54918 Mtetra
.51214 .54918 .5176 .55478 .5276 .55175 .52217 .54613 Mtetra
.52217 .54613 .5276 .55175 .53764 .54871 .53223 .54307 Mtetra
.53223 .54307 .53764 .54871 .54771 .54566 .54232 .54 Mtetra
.54232 .54 .54771 .54566 .55782 .5426 .55246 .53692 Mtetra
.55246 .53692 .55782 .5426 .56797 .53953 .56263 .53383 Mtetra
.56263 .53383 .56797 .53953 .57815 .53644 .57284 .53072 Mtetra
.57284 .53072 .57815 .53644 .58837 .53335 .58309 .52761 Mtetra
.58309 .52761 .58837 .53335 .59864 .53024 .59337 .52448 Mtetra
.59337 .52448 .59864 .53024 .60893 .52712 .6037 .52134 Mtetra
.6037 .52134 .60893 .52712 .61927 .524 .61406 .51819 Mtetra
.61406 .51819 .61927 .524 .62964 .52085 .62446 .51503 Mtetra
.62446 .51503 .62964 .52085 .64006 .5177 .6349 .51185 Mtetra
.6349 .51185 .64006 .5177 .65051 .51454 .64538 .50866 Mtetra
.64538 .50866 .65051 .51454 .661 .51136 .65589 .50547 Mtetra
.65589 .50547 .661 .51136 .67153 .50817 .66645 .50226 Mtetra
.66645 .50226 .67153 .50817 .6821 .50497 .67705 .49903 Mtetra
.67705 .49903 .6821 .50497 .69271 .50176 .68768 .4958 Mtetra
.68768 .4958 .69271 .50176 .70336 .49854 .69836 .49255 Mtetra
.69836 .49255 .70336 .49854 .71405 .4953 .70908 .48929 Mtetra
.70908 .48929 .71405 .4953 .72477 .49205 .71984 .48602 Mtetra
.71984 .48602 .72477 .49205 .73554 .48879 .73063 .48274 Mtetra
.73063 .48274 .73554 .48879 .74636 .48552 .74147 .47944 Mtetra
.74147 .47944 .74636 .48552 .75721 .48223 .75235 .47613 Mtetra
.75235 .47613 .75721 .48223 .7681 .47893 .76328 .47281 Mtetra
.76328 .47281 .7681 .47893 .77903 .47562 .77424 .46948 Mtetra
.77424 .46948 .77903 .47562 .79001 .4723 .78524 .46613 Mtetra
.78524 .46613 .79001 .4723 .80103 .46897 .79629 .46277 Mtetra
.79629 .46277 .80103 .46897 .81209 .46562 .80738 .4594 Mtetra
.80738 .4594 .81209 .46562 .82319 .46226 .81852 .45602 Mtetra
.81852 .45602 .82319 .46226 .83434 .45888 .82969 .45262 Mtetra
.82969 .45262 .83434 .45888 .84552 .45549 .84091 .44921 Mtetra
.84091 .44921 .84552 .45549 .85676 .45209 .85217 .44578 Mtetra
.85217 .44578 .85676 .45209 .86803 .44868 .86348 .44234 Mtetra
.86348 .44234 .86803 .44868 .87935 .44525 .87483 .43889 Mtetra
.87483 .43889 .87935 .44525 .89071 .44181 .88623 .43543 Mtetra
.88623 .43543 .89071 .44181 .90212 .43836 .89766 .43195 Mtetra
.89766 .43195 .90212 .43836 .91357 .43489 .90915 .42846 Mtetra
.29453 .60833 .3005 .61354 .30977 .61072 .30382 .60549 Mtetra
.30382 .60549 .30977 .61072 .31906 .60789 .31314 .60265 Mtetra
.31314 .60265 .31906 .60789 .32839 .60505 .32249 .59979 Mtetra
.32249 .59979 .32839 .60505 .33776 .60221 .33187 .59692 Mtetra
.33187 .59692 .33776 .60221 .34715 .59935 .34129 .59405 Mtetra
.34129 .59405 .34715 .59935 .35658 .59648 .35074 .59116 Mtetra
.35074 .59116 .35658 .59648 .36605 .5936 .36022 .58826 Mtetra
.36022 .58826 .36605 .5936 .37555 .59072 .36974 .58536 Mtetra
.36974 .58536 .37555 .59072 .38508 .58782 .37929 .58244 Mtetra
.37929 .58244 .38508 .58782 .39464 .58491 .38888 .57951 Mtetra
.38888 .57951 .39464 .58491 .40424 .58199 .3985 .57657 Mtetra
.3985 .57657 .40424 .58199 .41387 .57906 .40815 .57363 Mtetra
.40815 .57363 .41387 .57906 .42354 .57612 .41784 .57067 Mtetra
.41784 .57067 .42354 .57612 .43324 .57317 .42757 .5677 Mtetra
.42757 .5677 .43324 .57317 .44298 .57021 .43733 .56471 Mtetra
.43733 .56471 .44298 .57021 .45276 .56724 .44712 .56172 Mtetra
.44712 .56172 .45276 .56724 .46256 .56426 .45695 .55872 Mtetra
.45695 .55872 .46256 .56426 .47241 .56126 .46682 .55571 Mtetra
.46682 .55571 .47241 .56126 .48229 .55826 .47672 .55268 Mtetra
.47672 .55268 .48229 .55826 .4922 .55524 .48666 .54965 Mtetra
.48666 .54965 .4922 .55524 .50215 .55222 .49664 .5466 Mtetra
.49664 .5466 .50215 .55222 .51214 .54918 .50665 .54354 Mtetra
.50665 .54354 .51214 .54918 .52217 .54613 .5167 .54047 Mtetra
.5167 .54047 .52217 .54613 .53223 .54307 .52678 .53739 Mtetra
.52678 .53739 .53223 .54307 .54232 .54 .5369 .5343 Mtetra
.5369 .5343 .54232 .54 .55246 .53692 .54706 .5312 Mtetra
.54706 .5312 .55246 .53692 .56263 .53383 .55726 .52809 Mtetra
.55726 .52809 .56263 .53383 .57284 .53072 .56749 .52496 Mtetra
.56749 .52496 .57284 .53072 .58309 .52761 .57777 .52182 Mtetra
.57777 .52182 .58309 .52761 .59337 .52448 .58808 .51867 Mtetra
.58808 .51867 .59337 .52448 .6037 .52134 .59843 .51551 Mtetra
.59843 .51551 .6037 .52134 .61406 .51819 .60881 .51234 Mtetra
.60881 .51234 .61406 .51819 .62446 .51503 .61924 .50916 Mtetra
.61924 .50916 .62446 .51503 .6349 .51185 .62971 .50596 Mtetra
.62971 .50596 .6349 .51185 .64538 .50866 .64021 .50275 Mtetra
.64021 .50275 .64538 .50866 .65589 .50547 .65075 .49953 Mtetra
.65075 .49953 .65589 .50547 .66645 .50226 .66134 .4963 Mtetra
.66134 .4963 .66645 .50226 .67705 .49903 .67196 .49305 Mtetra
.67196 .49305 .67705 .49903 .68768 .4958 .68263 .4898 Mtetra
.68263 .4898 .68768 .4958 .69836 .49255 .69333 .48653 Mtetra
.69333 .48653 .69836 .49255 .70908 .48929 .70408 .48325 Mtetra
.70408 .48325 .70908 .48929 .71984 .48602 .71486 .47995 Mtetra
.71486 .47995 .71984 .48602 .73063 .48274 .72569 .47664 Mtetra
.72569 .47664 .73063 .48274 .74147 .47944 .73656 .47333 Mtetra
.73656 .47333 .74147 .47944 .75235 .47613 .74746 .46999 Mtetra
.74746 .46999 .75235 .47613 .76328 .47281 .75842 .46665 Mtetra
.75842 .46665 .76328 .47281 .77424 .46948 .76941 .46329 Mtetra
.76941 .46329 .77424 .46948 .78524 .46613 .78044 .45992 Mtetra
.78044 .45992 .78524 .46613 .79629 .46277 .79152 .45654 Mtetra
.79152 .45654 .79629 .46277 .80738 .4594 .80264 .45314 Mtetra
.80264 .45314 .80738 .4594 .81852 .45602 .81381 .44973 Mtetra
.81381 .44973 .81852 .45602 .82969 .45262 .82501 .44631 Mtetra
.82501 .44631 .82969 .45262 .84091 .44921 .83626 .44287 Mtetra
.83626 .44287 .84091 .44921 .85217 .44578 .84756 .43942 Mtetra
.84756 .43942 .85217 .44578 .86348 .44234 .8589 .43596 Mtetra
.8589 .43596 .86348 .44234 .87483 .43889 .87028 .43248 Mtetra
.87028 .43248 .87483 .43889 .88623 .43543 .88171 .42899 Mtetra
.88171 .42899 .88623 .43543 .89766 .43195 .89318 .42549 Mtetra
.89318 .42549 .89766 .43195 .90915 .42846 .90469 .42197 Mtetra
.28853 .60308 .29453 .60833 .30382 .60549 .29783 .60023 Mtetra
.29783 .60023 .30382 .60549 .31314 .60265 .30717 .59737 Mtetra
.30717 .59737 .31314 .60265 .32249 .59979 .31654 .59449 Mtetra
.31654 .59449 .32249 .59979 .33187 .59692 .32594 .59161 Mtetra
.32594 .59161 .33187 .59692 .34129 .59405 .33538 .58871 Mtetra
.33538 .58871 .34129 .59405 .35074 .59116 .34485 .58581 Mtetra
.34485 .58581 .35074 .59116 .36022 .58826 .35435 .58289 Mtetra
.35435 .58289 .36022 .58826 .36974 .58536 .36389 .57996 Mtetra
.36389 .57996 .36974 .58536 .37929 .58244 .37347 .57703 Mtetra
.37347 .57703 .37929 .58244 .38888 .57951 .38307 .57408 Mtetra
.38307 .57408 .38888 .57951 .3985 .57657 .39272 .57112 Mtetra
.39272 .57112 .3985 .57657 .40815 .57363 .40239 .56815 Mtetra
.40239 .56815 .40815 .57363 .41784 .57067 .41211 .56517 Mtetra
.41211 .56517 .41784 .57067 .42757 .5677 .42185 .56218 Mtetra
.42185 .56218 .42757 .5677 .43733 .56471 .43163 .55918 Mtetra
.43163 .55918 .43733 .56471 .44712 .56172 .44145 .55617 Mtetra
.44145 .55617 .44712 .56172 .45695 .55872 .45131 .55315 Mtetra
.45131 .55315 .45695 .55872 .46682 .55571 .4612 .55012 Mtetra
.4612 .55012 .46682 .55571 .47672 .55268 .47112 .54707 Mtetra
.47112 .54707 .47672 .55268 .48666 .54965 .48108 .54401 Mtetra
.48108 .54401 .48666 .54965 .49664 .5466 .49108 .54095 Mtetra
.49108 .54095 .49664 .5466 .50665 .54354 .50112 .53787 Mtetra
.50112 .53787 .50665 .54354 .5167 .54047 .51119 .53478 Mtetra
.51119 .53478 .5167 .54047 .52678 .53739 .5213 .53168 Mtetra
.5213 .53168 .52678 .53739 .5369 .5343 .53144 .52857 Mtetra
.53144 .52857 .5369 .5343 .54706 .5312 .54163 .52544 Mtetra
.54163 .52544 .54706 .5312 .55726 .52809 .55185 .52231 Mtetra
.55185 .52231 .55726 .52809 .56749 .52496 .56211 .51916 Mtetra
.56211 .51916 .56749 .52496 .57777 .52182 .57241 .516 Mtetra
.57241 .516 .57777 .52182 .58808 .51867 .58274 .51283 Mtetra
.58274 .51283 .58808 .51867 .59843 .51551 .59312 .50965 Mtetra
.59312 .50965 .59843 .51551 .60881 .51234 .60353 .50645 Mtetra
.60353 .50645 .60881 .51234 .61924 .50916 .61398 .50324 Mtetra
.61398 .50324 .61924 .50916 .62971 .50596 .62448 .50003 Mtetra
.62448 .50003 .62971 .50596 .64021 .50275 .63501 .4968 Mtetra
.63501 .4968 .64021 .50275 .65075 .49953 .64558 .49355 Mtetra
.64558 .49355 .65075 .49953 .66134 .4963 .65619 .4903 Mtetra
.65619 .4903 .66134 .4963 .67196 .49305 .66684 .48703 Mtetra
.66684 .48703 .67196 .49305 .68263 .4898 .67753 .48375 Mtetra
.67753 .48375 .68263 .4898 .69333 .48653 .68826 .48046 Mtetra
.68826 .48046 .69333 .48653 .70408 .48325 .69904 .47715 Mtetra
.69904 .47715 .70408 .48325 .71486 .47995 .70985 .47384 Mtetra
.70985 .47384 .71486 .47995 .72569 .47664 .72071 .47051 Mtetra
.72071 .47051 .72569 .47664 .73656 .47333 .7316 .46716 Mtetra
.7316 .46716 .73656 .47333 .74746 .46999 .74254 .46381 Mtetra
.74254 .46381 .74746 .46999 .75842 .46665 .75352 .46044 Mtetra
.75352 .46044 .75842 .46665 .76941 .46329 .76455 .45706 Mtetra
.76455 .45706 .76941 .46329 .78044 .45992 .77561 .45366 Mtetra
.77561 .45366 .78044 .45992 .79152 .45654 .78672 .45026 Mtetra
.78672 .45026 .79152 .45654 .80264 .45314 .79787 .44684 Mtetra
.79787 .44684 .80264 .45314 .81381 .44973 .80906 .4434 Mtetra
.80906 .4434 .81381 .44973 .82501 .44631 .8203 .43995 Mtetra
.8203 .43995 .82501 .44631 .83626 .44287 .83158 .43649 Mtetra
.83158 .43649 .83626 .44287 .84756 .43942 .84291 .43302 Mtetra
.84291 .43302 .84756 .43942 .8589 .43596 .85428 .42953 Mtetra
.85428 .42953 .8589 .43596 .87028 .43248 .86569 .42603 Mtetra
.86569 .42603 .87028 .43248 .88171 .42899 .87715 .42251 Mtetra
.87715 .42251 .88171 .42899 .89318 .42549 .88866 .41899 Mtetra
.88866 .41899 .89318 .42549 .90469 .42197 .90021 .41544 Mtetra
.28248 .59781 .28853 .60308 .29783 .60023 .2918 .59493 Mtetra
.2918 .59493 .29783 .60023 .30717 .59737 .30116 .59205 Mtetra
.30116 .59205 .30717 .59737 .31654 .59449 .31055 .58916 Mtetra
.31055 .58916 .31654 .59449 .32594 .59161 .31998 .58625 Mtetra
.31998 .58625 .32594 .59161 .33538 .58871 .32943 .58334 Mtetra
.32943 .58334 .33538 .58871 .34485 .58581 .33892 .58041 Mtetra
.33892 .58041 .34485 .58581 .35435 .58289 .34845 .57748 Mtetra
.34845 .57748 .35435 .58289 .36389 .57996 .35801 .57453 Mtetra
.35801 .57453 .36389 .57996 .37347 .57703 .3676 .57158 Mtetra
.3676 .57158 .37347 .57703 .38307 .57408 .37723 .56861 Mtetra
.37723 .56861 .38307 .57408 .39272 .57112 .3869 .56563 Mtetra
.3869 .56563 .39272 .57112 .40239 .56815 .3966 .56264 Mtetra
.3966 .56264 .40239 .56815 .41211 .56517 .40633 .55965 Mtetra
.40633 .55965 .41211 .56517 .42185 .56218 .4161 .55664 Mtetra
.4161 .55664 .42185 .56218 .43163 .55918 .4259 .55361 Mtetra
.4259 .55361 .43163 .55918 .44145 .55617 .43574 .55058 Mtetra
.43574 .55058 .44145 .55617 .45131 .55315 .44562 .54754 Mtetra
.44562 .54754 .45131 .55315 .4612 .55012 .45553 .54449 Mtetra
.45553 .54449 .4612 .55012 .47112 .54707 .46548 .54142 Mtetra
.46548 .54142 .47112 .54707 .48108 .54401 .47547 .53834 Mtetra
.47547 .53834 .48108 .54401 .49108 .54095 .48549 .53526 Mtetra
.48549 .53526 .49108 .54095 .50112 .53787 .49555 .53216 Mtetra
.49555 .53216 .50112 .53787 .51119 .53478 .50564 .52905 Mtetra
.50564 .52905 .51119 .53478 .5213 .53168 .51578 .52592 Mtetra
.51578 .52592 .5213 .53168 .53144 .52857 .52595 .52279 Mtetra
.52595 .52279 .53144 .52857 .54163 .52544 .53616 .51964 Mtetra
.53616 .51964 .54163 .52544 .55185 .52231 .5464 .51649 Mtetra
.5464 .51649 .55185 .52231 .56211 .51916 .55669 .51332 Mtetra
.55669 .51332 .56211 .51916 .57241 .516 .56701 .51014 Mtetra
.56701 .51014 .57241 .516 .58274 .51283 .57737 .50694 Mtetra
.57737 .50694 .58274 .51283 .59312 .50965 .58777 .50374 Mtetra
.58777 .50374 .59312 .50965 .60353 .50645 .59821 .50052 Mtetra
.59821 .50052 .60353 .50645 .61398 .50324 .60869 .49729 Mtetra
.60869 .49729 .61398 .50324 .62448 .50003 .61921 .49405 Mtetra
.61921 .49405 .62448 .50003 .63501 .4968 .62977 .4908 Mtetra
.62977 .4908 .63501 .4968 .64558 .49355 .64037 .48753 Mtetra
.64037 .48753 .64558 .49355 .65619 .4903 .65101 .48426 Mtetra
.65101 .48426 .65619 .4903 .66684 .48703 .66168 .48097 Mtetra
.66168 .48097 .66684 .48703 .67753 .48375 .6724 .47766 Mtetra
.6724 .47766 .67753 .48375 .68826 .48046 .68316 .47435 Mtetra
.68316 .47435 .68826 .48046 .69904 .47715 .69396 .47102 Mtetra
.69396 .47102 .69904 .47715 .70985 .47384 .70481 .46768 Mtetra
.70481 .46768 .70985 .47384 .72071 .47051 .71569 .46433 Mtetra
.71569 .46433 .72071 .47051 .7316 .46716 .72662 .46096 Mtetra
.72662 .46096 .7316 .46716 .74254 .46381 .73758 .45758 Mtetra
.73758 .45758 .74254 .46381 .75352 .46044 .74859 .45419 Mtetra
.74859 .45419 .75352 .46044 .76455 .45706 .75965 .45078 Mtetra
.75965 .45078 .76455 .45706 .77561 .45366 .77074 .44736 Mtetra
.77074 .44736 .77561 .45366 .78672 .45026 .78188 .44393 Mtetra
.78188 .44393 .78672 .45026 .79787 .44684 .79306 .44049 Mtetra
.79306 .44049 .79787 .44684 .80906 .4434 .80429 .43703 Mtetra
.80429 .43703 .80906 .4434 .8203 .43995 .81556 .43355 Mtetra
.81556 .43355 .8203 .43995 .83158 .43649 .82687 .43007 Mtetra
.82687 .43007 .83158 .43649 .84291 .43302 .83823 .42657 Mtetra
.83823 .42657 .84291 .43302 .85428 .42953 .84963 .42306 Mtetra
.84963 .42306 .85428 .42953 .86569 .42603 .86108 .41953 Mtetra
.86108 .41953 .86569 .42603 .87715 .42251 .87257 .41599 Mtetra
.87257 .41599 .87715 .42251 .88866 .41899 .8841 .41243 Mtetra
.8841 .41243 .88866 .41899 .90021 .41544 .89569 .40886 Mtetra
.27639 .59249 .28248 .59781 .2918 .59493 .28574 .5896 Mtetra
.28574 .5896 .2918 .59493 .30116 .59205 .29511 .5867 Mtetra
.29511 .5867 .30116 .59205 .31055 .58916 .30452 .58379 Mtetra
.30452 .58379 .31055 .58916 .31998 .58625 .31397 .58087 Mtetra
.31397 .58087 .31998 .58625 .32943 .58334 .32345 .57793 Mtetra
.32345 .57793 .32943 .58334 .33892 .58041 .33296 .57499 Mtetra
.33296 .57499 .33892 .58041 .34845 .57748 .34251 .57203 Mtetra
.34251 .57203 .34845 .57748 .35801 .57453 .35209 .56907 Mtetra
.35209 .56907 .35801 .57453 .3676 .57158 .3617 .56609 Mtetra
.3617 .56609 .3676 .57158 .37723 .56861 .37135 .56311 Mtetra
.37135 .56311 .37723 .56861 .3869 .56563 .38104 .56011 Mtetra
.38104 .56011 .3869 .56563 .3966 .56264 .39076 .5571 Mtetra
.39076 .5571 .3966 .56264 .40633 .55965 .40052 .55408 Mtetra
.40052 .55408 .40633 .55965 .4161 .55664 .41031 .55105 Mtetra
.41031 .55105 .4161 .55664 .4259 .55361 .42013 .54801 Mtetra
.42013 .54801 .4259 .55361 .43574 .55058 .43 .54496 Mtetra
.43 .54496 .43574 .55058 .44562 .54754 .4399 .54189 Mtetra
.4399 .54189 .44562 .54754 .45553 .54449 .44983 .53882 Mtetra
.44983 .53882 .45553 .54449 .46548 .54142 .4598 .53573 Mtetra
.4598 .53573 .46548 .54142 .47547 .53834 .46981 .53263 Mtetra
.46981 .53263 .47547 .53834 .48549 .53526 .47986 .52952 Mtetra
.47986 .52952 .48549 .53526 .49555 .53216 .48994 .5264 Mtetra
.48994 .5264 .49555 .53216 .50564 .52905 .50006 .52327 Mtetra
.50006 .52327 .50564 .52905 .51578 .52592 .51022 .52013 Mtetra
.51022 .52013 .51578 .52592 .52595 .52279 .52041 .51697 Mtetra
.52041 .51697 .52595 .52279 .53616 .51964 .53065 .51381 Mtetra
.53065 .51381 .53616 .51964 .5464 .51649 .54092 .51063 Mtetra
.54092 .51063 .5464 .51649 .55669 .51332 .55123 .50744 Mtetra
.55123 .50744 .55669 .51332 .56701 .51014 .56158 .50423 Mtetra
.56158 .50423 .56701 .51014 .57737 .50694 .57197 .50102 Mtetra
.57197 .50102 .57737 .50694 .58777 .50374 .58239 .49779 Mtetra
.58239 .49779 .58777 .50374 .59821 .50052 .59286 .49455 Mtetra
.59286 .49455 .59821 .50052 .60869 .49729 .60336 .4913 Mtetra
.60336 .4913 .60869 .49729 .61921 .49405 .61391 .48804 Mtetra
.61391 .48804 .61921 .49405 .62977 .4908 .62449 .48476 Mtetra
.62449 .48476 .62977 .4908 .64037 .48753 .63512 .48147 Mtetra
.63512 .48147 .64037 .48753 .65101 .48426 .64578 .47817 Mtetra
.64578 .47817 .65101 .48426 .66168 .48097 .65649 .47486 Mtetra
.65649 .47486 .66168 .48097 .6724 .47766 .66724 .47153 Mtetra
.66724 .47153 .6724 .47766 .68316 .47435 .67803 .46819 Mtetra
.67803 .46819 .68316 .47435 .69396 .47102 .68886 .46484 Mtetra
.68886 .46484 .69396 .47102 .70481 .46768 .69973 .46148 Mtetra
.69973 .46148 .70481 .46768 .71569 .46433 .71064 .4581 Mtetra
.71064 .4581 .71569 .46433 .72662 .46096 .72159 .45471 Mtetra
.72159 .45471 .72662 .46096 .73758 .45758 .73259 .45131 Mtetra
.73259 .45131 .73758 .45758 .74859 .45419 .74363 .44789 Mtetra
.74363 .44789 .74859 .45419 .75965 .45078 .75471 .44446 Mtetra
.75471 .44446 .75965 .45078 .77074 .44736 .76584 .44102 Mtetra
.76584 .44102 .77074 .44736 .78188 .44393 .77701 .43756 Mtetra
.77701 .43756 .78188 .44393 .79306 .44049 .78822 .43409 Mtetra
.78822 .43409 .79306 .44049 .80429 .43703 .79948 .43061 Mtetra
.79948 .43061 .80429 .43703 .81556 .43355 .81078 .42711 Mtetra
.81078 .42711 .81556 .43355 .82687 .43007 .82212 .4236 Mtetra
.82212 .4236 .82687 .43007 .83823 .42657 .83351 .42007 Mtetra
.83351 .42007 .83823 .42657 .84963 .42306 .84494 .41653 Mtetra
.84494 .41653 .84963 .42306 .86108 .41953 .85642 .41298 Mtetra
.85642 .41298 .86108 .41953 .87257 .41599 .86795 .40941 Mtetra
.86795 .40941 .87257 .41599 .8841 .41243 .87952 .40583 Mtetra
.87952 .40583 .8841 .41243 .89569 .40886 .89113 .40224 Mtetra
.27027 .58715 .27639 .59249 .28574 .5896 .27963 .58424 Mtetra
.27963 .58424 .28574 .5896 .29511 .5867 .28903 .58132 Mtetra
.28903 .58132 .29511 .5867 .30452 .58379 .29846 .57838 Mtetra
.29846 .57838 .30452 .58379 .31397 .58087 .30792 .57544 Mtetra
.30792 .57544 .31397 .58087 .32345 .57793 .31742 .57249 Mtetra
.31742 .57249 .32345 .57793 .33296 .57499 .32696 .56952 Mtetra
.32696 .56952 .33296 .57499 .34251 .57203 .33652 .56655 Mtetra
.33652 .56655 .34251 .57203 .35209 .56907 .34613 .56357 Mtetra
.34613 .56357 .35209 .56907 .3617 .56609 .35576 .56057 Mtetra
.35576 .56057 .3617 .56609 .37135 .56311 .36543 .55756 Mtetra
.36543 .55756 .37135 .56311 .38104 .56011 .37514 .55455 Mtetra
.37514 .55455 .38104 .56011 .39076 .5571 .38488 .55152 Mtetra
.38488 .55152 .39076 .5571 .40052 .55408 .39466 .54848 Mtetra
.39466 .54848 .40052 .55408 .41031 .55105 .40448 .54543 Mtetra
.40448 .54543 .41031 .55105 .42013 .54801 .41432 .54236 Mtetra
.41432 .54236 .42013 .54801 .43 .54496 .42421 .53929 Mtetra
.42421 .53929 .43 .54496 .4399 .54189 .43413 .53621 Mtetra
.43413 .53621 .4399 .54189 .44983 .53882 .44409 .53311 Mtetra
.44409 .53311 .44983 .53882 .4598 .53573 .45409 .53 Mtetra
.45409 .53 .4598 .53573 .46981 .53263 .46412 .52688 Mtetra
.46412 .52688 .46981 .53263 .47986 .52952 .47419 .52375 Mtetra
.47419 .52375 .47986 .52952 .48994 .5264 .4843 .52061 Mtetra
.4843 .52061 .48994 .5264 .50006 .52327 .49444 .51746 Mtetra
.49444 .51746 .50006 .52327 .51022 .52013 .50462 .51429 Mtetra
.50462 .51429 .51022 .52013 .52041 .51697 .51484 .51112 Mtetra
.51484 .51112 .52041 .51697 .53065 .51381 .5251 .50793 Mtetra
.5251 .50793 .53065 .51381 .54092 .51063 .5354 .50473 Mtetra
.5354 .50473 .54092 .51063 .55123 .50744 .54573 .50151 Mtetra
.54573 .50151 .55123 .50744 .56158 .50423 .55611 .49829 Mtetra
.55611 .49829 .56158 .50423 .57197 .50102 .56652 .49505 Mtetra
.56652 .49505 .57197 .50102 .58239 .49779 .57697 .4918 Mtetra
.57697 .4918 .58239 .49779 .59286 .49455 .58747 .48854 Mtetra
.58747 .48854 .59286 .49455 .60336 .4913 .598 .48527 Mtetra
.598 .48527 .60336 .4913 .61391 .48804 .60857 .48198 Mtetra
.60857 .48198 .61391 .48804 .62449 .48476 .61918 .47868 Mtetra
.61918 .47868 .62449 .48476 .63512 .48147 .62983 .47537 Mtetra
.62983 .47537 .63512 .48147 .64578 .47817 .64053 .47205 Mtetra
.64053 .47205 .64578 .47817 .65649 .47486 .65126 .46871 Mtetra
.65126 .46871 .65649 .47486 .66724 .47153 .66204 .46536 Mtetra
.66204 .46536 .66724 .47153 .67803 .46819 .67285 .462 Mtetra
.67285 .462 .67803 .46819 .68886 .46484 .68371 .45862 Mtetra
.68371 .45862 .68886 .46484 .69973 .46148 .69461 .45523 Mtetra
.69461 .45523 .69973 .46148 .71064 .4581 .70555 .45183 Mtetra
.70555 .45183 .71064 .4581 .72159 .45471 .71654 .44842 Mtetra
.71654 .44842 .72159 .45471 .73259 .45131 .72756 .44499 Mtetra
.72756 .44499 .73259 .45131 .74363 .44789 .73863 .44155 Mtetra
.73863 .44155 .74363 .44789 .75471 .44446 .74974 .43809 Mtetra
.74974 .43809 .75471 .44446 .76584 .44102 .7609 .43462 Mtetra
.7609 .43462 .76584 .44102 .77701 .43756 .7721 .43114 Mtetra
.7721 .43114 .77701 .43756 .78822 .43409 .78334 .42765 Mtetra
.78334 .42765 .78822 .43409 .79948 .43061 .79463 .42414 Mtetra
.79463 .42414 .79948 .43061 .81078 .42711 .80596 .42062 Mtetra
.80596 .42062 .81078 .42711 .82212 .4236 .81734 .41708 Mtetra
.81734 .41708 .82212 .4236 .83351 .42007 .82876 .41353 Mtetra
.82876 .41353 .83351 .42007 .84494 .41653 .84023 .40996 Mtetra
.84023 .40996 .84494 .41653 .85642 .41298 .85174 .40639 Mtetra
.85174 .40639 .85642 .41298 .86795 .40941 .8633 .40279 Mtetra
.8633 .40279 .86795 .40941 .87952 .40583 .8749 .39919 Mtetra
.8749 .39919 .87952 .40583 .89113 .40224 .88655 .39556 Mtetra
.2641 .58177 .27027 .58715 .27963 .58424 .27348 .57884 Mtetra
.27348 .57884 .27963 .58424 .28903 .58132 .2829 .57589 Mtetra
.2829 .57589 .28903 .58132 .29846 .57838 .29235 .57294 Mtetra
.29235 .57294 .29846 .57838 .30792 .57544 .30184 .56998 Mtetra
.30184 .56998 .30792 .57544 .31742 .57249 .31136 .56701 Mtetra
.31136 .56701 .31742 .57249 .32696 .56952 .32091 .56403 Mtetra
.32091 .56403 .32696 .56952 .33652 .56655 .3305 .56103 Mtetra
.3305 .56103 .33652 .56655 .34613 .56357 .34012 .55803 Mtetra
.34012 .55803 .34613 .56357 .35576 .56057 .34978 .55501 Mtetra
.34978 .55501 .35576 .56057 .36543 .55756 .35947 .55198 Mtetra
.35947 .55198 .36543 .55756 .37514 .55455 .3692 .54895 Mtetra
.3692 .54895 .37514 .55455 .38488 .55152 .37897 .5459 Mtetra
.37897 .5459 .38488 .55152 .39466 .54848 .38877 .54284 Mtetra
.38877 .54284 .39466 .54848 .40448 .54543 .3986 .53976 Mtetra
.3986 .53976 .40448 .54543 .41432 .54236 .40848 .53668 Mtetra
.40848 .53668 .41432 .54236 .42421 .53929 .41839 .53359 Mtetra
.41839 .53359 .42421 .53929 .43413 .53621 .42833 .53048 Mtetra
.42833 .53048 .43413 .53621 .44409 .53311 .43831 .52737 Mtetra
.43831 .52737 .44409 .53311 .45409 .53 .44833 .52424 Mtetra
.44833 .52424 .45409 .53 .46412 .52688 .45839 .5211 Mtetra
.45839 .5211 .46412 .52688 .47419 .52375 .46848 .51794 Mtetra
.46848 .51794 .47419 .52375 .4843 .52061 .47861 .51478 Mtetra
.47861 .51478 .4843 .52061 .49444 .51746 .48878 .51161 Mtetra
.48878 .51161 .49444 .51746 .50462 .51429 .49899 .50842 Mtetra
.49899 .50842 .50462 .51429 .51484 .51112 .50923 .50522 Mtetra
.50923 .50522 .51484 .51112 .5251 .50793 .51952 .50201 Mtetra
.51952 .50201 .5251 .50793 .5354 .50473 .52984 .49879 Mtetra
.52984 .49879 .5354 .50473 .54573 .50151 .5402 .49555 Mtetra
.5402 .49555 .54573 .50151 .55611 .49829 .5506 .4923 Mtetra
.5506 .4923 .55611 .49829 .56652 .49505 .56104 .48904 Mtetra
.56104 .48904 .56652 .49505 .57697 .4918 .57152 .48577 Mtetra
.57152 .48577 .57697 .4918 .58747 .48854 .58203 .48249 Mtetra
.58203 .48249 .58747 .48854 .598 .48527 .59259 .47919 Mtetra
.59259 .47919 .598 .48527 .60857 .48198 .60319 .47588 Mtetra
.60319 .47588 .60857 .48198 .61918 .47868 .61383 .47256 Mtetra
.61383 .47256 .61918 .47868 .62983 .47537 .62451 .46922 Mtetra
.62451 .46922 .62983 .47537 .64053 .47205 .63523 .46587 Mtetra
.63523 .46587 .64053 .47205 .65126 .46871 .64599 .46251 Mtetra
.64599 .46251 .65126 .46871 .66204 .46536 .6568 .45914 Mtetra
.6568 .45914 .66204 .46536 .67285 .462 .66764 .45575 Mtetra
.66764 .45575 .67285 .462 .68371 .45862 .67853 .45235 Mtetra
.67853 .45235 .68371 .45862 .69461 .45523 .68946 .44894 Mtetra
.68946 .44894 .69461 .45523 .70555 .45183 .70043 .44552 Mtetra
.70043 .44552 .70555 .45183 .71654 .44842 .71144 .44208 Mtetra
.71144 .44208 .71654 .44842 .72756 .44499 .7225 .43862 Mtetra
.7225 .43862 .72756 .44499 .73863 .44155 .7336 .43516 Mtetra
.7336 .43516 .73863 .44155 .74974 .43809 .74474 .43168 Mtetra
.74474 .43168 .74974 .43809 .7609 .43462 .75593 .42819 Mtetra
.75593 .42819 .7609 .43462 .7721 .43114 .76716 .42468 Mtetra
.76716 .42468 .7721 .43114 .78334 .42765 .77843 .42116 Mtetra
.77843 .42116 .78334 .42765 .79463 .42414 .78975 .41762 Mtetra
.78975 .41762 .79463 .42414 .80596 .42062 .80111 .41408 Mtetra
.80111 .41408 .80596 .42062 .81734 .41708 .81252 .41051 Mtetra
.81252 .41051 .81734 .41708 .82876 .41353 .82397 .40694 Mtetra
.82397 .40694 .82876 .41353 .84023 .40996 .83547 .40335 Mtetra
.83547 .40335 .84023 .40996 .85174 .40639 .84702 .39974 Mtetra
.84702 .39974 .85174 .40639 .8633 .40279 .85861 .39612 Mtetra
.85861 .39612 .8633 .40279 .8749 .39919 .87025 .39249 Mtetra
.87025 .39249 .8749 .39919 .88655 .39556 .88193 .38884 Mtetra
.25789 .57635 .2641 .58177 .27348 .57884 .2673 .5734 Mtetra
.2673 .5734 .27348 .57884 .2829 .57589 .27673 .57044 Mtetra
.27673 .57044 .2829 .57589 .29235 .57294 .2862 .56747 Mtetra
.2862 .56747 .29235 .57294 .30184 .56998 .29571 .56449 Mtetra
.29571 .56449 .30184 .56998 .31136 .56701 .30525 .56149 Mtetra
.30525 .56149 .31136 .56701 .32091 .56403 .31483 .55849 Mtetra
.31483 .55849 .32091 .56403 .3305 .56103 .32444 .55548 Mtetra
.32444 .55548 .3305 .56103 .34012 .55803 .33408 .55245 Mtetra
.33408 .55245 .34012 .55803 .34978 .55501 .34376 .54941 Mtetra
.34376 .54941 .34978 .55501 .35947 .55198 .35348 .54637 Mtetra
.35348 .54637 .35947 .55198 .3692 .54895 .36323 .54331 Mtetra
.36323 .54331 .3692 .54895 .37897 .5459 .37301 .54024 Mtetra
.37301 .54024 .37897 .5459 .38877 .54284 .38284 .53716 Mtetra
.38284 .53716 .38877 .54284 .3986 .53976 .39269 .53406 Mtetra
.39269 .53406 .3986 .53976 .40848 .53668 .40259 .53096 Mtetra
.40259 .53096 .40848 .53668 .41839 .53359 .41252 .52785 Mtetra
.41252 .52785 .41839 .53359 .42833 .53048 .42249 .52472 Mtetra
.42249 .52472 .42833 .53048 .43831 .52737 .43249 .52158 Mtetra
.43249 .52158 .43831 .52737 .44833 .52424 .44254 .51843 Mtetra
.44254 .51843 .44833 .52424 .45839 .5211 .45262 .51527 Mtetra
.45262 .51527 .45839 .5211 .46848 .51794 .46273 .5121 Mtetra
.46273 .5121 .46848 .51794 .47861 .51478 .47289 .50891 Mtetra
.47289 .50891 .47861 .51478 .48878 .51161 .48308 .50571 Mtetra
.48308 .50571 .48878 .51161 .49899 .50842 .49331 .5025 Mtetra
.49331 .5025 .49899 .50842 .50923 .50522 .50358 .49928 Mtetra
.50358 .49928 .50923 .50522 .51952 .50201 .51389 .49605 Mtetra
.51389 .49605 .51952 .50201 .52984 .49879 .52424 .4928 Mtetra
.52424 .4928 .52984 .49879 .5402 .49555 .53463 .48955 Mtetra
.53463 .48955 .5402 .49555 .5506 .4923 .54505 .48627 Mtetra
.54505 .48627 .5506 .4923 .56104 .48904 .55552 .48299 Mtetra
.55552 .48299 .56104 .48904 .57152 .48577 .56602 .4797 Mtetra
.56602 .4797 .57152 .48577 .58203 .48249 .57657 .47639 Mtetra
.57657 .47639 .58203 .48249 .59259 .47919 .58715 .47307 Mtetra
.58715 .47307 .59259 .47919 .60319 .47588 .59778 .46974 Mtetra
.59778 .46974 .60319 .47588 .61383 .47256 .60844 .46639 Mtetra
.60844 .46639 .61383 .47256 .62451 .46922 .61915 .46303 Mtetra
.61915 .46303 .62451 .46922 .63523 .46587 .6299 .45966 Mtetra
.6299 .45966 .63523 .46587 .64599 .46251 .64069 .45628 Mtetra
.64069 .45628 .64599 .46251 .6568 .45914 .65152 .45288 Mtetra
.65152 .45288 .6568 .45914 .66764 .45575 .66239 .44947 Mtetra
.66239 .44947 .66764 .45575 .67853 .45235 .67331 .44604 Mtetra
.67331 .44604 .67853 .45235 .68946 .44894 .68427 .44261 Mtetra
.68427 .44261 .68946 .44894 .70043 .44552 .69527 .43916 Mtetra
.69527 .43916 .70043 .44552 .71144 .44208 .70631 .43569 Mtetra
.70631 .43569 .71144 .44208 .7225 .43862 .7174 .43222 Mtetra
.7174 .43222 .7225 .43862 .7336 .43516 .72853 .42872 Mtetra
.72853 .42872 .7336 .43516 .74474 .43168 .7397 .42522 Mtetra
.7397 .42522 .74474 .43168 .75593 .42819 .75092 .4217 Mtetra
.75092 .4217 .75593 .42819 .76716 .42468 .76218 .41817 Mtetra
.76218 .41817 .76716 .42468 .77843 .42116 .77348 .41462 Mtetra
.77348 .41462 .77843 .42116 .78975 .41762 .78483 .41106 Mtetra
.78483 .41106 .78975 .41762 .80111 .41408 .79623 .40749 Mtetra
.79623 .40749 .80111 .41408 .81252 .41051 .80767 .4039 Mtetra
.80767 .4039 .81252 .41051 .82397 .40694 .81915 .4003 Mtetra
.81915 .4003 .82397 .40694 .83547 .40335 .83069 .39668 Mtetra
.83069 .39668 .83547 .40335 .84702 .39974 .84226 .39305 Mtetra
.84226 .39305 .84702 .39974 .85861 .39612 .85389 .3894 Mtetra
.85389 .3894 .85861 .39612 .87025 .39249 .86556 .38574 Mtetra
.86556 .38574 .87025 .39249 .88193 .38884 .87727 .38207 Mtetra
.25164 .57089 .25789 .57635 .2673 .5734 .26107 .56792 Mtetra
.26107 .56792 .2673 .5734 .27673 .57044 .27052 .56494 Mtetra
.27052 .56494 .27673 .57044 .2862 .56747 .28002 .56195 Mtetra
.28002 .56195 .2862 .56747 .29571 .56449 .28954 .55895 Mtetra
.28954 .55895 .29571 .56449 .30525 .56149 .2991 .55594 Mtetra
.2991 .55594 .30525 .56149 .31483 .55849 .3087 .55292 Mtetra
.3087 .55292 .31483 .55849 .32444 .55548 .31833 .54988 Mtetra
.31833 .54988 .32444 .55548 .33408 .55245 .328 .54684 Mtetra
.328 .54684 .33408 .55245 .34376 .54941 .3377 .54378 Mtetra
.3377 .54378 .34376 .54941 .35348 .54637 .34744 .54071 Mtetra
.34744 .54071 .35348 .54637 .36323 .54331 .35721 .53763 Mtetra
.35721 .53763 .36323 .54331 .37301 .54024 .36702 .53454 Mtetra
.36702 .53454 .37301 .54024 .38284 .53716 .37686 .53144 Mtetra
.37686 .53144 .38284 .53716 .39269 .53406 .38674 .52833 Mtetra
.38674 .52833 .39269 .53406 .40259 .53096 .39666 .5252 Mtetra
.39666 .5252 .40259 .53096 .41252 .52785 .40662 .52206 Mtetra
.40662 .52206 .41252 .52785 .42249 .52472 .41661 .51892 Mtetra
.41661 .51892 .42249 .52472 .43249 .52158 .42664 .51576 Mtetra
.42664 .51576 .43249 .52158 .44254 .51843 .4367 .51258 Mtetra
.4367 .51258 .44254 .51843 .45262 .51527 .44681 .5094 Mtetra
.44681 .5094 .45262 .51527 .46273 .5121 .45695 .50621 Mtetra
.45695 .50621 .46273 .5121 .47289 .50891 .46713 .503 Mtetra
.46713 .503 .47289 .50891 .48308 .50571 .47734 .49978 Mtetra
.47734 .49978 .48308 .50571 .49331 .5025 .4876 .49655 Mtetra
.4876 .49655 .49331 .5025 .50358 .49928 .49789 .4933 Mtetra
.49789 .4933 .50358 .49928 .51389 .49605 .50823 .49005 Mtetra
.50823 .49005 .51389 .49605 .52424 .4928 .5186 .48678 Mtetra
.5186 .48678 .52424 .4928 .53463 .48955 .52901 .4835 Mtetra
.52901 .4835 .53463 .48955 .54505 .48627 .53946 .4802 Mtetra
.53946 .4802 .54505 .48627 .55552 .48299 .54996 .4769 Mtetra
.54996 .4769 .55552 .48299 .56602 .4797 .56049 .47358 Mtetra
.56049 .47358 .56602 .4797 .57657 .47639 .57106 .47025 Mtetra
.57106 .47025 .57657 .47639 .58715 .47307 .58167 .46691 Mtetra
.58167 .46691 .58715 .47307 .59778 .46974 .59232 .46355 Mtetra
.59232 .46355 .59778 .46974 .60844 .46639 .60302 .46018 Mtetra
.60302 .46018 .60844 .46639 .61915 .46303 .61375 .4568 Mtetra
.61375 .4568 .61915 .46303 .6299 .45966 .62453 .4534 Mtetra
.62453 .4534 .6299 .45966 .64069 .45628 .63535 .44999 Mtetra
.63535 .44999 .64069 .45628 .65152 .45288 .64621 .44657 Mtetra
.64621 .44657 .65152 .45288 .66239 .44947 .65711 .44314 Mtetra
.65711 .44314 .66239 .44947 .67331 .44604 .66805 .43969 Mtetra
.66805 .43969 .67331 .44604 .68427 .44261 .67904 .43623 Mtetra
.67904 .43623 .68427 .44261 .69527 .43916 .69007 .43275 Mtetra
.69007 .43275 .69527 .43916 .70631 .43569 .70114 .42926 Mtetra
.70114 .42926 .70631 .43569 .7174 .43222 .71226 .42576 Mtetra
.71226 .42576 .7174 .43222 .72853 .42872 .72342 .42224 Mtetra
.72342 .42224 .72853 .42872 .7397 .42522 .73462 .41871 Mtetra
.73462 .41871 .7397 .42522 .75092 .4217 .74587 .41517 Mtetra
.74587 .41517 .75092 .4217 .76218 .41817 .75716 .41161 Mtetra
.75716 .41161 .76218 .41817 .77348 .41462 .7685 .40804 Mtetra
.7685 .40804 .77348 .41462 .78483 .41106 .77988 .40445 Mtetra
.77988 .40445 .78483 .41106 .79623 .40749 .79131 .40085 Mtetra
.79131 .40085 .79623 .40749 .80767 .4039 .80278 .39724 Mtetra
.80278 .39724 .80767 .4039 .81915 .4003 .8143 .39361 Mtetra
.8143 .39361 .81915 .4003 .83069 .39668 .82586 .38996 Mtetra
.82586 .38996 .83069 .39668 .84226 .39305 .83747 .38631 Mtetra
.83747 .38631 .84226 .39305 .85389 .3894 .84913 .38263 Mtetra
.84913 .38263 .85389 .3894 .86556 .38574 .86083 .37895 Mtetra
.86083 .37895 .86556 .38574 .87727 .38207 .87259 .37524 Mtetra
.24535 .5654 .25164 .57089 .26107 .56792 .2548 .56242 Mtetra
.2548 .56242 .26107 .56792 .27052 .56494 .26427 .55942 Mtetra
.26427 .55942 .27052 .56494 .28002 .56195 .27379 .55641 Mtetra
.27379 .55641 .28002 .56195 .28954 .55895 .28333 .55338 Mtetra
.28333 .55338 .28954 .55895 .2991 .55594 .29292 .55035 Mtetra
.29292 .55035 .2991 .55594 .3087 .55292 .30253 .54731 Mtetra
.30253 .54731 .3087 .55292 .31833 .54988 .31218 .54425 Mtetra
.31218 .54425 .31833 .54988 .328 .54684 .32187 .54118 Mtetra
.32187 .54118 .328 .54684 .3377 .54378 .3316 .53811 Mtetra
.3316 .53811 .3377 .54378 .34744 .54071 .34135 .53502 Mtetra
.34135 .53502 .34744 .54071 .35721 .53763 .35115 .53192 Mtetra
.35115 .53192 .35721 .53763 .36702 .53454 .36098 .52881 Mtetra
.36098 .52881 .36702 .53454 .37686 .53144 .37085 .52568 Mtetra
.37085 .52568 .37686 .53144 .38674 .52833 .38075 .52255 Mtetra
.38075 .52255 .38674 .52833 .39666 .5252 .39069 .5194 Mtetra
.39069 .5194 .39666 .5252 .40662 .52206 .40067 .51624 Mtetra
.40067 .51624 .40662 .52206 .41661 .51892 .41068 .51307 Mtetra
.41068 .51307 .41661 .51892 .42664 .51576 .42074 .50989 Mtetra
.42074 .50989 .42664 .51576 .4367 .51258 .43083 .5067 Mtetra
.43083 .5067 .4367 .51258 .44681 .5094 .44095 .50349 Mtetra
.44095 .50349 .44681 .5094 .45695 .50621 .45112 .50027 Mtetra
.45112 .50027 .45695 .50621 .46713 .503 .46132 .49704 Mtetra
.46132 .49704 .46713 .503 .47734 .49978 .47157 .4938 Mtetra
.47157 .4938 .47734 .49978 .4876 .49655 .48185 .49055 Mtetra
.48185 .49055 .4876 .49655 .49789 .4933 .49217 .48728 Mtetra
.49217 .48728 .49789 .4933 .50823 .49005 .50253 .484 Mtetra
.50253 .484 .50823 .49005 .5186 .48678 .51292 .48071 Mtetra
.51292 .48071 .5186 .48678 .52901 .4835 .52336 .47741 Mtetra
.52336 .47741 .52901 .4835 .53946 .4802 .53384 .47409 Mtetra
.53384 .47409 .53946 .4802 .54996 .4769 .54436 .47076 Mtetra
.54436 .47076 .54996 .4769 .56049 .47358 .55491 .46742 Mtetra
.55491 .46742 .56049 .47358 .57106 .47025 .56551 .46407 Mtetra
.56551 .46407 .57106 .47025 .58167 .46691 .57615 .4607 Mtetra
.57615 .4607 .58167 .46691 .59232 .46355 .58683 .45732 Mtetra
.58683 .45732 .59232 .46355 .60302 .46018 .59755 .45393 Mtetra
.59755 .45393 .60302 .46018 .61375 .4568 .60832 .45052 Mtetra
.60832 .45052 .61375 .4568 .62453 .4534 .61912 .4471 Mtetra
.61912 .4471 .62453 .4534 .63535 .44999 .62997 .44367 Mtetra
.62997 .44367 .63535 .44999 .64621 .44657 .64085 .44022 Mtetra
.64085 .44022 .64621 .44657 .65711 .44314 .65178 .43676 Mtetra
.65178 .43676 .65711 .44314 .66805 .43969 .66276 .43329 Mtetra
.66276 .43329 .66805 .43969 .67904 .43623 .67377 .4298 Mtetra
.67377 .4298 .67904 .43623 .69007 .43275 .68483 .4263 Mtetra
.68483 .4263 .69007 .43275 .70114 .42926 .69594 .42279 Mtetra
.69594 .42279 .70114 .42926 .71226 .42576 .70708 .41926 Mtetra
.70708 .41926 .71226 .42576 .72342 .42224 .71827 .41572 Mtetra
.71827 .41572 .72342 .42224 .73462 .41871 .72951 .41216 Mtetra
.72951 .41216 .73462 .41871 .74587 .41517 .74079 .40859 Mtetra
.74079 .40859 .74587 .41517 .75716 .41161 .75211 .40501 Mtetra
.75211 .40501 .75716 .41161 .7685 .40804 .76348 .40141 Mtetra
.76348 .40141 .7685 .40804 .77988 .40445 .77489 .3978 Mtetra
.77489 .3978 .77988 .40445 .79131 .40085 .78635 .39417 Mtetra
.78635 .39417 .79131 .40085 .80278 .39724 .79786 .39053 Mtetra
.79786 .39053 .80278 .39724 .8143 .39361 .80941 .38687 Mtetra
.80941 .38687 .8143 .39361 .82586 .38996 .821 .3832 Mtetra
.821 .3832 .82586 .38996 .83747 .38631 .83265 .37952 Mtetra
.83265 .37952 .83747 .38631 .84913 .38263 .84434 .37581 Mtetra
.84434 .37581 .84913 .38263 .86083 .37895 .85608 .3721 Mtetra
.85608 .3721 .86083 .37895 .87259 .37524 .86786 .36837 Mtetra
.23902 .55988 .24535 .5654 .2548 .56242 .24848 .55687 Mtetra
.24848 .55687 .2548 .56242 .26427 .55942 .25798 .55385 Mtetra
.25798 .55385 .26427 .55942 .27379 .55641 .26751 .55082 Mtetra
.656 .752 .92 r
.26751 .55082 .27379 .55641 .28333 .55338 .27708 .54778 Mtetra
.27708 .54778 .28333 .55338 .29292 .55035 .28669 .54472 Mtetra
.656 .751 .92 r
.28669 .54472 .29292 .55035 .30253 .54731 .29632 .54166 Mtetra
.29632 .54166 .30253 .54731 .31218 .54425 .306 .53858 Mtetra
.306 .53858 .31218 .54425 .32187 .54118 .31571 .53549 Mtetra
.31571 .53549 .32187 .54118 .3316 .53811 .32545 .53239 Mtetra
.32545 .53239 .3316 .53811 .34135 .53502 .33523 .52928 Mtetra
.33523 .52928 .34135 .53502 .35115 .53192 .34505 .52616 Mtetra
.34505 .52616 .35115 .53192 .36098 .52881 .3549 .52303 Mtetra
.3549 .52303 .36098 .52881 .37085 .52568 .36479 .51989 Mtetra
.36479 .51989 .37085 .52568 .38075 .52255 .37472 .51673 Mtetra
.37472 .51673 .38075 .52255 .39069 .5194 .38468 .51356 Mtetra
.38468 .51356 .39069 .5194 .40067 .51624 .39468 .51038 Mtetra
.39468 .51038 .40067 .51624 .41068 .51307 .40472 .50719 Mtetra
.40472 .50719 .41068 .51307 .42074 .50989 .4148 .50399 Mtetra
.4148 .50399 .42074 .50989 .43083 .5067 .42491 .50077 Mtetra
.42491 .50077 .43083 .5067 .44095 .50349 .43506 .49754 Mtetra
.43506 .49754 .44095 .50349 .45112 .50027 .44525 .4943 Mtetra
.44525 .4943 .45112 .50027 .46132 .49704 .45548 .49105 Mtetra
.45548 .49105 .46132 .49704 .47157 .4938 .46575 .48779 Mtetra
.46575 .48779 .47157 .4938 .48185 .49055 .47605 .48451 Mtetra
.47605 .48451 .48185 .49055 .49217 .48728 .4864 .48122 Mtetra
.4864 .48122 .49217 .48728 .50253 .484 .49678 .47792 Mtetra
.49678 .47792 .50253 .484 .51292 .48071 .50721 .4746 Mtetra
.50721 .4746 .51292 .48071 .52336 .47741 .51767 .47128 Mtetra
.51767 .47128 .52336 .47741 .53384 .47409 .52817 .46794 Mtetra
.52817 .46794 .53384 .47409 .54436 .47076 .53872 .46458 Mtetra
.53872 .46458 .54436 .47076 .55491 .46742 .5493 .46122 Mtetra
.5493 .46122 .55491 .46742 .56551 .46407 .55993 .45784 Mtetra
.55993 .45784 .56551 .46407 .57615 .4607 .57059 .45445 Mtetra
.57059 .45445 .57615 .4607 .58683 .45732 .5813 .45104 Mtetra
.5813 .45104 .58683 .45732 .59755 .45393 .59205 .44763 Mtetra
.59205 .44763 .59755 .45393 .60832 .45052 .60284 .4442 Mtetra
.60284 .4442 .60832 .45052 .61912 .4471 .61367 .44075 Mtetra
.61367 .44075 .61912 .4471 .62997 .44367 .62455 .43729 Mtetra
.62455 .43729 .62997 .44367 .64085 .44022 .63546 .43382 Mtetra
.63546 .43382 .64085 .44022 .65178 .43676 .64642 .43034 Mtetra
.64642 .43034 .65178 .43676 .66276 .43329 .65743 .42684 Mtetra
.65743 .42684 .66276 .43329 .67377 .4298 .66847 .42333 Mtetra
.66847 .42333 .67377 .4298 .68483 .4263 .67956 .4198 Mtetra
.67956 .4198 .68483 .4263 .69594 .42279 .69069 .41626 Mtetra
.69069 .41626 .69594 .42279 .70708 .41926 .70187 .41271 Mtetra
.70187 .41271 .70708 .41926 .71827 .41572 .71309 .40914 Mtetra
.71309 .40914 .71827 .41572 .72951 .41216 .72436 .40556 Mtetra
.72436 .40556 .72951 .41216 .74079 .40859 .73566 .40196 Mtetra
.73566 .40196 .74079 .40859 .75211 .40501 .74702 .39835 Mtetra
.74702 .39835 .75211 .40501 .76348 .40141 .75842 .39473 Mtetra
.75842 .39473 .76348 .40141 .77489 .3978 .76987 .39109 Mtetra
.76987 .39109 .77489 .3978 .78635 .39417 .78136 .38743 Mtetra
.78136 .38743 .78635 .39417 .79786 .39053 .79289 .38377 Mtetra
.79289 .38377 .79786 .39053 .80941 .38687 .80448 .38009 Mtetra
.80448 .38009 .80941 .38687 .821 .3832 .81611 .37639 Mtetra
.81611 .37639 .821 .3832 .83265 .37952 .82779 .37268 Mtetra
.656 .752 .92 r
.82779 .37268 .83265 .37952 .84434 .37581 .83951 .36895 Mtetra
.83951 .36895 .84434 .37581 .85608 .3721 .85128 .3652 Mtetra
.656 .751 .92 r
.85128 .3652 .85608 .3721 .86786 .36837 .8631 .36144 Mtetra
.655 .751 .92 r
.23264 .55431 .23902 .55988 .24848 .55687 .24213 .55129 Mtetra
.656 .752 .921 r
.24213 .55129 .24848 .55687 .25798 .55385 .25165 .54826 Mtetra
.25165 .54826 .25798 .55385 .26751 .55082 .2612 .54521 Mtetra
.2612 .54521 .26751 .55082 .27708 .54778 .27079 .54215 Mtetra
.27079 .54215 .27708 .54778 .28669 .54472 .28041 .53907 Mtetra
.28041 .53907 .28669 .54472 .29632 .54166 .29007 .53598 Mtetra
.29007 .53598 .29632 .54166 .306 .53858 .29977 .53288 Mtetra
.656 .752 .92 r
.29977 .53288 .306 .53858 .31571 .53549 .3095 .52977 Mtetra
.3095 .52977 .31571 .53549 .32545 .53239 .31926 .52665 Mtetra
.31926 .52665 .32545 .53239 .33523 .52928 .32907 .52352 Mtetra
.32907 .52352 .33523 .52928 .34505 .52616 .33891 .52037 Mtetra
.33891 .52037 .34505 .52616 .3549 .52303 .34878 .51722 Mtetra
.656 .751 .92 r
.34878 .51722 .3549 .52303 .36479 .51989 .35869 .51405 Mtetra
.35869 .51405 .36479 .51989 .37472 .51673 .36864 .51087 Mtetra
.36864 .51087 .37472 .51673 .38468 .51356 .37863 .50768 Mtetra
.37863 .50768 .38468 .51356 .39468 .51038 .38865 .50448 Mtetra
.38865 .50448 .39468 .51038 .40472 .50719 .39872 .50127 Mtetra
.39872 .50127 .40472 .50719 .4148 .50399 .40882 .49804 Mtetra
.40882 .49804 .4148 .50399 .42491 .50077 .41895 .4948 Mtetra
.41895 .4948 .42491 .50077 .43506 .49754 .42913 .49155 Mtetra
.42913 .49155 .43506 .49754 .44525 .4943 .43934 .48829 Mtetra
.43934 .48829 .44525 .4943 .45548 .49105 .4496 .48501 Mtetra
.4496 .48501 .45548 .49105 .46575 .48779 .45989 .48173 Mtetra
.45989 .48173 .46575 .48779 .47605 .48451 .47022 .47843 Mtetra
.47022 .47843 .47605 .48451 .4864 .48122 .48059 .47511 Mtetra
.48059 .47511 .4864 .48122 .49678 .47792 .491 .47179 Mtetra
.491 .47179 .49678 .47792 .50721 .4746 .50145 .46845 Mtetra
.50145 .46845 .50721 .4746 .51767 .47128 .51194 .4651 Mtetra
.51194 .4651 .51767 .47128 .52817 .46794 .52247 .46174 Mtetra
.52247 .46174 .52817 .46794 .53872 .46458 .53304 .45836 Mtetra
.53304 .45836 .53872 .46458 .5493 .46122 .54365 .45497 Mtetra
.54365 .45497 .5493 .46122 .55993 .45784 .5543 .45157 Mtetra
.5543 .45157 .55993 .45784 .57059 .45445 .565 .44815 Mtetra
.565 .44815 .57059 .45445 .5813 .45104 .57573 .44472 Mtetra
.57573 .44472 .5813 .45104 .59205 .44763 .58651 .44128 Mtetra
.58651 .44128 .59205 .44763 .60284 .4442 .59732 .43783 Mtetra
.59732 .43783 .60284 .4442 .61367 .44075 .60819 .43436 Mtetra
.60819 .43436 .61367 .44075 .62455 .43729 .61909 .43087 Mtetra
.61909 .43087 .62455 .43729 .63546 .43382 .63003 .42738 Mtetra
.63003 .42738 .63546 .43382 .64642 .43034 .64102 .42387 Mtetra
.64102 .42387 .64642 .43034 .65743 .42684 .65205 .42034 Mtetra
.65205 .42034 .65743 .42684 .66847 .42333 .66313 .41681 Mtetra
.66313 .41681 .66847 .42333 .67956 .4198 .67425 .41326 Mtetra
.67425 .41326 .67956 .4198 .69069 .41626 .68541 .40969 Mtetra
.68541 .40969 .69069 .41626 .70187 .41271 .69662 .40611 Mtetra
.69662 .40611 .70187 .41271 .71309 .40914 .70787 .40252 Mtetra
.70787 .40252 .71309 .40914 .72436 .40556 .71917 .39891 Mtetra
.71917 .39891 .72436 .40556 .73566 .40196 .73051 .39529 Mtetra
.73051 .39529 .73566 .40196 .74702 .39835 .74189 .39165 Mtetra
.656 .752 .92 r
.74189 .39165 .74702 .39835 .75842 .39473 .75333 .388 Mtetra
.75333 .388 .75842 .39473 .76987 .39109 .7648 .38434 Mtetra
.7648 .38434 .76987 .39109 .78136 .38743 .77633 .38066 Mtetra
.656 .752 .921 r
.77633 .38066 .78136 .38743 .79289 .38377 .7879 .37697 Mtetra
.7879 .37697 .79289 .38377 .80448 .38009 .79951 .37326 Mtetra
.79951 .37326 .80448 .38009 .81611 .37639 .81118 .36954 Mtetra
.81118 .36954 .81611 .37639 .82779 .37268 .82289 .36579 Mtetra
.82289 .36579 .82779 .37268 .83951 .36895 .83465 .36203 Mtetra
.656 .752 .92 r
.83465 .36203 .83951 .36895 .85128 .3652 .84645 .35826 Mtetra
.84645 .35826 .85128 .3652 .8631 .36144 .85831 .35446 Mtetra
.655 .751 .921 r
.22623 .54871 .23264 .55431 .24213 .55129 .23573 .54568 Mtetra
.655 .752 .921 r
.23573 .54568 .24213 .55129 .25165 .54826 .24527 .54264 Mtetra
.24527 .54264 .25165 .54826 .2612 .54521 .25484 .53957 Mtetra
.656 .752 .921 r
.25484 .53957 .2612 .54521 .27079 .54215 .26445 .53649 Mtetra
.656 .753 .921 r
.26445 .53649 .27079 .54215 .28041 .53907 .2741 .53339 Mtetra
.2741 .53339 .28041 .53907 .29007 .53598 .28378 .53028 Mtetra
.656 .752 .921 r
.28378 .53028 .29007 .53598 .29977 .53288 .29349 .52716 Mtetra
.29349 .52716 .29977 .53288 .3095 .52977 .30325 .52402 Mtetra
.30325 .52402 .3095 .52977 .31926 .52665 .31303 .52087 Mtetra
.656 .752 .92 r
.31303 .52087 .31926 .52665 .32907 .52352 .32286 .51771 Mtetra
.32286 .51771 .32907 .52352 .33891 .52037 .33272 .51454 Mtetra
.33272 .51454 .33891 .52037 .34878 .51722 .34262 .51136 Mtetra
.656 .751 .92 r
.34262 .51136 .34878 .51722 .35869 .51405 .35256 .50817 Mtetra
.35256 .50817 .35869 .51405 .36864 .51087 .36253 .50497 Mtetra
.36253 .50497 .36864 .51087 .37863 .50768 .37254 .50176 Mtetra
.37254 .50176 .37863 .50768 .38865 .50448 .38258 .49853 Mtetra
.38258 .49853 .38865 .50448 .39872 .50127 .39267 .4953 Mtetra
.39267 .4953 .39872 .50127 .40882 .49804 .40279 .49205 Mtetra
.40279 .49205 .40882 .49804 .41895 .4948 .41295 .48879 Mtetra
.41295 .48879 .41895 .4948 .42913 .49155 .42315 .48552 Mtetra
.42315 .48552 .42913 .49155 .43934 .48829 .43339 .48223 Mtetra
.43339 .48223 .43934 .48829 .4496 .48501 .44367 .47893 Mtetra
.44367 .47893 .4496 .48501 .45989 .48173 .45399 .47562 Mtetra
.45399 .47562 .45989 .48173 .47022 .47843 .46434 .4723 Mtetra
.46434 .4723 .47022 .47843 .48059 .47511 .47474 .46896 Mtetra
.47474 .46896 .48059 .47511 .491 .47179 .48517 .46562 Mtetra
.48517 .46562 .491 .47179 .50145 .46845 .49565 .46225 Mtetra
.49565 .46225 .50145 .46845 .51194 .4651 .50617 .45888 Mtetra
.50617 .45888 .51194 .4651 .52247 .46174 .51672 .45549 Mtetra
.51672 .45549 .52247 .46174 .53304 .45836 .52732 .45209 Mtetra
.52732 .45209 .53304 .45836 .54365 .45497 .53796 .44868 Mtetra
.53796 .44868 .54365 .45497 .5543 .45157 .54864 .44525 Mtetra
.54864 .44525 .5543 .45157 .565 .44815 .55936 .44181 Mtetra
.55936 .44181 .565 .44815 .57573 .44472 .57012 .43836 Mtetra
.57012 .43836 .57573 .44472 .58651 .44128 .58092 .43489 Mtetra
.58092 .43489 .58651 .44128 .59732 .43783 .59177 .43141 Mtetra
.59177 .43141 .59732 .43783 .60819 .43436 .60266 .42792 Mtetra
.60266 .42792 .60819 .43436 .61909 .43087 .61359 .42441 Mtetra
.61359 .42441 .61909 .43087 .63003 .42738 .62456 .42089 Mtetra
.62456 .42089 .63003 .42738 .64102 .42387 .63558 .41735 Mtetra
.63558 .41735 .64102 .42387 .65205 .42034 .64664 .4138 Mtetra
.64664 .4138 .65205 .42034 .66313 .41681 .65775 .41024 Mtetra
.65775 .41024 .66313 .41681 .67425 .41326 .6689 .40666 Mtetra
.6689 .40666 .67425 .41326 .68541 .40969 .68009 .40307 Mtetra
.68009 .40307 .68541 .40969 .69662 .40611 .69133 .39946 Mtetra
.69133 .39946 .69662 .40611 .70787 .40252 .70261 .39584 Mtetra
.70261 .39584 .70787 .40252 .71917 .39891 .71394 .39221 Mtetra
.71394 .39221 .71917 .39891 .73051 .39529 .72531 .38856 Mtetra
.72531 .38856 .73051 .39529 .74189 .39165 .73673 .3849 Mtetra
.73673 .3849 .74189 .39165 .75333 .388 .74819 .38123 Mtetra
.655 .752 .921 r
.74819 .38123 .75333 .388 .7648 .38434 .7597 .37755 Mtetra
.7597 .37755 .7648 .38434 .77633 .38066 .77126 .37385 Mtetra
.77126 .37385 .77633 .38066 .7879 .37697 .78286 .37013 Mtetra
.78286 .37013 .7879 .37697 .79951 .37326 .79452 .3664 Mtetra
.656 .752 .921 r
.79452 .3664 .79951 .37326 .81118 .36954 .80621 .36265 Mtetra
.656 .753 .921 r
.80621 .36265 .81118 .36954 .82289 .36579 .81796 .35888 Mtetra
.81796 .35888 .82289 .36579 .83465 .36203 .82975 .35508 Mtetra
.656 .752 .921 r
.82975 .35508 .83465 .36203 .84645 .35826 .84159 .35127 Mtetra
.657 .752 .92 r
.84159 .35127 .84645 .35826 .85831 .35446 .85348 .34743 Mtetra
.654 .751 .921 r
.21976 .54307 .22623 .54871 .23573 .54568 .22928 .54005 Mtetra
.654 .752 .922 r
.22928 .54005 .23573 .54568 .24527 .54264 .23884 .53701 Mtetra
.655 .753 .922 r
.23884 .53701 .24527 .54264 .25484 .53957 .24843 .53394 Mtetra
.655 .754 .922 r
.24843 .53394 .25484 .53957 .26445 .53649 .25806 .53085 Mtetra
.656 .754 .923 r
.25806 .53085 .26445 .53649 .2741 .53339 .26773 .52774 Mtetra
.656 .755 .922 r
.26773 .52774 .2741 .53339 .28378 .53028 .27743 .5246 Mtetra
.27743 .5246 .28378 .53028 .29349 .52716 .28717 .52145 Mtetra
.656 .754 .922 r
.28717 .52145 .29349 .52716 .30325 .52402 .29695 .51828 Mtetra
.29695 .51828 .30325 .52402 .31303 .52087 .30676 .5151 Mtetra
.656 .754 .921 r
.30676 .5151 .31303 .52087 .32286 .51771 .31661 .5119 Mtetra
.656 .753 .921 r
.31661 .5119 .32286 .51771 .33272 .51454 .32649 .5087 Mtetra
.32649 .5087 .33272 .51454 .34262 .51136 .33641 .50549 Mtetra
.656 .752 .921 r
.33641 .50549 .34262 .51136 .35256 .50817 .34637 .50228 Mtetra
.34637 .50228 .35256 .50817 .36253 .50497 .35637 .49905 Mtetra
.35637 .49905 .36253 .50497 .37254 .50176 .3664 .49581 Mtetra
.3664 .49581 .37254 .50176 .38258 .49853 .37647 .49256 Mtetra
.656 .752 .92 r
.37647 .49256 .38258 .49853 .39267 .4953 .38658 .4893 Mtetra
.38658 .4893 .39267 .4953 .40279 .49205 .39673 .48603 Mtetra
.39673 .48603 .40279 .49205 .41295 .48879 .40691 .48274 Mtetra
.40691 .48274 .41295 .48879 .42315 .48552 .41714 .47944 Mtetra
.656 .751 .92 r
.41714 .47944 .42315 .48552 .43339 .48223 .4274 .47613 Mtetra
.4274 .47613 .43339 .48223 .44367 .47893 .4377 .47281 Mtetra
.4377 .47281 .44367 .47893 .45399 .47562 .44805 .46948 Mtetra
.44805 .46948 .45399 .47562 .46434 .4723 .45843 .46613 Mtetra
.45843 .46613 .46434 .4723 .47474 .46896 .46885 .46277 Mtetra
.46885 .46277 .47474 .46896 .48517 .46562 .47931 .4594 Mtetra
.47931 .4594 .48517 .46562 .49565 .46225 .48981 .45602 Mtetra
.48981 .45602 .49565 .46225 .50617 .45888 .50035 .45262 Mtetra
.50035 .45262 .50617 .45888 .51672 .45549 .51093 .44921 Mtetra
.51093 .44921 .51672 .45549 .52732 .45209 .52156 .44578 Mtetra
.52156 .44578 .52732 .45209 .53796 .44868 .53222 .44234 Mtetra
.53222 .44234 .53796 .44868 .54864 .44525 .54293 .43889 Mtetra
.54293 .43889 .54864 .44525 .55936 .44181 .55368 .43543 Mtetra
.55368 .43543 .55936 .44181 .57012 .43836 .56447 .43195 Mtetra
.56447 .43195 .57012 .43836 .58092 .43489 .5753 .42846 Mtetra
.5753 .42846 .58092 .43489 .59177 .43141 .58617 .42495 Mtetra
.58617 .42495 .59177 .43141 .60266 .42792 .59709 .42143 Mtetra
.59709 .42143 .60266 .42792 .61359 .42441 .60805 .4179 Mtetra
.60805 .4179 .61359 .42441 .62456 .42089 .61906 .41435 Mtetra
.61906 .41435 .62456 .42089 .63558 .41735 .6301 .41079 Mtetra
.6301 .41079 .63558 .41735 .64664 .4138 .64119 .40722 Mtetra
.656 .752 .92 r
.64119 .40722 .64664 .4138 .65775 .41024 .65233 .40363 Mtetra
.65233 .40363 .65775 .41024 .6689 .40666 .66351 .40003 Mtetra
.656 .752 .921 r
.66351 .40003 .6689 .40666 .68009 .40307 .67473 .39641 Mtetra
.67473 .39641 .68009 .40307 .69133 .39946 .686 .39278 Mtetra
.686 .39278 .69133 .39946 .70261 .39584 .69731 .38914 Mtetra
.655 .752 .921 r
.69731 .38914 .70261 .39584 .71394 .39221 .70867 .38549 Mtetra
.70867 .38549 .71394 .39221 .72531 .38856 .72008 .38182 Mtetra
.72008 .38182 .72531 .38856 .73673 .3849 .73153 .37815 Mtetra
.655 .753 .922 r
.73153 .37815 .73673 .3849 .74819 .38123 .74303 .37446 Mtetra
.74303 .37446 .74819 .38123 .7597 .37755 .75457 .37076 Mtetra
.75457 .37076 .7597 .37755 .77126 .37385 .76616 .36704 Mtetra
.655 .754 .922 r
.76616 .36704 .77126 .37385 .78286 .37013 .7778 .36331 Mtetra
.655 .754 .923 r
.7778 .36331 .78286 .37013 .79452 .3664 .78948 .35955 Mtetra
.656 .754 .923 r
.78948 .35955 .79452 .3664 .80621 .36265 .80122 .35577 Mtetra
.656 .755 .922 r
.80122 .35577 .80621 .36265 .81796 .35888 .81299 .35196 Mtetra
.657 .754 .922 r
.81299 .35196 .81796 .35888 .82975 .35508 .82482 .34812 Mtetra
.657 .754 .921 r
.82482 .34812 .82975 .35508 .84159 .35127 .83669 .34425 Mtetra
.658 .753 .921 r
.83669 .34425 .84159 .35127 .85348 .34743 .84861 .34035 Mtetra
.651 .75 .922 r
.21326 .53739 .21976 .54307 .22928 .54005 .22279 .53442 Mtetra
.652 .753 .924 r
.22279 .53442 .22928 .54005 .23884 .53701 .23237 .53141 Mtetra
.652 .755 .925 r
.23237 .53141 .23884 .53701 .24843 .53394 .24198 .52837 Mtetra
.654 .757 .925 r
.24198 .52837 .24843 .53394 .25806 .53085 .25162 .52529 Mtetra
.655 .758 .926 r
.25162 .52529 .25806 .53085 .26773 .52774 .26131 .52217 Mtetra
.656 .759 .926 r
.26131 .52217 .26773 .52774 .27743 .5246 .27104 .51901 Mtetra
.657 .759 .925 r
.27104 .51901 .27743 .5246 .28717 .52145 .2808 .51581 Mtetra
.2808 .51581 .28717 .52145 .29695 .51828 .2906 .5126 Mtetra
.657 .758 .924 r
.2906 .5126 .29695 .51828 .30676 .5151 .30044 .50937 Mtetra
.658 .757 .923 r
.30044 .50937 .30676 .5151 .31661 .5119 .31031 .50612 Mtetra
.657 .756 .923 r
.31031 .50612 .31661 .5119 .32649 .5087 .32022 .50288 Mtetra
.657 .755 .922 r
.32022 .50288 .32649 .5087 .33641 .50549 .33016 .49962 Mtetra
.657 .754 .921 r
.33016 .49962 .33641 .50549 .34637 .50228 .34015 .49636 Mtetra
.657 .753 .921 r
.34015 .49636 .34637 .50228 .35637 .49905 .35017 .49309 Mtetra
.656 .753 .921 r
.35017 .49309 .35637 .49905 .3664 .49581 .36022 .48982 Mtetra
.656 .752 .92 r
.36022 .48982 .3664 .49581 .37647 .49256 .37032 .48654 Mtetra
.37032 .48654 .37647 .49256 .38658 .4893 .38045 .48325 Mtetra
.38045 .48325 .38658 .4893 .39673 .48603 .39062 .47995 Mtetra
.656 .751 .92 r
.39062 .47995 .39673 .48603 .40691 .48274 .40083 .47664 Mtetra
.40083 .47664 .40691 .48274 .41714 .47944 .41108 .47332 Mtetra
.41108 .47332 .41714 .47944 .4274 .47613 .42137 .46999 Mtetra
.42137 .46999 .4274 .47613 .4377 .47281 .43169 .46664 Mtetra
.43169 .46664 .4377 .47281 .44805 .46948 .44206 .46328 Mtetra
.44206 .46328 .44805 .46948 .45843 .46613 .45247 .45991 Mtetra
.45247 .45991 .45843 .46613 .46885 .46277 .46291 .45653 Mtetra
.46291 .45653 .46885 .46277 .47931 .4594 .4734 .45313 Mtetra
.4734 .45313 .47931 .4594 .48981 .45602 .48393 .44972 Mtetra
.48393 .44972 .48981 .45602 .50035 .45262 .4945 .4463 Mtetra
.4945 .4463 .50035 .45262 .51093 .44921 .50511 .44286 Mtetra
.50511 .44286 .51093 .44921 .52156 .44578 .51576 .43942 Mtetra
.51576 .43942 .52156 .44578 .53222 .44234 .52645 .43595 Mtetra
.52645 .43595 .53222 .44234 .54293 .43889 .53718 .43248 Mtetra
.53718 .43248 .54293 .43889 .55368 .43543 .54796 .42899 Mtetra
.54796 .42899 .55368 .43543 .56447 .43195 .55878 .42548 Mtetra
.55878 .42548 .56447 .43195 .5753 .42846 .56964 .42196 Mtetra
.56964 .42196 .5753 .42846 .58617 .42495 .58054 .41843 Mtetra
.58054 .41843 .58617 .42495 .59709 .42143 .59149 .41489 Mtetra
.59149 .41489 .59709 .42143 .60805 .4179 .60247 .41133 Mtetra
.60247 .41133 .60805 .4179 .61906 .41435 .61351 .40776 Mtetra
.61351 .40776 .61906 .41435 .6301 .41079 .62458 .40417 Mtetra
.62458 .40417 .6301 .41079 .64119 .40722 .6357 .40058 Mtetra
.6357 .40058 .64119 .40722 .65233 .40363 .64687 .39696 Mtetra
.655 .751 .92 r
.64687 .39696 .65233 .40363 .66351 .40003 .65808 .39334 Mtetra
.655 .751 .921 r
.65808 .39334 .66351 .40003 .67473 .39641 .66933 .38971 Mtetra
.655 .752 .921 r
.66933 .38971 .67473 .39641 .686 .39278 .68063 .38607 Mtetra
.68063 .38607 .686 .39278 .69731 .38914 .69198 .38241 Mtetra
.655 .752 .922 r
.69198 .38241 .69731 .38914 .70867 .38549 .70337 .37875 Mtetra
.654 .753 .922 r
.70337 .37875 .70867 .38549 .72008 .38182 .71481 .37509 Mtetra
.654 .754 .923 r
.71481 .37509 .72008 .38182 .73153 .37815 .72629 .37141 Mtetra
.654 .755 .924 r
.72629 .37141 .73153 .37815 .74303 .37446 .73783 .36773 Mtetra
.654 .756 .925 r
.73783 .36773 .74303 .37446 .75457 .37076 .74941 .36403 Mtetra
.654 .757 .925 r
.74941 .36403 .75457 .37076 .76616 .36704 .76103 .36031 Mtetra
.654 .758 .926 r
.76103 .36031 .76616 .36704 .7778 .36331 .77271 .35656 Mtetra
.655 .759 .926 r
.77271 .35656 .7778 .36331 .78948 .35955 .78442 .35278 Mtetra
.656 .759 .926 r
.78442 .35278 .78948 .35955 .80122 .35577 .79619 .34896 Mtetra
.657 .759 .925 r
.79619 .34896 .80122 .35577 .81299 .35196 .808 .34508 Mtetra
.658 .758 .924 r
.808 .34508 .81299 .35196 .82482 .34812 .81986 .34116 Mtetra
.659 .757 .922 r
.81986 .34116 .82482 .34812 .83669 .34425 .83176 .33721 Mtetra
.66 .756 .921 r
.83176 .33721 .83669 .34425 .84861 .34035 .8437 .33321 Mtetra
.646 .749 .924 r
.20671 .53168 .21326 .53739 .22279 .53442 .21625 .5288 Mtetra
.647 .753 .927 r
.21625 .5288 .22279 .53442 .23237 .53141 .22584 .52587 Mtetra
.648 .757 .929 r
.22584 .52587 .23237 .53141 .24198 .52837 .23546 .5229 Mtetra
.65 .761 .93 r
.23546 .5229 .24198 .52837 .25162 .52529 .24513 .51987 Mtetra
.653 .764 .931 r
.24513 .51987 .25162 .52529 .26131 .52217 .25483 .51677 Mtetra
.655 .766 .931 r
.25483 .51677 .26131 .52217 .27104 .51901 .26458 .51361 Mtetra
.656 .767 .931 r
.26458 .51361 .27104 .51901 .2808 .51581 .27436 .51039 Mtetra
.658 .767 .93 r
.27436 .51039 .2808 .51581 .2906 .5126 .28419 .50713 Mtetra
.659 .767 .93 r
.28419 .50713 .2906 .5126 .30044 .50937 .29405 .50384 Mtetra
.659 .766 .928 r
.29405 .50384 .30044 .50937 .31031 .50612 .30395 .50053 Mtetra
.659 .764 .927 r
.30395 .50053 .31031 .50612 .32022 .50288 .31389 .49721 Mtetra
.659 .762 .926 r
.31389 .49721 .32022 .50288 .33016 .49962 .32386 .49388 Mtetra
.658 .761 .925 r
.32386 .49388 .33016 .49962 .34015 .49636 .33387 .49056 Mtetra
.658 .759 .924 r
.33387 .49056 .34015 .49636 .35017 .49309 .34391 .48724 Mtetra
.657 .758 .924 r
.34391 .48724 .35017 .49309 .36022 .48982 .35399 .48391 Mtetra
.657 .756 .923 r
.35399 .48391 .36022 .48982 .37032 .48654 .36411 .48058 Mtetra
.657 .755 .923 r
.36411 .48058 .37032 .48654 .38045 .48325 .37427 .47725 Mtetra
.657 .755 .922 r
.37427 .47725 .38045 .48325 .39062 .47995 .38447 .47391 Mtetra
.656 .754 .922 r
.38447 .47391 .39062 .47995 .40083 .47664 .3947 .47056 Mtetra
.656 .753 .922 r
.3947 .47056 .40083 .47664 .41108 .47332 .40498 .4672 Mtetra
.656 .753 .921 r
.40498 .4672 .41108 .47332 .42137 .46999 .41529 .46384 Mtetra
.41529 .46384 .42137 .46999 .43169 .46664 .42564 .46046 Mtetra
.42564 .46046 .43169 .46664 .44206 .46328 .43603 .45708 Mtetra
.656 .752 .921 r
.43603 .45708 .44206 .46328 .45247 .45991 .44647 .45368 Mtetra
.44647 .45368 .45247 .45991 .46291 .45653 .45694 .45027 Mtetra
.45694 .45027 .46291 .45653 .4734 .45313 .46745 .44685 Mtetra
.46745 .44685 .4734 .45313 .48393 .44972 .47801 .44341 Mtetra
.47801 .44341 .48393 .44972 .4945 .4463 .4886 .43996 Mtetra
.4886 .43996 .4945 .4463 .50511 .44286 .49924 .4365 Mtetra
.49924 .4365 .50511 .44286 .51576 .43942 .50991 .43303 Mtetra
.50991 .43303 .51576 .43942 .52645 .43595 .52063 .42954 Mtetra
.52063 .42954 .52645 .43595 .53718 .43248 .53139 .42604 Mtetra
.53139 .42604 .53718 .43248 .54796 .42899 .5422 .42253 Mtetra
.5422 .42253 .54796 .42899 .55878 .42548 .55304 .419 Mtetra
.55304 .419 .55878 .42548 .56964 .42196 .56393 .41546 Mtetra
.56393 .41546 .56964 .42196 .58054 .41843 .57486 .41191 Mtetra
.57486 .41191 .58054 .41843 .59149 .41489 .58584 .40834 Mtetra
.655 .752 .921 r
.58584 .40834 .59149 .41489 .60247 .41133 .59686 .40476 Mtetra
.655 .753 .921 r
.59686 .40476 .60247 .41133 .61351 .40776 .60792 .40117 Mtetra
.655 .753 .922 r
.60792 .40117 .61351 .40776 .62458 .40417 .61902 .39757 Mtetra
.61902 .39757 .62458 .40417 .6357 .40058 .63018 .39396 Mtetra
.63018 .39396 .6357 .40058 .64687 .39696 .64137 .39034 Mtetra
.655 .754 .923 r
.64137 .39034 .64687 .39696 .65808 .39334 .65261 .38671 Mtetra
.654 .755 .923 r
.65261 .38671 .65808 .39334 .66933 .38971 .6639 .38308 Mtetra
.654 .755 .924 r
.6639 .38308 .66933 .38971 .68063 .38607 .67523 .37944 Mtetra
.653 .756 .925 r
.67523 .37944 .68063 .38607 .69198 .38241 .68661 .3758 Mtetra
.653 .757 .926 r
.68661 .3758 .69198 .38241 .70337 .37875 .69804 .37215 Mtetra
.652 .759 .927 r
.69804 .37215 .70337 .37875 .71481 .37509 .70951 .36851 Mtetra
.652 .76 .929 r
.70951 .36851 .71481 .37509 .72629 .37141 .72103 .36485 Mtetra
.652 .762 .93 r
.72103 .36485 .72629 .37141 .73783 .36773 .7326 .36118 Mtetra
.652 .763 .931 r
.7326 .36118 .73783 .36773 .74941 .36403 .74422 .3575 Mtetra
.652 .765 .932 r
.74422 .3575 .74941 .36403 .76103 .36031 .75588 .35377 Mtetra
.653 .766 .932 r
.75588 .35377 .76103 .36031 .77271 .35656 .76759 .35 Mtetra
.655 .767 .932 r
.76759 .35 .77271 .35656 .78442 .35278 .77934 .34617 Mtetra
.657 .767 .931 r
.77934 .34617 .78442 .35278 .79619 .34896 .79114 .34227 Mtetra
.66 .766 .929 r
.79114 .34227 .79619 .34896 .808 .34508 .80298 .3383 Mtetra
.662 .765 .926 r
.80298 .3383 .808 .34508 .81986 .34116 .81486 .33426 Mtetra
.663 .762 .924 r
.81486 .33426 .81986 .34116 .83176 .33721 .82679 .33016 Mtetra
.664 .759 .921 r
.82679 .33016 .83176 .33721 .8437 .33321 .83876 .32602 Mtetra
.637 .747 .928 r
.20012 .52592 .20671 .53168 .21625 .5288 .20966 .52321 Mtetra
.638 .754 .932 r
.20966 .52321 .21625 .5288 .22584 .52587 .21925 .52046 Mtetra
.639 .761 .936 r
.21925 .52046 .22584 .52587 .23546 .5229 .22888 .51764 Mtetra
.642 .768 .94 r
.22888 .51764 .23546 .5229 .24513 .51987 .23855 .51475 Mtetra
.645 .775 .942 r
.23855 .51475 .24513 .51987 .25483 .51677 .24827 .51175 Mtetra
.649 .78 .944 r
.24827 .51175 .25483 .51677 .26458 .51361 .25803 .50865 Mtetra
.653 .784 .944 r
.25803 .50865 .26458 .51361 .27436 .51039 .26784 .50545 Mtetra
.656 .787 .944 r
.26784 .50545 .27436 .51039 .28419 .50713 .27769 .50216 Mtetra
.659 .787 .943 r
.27769 .50216 .28419 .50713 .29405 .50384 .28758 .4988 Mtetra
.661 .786 .941 r
.28758 .4988 .29405 .50384 .30395 .50053 .29751 .49539 Mtetra
.662 .783 .939 r
.29751 .49539 .30395 .50053 .31389 .49721 .30748 .49196 Mtetra
.662 .78 .936 r
.30748 .49196 .31389 .49721 .32386 .49388 .31748 .48851 Mtetra
.662 .776 .934 r
.31748 .48851 .32386 .49388 .33387 .49056 .32752 .48506 Mtetra
.661 .772 .932 r
.32752 .48506 .33387 .49056 .34391 .48724 .3376 .48162 Mtetra
.661 .768 .93 r
.3376 .48162 .34391 .48724 .35399 .48391 .34771 .47819 Mtetra
.66 .765 .928 r
.34771 .47819 .35399 .48391 .36411 .48058 .35786 .47476 Mtetra
.659 .762 .926 r
.35786 .47476 .36411 .48058 .37427 .47725 .36804 .47134 Mtetra
.658 .76 .925 r
.36804 .47134 .37427 .47725 .38447 .47391 .37827 .46793 Mtetra
.658 .758 .924 r
.37827 .46793 .38447 .47391 .3947 .47056 .38853 .46452 Mtetra
.657 .757 .923 r
.38853 .46452 .3947 .47056 .40498 .4672 .39883 .4611 Mtetra
.657 .755 .922 r
.39883 .4611 .40498 .4672 .41529 .46384 .40917 .45769 Mtetra
.657 .754 .922 r
.40917 .45769 .41529 .46384 .42564 .46046 .41955 .45427 Mtetra
.657 .754 .921 r
.41955 .45427 .42564 .46046 .43603 .45708 .42996 .45085 Mtetra
.656 .753 .921 r
.42996 .45085 .43603 .45708 .44647 .45368 .44042 .44741 Mtetra
.44042 .44741 .44647 .45368 .45694 .45027 .45092 .44397 Mtetra
.656 .752 .921 r
.45092 .44397 .45694 .45027 .46745 .44685 .46146 .44052 Mtetra
.46146 .44052 .46745 .44685 .47801 .44341 .47204 .43705 Mtetra
.47204 .43705 .47801 .44341 .4886 .43996 .48266 .43358 Mtetra
.48266 .43358 .4886 .43996 .49924 .4365 .49332 .43009 Mtetra
.49332 .43009 .49924 .4365 .50991 .43303 .50403 .42659 Mtetra
.50403 .42659 .50991 .43303 .52063 .42954 .51477 .42308 Mtetra
.51477 .42308 .52063 .42954 .53139 .42604 .52556 .41955 Mtetra
.52556 .41955 .53139 .42604 .5422 .42253 .53639 .41602 Mtetra
.655 .752 .921 r
.53639 .41602 .5422 .42253 .55304 .419 .54727 .41247 Mtetra
.54727 .41247 .55304 .419 .56393 .41546 .55818 .40891 Mtetra
.55818 .40891 .56393 .41546 .57486 .41191 .56915 .40535 Mtetra
.655 .753 .922 r
.56915 .40535 .57486 .41191 .58584 .40834 .58015 .40177 Mtetra
.58015 .40177 .58584 .40834 .59686 .40476 .5912 .39819 Mtetra
.654 .754 .923 r
.5912 .39819 .59686 .40476 .60792 .40117 .60229 .3946 Mtetra
.654 .754 .924 r
.60229 .3946 .60792 .40117 .61902 .39757 .61343 .391 Mtetra
.653 .755 .925 r
.61343 .391 .61902 .39757 .63018 .39396 .62461 .38741 Mtetra
.653 .756 .926 r
.62461 .38741 .63018 .39396 .64137 .39034 .63584 .38381 Mtetra
.652 .758 .927 r
.63584 .38381 .64137 .39034 .65261 .38671 .64711 .38022 Mtetra
.651 .76 .929 r
.64711 .38022 .65261 .38671 .6639 .38308 .65844 .37664 Mtetra
.65 .762 .931 r
.65844 .37664 .6639 .38308 .67523 .37944 .6698 .37306 Mtetra
.649 .765 .934 r
.6698 .37306 .67523 .37944 .68661 .3758 .68122 .36949 Mtetra
.648 .768 .936 r
.68122 .36949 .68661 .3758 .69804 .37215 .69269 .36592 Mtetra
.647 .771 .939 r
.69269 .36592 .69804 .37215 .70951 .36851 .7042 .36235 Mtetra
.646 .775 .942 r
.7042 .36235 .70951 .36851 .72103 .36485 .71576 .35876 Mtetra
.646 .778 .944 r
.71576 .35876 .72103 .36485 .7326 .36118 .72737 .35515 Mtetra
.647 .782 .945 r
.72737 .35515 .7326 .36118 .74422 .3575 .73903 .35148 Mtetra
.65 .784 .946 r
.73903 .35148 .74422 .3575 .75588 .35377 .75073 .34774 Mtetra
.653 .786 .945 r
.75073 .34774 .75588 .35377 .76759 .35 .76247 .3439 Mtetra
.657 .786 .943 r
.76247 .3439 .76759 .35 .77934 .34617 .77426 .33995 Mtetra
.661 .784 .94 r
.77426 .33995 .77934 .34617 .79114 .34227 .78608 .3359 Mtetra
.665 .781 .936 r
.78608 .3359 .79114 .34227 .80298 .3383 .79794 .33173 Mtetra
.668 .777 .931 r
.79794 .33173 .80298 .3383 .81486 .33426 .80985 .32747 Mtetra
.67 .771 .926 r
.80985 .32747 .81486 .33426 .82679 .33016 .82179 .32315 Mtetra
.671 .765 .92 r
.82179 .32315 .82679 .33016 .83876 .32602 .83378 .31877 Mtetra
.626 .744 .932 r
.19348 .52013 .20012 .52592 .20966 .52321 .20302 .51763 Mtetra
.626 .752 .938 r
.20302 .51763 .20966 .52321 .21925 .52046 .2126 .51511 Mtetra
.627 .761 .943 r
.2126 .51511 .21925 .52046 .22888 .51764 .22223 .51252 Mtetra
.629 .771 .948 r
.22223 .51252 .22888 .51764 .23855 .51475 .23191 .50984 Mtetra
.633 .781 .952 r
.23191 .50984 .23855 .51475 .24827 .51175 .24163 .50703 Mtetra
.638 .791 .956 r
.24163 .50703 .24827 .51175 .25803 .50865 .2514 .50409 Mtetra
.644 .799 .957 r
.2514 .50409 .25803 .50865 .26784 .50545 .26123 .50099 Mtetra
.649 .805 .958 r
.26123 .50099 .26784 .50545 .27769 .50216 .2711 .49775 Mtetra
.655 .809 .957 r
.2711 .49775 .27769 .50216 .28758 .4988 .28101 .49438 Mtetra
.659 .81 .956 r
.28101 .49438 .28758 .4988 .29751 .49539 .29097 .49092 Mtetra
.662 .809 .954 r
.29097 .49092 .29751 .49539 .30748 .49196 .30097 .48738 Mtetra
.664 .807 .952 r
.30097 .48738 .30748 .49196 .31748 .48851 .31101 .4838 Mtetra
.665 .803 .949 r
.31101 .4838 .31748 .48851 .32752 .48506 .32109 .4802 Mtetra
.665 .798 .946 r
.32109 .4802 .32752 .48506 .3376 .48162 .3312 .47661 Mtetra
.664 .793 .943 r
.3312 .47661 .3376 .48162 .34771 .47819 .34134 .47302 Mtetra
.663 .788 .941 r
.34134 .47302 .34771 .47819 .35786 .47476 .35153 .46945 Mtetra
.662 .783 .938 r
.35153 .46945 .35786 .47476 .36804 .47134 .36174 .4659 Mtetra
.661 .779 .936 r
.36174 .4659 .36804 .47134 .37827 .46793 .372 .46237 Mtetra
.66 .775 .934 r
.372 .46237 .37827 .46793 .38853 .46452 .38229 .45885 Mtetra
.66 .772 .933 r
.38229 .45885 .38853 .46452 .39883 .4611 .39262 .45535 Mtetra
.659 .769 .931 r
.39262 .45535 .39883 .4611 .40917 .45769 .40299 .45185 Mtetra
.658 .767 .93 r
.40299 .45185 .40917 .45769 .41955 .45427 .41339 .44836 Mtetra
.658 .765 .929 r
.41339 .44836 .41955 .45427 .42996 .45085 .42384 .44487 Mtetra
.657 .764 .928 r
.42384 .44487 .42996 .45085 .44042 .44741 .43433 .44138 Mtetra
.657 .762 .928 r
.43433 .44138 .44042 .44741 .45092 .44397 .44485 .43788 Mtetra
.656 .761 .927 r
.44485 .43788 .45092 .44397 .46146 .44052 .45542 .43439 Mtetra
.45542 .43439 .46146 .44052 .47204 .43705 .46603 .43088 Mtetra
.656 .76 .926 r
.46603 .43088 .47204 .43705 .48266 .43358 .47667 .42737 Mtetra
.47667 .42737 .48266 .43358 .49332 .43009 .48736 .42386 Mtetra
.655 .76 .926 r
.48736 .42386 .49332 .43009 .50403 .42659 .4981 .42033 Mtetra
.655 .759 .926 r
.4981 .42033 .50403 .42659 .51477 .42308 .50887 .4168 Mtetra
.655 .76 .927 r
.50887 .4168 .51477 .42308 .52556 .41955 .51969 .41326 Mtetra
.51969 .41326 .52556 .41955 .53639 .41602 .53055 .40971 Mtetra
.654 .76 .927 r
.53055 .40971 .53639 .41602 .54727 .41247 .54145 .40616 Mtetra
.654 .761 .928 r
.54145 .40616 .54727 .41247 .55818 .40891 .5524 .4026 Mtetra
.653 .761 .929 r
.5524 .4026 .55818 .40891 .56915 .40535 .56339 .39904 Mtetra
.653 .762 .93 r
.56339 .39904 .56915 .40535 .58015 .40177 .57442 .39548 Mtetra
.652 .763 .931 r
.57442 .39548 .58015 .40177 .5912 .39819 .5855 .39192 Mtetra
.651 .765 .932 r
.5855 .39192 .5912 .39819 .60229 .3946 .59663 .38836 Mtetra
.65 .767 .934 r
.59663 .38836 .60229 .3946 .61343 .391 .6078 .38481 Mtetra
.649 .769 .936 r
.6078 .38481 .61343 .391 .62461 .38741 .61902 .38128 Mtetra
.647 .771 .939 r
.61902 .38128 .62461 .38741 .63584 .38381 .63028 .37775 Mtetra
.646 .774 .942 r
.63028 .37775 .63584 .38381 .64711 .38022 .64159 .37425 Mtetra
.644 .777 .945 r
.64159 .37425 .64711 .38022 .65844 .37664 .65295 .37076 Mtetra
.642 .781 .948 r
.65295 .37076 .65844 .37664 .6698 .37306 .66436 .36728 Mtetra
.64 .785 .952 r
.66436 .36728 .6698 .37306 .68122 .36949 .67582 .36382 Mtetra
.638 .79 .955 r
.67582 .36382 .68122 .36949 .69269 .36592 .68733 .36036 Mtetra
.637 .794 .958 r
.68733 .36036 .69269 .36592 .7042 .36235 .69889 .35687 Mtetra
.637 .799 .96 r
.69889 .35687 .7042 .36235 .71576 .35876 .71049 .35335 Mtetra
.639 .803 .961 r
.71049 .35335 .71576 .35876 .72737 .35515 .72214 .34975 Mtetra
.643 .806 .961 r
.72214 .34975 .72737 .35515 .73903 .35148 .73384 .34604 Mtetra
.648 .808 .96 r
.73384 .34604 .73903 .35148 .75073 .34774 .74557 .3422 Mtetra
.655 .807 .956 r
.74557 .3422 .75073 .34774 .76247 .3439 .75735 .3382 Mtetra
.662 .805 .951 r
.75735 .3382 .76247 .3439 .77426 .33995 .76916 .33404 Mtetra
.668 .8 .946 r
.76916 .33404 .77426 .33995 .78608 .3359 .781 .32973 Mtetra
.674 .794 .939 r
.781 .32973 .78608 .3359 .79794 .33173 .79288 .32529 Mtetra
.677 .786 .932 r
.79288 .32529 .79794 .33173 .80985 .32747 .8048 .32074 Mtetra
.679 .778 .925 r
.8048 .32074 .80985 .32747 .82179 .32315 .81676 .31612 Mtetra
.68 .77 .919 r
.81676 .31612 .82179 .32315 .83378 .31877 .82876 .31146 Mtetra
.615 .74 .935 r
.18679 .51429 .19348 .52013 .20302 .51763 .19633 .512 Mtetra
.612 .748 .942 r
.19633 .512 .20302 .51763 .2126 .51511 .20591 .50972 Mtetra
.611 .757 .949 r
.20591 .50972 .2126 .51511 .22223 .51252 .21553 .50742 Mtetra
.61 .769 .956 r
.21553 .50742 .22223 .51252 .23191 .50984 .2252 .50506 Mtetra
.611 .782 .963 r
.2252 .50506 .23191 .50984 .24163 .50703 .23491 .5026 Mtetra
.613 .797 .97 r
.23491 .5026 .24163 .50703 .2514 .50409 .24468 .50002 Mtetra
.618 .813 .975 r
.24468 .50002 .2514 .50409 .26123 .50099 .2545 .49725 Mtetra
.623 .828 .979 r
.2545 .49725 .26123 .50099 .2711 .49775 .26438 .49429 Mtetra
.63 .842 .981 r
.26438 .49429 .2711 .49775 .28101 .49438 .27431 .49112 Mtetra
.636 .852 .982 r
.27431 .49112 .28101 .49438 .29097 .49092 .28429 .48777 Mtetra
.643 .858 .981 r
.28429 .48777 .29097 .49092 .30097 .48738 .29432 .48424 Mtetra
.649 .861 .98 r
.29432 .48424 .30097 .48738 .31101 .4838 .30439 .4806 Mtetra
.654 .86 .978 r
.30439 .4806 .31101 .4838 .32109 .4802 .3145 .47686 Mtetra
.658 .857 .976 r
.3145 .47686 .32109 .4802 .3312 .47661 .32466 .47308 Mtetra
.661 .851 .973 r
.32466 .47308 .3312 .47661 .34134 .47302 .33485 .46927 Mtetra
.663 .844 .969 r
.33485 .46927 .34134 .47302 .35153 .46945 .34507 .46547 Mtetra
.664 .835 .966 r
.34507 .46547 .35153 .46945 .36174 .4659 .35533 .46168 Mtetra
.664 .827 .962 r
.35533 .46168 .36174 .4659 .372 .46237 .36563 .45792 Mtetra
.663 .819 .958 r
.36563 .45792 .372 .46237 .38229 .45885 .37596 .45418 Mtetra
.663 .812 .955 r
.37596 .45418 .38229 .45885 .39262 .45535 .38632 .45048 Mtetra
.662 .805 .951 r
.38632 .45048 .39262 .45535 .40299 .45185 .39673 .44681 Mtetra
.661 .799 .949 r
.39673 .44681 .40299 .45185 .41339 .44836 .40717 .44316 Mtetra
.66 .794 .946 r
.40717 .44316 .41339 .44836 .42384 .44487 .41765 .43954 Mtetra
.659 .789 .944 r
.41765 .43954 .42384 .44487 .43433 .44138 .42817 .43593 Mtetra
.658 .785 .942 r
.42817 .43593 .43433 .44138 .44485 .43788 .43872 .43234 Mtetra
.657 .783 .941 r
.43872 .43234 .44485 .43788 .45542 .43439 .44932 .42876 Mtetra
.656 .78 .94 r
.44932 .42876 .45542 .43439 .46603 .43088 .45996 .42519 Mtetra
.656 .778 .939 r
.45996 .42519 .46603 .43088 .47667 .42737 .47064 .42163 Mtetra
.655 .777 .939 r
.47064 .42163 .47667 .42737 .48736 .42386 .48136 .41807 Mtetra
.654 .777 .939 r
.48136 .41807 .48736 .42386 .4981 .42033 .49212 .41452 Mtetra
.653 .776 .939 r
.49212 .41452 .4981 .42033 .50887 .4168 .50292 .41098 Mtetra
.652 .776 .939 r
.50292 .41098 .50887 .4168 .51969 .41326 .51377 .40744 Mtetra
.651 .777 .94 r
.51377 .40744 .51969 .41326 .53055 .40971 .52466 .40391 Mtetra
.65 .778 .942 r
.52466 .40391 .53055 .40971 .54145 .40616 .53559 .40039 Mtetra
.649 .78 .944 r
.53559 .40039 .54145 .40616 .5524 .4026 .54657 .39688 Mtetra
.647 .782 .946 r
.54657 .39688 .5524 .4026 .56339 .39904 .5576 .39339 Mtetra
.645 .785 .949 r
.5576 .39339 .56339 .39904 .57442 .39548 .56867 .38991 Mtetra
.643 .788 .952 r
.56867 .38991 .57442 .39548 .5855 .39192 .57978 .38646 Mtetra
.64 .792 .955 r
.57978 .38646 .5855 .39192 .59663 .38836 .59094 .38303 Mtetra
.637 .797 .96 r
.59094 .38303 .59663 .38836 .6078 .38481 .60215 .37964 Mtetra
.633 .803 .964 r
.60215 .37964 .6078 .38481 .61902 .38128 .61341 .37627 Mtetra
.628 .809 .969 r
.61341 .37627 .61902 .38128 .63028 .37775 .62472 .37293 Mtetra
.623 .815 .974 r
.62472 .37293 .63028 .37775 .64159 .37425 .63608 .36962 Mtetra
.618 .822 .979 r
.63608 .36962 .64159 .37425 .65295 .37076 .64749 .36632 Mtetra
.614 .829 .983 r
.64749 .36632 .65295 .37076 .66436 .36728 .65894 .36303 Mtetra
.61 .836 .986 r
.65894 .36303 .66436 .36728 .67582 .36382 .67045 .35971 Mtetra
.608 .842 .988 r
.67045 .35971 .67582 .36382 .68733 .36036 .68201 .35634 Mtetra
.609 .848 .989 r
.68201 .35634 .68733 .36036 .69889 .35687 .69361 .35288 Mtetra
.615 .851 .988 r
.69361 .35288 .69889 .35687 .71049 .35335 .70526 .34929 Mtetra
.625 .854 .986 r
.70526 .34929 .71049 .35335 .72214 .34975 .71695 .34553 Mtetra
.637 .852 .982 r
.71695 .34553 .72214 .34975 .73384 .34604 .72867 .34157 Mtetra
.651 .848 .976 r
.72867 .34157 .73384 .34604 .74557 .3422 .74043 .33738 Mtetra
.664 .84 .968 r
.74043 .33738 .74557 .3422 .75735 .3382 .75222 .33299 Mtetra
.675 .83 .958 r
.75222 .33299 .75735 .3382 .76916 .33404 .76404 .32841 Mtetra
.682 .818 .948 r
.76404 .32841 .76916 .33404 .781 .32973 .7759 .32368 Mtetra
.686 .805 .938 r
.7759 .32368 .781 .32973 .79288 .32529 .78779 .31885 Mtetra
.689 .793 .929 r
.78779 .31885 .79288 .32529 .8048 .32074 .79972 .31396 Mtetra
.689 .782 .922 r
.79972 .31396 .8048 .32074 .81676 .31612 .81169 .30903 Mtetra
.688 .772 .916 r
.81169 .30903 .81676 .31612 .82876 .31146 .82371 .3041 Mtetra
.61 .739 .937 r
.18006 .50842 .18679 .51429 .19633 .512 .18961 .5062 Mtetra
.605 .741 .941 r
.18961 .5062 .19633 .512 .20591 .50972 .19919 .50406 Mtetra
.601 .745 .946 r
.19919 .50406 .20591 .50972 .21553 .50742 .20881 .50195 Mtetra
.597 .752 .952 r
.20881 .50195 .21553 .50742 .2252 .50506 .21847 .49986 Mtetra
.593 .762 .96 r
.21847 .49986 .2252 .50506 .23491 .5026 .22817 .49778 Mtetra
.591 .777 .968 r
.22817 .49778 .23491 .5026 .24468 .50002 .23792 .49563 Mtetra
.591 .795 .977 r
.23792 .49563 .24468 .50002 .2545 .49725 .24773 .49334 Mtetra
.594 .815 .984 r
.24773 .49334 .2545 .49725 .26438 .49429 .25759 .49086 Mtetra
.599 .836 .989 r
.25759 .49086 .26438 .49429 .27431 .49112 .26752 .48811 Mtetra
.605 .855 .991 r
.26752 .48811 .27431 .49112 .28429 .48777 .2775 .48511 Mtetra
.613 .871 .991 r
.2775 .48511 .28429 .48777 .29432 .48424 .28755 .48183 Mtetra
.62 .882 .989 r
.28755 .48183 .29432 .48424 .30439 .4806 .29764 .47832 Mtetra
.628 .89 .987 r
.29764 .47832 .30439 .4806 .3145 .47686 .30779 .47461 Mtetra
.635 .893 .986 r
.30779 .47461 .3145 .47686 .32466 .47308 .31798 .47077 Mtetra
.641 .894 .985 r
.31798 .47077 .32466 .47308 .33485 .46927 .32821 .46684 Mtetra
.646 .891 .984 r
.32821 .46684 .33485 .46927 .34507 .46547 .33848 .46285 Mtetra
.65 .886 .983 r
.33848 .46285 .34507 .46547 .35533 .46168 .34879 .45886 Mtetra
.653 .88 .982 r
.34879 .45886 .35533 .46168 .36563 .45792 .35913 .45487 Mtetra
.655 .873 .98 r
.35913 .45487 .36563 .45792 .37596 .45418 .36951 .45091 Mtetra
.656 .865 .978 r
.36951 .45091 .37596 .45418 .38632 .45048 .37992 .44698 Mtetra
.656 .858 .977 r
.37992 .44698 .38632 .45048 .39673 .44681 .39036 .4431 Mtetra
.656 .85 .974 r
.39036 .4431 .39673 .44681 .40717 .44316 .40084 .43926 Mtetra
.656 .844 .972 r
.40084 .43926 .40717 .44316 .41765 .43954 .41136 .43546 Mtetra
.655 .838 .971 r
.41136 .43546 .41765 .43954 .42817 .43593 .42192 .4317 Mtetra
.654 .832 .969 r
.42192 .4317 .42817 .43593 .43872 .43234 .43251 .42798 Mtetra
.652 .828 .968 r
.43251 .42798 .43872 .43234 .44932 .42876 .44314 .4243 Mtetra
.651 .824 .966 r
.44314 .4243 .44932 .42876 .45996 .42519 .45382 .42064 Mtetra
.65 .821 .966 r
.45382 .42064 .45996 .42519 .47064 .42163 .46453 .41701 Mtetra
.648 .819 .966 r
.46453 .41701 .47064 .42163 .48136 .41807 .47528 .41341 Mtetra
.646 .818 .966 r
.47528 .41341 .48136 .41807 .49212 .41452 .48608 .40984 Mtetra
.644 .817 .966 r
.48608 .40984 .49212 .41452 .50292 .41098 .49692 .40629 Mtetra
.642 .818 .967 r
.49692 .40629 .50292 .41098 .51377 .40744 .5078 .40277 Mtetra
.639 .818 .969 r
.5078 .40277 .51377 .40744 .52466 .40391 .51872 .39928 Mtetra
.636 .82 .971 r
.51872 .39928 .52466 .40391 .53559 .40039 .52969 .39582 Mtetra
.632 .822 .973 r
.52969 .39582 .53559 .40039 .54657 .39688 .54071 .39239 Mtetra
.628 .825 .976 r
.54071 .39239 .54657 .39688 .5576 .39339 .55177 .389 Mtetra
.623 .828 .979 r
.55177 .389 .5576 .39339 .56867 .38991 .56288 .38565 Mtetra
.617 .832 .983 r
.56288 .38565 .56867 .38991 .57978 .38646 .57403 .38235 Mtetra
.611 .837 .986 r
.57403 .38235 .57978 .38646 .59094 .38303 .58524 .37909 Mtetra
.603 .842 .989 r
.58524 .37909 .59094 .38303 .60215 .37964 .59649 .37587 Mtetra
.594 .847 .992 r
.59649 .37587 .60215 .37964 .61341 .37627 .6078 .37269 Mtetra
.586 .852 .994 r
.6078 .37269 .61341 .37627 .62472 .37293 .61915 .36953 Mtetra
.577 .856 .996 r
.61915 .36953 .62472 .37293 .63608 .36962 .63056 .36639 Mtetra
.57 .861 .996 r
.63056 .36639 .63608 .36962 .64749 .36632 .64202 .36323 Mtetra
.567 .866 .996 r
.64202 .36323 .64749 .36632 .65894 .36303 .65353 .36002 Mtetra
.568 .87 .995 r
.65353 .36002 .65894 .36303 .67045 .35971 .66508 .35672 Mtetra
.575 .874 .994 r
.66508 .35672 .67045 .35971 .68201 .35634 .67668 .35327 Mtetra
.59 .878 .993 r
.67668 .35327 .68201 .35634 .69361 .35288 .68832 .34962 Mtetra
.609 .879 .991 r
.68832 .34962 .69361 .35288 .70526 .34929 .7 .34574 Mtetra
.633 .878 .987 r
.7 .34574 .70526 .34929 .71695 .34553 .71171 .34156 Mtetra
.655 .87 .98 r
.71171 .34156 .71695 .34553 .72867 .34157 .72346 .33711 Mtetra
.674 .859 .97 r
.72346 .33711 .72867 .34157 .74043 .33738 .73522 .33238 Mtetra
.687 .843 .958 r
.73522 .33238 .74043 .33738 .75222 .33299 .74702 .32745 Mtetra
.695 .826 .945 r
.74702 .32745 .75222 .33299 .76404 .32841 .75885 .32236 Mtetra
.698 .81 .934 r
.75885 .32236 .76404 .32841 .7759 .32368 .77071 .3172 Mtetra
.697 .795 .925 r
.77071 .3172 .7759 .32368 .78779 .31885 .78262 .31203 Mtetra
.696 .784 .919 r
.78262 .31203 .78779 .31885 .79972 .31396 .79457 .30687 Mtetra
.694 .775 .914 r
.79457 .30687 .79972 .31396 .81169 .30903 .80657 .30175 Mtetra
.691 .769 .911 r
.80657 .30175 .81169 .30903 .82371 .3041 .81861 .29669 Mtetra
.624 .743 .932 r
.17328 .5025 .18006 .50842 .18961 .5062 .18288 .49999 Mtetra
.619 .732 .927 r
.18288 .49999 .18961 .5062 .19919 .50406 .1925 .49758 Mtetra
.614 .722 .923 r
.1925 .49758 .19919 .50406 .20881 .50195 .20215 .4953 Mtetra
.607 .715 .921 r
.20215 .4953 .20881 .50195 .21847 .49986 .21183 .49317 Mtetra
.598 .711 .923 r
.21183 .49317 .21847 .49986 .22817 .49778 .22154 .49122 Mtetra
.591 .714 .929 r
.22154 .49122 .22817 .49778 .23792 .49563 .23128 .48937 Mtetra
.585 .723 .939 r
.23128 .48937 .23792 .49563 .24773 .49334 .24106 .48758 Mtetra
.581 .741 .952 r
.24106 .48758 .24773 .49334 .25759 .49086 .25089 .48576 Mtetra
.579 .766 .967 r
.25089 .48576 .25759 .49086 .26752 .48811 .26077 .4838 Mtetra
.577 .797 .983 r
.26077 .4838 .26752 .48811 .2775 .48511 .27072 .48163 Mtetra
.575 .83 .993 r
.27072 .48163 .2775 .48511 .28755 .48183 .28073 .47917 Mtetra
.568 .859 .996 r
.28073 .47917 .28755 .48183 .29764 .47832 .2908 .47642 Mtetra
.561 .883 .99 r
.2908 .47642 .29764 .47832 .30779 .47461 .30094 .47336 Mtetra
.549 .898 .977 r
.30094 .47336 .30779 .47461 .31798 .47077 .31114 .47002 Mtetra
.539 .906 .961 r
.31114 .47002 .31798 .47077 .32821 .46684 .32139 .46643 Mtetra
.53 .909 .946 r
.32139 .46643 .32821 .46684 .33848 .46285 .33169 .46266 Mtetra
.525 .911 .935 r
.33169 .46266 .33848 .46285 .34879 .45886 .34203 .45876 Mtetra
.524 .912 .93 r
.34203 .45876 .34879 .45886 .35913 .45487 .35242 .45476 Mtetra
.527 .913 .93 r
.35242 .45476 .35913 .45487 .36951 .45091 .36284 .45072 Mtetra
.532 .914 .933 r
.36284 .45072 .36951 .45091 .37992 .44698 .3733 .44665 Mtetra
.538 .915 .939 r
.3733 .44665 .37992 .44698 .39036 .4431 .3838 .4426 Mtetra
.544 .916 .946 r
.3838 .4426 .39036 .4431 .40084 .43926 .39433 .43857 Mtetra
.551 .915 .953 r
.39433 .43857 .40084 .43926 .41136 .43546 .4049 .43458 Mtetra
.556 .914 .96 r
.4049 .43458 .41136 .43546 .42192 .4317 .41551 .43064 Mtetra
.56 .912 .965 r
.41551 .43064 .42192 .4317 .43251 .42798 .42615 .42676 Mtetra
.562 .91 .97 r
.42615 .42676 .43251 .42798 .44314 .4243 .43683 .42293 Mtetra
.563 .907 .973 r
.43683 .42293 .44314 .4243 .45382 .42064 .44755 .41915 Mtetra
.562 .904 .976 r
.44755 .41915 .45382 .42064 .46453 .41701 .4583 .41544 Mtetra
.56 .902 .978 r
.4583 .41544 .46453 .41701 .47528 .41341 .4691 .41178 Mtetra
.556 .899 .978 r
.4691 .41178 .47528 .41341 .48608 .40984 .47994 .40819 Mtetra
.549 .897 .978 r
.47994 .40819 .48608 .40984 .49692 .40629 .49083 .40465 Mtetra
.541 .894 .977 r
.49083 .40465 .49692 .40629 .5078 .40277 .50175 .40117 Mtetra
.531 .892 .975 r
.50175 .40117 .5078 .40277 .51872 .39928 .51272 .39776 Mtetra
.519 .889 .972 r
.51272 .39776 .51872 .39928 .52969 .39582 .52374 .3944 Mtetra
.505 .886 .967 r
.52374 .3944 .52969 .39582 .54071 .39239 .5348 .39109 Mtetra
.488 .882 .96 r
.5348 .39109 .54071 .39239 .55177 .389 .54591 .38785 Mtetra
.471 .877 .951 r
.54591 .38785 .55177 .389 .56288 .38565 .55707 .38465 Mtetra
.452 .871 .941 r
.55707 .38465 .56288 .38565 .57403 .38235 .56828 .38149 Mtetra
.435 .865 .93 r
.56828 .38149 .57403 .38235 .58524 .37909 .57953 .37836 Mtetra
.419 .859 .92 r
.57953 .37836 .58524 .37909 .59649 .37587 .59084 .37524 Mtetra
.41 .855 .911 r
.59084 .37524 .59649 .37587 .6078 .37269 .6022 .3721 Mtetra
.407 .855 .907 r
.6022 .3721 .6078 .37269 .61915 .36953 .61361 .36891 Mtetra
.416 .859 .91 r
.61361 .36891 .61915 .36953 .63056 .36639 .62507 .36563 Mtetra
.438 .87 .921 r
.62507 .36563 .63056 .36639 .64202 .36323 .63657 .36221 Mtetra
.474 .884 .938 r
.63657 .36221 .64202 .36323 .65353 .36002 .64812 .3586 Mtetra
.522 .899 .959 r
.64812 .3586 .65353 .36002 .66508 .35672 .6597 .35474 Mtetra
.574 .908 .976 r
.6597 .35474 .66508 .35672 .67668 .35327 .67132 .35059 Mtetra
.625 .906 .984 r
.67132 .35059 .67668 .35327 .68832 .34962 .68297 .34611 Mtetra
.664 .89 .98 r
.68297 .34611 .68832 .34962 .7 .34574 .69465 .34133 Mtetra
.69 .865 .965 r
.69465 .34133 .7 .34574 .71171 .34156 .70636 .33623 Mtetra
.704 .835 .945 r
.70636 .33623 .71171 .34156 .72346 .33711 .71809 .33091 Mtetra
.709 .806 .925 r
.71809 .33091 .72346 .33711 .73522 .33238 .72985 .32545 Mtetra
.708 .782 .909 r
.72985 .32545 .73522 .33238 .74702 .32745 .74165 .31993 Mtetra
.704 .763 .898 r
.74165 .31993 .74702 .32745 .75885 .32236 .75349 .31448 Mtetra
.699 .751 .892 r
.75349 .31448 .75885 .32236 .77071 .3172 .76537 .30912 Mtetra
.692 .744 .891 r
.76537 .30912 .77071 .3172 .78262 .31203 .77732 .30395 Mtetra
.687 .743 .893 r
.77732 .30395 .78262 .31203 .79457 .30687 .78931 .29892 Mtetra
.684 .746 .899 r
.78931 .29892 .79457 .30687 .80657 .30175 .80137 .29401 Mtetra
.68 .752 .906 r
.80137 .29401 .80657 .30175 .81861 .29669 .81347 .28921 Mtetra
.652 .751 .922 r
.16646 .49655 .17328 .5025 .18288 .49999 .17614 .49338 Mtetra
.647 .729 .908 r
.17614 .49338 .18288 .49999 .1925 .49758 .18584 .49035 Mtetra
.639 .707 .896 r
.18584 .49035 .1925 .49758 .20215 .4953 .19556 .4875 Mtetra
.628 .688 .887 r
.19556 .4875 .20215 .4953 .21183 .49317 .2053 .48491 Mtetra
.613 .671 .881 r
.2053 .48491 .21183 .49317 .22154 .49122 .21504 .48268 Mtetra
.6 .659 .879 r
.21504 .48268 .22154 .49122 .23128 .48937 .2248 .48076 Mtetra
.586 .652 .882 r
.2248 .48076 .23128 .48937 .24106 .48758 .23457 .47919 Mtetra
.576 .655 .89 r
.23457 .47919 .24106 .48758 .25089 .48576 .24436 .47784 Mtetra
.567 .665 .904 r
.24436 .47784 .25089 .48576 .26077 .4838 .2542 .47661 Mtetra
.562 .687 .924 r
.2542 .47661 .26077 .4838 .27072 .48163 .26409 .47535 Mtetra
.56 .718 .947 r
.26409 .47535 .27072 .48163 .28073 .47917 .27404 .47393 Mtetra
.559 .757 .97 r
.27404 .47393 .28073 .47917 .2908 .47642 .28406 .47225 Mtetra
.559 .8 .989 r
.28406 .47225 .2908 .47642 .30094 .47336 .29416 .47022 Mtetra
.553 .839 .998 r
.29416 .47022 .30094 .47336 .31114 .47002 .30432 .46782 Mtetra
.543 .869 .994 r
.30432 .46782 .31114 .47002 .32139 .46643 .31456 .46504 Mtetra
.528 .888 .978 r
.31456 .46504 .32139 .46643 .33169 .46266 .32485 .46193 Mtetra
.511 .896 .955 r
.32485 .46193 .33169 .46266 .34203 .45876 .33521 .45854 Mtetra
.493 .897 .93 r
.33521 .45854 .34203 .45876 .35242 .45476 .34562 .45491 Mtetra
.478 .894 .908 r
.34562 .45491 .35242 .45476 .36284 .45072 .35608 .45111 Mtetra
.467 .89 .891 r
.35608 .45111 .36284 .45072 .3733 .44665 .36658 .44719 Mtetra
.458 .886 .88 r
.36658 .44719 .3733 .44665 .3838 .4426 .37712 .44321 Mtetra
.452 .884 .873 r
.37712 .44321 .3838 .4426 .39433 .43857 .3877 .43919 Mtetra
.448 .882 .87 r
.3877 .43919 .39433 .43857 .4049 .43458 .39832 .43516 Mtetra
.445 .88 .87 r
.39832 .43516 .4049 .43458 .41551 .43064 .40897 .43116 Mtetra
.442 .878 .872 r
.40897 .43116 .41551 .43064 .42615 .42676 .41967 .42721 Mtetra
.439 .877 .874 r
.41967 .42721 .42615 .42676 .43683 .42293 .4304 .4233 Mtetra
.435 .875 .876 r
.4304 .4233 .43683 .42293 .44755 .41915 .44117 .41946 Mtetra
.43 .872 .877 r
.44117 .41946 .44755 .41915 .4583 .41544 .45198 .4157 Mtetra
.424 .868 .877 r
.45198 .4157 .4583 .41544 .4691 .41178 .46282 .412 Mtetra
.415 .864 .876 r
.46282 .412 .4691 .41178 .47994 .40819 .47371 .40839 Mtetra
.406 .858 .873 r
.47371 .40839 .47994 .40819 .49083 .40465 .48465 .40485 Mtetra
.394 .852 .869 r
.48465 .40485 .49083 .40465 .50175 .40117 .49562 .40138 Mtetra
.382 .845 .864 r
.49562 .40138 .50175 .40117 .51272 .39776 .50665 .39799 Mtetra
.369 .838 .857 r
.50665 .39799 .51272 .39776 .52374 .3944 .51771 .39466 Mtetra
.356 .83 .85 r
.51771 .39466 .52374 .3944 .5348 .39109 .52883 .39139 Mtetra
.345 .824 .843 r
.52883 .39139 .5348 .39109 .54591 .38785 .53999 .38816 Mtetra
.337 .819 .838 r
.53999 .38816 .54591 .38785 .55707 .38465 .5512 .38496 Mtetra
.335 .817 .836 r
.5512 .38496 .55707 .38465 .56828 .38149 .56247 .38175 Mtetra
.34 .82 .84 r
.56247 .38175 .56828 .38149 .57953 .37836 .57378 .37851 Mtetra
.354 .829 .85 r
.57378 .37851 .57953 .37836 .59084 .37524 .58514 .3752 Mtetra
.382 .845 .869 r
.58514 .3752 .59084 .37524 .6022 .3721 .59655 .37177 Mtetra
.423 .866 .896 r
.59655 .37177 .6022 .3721 .61361 .36891 .608 .36816 Mtetra
.477 .889 .927 r
.608 .36816 .61361 .36891 .62507 .36563 .61949 .36432 Mtetra
.54 .909 .957 r
.61949 .36432 .62507 .36563 .63657 .36221 .63103 .36018 Mtetra
.602 .916 .977 r
.63103 .36018 .63657 .36221 .64812 .3586 .64259 .3557 Mtetra
.656 .907 .98 r
.64259 .3557 .64812 .3586 .6597 .35474 .65418 .35081 Mtetra
.694 .882 .968 r
.65418 .35081 .6597 .35474 .67132 .35059 .6658 .34556 Mtetra
.716 .847 .944 r
.6658 .34556 .67132 .35059 .68297 .34611 .67744 .33992 Mtetra
.724 .809 .917 r
.67744 .33992 .68297 .34611 .69465 .34133 .6891 .334 Mtetra
.724 .774 .892 r
.6891 .334 .69465 .34133 .70636 .33623 .70079 .32791 Mtetra
.718 .744 .872 r
.70079 .32791 .70636 .33623 .71809 .33091 .7125 .32178 Mtetra
.709 .72 .858 r
.7125 .32178 .71809 .33091 .72985 .32545 .72426 .31577 Mtetra
.7 .704 .851 r
.72426 .31577 .72985 .32545 .74165 .31993 .73607 .30998 Mtetra
.689 .694 .849 r
.73607 .30998 .74165 .31993 .75349 .31448 .74794 .30453 Mtetra
.681 .691 .853 r
.74794 .30453 .75349 .31448 .76537 .30912 .75987 .2994 Mtetra
.672 .694 .862 r
.75987 .2994 .76537 .30912 .77732 .30395 .77188 .29464 Mtetra
.666 .702 .874 r
.77188 .29464 .77732 .30395 .78931 .29892 .78395 .29015 Mtetra
.662 .715 .888 r
.78395 .29015 .78931 .29892 .80137 .29401 .79609 .28585 Mtetra
.658 .732 .904 r
.79609 .28585 .80137 .29401 .81347 .28921 .8083 .28168 Mtetra
.689 .759 .905 r
.15958 .49055 .16646 .49655 .17614 .49338 .16939 .48642 Mtetra
.683 .728 .885 r
.16939 .48642 .17614 .49338 .18584 .49035 .17921 .48235 Mtetra
.673 .698 .865 r
.17921 .48235 .18584 .49035 .19556 .4875 .18906 .47843 Mtetra
.66 .668 .847 r
.18906 .47843 .19556 .4875 .2053 .48491 .19891 .47476 Mtetra
.645 .639 .83 r
.19891 .47476 .2053 .48491 .21504 .48268 .20876 .47144 Mtetra
.629 .612 .815 r
.20876 .47144 .21504 .48268 .2248 .48076 .21861 .46853 Mtetra
.611 .588 .802 r
.21861 .46853 .2248 .48076 .23457 .47919 .22845 .46612 Mtetra
.596 .568 .792 r
.22845 .46612 .23457 .47919 .24436 .47784 .2383 .46417 Mtetra
.582 .552 .786 r
.2383 .46417 .24436 .47784 .2542 .47661 .24815 .46269 Mtetra
.572 .544 .784 r
.24815 .46269 .2542 .47661 .26409 .47535 .25803 .46154 Mtetra
.565 .542 .788 r
.25803 .46154 .26409 .47535 .27404 .47393 .26793 .46063 Mtetra
.563 .549 .797 r
.26793 .46063 .27404 .47393 .28406 .47225 .27789 .45979 Mtetra
.564 .564 .811 r
.27789 .45979 .28406 .47225 .29416 .47022 .2879 .45888 Mtetra
.569 .587 .832 r
.2879 .45888 .29416 .47022 .30432 .46782 .29798 .4578 Mtetra
.577 .619 .858 r
.29798 .4578 .30432 .46782 .31456 .46504 .30813 .45644 Mtetra
.585 .659 .889 r
.30813 .45644 .31456 .46504 .32485 .46193 .31835 .45479 Mtetra
.593 .707 .922 r
.31835 .45479 .32485 .46193 .33521 .45854 .32864 .45278 Mtetra
.597 .757 .955 r
.32864 .45278 .33521 .45854 .34562 .45491 .339 .45047 Mtetra
.595 .807 .981 r
.339 .45047 .34562 .45491 .35608 .45111 .34943 .44785 Mtetra
.582 .849 .995 r
.34943 .44785 .35608 .45111 .36658 .44719 .35991 .44497 Mtetra
.558 .878 .992 r
.35991 .44497 .36658 .44719 .37712 .44321 .37045 .44187 Mtetra
.523 .89 .973 r
.37045 .44187 .37712 .44321 .3877 .43919 .38104 .4386 Mtetra
.482 .888 .94 r
.38104 .4386 .3877 .43919 .39832 .43516 .39168 .43519 Mtetra
.44 .874 .901 r
.39168 .43519 .39832 .43516 .40897 .43116 .40236 .43168 Mtetra
.399 .855 .86 r
.40236 .43168 .40897 .43116 .41967 .42721 .41309 .4281 Mtetra
.364 .834 .823 r
.41309 .4281 .41967 .42721 .4304 .4233 .42387 .42447 Mtetra
.334 .815 .792 r
.42387 .42447 .4304 .4233 .44117 .41946 .43468 .42083 Mtetra
.311 .799 .768 r
.43468 .42083 .44117 .41946 .45198 .4157 .44554 .41718 Mtetra
.294 .787 .751 r
.44554 .41718 .45198 .4157 .46282 .412 .45644 .41354 Mtetra
.285 .78 .742 r
.45644 .41354 .46282 .412 .47371 .40839 .46739 .4099 Mtetra
.282 .778 .741 r
.46739 .4099 .47371 .40839 .48465 .40485 .47838 .40627 Mtetra
.287 .782 .748 r
.47838 .40627 .48465 .40485 .49562 .40138 .48941 .40265 Mtetra
.3 .792 .763 r
.48941 .40265 .49562 .40138 .50665 .39799 .50049 .39902 Mtetra
.323 .808 .788 r
.50049 .39902 .50665 .39799 .51771 .39466 .51162 .39537 Mtetra
.357 .83 .821 r
.51162 .39537 .51771 .39466 .52883 .39139 .52279 .39168 Mtetra
.401 .856 .861 r
.52279 .39168 .52883 .39139 .53999 .38816 .534 .38791 Mtetra
.456 .883 .904 r
.534 .38791 .53999 .38816 .5512 .38496 .54526 .38405 Mtetra
.517 .904 .944 r
.54526 .38405 .5512 .38496 .56247 .38175 .55657 .38004 Mtetra
.578 .912 .974 r
.55657 .38004 .56247 .38175 .57378 .37851 .56792 .37585 Mtetra
.631 .903 .985 r
.56792 .37585 .57378 .37851 .58514 .3752 .5793 .37143 Mtetra
.67 .876 .976 r
.5793 .37143 .58514 .3752 .59655 .37177 .59073 .36675 Mtetra
.695 .836 .951 r
.59073 .36675 .59655 .37177 .608 .36816 .60219 .36175 Mtetra
.707 .792 .917 r
.60219 .36175 .608 .36816 .61949 .36432 .61367 .35643 Mtetra
.71 .748 .881 r
.61367 .35643 .61949 .36432 .63103 .36018 .62519 .35074 Mtetra
.708 .708 .848 r
.62519 .35074 .63103 .36018 .64259 .3557 .63673 .34474 Mtetra
.703 .675 .82 r
.63673 .34474 .64259 .3557 .65418 .35081 .64828 .33844 Mtetra
.696 .647 .797 r
.64828 .33844 .65418 .35081 .6658 .34556 .65987 .33195 Mtetra
.689 .626 .78 r
.65987 .33195 .6658 .34556 .67744 .33992 .67148 .32538 Mtetra
.681 .61 .769 r
.67148 .32538 .67744 .33992 .6891 .334 .68312 .31888 Mtetra
.674 .599 .764 r
.68312 .31888 .6891 .334 .70079 .32791 .6948 .31261 Mtetra
.667 .594 .764 r
.6948 .31261 .70079 .32791 .7125 .32178 .70654 .30667 Mtetra
.659 .592 .769 r
.70654 .30667 .7125 .32178 .72426 .31577 .71834 .30121 Mtetra
.652 .596 .779 r
.71834 .30121 .72426 .31577 .73607 .30998 .73021 .29622 Mtetra
.646 .604 .793 r
.73021 .29622 .73607 .30998 .74794 .30453 .74216 .29175 Mtetra
.64 .617 .811 r
.74216 .29175 .74794 .30453 .75987 .2994 .7542 .2877 Mtetra
.635 .634 .833 r
.7542 .2877 .75987 .2994 .77188 .29464 .76631 .28401 Mtetra
.631 .655 .856 r
.76631 .28401 .77188 .29464 .78395 .29015 .7785 .28058 Mtetra
.627 .68 .88 r
.7785 .28058 .78395 .29015 .79609 .28585 .79076 .27731 Mtetra
.625 .707 .905 r
.79076 .27731 .79609 .28585 .8083 .28168 .80308 .27409 Mtetra
.718 .764 .889 r
.15266 .48451 .15958 .49055 .16939 .48642 .16259 .47945 Mtetra
.713 .736 .869 r
.16259 .47945 .16939 .48642 .17921 .48235 .17255 .47433 Mtetra
.705 .707 .85 r
.17255 .47433 .17921 .48235 .18906 .47843 .18253 .46924 Mtetra
.693 .677 .83 r
.18253 .46924 .18906 .47843 .19891 .47476 .19252 .46427 Mtetra
.68 .647 .811 r
.19252 .46427 .19891 .47476 .20876 .47144 .20252 .4595 Mtetra
.663 .616 .792 r
.20252 .4595 .20876 .47144 .21861 .46853 .21252 .45508 Mtetra
.644 .586 .775 r
.21252 .45508 .21861 .46853 .22845 .46612 .2225 .45114 Mtetra
.625 .558 .759 r
.2225 .45114 .22845 .46612 .2383 .46417 .23246 .44779 Mtetra
.605 .532 .746 r
.23246 .44779 .2383 .46417 .24815 .46269 .2424 .44515 Mtetra
.587 .511 .736 r
.2424 .44515 .24815 .46269 .25803 .46154 .25232 .44317 Mtetra
.571 .495 .73 r
.25232 .44317 .25803 .46154 .26793 .46063 .26224 .44187 Mtetra
.559 .485 .728 r
.26224 .44187 .26793 .46063 .27789 .45979 .27217 .44109 Mtetra
.55 .48 .73 r
.27217 .44109 .27789 .45979 .2879 .45888 .28212 .44069 Mtetra
.546 .482 .736 r
.28212 .44069 .2879 .45888 .29798 .4578 .29212 .44048 Mtetra
.545 .491 .746 r
.29212 .44048 .29798 .4578 .30813 .45644 .30218 .44028 Mtetra
.547 .505 .76 r
.30218 .44028 .30813 .45644 .31835 .45479 .3123 .43997 Mtetra
.553 .525 .778 r
.3123 .43997 .31835 .45479 .32864 .45278 .3225 .43942 Mtetra
.561 .551 .8 r
.3225 .43942 .32864 .45278 .339 .45047 .33277 .43859 Mtetra
.571 .581 .825 r
.33277 .43859 .339 .45047 .34943 .44785 .34312 .4374 Mtetra
.581 .616 .852 r
.34312 .4374 .34943 .44785 .35991 .44497 .35354 .43588 Mtetra
.591 .654 .88 r
.35354 .43588 .35991 .44497 .37045 .44187 .36403 .43401 Mtetra
.6 .692 .907 r
.36403 .43401 .37045 .44187 .38104 .4386 .37459 .43183 Mtetra
.608 .731 .932 r
.37459 .43183 .38104 .4386 .39168 .43519 .38521 .42936 Mtetra
.612 .766 .953 r
.38521 .42936 .39168 .43519 .40236 .43168 .39589 .42665 Mtetra
.614 .797 .969 r
.39589 .42665 .40236 .43168 .41309 .4281 .40663 .42372 Mtetra
.614 .822 .98 r
.40663 .42372 .41309 .4281 .42387 .42447 .41742 .4206 Mtetra
.612 .842 .987 r
.41742 .4206 .42387 .42447 .43468 .42083 .42826 .41732 Mtetra
.611 .856 .99 r
.42826 .41732 .43468 .42083 .44554 .41718 .43915 .4139 Mtetra
.612 .866 .991 r
.43915 .4139 .44554 .41718 .45644 .41354 .45009 .41036 Mtetra
.615 .871 .99 r
.45009 .41036 .45644 .41354 .46739 .4099 .46108 .4067 Mtetra
.621 .873 .989 r
.46108 .4067 .46739 .4099 .47838 .40627 .47211 .40292 Mtetra
.631 .872 .987 r
.47211 .40292 .47838 .40627 .48941 .40265 .48319 .39902 Mtetra
.644 .866 .983 r
.48319 .39902 .48941 .40265 .50049 .39902 .49431 .39497 Mtetra
.658 .855 .975 r
.49431 .39497 .50049 .39902 .51162 .39537 .50548 .39076 Mtetra
.672 .839 .963 r
.50548 .39076 .51162 .39537 .52279 .39168 .51669 .38637 Mtetra
.685 .818 .947 r
.51669 .38637 .52279 .39168 .534 .38791 .52794 .38175 Mtetra
.695 .791 .925 r
.52794 .38175 .534 .38791 .54526 .38405 .53923 .37687 Mtetra
.701 .762 .899 r
.53923 .37687 .54526 .38405 .55657 .38004 .55055 .37169 Mtetra
.703 .73 .871 r
.55055 .37169 .55657 .38004 .56792 .37585 .56191 .3662 Mtetra
.703 .699 .843 r
.56191 .3662 .56792 .37585 .5793 .37143 .5733 .36034 Mtetra
.7 .669 .816 r
.5733 .36034 .5793 .37143 .59073 .36675 .58471 .35413 Mtetra
.696 .642 .791 r
.58471 .35413 .59073 .36675 .60219 .36175 .59615 .34756 Mtetra
.691 .617 .769 r
.59615 .34756 .60219 .36175 .61367 .35643 .60761 .34068 Mtetra
.685 .596 .751 r
.60761 .34068 .61367 .35643 .62519 .35074 .61908 .33354 Mtetra
.678 .578 .736 r
.61908 .33354 .62519 .35074 .63673 .34474 .63058 .32627 Mtetra
.671 .563 .725 r
.63058 .32627 .63673 .34474 .64828 .33844 .6421 .319 Mtetra
.663 .552 .718 r
.6421 .319 .64828 .33844 .65987 .33195 .65365 .31192 Mtetra
.655 .542 .715 r
.65365 .31192 .65987 .33195 .67148 .32538 .66524 .30522 Mtetra
.646 .537 .716 r
.66524 .30522 .67148 .32538 .68312 .31888 .67689 .29904 Mtetra
.637 .534 .721 r
.67689 .29904 .68312 .31888 .6948 .31261 .68861 .29355 Mtetra
.629 .536 .73 r
.68861 .29355 .6948 .31261 .70654 .30667 .7004 .28874 Mtetra
.621 .541 .743 r
.7004 .28874 .70654 .30667 .71834 .30121 .71228 .28466 Mtetra
.614 .552 .761 r
.71228 .28466 .71834 .30121 .73021 .29622 .72426 .28119 Mtetra
.607 .567 .783 r
.72426 .28119 .73021 .29622 .74216 .29175 .73632 .27823 Mtetra
.602 .586 .808 r
.73632 .27823 .74216 .29175 .7542 .2877 .74847 .27562 Mtetra
.598 .61 .834 r
.74847 .27562 .7542 .2877 .76631 .28401 .7607 .27323 Mtetra
.595 .635 .861 r
.7607 .27323 .76631 .28401 .7785 .28058 .773 .27096 Mtetra
.592 .663 .888 r
.773 .27096 .7785 .28058 .79076 .27731 .78538 .26873 Mtetra
.59 .691 .913 r
.78538 .26873 .79076 .27731 .80308 .27409 .79782 .26643 Mtetra
.725 .765 .884 r
.14569 .47843 .15266 .48451 .16259 .47945 .15567 .47308 Mtetra
.727 .757 .877 r
.15567 .47308 .16259 .47945 .17255 .47433 .16569 .4676 Mtetra
.727 .747 .869 r
.16569 .4676 .17255 .47433 .18253 .46924 .17575 .46201 Mtetra
.725 .734 .858 r
.17575 .46201 .18253 .46924 .19252 .46427 .18583 .45633 Mtetra
.721 .716 .845 r
.18583 .45633 .19252 .46427 .20252 .4595 .19595 .45059 Mtetra
.711 .691 .829 r
.19595 .45059 .20252 .4595 .21252 .45508 .20608 .4449 Mtetra
.698 .662 .811 r
.20608 .4449 .21252 .45508 .2225 .45114 .21623 .43936 Mtetra
.68 .628 .79 r
.21623 .43936 .2225 .45114 .23246 .44779 .22636 .43414 Mtetra
.659 .593 .769 r
.22636 .43414 .23246 .44779 .2424 .44515 .23649 .42938 Mtetra
.638 .557 .748 r
.23649 .42938 .2424 .44515 .25232 .44317 .24659 .42517 Mtetra
.616 .525 .728 r
.24659 .42517 .25232 .44317 .26224 .44187 .25668 .42163 Mtetra
.598 .497 .71 r
.25668 .42163 .26224 .44187 .27217 .44109 .26675 .41874 Mtetra
.582 .474 .696 r
.26675 .41874 .27217 .44109 .28212 .44069 .27681 .4165 Mtetra
.571 .457 .685 r
.27681 .4165 .28212 .44069 .29212 .44048 .28687 .41479 Mtetra
.562 .444 .676 r
.28687 .41479 .29212 .44048 .30218 .44028 .29696 .4135 Mtetra
.557 .436 .671 r
.29696 .4135 .30218 .44028 .3123 .43997 .30708 .41249 Mtetra
.554 .431 .667 r
.30708 .41249 .3123 .43997 .3225 .43942 .31725 .41163 Mtetra
.553 .43 .666 r
.31725 .41163 .3225 .43942 .33277 .43859 .32747 .4108 Mtetra
.554 .431 .666 r
.32747 .4108 .33277 .43859 .34312 .4374 .33776 .40989 Mtetra
.556 .434 .668 r
.33776 .40989 .34312 .4374 .35354 .43588 .34811 .40885 Mtetra
.56 .438 .671 r
.34811 .40885 .35354 .43588 .36403 .43401 .35852 .4076 Mtetra
.564 .444 .675 r
.35852 .4076 .36403 .43401 .37459 .43183 .36901 .40612 Mtetra
.569 .451 .679 r
.36901 .40612 .37459 .43183 .38521 .42936 .37956 .40437 Mtetra
.574 .458 .683 r
.37956 .40437 .38521 .42936 .39589 .42665 .39017 .40235 Mtetra
.579 .465 .688 r
.39017 .40235 .39589 .42665 .40663 .42372 .40085 .40005 Mtetra
.584 .472 .692 r
.40085 .40005 .40663 .42372 .41742 .4206 .4116 .39746 Mtetra
.59 .479 .695 r
.4116 .39746 .41742 .4206 .42826 .41732 .42239 .39459 Mtetra
.595 .485 .698 r
.42239 .39459 .42826 .41732 .43915 .4139 .43325 .39144 Mtetra
.6 .489 .7 r
.43325 .39144 .43915 .4139 .45009 .41036 .44416 .38802 Mtetra
.604 .493 .7 r
.44416 .38802 .45009 .41036 .46108 .4067 .45512 .38431 Mtetra
.608 .496 .7 r
.45512 .38431 .46108 .4067 .47211 .40292 .46613 .38034 Mtetra
.612 .497 .698 r
.46613 .38034 .47211 .40292 .48319 .39902 .47719 .37608 Mtetra
.615 .497 .696 r
.47719 .37608 .48319 .39902 .49431 .39497 .48829 .37154 Mtetra
.617 .496 .692 r
.48829 .37154 .49431 .39497 .50548 .39076 .49944 .36672 Mtetra
.619 .494 .688 r
.49944 .36672 .50548 .39076 .51669 .38637 .51062 .3616 Mtetra
.621 .492 .684 r
.51062 .3616 .51669 .38637 .52794 .38175 .52184 .35619 Mtetra
.622 .489 .679 r
.52184 .35619 .52794 .38175 .53923 .37687 .5331 .3505 Mtetra
.623 .486 .674 r
.5331 .3505 .53923 .37687 .55055 .37169 .54438 .34452 Mtetra
.623 .483 .67 r
.54438 .34452 .55055 .37169 .56191 .3662 .5557 .33831 Mtetra
.624 .48 .667 r
.5557 .33831 .56191 .3662 .5733 .36034 .56704 .33187 Mtetra
.624 .478 .664 r
.56704 .33187 .5733 .36034 .58471 .35413 .5784 .32529 Mtetra
.623 .477 .662 r
.5784 .32529 .58471 .35413 .59615 .34756 .5898 .31862 Mtetra
.623 .476 .662 r
.5898 .31862 .59615 .34756 .60761 .34068 .60122 .31197 Mtetra
.622 .476 .663 r
.60122 .31197 .60761 .34068 .61908 .33354 .61267 .30546 Mtetra
.62 .478 .666 r
.61267 .30546 .61908 .33354 .63058 .32627 .62416 .29922 Mtetra
.618 .481 .672 r
.62416 .29922 .63058 .32627 .6421 .319 .63569 .29341 Mtetra
.615 .486 .681 r
.63569 .29341 .6421 .319 .65365 .31192 .64729 .28814 Mtetra
.611 .492 .693 r
.64729 .28814 .65365 .31192 .66524 .30522 .65895 .28353 Mtetra
.607 .503 .709 r
.65895 .28353 .66524 .30522 .67689 .29904 .67068 .27958 Mtetra
.602 .516 .73 r
.67068 .27958 .67689 .29904 .68861 .29355 .6825 .27632 Mtetra
.596 .534 .755 r
.6825 .27632 .68861 .29355 .7004 .28874 .69441 .27364 Mtetra
.589 .556 .784 r
.69441 .27364 .7004 .28874 .71228 .28466 .70641 .27144 Mtetra
.583 .58 .815 r
.70641 .27144 .71228 .28466 .72426 .28119 .7185 .26956 Mtetra
.578 .608 .846 r
.7185 .26956 .72426 .28119 .73632 .27823 .73066 .26785 Mtetra
.573 .634 .873 r
.73066 .26785 .73632 .27823 .74847 .27562 .74291 .2662 Mtetra
.572 .658 .895 r
.74291 .2662 .74847 .27562 .7607 .27323 .75521 .26448 Mtetra
.571 .678 .912 r
.75521 .26448 .7607 .27323 .773 .27096 .76759 .26268 Mtetra
.572 .693 .923 r
.76759 .26268 .773 .27096 .78538 .26873 .78003 .26077 Mtetra
.574 .705 .931 r
.78003 .26077 .78538 .26873 .79782 .26643 .79252 .25872 Mtetra
.714 .763 .891 r
.13868 .4723 .14569 .47843 .15567 .47308 .14864 .46731 Mtetra
.721 .776 .896 r
.14864 .46731 .15567 .47308 .16569 .4676 .15865 .46215 Mtetra
.729 .788 .9 r
.15865 .46215 .16569 .4676 .17575 .46201 .1687 .45677 Mtetra
.738 .797 .9 r
.1687 .45677 .17575 .46201 .18583 .45633 .17882 .45112 Mtetra
.748 .799 .894 r
.17882 .45112 .18583 .45633 .19595 .45059 .18899 .44511 Mtetra
.753 .792 .884 r
.18899 .44511 .19595 .45059 .20608 .4449 .19921 .43881 Mtetra
.755 .774 .868 r
.19921 .43881 .20608 .4449 .21623 .43936 .20948 .4322 Mtetra
.749 .744 .848 r
.20948 .4322 .21623 .43936 .22636 .43414 .21978 .42545 Mtetra
.736 .706 .822 r
.21978 .42545 .22636 .43414 .23649 .42938 .23011 .41864 Mtetra
.715 .661 .794 r
.23011 .41864 .23649 .42938 .24659 .42517 .24044 .41198 Mtetra
.691 .615 .766 r
.24044 .41198 .24659 .42517 .25668 .42163 .25076 .40567 Mtetra
.665 .571 .739 r
.25076 .40567 .25668 .42163 .26675 .41874 .26106 .39985 Mtetra
.64 .532 .716 r
.26106 .39985 .26675 .41874 .27681 .4165 .27133 .3947 Mtetra
.619 .5 .696 r
.27133 .3947 .27681 .4165 .28687 .41479 .28158 .39023 Mtetra
.6 .474 .68 r
.28158 .39023 .28687 .41479 .29696 .4135 .2918 .38651 Mtetra
.586 .454 .668 r
.2918 .38651 .29696 .4135 .30708 .41249 .30202 .38341 Mtetra
.575 .439 .658 r
.30202 .38341 .30708 .41249 .31725 .41163 .31225 .38087 Mtetra
.567 .428 .651 r
.31225 .38087 .31725 .41163 .32747 .4108 .32249 .37876 Mtetra
.562 .421 .647 r
.32249 .37876 .32747 .4108 .33776 .40989 .33277 .37695 Mtetra
.559 .416 .643 r
.33277 .37695 .33776 .40989 .34811 .40885 .34308 .37533 Mtetra
.558 .414 .642 r
.34308 .37533 .34811 .40885 .35852 .4076 .35345 .37377 Mtetra
.558 .413 .641 r
.35345 .37377 .35852 .4076 .36901 .40612 .36387 .37219 Mtetra
.559 .414 .641 r
.36387 .37219 .36901 .40612 .37956 .40437 .37435 .37049 Mtetra
.561 .416 .641 r
.37435 .37049 .37956 .40437 .39017 .40235 .38489 .36862 Mtetra
.564 .419 .642 r
.38489 .36862 .39017 .40235 .40085 .40005 .3955 .36651 Mtetra
.567 .422 .643 r
.3955 .36651 .40085 .40005 .4116 .39746 .40617 .36412 Mtetra
.571 .425 .644 r
.40617 .36412 .4116 .39746 .42239 .39459 .4169 .36141 Mtetra
.575 .428 .645 r
.4169 .36141 .42239 .39459 .43325 .39144 .42769 .35837 Mtetra
.579 .432 .645 r
.42769 .35837 .43325 .39144 .44416 .38802 .43853 .35498 Mtetra
.583 .435 .645 r
.43853 .35498 .44416 .38802 .45512 .38431 .44944 .35123 Mtetra
.587 .437 .645 r
.44944 .35123 .45512 .38431 .46613 .38034 .46039 .34712 Mtetra
.591 .44 .645 r
.46039 .34712 .46613 .38034 .47719 .37608 .47139 .34265 Mtetra
.594 .441 .644 r
.47139 .34265 .47719 .37608 .48829 .37154 .48243 .33785 Mtetra
.597 .442 .643 r
.48243 .33785 .48829 .37154 .49944 .36672 .49352 .33272 Mtetra
.599 .443 .642 r
.49352 .33272 .49944 .36672 .51062 .3616 .50464 .32731 Mtetra
.601 .444 .641 r
.50464 .32731 .51062 .3616 .52184 .35619 .5158 .32165 Mtetra
.602 .444 .64 r
.5158 .32165 .52184 .35619 .5331 .3505 .52699 .3158 Mtetra
.603 .444 .64 r
.52699 .3158 .5331 .3505 .54438 .34452 .53821 .30983 Mtetra
.53821 .30983 .54438 .34452 .5557 .33831 .54946 .30383 Mtetra
.603 .445 .64 r
.54946 .30383 .5557 .33831 .56704 .33187 .56074 .29789 Mtetra
.602 .446 .642 r
.56074 .29789 .56704 .33187 .5784 .32529 .57206 .29212 Mtetra
.6 .447 .645 r
.57206 .29212 .5784 .32529 .5898 .31862 .58342 .28666 Mtetra
.598 .449 .65 r
.58342 .28666 .5898 .31862 .60122 .31197 .59482 .28163 Mtetra
.594 .452 .657 r
.59482 .28163 .60122 .31197 .61267 .30546 .60628 .27716 Mtetra
.59 .457 .668 r
.60628 .27716 .61267 .30546 .62416 .29922 .6178 .27334 Mtetra
.585 .464 .682 r
.6178 .27334 .62416 .29922 .63569 .29341 .62939 .27028 Mtetra
.579 .475 .701 r
.62939 .27028 .63569 .29341 .64729 .28814 .64107 .26791 Mtetra
.571 .491 .726 r
.64107 .26791 .64729 .28814 .65895 .28353 .65284 .26624 Mtetra
.563 .513 .758 r
.65284 .26624 .65895 .28353 .67068 .27958 .6647 .26509 Mtetra
.554 .544 .798 r
.6647 .26509 .67068 .27958 .6825 .27632 .67665 .26429 Mtetra
.544 .58 .842 r
.67665 .26429 .6825 .27632 .69441 .27364 .68868 .26367 Mtetra
.535 .623 .886 r
.68868 .26367 .69441 .27364 .70641 .27144 .70079 .26299 Mtetra
.527 .663 .922 r
.70079 .26299 .70641 .27144 .7185 .26956 .71297 .26217 Mtetra
.528 .698 .947 r
.71297 .26217 .7185 .26956 .73066 .26785 .72521 .26105 Mtetra
.533 .723 .96 r
.72521 .26105 .73066 .26785 .74291 .2662 .7375 .25961 Mtetra
.547 .738 .964 r
.7375 .25961 .74291 .2662 .75521 .26448 .74985 .25782 Mtetra
.562 .743 .962 r
.74985 .25782 .75521 .26448 .76759 .26268 .76224 .25574 Mtetra
.575 .741 .955 r
.76224 .25574 .76759 .26268 .78003 .26077 .77468 .25343 Mtetra
.586 .733 .945 r
.77468 .25343 .78003 .26077 .79252 .25872 .78718 .25095 Mtetra
.681 .757 .909 r
.13161 .46613 .13868 .4723 .14864 .46731 .14148 .46213 Mtetra
.687 .792 .93 r
.14148 .46213 .14864 .46731 .15865 .46215 .1514 .45798 Mtetra
.694 .83 .948 r
.1514 .45798 .15865 .46215 .1687 .45677 .16137 .45362 Mtetra
.701 .869 .961 r
.16137 .45362 .1687 .45677 .17882 .45112 .17141 .44895 Mtetra
.709 .905 .965 r
.17141 .44895 .17882 .45112 .18899 .44511 .18152 .4439 Mtetra
.712 .936 .961 r
.18152 .4439 .18899 .44511 .19921 .43881 .19169 .43843 Mtetra
.715 .958 .947 r
.19169 .43843 .19921 .43881 .20948 .4322 .20194 .43249 Mtetra
.714 .971 .93 r
.20194 .43249 .20948 .4322 .21978 .42545 .21225 .42615 Mtetra
.719 .978 .916 r
.21225 .42615 .21978 .42545 .23011 .41864 .22262 .41943 Mtetra
.727 .981 .911 r
.22262 .41943 .23011 .41864 .24044 .41198 .23303 .41247 Mtetra
.743 .979 .916 r
.23303 .41247 .24044 .41198 .25076 .40567 .24346 .40539 Mtetra
.761 .967 .929 r
.24346 .40539 .25076 .40567 .26106 .39985 .25391 .39835 Mtetra
.772 .936 .936 r
.25391 .39835 .26106 .39985 .27133 .3947 .26436 .3915 Mtetra
.768 .88 .928 r
.26436 .3915 .27133 .3947 .28158 .39023 .2748 .38498 Mtetra
.747 .809 .901 r
.2748 .38498 .28158 .39023 .2918 .38651 .28523 .37888 Mtetra
.719 .733 .863 r
.28523 .37888 .2918 .38651 .30202 .38341 .29565 .37323 Mtetra
.688 .666 .823 r
.29565 .37323 .30202 .38341 .31225 .38087 .30607 .36807 Mtetra
.662 .61 .786 r
.30607 .36807 .31225 .38087 .32249 .37876 .31648 .36333 Mtetra
.64 .566 .755 r
.31648 .36333 .32249 .37876 .33277 .37695 .32691 .35898 Mtetra
.623 .532 .73 r
.32691 .35898 .33277 .37695 .34308 .37533 .33735 .35495 Mtetra
.61 .506 .71 r
.33735 .35495 .34308 .37533 .35345 .37377 .34781 .35118 Mtetra
.601 .486 .695 r
.34781 .35118 .35345 .37377 .36387 .37219 .35831 .3476 Mtetra
.594 .472 .682 r
.35831 .3476 .36387 .37219 .37435 .37049 .36884 .34414 Mtetra
.59 .461 .673 r
.36884 .34414 .37435 .37049 .38489 .36862 .37941 .34076 Mtetra
.587 .452 .665 r
.37941 .34076 .38489 .36862 .3955 .36651 .39002 .33739 Mtetra
.585 .447 .659 r
.39002 .33739 .3955 .36651 .40617 .36412 .40067 .33399 Mtetra
.584 .443 .655 r
.40067 .33399 .40617 .36412 .4169 .36141 .41138 .33052 Mtetra
.584 .44 .652 r
.41138 .33052 .4169 .36141 .42769 .35837 .42213 .32696 Mtetra
.584 .439 .65 r
.42213 .32696 .42769 .35837 .43853 .35498 .43293 .32329 Mtetra
.585 .439 .649 r
.43293 .32329 .43853 .35498 .44944 .35123 .44377 .31949 Mtetra
.586 .44 .649 r
.44377 .31949 .44944 .35123 .46039 .34712 .45466 .31556 Mtetra
.588 .442 .65 r
.45466 .31556 .46039 .34712 .47139 .34265 .4656 .31152 Mtetra
.589 .444 .652 r
.4656 .31152 .47139 .34265 .48243 .33785 .47658 .30739 Mtetra
.591 .448 .655 r
.47658 .30739 .48243 .33785 .49352 .33272 .4876 .30318 Mtetra
.593 .452 .659 r
.4876 .30318 .49352 .33272 .50464 .32731 .49867 .29895 Mtetra
.595 .458 .665 r
.49867 .29895 .50464 .32731 .5158 .32165 .50978 .29473 Mtetra
.597 .466 .672 r
.50978 .29473 .5158 .32165 .52699 .3158 .52093 .29057 Mtetra
.599 .475 .682 r
.52093 .29057 .52699 .3158 .53821 .30983 .53212 .28655 Mtetra
.601 .486 .695 r
.53212 .28655 .53821 .30983 .54946 .30383 .54336 .28271 Mtetra
.602 .501 .711 r
.54336 .28271 .54946 .30383 .56074 .29789 .55465 .27914 Mtetra
.603 .52 .734 r
.55465 .27914 .56074 .29789 .57206 .29212 .566 .27589 Mtetra
.602 .545 .763 r
.566 .27589 .57206 .29212 .58342 .28666 .5774 .27304 Mtetra
.597 .577 .802 r
.5774 .27304 .58342 .28666 .59482 .28163 .58887 .27062 Mtetra
.585 .62 .853 r
.58887 .27062 .59482 .28163 .60628 .27716 .6004 .2687 Mtetra
.558 .673 .914 r
.6004 .2687 .60628 .27716 .6178 .27334 .61202 .26725 Mtetra
.5 .727 .974 r
.61202 .26725 .6178 .27334 .62939 .27028 .62372 .26624 Mtetra
.399 .757 .994 r
.62372 .26624 .62939 .27028 .64107 .26791 .6355 .26557 Mtetra
.263 .736 .94 r
.6355 .26557 .64107 .26791 .65284 .26624 .64737 .26511 Mtetra
.148 .683 .847 r
.64737 .26511 .65284 .26624 .6647 .26509 .65931 .26471 Mtetra
.089 .647 .777 r
.65931 .26471 .6647 .26509 .67665 .26429 .67133 .26418 Mtetra
.086 .646 .757 r
.67133 .26418 .67665 .26429 .68868 .26367 .68342 .26342 Mtetra
.137 .683 .788 r
.68342 .26342 .68868 .26367 .70079 .26299 .69556 .26227 Mtetra
.222 .741 .851 r
.69556 .26227 .70079 .26299 .71297 .26217 .70776 .2607 Mtetra
.332 .802 .923 r
.70776 .2607 .71297 .26217 .72521 .26105 .71999 .25866 Mtetra
.436 .839 .975 r
.71999 .25866 .72521 .26105 .7375 .25961 .73227 .25619 Mtetra
.521 .849 .997 r
.73227 .25619 .7375 .25961 .74985 .25782 .74459 .25331 Mtetra
.576 .835 .994 r
.74459 .25331 .74985 .25782 .76224 .25574 .75695 .25011 Mtetra
.609 .807 .976 r
.75695 .25011 .76224 .25574 .77468 .25343 .76935 .24669 Mtetra
.626 .774 .951 r
.76935 .24669 .77468 .25343 .78718 .25095 .7818 .24311 Mtetra
.627 .744 .931 r
.12449 .45992 .13161 .46613 .14148 .46213 .13423 .45718 Mtetra
.622 .788 .961 r
.13423 .45718 .14148 .46213 .1514 .45798 .14402 .45437 Mtetra
.611 .836 .986 r
.14402 .45437 .1514 .45798 .16137 .45362 .15386 .45141 Mtetra
.586 .879 .993 r
.15386 .45141 .16137 .45362 .17141 .44895 .16377 .44825 Mtetra
.537 .903 .964 r
.16377 .44825 .17141 .44895 .18152 .4439 .17374 .4448 Mtetra
.454 .885 .878 r
.17374 .4448 .18152 .4439 .19169 .43843 .18379 .441 Mtetra
.346 .815 .737 r
.18379 .441 .19169 .43843 .20194 .43249 .19392 .43679 Mtetra
0 0 0 r
.19392 .43679 .20194 .43249 .21225 .42615 .20412 .43211 Mtetra
.20412 .43211 .21225 .42615 .22262 .41943 .21441 .42692 Mtetra
.21441 .42692 .22262 .41943 .23303 .41247 .22477 .4212 Mtetra
.22477 .4212 .23303 .41247 .24346 .40539 .23521 .41495 Mtetra
.23521 .41495 .24346 .40539 .25391 .39835 .24571 .40823 Mtetra
.24571 .40823 .25391 .39835 .26436 .3915 .25626 .40109 Mtetra
.25626 .40109 .26436 .3915 .2748 .38498 .26685 .39369 Mtetra
.26685 .39369 .2748 .38498 .28523 .37888 .27747 .38614 Mtetra
.27747 .38614 .28523 .37888 .29565 .37323 .2881 .37859 Mtetra
.2881 .37859 .29565 .37323 .30607 .36807 .29874 .37116 Mtetra
.576 .932 .769 r
.29874 .37116 .30607 .36807 .31648 .36333 .30938 .36393 Mtetra
.711 .98 .907 r
.30938 .36393 .31648 .36333 .32691 .35898 .32002 .35697 Mtetra
.761 .929 .942 r
.32002 .35697 .32691 .35898 .33735 .35495 .33066 .35031 Mtetra
.755 .839 .915 r
.33066 .35031 .33735 .35495 .34781 .35118 .3413 .34398 Mtetra
.729 .754 .872 r
.3413 .34398 .34781 .35118 .35831 .3476 .35195 .33798 Mtetra
.702 .687 .832 r
.35195 .33798 .35831 .3476 .36884 .34414 .36261 .33231 Mtetra
.679 .637 .8 r
.36261 .33231 .36884 .34414 .37941 .34076 .37328 .32696 Mtetra
.661 .599 .775 r
.37328 .32696 .37941 .34076 .39002 .33739 .38397 .32191 Mtetra
.646 .572 .757 r
.38397 .32191 .39002 .33739 .40067 .33399 .39468 .31713 Mtetra
.635 .551 .743 r
.39468 .31713 .40067 .33399 .41138 .33052 .40542 .31262 Mtetra
.626 .537 .734 r
.40542 .31262 .41138 .33052 .42213 .32696 .41618 .30834 Mtetra
.619 .527 .728 r
.41618 .30834 .42213 .32696 .43293 .32329 .42698 .30429 Mtetra
.614 .521 .725 r
.42698 .30429 .43293 .32329 .44377 .31949 .43781 .30045 Mtetra
.61 .518 .726 r
.43781 .30045 .44377 .31949 .45466 .31556 .44868 .29683 Mtetra
.606 .519 .73 r
.44868 .29683 .45466 .31556 .4656 .31152 .45959 .29344 Mtetra
.604 .524 .737 r
.45959 .29344 .4656 .31152 .47658 .30739 .47054 .29028 Mtetra
.601 .532 .749 r
.47054 .29028 .47658 .30739 .4876 .30318 .48154 .28739 Mtetra
.598 .545 .767 r
.48154 .28739 .4876 .30318 .49867 .29895 .49259 .28478 Mtetra
.594 .565 .791 r
.49259 .28478 .49867 .29895 .50978 .29473 .50369 .28248 Mtetra
.588 .593 .825 r
.50369 .28248 .50978 .29473 .52093 .29057 .51484 .2805 Mtetra
.575 .633 .872 r
.51484 .2805 .52093 .29057 .53212 .28655 .52606 .27886 Mtetra
.546 .688 .933 r
.52606 .27886 .53212 .28655 .54336 .28271 .53734 .27756 Mtetra
.472 .748 .989 r
.53734 .27756 .54336 .28271 .55465 .27914 .54869 .27661 Mtetra
.301 .753 .957 r
.54869 .27661 .55465 .27914 .566 .27589 .56011 .27597 Mtetra
.031 .602 .718 r
.56011 .27597 .566 .27589 .5774 .27304 .5716 .27561 Mtetra
.186 0 0 r
.5716 .27561 .5774 .27304 .58887 .27062 .58318 .27547 Mtetra
.304 0 0 r
.58318 .27547 .58887 .27062 .6004 .2687 .59484 .27547 Mtetra
.359 0 0 r
.59484 .27547 .6004 .2687 .61202 .26725 .60657 .27547 Mtetra
.382 0 .007 r
.60657 .27547 .61202 .26725 .62372 .26624 .61839 .27533 Mtetra
.385 0 .038 r
.61839 .27533 .62372 .26624 .6355 .26557 .63027 .27494 Mtetra
.373 0 .04 r
.63027 .27494 .6355 .26557 .64737 .26511 .64221 .27412 Mtetra
.347 0 .016 r
.64221 .27412 .64737 .26511 .65931 .26471 .65422 .27283 Mtetra
.303 0 0 r
.65422 .27283 .65931 .26471 .67133 .26418 .66627 .27098 Mtetra
.236 0 0 r
.66627 .27098 .67133 .26418 .68342 .26342 .67836 .2686 Mtetra
.133 0 0 r
.67836 .2686 .68342 .26342 .69556 .26227 .69049 .26569 Mtetra
0 0 0 r
.69049 .26569 .69556 .26227 .70776 .2607 .70266 .2623 Mtetra
.213 .724 .676 r
.70266 .2623 .70776 .2607 .71999 .25866 .71486 .25847 Mtetra
.409 .861 .864 r
.71486 .25847 .71999 .25866 .73227 .25619 .72709 .25427 Mtetra
.554 .911 .964 r
.72709 .25427 .73227 .25619 .74459 .25331 .73935 .24978 Mtetra
.633 .895 .986 r
.73935 .24978 .74459 .25331 .75695 .25011 .75165 .24505 Mtetra
.667 .853 .971 r
.75165 .24505 .75695 .25011 .76935 .24669 .76399 .24017 Mtetra
.679 .805 .943 r
.76399 .24017 .76935 .24669 .7818 .24311 .77637 .23521 Mtetra
.569 .726 .948 r
.11732 .45366 .12449 .45992 .13423 .45718 .12695 .45199 Mtetra
.554 .761 .974 r
.12695 .45199 .13423 .45718 .14402 .45437 .13662 .4503 Mtetra
.532 .797 .994 r
.13662 .4503 .14402 .45437 .15386 .45141 .14635 .44853 Mtetra
.498 .828 .999 r
.14635 .44853 .15386 .45141 .16377 .44825 .15614 .44663 Mtetra
.445 .844 .976 r
.15614 .44663 .16377 .44825 .17374 .4448 .166 .44454 Mtetra
.37 .831 .908 r
.166 .44454 .17374 .4448 .18379 .441 .17594 .44219 Mtetra
.275 .779 .79 r
.17594 .44219 .18379 .441 .19392 .43679 .18595 .43952 Mtetra
0 0 0 r
.18595 .43952 .19392 .43679 .20412 .43211 .19604 .43646 Mtetra
.19604 .43646 .20412 .43211 .21441 .42692 .20622 .43295 Mtetra
.20622 .43295 .21441 .42692 .22477 .4212 .21648 .42897 Mtetra
.059 0 0 r
.21648 .42897 .22477 .4212 .23521 .41495 .22683 .42448 Mtetra
.109 0 0 r
.22683 .42448 .23521 .41495 .24571 .40823 .23725 .4195 Mtetra
.148 0 0 r
.23725 .4195 .24571 .40823 .25626 .40109 .24774 .41405 Mtetra
.182 0 .025 r
.24774 .41405 .25626 .40109 .26685 .39369 .25829 .40822 Mtetra
.21 0 .074 r
.25829 .40822 .26685 .39369 .27747 .38614 .2689 .40209 Mtetra
.235 0 .113 r
.2689 .40209 .27747 .38614 .2881 .37859 .27954 .39576 Mtetra
.256 0 .143 r
.27954 .39576 .2881 .37859 .29874 .37116 .29021 .38932 Mtetra
.273 0 .167 r
.29021 .38932 .29874 .37116 .30938 .36393 .30091 .38287 Mtetra
.288 0 .184 r
.30091 .38287 .30938 .36393 .32002 .35697 .31162 .37648 Mtetra
.301 0 .198 r
.31162 .37648 .32002 .35697 .33066 .35031 .32236 .37019 Mtetra
.311 0 .207 r
.32236 .37019 .33066 .35031 .3413 .34398 .3331 .36405 Mtetra
.32 0 .214 r
.3331 .36405 .3413 .34398 .35195 .33798 .34387 .3581 Mtetra
.329 0 .219 r
.34387 .3581 .35195 .33798 .36261 .33231 .35465 .35236 Mtetra
.336 0 .222 r
.35465 .35236 .36261 .33231 .37328 .32696 .36544 .34687 Mtetra
.343 0 .224 r
.36544 .34687 .37328 .32696 .38397 .32191 .37626 .34163 Mtetra
.349 .001 .225 r
.37626 .34163 .38397 .32191 .39468 .31713 .38709 .33665 Mtetra
.356 .006 .226 r
.38709 .33665 .39468 .31713 .40542 .31262 .39795 .33196 Mtetra
.363 .011 .227 r
.39795 .33196 .40542 .31262 .41618 .30834 .40884 .32754 Mtetra
.37 .017 .229 r
.40884 .32754 .41618 .30834 .42698 .30429 .41975 .32341 Mtetra
.378 .023 .232 r
.41975 .32341 .42698 .30429 .43781 .30045 .4307 .31957 Mtetra
.386 .031 .235 r
.4307 .31957 .43781 .30045 .44868 .29683 .44169 .31601 Mtetra
.394 .039 .239 r
.44169 .31601 .44868 .29683 .45959 .29344 .45271 .31274 Mtetra
.402 .047 .244 r
.45271 .31274 .45959 .29344 .47054 .29028 .46378 .30975 Mtetra
.411 .055 .249 r
.46378 .30975 .47054 .29028 .48154 .28739 .4749 .30704 Mtetra
.418 .064 .254 r
.4749 .30704 .48154 .28739 .49259 .28478 .48607 .30461 Mtetra
.426 .071 .258 r
.48607 .30461 .49259 .28478 .50369 .28248 .49729 .30244 Mtetra
.432 .077 .262 r
.49729 .30244 .50369 .28248 .51484 .2805 .50857 .30051 Mtetra
.437 .082 .264 r
.50857 .30051 .51484 .2805 .52606 .27886 .51991 .29881 Mtetra
.441 .085 .264 r
.51991 .29881 .52606 .27886 .53734 .27756 .53131 .29731 Mtetra
.444 .086 .263 r
.53131 .29731 .53734 .27756 .54869 .27661 .54278 .29597 Mtetra
.444 .084 .258 r
.54278 .29597 .54869 .27661 .56011 .27597 .55432 .29474 Mtetra
.443 .079 .251 r
.55432 .29474 .56011 .27597 .5716 .27561 .56593 .29358 Mtetra
.439 .07 .239 r
.56593 .29358 .5716 .27561 .58318 .27547 .57761 .2924 Mtetra
.431 .055 .223 r
.57761 .2924 .58318 .27547 .59484 .27547 .58936 .29113 Mtetra
.418 .033 .199 r
.58936 .29113 .59484 .27547 .60657 .27547 .60117 .28967 Mtetra
.397 0 .165 r
.60117 .28967 .60657 .27547 .61839 .27533 .61304 .28789 Mtetra
.367 0 .119 r
.61304 .28789 .61839 .27533 .63027 .27494 .62498 .28573 Mtetra
.323 0 .056 r
.62498 .28573 .63027 .27494 .64221 .27412 .63696 .28309 Mtetra
.26 0 0 r
.63696 .28309 .64221 .27412 .65422 .27283 .64898 .27995 Mtetra
.17 0 0 r
.64898 .27995 .65422 .27283 .66627 .27098 .66104 .27628 Mtetra
.046 0 0 r
.66104 .27628 .66627 .27098 .67836 .2686 .67313 .27212 Mtetra
0 0 0 r
.67313 .27212 .67836 .2686 .69049 .26569 .68526 .26748 Mtetra
.307 .784 .694 r
.68526 .26748 .69049 .26569 .70266 .2623 .6974 .26244 Mtetra
.481 .899 .854 r
.6974 .26244 .70266 .2623 .71486 .25847 .70958 .25705 Mtetra
.604 .941 .942 r
.70958 .25705 .71486 .25847 .72709 .25427 .72178 .25139 Mtetra
.674 .93 .97 r
.72178 .25139 .72709 .25427 .73935 .24978 .73401 .24552 Mtetra
.706 .895 .965 r
.73401 .24552 .73935 .24978 .75165 .24505 .74627 .2395 Mtetra
.718 .854 .946 r
.74627 .2395 .75165 .24505 .76399 .24017 .75857 .23339 Mtetra
.718 .812 .923 r
.75857 .23339 .76399 .24017 .77637 .23521 .7709 .22725 Mtetra
.522 .709 .957 r
.1101 .44736 .11732 .45366 .12695 .45199 .11965 .4464 Mtetra
.505 .73 .974 r
.11965 .4464 .12695 .45199 .13662 .4503 .12925 .44545 Mtetra
.485 .751 .988 r
.12925 .44545 .13662 .4503 .14635 .44853 .13891 .44449 Mtetra
.46 .772 .997 r
.13891 .44449 .14635 .44853 .15614 .44663 .14862 .44347 Mtetra
.426 .79 .995 r
.14862 .44347 .15614 .44663 .166 .44454 .1584 .44235 Mtetra
.381 .799 .975 r
.1584 .44235 .166 .44454 .17594 .44219 .16824 .44108 Mtetra
.322 .792 .927 r
.16824 .44108 .17594 .44219 .18595 .43952 .17816 .43961 Mtetra
.242 .757 .838 r
.17816 .43961 .18595 .43952 .19604 .43646 .18815 .4379 Mtetra
.147 .686 .707 r
.18815 .4379 .19604 .43646 .20622 .43295 .19822 .43593 Mtetra
0 0 0 r
.19822 .43593 .20622 .43295 .21648 .42897 .20836 .43369 Mtetra
.066 0 0 r
.20836 .43369 .21648 .42897 .22683 .42448 .21858 .4312 Mtetra
.157 0 0 r
.21858 .4312 .22683 .42448 .23725 .4195 .22886 .42846 Mtetra
.229 0 0 r
.22886 .42846 .23725 .4195 .24774 .41405 .23921 .42549 Mtetra
.283 0 .043 r
.23921 .42549 .24774 .41405 .25829 .40822 .24962 .4223 Mtetra
.322 0 .122 r
.24962 .4223 .25829 .40822 .2689 .40209 .2601 .41889 Mtetra
.35 0 .181 r
.2601 .41889 .2689 .40209 .27954 .39576 .27063 .41526 Mtetra
.371 .015 .225 r
.27063 .41526 .27954 .39576 .29021 .38932 .28122 .41143 Mtetra
.386 .044 .258 r
.28122 .41143 .29021 .38932 .30091 .38287 .29186 .40743 Mtetra
.398 .066 .282 r
.29186 .40743 .30091 .38287 .31162 .37648 .30255 .40326 Mtetra
.407 .083 .301 r
.30255 .40326 .31162 .37648 .32236 .37019 .31329 .39896 Mtetra
.414 .096 .315 r
.31329 .39896 .32236 .37019 .3331 .36405 .32408 .39455 Mtetra
.419 .107 .326 r
.32408 .39455 .3331 .36405 .34387 .3581 .33491 .39006 Mtetra
.424 .115 .335 r
.33491 .39006 .34387 .3581 .35465 .35236 .34578 .38552 Mtetra
.428 .122 .342 r
.34578 .38552 .35465 .35236 .36544 .34687 .35669 .38098 Mtetra
.431 .127 .347 r
.35669 .38098 .36544 .34687 .37626 .34163 .36763 .37648 Mtetra
.435 .132 .351 r
.36763 .37648 .37626 .34163 .38709 .33665 .37861 .37205 Mtetra
.438 .136 .354 r
.37861 .37205 .38709 .33665 .39795 .33196 .38963 .36774 Mtetra
.441 .14 .357 r
.38963 .36774 .39795 .33196 .40884 .32754 .40068 .36357 Mtetra
.444 .143 .358 r
.40068 .36357 .40884 .32754 .41975 .32341 .41176 .35955 Mtetra
.447 .146 .36 r
.41176 .35955 .41975 .32341 .4307 .31957 .42289 .35572 Mtetra
.45 .148 .361 r
.42289 .35572 .4307 .31957 .44169 .31601 .43406 .35205 Mtetra
.452 .149 .361 r
.43406 .35205 .44169 .31601 .45271 .31274 .44527 .34855 Mtetra
.453 .15 .36 r
.44527 .34855 .45271 .31274 .46378 .30975 .45652 .34519 Mtetra
.454 .15 .359 r
.45652 .34519 .46378 .30975 .4749 .30704 .46782 .34195 Mtetra
.454 .149 .357 r
.46782 .34195 .4749 .30704 .48607 .30461 .47918 .33878 Mtetra
.453 .146 .354 r
.47918 .33878 .48607 .30461 .49729 .30244 .49059 .33566 Mtetra
.451 .142 .35 r
.49059 .33566 .49729 .30244 .50857 .30051 .50205 .33253 Mtetra
.448 .136 .343 r
.50205 .33253 .50857 .30051 .51991 .29881 .51356 .32936 Mtetra
.443 .128 .335 r
.51356 .32936 .51991 .29881 .53131 .29731 .52513 .32611 Mtetra
.437 .117 .324 r
.52513 .32611 .53131 .29731 .54278 .29597 .53675 .32274 Mtetra
.428 .102 .309 r
.53675 .32274 .54278 .29597 .55432 .29474 .54843 .31924 Mtetra
.416 .082 .289 r
.54843 .31924 .55432 .29474 .56593 .29358 .56015 .31558 Mtetra
.399 .056 .263 r
.56015 .31558 .56593 .29358 .57761 .2924 .57193 .31173 Mtetra
.377 .021 .228 r
.57193 .31173 .57761 .2924 .58936 .29113 .58376 .30767 Mtetra
.345 0 .179 r
.58376 .30767 .58936 .29113 .60117 .28967 .59563 .3034 Mtetra
.3 0 .112 r
.59563 .3034 .60117 .28967 .61304 .28789 .60754 .29889 Mtetra
.234 0 .018 r
.60754 .29889 .61304 .28789 .62498 .28573 .6195 .29414 Mtetra
.14 0 0 r
.6195 .29414 .62498 .28573 .63696 .28309 .6315 .28916 Mtetra
.007 0 0 r
.6315 .28916 .63696 .28309 .64898 .27995 .64353 .28392 Mtetra
0 0 0 r
.64353 .28392 .64898 .27995 .66104 .27628 .65559 .27839 Mtetra
.351 .808 .689 r
.65559 .27839 .66104 .27628 .67313 .27212 .66769 .2726 Mtetra
.514 .914 .84 r
.66769 .2726 .67313 .27212 .68526 .26748 .67981 .26651 Mtetra
.626 .955 .923 r
.67981 .26651 .68526 .26748 .6974 .26244 .69195 .26017 Mtetra
.692 .951 .955 r
.69195 .26017 .6974 .26244 .70958 .25705 .70412 .25361 Mtetra
.725 .927 .958 r
.70412 .25361 .70958 .25705 .72178 .25139 .71631 .24688 Mtetra
.74 .895 .949 r
.71631 .24688 .72178 .25139 .73401 .24552 .72854 .24003 Mtetra
.745 .864 .935 r
.72854 .24003 .73401 .24552 .74627 .2395 .74079 .23312 Mtetra
.744 .834 .92 r
.74079 .23312 .74627 .2395 .75857 .23339 .75307 .22617 Mtetra
.74 .807 .905 r
.75307 .22617 .75857 .23339 .7709 .22725 .76539 .21923 Mtetra
.512 .706 .958 r
.10283 .44102 .1101 .44736 .11965 .4464 .11238 .44017 Mtetra
.504 .708 .962 r
.11238 .44017 .11965 .4464 .12925 .44545 .12197 .4394 Mtetra
.496 .711 .967 r
.12197 .4394 .12925 .44545 .13891 .44449 .13161 .43867 Mtetra
.486 .717 .973 r
.13161 .43867 .13891 .44449 .14862 .44347 .1413 .43799 Mtetra
.473 .725 .98 r
.1413 .43799 .14862 .44347 .1584 .44235 .15104 .43734 Mtetra
.458 .737 .988 r
.15104 .43734 .1584 .44235 .16824 .44108 .16083 .43669 Mtetra
.437 .752 .994 r
.16083 .43669 .16824 .44108 .17816 .43961 .17069 .43598 Mtetra
.409 .768 .995 r
.17069 .43598 .17816 .43961 .18815 .4379 .18061 .43519 Mtetra
.369 .78 .981 r
.18061 .43519 .18815 .4379 .19822 .43593 .1906 .43425 Mtetra
.312 .776 .941 r
.1906 .43425 .19822 .43593 .20836 .43369 .20066 .43315 Mtetra
.239 .75 .868 r
.20066 .43315 .20836 .43369 .21858 .4312 .2108 .43184 Mtetra
.154 .696 .76 r
.2108 .43184 .21858 .4312 .22886 .42846 .22101 .43032 Mtetra
0 0 0 r
.22101 .43032 .22886 .42846 .23921 .42549 .2313 .42856 Mtetra
.003 0 0 r
.2313 .42856 .23921 .42549 .24962 .4223 .24166 .42656 Mtetra
.064 0 0 r
.24166 .42656 .24962 .4223 .2601 .41889 .25209 .42431 Mtetra
.114 0 0 r
.25209 .42431 .2601 .41889 .27063 .41526 .26259 .42183 Mtetra
.155 0 0 r
.26259 .42183 .27063 .41526 .28122 .41143 .27316 .41912 Mtetra
.189 0 0 r
.27316 .41912 .28122 .41143 .29186 .40743 .28379 .41621 Mtetra
.217 0 0 r
.28379 .41621 .29186 .40743 .30255 .40326 .29448 .41312 Mtetra
.241 0 0 r
.29448 .41312 .30255 .40326 .31329 .39896 .30523 .40986 Mtetra
.261 0 .011 r
.30523 .40986 .31329 .39896 .32408 .39455 .31604 .40645 Mtetra
.278 0 .047 r
.31604 .40645 .32408 .39455 .33491 .39006 .3269 .40292 Mtetra
.293 0 .078 r
.3269 .40292 .33491 .39006 .34578 .38552 .33781 .39927 Mtetra
.306 0 .103 r
.33781 .39927 .34578 .38552 .35669 .38098 .34877 .39554 Mtetra
.317 0 .125 r
.34877 .39554 .35669 .38098 .36763 .37648 .35978 .39174 Mtetra
.326 0 .142 r
.35978 .39174 .36763 .37648 .37861 .37205 .37083 .3879 Mtetra
.334 0 .155 r
.37083 .3879 .37861 .37205 .38963 .36774 .38193 .38403 Mtetra
.34 0 .165 r
.38193 .38403 .38963 .36774 .40068 .36357 .39308 .38017 Mtetra
.344 0 .172 r
.39308 .38017 .40068 .36357 .41176 .35955 .40427 .37631 Mtetra
.347 0 .176 r
.40427 .37631 .41176 .35955 .42289 .35572 .41551 .37246 Mtetra
.348 0 .176 r
.41551 .37246 .42289 .35572 .43406 .35205 .42679 .36863 Mtetra
.347 0 .173 r
.42679 .36863 .43406 .35205 .44527 .34855 .43812 .3648 Mtetra
.344 0 .167 r
.43812 .3648 .44527 .34855 .45652 .34519 .4495 .36097 Mtetra
.338 0 .157 r
.4495 .36097 .45652 .34519 .46782 .34195 .46092 .35712 Mtetra
.329 0 .143 r
.46092 .35712 .46782 .34195 .47918 .33878 .4724 .35322 Mtetra
.317 0 .125 r
.4724 .35322 .47918 .33878 .49059 .33566 .48392 .34926 Mtetra
.302 0 .101 r
.48392 .34926 .49059 .33566 .50205 .33253 .4955 .34521 Mtetra
.281 0 .072 r
.4955 .34521 .50205 .33253 .51356 .32936 .50712 .34104 Mtetra
.256 0 .036 r
.50712 .34104 .51356 .32936 .52513 .32611 .51879 .33674 Mtetra
.223 0 0 r
.51879 .33674 .52513 .32611 .53675 .32274 .53051 .33229 Mtetra
.183 0 0 r
.53051 .33229 .53675 .32274 .54843 .31924 .54227 .32766 Mtetra
.132 0 0 r
.54227 .32766 .54843 .31924 .56015 .31558 .55408 .32285 Mtetra
.068 0 0 r
.55408 .32285 .56015 .31558 .57193 .31173 .56593 .31782 Mtetra
0 0 0 r
.56593 .31782 .57193 .31173 .58376 .30767 .57782 .31255 Mtetra
.57782 .31255 .58376 .30767 .59563 .3034 .58975 .30704 Mtetra
.58975 .30704 .59563 .3034 .60754 .29889 .60172 .30126 Mtetra
.368 .817 .688 r
.60172 .30126 .60754 .29889 .6195 .29414 .61371 .29523 Mtetra
.498 .904 .808 r
.61371 .29523 .6195 .29414 .6315 .28916 .62574 .28894 Mtetra
.605 .952 .894 r
.62574 .28894 .6315 .28916 .64353 .28392 .63779 .28242 Mtetra
.68 .962 .94 r
.63779 .28242 .64353 .28392 .65559 .27839 .64987 .27568 Mtetra
.724 .945 .954 r
.64987 .27568 .65559 .27839 .66769 .2726 .66197 .26876 Mtetra
.746 .915 .949 r
.66197 .26876 .66769 .2726 .67981 .26651 .6741 .26167 Mtetra
.754 .884 .938 r
.6741 .26167 .67981 .26651 .69195 .26017 .68626 .25447 Mtetra
.756 .857 .925 r
.68626 .25447 .69195 .26017 .70412 .25361 .69844 .24721 Mtetra
.754 .834 .913 r
.69844 .24721 .70412 .25361 .71631 .24688 .71065 .23993 Mtetra
.75 .817 .905 r
.71065 .23993 .71631 .24688 .72854 .24003 .72289 .23268 Mtetra
.747 .804 .899 r
.72289 .23268 .72854 .24003 .74079 .23312 .73517 .22545 Mtetra
.743 .795 .894 r
.73517 .22545 .74079 .23312 .75307 .22617 .74748 .21827 Mtetra
.74 .788 .892 r
.74748 .21827 .75307 .22617 .76539 .21923 .75983 .21113 Mtetra
.541 .716 .954 r
.09551 .43462 .10283 .44102 .11238 .44017 .10512 .43334 Mtetra
.54 .702 .944 r
.10512 .43334 .11238 .44017 .12197 .4394 .11478 .43216 Mtetra
.537 .688 .936 r
.11478 .43216 .12197 .4394 .13161 .43867 .12447 .43108 Mtetra
.533 .675 .929 r
.12447 .43108 .13161 .43867 .1413 .43799 .1342 .43013 Mtetra
.526 .665 .924 r
.1342 .43013 .1413 .43799 .15104 .43734 .14396 .42935 Mtetra
.52 .659 .923 r
.14396 .42935 .15104 .43734 .16083 .43669 .15376 .42868 Mtetra
.513 .656 .924 r
.15376 .42868 .16083 .43669 .17069 .43598 .16361 .42812 Mtetra
.509 .66 .928 r
.16361 .42812 .17069 .43598 .18061 .43519 .17352 .42759 Mtetra
.507 .668 .935 r
.17352 .42759 .18061 .43519 .1906 .43425 .18348 .42701 Mtetra
.509 .682 .944 r
.18348 .42701 .1906 .43425 .20066 .43315 .19351 .42632 Mtetra
.515 .699 .953 r
.19351 .42632 .20066 .43315 .2108 .43184 .20363 .42542 Mtetra
.524 .718 .961 r
.20363 .42542 .2108 .43184 .22101 .43032 .21382 .42427 Mtetra
.537 .737 .967 r
.21382 .42427 .22101 .43032 .2313 .42856 .2241 .4228 Mtetra
.55 .753 .971 r
.2241 .4228 .2313 .42856 .24166 .42656 .23446 .42105 Mtetra
.563 .767 .974 r
.23446 .42105 .24166 .42656 .25209 .42431 .2449 .41901 Mtetra
.573 .779 .976 r
.2449 .41901 .25209 .42431 .26259 .42183 .2554 .41674 Mtetra
.58 .79 .979 r
.2554 .41674 .26259 .42183 .27316 .41912 .26598 .41427 Mtetra
.585 .801 .982 r
.26598 .41427 .27316 .41912 .28379 .41621 .27662 .41166 Mtetra
.585 .813 .986 r
.27662 .41166 .28379 .41621 .29448 .41312 .28731 .40892 Mtetra
.582 .826 .991 r
.28731 .40892 .29448 .41312 .30523 .40986 .29807 .4061 Mtetra
.575 .84 .995 r
.29807 .4061 .30523 .40986 .31604 .40645 .30887 .4032 Mtetra
.564 .854 .997 r
.30887 .4032 .31604 .40645 .3269 .40292 .31973 .40022 Mtetra
.548 .867 .995 r
.31973 .40022 .3269 .40292 .33781 .39927 .33065 .39717 Mtetra
.527 .877 .987 r
.33065 .39717 .33781 .39927 .34877 .39554 .34162 .39402 Mtetra
.501 .881 .971 r
.34162 .39402 .34877 .39554 .35978 .39174 .35264 .39078 Mtetra
.474 .88 .948 r
.35264 .39078 .35978 .39174 .37083 .3879 .36372 .38743 Mtetra
.448 .875 .923 r
.36372 .38743 .37083 .3879 .38193 .38403 .37485 .38396 Mtetra
.428 .868 .898 r
.37485 .38396 .38193 .38403 .39308 .38017 .38603 .38036 Mtetra
.417 .864 .881 r
.38603 .38036 .39308 .38017 .40427 .37631 .39727 .37663 Mtetra
.417 .865 .873 r
.39727 .37663 .40427 .37631 .41551 .37246 .40856 .37276 Mtetra
.43 .871 .876 r
.40856 .37276 .41551 .37246 .42679 .36863 .41991 .36875 Mtetra
.453 .883 .889 r
.41991 .36875 .42679 .36863 .43812 .3648 .4313 .36461 Mtetra
.486 .897 .911 r
.4313 .36461 .43812 .3648 .4495 .36097 .44274 .36034 Mtetra
.523 .91 .935 r
.44274 .36034 .4495 .36097 .46092 .35712 .45424 .35594 Mtetra
.562 .918 .957 r
.45424 .35594 .46092 .35712 .4724 .35322 .46578 .35143 Mtetra
.597 .919 .973 r
.46578 .35143 .4724 .35322 .48392 .34926 .47736 .34682 Mtetra
.626 .912 .981 r
.47736 .34682 .48392 .34926 .4955 .34521 .48899 .34212 Mtetra
.647 .9 .983 r
.48899 .34212 .4955 .34521 .50712 .34104 .50067 .33733 Mtetra
.663 .885 .979 r
.50067 .33733 .50712 .34104 .51879 .33674 .51239 .33246 Mtetra
.674 .869 .973 r
.51239 .33246 .51879 .33674 .53051 .33229 .52415 .32751 Mtetra
.682 .855 .965 r
.52415 .32751 .53051 .33229 .54227 .32766 .53596 .32247 Mtetra
.689 .844 .957 r
.53596 .32247 .54227 .32766 .55408 .32285 .54781 .3173 Mtetra
.696 .834 .949 r
.54781 .3173 .55408 .32285 .56593 .31782 .5597 .31196 Mtetra
.704 .827 .941 r
.5597 .31196 .56593 .31782 .57782 .31255 .57163 .30642 Mtetra
.712 .821 .933 r
.57163 .30642 .57782 .31255 .58975 .30704 .5836 .30064 Mtetra
.721 .816 .924 r
.5836 .30064 .58975 .30704 .60172 .30126 .5956 .29455 Mtetra
.729 .809 .915 r
.5956 .29455 .60172 .30126 .61371 .29523 .60762 .28815 Mtetra
.736 .801 .904 r
.60762 .28815 .61371 .29523 .62574 .28894 .61968 .28143 Mtetra
.741 .79 .893 r
.61968 .28143 .62574 .28894 .63779 .28242 .63176 .27442 Mtetra
.743 .778 .881 r
.63176 .27442 .63779 .28242 .64987 .27568 .64386 .2672 Mtetra
.743 .766 .872 r
.64386 .2672 .64987 .27568 .66197 .26876 .65598 .25983 Mtetra
.74 .755 .864 r
.65598 .25983 .66197 .26876 .6741 .26167 .66814 .25241 Mtetra
.737 .746 .859 r
.66814 .25241 .6741 .26167 .68626 .25447 .68032 .245 Mtetra
.733 .74 .857 r
.68032 .245 .68626 .25447 .69844 .24721 .69253 .23769 Mtetra
.73 .739 .858 r
.69253 .23769 .69844 .24721 .71065 .23993 .70479 .23049 Mtetra
.727 .741 .863 r
.70479 .23049 .71065 .23993 .72289 .23268 .71708 .22345 Mtetra
.725 .746 .869 r
.71708 .22345 .72289 .23268 .73517 .22545 .72942 .21653 Mtetra
.725 .755 .877 r
.72942 .21653 .73517 .22545 .74748 .21827 .7418 .20971 Mtetra
.725 .766 .886 r
.7418 .20971 .74748 .21827 .75983 .21113 .75422 .20298 Mtetra
.604 .737 .939 r
.08813 .42819 .09551 .43462 .10512 .43334 .09791 .4258 Mtetra
.604 .703 .913 r
.09791 .4258 .10512 .43334 .11478 .43216 .10771 .42349 Mtetra
.6 .67 .889 r
.10771 .42349 .11478 .43216 .12447 .43108 .11755 .42128 Mtetra
.595 .64 .866 r
.11755 .42128 .12447 .43108 .1342 .43013 .12742 .41923 Mtetra
.587 .612 .845 r
.12742 .41923 .1342 .43013 .14396 .42935 .13731 .41736 Mtetra
.58 .588 .826 r
.13731 .41736 .14396 .42935 .15376 .42868 .14723 .41566 Mtetra
.573 .567 .809 r
.14723 .41566 .15376 .42868 .16361 .42812 .15718 .41414 Mtetra
.568 .55 .794 r
.15718 .41414 .16361 .42812 .17352 .42759 .16717 .41274 Mtetra
.565 .537 .782 r
.16717 .41274 .17352 .42759 .18348 .42701 .1772 .41143 Mtetra
.563 .527 .772 r
.1772 .41143 .18348 .42701 .19351 .42632 .18728 .41015 Mtetra
.563 .52 .765 r
.18728 .41015 .19351 .42632 .20363 .42542 .19742 .40884 Mtetra
.564 .516 .76 r
.19742 .40884 .20363 .42542 .21382 .42427 .20762 .40746 Mtetra
.567 .516 .758 r
.20762 .40746 .21382 .42427 .2241 .4228 .21789 .40596 Mtetra
.57 .518 .757 r
.21789 .40596 .2241 .4228 .23446 .42105 .22822 .40435 Mtetra
.573 .522 .759 r
.22822 .40435 .23446 .42105 .2449 .41901 .23862 .4026 Mtetra
.577 .527 .763 r
.23862 .4026 .2449 .41901 .2554 .41674 .24909 .40073 Mtetra
.58 .535 .768 r
.24909 .40073 .2554 .41674 .26598 .41427 .25962 .39873 Mtetra
.584 .543 .775 r
.25962 .39873 .26598 .41427 .27662 .41166 .27021 .39663 Mtetra
.587 .552 .782 r
.27021 .39663 .27662 .41166 .28731 .40892 .28086 .39442 Mtetra
.591 .562 .79 r
.28086 .39442 .28731 .40892 .29807 .4061 .29157 .39211 Mtetra
.594 .572 .798 r
.29157 .39211 .29807 .4061 .30887 .4032 .30234 .3897 Mtetra
.598 .582 .806 r
.30234 .3897 .30887 .4032 .31973 .40022 .31317 .38718 Mtetra
.603 .592 .813 r
.31317 .38718 .31973 .40022 .33065 .39717 .32407 .38453 Mtetra
.608 .602 .82 r
.32407 .38453 .33065 .39717 .34162 .39402 .33502 .38174 Mtetra
.613 .611 .825 r
.33502 .38174 .34162 .39402 .35264 .39078 .34603 .37879 Mtetra
.618 .62 .83 r
.34603 .37879 .35264 .39078 .36372 .38743 .35711 .37567 Mtetra
.624 .627 .833 r
.35711 .37567 .36372 .38743 .37485 .38396 .36824 .37236 Mtetra
.63 .634 .836 r
.36824 .37236 .37485 .38396 .38603 .38036 .37944 .36886 Mtetra
.635 .639 .837 r
.37944 .36886 .38603 .38036 .39727 .37663 .39069 .36515 Mtetra
.641 .642 .836 r
.39069 .36515 .39727 .37663 .40856 .37276 .40199 .36125 Mtetra
.646 .645 .835 r
.40199 .36125 .40856 .37276 .41991 .36875 .41335 .35714 Mtetra
.65 .645 .832 r
.41335 .35714 .41991 .36875 .4313 .36461 .42477 .35284 Mtetra
.654 .645 .828 r
.42477 .35284 .4313 .36461 .44274 .36034 .43623 .34833 Mtetra
.658 .642 .824 r
.43623 .34833 .44274 .36034 .45424 .35594 .44774 .34364 Mtetra
.66 .639 .818 r
.44774 .34364 .45424 .35594 .46578 .35143 .4593 .33877 Mtetra
.662 .634 .812 r
.4593 .33877 .46578 .35143 .47736 .34682 .47091 .33373 Mtetra
.662 .628 .805 r
.47091 .33373 .47736 .34682 .48899 .34212 .48256 .32854 Mtetra
.662 .621 .797 r
.48256 .32854 .48899 .34212 .50067 .33733 .49425 .32323 Mtetra
.662 .613 .79 r
.49425 .32323 .50067 .33733 .51239 .33246 .50598 .31779 Mtetra
.66 .605 .782 r
.50598 .31779 .51239 .33246 .52415 .32751 .51775 .31224 Mtetra
.659 .597 .774 r
.51775 .31224 .52415 .32751 .53596 .32247 .52957 .30658 Mtetra
.658 .589 .767 r
.52957 .30658 .53596 .32247 .54781 .3173 .54142 .30081 Mtetra
.656 .582 .76 r
.54142 .30081 .54781 .3173 .5597 .31196 .55331 .29491 Mtetra
.656 .576 .753 r
.55331 .29491 .5597 .31196 .57163 .30642 .56523 .28889 Mtetra
.655 .571 .748 r
.56523 .28889 .57163 .30642 .5836 .30064 .57719 .28273 Mtetra
.656 .568 .744 r
.57719 .28273 .5836 .30064 .5956 .29455 .58919 .27642 Mtetra
.657 .566 .742 r
.58919 .27642 .5956 .29455 .60762 .28815 .60121 .26998 Mtetra
.658 .567 .741 r
.60121 .26998 .60762 .28815 .61968 .28143 .61327 .2634 Mtetra
.66 .57 .743 r
.61327 .2634 .61968 .28143 .63176 .27442 .62536 .25675 Mtetra
.663 .575 .746 r
.62536 .25675 .63176 .27442 .64386 .2672 .63749 .25005 Mtetra
.665 .582 .752 r
.63749 .25005 .64386 .2672 .65598 .25983 .64965 .24338 Mtetra
.668 .592 .761 r
.64965 .24338 .65598 .25983 .66814 .25241 .66184 .23678 Mtetra
.67 .603 .772 r
.66184 .23678 .66814 .25241 .68032 .245 .67408 .2303 Mtetra
.673 .617 .785 r
.67408 .2303 .68032 .245 .69253 .23769 .68637 .224 Mtetra
.676 .634 .8 r
.68637 .224 .69253 .23769 .70479 .23049 .69871 .21786 Mtetra
.678 .654 .819 r
.69871 .21786 .70479 .23049 .71708 .22345 .71109 .21191 Mtetra
.682 .677 .839 r
.71109 .21191 .71708 .22345 .72942 .21653 .72353 .20609 Mtetra
.685 .703 .861 r
.72353 .20609 .72942 .21653 .7418 .20971 .73603 .20039 Mtetra
.689 .733 .884 r
.73603 .20039 .7418 .20971 .75422 .20298 .74857 .19475 Mtetra
.667 .754 .915 r
.0807 .4217 .08813 .42819 .09791 .4258 .09068 .41789 Mtetra
.661 .711 .885 r
.09068 .41789 .09791 .4258 .10771 .42349 .10069 .41412 Mtetra
.652 .672 .857 r
.10069 .41412 .10771 .42349 .11755 .42128 .11073 .41044 Mtetra
.641 .637 .83 r
.11073 .41044 .11755 .42128 .12742 .41923 .12079 .40687 Mtetra
.63 .606 .807 r
.12079 .40687 .12742 .41923 .13731 .41736 .13086 .40348 Mtetra
.619 .577 .785 r
.13086 .40348 .13731 .41736 .14723 .41566 .14096 .40025 Mtetra
.608 .552 .766 r
.14096 .40025 .14723 .41566 .15718 .41414 .15107 .39723 Mtetra
.599 .531 .749 r
.15107 .39723 .15718 .41414 .16717 .41274 .1612 .3944 Mtetra
.59 .512 .735 r
.1612 .3944 .16717 .41274 .1772 .41143 .17136 .39176 Mtetra
.583 .497 .723 r
.17136 .39176 .1772 .41143 .18728 .41015 .18154 .38931 Mtetra
.577 .484 .713 r
.18154 .38931 .18728 .41015 .19742 .40884 .19175 .38704 Mtetra
.572 .475 .706 r
.19175 .38704 .19742 .40884 .20762 .40746 .202 .38492 Mtetra
.568 .468 .7 r
.202 .38492 .20762 .40746 .21789 .40596 .21228 .38293 Mtetra
.565 .463 .697 r
.21228 .38293 .21789 .40596 .22822 .40435 .2226 .38104 Mtetra
.564 .461 .696 r
.2226 .38104 .22822 .40435 .23862 .4026 .23298 .3792 Mtetra
.564 .461 .695 r
.23298 .3792 .23862 .4026 .24909 .40073 .2434 .37736 Mtetra
.564 .462 .696 r
.2434 .37736 .24909 .40073 .25962 .39873 .25389 .37548 Mtetra
.566 .464 .697 r
.25389 .37548 .25962 .39873 .27021 .39663 .26443 .37354 Mtetra
.568 .466 .699 r
.26443 .37354 .27021 .39663 .28086 .39442 .27504 .37149 Mtetra
.57 .469 .7 r
.27504 .37149 .28086 .39442 .29157 .39211 .28571 .36933 Mtetra
.573 .472 .702 r
.28571 .36933 .29157 .39211 .30234 .3897 .29644 .36703 Mtetra
.575 .475 .703 r
.29644 .36703 .30234 .3897 .31317 .38718 .30724 .36458 Mtetra
.578 .478 .704 r
.30724 .36458 .31317 .38718 .32407 .38453 .3181 .36196 Mtetra
.582 .48 .704 r
.3181 .36196 .32407 .38453 .33502 .38174 .32902 .35917 Mtetra
.585 .482 .704 r
.32902 .35917 .33502 .38174 .34603 .37879 .34001 .35618 Mtetra
.588 .484 .704 r
.34001 .35618 .34603 .37879 .35711 .37567 .35106 .35301 Mtetra
.591 .486 .704 r
.35106 .35301 .35711 .37567 .36824 .37236 .36217 .34964 Mtetra
.594 .488 .703 r
.36217 .34964 .36824 .37236 .37944 .36886 .37334 .34608 Mtetra
.597 .49 .703 r
.37334 .34608 .37944 .36886 .39069 .36515 .38457 .34232 Mtetra
.6 .491 .702 r
.38457 .34232 .39069 .36515 .40199 .36125 .39585 .33837 Mtetra
.602 .493 .702 r
.39585 .33837 .40199 .36125 .41335 .35714 .40718 .33423 Mtetra
.605 .495 .702 r
.40718 .33423 .41335 .35714 .42477 .35284 .41857 .3299 Mtetra
.608 .497 .701 r
.41857 .3299 .42477 .35284 .43623 .34833 .43001 .32536 Mtetra
.611 .499 .701 r
.43001 .32536 .43623 .34833 .44774 .34364 .4415 .32063 Mtetra
.614 .5 .701 r
.4415 .32063 .44774 .34364 .4593 .33877 .45304 .31571 Mtetra
.616 .502 .7 r
.45304 .31571 .4593 .33877 .47091 .33373 .46462 .31059 Mtetra
.619 .503 .7 r
.46462 .31059 .47091 .33373 .48256 .32854 .47625 .30529 Mtetra
.621 .504 .699 r
.47625 .30529 .48256 .32854 .49425 .32323 .48792 .29981 Mtetra
.622 .504 .698 r
.48792 .29981 .49425 .32323 .50598 .31779 .49963 .29417 Mtetra
.623 .504 .696 r
.49963 .29417 .50598 .31779 .51775 .31224 .51138 .28838 Mtetra
.624 .503 .695 r
.51138 .28838 .51775 .31224 .52957 .30658 .52316 .28247 Mtetra
.625 .502 .693 r
.52316 .28247 .52957 .30658 .54142 .30081 .53499 .27644 Mtetra
.625 .501 .691 r
.53499 .27644 .54142 .30081 .55331 .29491 .54685 .27034 Mtetra
.625 .5 .69 r
.54685 .27034 .55331 .29491 .56523 .28889 .55875 .26419 Mtetra
.624 .499 .69 r
.55875 .26419 .56523 .28889 .57719 .28273 .57068 .25804 Mtetra
.623 .499 .69 r
.57068 .25804 .57719 .28273 .58919 .27642 .58265 .25193 Mtetra
.623 .499 .692 r
.58265 .25193 .58919 .27642 .60121 .26998 .59466 .2459 Mtetra
.622 .502 .695 r
.59466 .2459 .60121 .26998 .61327 .2634 .60671 .24001 Mtetra
.622 .506 .7 r
.60671 .24001 .61327 .2634 .62536 .25675 .61881 .23426 Mtetra
.623 .512 .707 r
.61881 .23426 .62536 .25675 .63749 .25005 .63096 .22869 Mtetra
.624 .521 .717 r
.63096 .22869 .63749 .25005 .64965 .24338 .64315 .22331 Mtetra
.625 .533 .729 r
.64315 .22331 .64965 .24338 .66184 .23678 .65541 .21812 Mtetra
.628 .547 .744 r
.65541 .21812 .66184 .23678 .67408 .2303 .66771 .21312 Mtetra
.63 .564 .762 r
.66771 .21312 .67408 .2303 .68637 .224 .68008 .20832 Mtetra
.633 .584 .782 r
.68008 .20832 .68637 .224 .69871 .21786 .69251 .2037 Mtetra
.635 .608 .805 r
.69251 .2037 .69871 .21786 .71109 .21191 .70501 .19925 Mtetra
.639 .636 .831 r
.70501 .19925 .71109 .21191 .72353 .20609 .71757 .19492 Mtetra
.642 .668 .86 r
.71757 .19492 .72353 .20609 .73603 .20039 .73019 .19067 Mtetra
.644 .705 .891 r
.73019 .19067 .73603 .20039 .74857 .19475 .74288 .18646 Mtetra
.712 .763 .892 r
.07322 .41517 .0807 .4217 .09068 .41789 .0834 .41001 Mtetra
.702 .724 .867 r
.0834 .41001 .09068 .41789 .10069 .41412 .09361 .40488 Mtetra
.691 .689 .843 r
.09361 .40488 .10069 .41412 .11073 .41044 .10383 .39982 Mtetra
.679 .657 .821 r
.10383 .39982 .11073 .41044 .12079 .40687 .11408 .39486 Mtetra
.666 .628 .802 r
.11408 .39486 .12079 .40687 .13086 .40348 .12433 .39007 Mtetra
.654 .601 .783 r
.12433 .39007 .13086 .40348 .14096 .40025 .13459 .38545 Mtetra
.642 .577 .767 r
.13459 .38545 .14096 .40025 .15107 .39723 .14486 .38104 Mtetra
.631 .556 .752 r
.14486 .38104 .15107 .39723 .1612 .3944 .15514 .37683 Mtetra
.62 .537 .739 r
.15514 .37683 .1612 .3944 .17136 .39176 .16544 .37285 Mtetra
.611 .52 .726 r
.16544 .37285 .17136 .39176 .18154 .38931 .17574 .36906 Mtetra
.603 .505 .715 r
.17574 .36906 .18154 .38931 .19175 .38704 .18607 .36546 Mtetra
.596 .491 .705 r
.18607 .36546 .19175 .38704 .202 .38492 .19642 .36202 Mtetra
.59 .479 .696 r
.19642 .36202 .202 .38492 .21228 .38293 .20681 .3587 Mtetra
.586 .469 .687 r
.20681 .3587 .21228 .38293 .2226 .38104 .21722 .35546 Mtetra
.582 .46 .679 r
.21722 .35546 .2226 .38104 .23298 .3792 .22768 .35228 Mtetra
.579 .451 .671 r
.22768 .35228 .23298 .3792 .2434 .37736 .23818 .34912 Mtetra
.576 .444 .664 r
.23818 .34912 .2434 .37736 .25389 .37548 .24873 .34595 Mtetra
.574 .438 .658 r
.24873 .34595 .25389 .37548 .26443 .37354 .25932 .34276 Mtetra
.572 .433 .652 r
.25932 .34276 .26443 .37354 .27504 .37149 .26996 .33953 Mtetra
.571 .428 .648 r
.26996 .33953 .27504 .37149 .28571 .36933 .28066 .33627 Mtetra
.57 .424 .643 r
.28066 .33627 .28571 .36933 .29644 .36703 .2914 .33296 Mtetra
.569 .42 .64 r
.2914 .33296 .29644 .36703 .30724 .36458 .30219 .32959 Mtetra
.568 .417 .636 r
.30219 .32959 .30724 .36458 .3181 .36196 .31304 .32616 Mtetra
.568 .415 .634 r
.31304 .32616 .3181 .36196 .32902 .35917 .32393 .32266 Mtetra
.568 .413 .632 r
.32393 .32266 .32902 .35917 .34001 .35618 .33488 .31909 Mtetra
.568 .412 .63 r
.33488 .31909 .34001 .35618 .35106 .35301 .34588 .31544 Mtetra
.568 .411 .629 r
.34588 .31544 .35106 .35301 .36217 .34964 .35693 .3117 Mtetra
.568 .411 .628 r
.35693 .3117 .36217 .34964 .37334 .34608 .36803 .30788 Mtetra
.569 .411 .627 r
.36803 .30788 .37334 .34608 .38457 .34232 .37919 .30396 Mtetra
.57 .411 .627 r
.37919 .30396 .38457 .34232 .39585 .33837 .39039 .29996 Mtetra
.39039 .29996 .39585 .33837 .40718 .33423 .40164 .29586 Mtetra
.571 .412 .627 r
.40164 .29586 .40718 .33423 .41857 .3299 .41294 .29168 Mtetra
.572 .413 .628 r
.41294 .29168 .41857 .3299 .43001 .32536 .42429 .2874 Mtetra
.573 .415 .629 r
.42429 .2874 .43001 .32536 .4415 .32063 .43569 .28304 Mtetra
.575 .417 .63 r
.43569 .28304 .4415 .32063 .45304 .31571 .44714 .2786 Mtetra
.576 .419 .632 r
.44714 .2786 .45304 .31571 .46462 .31059 .45864 .27408 Mtetra
.578 .422 .634 r
.45864 .27408 .46462 .31059 .47625 .30529 .47018 .26948 Mtetra
.579 .425 .636 r
.47018 .26948 .47625 .30529 .48792 .29981 .48176 .26483 Mtetra
.581 .429 .639 r
.48176 .26483 .48792 .29981 .49963 .29417 .4934 .26011 Mtetra
.583 .433 .643 r
.4934 .26011 .49963 .29417 .51138 .28838 .50508 .25534 Mtetra
.586 .438 .647 r
.50508 .25534 .51138 .28838 .52316 .28247 .5168 .25052 Mtetra
.588 .443 .652 r
.5168 .25052 .52316 .28247 .53499 .27644 .52857 .24567 Mtetra
.591 .449 .657 r
.52857 .24567 .53499 .27644 .54685 .27034 .54039 .24079 Mtetra
.593 .456 .663 r
.54039 .24079 .54685 .27034 .55875 .26419 .55225 .2359 Mtetra
.596 .463 .67 r
.55225 .2359 .55875 .26419 .57068 .25804 .56415 .23103 Mtetra
.598 .47 .677 r
.56415 .23103 .57068 .25804 .58265 .25193 .57611 .2262 Mtetra
.6 .478 .685 r
.57611 .2262 .58265 .25193 .59466 .2459 .58812 .22146 Mtetra
.602 .487 .694 r
.58812 .22146 .59466 .2459 .60671 .24001 .60017 .21684 Mtetra
.603 .496 .704 r
.60017 .21684 .60671 .24001 .61881 .23426 .61229 .21238 Mtetra
.604 .505 .715 r
.61229 .21238 .61881 .23426 .63096 .22869 .62446 .20811 Mtetra
.604 .516 .727 r
.62446 .20811 .63096 .22869 .64315 .22331 .63669 .20403 Mtetra
.604 .527 .741 r
.63669 .20403 .64315 .22331 .65541 .21812 .64899 .20019 Mtetra
.604 .541 .757 r
.64899 .20019 .65541 .21812 .66771 .21312 .66136 .19655 Mtetra
.603 .557 .775 r
.66136 .19655 .66771 .21312 .68008 .20832 .6738 .19313 Mtetra
.603 .575 .796 r
.6738 .19313 .68008 .20832 .69251 .2037 .68632 .18989 Mtetra
.602 .597 .819 r
.68632 .18989 .69251 .2037 .70501 .19925 .69891 .18681 Mtetra
.601 .622 .845 r
.69891 .18681 .70501 .19925 .71757 .19492 .71157 .18385 Mtetra
.6 .652 .873 r
.71157 .18385 .71757 .19492 .73019 .19067 .72432 .18096 Mtetra
.597 .685 .903 r
.72432 .18096 .73019 .19067 .74288 .18646 .73713 .1781 Mtetra
.741 .766 .874 r
.06568 .40859 .07322 .41517 .0834 .41001 .07604 .40232 Mtetra
.732 .736 .855 r
.07604 .40232 .0834 .41001 .09361 .40488 .08642 .39606 Mtetra
.721 .708 .837 r
.08642 .39606 .09361 .40488 .10383 .39982 .09681 .38986 Mtetra
.71 .681 .821 r
.09681 .38986 .10383 .39982 .11408 .39486 .10722 .38375 Mtetra
.698 .656 .805 r
.10722 .38375 .11408 .39486 .12433 .39007 .11763 .37779 Mtetra
.686 .633 .791 r
.11763 .37779 .12433 .39007 .13459 .38545 .12804 .37199 Mtetra
.674 .611 .777 r
.12804 .37199 .13459 .38545 .14486 .38104 .13846 .36638 Mtetra
.662 .591 .764 r
.13846 .36638 .14486 .38104 .15514 .37683 .14888 .36097 Mtetra
.652 .572 .752 r
.14888 .36097 .15514 .37683 .16544 .37285 .15931 .35575 Mtetra
.642 .554 .74 r
.15931 .35575 .16544 .37285 .17574 .36906 .16975 .35068 Mtetra
.634 .538 .728 r
.16975 .35068 .17574 .36906 .18607 .36546 .1802 .34575 Mtetra
.627 .523 .717 r
.1802 .34575 .18607 .36546 .19642 .36202 .19069 .3409 Mtetra
.62 .509 .706 r
.19069 .3409 .19642 .36202 .20681 .3587 .2012 .33609 Mtetra
.615 .496 .695 r
.2012 .33609 .20681 .3587 .21722 .35546 .21174 .3313 Mtetra
.609 .485 .685 r
.21174 .3313 .21722 .35546 .22768 .35228 .22231 .32652 Mtetra
.604 .473 .676 r
.22231 .32652 .22768 .35228 .23818 .34912 .23292 .32175 Mtetra
.6 .463 .667 r
.23292 .32175 .23818 .34912 .24873 .34595 .24357 .317 Mtetra
.595 .454 .659 r
.24357 .317 .24873 .34595 .25932 .34276 .25424 .31228 Mtetra
.591 .446 .652 r
.25424 .31228 .25932 .34276 .26996 .33953 .26495 .30761 Mtetra
.587 .438 .646 r
.26495 .30761 .26996 .33953 .28066 .33627 .27569 .303 Mtetra
.583 .432 .641 r
.27569 .303 .28066 .33627 .2914 .33296 .28646 .29846 Mtetra
.58 .426 .637 r
.28646 .29846 .2914 .33296 .30219 .32959 .29727 .294 Mtetra
.577 .421 .633 r
.29727 .294 .30219 .32959 .31304 .32616 .30811 .28961 Mtetra
.575 .417 .63 r
.30811 .28961 .31304 .32616 .32393 .32266 .31898 .2853 Mtetra
.573 .414 .627 r
.31898 .2853 .32393 .32266 .33488 .31909 .32989 .28104 Mtetra
.571 .411 .625 r
.32989 .28104 .33488 .31909 .34588 .31544 .34084 .27684 Mtetra
.57 .409 .624 r
.34084 .27684 .34588 .31544 .35693 .3117 .35184 .27269 Mtetra
.569 .407 .623 r
.35184 .27269 .35693 .3117 .36803 .30788 .36287 .26857 Mtetra
.568 .406 .622 r
.36287 .26857 .36803 .30788 .37919 .30396 .37395 .26448 Mtetra
.567 .406 .622 r
.37395 .26448 .37919 .30396 .39039 .29996 .38506 .26042 Mtetra
.567 .405 .622 r
.38506 .26042 .39039 .29996 .40164 .29586 .39623 .25639 Mtetra
.39623 .25639 .40164 .29586 .41294 .29168 .40744 .25239 Mtetra
.566 .406 .623 r
.40744 .25239 .41294 .29168 .42429 .2874 .41869 .24842 Mtetra
.566 .406 .624 r
.41869 .24842 .42429 .2874 .43569 .28304 .42999 .2445 Mtetra
.566 .408 .625 r
.42999 .2445 .43569 .28304 .44714 .2786 .44134 .24063 Mtetra
.566 .409 .627 r
.44134 .24063 .44714 .2786 .45864 .27408 .45274 .23683 Mtetra
.566 .411 .63 r
.45274 .23683 .45864 .27408 .47018 .26948 .46419 .23309 Mtetra
.566 .413 .633 r
.46419 .23309 .47018 .26948 .48176 .26483 .47568 .22944 Mtetra
.567 .417 .637 r
.47568 .22944 .48176 .26483 .4934 .26011 .48723 .22586 Mtetra
.567 .421 .642 r
.48723 .22586 .4934 .26011 .50508 .25534 .49883 .22235 Mtetra
.568 .425 .647 r
.49883 .22235 .50508 .25534 .5168 .25052 .51048 .21891 Mtetra
.57 .431 .653 r
.51048 .21891 .5168 .25052 .52857 .24567 .5222 .21551 Mtetra
.571 .438 .66 r
.5222 .21551 .52857 .24567 .54039 .24079 .53396 .21215 Mtetra
.574 .446 .669 r
.53396 .21215 .54039 .24079 .55225 .2359 .54579 .20881 Mtetra
.576 .455 .678 r
.54579 .20881 .55225 .2359 .56415 .23103 .55767 .20548 Mtetra
.579 .465 .688 r
.55767 .20548 .56415 .23103 .57611 .2262 .56962 .20216 Mtetra
.582 .476 .699 r
.56962 .20216 .57611 .2262 .58812 .22146 .58162 .19886 Mtetra
.584 .487 .71 r
.58162 .19886 .58812 .22146 .60017 .21684 .59369 .1956 Mtetra
.586 .499 .723 r
.59369 .1956 .60017 .21684 .61229 .21238 .60582 .19243 Mtetra
.586 .51 .736 r
.60582 .19243 .61229 .21238 .62446 .20811 .61802 .18939 Mtetra
.586 .522 .75 r
.61802 .18939 .62446 .20811 .63669 .20403 .63029 .18652 Mtetra
.584 .534 .765 r
.63029 .18652 .63669 .20403 .64899 .20019 .64263 .18385 Mtetra
.581 .548 .782 r
.64263 .18385 .64899 .20019 .66136 .19655 .65505 .18137 Mtetra
.578 .562 .8 r
.65505 .18137 .66136 .19655 .6738 .19313 .66756 .1791 Mtetra
.574 .579 .82 r
.66756 .1791 .6738 .19313 .68632 .18989 .68014 .17701 Mtetra
.57 .597 .841 r
.68014 .17701 .68632 .18989 .69891 .18681 .69282 .17506 Mtetra
.565 .619 .865 r
.69282 .17506 .69891 .18681 .71157 .18385 .70557 .17322 Mtetra
.56 .643 .889 r
.70557 .17322 .71157 .18385 .72432 .18096 .71841 .17144 Mtetra
.553 .67 .915 r
.71841 .17144 .72432 .18096 .73713 .1781 .73134 .16968 Mtetra
.755 .768 .863 r
.05808 .40196 .06568 .40859 .07604 .40232 .06856 .39503 Mtetra
.75 .751 .853 r
.06856 .39503 .07604 .40232 .08642 .39606 .07906 .3881 Mtetra
.743 .734 .843 r
.07906 .3881 .08642 .39606 .09681 .38986 .08957 .38119 Mtetra
.736 .717 .833 r
.08957 .38119 .09681 .38986 .10722 .38375 .10009 .37434 Mtetra
.727 .699 .824 r
.10009 .37434 .10722 .38375 .11763 .37779 .11062 .36759 Mtetra
.718 .682 .814 r
.11062 .36759 .11763 .37779 .12804 .37199 .12116 .36094 Mtetra
.708 .663 .803 r
.12116 .36094 .12804 .37199 .13846 .36638 .1317 .35445 Mtetra
.699 .645 .793 r
.1317 .35445 .13846 .36638 .14888 .36097 .14224 .34811 Mtetra
.688 .627 .782 r
.14224 .34811 .14888 .36097 .15931 .35575 .15278 .34193 Mtetra
.679 .61 .772 r
.15278 .34193 .15931 .35575 .16975 .35068 .16334 .3359 Mtetra
.67 .594 .762 r
.16334 .3359 .16975 .35068 .1802 .34575 .1739 .33002 Mtetra
.662 .58 .752 r
.1739 .33002 .1802 .34575 .19069 .3409 .18447 .32425 Mtetra
.655 .566 .743 r
.18447 .32425 .19069 .3409 .2012 .33609 .19507 .3186 Mtetra
.648 .555 .736 r
.19507 .3186 .2012 .33609 .21174 .3313 .20568 .31304 Mtetra
.643 .545 .729 r
.20568 .31304 .21174 .3313 .22231 .32652 .21631 .30758 Mtetra
.638 .537 .724 r
.21631 .30758 .22231 .32652 .23292 .32175 .22696 .30222 Mtetra
.633 .53 .719 r
.22696 .30222 .23292 .32175 .24357 .317 .23763 .29695 Mtetra
.629 .523 .715 r
.23763 .29695 .24357 .317 .25424 .31228 .24833 .29178 Mtetra
.625 .518 .712 r
.24833 .29178 .25424 .31228 .26495 .30761 .25906 .28672 Mtetra
.622 .513 .709 r
.25906 .28672 .26495 .30761 .27569 .303 .2698 .28176 Mtetra
.619 .509 .707 r
.2698 .28176 .27569 .303 .28646 .29846 .28058 .27691 Mtetra
.616 .505 .705 r
.28058 .27691 .28646 .29846 .29727 .294 .29138 .27217 Mtetra
.613 .502 .704 r
.29138 .27217 .29727 .294 .30811 .28961 .30222 .26754 Mtetra
.61 .499 .702 r
.30222 .26754 .30811 .28961 .31898 .2853 .31308 .263 Mtetra
.608 .496 .701 r
.31308 .263 .31898 .2853 .32989 .28104 .32398 .25855 Mtetra
.606 .494 .7 r
.32398 .25855 .32989 .28104 .34084 .27684 .33492 .25418 Mtetra
.604 .492 .699 r
.33492 .25418 .34084 .27684 .35184 .27269 .34589 .24988 Mtetra
.602 .49 .699 r
.34589 .24988 .35184 .27269 .36287 .26857 .3569 .24566 Mtetra
.6 .489 .698 r
.3569 .24566 .36287 .26857 .37395 .26448 .36795 .24149 Mtetra
.599 .488 .698 r
.36795 .24149 .37395 .26448 .38506 .26042 .37905 .23739 Mtetra
.598 .487 .698 r
.37905 .23739 .38506 .26042 .39623 .25639 .39018 .23335 Mtetra
.597 .486 .699 r
.39018 .23335 .39623 .25639 .40744 .25239 .40136 .22937 Mtetra
.595 .486 .699 r
.40136 .22937 .40744 .25239 .41869 .24842 .41259 .22546 Mtetra
.594 .486 .7 r
.41259 .22546 .41869 .24842 .42999 .2445 .42386 .22162 Mtetra
.593 .486 .701 r
.42386 .22162 .42999 .2445 .44134 .24063 .43518 .21786 Mtetra
.591 .486 .703 r
.43518 .21786 .44134 .24063 .45274 .23683 .44654 .2142 Mtetra
.59 .486 .705 r
.44654 .2142 .45274 .23683 .46419 .23309 .45796 .21063 Mtetra
.588 .487 .706 r
.45796 .21063 .46419 .23309 .47568 .22944 .46943 .20717 Mtetra
.587 .488 .709 r
.46943 .20717 .47568 .22944 .48723 .22586 .48094 .20382 Mtetra
.585 .489 .711 r
.48094 .20382 .48723 .22586 .49883 .22235 .49252 .20059 Mtetra
.584 .49 .714 r
.49252 .20059 .49883 .22235 .51048 .21891 .50415 .19746 Mtetra
.582 .492 .718 r
.50415 .19746 .51048 .21891 .5222 .21551 .51584 .19444 Mtetra
.581 .495 .722 r
.51584 .19444 .5222 .21551 .53396 .21215 .52758 .19152 Mtetra
.58 .498 .727 r
.52758 .19152 .53396 .21215 .54579 .20881 .53939 .1887 Mtetra
.579 .502 .732 r
.53939 .1887 .54579 .20881 .55767 .20548 .55127 .18599 Mtetra
.578 .508 .739 r
.55127 .18599 .55767 .20548 .56962 .20216 .56321 .18337 Mtetra
.578 .515 .748 r
.56321 .18337 .56962 .20216 .58162 .19886 .57522 .18085 Mtetra
.576 .523 .758 r
.57522 .18085 .58162 .19886 .59369 .1956 .58729 .17845 Mtetra
.575 .532 .77 r
.58729 .17845 .59369 .1956 .60582 .19243 .59944 .17618 Mtetra
.573 .542 .783 r
.59944 .17618 .60582 .19243 .61802 .18939 .61167 .17406 Mtetra
.569 .554 .797 r
.61167 .17406 .61802 .18939 .63029 .18652 .62397 .1721 Mtetra
.565 .566 .813 r
.62397 .1721 .63029 .18652 .64263 .18385 .63636 .17031 Mtetra
.56 .579 .83 r
.63636 .17031 .64263 .18385 .65505 .18137 .64883 .16869 Mtetra
.554 .593 .847 r
.64883 .16869 .65505 .18137 .66756 .1791 .66138 .16722 Mtetra
.548 .607 .864 r
.66138 .16722 .66756 .1791 .68014 .17701 .67403 .16588 Mtetra
.541 .621 .881 r
.67403 .16588 .68014 .17701 .69282 .17506 .68676 .16464 Mtetra
.534 .636 .897 r
.68676 .16464 .69282 .17506 .70557 .17322 .69959 .16346 Mtetra
.528 .651 .913 r
.69959 .16346 .70557 .17322 .71841 .17144 .7125 .16232 Mtetra
.521 .667 .928 r
.7125 .16232 .71841 .17144 .73134 .16968 .7255 .16118 Mtetra
.758 .768 .861 r
.05043 .39529 .05808 .40196 .06856 .39503 .06096 .38821 Mtetra
.757 .765 .859 r
.06096 .38821 .06856 .39503 .07906 .3881 .07151 .38111 Mtetra
.756 .761 .857 r
.07151 .38111 .07906 .3881 .08957 .38119 .08207 .374 Mtetra
.753 .756 .855 r
.08207 .374 .08957 .38119 .10009 .37434 .09265 .36691 Mtetra
.751 .751 .852 r
.09265 .36691 .10009 .37434 .11062 .36759 .10325 .35986 Mtetra
.747 .743 .849 r
.10325 .35986 .11062 .36759 .12116 .36094 .11385 .35286 Mtetra
.742 .735 .845 r
.11385 .35286 .12116 .36094 .1317 .35445 .12447 .34596 Mtetra
.736 .725 .841 r
.12447 .34596 .1317 .35445 .14224 .34811 .13508 .33916 Mtetra
.729 .713 .836 r
.13508 .33916 .14224 .34811 .15278 .34193 .14571 .3325 Mtetra
.722 .702 .83 r
.14571 .3325 .15278 .34193 .16334 .3359 .15634 .32597 Mtetra
.714 .69 .825 r
.15634 .32597 .16334 .3359 .1739 .33002 .16697 .31961 Mtetra
.707 .678 .82 r
.16697 .31961 .1739 .33002 .18447 .32425 .17761 .31341 Mtetra
.699 .668 .816 r
.17761 .31341 .18447 .32425 .19507 .3186 .18825 .30741 Mtetra
.692 .659 .813 r
.18825 .30741 .19507 .3186 .20568 .31304 .1989 .30158 Mtetra
.686 .653 .811 r
.1989 .30158 .20568 .31304 .21631 .30758 .20956 .29595 Mtetra
.681 .648 .811 r
.20956 .29595 .21631 .30758 .22696 .30222 .22024 .29048 Mtetra
.677 .645 .811 r
.22024 .29048 .22696 .30222 .23763 .29695 .23093 .28517 Mtetra
.673 .643 .812 r
.23093 .28517 .23763 .29695 .24833 .29178 .24164 .28 Mtetra
.67 .642 .814 r
.24164 .28 .24833 .29178 .25906 .28672 .25237 .27496 Mtetra
.667 .642 .816 r
.25237 .27496 .25906 .28672 .2698 .28176 .26312 .27003 Mtetra
.664 .642 .818 r
.26312 .27003 .2698 .28176 .28058 .27691 .27391 .26522 Mtetra
.662 .642 .82 r
.27391 .26522 .28058 .27691 .29138 .27217 .28472 .2605 Mtetra
.659 .642 .822 r
.28472 .2605 .29138 .27217 .30222 .26754 .29557 .25586 Mtetra
.657 .642 .823 r
.29557 .25586 .30222 .26754 .31308 .263 .30644 .25132 Mtetra
.655 .641 .825 r
.30644 .25132 .31308 .263 .32398 .25855 .31736 .24684 Mtetra
.652 .641 .826 r
.31736 .24684 .32398 .25855 .33492 .25418 .3283 .24244 Mtetra
.65 .64 .826 r
.3283 .24244 .33492 .25418 .34589 .24988 .33929 .23811 Mtetra
.648 .639 .827 r
.33929 .23811 .34589 .24988 .3569 .24566 .35032 .23384 Mtetra
.646 .637 .828 r
.35032 .23384 .3569 .24566 .36795 .24149 .36138 .22964 Mtetra
.643 .636 .828 r
.36138 .22964 .36795 .24149 .37905 .23739 .37249 .2255 Mtetra
.641 .635 .829 r
.37249 .2255 .37905 .23739 .39018 .23335 .38364 .22143 Mtetra
.639 .634 .83 r
.38364 .22143 .39018 .23335 .40136 .22937 .39483 .21742 Mtetra
.637 .633 .83 r
.39483 .21742 .40136 .22937 .41259 .22546 .40607 .21348 Mtetra
.634 .632 .831 r
.40607 .21348 .41259 .22546 .42386 .22162 .41736 .2096 Mtetra
.632 .631 .832 r
.41736 .2096 .42386 .22162 .43518 .21786 .42869 .2058 Mtetra
.629 .63 .832 r
.42869 .2058 .43518 .21786 .44654 .2142 .44007 .20208 Mtetra
.626 .628 .833 r
.44007 .20208 .44654 .2142 .45796 .21063 .4515 .19844 Mtetra
.623 .626 .833 r
.4515 .19844 .45796 .21063 .46943 .20717 .46298 .19488 Mtetra
.62 .623 .832 r
.46298 .19488 .46943 .20717 .48094 .20382 .47451 .19143 Mtetra
.616 .62 .832 r
.47451 .19143 .48094 .20382 .49252 .20059 .4861 .18809 Mtetra
.612 .617 .832 r
.4861 .18809 .49252 .20059 .50415 .19746 .49774 .18487 Mtetra
.607 .614 .832 r
.49774 .18487 .50415 .19746 .51584 .19444 .50944 .18178 Mtetra
.602 .611 .832 r
.50944 .18178 .51584 .19444 .52758 .19152 .5212 .17884 Mtetra
.597 .608 .834 r
.5212 .17884 .52758 .19152 .53939 .1887 .53302 .17605 Mtetra
.592 .607 .836 r
.53302 .17605 .53939 .1887 .55127 .18599 .54491 .17344 Mtetra
.586 .607 .84 r
.54491 .17344 .55127 .18599 .56321 .18337 .55686 .17102 Mtetra
.579 .608 .846 r
.55686 .17102 .56321 .18337 .57522 .18085 .56889 .1688 Mtetra
.572 .611 .853 r
.56889 .1688 .57522 .18085 .58729 .17845 .58099 .16677 Mtetra
.566 .617 .862 r
.58099 .16677 .58729 .17845 .59944 .17618 .59317 .16493 Mtetra
.558 .623 .873 r
.59317 .16493 .59944 .17618 .61167 .17406 .60542 .16325 Mtetra
.551 .631 .884 r
.60542 .16325 .61167 .17406 .62397 .1721 .61776 .16172 Mtetra
.543 .639 .895 r
.61776 .16172 .62397 .1721 .63636 .17031 .63019 .16033 Mtetra
.536 .646 .905 r
.63019 .16033 .63636 .17031 .64883 .16869 .64269 .15906 Mtetra
.528 .653 .914 r
.64269 .15906 .64883 .16869 .66138 .16722 .65529 .15789 Mtetra
.522 .659 .922 r
.65529 .15789 .66138 .16722 .67403 .16588 .66798 .15679 Mtetra
.517 .665 .929 r
.66798 .15679 .67403 .16588 .68676 .16464 .68075 .15573 Mtetra
.513 .669 .934 r
.68075 .15573 .68676 .16464 .69959 .16346 .69362 .15469 Mtetra
.511 .673 .937 r
.69362 .15469 .69959 .16346 .7125 .16232 .70657 .15366 Mtetra
.51 .677 .941 r
.70657 .15366 .7125 .16232 .7255 .16118 .71961 .15261 Mtetra
.745 .767 .871 r
.04273 .38856 .05043 .39529 .06096 .38821 .0532 .38202 Mtetra
.75 .783 .88 r
.0532 .38202 .06096 .38821 .07151 .38111 .0637 .37546 Mtetra
.754 .8 .89 r
.0637 .37546 .07151 .38111 .08207 .374 .07422 .36888 Mtetra
.757 .818 .9 r
.07422 .36888 .08207 .374 .09265 .36691 .08476 .3623 Mtetra
.759 .835 .91 r
.08476 .3623 .09265 .36691 .10325 .35986 .09533 .35573 Mtetra
.76 .852 .919 r
.09533 .35573 .10325 .35986 .11385 .35286 .10591 .3492 Mtetra
.759 .868 .928 r
.10591 .3492 .11385 .35286 .12447 .34596 .1165 .34273 Mtetra
.756 .883 .936 r
.1165 .34273 .12447 .34596 .13508 .33916 .12711 .33634 Mtetra
.751 .897 .944 r
.12711 .33634 .13508 .33916 .14571 .3325 .13773 .33004 Mtetra
.744 .91 .95 r
.13773 .33004 .14571 .3325 .15634 .32597 .14836 .32384 Mtetra
.735 .92 .955 r
.14836 .32384 .15634 .32597 .16697 .31961 .159 .31776 Mtetra
.724 .929 .958 r
.159 .31776 .16697 .31961 .17761 .31341 .16966 .3118 Mtetra
.713 .935 .961 r
.16966 .3118 .17761 .31341 .18825 .30741 .18033 .30597 Mtetra
.701 .939 .962 r
.18033 .30597 .18825 .30741 .1989 .30158 .19101 .30026 Mtetra
.69 .941 .963 r
.19101 .30026 .1989 .30158 .20956 .29595 .20171 .29466 Mtetra
.681 .941 .964 r
.20171 .29466 .20956 .29595 .22024 .29048 .21243 .28917 Mtetra
.673 .939 .965 r
.21243 .28917 .22024 .29048 .23093 .28517 .22317 .28379 Mtetra
.667 .937 .967 r
.22317 .28379 .23093 .28517 .24164 .28 .23394 .2785 Mtetra
.663 .934 .969 r
.23394 .2785 .24164 .28 .25237 .27496 .24473 .2733 Mtetra
.66 .93 .971 r
.24473 .2733 .25237 .27496 .26312 .27003 .25555 .26819 Mtetra
.658 .926 .974 r
.25555 .26819 .26312 .27003 .27391 .26522 .26639 .26317 Mtetra
.656 .921 .976 r
.26639 .26317 .27391 .26522 .28472 .2605 .27727 .25825 Mtetra
.653 .916 .978 r
.27727 .25825 .28472 .2605 .29557 .25586 .28817 .25342 Mtetra
.651 .91 .98 r
.28817 .25342 .29557 .25586 .30644 .25132 .2991 .24868 Mtetra
.648 .905 .982 r
.2991 .24868 .30644 .25132 .31736 .24684 .31007 .24403 Mtetra
.645 .9 .983 r
.31007 .24403 .31736 .24684 .3283 .24244 .32107 .23948 Mtetra
.641 .895 .985 r
.32107 .23948 .3283 .24244 .33929 .23811 .33211 .23503 Mtetra
.636 .891 .986 r
.33211 .23503 .33929 .23811 .35032 .23384 .34318 .23067 Mtetra
.631 .887 .987 r
.34318 .23067 .35032 .23384 .36138 .22964 .35429 .2264 Mtetra
.625 .884 .988 r
.35429 .2264 .36138 .22964 .37249 .2255 .36545 .22224 Mtetra
.617 .882 .99 r
.36545 .22224 .37249 .2255 .38364 .22143 .37664 .21817 Mtetra
.609 .881 .991 r
.37664 .21817 .38364 .22143 .39483 .21742 .38787 .21419 Mtetra
.6 .88 .992 r
.38787 .21419 .39483 .21742 .40607 .21348 .39915 .21032 Mtetra
.59 .879 .993 r
.39915 .21032 .40607 .21348 .41736 .2096 .41048 .20654 Mtetra
.578 .879 .993 r
.41048 .20654 .41736 .2096 .42869 .2058 .42185 .20285 Mtetra
.566 .878 .993 r
.42185 .20285 .42869 .2058 .44007 .20208 .43328 .19926 Mtetra
.551 .877 .992 r
.43328 .19926 .44007 .20208 .4515 .19844 .44475 .19577 Mtetra
.536 .876 .989 r
.44475 .19577 .4515 .19844 .46298 .19488 .45627 .19236 Mtetra
.519 .874 .986 r
.45627 .19236 .46298 .19488 .47451 .19143 .46785 .18906 Mtetra
.502 .871 .982 r
.46785 .18906 .47451 .19143 .4861 .18809 .47949 .18584 Mtetra
.485 .867 .977 r
.47949 .18584 .4861 .18809 .49774 .18487 .49118 .18273 Mtetra
.469 .862 .973 r
.49118 .18273 .49774 .18487 .50944 .18178 .50293 .1797 Mtetra
.454 .857 .968 r
.50293 .1797 .50944 .18178 .5212 .17884 .51475 .17678 Mtetra
.441 .851 .965 r
.51475 .17678 .5212 .17884 .53302 .17605 .52662 .17396 Mtetra
.43 .845 .964 r
.52662 .17396 .53302 .17605 .54491 .17344 .53856 .17126 Mtetra
.423 .84 .965 r
.53856 .17126 .54491 .17344 .55686 .17102 .55057 .16867 Mtetra
.42 .834 .969 r
.55057 .16867 .55686 .17102 .56889 .1688 .56265 .16621 Mtetra
.42 .829 .975 r
.56265 .16621 .56889 .1688 .58099 .16677 .5748 .16389 Mtetra
.424 .824 .981 r
.5748 .16389 .58099 .16677 .59317 .16493 .58702 .16169 Mtetra
.43 .818 .988 r
.58702 .16169 .59317 .16493 .60542 .16325 .59932 .15961 Mtetra
.439 .81 .994 r
.59932 .15961 .60542 .16325 .61776 .16172 .61169 .15764 Mtetra
.449 .802 .997 r
.61169 .15764 .61776 .16172 .63019 .16033 .62415 .15578 Mtetra
.461 .792 .999 r
.62415 .15578 .63019 .16033 .64269 .15906 .63669 .154 Mtetra
.473 .781 .998 r
.63669 .154 .64269 .15906 .65529 .15789 .64931 .15229 Mtetra
.486 .769 .994 r
.64931 .15229 .65529 .15789 .66798 .15679 .66202 .15061 Mtetra
.498 .755 .987 r
.66202 .15061 .66798 .15679 .68075 .15573 .67481 .14896 Mtetra
.509 .741 .978 r
.67481 .14896 .68075 .15573 .69362 .15469 .68768 .14732 Mtetra
.52 .726 .967 r
.68768 .14732 .69362 .15469 .70657 .15366 .70064 .14566 Mtetra
.529 .71 .955 r
.70064 .14566 .70657 .15366 .71961 .15261 .71368 .14397 Mtetra
.719 .764 .888 r
.03496 .38178 .04273 .38856 .0532 .38202 .04531 .37624 Mtetra
.725 .795 .907 r
.04531 .37624 .0532 .38202 .0637 .37546 .05569 .37067 Mtetra
.729 .828 .926 r
.05569 .37067 .0637 .37546 .07422 .36888 .06611 .36508 Mtetra
.729 .861 .943 r
.06611 .36508 .07422 .36888 .08476 .3623 .07655 .35948 Mtetra
.724 .894 .957 r
.07655 .35948 .08476 .3623 .09533 .35573 .08702 .35388 Mtetra
.711 .923 .964 r
.08702 .35388 .09533 .35573 .10591 .3492 .09751 .3483 Mtetra
.688 .944 .961 r
.09751 .3483 .10591 .3492 .1165 .34273 .10803 .34275 Mtetra
.651 .954 .944 r
.10803 .34275 .1165 .34273 .12711 .33634 .11857 .33725 Mtetra
.601 .949 .911 r
.11857 .33725 .12711 .33634 .13773 .33004 .12913 .33181 Mtetra
.54 .927 .861 r
.12913 .33181 .13773 .33004 .14836 .32384 .13972 .32642 Mtetra
.471 .89 .799 r
.13972 .32642 .14836 .32384 .159 .31776 .15033 .32108 Mtetra
.403 .845 .731 r
.15033 .32108 .159 .31776 .16966 .3118 .16097 .31578 Mtetra
.341 .797 .666 r
.16097 .31578 .16966 .3118 .18033 .30597 .17164 .31051 Mtetra
0 0 0 r
.17164 .31051 .18033 .30597 .19101 .30026 .18233 .30525 Mtetra
.18233 .30525 .19101 .30026 .20171 .29466 .19306 .3 Mtetra
.19306 .3 .20171 .29466 .21243 .28917 .20383 .29476 Mtetra
.20383 .29476 .21243 .28917 .22317 .28379 .21462 .28953 Mtetra
.21462 .28953 .22317 .28379 .23394 .2785 .22545 .28432 Mtetra
.22545 .28432 .23394 .2785 .24473 .2733 .23631 .27915 Mtetra
.23631 .27915 .24473 .2733 .25555 .26819 .24719 .27403 Mtetra
.24719 .27403 .25555 .26819 .26639 .26317 .25811 .26896 Mtetra
.25811 .26896 .26639 .26317 .27727 .25825 .26906 .26397 Mtetra
.26906 .26397 .27727 .25825 .28817 .25342 .28005 .25906 Mtetra
.28005 .25906 .28817 .25342 .2991 .24868 .29106 .25424 Mtetra
.29106 .25424 .2991 .24868 .31007 .24403 .3021 .24951 Mtetra
.3021 .24951 .31007 .24403 .32107 .23948 .31318 .24489 Mtetra
.31318 .24489 .32107 .23948 .33211 .23503 .3243 .24038 Mtetra
.3243 .24038 .33211 .23503 .34318 .23067 .33545 .23597 Mtetra
.33545 .23597 .34318 .23067 .35429 .2264 .34663 .23167 Mtetra
.34663 .23167 .35429 .2264 .36545 .22224 .35786 .22748 Mtetra
.35786 .22748 .36545 .22224 .37664 .21817 .36913 .2234 Mtetra
.36913 .2234 .37664 .21817 .38787 .21419 .38044 .21943 Mtetra
.38044 .21943 .38787 .21419 .39915 .21032 .39179 .21557 Mtetra
.39179 .21557 .39915 .21032 .41048 .20654 .40319 .21181 Mtetra
.004 0 0 r
.40319 .21181 .41048 .20654 .42185 .20285 .41464 .20816 Mtetra
.017 0 0 r
.41464 .20816 .42185 .20285 .43328 .19926 .42614 .20461 Mtetra
.029 0 0 r
.42614 .20461 .43328 .19926 .44475 .19577 .43769 .20115 Mtetra
.04 0 0 r
.43769 .20115 .44475 .19577 .45627 .19236 .44929 .19777 Mtetra
.05 0 0 r
.44929 .19777 .45627 .19236 .46785 .18906 .46095 .19447 Mtetra
.057 0 0 r
.46095 .19447 .46785 .18906 .47949 .18584 .47267 .19123 Mtetra
.061 0 0 r
.47267 .19123 .47949 .18584 .49118 .18273 .48445 .18803 Mtetra
.062 0 0 r
.48445 .18803 .49118 .18273 .50293 .1797 .49628 .18488 Mtetra
.059 0 0 r
.49628 .18488 .50293 .1797 .51475 .17678 .50818 .18175 Mtetra
.051 0 0 r
.50818 .18175 .51475 .17678 .52662 .17396 .52014 .17863 Mtetra
.036 0 0 r
.52014 .17863 .52662 .17396 .53856 .17126 .53216 .17553 Mtetra
.015 0 0 r
.53216 .17553 .53856 .17126 .55057 .16867 .54424 .17243 Mtetra
0 0 0 r
.54424 .17243 .55057 .16867 .56265 .16621 .55639 .16935 Mtetra
.55639 .16935 .56265 .16621 .5748 .16389 .56861 .16629 Mtetra
.56861 .16629 .5748 .16389 .58702 .16169 .58089 .16328 Mtetra
.58089 .16328 .58702 .16169 .59932 .15961 .59324 .16032 Mtetra
.218 .74 .758 r
.59324 .16032 .59932 .15961 .61169 .15764 .60567 .15742 Mtetra
.285 .786 .838 r
.60567 .15742 .61169 .15764 .62415 .15578 .61816 .15458 Mtetra
.353 .82 .907 r
.61816 .15458 .62415 .15578 .63669 .154 .63073 .15178 Mtetra
.414 .839 .959 r
.63073 .15178 .63669 .154 .64931 .15229 .64337 .14903 Mtetra
.467 .841 .989 r
.64337 .14903 .64931 .15229 .66202 .15061 .65608 .14629 Mtetra
.509 .828 1 r
.65608 .14629 .66202 .15061 .67481 .14896 .66887 .14356 Mtetra
.539 .806 .995 r
.66887 .14356 .67481 .14896 .68768 .14732 .68174 .14082 Mtetra
.56 .778 .98 r
.68174 .14082 .68768 .14732 .70064 .14566 .69468 .13805 Mtetra
.575 .748 .959 r
.69468 .13805 .70064 .14566 .71368 .14397 .70769 .13525 Mtetra
.676 .756 .911 r
.02714 .37496 .03496 .38178 .04531 .37624 .03732 .3707 Mtetra
.679 .798 .938 r
.03732 .3707 .04531 .37624 .05569 .37067 .04753 .36641 Mtetra
.676 .841 .962 r
.04753 .36641 .05569 .37067 .06611 .36508 .05779 .36209 Mtetra
.663 .881 .979 r
.05779 .36209 .06611 .36508 .07655 .35948 .06809 .35775 Mtetra
.634 .913 .981 r
.06809 .35775 .07655 .35948 .08702 .35388 .07842 .3534 Mtetra
.585 .926 .959 r
.07842 .3534 .08702 .35388 .09751 .3483 .08879 .34904 Mtetra
.513 .912 .905 r
.08879 .34904 .09751 .3483 .10803 .34275 .09919 .34468 Mtetra
.423 .867 .821 r
.09919 .34468 .10803 .34275 .11857 .33725 .10964 .34034 Mtetra
.324 .798 .716 r
.10964 .34034 .11857 .33725 .12913 .33181 .12011 .336 Mtetra
0 0 0 r
.12011 .336 .12913 .33181 .13972 .32642 .13063 .33166 Mtetra
.13063 .33166 .13972 .32642 .15033 .32108 .14118 .32732 Mtetra
.14118 .32732 .15033 .32108 .16097 .31578 .15178 .32295 Mtetra
.15178 .32295 .16097 .31578 .17164 .31051 .16242 .31852 Mtetra
.023 0 0 r
.16242 .31852 .17164 .31051 .18233 .30525 .17311 .31404 Mtetra
.056 0 0 r
.17311 .31404 .18233 .30525 .19306 .3 .18384 .30947 Mtetra
.084 0 0 r
.18384 .30947 .19306 .3 .20383 .29476 .19462 .30485 Mtetra
.106 0 0 r
.19462 .30485 .20383 .29476 .21462 .28953 .20544 .30017 Mtetra
.126 0 0 r
.20544 .30017 .21462 .28953 .22545 .28432 .2163 .29546 Mtetra
.143 0 0 r
.2163 .29546 .22545 .28432 .23631 .27915 .22721 .29072 Mtetra
.158 0 0 r
.22721 .29072 .23631 .27915 .24719 .27403 .23815 .28598 Mtetra
.171 0 0 r
.23815 .28598 .24719 .27403 .25811 .26896 .24913 .28125 Mtetra
.184 0 0 r
.24913 .28125 .25811 .26896 .26906 .26397 .26015 .27655 Mtetra
.195 0 0 r
.26015 .27655 .26906 .26397 .28005 .25906 .27121 .27189 Mtetra
.205 0 0 r
.27121 .27189 .28005 .25906 .29106 .25424 .2823 .26728 Mtetra
.215 0 .005 r
.2823 .26728 .29106 .25424 .3021 .24951 .29343 .26273 Mtetra
.223 0 .014 r
.29343 .26273 .3021 .24951 .31318 .24489 .3046 .25824 Mtetra
.23 0 .021 r
.3046 .25824 .31318 .24489 .3243 .24038 .31581 .25382 Mtetra
.237 0 .027 r
.31581 .25382 .3243 .24038 .33545 .23597 .32706 .24947 Mtetra
.243 0 .032 r
.32706 .24947 .33545 .23597 .34663 .23167 .33835 .2452 Mtetra
.247 0 .035 r
.33835 .2452 .34663 .23167 .35786 .22748 .34968 .24099 Mtetra
.251 0 .037 r
.34968 .24099 .35786 .22748 .36913 .2234 .36105 .23685 Mtetra
.255 0 .038 r
.36105 .23685 .36913 .2234 .38044 .21943 .37247 .23279 Mtetra
.257 0 .037 r
.37247 .23279 .38044 .21943 .39179 .21557 .38394 .2288 Mtetra
.259 0 .035 r
.38394 .2288 .39179 .21557 .40319 .21181 .39545 .22487 Mtetra
.259 0 .032 r
.39545 .22487 .40319 .21181 .41464 .20816 .40702 .22101 Mtetra
.259 0 .028 r
.40702 .22101 .41464 .20816 .42614 .20461 .41863 .21721 Mtetra
.257 0 .021 r
.41863 .21721 .42614 .20461 .43769 .20115 .4303 .21346 Mtetra
.255 0 .013 r
.4303 .21346 .43769 .20115 .44929 .19777 .44202 .20975 Mtetra
.25 0 .003 r
.44202 .20975 .44929 .19777 .46095 .19447 .45379 .20607 Mtetra
.244 0 0 r
.45379 .20607 .46095 .19447 .47267 .19123 .46562 .20241 Mtetra
.235 0 0 r
.46562 .20241 .47267 .19123 .48445 .18803 .47751 .19873 Mtetra
.224 0 0 r
.47751 .19873 .48445 .18803 .49628 .18488 .48946 .19504 Mtetra
.21 0 0 r
.48946 .19504 .49628 .18488 .50818 .18175 .50146 .19131 Mtetra
.191 0 0 r
.50146 .19131 .50818 .18175 .52014 .17863 .51352 .18752 Mtetra
.168 0 0 r
.51352 .18752 .52014 .17863 .53216 .17553 .52565 .18367 Mtetra
.14 0 0 r
.52565 .18367 .53216 .17553 .54424 .17243 .53783 .17974 Mtetra
.105 0 0 r
.53783 .17974 .54424 .17243 .55639 .16935 .55007 .17574 Mtetra
.062 0 0 r
.55007 .17574 .55639 .16935 .56861 .16629 .56236 .1717 Mtetra
.01 0 0 r
.56236 .1717 .56861 .16629 .58089 .16328 .57472 .16761 Mtetra
0 0 0 r
.57472 .16761 .58089 .16328 .59324 .16032 .58713 .16352 Mtetra
.58713 .16352 .59324 .16032 .60567 .15742 .59961 .15942 Mtetra
.59961 .15942 .60567 .15742 .61816 .15458 .61215 .15534 Mtetra
.313 .802 .784 r
.61215 .15534 .61816 .15458 .63073 .15178 .62474 .15125 Mtetra
.408 .859 .883 r
.62474 .15125 .63073 .15178 .64337 .14903 .6374 .14717 Mtetra
.491 .887 .952 r
.6374 .14717 .64337 .14903 .65608 .14629 .65013 .14308 Mtetra
.554 .886 .988 r
.65013 .14308 .65608 .14629 .66887 .14356 .66291 .13897 Mtetra
.595 .862 .993 r
.66291 .13897 .66887 .14356 .68174 .14082 .67576 .13484 Mtetra
.62 .825 .979 r
.67576 .13484 .68174 .14082 .69468 .13805 .68868 .13068 Mtetra
.632 .784 .954 r
.68868 .13068 .69468 .13805 .70769 .13525 .70165 .12647 Mtetra
.615 .741 .935 r
.01926 .36808 .02714 .37496 .03732 .3707 .02924 .36524 Mtetra
.609 .786 .966 r
.02924 .36524 .03732 .3707 .04753 .36641 .03926 .36235 Mtetra
.591 .831 .99 r
.03926 .36235 .04753 .36641 .05779 .36209 .04934 .35942 Mtetra
.557 .865 .996 r
.04934 .35942 .05779 .36209 .06809 .35775 .05947 .35644 Mtetra
.5 .879 .973 r
.05947 .35644 .06809 .35775 .07842 .3534 .06965 .35342 Mtetra
.42 .861 .911 r
.06965 .35342 .07842 .3534 .08879 .34904 .07988 .35036 Mtetra
.323 .81 .814 r
.07988 .35036 .08879 .34904 .09919 .34468 .09016 .34724 Mtetra
.224 .735 .697 r
.09016 .34724 .09919 .34468 .10964 .34034 .1005 .34409 Mtetra
0 0 0 r
.1005 .34409 .10964 .34034 .12011 .336 .11088 .34088 Mtetra
.11088 .34088 .12011 .336 .13063 .33166 .12132 .33763 Mtetra
.013 0 0 r
.12132 .33763 .13063 .33166 .14118 .32732 .1318 .33434 Mtetra
.066 0 0 r
.1318 .33434 .14118 .32732 .15178 .32295 .14234 .33099 Mtetra
.111 0 0 r
.14234 .33099 .15178 .32295 .16242 .31852 .15293 .32761 Mtetra
.149 0 0 r
.15293 .32761 .16242 .31852 .17311 .31404 .16357 .32417 Mtetra
.181 0 0 r
.16357 .32417 .17311 .31404 .18384 .30947 .17427 .32068 Mtetra
.21 0 0 r
.17427 .32068 .18384 .30947 .19462 .30485 .18501 .31715 Mtetra
.234 0 0 r
.18501 .31715 .19462 .30485 .20544 .30017 .19581 .31357 Mtetra
.255 0 .026 r
.19581 .31357 .20544 .30017 .2163 .29546 .20666 .30995 Mtetra
.273 0 .058 r
.20666 .30995 .2163 .29546 .22721 .29072 .21755 .30627 Mtetra
.288 0 .086 r
.21755 .30627 .22721 .29072 .23815 .28598 .22851 .30255 Mtetra
.3 0 .109 r
.22851 .30255 .23815 .28598 .24913 .28125 .23951 .29878 Mtetra
.311 0 .129 r
.23951 .29878 .24913 .28125 .26015 .27655 .25056 .29496 Mtetra
.319 0 .145 r
.25056 .29496 .26015 .27655 .27121 .27189 .26167 .29109 Mtetra
.326 0 .159 r
.26167 .29109 .27121 .27189 .2823 .26728 .27283 .28717 Mtetra
.332 0 .17 r
.27283 .28717 .2823 .26728 .29343 .26273 .28403 .2832 Mtetra
.336 0 .178 r
.28403 .2832 .29343 .26273 .3046 .25824 .29529 .27918 Mtetra
.339 0 .185 r
.29529 .27918 .3046 .25824 .31581 .25382 .30661 .27512 Mtetra
.341 0 .189 r
.30661 .27512 .31581 .25382 .32706 .24947 .31797 .271 Mtetra
.342 0 .192 r
.31797 .271 .32706 .24947 .33835 .2452 .32938 .26683 Mtetra
.342 0 .194 r
.32938 .26683 .33835 .2452 .34968 .24099 .34085 .26262 Mtetra
.341 0 .193 r
.34085 .26262 .34968 .24099 .36105 .23685 .35237 .25835 Mtetra
.34 0 .191 r
.35237 .25835 .36105 .23685 .37247 .23279 .36394 .25403 Mtetra
.337 0 .188 r
.36394 .25403 .37247 .23279 .38394 .2288 .37556 .24966 Mtetra
.333 0 .182 r
.37556 .24966 .38394 .2288 .39545 .22487 .38723 .24524 Mtetra
.328 0 .174 r
.38723 .24524 .39545 .22487 .40702 .22101 .39896 .24077 Mtetra
.321 0 .165 r
.39896 .24077 .40702 .22101 .41863 .21721 .41073 .23625 Mtetra
.313 0 .153 r
.41073 .23625 .41863 .21721 .4303 .21346 .42256 .23167 Mtetra
.304 0 .138 r
.42256 .23167 .4303 .21346 .44202 .20975 .43444 .22704 Mtetra
.292 0 .12 r
.43444 .22704 .44202 .20975 .45379 .20607 .44636 .22237 Mtetra
.278 0 .098 r
.44636 .22237 .45379 .20607 .46562 .20241 .45834 .21763 Mtetra
.261 0 .073 r
.45834 .21763 .46562 .20241 .47751 .19873 .47037 .21285 Mtetra
.241 0 .042 r
.47037 .21285 .47751 .19873 .48946 .19504 .48246 .20802 Mtetra
.218 0 .007 r
.48246 .20802 .48946 .19504 .50146 .19131 .49459 .20313 Mtetra
.19 0 0 r
.49459 .20313 .50146 .19131 .51352 .18752 .50677 .19819 Mtetra
.158 0 0 r
.50677 .19819 .51352 .18752 .52565 .18367 .51901 .19319 Mtetra
.121 0 0 r
.51901 .19319 .52565 .18367 .53783 .17974 .53129 .18814 Mtetra
.078 0 0 r
.53129 .18814 .53783 .17974 .55007 .17574 .54363 .18304 Mtetra
.028 0 0 r
.54363 .18304 .55007 .17574 .56236 .1717 .55601 .17789 Mtetra
0 0 0 r
.55601 .17789 .56236 .1717 .57472 .16761 .56845 .17268 Mtetra
.56845 .17268 .57472 .16761 .58713 .16352 .58094 .16742 Mtetra
.58094 .16742 .58713 .16352 .59961 .15942 .59347 .1621 Mtetra
.59347 .1621 .59961 .15942 .61215 .15534 .60606 .15673 Mtetra
.374 .834 .759 r
.60606 .15673 .61215 .15534 .62474 .15125 .6187 .15131 Mtetra
.475 .896 .86 r
.6187 .15131 .62474 .15125 .6374 .14717 .63138 .14583 Mtetra
.561 .927 .933 r
.63138 .14583 .6374 .14717 .65013 .14308 .64412 .14029 Mtetra
.625 .926 .972 r
.64412 .14029 .65013 .14308 .66291 .13897 .65691 .1347 Mtetra
.664 .899 .98 r
.65691 .1347 .66291 .13897 .67576 .13484 .66974 .12906 Mtetra
.683 .857 .965 r
.66974 .12906 .67576 .13484 .68868 .13068 .68263 .12336 Mtetra
.689 .811 .94 r
.68263 .12336 .68868 .13068 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Rooooo`;o/<o`00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`1Aooooo`00H?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B47ooooo`03o`000?oooooooooo01gooooo0ol00002ooooo`03o`000?oooooooooo05gooooo00?o
[]_gok3?l?n`co000_n`co000ol0003o/<o`ooooo`0Eooooo`03o`000?oooooooooo053ooooo001P
ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0001cooooo0_l0001Sooooo`Co[]_g0on`
co000ol0003oXLSdooooo`0Dooooo`03o`000?oooooo0000057ooooo001Pooooo`05o`000?oooooo
ooooooooool000002oooool01?m4A4CogMgMooooool0000Jooooo`?o0000Hoooool2ojWVnPGo[]_g
00?o/<o`oj78m?l000000_nQb?@Fooooo`03o`000?oooooooooo04oooooo001Pooooo`05o`000?oo
ooooooooooooool000002oooool01?oMgMgoEEEEooooool0000Hooooo`;o0000I?ooool5ojWVnP;o
[]_g0onNdoX00onQb?Co0000oj78m002oj78m1Kooooo00?o0000ooooooooool0C_ooool0063ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001Gooooo0ol00002ooooo`03
o`000?oooooooooo05oooooo0_nOkOP3ojWVnP;oV=cn1_nNdoX01?l0003oXLSdoi>omOnC_oDFoooo
o`03o`000?oooooooooo04kooooo001Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^
k^koA4A4o`00000Cooooo`;o0000IOooool3oio]n0;oSN;l1OnHg?h3oikCnP;oSlOj00?o0000oi>o
mOnC_oD00_nC_oDFooooo`03o`000?oooooooooo04gooooo001Pooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03Oooool00omgMgOo0000ooooo`0?ooooo`?o0000IOooool2oho]kP03oio]n?n=h_coSN;l
00?oSN;l0_nHg?h3ohW>oPCoSlOj00?o0000oi>omOnC_oD00onC_oDFooooo`03o`000?oooooooooo
04cooooo0022ooooo`;o0000IOooool3oho]kPCoON?c0_n=h_`3oh;Co`GoRLkn0_n?aoX00on5^OOo
0000ohNem004ohNem1Kooooo00?o0000ooooooooool0C?ooool007oooooo0ol00002ooooo`03o`00
0?oooooooooo05oooooo0_miiM`4ofSKhP;oON?c1?mgeod4oh;Co`;oRLkn0on2_OX2ohFim`03o`00
0?n5^OOoQkGd00CoQkGd5?ooool3o`0004gooooo001looooo`?o0000I?ooool2oeoE`P03oe3=b?mJ
dNSoF]7X00;oF]7X1?mYe_D2ogOGo@?oO<Cn1?mo`O`5oh:mnP04ohFimol0003oQKWgohFim`CoQkGd
5oooool00ol0003oooooooooo`1:ooooo`00N_ooool2o`0006Gooooo0_mOeL83odS9eP;oF]7X0omf
b_l5ogW7o`CoO<Cn1?mo`O`2oh:mnP;oPj__0_n2[>l00ol0003oPZc_oh:]l004oh:]l1Kooooo00?o
0000ooooooooool0B_ooool007Oooooo0ol0001Tooooo`;o00000om`coh5og;=o`CoM/[o0_miaol2
ohNWj@CoQJS/1?n4Z^d5oh>[k`04oh:/kol0003oPZc_oh:/k`GoPZg`5_ooool00ol0003ooooooooo
o`19ooooo`00MOooool2o`0000;ooooo00?o0000ooooooooool0G_ooool3o`0000?oK]7l1?m`coh2
og;=o`;oRj?U1?n9YNL5ohNWj@CoQJS/1?n4Z^d5oh>[k`04o`000?n2[>ooPZc_oh:/k`;oPZg`0_n5
Z^dGooooo`03o`000?oooooooooo04Sooooo001booooo`?o00001Oooool00ol0003oooooooooo`1H
ooooo`;o000000?o0P00o`000?l000000_m/d_/2ofkAo0;oSYoO1?n=XN85oh^Si@CoRJGW1On7YnT4
ohFXk0CoQ:[]0_n3Znl2ohRRi@04o`000?n7Y^WoQjKYohNVj@GoQJ[]5_ooool00ol0003ooooooooo
o`18ooooo`00L?ooool2o`0005oooooo0_l00002o`l00004o`800?l0003oTYcJoi:LfP?oT9gL1On>
Wml4ohfQhPGoRj?U1?n9YNL2ohNWj@;oSIOH1?n<Vmd4ohZNh@CoR:;U00?o0000ohNVjOn7Y^T00_n7
Y^T5ohFZkAKooooo00?o0000ooooooooool0Aoooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`00023ooooo0ol0001Mooooo`04o`<00?l0003o6P00oaX000?o3`00
0_l00004oi:LfP?oT9gL1On>Wml4ohfQhP;oRj?U0_n@T=04ohnDe0GoSIOH1?n<Vmd4ohZNh@?oR:;U
00?o0000ohRRiOn7Y^T00on7Y^T2ohFZk@;oSJ_Z5Oooool3o`0004Sooooo000hooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Nooooo`;o
00000oooool00ol0003oooooooooo`1Cooooo`05o`d00?l9003o2@00o`T00?l300000_lS0003oaX0
0004o`l00?l7003o1`00o`0000;oU9_H1?nBW=X4oi2Mg0;oSYoO0_nBR/P4oi6=c0GoT93@1?n?U=@4
ohfGf0GoS9_M1?n:W^42ohRRi@03o`000?n@W]goSjCS00?oSjCS1On=ZnXFooooo`03o`000?oooooo
oooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo02Wooooo000hooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP0Looooo`?o0000Eoooool01Ol?003o3@00o`d00?l=003o2@0000;o:`000olS00000olJ003o4`00
oa<00003o`L000CoU9_H1OnBW=X2oi2Mg003oi>8aOnBR/SoTX[800?oTX[81?nASL`4oi2@d0CoSiCD
1On=UmP2ohbKg@;oTYCA1?nAV=L2oi2Ng@03o`000?n@W]goT9kM00CoSjCS1On=ZnXFooooo`03o`00
0?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003o
ooooooooo`0Zooooo`00>?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^
k^h06?ooool3o`0005Kooooo1?l?00000ol=003o<000oc000004ob/00003ob<00?lN003o4`0000;o
4`0000?o1`00oiJKeonFVmL00_nFVmL4oiBKf0;oTYcJ0_nCQL84oi>8a@CoTX[81?nASL`4oi2@d0Go
SiCD0_n=UmP2oi>?c0GoTYCA1?nAV=L01?n@W]go0000oi2NgOn@W]d5ohnTh`;oSJ_Z0onH[nLFoooo
o`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000:oooool0
03Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo01Gooooo0ol0001D
ooooo`Ko3`0000?o=@00oc000?l`00000_l`0003ob/000?o7P0000Co4`00oiNKe_nGVmKoUi_F0_nF
VmL2oi>2_@CoTh>o1OnCQL83oi>8a@CoTX[81OnASL`4oi2@d0;oSiCD0_nDS<P5oi>?c0CoTYCA1?nA
V=L00on@W]go0000oi2Ng@02oi2Ng@;oSjCS0_nIY]l6oiR_iaGooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000;?ooool003Sooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo017ooooo0ol00003ooooo`03
o`000?oooooooooo04kooooo00?o3P00o`l00?l?00000_l?0002ocT000?o=@000ol`00000ol[003o
:000obP00003oah00003oiRKeOnGVmKoUi_F00;oU82k1OnCP[d4oi>3_`CoThG20onCR<D5oi::b0;o
THg<0_nFQKl4oiF8``GoU8c81?nCSl`4oi:Dd@GoTISG00Co0000oi2NgOnIWmSoVIoH1OnIY]l4oiR_
i`03ojBdi?oooooooooo01Cooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000_ooooo00CogMgMoeEEEOoooooo0000;?ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41004Oooool2o`0005?ooooo00Go3000o`h00?l>003o
3P00o`l00002oc`000?o>@000ole0003oc0000Co:00000Co7P00oiRKeOnHVmGoU7nj1OnDP;/4oi>2
_@CoTh>o1?nCQL84oi>8a@;oTX[80_nFP[`5oiJ5_`CoUHS31?nDS<P4oi>?c0GoTYCA0_nAV=L2oiZH
d@03o`000?nIWmSoVIoH00;oVIoH1OnIY]l00onH[nOoY;CTojBdi002ojBdi1Kooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;?ooool0
03Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03_oo
ool3o`00057ooooo0_l:0002o``00003o`h00?ln003o?P0000Co?0000_li00000ole003o=`01ocL0
0@04oc0000?o:0000_nDO[P3oiAo^PGoU82k1?nCP[d4oi>3_`GoThG20_nCR<D00onFOkWoUX:loiJ2
_003oiJ2_0CoUXFo1?nER<<4oiB<b0GoTho<0_nBU=42oiZCb`CoVYSA00?o0000oiVOf?nIWmP00onI
WmP2oiVVg`;oY:_L1_nT]>@Dooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?ok^k^odA4A?l00000;?ooool005Wooooo0ol0001@ooooo`06o`L00?l:003o2P00o`X00?l<003o
?`001?ln0003oc`00003ocT00?lm00[o=`0100?o=`010ol`00000olX003oU7fgoiAn^003oiAn^0Co
U7nj1?nDP;/5oi>2_@CoTh>o0_nCQL82oiEl]@?oUWni1OnFP[`4oiJ5_`CoUHS31OnDS<P2oi>?c0;o
VXk61OnJTl/3oiZHd@04o`000?nJV=7oVIoHoiVOf0;oXj;D1OnTZm`4ojBdi003ok2kh_oooooooooo
017ooooo00Co0000oooooooooooo00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?o
MgMgo`000?ooool0:oooool005Kooooo0ol00003ooooo`03o`000?oooooooooo04[ooooo0ol70000
0ol:003o@@03od400`03ocl000?o?P0000?o?000od804_m201800olm00X3ocL00@;o<0001?nDOKL5
oiAn^0?oU7nj1OnDP;/4oi>2_@;oTh>o0_nDNK84oiEl]@CoUWni1?nFP[`5oiJ5_`CoUHS30_nDS<P2
oiZ:`@GoVXk61?nJTl/3oiZHd@03o`000?nRVlkoXj;D00CoXj;D1OnTZm`00onT]>Co/;_Rok2khP02
ok2khQKooooo00?o0000ooooooooool0@?ooool005Cooooo0_l0001Aooooo`04o`@00?l7003o@@05
od401@Co@@030_lo0002och00003odL06Om201;o@P0B00;o@P0B0_lm00X4ocL00@;oUGff1OnDOKL4
oiAn^0?oU7nj1OnDP;/2oi>2_@;oU7N`1?nDNK85oiEl]@?oUWni1OnFP[`4oiJ5_`;oUHS30_nJQ[d5
oiZ:`@CoVXk61OnJTl/00onJV=7oXY_>o`000002oj:KcPCoXj;D1?nTZm`00on_/mco/;_Rok2khP03
ok2khQKooooo00?o0000ooooooooool0@?ooool0057ooooo0ol0001@ooooo`03o`400?l4003o@P07
00Co@@050om100<3ocl000?oA`0I0om20183ocd02P03ocL00OnEOKKoUGff00CoUGff1?nDOKL4oiAn
^0CoU7nj0onDP;/00onCM:goU7N`oiAg/002oiAg/0GoU7Vb1?nEO;D3oiIo^@GoUX:l0_nFQKl2oiZ4
^PGoVXJm1?nJR/45oiZ>aP;oVY?;0_nRULP2oj:KcP03o`000?nRVlkoXY_>00GoXj;D00?oY:_Lojnc
g?n_/m`00_n_/m`3ok2khP;o^LCR5_ooool00ol0003oooooooooo`0oooooo`00C_ooool5o`0004ko
oooo00?o0@00od802?m200P00om200L3od401@?o@@0300?o?`00odX07_m:01h00om701T3od804P;o
?@0:00?oUWbeoiEm]_nEOKH01_nEOKH4oiAm]`GoU7jh0onDOkX01?nDP;_oTgB]oi=d[OnCM:d5oiAg
/0CoU7Vb1?nEO;D4oiIo^@?oUX:l00?oVX6goiZ4^_nJQ;X00onJQ;X4oiZ6_@CoVX[11?nJS/H00onQ
T<?oXYG8oj:Eb003oj:Eb003oj:Kc_l0003oXY_>00;oXY_>0_nSX]@2ojj]ePKo[k?L00?o/;_RokW4
h_nia>800_nia>8Fooooo`03o`000?oooooooooo03kooooo001<ooooo`;o00001Oooool00ol0003o
ooooooooo`17ooooo`;o00001Om200P2od801`Co@@0500?o@@03odd08om:01h00om:01h3odL06@?o
@P0B1?nFO;D7oiEm]PGoU7fg1?nDO[P2oiAo^P03oi9bZonCM:goTgB]00?oTgB]1?nDMk04oiAi/PGo
UGbe0onFOkT01?nFP[coVX6goiZ1]onJPKL5oiZ4^PCoVXJm1OnJR/400onJS/KoXI33oj6@``02oj6@
``CoXYG800GoXY_>o`000?nRVlkoXY_>ojfWd@05ojj]ePCo[k?L00?o^L7PokW4h_nia>800_nia>80
0onmbNCoooooooooo`0Dooooo`03o`000?oooooooooo03kooooo0019ooooo`?o0000C_ooool4o`00
00Go@P080om200L00om100GoD00Woe009`03odd08`?oBP0N1?m701T00om201;oUWbdoiIl]004oiIl
]@SoUGff1?nDOKL2oiAn^0;oTW2X0onBLZ/5oi=d[@CoU7N`1?nDNK85oiEl]@;oUWni00?oVWjdoiZ1
]onJPKL00onJPKL4oiZ4^PGoVXJm0_nJR/42oj2<_PGoXI331OnRULP00onRVlko0000ojfWd@02ojfW
d@Go[ZgF00?o[k?LokW1h?ni`N000_ni`N02okW4hP?o_LWT5?ooool3o`0003oooooo000Rooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08?ooool2o`0004kooooo1?l00002od402@Go@P0800?o@P07oe80
:_mB02X01?m@02L2odd08`CoBP0N0_m701T00onGO;CoUWbdoiIl]002oiIl]0CoUWbe2?nEOKH2oiAm
]`;oTFjW1?nBL:P4oi9bZ`CoTgB]1?nDMk05oiAi/P?oUGbe00?oVWbaoiYn]?nJO[@00_nJO[@4oiZ1
]`GoVXBj0onJQ[d00onOR;[oX8bnoj2<_P03oj2<_PCoXI331?nRULP00on]X/co[JOAo`000003ojfW
d@Co[ZgF00?o^KkNokW1h?ni`N000oni`N000onia>;o_LWTokg9i003okg9i1Gooooo00?o0000oooo
ooooool0?Oooool002;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`?o00000_ooool00ol0
003oooooooooo`19ooooo`;o00001_m100T3od802003oe<0;?mB02[oDP0Z00;oDP0Z0om@02L3odd0
8`CoBP0N0onGO;@4oiIl]0GoUWbe1OnEOKH2oi5/Y@CoTFjW1OnBL:P3oi9bZ`CoTgB]1OnDMk04oiAi
/P04oiEl]OnJO;7oVWbaoiYl/@CoVWjd1?nJPKL5oiZ4^P03oiZ6_OnOR;[oWhRj00;oWhRj1?nPS;h5
oj6@``03oj:Eb?n]X/co[J;<00;o[J;<00?o0000ojfWdOn]Ym400_n]Ym400on^[MKo^KkNokVngP02
okVngP?o^L7P0_nnbn@4okg9i0;o_LkW5Oooool00ol0003oooooooooo`0looooo`008_ooool01Ol@
413ooooooooooooooooo410@01_ooooo0_l0001?ooooo`03o`000?m000Wo@@0900Ko@@090om200P2
oe<0;0?oDP0Z1?m@02L3odd08`04odX07_nGO;?oUgbcoiMl/`?oUgbd1OnFO;@4oiIl]@;oUGff00?o
TF^Toi5/YOnAK:D00_nAK:D5oi5^Y`CoTW2X0onBLZ/4oi=d[@GoU7N`0_nDNK82oiUj[`GoVWba1?nJ
O[@4oiZ1]`?oVXBj00?oWhFgoin8^_nOR;X00onOR;X4oj2<_PCoXI3300?o[9g8ojfRc?n]X/`00on]
X/`01Ol0003o[JOAojfWdOn]Ym7o^[gL00Go^KkN00?o^L7Pokk;i?nnbn@00onnbn@00onmbNCo_LkW
okg>i`03okg>iaGooooo00?o0000ooooooooool0>oooool002;ooooo00Go0000oooooooooooooooo
o`00000Hooooo`?o0000COooool2o`000004ocl02?m000Wo@009od002@Ko@@0900?o@P08oeD0;_mE
02h00omC02`3oe80:P?oD00W0_m=02<6oiMl/`CoUgbd1?nFO;@2oiIl]@;oTFZS0onAJj@5oi5/Y@Co
TFjW1?nBL:P3oi9bZ`GoTgB]0onDMk000onIN:goVGZ_oiUj[`02oiUj[`GoVWba1?nJO[@4oiZ1]`03
oiZ4^_nOQKOoWhFg00;oWhFg1?nOR;X5oj2<_P03oj6@`on/WLSo[9g800;o[9g81?n]X/`00ol0003o
[JOAokZmg003okZmg0?o^KkN0_nocNH4okk;i0;o_]G[1?nmc^L00ongcncoooooooooo`0Cooooo`03
o`000?oooooooooo03_ooooo000Rooooo`05o`000?ooooooooooooooool000005_ooool3o`0004co
oooo0ol00003ocl020;o@0091?m100T2oeH0<0CoE@0^0_mC02`4oe80:P?oD00W00?oV7bcoiMl/onG
O;<01_nGO;<3oiMl]0;oUWbd0_n@JJ84oi5ZX`CoTF^T1?nAK:D4oi5^Y`CoTW2X1?nBLZ/4oi=d[@04
oiAg/?nIN:goVGR]oiUh[@GoVGZ_1?nJO;44oiYn]0?oVX6g00?oWh>doin5]onOQKL00onOQKL5oin8
^P?oX8bn00?oZi[5ojbMb?n/WLP00on/WLP4ojfRc003o`000?nj_Mco^[gL00Co^[gL00?o^KkNoko=
i_nocNH00_nocNH00onnbnCo_]G[okkEj`03okkEj`03okg>iongcnco]lo/00;o]lo/5Oooool00ol0
003oooooooooo`0jooooo`008_ooool01Ol@413ooooooooooooooooo410@01?ooooo0ol00002oooo
o`03o`000?oooooooooo04Wooooo0_l000001?ln00So?`08ocl02?lo00P3od002@03od402OmG033o
EP0`00?oEP0`0omE02h3oe<0;0?oDP0Z0_m@02L3oiQl/`SoUgbc0_nGO;@00on@JJ7oT6VRoi1YXP02
oi1YXPCoTFZS1?nAJj@4oi5/Y@CoTFjW1?nBL:P4oi9bZ`;oTgB]0_nHMZ/5oiUh[@CoVGZ_1OnJO;44
oiYn]003oiZ1]onOPkCoWh>d00GoWhFg1OnOR;X00onPS;koZi[5oj^Ja@02oj^Ja@Co[9g80on]X/`0
0onj_M_o0000okZmf`04okZmg003okoAionocNKo_lgV00;o_lgV0_nngNl4okkEj`;o]m[b1?ngcn`F
ooooo`03o`000?oooooooooo03Wooooo000Rooooo`05ogMgMonHV9SooooooiRHV?mgMgL04?ooool3
o`0004kooooo0_l000001?ll00Ko?P08och02?ln00P2ocl020;o@00900CoE`0aoeL0<?mG033oE`0`
0omF0304oeD0;P?oD`0/0_mB02X2oiQl/PCoV7bc1onGO;<01?n@J:3oT6VQoi1YXOn@JJ44oi1YXPGo
TFZS0onAJj@4oi5/Y@CoTFjW1OnBL:P2oi9bZ`03oiMdZOnHMZ_oV7J[00;oV7J[1OnIN:d4oiUj[`Go
VWba0_nJO[@2oin1/`CoWh>d1OnOQKL3oin8^P03oj^G`_n[V/GoZi[500?oZi[51On/WLP01?n]X/co
^[gKokZmfol00002okZmf`03okZmg?nodNOo_m7W00;o_m7W00?o_lgVokkMkonngNl00onngNl00onn
eN_o]m[bokOJlP03okOJlP;o]lo/0_n]c_4Dooooo`;o0000>oooool002;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0>ooooo`;o0000C_ooool3o`0000?o?0060_ln00P3ocl020?oE`0a0omG0303oeH0
<0?oE@0^0omC02`00omB02[oV7bboiQl/P02oiQl/PGoV7bc1?nGO;<3oi1XX0?oT6VQ1On@JJ84oi5Z
X`?oTF^T1?nAK:D5oi5^Y`CoTW2X00?oTW:[oiMdZOnGM:T01OnHMZ/4oiUh[@GoVGZ_0onJO;400onO
P;7oWh6coin1/`02oin1/`CoWh>d1OnOQKL00onOR;[oZiO2oj^G`P02oj^G`PCoZi[51?n/WLP01onk
_M_o^[gKokZmfonj_M_o0000okZmfoo1eNT01?nodNL2okgUlPCo_]g_0_ndiOL4okOJlP03oj[Jn?n]
c_7o[Lka00?o[Lka5Oooool00ol0003oooooooooo`0hooooo`00<_ooool5o`0004gooooo0_l00000
1?lj00Go?006oc`01_ll00H3och02003ocl02?mG037oE`0a00;oE`0a0omG0303oeH0<0CoE@0^00?o
D`0/oiQl/_nHO;801_nHO;84oiQl/`;oUgbc00?oT6ROoi1XX?n@J:000_n@J:04oi1YX@CoT6VR1?nA
JZ<3oi5[Y0GoTFbU1?nAKZL2oi9`Z0;oUg:X1?nGM:T4oiQfZ`CoVGR]1OnINZl01?nJO;7oWh2aoin0
/OnOP;45oin1/`?oWh>d1?nOQKL00onZU<3oZiO2oj^G`P03oj^G`PGoZi[500?o[9g8ok^mfonk_M/0
0_nk_M/00onj_M_o0000o`000003ol7Ej@;o_m7W1?nmiO800onngNoo]>GgokCUm`03okCUm`03okOJ
l_nZf_SoZ][h00;oZ][h0on]c_400onPa_?oooooooooo`0Dooooo`03o`000?oooooooooo03Oooooo
000`ooooo`;o0000Coooool00ol0003o>@03ocT00`03ocX01@;o?00600?o?P08oeL0<OmG03401_mG
0343oeL0<0?oEP0`00?oE@0^oiUl/_nIO;800_nIO;88oiQl/P;oV7bc0_n@Iil3oi1XW`GoT6RP0on@
JJ44oi1YXPCoTFZS1?nAJj@4oi5/Y@?oTFjW00?oUW6VoiMbZ?nGLZP00_nGLZP4oiMdZ@CoV7J[1OnI
N:d3oiUj[`03oimo/OnOP;7oWh2a00?oWh2a1?nOPK<4oin3]0;oWhFg0onZU<04oj^G`PCoZi[500Co
_;kKok^mfonk_M_o^kgK0ol000000onj_M_o0000ol7Ej@02ol7Ej@03okoAionmiO;o_NGb00;o_NGb
0_n/k_P4okCUm`03oj;Uo?nZf_SoZ][h00?oZ][h00?o[Lkaoj36lonPa_<00_nPa_<Eooooo`03o`00
0?oooooooooo03Oooooo000]ooooo`?o0000C_ooool00ol0003o=`01ocT00`03ocT00`;o>P0500?o
?006oeL0<?mG03402?mG0344oeL0<003oeH0<?nIO;;oVGbb00GoVGbb1_nHO;86oi1WW`?oT6RO1On@
J:03oi1YX@CoT6VR1?nAJZ<4oi5[Y0CoTFbU00CoTFjWoiIaY_nFLJKoUW6V1OnGLZP3oiMdZ@CoV7J[
1OnIN:d01?nINZooWgnaoimo/OnOOk45oin0/@CoWh6c1?nOPk@00onOQKOoZYC0ojZD`002ojZD`0Go
ZiO200CoZi[5okbnfonl_]_o_;kK0ol00002ok^mf`;o`M_/00?o`MGYo`000?o1eNT00onikOD00onm
iO;o[>khojc^n003ojc^n003okCUmonRiOcoX^Gl00;oX^Gl0_nZf_P3oi_>n@GoX<Kc5Oooool00ol0
003oooooooooo`0fooooo`00;?ooool2o`0004oooooo00?o0000ocL00Olg00400oli00<2ocX01@?o
E`0`2OmG0343oeL0<003oeH0<?nIOK;oVGbb00OoVGbb0_nHO;800onAIiooT6NOoi1WW`06oi1WW`Co
T6RO1?n@J:03oi1YX@CoT6VR1OnAJZ<3oi5[Y0;oTFbU0_nFL:D5oiIaYPCoUg:X0onGM:T5oiQfZ`?o
VGR]00?oWgn`oimo/OnOOk400onOOk44oin0/@GoWh6c0_nOPk@00onYTkkoZYC0ojZD`003ojZD`0Co
ZiO200?o_L7Mokbnfol000000_l00002okbnf`03ok^mfoo1fnco`M_/00?o`M_/00Co`MGYo`000?ni
kOGo^Nge0onJl?42ojc^n0?oSNWf0_nRiO`4oi?EoPCoVlki0_nPa_<3oiJklAGooooo00?o0000oooo
ooooool0=Oooool002cooooo0ol0001;ooooo`03o`000?ld003o=00000;o=`010oli00<00olj00Go
EP0_oeL0<002oeL0<0[oE`0a00?oE`0`oiUm/_nIOK800_nIOK88oiUl/P03oiQl/_nAIiooTFNO00So
T6NO1?n@J9l4oi1XX0?oT6VQ1On@JJ84oi5ZX`;oTF^T00?oUFjToiI`YOnFL:D00_nFL:D5oiIaYPCo
Ug:X0onGM:T5oiQfZ`04oiUh[OnOOk3oWgn`oimo/0GoWgna1?nOP;45oin1/`04oin3]?nYTkkoZI>n
ojVC_PGoZYC00_n[Ul83o`0000Co_;kK0_o1h_04ol7Kk0;o/O?d00Co^Ngeo`000?nJl?7oV_3a0omX
g=d2ohgYmPCoQMWo0_nCeOh2ohnnmPGoTkgd1OnF^o4Dooooo`03o`000?oooooooooo03Gooooo000/
ooooo`04o`000?oooooo0000o`0004Oooooo00?o0000oc400?ld00000old00001?lg007o>@03ocT0
0omF02d3oeH0;`?oE`0`2?mG0343oiYm/PGoVGfb1OnIO;85oi5WW`SoT6NO1?n@J9l4oi1XX0?oT6VQ
1On@JJ84oi5ZX`03oi5[Y?nEKZCoUFjT00GoUW2U1?nFLJH4oiMbZ0CoUgBY0onHMZ/6oimo/0CoWgna
1OnOP;43oin1/`03ojRA__nYTkkoZI>n00;oZI>n1?nZU<03o`0000Co_L7M00?o_;kKol7Rl?o1h_00
0oo1h_001oo1fnco/O?dok7cm?naloCoNnKJocJi[Ol000000omDcN`4ofoFn@;oQMWo0on<_?H4ohnn
mPGoTkgd0_nF^o42oi:dkQ?ooooo00?o0000ooooool000002?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`06Oooool002cooooo0_l00002
ooooo`03o`000?oooooooooo04?ooooo00?o0000oc400?la00000old0002ocL00@?oEP0]0_mF02l3
oeL0<0OoE`0a1_nJOK84oiUm/P;oVGbb2OnAIil7oi1WW`CoT6RO1?n@J:04oi1YX@CoT6VR0_nAJZ<2
oiA]X`?oUFjT1OnFL:D4oiIaYPCoUg:X1?nGM:T00onHMZ_oWgn`oimo/006oimo/0CoWgna1OnOP;40
0onOPK?oZ96nojRA_P02ojRA_P?oZI>n00GoZYC0o`000?l0003o0000okk4g`05okg1g@;o_^[b1?o1
h_02oj3dk007ok7cm?lS[/Wo>;gIocRmfOn6ZNcoQk;bo`000003ohNblPCoR;We1On<_?H4ohnnmP;o
Tkgd0_nB/N`5oi:dkQGooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B406Oooool002_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0oooooo`;o000000?o;`00oc400?la00000old00000olg
007oE00[oeH0;@02oeH0;@?oEP0_0omG0305oeL0<@SoVWfb0_nIOK8=oi5WW`SoT6NO0on@J9l5oi1X
X0?oT6VQ0on@JJ800onDK:;oU6fSoiA]X`02oiA]X`CoUFjT1?nFL:D4oiIaYPGoUg:X0_nGM:T:oimo
/0GoWgna0onOP;400onXTKgoZ96nojRA_P03ojRA_P;oZI>n0_l000000onZU<3o_/COokk4g`02okk4
g`?o_L7M1?nnj_801?o1h_3oX?C/oj3dk?nPm>`3ohROhPCoQZW/00?oQk;bo`000?n7/_800_n7/_84
ohRim@;oS;cf0_nBZ>D4oi:]j@GoT[7/1?nB]>hEooooo`03o`000?oooooooooo00Gooooo00Go410@
oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool002_ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0kooooo`?o00000ol_00001?la003o=000oc@0
0?mC02P3oe@0:`?oEP0]0_mF02l4oeL0<003oeL0<OnKO[?oVgjc00;oVgjc1onJOK800onAJ9ooTFNO
oi5WW`0=oi5WW`SoT6NO0on@J9l5oi1XX0?oT6VQ00CoT6VRoiA/X_nDK:;oU6bR1?nDKJ<4oiE^Y0Co
UW2U1OnFLJH4oiMbZ003oiMdZOnOOk3oWgn`00WoWgn`1OnOOk400onOP;7oZ96mojRA_@02ojRA_@?o
Z96n0ol000000onYTkko_/OQokk4g`05okk4g`03okg1gOnnj_;o_^[b00;o_^[b0_n3jML3oh^De`Co
R9oR1?n6ZN`01?l0003oQk;boi>Kf?nCVmP4oi:Rg`GoTZSU1?nB[NT4oi:ak0;oT[C^0onG/>TEoooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9So
oooooiRHV?lQ8B406Oooool002_ooooo0ol00005ooooo`03o`000?oooooooooo03Wooooo0_l00000
1?l[003o;`00obl00?l_0002oc4000?oD`0X0_mD02/3oeH0;@?oEP0_0_mG0308oi]n/`GoVWfb0_nA
J9l?oi5WW`SoT6NO1?n@J9l4oi1XX0;oT6VQ00?oTfbRoiA/X_nDK:800_nDK:85oiA]X`?oUFjT1?nF
L:D5oiIaYP?oUg:X00?oWh2`oimo/?nOOk002onOOk03oimo/@03ojR@_OnXTKgoZ96m00?oZ96m0ol0
0002ojRA_P04ojVC__nnan7o_/OQokk7h@Co_/CO0onilO@01?nnj_;oPnWGoh?Yeon=Rl`4oh^De`;o
R9oR0_nFS/P4oiFDd003oi>Kf?l0003oTi_H00;oTi_H1?nBX]l5oi:Xi@;oTZgY00?oV:;LoiNYhonG
ZN<00onGZN<5oiN`jAGooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go0000oeEEEOl0003o410@olc<c00Iooooo`00:oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo03Kooooo00Co0000obP00?l[003o:`000ol_00000ola003oD@0Uoe<0:002
oe<0:0?oE00[0omF02d3oeH0;`?oW7nc1onKO[<2oiYm/PGoTFRO3onAIil8oi1WW`CoT6RO0on@J:00
1?nCJj7oTfbRoi=/X_nCK:85oiA/XPCoU6fS0onEKZ@5oiI`Y@CoUW6V00CoUg:Xoin0/?nOP;3oWh2`
3OnOOk000onOOk7oZ92mojR@_@02ojR@_@04ojRA_Ol0003o0000o`0000CoZ96n00?o_L[Tokk7hOnn
an400onnan400onna=oo^O7dokWam002okWam003oeW>/?n=RlcoSH_<00?oSH_<0_n;U=L00onHR<7o
UXk8oiJ>b003oiJ>b0CoUIC@00CoTi_Ho`000?nCVmSoTi_H1OnBX]l2oi:Xi@;oVIcE1?nHX]`5oiNY
h`;oUk3Y0_nO]>LEooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooooooooa0@400;
ooooo`03oeEEEOn7QhOooooo01_ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0<oooool01_l0003o:000obP00?lX003o:`00obl000;oC`0Q0omA02D3oe<0:0;oE00[1?mF
02d00omF02ooW82doiao/`03oiao/`KoVgjc00?oTVVOoi5XWonAJ9l01_nAJ9l>oi5WW`SoT6NO1?n@
J9l01?n@J:3oTf^Qoi=[XOnCJj43oi=/XPGoU6bR1?nDKJ<3oiE^Y0GoUW2U0onFLJH00onOP;7oWh2`
oin0/003oin0/0_oWgn`00CoYi6nojR@_OnXT;goZ92m0ol00004ojRA_@;oZ96n0onmb^@3okk7h@?o
[_K`00?o^O7doi23`_n@Pl800_n@Pl82ohf;c0;oVXBj1?nHR<44oiJ>b0GoUIC@00CoTi_Ho`000?nC
VmSoTi_H0_nBX]l2oiZFcPGoVIcE1?nHX]`2oiNYh`;oX:kQ1OnO]>LCooooo`?o00001?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P06oooool0013ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0`ooooo`03o`000?lT003o:00000;o:00000?oC00K
odl08Om?02400_m?0242oe409@?oD`0X0omD02/00omF02goWH6doif1]003oib0]0CoW7nc0onKO[<0
1?nBJJ3oTVVOoi9YWonBJIl8oi5XW`koTFNO2?n@Iil2oi1XW`;oTfZQ1?nCJj44oi=/XPCoU6bR1?nD
KJ<4oiE^Y0CoUW2U00CoUW6Voin0/OnOP;7oWh2a1OnOP;09oimo/0?oYi6n0ol00002ojR@_@GoZ96m
00?oZ96nokg:i?nmb^@00onmb^@00onnan7o[_K`ojkfl003oi9m^@;oT8?20_nKP;D5oiZ4^P?oV8S1
1?nFS/P4oiFDd003oif=`_nKTLSo000000;oVi781?nJU/h5oiVLe@;oV:;L0_nQYm/5oj2^h@GoWkCW
5Oooool02Ol0003oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co
0000oa0@41Wooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o
0000ooooooooool01?ooool3o`0000[ooooo00?o0000ooooooooool0;?ooool01?l0003o8000ob@0
0?lT0003obP000;oC00K0om?0243oe409@?oD`0X00?oE00[oij2]?nMPK@00onMPK@4oib0]0?oW7nc
00CoVgjcoi9YX?nBJJ3oTVVP0onBJIl8oi5XW`ooTFNO1_n@Iil00onBJZ7oTfZQoi=ZX@02oi=ZX@Go
Tf^Q0onCK:84oiA/XPCoU6fS1?nEKZ@3oiI`Y@KoWh2a1?nOP;07oimo/003ojNB_onWTKko000000;o
000000?oYi6nojR@_OnXT;d00onXT;d3ojRA_@;o_<gW1?nmb^@01?nJlnCoU7VcoiAi/onDNK<2oi9m
^@03oiam/OnKP;GoVh2e00?oVh2e1?nJQ;X3oiR8`@GoUXk800?oUIC@oif=`_nMSL800_nMSL801?nK
TLSo0000oi^Ab?nKTLP4oiZFcP?oVIcE00?oXZ;Eoj6WfonQYm/00onQYm/5oj2^h@;oWkCW0_nX^nLE
ooooo`03o`000?oooooooooo02oooooo0008ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol00005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:_ooool3
ob000004ob@00?lX003oB@0FodT05P;oC00K1?m?0242oe409@;oD`0X00CoWh>eoij2]?nNP[CoWX:d
1?nMPK@4oib0]0;oW7nc00?oTfZQoi9YX?nBJJ000_nBJJ04oi9YW`OoTFRO3onAIil3oi1WW`04oi9Y
X?nBJZ7oTVZQoi9ZX@CoTfZQ1OnCJj43oi=/XPCoU6bR1OnDKJ<3oiE^Y003oiI`YOnOP;7oWh2a00Ko
Wh2a1?nOP;06oimo/003ojNB_ol0003o000000CoYi6n1OnXT;d00onXTKgo_<gWokc=i`03okc=i`03
okg:i?nJlnCoV_?T00CoU7Vc00?oTWfioiam/OnLOK401OnKP;D4oiZ4^PCoV8S10_nFS/P2oij:_PGo
WHg20_nKTLP00ol0003oVi78oiZFcP03oiZFcP03oiVLeOnRX]GoXZ;E00;oXZ;E1OnQYm/2oj2^h@;o
ZKOS1OnX^nLEooooo`03o`000?oooooooooo02kooooo000@ooooo`05o`000?ooooooooooooooool0
00002oooool01?m4A4CogMgMooooool00006ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool09oooool01OlK003o8000ob000?lP003oA@0>00CoB@0F0_m<01/3odl08@?oD@0U0onOPkD3
oij2]0GoWH6d0_nLP;@01?nCJj;oTfZQoi=ZXOnCJZ44oi9YX0CoTVVO1onAJ9l?oi5WW`04oi1WWonB
JJ3oTVVPoi9YX0?oTVZQ1OnCJZ44oi=[X@?oTfbR1OnDK:84oiA]X`;oUFjT00?oWh6boin0/OnOP;40
1onOP;45oin0/0?oWgn`0ol00002ojNB_`GoYi6n0onXT;d2ok[?jPCo_<gW0_moilh2oiEf[P;oU7Vc
0_nMO:h4oiam/@CoVh2e1OnJQ;X2oiR8`@03oj69^_nNR[koWXZn00?oWXZn1?nMSL82oi^Ab003o`00
0?nKTLSoVi7800;oVYK>00?oXig?oj:ReOnRX]D00onRX]D4oj6Wf`03ojZcgonY]n?oZKOS00?oZKOS
0onX^nL2ojk0iaGooooo00?o0000ooooooooool0;Oooool0013ooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Tooooo`03o`000?lK003o800000;o80000_m500h3odT05P;oC00K1?m?02400omA02Go
WhBfoin3]@03oin3]@CoWX:d1?nMPK@00onLP;CoTf^Roi=[XP03oi=ZX@CoTVVP1?nBJIl7oi5XW`ko
TFNO1OnBJJ04oi9ZX@CoTfZQ1?nCJj43oi=/XPGoU6bR1?nDKJ<00onEKZCoWh6boin1/P09oin0/@Go
Wh2`0ol00002ojNC`0?oYi:o1OnWTKh00onXT;go^/oZok[?jP03ok[?jP03okc=iomoilkoOnO>00?o
UGJ^00?oWW^/oiel[_nMO:h00_nMO:h4oiam/@GoVh2e0onJQ;X00onSR;SoXHVjoj69^P02oj69^PCo
WXZn1OnMSL82oi^Ab003o`000?nUV/_oXig?00?oXig?1OnRX]D00onQYm_oZ[?OojZcg`02ojZcg`Co
ZKOS00?oZ;_Wojk0ion^`>L00on^`>LDooooo`03o`000?oooooooooo02gooooo000@ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`;o00003oooool2o`0002;o
oooo0_lE00001?lK003o8000od401_m100H2odD03P?oB@0F0om<01/00om?027oXHFgoj65]`03oin4
]PGoWh>e0onNP[@2oif1]0;oU6fS0onCJj84oi=ZX@?oTVVP1?nBJIl7oi5XW`[oTFNO0_nAJJ08oi9Y
X0?oTVZQ1?nCJZ44oi=[X@CoTfbR1?nDK:82oiA]X`KoWh6b2OnOP;401?nOP;3o0000o`000?l00005
ojNC`0CoYi:o0onWTKh2okS@k0Co^/oZ00GoG]6`oiMdZonGM:_oUgB[oiEf[P03oiik[0GoWGb^0onL
OK45oi^0]@03oiZ4^_nSR;SoXhRh00;oXhRh0onQRKX4oij:_PCoWHg200GoYYS7ojFJbonUV/_oYI[;
o`000005oj>Mc`;oXZ;E0_n//M`6ojZcg`;oZKOS0_n__^H4ojk0i`03ok34jOoooooooooo01?ooooo
00?o0000ooooooooool0;?ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^
k_m4A4Co000000Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Looooo`05o`h0
0?lE003o5@00oaD00?lk00001?m100H00om500koB@0FodT05P02odT05P03od`06onRQkSoXHFg00?o
XHFg0onOQ;H5oin3]@;oWX:d00?oUFjToiA]XonDKJ<00_nDKJ<4oi=[XP?oTfZQ1?nBJJ03oi9YW`So
TFRO1_nAIil5oi5YX0SoTVVP0onBJZ44oi=ZX@CoTf^Q1?nCK:83oiA/XP03oij1/_nOPK;oWh6b00Ko
Wh6b1onOP;43o`0000CoYiC21?nWTl04ojNB_`03ojNA__nhd>co^=3/00?o^=3/00Co^/oZoiQcZ?nH
LjSoV7>X0_nGM:/00onNNZ[oWW^/oiik[003oiik[0CoWGb^1?nLOK43oi^0]@03ojF9]onSR;SoXhRh
00?oXhRh0onQRKX5oij:_P03oif=`_nVV<OoYYS700;oYYS70onUV//01Ol0003oXig?oj>MconSWLoo
[[3J00Go[;7L1?nZ/ml00on__^Co[kkVojnniP03ojnniP03ojk0ion`a>Wo/<CY00;o/<CY4oooool2
o`0002kooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06_ooool2o`h000;o5@000_lk0003
od401P;oA@0>00?oB@0Foj>9^OnRQkP01?nRQkP3oj65]`CoWhBf0onOPkD01?nFL:GoUFjToiE^Y?nE
KZ@4oiA]X`CoTf^R0onCJZ44oi9YX0?oTVVO2?nAJ9l5oi5WW`KoTFVP2?nBJJ03oi9ZX@CoTfZQ1OnC
Jj43oi=/XP04oiA/X_nNPK;oWX6boij1/PSoWh6b1?nOP;43o`000003oin0/OnXU/CoYiC200CoYiC2
1OnWTl02ojNB_`;o]];^1?nhd>`5oiQcZ003oiMdZonNNZ[oWWZZ00GoWW^/1?nMO:h4oiam/@03oi^0
]OnURKOoYHVg00;oYHVg1?nSR;P4oj69^P?oWXZn00?oZ9O4ojJHaonVV<L00onVV<L3ojFJb`03o`00
0?nSWLoo[[3J00?o[[3J1On//M`00onZ/moo[kkTojnni002ojnni0?o[kkV0_naa^T4ok34jAGooooo
00?o0000ooooooooool0:oooool002Wooooo0_l0000Dooooo`03o`000?oooooooooo01Kooooo00Ko
ElbZo`D00?l>003o3P00oaD00?le0002oc/000?o@@0600?oA@0>ojnWcon^YLl00onSRKT4oj:7^0Co
XHFg0onOQ;H01?nOPkGoUW2UoiI`YOnFL:D3oiE^Y0CoU6fS1?nCJj83oi=ZX@CoTVVP1?nBJIl7oi5X
W`;oTFNO2OnAJJ08oi9YX0?oTVZQ1OnCJZ44oi=[X@;oTfbR00?oWX2coij1/_nNPK800onNPK88oin1
/P?o00000_nOP;44ojRFa0CoYiC21?nWTl02okCCl0Co]];^00Co^=3/oiUbY_nILZKoVG:V0onHLjP0
0onONJWoWWZZoiijZP02oiijZPCoWW^/1OnMO:h2oiam/@03ojN:]onURKOoYHVg00?oYHVg1OnSR;P3
oj69^P03oij:__nXUlCoZ9O400;oZ9O41?nVV<L3ojFJb`03ok2afOl0003o[[3J00Co[[3J0_n//M`2
ok6ni0Go[kkT00?o[kkVok76jOnaa^T00onaa^T2ok34j@;o/<GZ5Oooool00ol0003oooooooooo`0Z
ooooo`00:Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Cooooo00CoElbZo`D0
0?l>003o;P000ole00000olk003o@@06od401P02od401P03ojnWconTRk[oXhVi00?oXhVi1?nRQkP4
oj65]`;oWhBf00?oUg:VoiI`YOnFL:D00_nFL:D4oiE^Y0?oU6fS1?nCJj83oi=ZX@CoTVVP1?nBJIl5
oi5XW`goTFVP2?nBJJ03oi9ZX@GoTfZQ1?nCJj400onCK:;oWX2coij0/`05oij1/PKoWh6b0_l00002
oin0/@;oZ9S61OnXU/@5ojND`P03ojNC`?nddo3o]=?`00?o]=?`0_nfd^h00onILZGoVG:VoiUbYP02
oiUbYP04oiQcZ?nONJWoWgVYoimiZ@CoWWZZ1?nNNj`5oiel[P04oiam/OnWR[OoYhZgojN:]`CoYHVg
1OnSR;P2oj69^P03ojZH`onXUlCoZ9O400?oZ9O41OnVV<L01OnUV/_o/;7Iok2afOn`/MWo000000?o
[[3J00?o//3Tok6ni?na_^@00ona_^@2ojnni0?o//S[1?naa^T00on`b>co/<GZok35jP03ok35jQCo
oooo00?o0000ooooooooool0:_ooool002Wooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?l5003o1@0000?o;P000_le0002oc/00003od401_naZ=3o[jO?00CoY8^j
0onSRKT5oj:7^0;oXHFg00CoV7BXoiMbY_nGLZKoUg:V1?nFL:D4oiE^Y0CoU6fS0onCJj83oi=ZX@Co
TVVP1?nBJIl2oi5XW`03oi5YXOnAJJ3oTFVP00goTFVP2?nBJJ04oi9ZX@CoTfZQ0_nCJj42oif0/`Co
WX2c1?nNPK83oin1/P?o000000?oWh6bojRJb?nXV<H01?nXV<H4ojRFa0CoYiC20_nbeO84okCCl0Co
VG:U0onILZH6oimiZ@?oWWZZ1OnNNj`3oiel[P03ojV=]onWR[OoYhZg00;oYhZg1OnURKL3oj>8^003
ojbI`onZV<?oZYS300;oZYS31OnXUl@2ojJHa`;o/kCI1On`/MT00ol0003o//3Tok;0i002ok;0i0?o
/KkT0_nbbn`5ok;8j`03ok76jOn`b>co/<S/00;o/<S/0on`aNX2ojk5jaCooooo00?o0000oooooooo
ool0:Oooool002Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0=ooooo`?o0000
00?o1@00obH00?l^00000_l^0002ocD00005oc/00?nbZm3o/JS@ok6Xd?nUS[`01OnTRkX4oj>9^@Co
XXNh00?oXHFgoiQdZ?nHM:P01?nGLZH3oiI`Y@CoUFjT1?nDKJ<3oi=[XPCoTfZQ0onBJJ02oi9YW`Go
TFVQ4?nAJJ08oi9YX0?oTVZQ0onCJZ400onMOk?oWH2coif0/`02oif0/`CoWX2c1?nNPK83o`0000?o
Wh6b0onXV/P4ojRHaPGoZ9K400?oYiC2ok;El_nbeO800onbeO801?nddo3oVW:ToiYbY?nJLZ@3oiUb
Y@03oiUbY_nONJWoWgVY00KoWgVY0onNNZX5oiik[004oiel[_nYSKOoZHfgojV=]`CoYhZg1OnURKL0
0onSR;So[9W3ojbI``02ojbI``?oZYS31?nXUl@00one^=_o/kCIok>df@03ok>df@?o/;7I00?o]<?U
o`000?nb`>@01?nb`>@00ona_^Co//_/ok;;k002ok;;k0;o//S[0_n`bnd5ok38k003ok35j_n^aN_o
[/G[00?o[/G[5?ooool00ol0003oooooooooo`0Xooooo`00:Oooool3o`0001Oooooo00?o0000oooo
ooooool02oooool2o`000003oa`00?lV003o9P0000?o;P0000Go=@00ok:[d?nbZm3o/Z_@ojN@_P04
ojF>_0CoY8^j1?nSRKT2oj:7^0;oVGJZ0onHM:P4oiMbYPCoUW2U0onEKZ@4oiA]X`CoTf^R0onCJZ42
oi9YX0SoTFVQ4?nAJJ08oi9YX0?oTVZQ00CoTfZQoieo/onMOk?oWGnc1OnMP;<3oij0/`05oij1/_l0
003o0000o`000?nNPK800onOPK800onYW<[oZ9[8ojRJb002ojRJb0CoZ9S61?nXU/@2ok3Hm0Co/]Gb
1OnJLZ@2oiUbY@03oimjZOnONJWoWgVY00OoWgVY0onNNZX4oiik[003oj^@^OnYSKOoZHfg00?oZHfg
1?nWR[L3ojF9]`03ojjLa?n/VL?o[9W300?o[9W31?nZV<<00onXUlCo]KSKokFhf`02okFhf`Co/kCI
00?o/;7IokC3iOnd`nD00_nd`nD01Ol0003o//3Tok;0i?nb`>Co//o_00Co//_/0_n_c_04ok3;k@;o
/<S/0on]an`4ojk5j`03oj_3jooooooooooo017ooooo0_l0000Zooooo`00:Oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00Sooooo0_l00002oa`000;o9P0000?o;P00okB]dOnd[M40
0ond[M401?nbZm3oYi2nojN@__nWT;h3ojF>_0GoY8^j0_nSRKT00onJNJgoVGJZoiUfZP02oiUfZP?o
V7BX1?nGLZH4oiI`Y@?oUFjT1?nDKJ<4oi=[XP?oTfZQ00?oTVVPoi5YXOnAJJ402?nAJJ4?oi5YX0So
TVVP0_nBJZ400onLOk?oWGncoieo/`03oieo/`CoWH2c00CoWX2co`000?l0003o00001?nNPK800onO
PK;oZIc:ojVLbP02ojVLbP?oZ9[81OnXV<H00onXU/Co/=Sdok3Hm003ok3Hm003ok;El_nJLJ?oVW6S
00GoVW:T00?oVG:UoimjZOnONZT02OnONJT4oiijZP;oWW^/0_n[T;T5ojV=]`CoYhZg00?oYHVgojjL
a?n^W<@00_n^W<@4ojbI``?oZYS300?o]kkOokFhfone^=/00one^=/3ok>df@;o]LSX1Ond`nD00ol0
003o//o_ok;?k`02ok;?k`03ok;;k?n_c_3o[lk`00?o[lk`0_n`bnd2ojg9kPGo[LO/00?o[/G[oj_3
jon[`n/00_n[`n/Dooooo`03o`000?oooooooooo02Oooooo000>ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00005ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool01_ooool01Ol0003o7000oa`00?lL003o9P0000?o][3C1?nd[M400onYU<3oYi2nojN@_P02
ojN@_P?oYHjl1OnTRkX00onSRKWoVWV]oiYi[@04oiUfZP?oV7BX1?nGLZH4oiI`Y@CoUFjT0onDKJ<4
oi=[XP;oTfZQ00?oTFZRoi5YXOnAJJ402OnAJJ4?oi5YX0OoTVVP00CoVgncoiao/onLOk?oW7nc1OnM
Ok<2oif0/`?o00000onNP;<2oij1/P;oZIk<1OnYW<X4ojRJb0;oZ9S61?n^f_L2ok3Hm0KoVW6S0onJ
LZ@5oimjZ@SoWgVY1?nNNZX00onNNjcoZi2ioj^@^@02oj^@^@CoZHfg1?nWR[L5ojjLa0Go[9W300Co
ZYS3okNngong_]oo]kkO1One^=/00onc]=Wo]LSXokG8j002okG8j0;o]<?U0_nado401?l0003o/M?a
ok;?konbcnl2ojkAlPCo[lk`00?o[<_`ojg9k_n]bNh00on]bNh2ojg7k0;oZlG]1On[`n/Eooooo`03
o`000?oooooooooo02Kooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool00oooool2oa000004oa`00?nnj??o_^ScokRce0Go][3C00?o]:gAojVD`?nYU<000_nYU<03
ojN@_PCoYHjl0_nTRkX2oi]l[`CoVWV]0onIMZX4oiQdZ0?oUg:V1?nFL:D4oiE^Y0?oU6fS0_nCJj85
oi5ZXP_oTFVQ3onAJJ05oi9YX0?oVgnc1?nLOk<3oieo/`?o00000onMP;<2oij0/`03ojVPc_nYW/co
ZIk<00?oZIk<1?nYW<X3ojRJb0?o[=ki0on^f_L9oiYaX`;oVW:T1_nONZT9oimiZ@;oWWZZ00?o[I>l
oj^@^On[T;T00on[T;T5ojV=]`;oYhZg0_n`X<L4ojjLa0Co[9W300?o^LKTokNngong_]l00ong_]l2
okFhf`;o]Lk/1?neb>P2ojoGm@Co/M?a00?o0000ojkAl_n^dO800on^dO800on_c_3o[<_`ojc;l002
ojc;l0;o[LW^0on[a^h4oj_5k@;oZl?[0onY`^/Dooooo`03o`000?oooooooooo02Kooooo0006oooo
o`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool2
o`0001gooooo00Go0000ooooool3003o0`00oa000002ol3Ul@03okkXlonh/mCo^;?D00;o^;?D0onf
/=<00on[V<?oZIC0ojVD`003ojVD`0CoYi2n0_nUS[`00onMO[7oVgb_oi]l[`02oi]l[`CoVWV]1?nI
MZX3oiQdZ0CoUg:V0onFL:D4oiE^Y0;oU6fS00?oTF^Soi5ZX_nAJZ801OnAJZ8;oi5YX@ooTFVP0_nB
JJ02oiYn/`GoVgnc0onLOk<01?nMOk?o0000o`000?nMOk<5oif0/`04oij0/onYX<koZJ3>ojVPcPCo
ZIk<1OnYW<X00onXV/So[=kiojcNn@03ojcNn@03ojkJmonJLJ?oVW6S00SoVW6S00?oVW:ToimjZOnO
NZT01OnONZT9oimiZ@04oiijZ_n]Tkco[I>lojfC_0CoZi2i1OnYSKL01?nWR[Oo/:37ok2Paon`X<L5
ojjLa003ojbI`onia^Co^LKT00;o^LKT0ong_]l2okCEl@Co]Lk/00?o]LSXojoGmOn_eoD00on_eoD0
1Onado7o[=CeojcDmOn/e?Go000000;o[]7b0on[c?83ojc;l003oj[7kon[a^koZlK^00CoZlK^0_n[
aNd2ojW3k0GoZL;[5?ooool00ol0003oooooooooo`0Uooooo`003_ooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`0Looooo`03o`000?l3
003oVO;Y00?o`>Ga0_nj]]H5okRce004okJ`don[V<?oZiS3oj^H``CoZIC01?nWT;h00onUS[coWGja
oien/@04oi]l[`CoVWV]1?nIMZX3oiQdZ0CoUg:V0onFL:D2oiE^Y0;oTFbT0onAJj<8oi5ZXP[oTFVQ
3_nAJJ05oiYn/`GoVgnc00CoW7nco`000?l0003o00001?nMOk<3oif0/`03ojVRconYX<koZJ3>00;o
ZJ3>1OnYW/`2ojVLbPCoZN;j0_n/g_T<oiYaX`03oimjZ_nONZWoWgZY00KoWgZY2?nONJT00on_V<3o
[I>lojfC_002ojfC_0GoZi2i0onYSKL00onbYLco/:37ok2Pa`02ok2Pa`Co[Yc400?o^LoZokW6i?ni
a^@00onia^@00ong_]oo]=GaokCEl@03okCEl@;o]Lk/0on/foP2ojoGm@;oZMOg1?n/e?D00onYc_?o
0000oj_<lP04oj_<lP04ojc;l?nZanooZ/O_oj[7k`CoZlK^00?oZL?]ojW3k?nY`n`00onY`n`2ojW2
j`;oZ<7[5Oooool00ol0003oooooooooo`0Tooooo`003_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`0Jooooo`?oY_Ca0oo1h^l00oo0
iO7o^[KFokZfeP02okZfeP?o^;?D00?o[Ic5oj^H`on[V<<00_n[V<<5ojVD`0;oYi2n00?oWX:doien
/OnMO[400_nMO[43oi]l[`CoVWV]1?nIMZX3oiQdZ0CoUg:V0_nFL:D00onBKJGoTFbToi5/Y002oi5/
Y0?oTF^S2?nAJZ8:oi5YX@goTFVP1onJO[<2oi]o/`?o00000onLOk<4oieo/`03oif0/onYX/ooZJ;?
00;oZJ;?0onYX<h4ojVNc0?oYNKk0_nYh_X2oiUaY0coVW6S0onONZX8oimjZ@KoWgVY1?n_V<03ojfC
_0GoZi2i00CoZHfgok:Uc?nbYLco/ZG<1On`X<L00on^W<Co^LoZokW?jP02okW?jP?o^LKT0_n`gOL4
okCEl@03ojONn_n/foSo[=_h00;o[=_h0_nVfOT4ojWGm`06ojcDmOnYc_?oZLkcojW>lol0003oZLkc
0_n[c?82ojW8l0GoZ/O_00?oZlK^ojW3kOnY`nd00_nY`nd2ojW3k0?oZ<7/1?nX`N/Cooooo`;o0000
2?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`02Oooool000kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo
00?ooooo0_l0000Hooooo`;oK=gB0_nVm?44ol7Rk`03okbieonj]]Ko^[KF00Co^[KF00Co^;?DojfL
aOn]W<Go[Ic50on[V<<4ojVD`004oj25]onNP[CoWX:doij2]0CoWGja1?nKO:l3oiYi[@CoVGJZ0onH
M:P2oiMbYP;oTVjV0onBKJD4oi5/Y0CoTF^S1onAJZ8;oi5YX@WoTFVP0_nIOK<7oiYn/`?o00000_nK
Ok<4oiao/`;oWGnc0_nXXm45ojVRc`CoZJ3>00?oZIk<ojGVnonUi_/00_nUi_/5oiUaY0[oVW6S00?o
Wg^[oimjZ_nONZX00onONZX8oimjZ@?oWgVY00?o/9g4ojnH`?n_V<000on_V<04ojfC_0?oZi2i00?o
/jcAok:Uc?nbYL`00onbYL`3ok2Pa`;o]mSa1OnicnX00onia^Co/=ggok3Mm`02ok3Mm`03okCElOnW
g_[oYmkj00;oYmkj00?o[=_hojKInOnVfOT00onVfOT2ojWGm`?oYlkd0_nYc_<00onXbO7o0000ojW8
l004ojW8l0;oZ/O_0onXa>d3ojW3k@03ojS2k?nX`NcoZ<7/00CoZ<7/0_nX`N/2ojS0jaCooooo00?o
0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q
8OnHV9SooooooiRHV?lQ8B402Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001?ooool2o`0001Kooooo0_li_;800om/gM;o/?7fok3amP04ol;N
k@04ol7Rkonl^MOo_;WGokbie`Co^[KF00?o/:38ojfLaOn]W<D00_n]W<D4oj^H``04ojVD`?nPQKOo
X8Fgoj25]`CoWX:d0onMO[44oi]l[`CoVWV]0onIMZX2oiQdZ003oi9`Z?nBKZKoTVjV00;oTVjV1?nB
KJD3oi5/Y0CoTF^S1onAJZ8;oi5YX@KoTFVP00?oV7fcoiUm/onIOK<00_nIOK<4oiYn/`?o000000?o
VWjcoi]o/onKOk<00onKOk<2oiao/`03ojRTd_nXXm7oZ:?A00?oZ:?A1OnYX/l2ojVPcP?oX>Wk00?o
YNKkoiUaY?nILJ@01OnILJ@9oiYaX`;oWg^[1OnONZX8oimjZ@;oWgVY0on`WL@4ojnH`0Co[I>l00?o
Zi2iok>/dOnc[=400_nc[=44ok:Uc003ok2Paongf?7o]mSa00?o]mSa0_nicnX3ojWSnP;o/=gg1?nR
h?`2ojONnP?oXm[k0_nVfOT2ojG>m@CoYlkd0_nWbO43ojS9l@03o`000?nYb?3oZLS`00?oZ<C^1OnX
a>d01?nY`ngoZ<;/ojS2k?nX`^`4ojS1k003ojS1jonX`>_oZ<3[00?oZ<3[5?ooool00ol0003ooooo
ooooo`04ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo0000
00Wooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo00?o0000ooooooooool04_ooool2oe;?d0;oPnWW0on`lOH4ol;Nk@03okflf?nl^MOo
_;WG00?o_;WG00?o^[KFok2Pb?n`X<P00_n`X<P3ojfLa@?oZiS300?oXXVjoj25]onPQKL00onPQKL3
oij2]0?oWGja1?nKO:l4oiYi[@;oVGJZ00CoTg6Yoi9`Z?nBL:SoTW2X1?nBKZH4oi9]Y@?oTFbT1?nA
Jj<7oi5ZXP_oTFVQ0_nAJJ02oiQl/`?oV7fc1OnIOK<3o`0000GoVWjc1?nKOk<01?nLOk?oZ:CBojRT
d_nXY=84ojRSd@CoZJ;?0onHjoT2oj3Yn`;oV76T2?nILJ@5oiYaX`;oWgb/1?nONj/4oimjZPSoWgZY
00?oWgVYok2Ma?n`WL@00_n`WL@5ojnH`0;o[I>l00?o]KGIok>/dOnc[=400onc[=43ok:Uc0?o/N7g
0_ngf?44oioWn`;oZN?j0onKhOd2oj;Po0?oWm[l0_nSf_/3ojC>mPCoYLke00?oYlkdojO9lOnWbO40
0onWbO42ojS9l@03ojO4k_l0003oZ<C^00CoZ<C^0_nXa>d7ojS2k003ojS1k?nX`N_oZ<7[00;oZ<7[
1?nX`>/Dooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05
oc8b<_nHV9SooooooiRHV?lb<S802Oooool002Oooooo00?o0000ooooooooool03_ooool3of_Lj@?o
UNge0onfk?H3ol;Jj`03ol;NkOnm_=So_KcH00;o_KcH0onl^ML00onbYL_o/:38ok2Pb003ok2Pb0Co
[Ic500CoZiS3oj:9^_nRRK[oXXVj1?nPQKL3oij2]0CoWGja0onKO:l2oiYi[@;oU7>[0onCLJT4oi9`
Z0?oTVjV1?nBKJD4oi5/Y0?oTF^S2?nAJZ89oi5YX@03oiMl]?nHO;?oV7bc00;oV7bc1?nHOK<01?nI
OK?o0000o`000?l00008oiYn/`;oVgnc0_nWYM<4ojRTdPGoZ:?A00CoZJ;?oiS[nOnHjoWoV>_i0_nH
L:@4oiQaY0SoVG6T0_nJLJ<00onOOJgoWgb/oiml[002oiml[0CoWg^[1?nONZX7oimjZ@03ok:Tb_n`
WLCo/9g400?o/9g41On_V<001?n]Tkco]KGIokFefOne]MT5ok>/d@04ok:Uc?nahOOo/N7gok7Qm`?o
T^Si0_nOio/3oiOPoP;oVn7m1?nMfO`2oioJo0;oXlgf1OnTc_H2ojG>m@?oY/Sb0_nWbO45ojO4kP04
o`000?nWa>koZ<C^ojS4kP;oYl;]1onX`^`2ojS1k0GoZ<7[1OnX`>/Dooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`02Ooo
ool002Oooooo0_l0000<ooooo`?oOn7i1?nRjO/00onEkOGo]^cfokK/mP04ol;Jj`;o_kkI1Onm_=P0
1?nl^MOo/ZG;ok:UbonbYL/5ok2Pb0;o[Ic500?oY8fmoj:9^_nRRKX00_nRRKX4oj25]`CoWX:d0onM
O[42oi]l[`03oiAe[OnDLj_oU7>[00;oU7>[1?nCLJT3oi9`Z0?oTVjV1?nBKJD4oi5/Y0?oTF^S2?nA
JZ85oi5YX@;oUW^d0onGO;@5oiQl/`;oV7fc0_l00003oiUm/`OoVWjc00?oYZGDojNUdonWYM<00onW
YM<4ojRTdP;oZ:?A0on?jo@2oiM`Y@?oV72T1?nHLJ@8oiUaY003oiYaXonOOJgoWgf]00GoWgb/0onO
Nj/4oimjZPKoWgZY0onbY<X5ok2Ma0;o[iS00_ne_n45okFef@;o/jcA0onWj?X01?nahOOoT^Sioi;X
nOnBj?T4oi?OoP;oUn3n0onKfOd2oigIo0;oXlce1OnScOH2ojC>mP;oYLSa1?nVb?800onV`nkoYlC^
ojO4kP05ojO4kP03ojO2kOl0003oYl;]00CoYl;]0_nX`^`3ojO1k0CoZ<7/0_nX`N/3ojO0j`CoZ<3[
5Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o
^[Zjoooooonj^[[o410@00Wooooo000Wooooo`03o`000?oooooooooo00Sooooo1?n>gOh00omohOWo
X^Wkoj;Yn`02oj;Yn`;o^NCd1?o2eNP00oo2f^_o_kkIoknnf@02oknnf@?o_KcH00?o]JW=ok:Ubonb
YL/00_nbYL/4ok2Pb003ojJB`?nTSKgoY8fm00;oY8fm0onRRKX5oj25]`?oWX:d0_nMO[401?nFN:oo
U7F]oiAe[OnDMJd4oiAcZ`CoTg6Y0onBL:P4oi9^YP?oTVfU1?nAK:@4oi5[X`OoTFZR0_nAJJ400onE
NkCoUW^doiIk]002oiIk]0CoUgbd0onHO;<3o`000003oiQm/onIOK?oVGfc00?oVGfc1?nJO[<4ojJU
e0CoYjGC0onXY=83ohGXk`03oho[m?nGL:GoUg2U00;oUg2U0onHL:@4oiQaY0OoVG6T00?oWWf_oimm
[OnOOJd00_nOOJd4oiml[0?oWg^[1OnONZX3oimjZ@03ok>[d?nbY<[o/ZC:00;o/ZC:1?n`WL@00ond
b^[o]KoQokFoh@03okFoh@?o]KGI0onJj_X2ojOXnP;oQNKe0onAg_h2oi?OoP;oVmOl1?nKfOd2oj?;
m@CoXlce0_nScOH3ojG7l@CoYLSa00?oY/SbojK3k_nV`nh00_nV`nh3ojO4kPGoYl;]00Co0000ojO2
kOnW`^goYl;]1onW`N`2ojS1k0OoYl3[0_nX`>/2ojO0ja;ooooo0ol00004ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Wooooo000Wooooo`03o`000?oo
oooooooo00Gooooo1?nGe?d2ohkMoP?oZN7j0onjg?400onii?Co`]GXol;Ej003ol;Ej0Ko_kkI00Co
_KcHokFYcOneZLgo]JW=1?nbYL/00on`X<SoYY;0ojJB`002ojJB`0?oY8fm1?nRRKX4oj25]`;oWX:d
00CoUgZboiIh[onFN:ooUWR_1?nDMJd3oiAcZ`CoTg6Y0onBL:P4oi9^YPCoTVfU0onAK:@4oi5[X`Go
TFZR0_nDN[@3oiEk]0GoUW^d0onGO;@3o`000003oiQl/onHOK?oV7fc00;oV7fc1?nIOK<2oiYn/`03
ojFUeOnVYMCoYZGD00?oYZGD1OnWYM<01?nXY=;oQNS_ohGXkon5j>l2oiI_Y@CoUg2U0onHL:@5oiQa
Y0CoVG6T0onNOJl4oimm[@CoWgb/1?nONj/4oimjZP03oimjZOncZm3o/j_@00;o/j_@1?nbY<X00on`
WLCo]<[ZokC:jP02okC:jPCo]KoQ00Co]KGIoi[Zn_nJj_[oV^[j0_mih_03oi7MoP;oTMkn0onLe_`4
oi_Go003oi_IoOnSboGoXl_e00?oXl_e0_nSc?D2ojG6l@GoYLOa0_nUb?47ojK3kP03ojO4k_nW`^go
Yl;]00CoYl;]00?o0000ojO1k?nW`N`01_nW`N`@ojO0jaCooooo00Wo0000ooooooooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Wooooo000Vooooo`?o
00000oooool3oi_9m`;oUmCm1?n]eoH00onYhO[o^]caok[Ll@02ok[Ll@?o`M7V0oo2eNP2ol30fPCo
_kkI00?o]jk@okFYcOneZLd00oneZLd2ok:Ub`03ojVG`onVT/3oYY;000?oYY;00onTSKd4oj:9^P;o
X8Fg0_nHOK@3oiMj/PCoUWR_0onDMJd4oiAcZ`?oTg6Y0onBL:P4oi9^YPCoTVfU0onAK:@4oi5[X`;o
TFZR00?oTgZdoiAj]?nDN[@00_nDN[@4oiEk]0CoUW^d0ol00005oiQl/`?oV7fc0_nIOK<2ojBTePCo
YJGE1OnVYM@2ojNUd`;oO>GY0onEKjD3oiI_Y@CoUg2U1?nHL:@4oiQaY0;oVG6T00?oWWj`oiim[onN
OJl00onNOJl3oimm[@CoWgb/1?nONj/2oimjZP;o/k;G1OncZm03ok:TbP;o/MKc1Ondb^X2okFoh@03
oh[Xm?m`g^_oL=k[00CoTMcn0_nAgOh2oigDn`GoW=Kl0_nKeo`3oj?:m0;oXl_e0_nUaO05ojG6l@;o
YLOa2OnV`nh2ojO1k0KoYl;]0_nW`N`01?l0003oYl7/ojO1k?nW`N`DojO0jaGooooo00?o0000oooo
ooooool07_ooool002Kooooo00?o0000oooooonM_Nl00_nM_Nl3oi_9m`?o[Lc`0on]eoH4ok[Ck@03
ok[LlOo1dNKo`M7V00?o`M7V00?o`]GXol30f_o0`=X00_o0`=X00ono_]Wo]jk@okN^d002okN^d0?o
]JW=00?o[9c6ojVG`onYUl<00_nYUl<4ojJB`0CoY8fm0_nRRKX00onJPKOoV7fdoiQm]002oiQm]0Co
UgZb0onFN:l3oiAe[@CoU7>[0onCLJT4oi9`Z0?oTVjV1?nBKJD3oi5/Y0;oTF^S0_nCNK<3oi=j]0Go
U7Zd0onENk@01?nFNkCo0000o`000?l00004oiMl]0CoV7bc0_nHOK<00onRXmKoY:CFojBTeP03ojBT
ePCoYJGE0_nVYM@3og?Rh`;oU6jU1?nEKjD3oiI_Y@CoUg2U1?nHL:@4oiQaY003oiUaY?nNO[3oWWj`
00GoWWf_0onOOJd5oiml[0;oWg^[00?o/k[Nok>beonc/]L00onc/]L5ok>[d003ok:Tb_nae_?o/MKc
00;o/MKc0_ndb^X2og[Sk@;oJ]_X0_nCfoh4oi7LoP03oikBn_nMe?_oWMCk00?oWMCk0_nLe_`3oj?8
l`;oXl[d0onUa>l4ojG5l0;oYLKa0onV`^d6ojK3kPOoYl7/0_nW`^d6ojO1k003o`000?nW`>_oYl3[
01GoYl3[5?ooool00ol0003oooooooooo`0Nooooo`006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Kooooo00?o0000oooooonM_Nl00onM_Nl00onKbOOo[Lc`ojg<l003ojg<l003ojgGm_njdngo^]?]
00;o^]?]0_o1c><4ol7AiP;o`<7J0oo0`=X2okZbdPGo]jk@00Co]JW=ojbLa_n/W<Ko[9c60onYUl<5
ojJB`0;oY8fm00CoW8FioiZ1]onJPKOoVX6g1?nHOK@4oiMj/P?oUWR_0onDMJd4oiAcZ`CoTg6Y0onB
L:P3oi9^YP;oTVfU0_nAN;<3oi9h/`CoTgVc1?nCN[@4oiAj]004oiEk]?l0003o0000o`0000CoUW^d
0onGO;@2oiQl/`;oXJ;F1?nRXmH4ojBTeP?oYJGE0_m^g^03oi=]Y@?oU6jU1?nEKjD3oiI_Y@GoUg2U
0onHL:@2oiQaY0;oWGja1?nNO[04oiim[`?oWgf]1OnOO:`01?nONj_o/k[Nok>jg_nc^]h5ok>be`;o
/j_@0on[h?T2ok7Fl`;oK=gU0_mXf^P2oiKJoPGoTm_n00?oTMcnoikBn_nNd_X00_nNd_X2oigDn`?o
Y<Ob0onSb?<2ojK3k`GoYLC_0_nUaO07ojK2k@;oY/?^2OnW`N`2ojO0k0KoYl7/0_nW`>/00ol0003o
Yl3[ojO0j`0EojO0jaCooooo00?o0000ooooooooool07Oooool001_ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo00;oWKg_0on]`NT3ojg<l0?o^L_X00?o^]?]ol7<hoo1
c><00oo1c><00oo1dNKo`<7Jol31fP03ol31fP03ol30f_nj/];o^[;B00;o^[;B0ong[]000on_X/[o
[9c6ojbLaP02ojbLaP?oZIO31OnVT/000onTSKgoW8Fioib5^@04oiZ1]`CoV7fd0onGN[83oiIh[`?o
U7F]1?nDLj/4oi=aZ@?oTW2X0_nBKZH00onAMk;oTGRcoi5h/`02oi5h/`?oTWRc1OnCNK<3oi=j]0;o
U7Zd0ol00003oiEk]0CoUW^d0_nGO;@00onOX=GoXJ;Foj6ReP03oj6ReP?oXZ?F1OnTY=H00onUYMGo
TVbToi9/Y004oi=]Y@?oU6jU1?nEKjD4oiI_Y@CoUg2U0_nHL:@00onMOk;oWGjaoien/@02oien/@Co
WWj`1?nNOJl4oimm[@?oWgb/00?o/l?Vok>jg_nc^]h00onc^]h2ok>be`CoXNOl0_n[h?T2of7HgP04
ofSJjOnHf?goV=SmoiSHo@CoU][n0_nCfoh4oio@n@;oW];j0_nTa_45ojC7lP03oj?8lonV`nooY/?_
00;oY/?_0_nUa>l2ojO1k@OoY/;]2OnW`N`7ojO0k0;oYl7/1OnW`>/00ol0003oYl3[ojO0j`0FojO0
ja?ooooo0_l0000Nooooo`006oooool01Ol@413ooooooooooooooooo410@00Kooooo0_l00002oooo
o`Go[L7Y00Co[Lc`okW;j?nibnSo^L_X0onob>43ol7<h`?o`L;K0oo0`MX00onl]mGo^[;BokZbdP04
okZbdP04okN^d?n_X/[o[j;:ojnRbP?o[9c61?nYUl<2ojJB`0;oWXVm1?nLQKT3oiZ1]`CoV7fd0onG
N[84oiIh[`?oU7F]0onDLj/2oi=aZ@GoT7Jb0onAMk85oi5h/`?oTWRc1?nCNK<2oi=j]0?o00000onD
N[@3oiEk]0;oUW^d0_nNW]@4oinPe@CoXJ;F1?nRXmH2ojBTeP03of[MgonAK:CoTVbT00;oTVbT1?nC
KJD3oiA^Y@GoUFnU0onFKjD4oiM`Y@03oiQ`Y?nMOk;oWGnb00GoWGja0onNO[05oiim[`?oWgf]00?o
Wgb/ok?3i_nc`nH00_nc`nH3ok>jgP?oTnWi0_nQio`2oe[Df@;oJm_[0_nJeod5oiSHo@;oU][n0onP
coP2oio@n@;oYLKa1OnTa_42ojC7lP;oY/?^1?nV`nl00onW`NcoYl7]ojO1k@03ojO1k@;oY/;]0onW
`>`6ojO1k0WoYl3/2_nW`>/00ol0003oYl3[ojO0j`0EojO0ja;ooooo00?o0000ooooool000007_oo
ool001_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo0_n]
`NT4okS3h`03okW;j?nob>7o_lSQ00?o_lSQ00?o`LcSol72foo1`]/00oo1`]/01?o0`M[o_;OEokbg
eOnl]mD4okZbdP03ok:Wc_n_X/[o[j;:00;o[j;:1?n/W<H2ojVG``03oj6>`?nNRKgoWXVm00?oWXVm
0onLQKT3oiZ1]`CoV7fd1?nGN[83oiIh[`?oU7F]0_nDLj/00on@M[7oT7Jboi1f/P05oi1f/PCoTGNb
1?nAN;<3oi9h/`CoTgVc0_l00002oi=j]0CoU7Zd0_nENk@00onLW=?oWYkDoijNe003oijNe0?oWj3E
1OnQX]H2oj:SeP;oJ]gQ0onAK:@3oi9/Y0CoTffU1?nDKZD4oiE_Y@?oUVnU0_nGL:D2oiao/PCoWGnb
1?nMO[43oiin/0GoWWf_0_nOOJd2ok7:k0Go/l?V00Go/k[Noi?YnOnCjOWoTnWioeOAe`04ofoMkP03
of_KjonJeogoV]Om00;oV]Om0_nHf?d4oj;=mP;oX<oh0_nUaO04ojG6l@;oY<Ka0onV`^d4ojK3kP03
ojK3konW`NcoYl7/00;oYl7/0onW`Nd7ojO0k0;oYl7/0_nW`>/7ojO0k0koYl3[00?o0000ojO0jonW
`>/05OnW`>/Dooooo`03o`000?oooooooooo01_ooooo000Kooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`03ooooo`Go^<?S0_nna=h3oko8h@;o`L?K1?o1`]/00onn^mOo
_;OEokbge@03okbge@03okZbd_nbYlko/ZO>00;o/ZO>0on_X/X3ojbLaP03ojBCa?nQS/3oXHk000;o
XHk01?nNRKd3oib5^@CoVX6g0onHOK@4oiMj/P;oUWR_1?n@M[83oi1f/@SoT7Jb0onAMk84oi5h/`?o
TWRc00GoTgVco`000?l0003o0000oi=i/`03oi=j]0;oU7Zd0_nKV]44oibLd`CoWYkD1?nOX=D2oj6R
eP;oKMkU0on@Jj@4oi5/Y0?oTVbT1OnCKJD3oiA^Y@CoUFnU0_nFKjD00onKO[?oW7nboiao/P02oiao
/PCoWGnb1?nMO[44oiin/0?oWWf_0_n_dO84ok7:k0;o/l?V0_n4io42oeGAeP?oLmk`0_m_gNh4oicF
o0;oV]Om0onSc?D2oj;=mP;oY/C_1OnUaO02ojG6l@OoY/;]0_nV`nh7ojO1k003ojO1kOnW`>coYl3/
00GoYl3/1_nW`>/2ojO0k1;oYl3[00?o0000ojO0jonW`>/05OnW`>/Eooooo`03o`000?oooooooooo
01[ooooo000Kooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`05oooo
o`?o^<?S1?nna=h00onob>7o`L?Kol73f`02ol73f`03ol72fonn^mOo_[_G00;o_[_G0onl]mD00one
[];o/ZO>ok:WcP03ok:WcPCo[j;:00Co[9c6ojBCa?nTTlCoY9?40onQS/04oij9_@CoW8Fi0onJPKL2
oiQm]003oi9i]?nAMk?oTGNc00;oTGNc1_n@M[84oi1f/@OoT7Jb0onAMk84oi5h/`04oi9h/ol0003o
0000o`0000CoTgVc0_nCN[@00onJUm3oVi[Aoi^Jd@03oi^Jd@?oW9cC1OnNW]@2oinPe@;oL]o/0on?
JZ@4oi1[Y0?oTFbT1?nBK:@4oi=]Y@?oU6jU0_nEKjD2oiYn/`?oVgjc1?nLOk84oieo/PGoWGja0onN
O[000onNOJoo[m7bojoAlP03ojoAlP;o/L[/0_mdh^L00omFdMKoN>3cogSPl`02ogSPl`;oLmk`0onM
e?/2oicFo0?oXl[d0_nSc?D7ojK4k`;oYLG`0onW`Nd6ojK2k@WoYl7/0_nW`>/6ojO0k1goYl3[00?o
0000ojO0jonW`>/05OnW`>/Dooooo`03o`000?oooooooooo01[ooooo000Kooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2o`0000Oooooo00?o^<?Sokk4g_nna=h00_nna=h00oo2a=co`L?Kol73
f`03ol73f`03oko0f_nn^mOo_[_G00?o_[_G00Co_;OEokF^d_ne[];o]JkB1OnbYlh2ojnRbP03ojNI
b?nTTlCoY9?400;oY9?40onQS/05oij9_@?oW8Fi0_nJPKL01?nCNkKoTWVdoi9i]?nBNK@4oi5g/`Oo
T7Jb0on@M[47oi1f/PCoTGNb00CoTGRco`000?l0003o00000onBN;<2oi=i/`;oVIC>1?nJUm04oi^J
d@CoW9cC0_nNW]@3ogWQlP?oSfVT0on?JZ@4oi1[Y0CoTFbT0onBK:@4oi=]Y@;oU6jU00?oVGfcoiYn
/onJO[<00_nJO[<4oi]n/`CoW7nb0onMOk85oien/@;oWWj`0_n/e_H4ojoAlP03ofKKg?mHd]OoF=;G
00?oO>7e0_mhh?<4oioCnP;oWMCk0_nTbO<3oj?:m0;oY/?^1onVa>l2ojO1k0GoYl7]0_nV`^d9ojO1
k0KoYl3[0_nW`>`QojO0j`03o`000?nW`>_oYl3[01GoYl3[5?ooool00ol0003oooooooooo`0Ioooo
o`006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool01oooool3okk4
gP?o`/CL0oo1`m/3oko0fP?o_[_G00?o^;GFokF^d_ne[]800_ne[]84ok:WcP03ojZPcOnWVLSoYiW8
00;oYiW80onTTl@4oj6>`0CoWXVm0_nLQKT01?nEOkWoTg^foi=k]_nCNkH4oi9i]0?oTGNc1on@M[83
oi1f/@SoT7Jb00CoTGNbo`000?l0003o00000onAN;<2oi9h/`03oiRBc?nIU<koVIC>00?oVIC>0onJ
Um05oi^Jd@;oW9cC0on0hOP00omihO;oSVVTohiYY003ohmYY0?oSfZT1?n@Jj@4oi5/Y0?oTVbT0_nC
KJD2oiQl/P?oVGfc1?nJO[<4oi]n/`CoW7nb1?nMOk83oien/@;oZ=[i1?n/e_H00on_dO;oFmCIoh7R
m`03oh7Rm`;oO>7e0onPdoT2oioCnP;oYLSb1OnTbO<00onSb_CoY/?^ojK3kP02ojK3kP;oY/C_1onW
`N`2ojO1k@;oYl3/1onW`N`^ojO0j`03o`000?nW`>_oYl3[01CoYl3[5?ooool00ol0003ooooooooo
o`0Iooooo`009Oooool00ol0003oooooooooo`08ooooo`03okk4g_o2a=co`/CL00?o`/CL00?o`L?K
oko0f_no`=X00ono`=X01?nn^mOo^;GFokRee_nh]MH4okF^dP03ok:Wc_nZX<goZZ3=00;oZZ3=0onW
VLP4ojBCa0;oXHk000?oVHNooiN3_?nGPk`00_nGPk`4oiEo^@?oTg^f0onBNK@4oi5g/`KoT7Jb1?n@
M[45oi1f/P?o000000?oTGNboiJ=b?nGSlX00onGSlX4oiRBc0CoVIC>1?nJUm02oi^Jd@CoQ^3l0_n0
hOP4ohiYY0?oSfVT1?n?JZ@3oi1[Y0CoTFbT0_nBK:@00onGN[7oV7bboiQl/P02oiQl/PCoVGfc1?nJ
O[<3oi]n/`CoW7nb1?nMOk800onMO[7oZ=[iojSJn@03ojSJn@;o[=Kf0on4hoP2oh7Rm`CoXM;i0_nP
doT6ojG8lP;oY<Wc1_nV`nh9ojO1k0KoYl3/0_nW`N`bojO0j`03o`000?nW`>_oYl3[01GoYl3[4_oo
ool00ol0003oooooo`00000Jooooo`009Oooool00ol0003oooooooooo`0:ooooo`?o`/CL0_o1a=`4
oko0fP03ok^lf_nh]MKo^;GF00?o^;GF0_ne[]82ojfXdPCoZZ3=1?nWVLP2ojBCa003oi^=a?nIQkoo
VHNo00;oVHNo0onGPk`4oiEo^@?oTg^f0onBNK@4oi5g/`OoT7Jb0on@M[42oi1f/P?o000000?oT7Jb
oiF;a_nFSLP00onFSLP4oiN?bP?oV9;<1OnIU<h2oiZGd0?oS=gn0_n6h?`00on?JZCoSVVTohiYY005
ohiYY0CoSfVT0on?JZ@3oi1[Y0;oTFbT0_nEN;43oiMj/@GoV7bb0onIOK<4oiYn/`CoVgjc0onLOk82
oieo/PCoY=gk0_nXf_T01?mBc/WoQnCiohOTnOn7i?T2ohCSn0?oX]7h0_nQd_T2ojK7l@OoYLSb0_nW
`nh6ojK3kPOoYl7/2?nW`>`fojO0j`03o`000?nW`>_oYl3[01GoYl3[5?ooool00ol0003ooooooooo
o`0Gooooo`009Oooool2o`0000cooooo00?o`/CLol74g?o1a=`00_o1a=`00ono`=[o^kcJok^lfP02
ok^lfP?o^;GF00?o/;3GojfXd_n]Z=800on]Z=84ojZPc@;oYiW800?oWY?8oi^=a?nKSL@00_nKSL@3
oiV7_`?oUh>l1?nEOkT3oi=k]P?oTWVd1?nAMk<7oi1f/P;oT7Ja00?oThK3o`000?l000000_nDR<@4
oiF;aP?oUXg81?nGSlX4oiRBc0;oVIC>1?n@f_l2ohcMoP03ohm[YOn?JZCoSfZT00;oSfZT1_n>JJ@4
ohmYY0?oSfZT0_n@Jj@00onDMk3oUGRaoiEh/@02oiEh/@CoUgZa1?nHO;83oiUm/`CoVWjc1?nKO[<2
oiao/P?oXMol0_nTgO/2odc:``04of7HgOn7i?WoQnCiohOTn@CoXm7h0_nRdOP6ojK7l@;oYLSb0onW
`^d4ojO3kP;oY/?^0onW`>`5ojO1k0KoYl3/>onW`>/00ol0003oYl3[ojO0j`0EojO0ja?ooooo00?o
0000ooooooooool05oooool002Cooooo00?o0000ooooooooool03Oooool3ol74g0?o_LCO1?nk_=X0
1?nh]MKo/;3Gok2`eon`/=L5ojfXdP;oZZ3=00?oXI_>oijCb?nNTlP00_nNTlP3oi^=a0?oVHNo1?nG
Pk`4oiEo^@?oTg^f0onBNK@3oi5g/`KoT7Jb00GoTXG2o`000?l0003o0000oi>6``04oiB8a0?oUH_6
0onFSLP5oiN?bP;oV9;<0onCeoh2oi3Jo`;oTFfV0on?JjD4ohmZY0KoSVVT1?n?JJ@2ohmZY004oi9e
[_nDMk3oU7N`oiAg/0GoUGRa0onGN[44oiQl/PCoVGfc0onJO[<2oi]n/`CoW]om0_nQgo`2odW8_`;o
I=[N0_n:i?X2ojCAm`CoXm7h0_nVa_06ojK7l@OoYl;]0_nW`nh7ojO0k0;oYl7/0_nW`>/3ojO0k3oo
Yl3[00?o0000ojO0jonW`>/05?nW`>/Dooooo`03o`000?oooooooooo01Kooooo000Tooooo`03o`00
0?oooooooooo00kooooo00?o`LCLokg4gonma=l00onma=l2ok^lfP03ok>igOn`/=Oo/;3G00?o/;3G
0_n]Z=82ojBSe0CoXI_>0onNTlP3oi^=a0CoVHNo0onGPk`4oiEo^@?oTg^f0onBNK@2oi5g/`03oi64
`_nAQ<7oTHC100;oTHC10ol000001?nBQL;oThK3oi>6`onCQ/<4oiB8a0?oUH_61?nFSLP2oiN?bPCo
U=?m0_nCeoh2oi=`Z0?oTFfV0on?JjD4ohmZY0GoSVVT00?oT76/oi5c[OnALjd00_nALjd3oi9e[PCo
U7N`1?nEN;43oiMj/@CoV7bb1?nIOK<2oiYn/`?oWMkm0_nNgod2odS7_@;oIm_O0_n<iOX7ojCAm`03
oj?An?nVa_3oY/K`00?oY/K`0_nVao48ojO2k@?oYl3[1_nW`>`7ojO0j`03ojO0k?nW`>_oYl3[03ko
Yl3[00?o0000ojO0jonW`>/05OnW`>/Dooooo`03o`000?oooooooooo01Gooooo000Tooooo`?o0000
3oooool4okg4g`03okK3i?nc^Mgo/kWM00;o/kWM0on`/=L00onV[=_oY:?DojBSe003ojBSe0?oXI_>
0onNTlP4oi^=a0?oVHNo0onGPk`2oiEo^@;oT8K50on@QL<3oi24`PCoTHC20ol000001?nAQ<7oTXG2
oi:5`_nBQL83oi>6``CoU8S41?nERlH2oiJ=b0CoUM3l0_nDdod2oiIdZ`?oTg2X0onAKJH2ohm[Y@03
ohe^Z_n>Kj_oSVn[00;oSVn[0on?L:/3oi1a[0CoTG>]1?nBMJh3oiAg/0CoUGRa0onGN[45oiQl/P;o
VGfc0onLgOd2oigNo@;oB<Nm0_mZgN02ohkVnP;oYM7g1onTdOL5ojK6l0WoYl;]1onW`>/2ojO0k4co
Yl3[00?o0000ojO0jonW`>/05OnW`>/Booooo`;o00002Oooool4o`000003oa0@4?oooooooooo00Oo
oooo000Tooooo`03o`000?oooooooooo013ooooo00?o_LCOokK3i?nf`n@00_nf`n@4ok>ig@04ok2`
eonV[=_oYZcKojJ/f`CoY:?D0onQVlh4oijCb0?oVhg40_nIQkl01?nAS<_oT8W8oi29b?n@RLP5oi26
a@?oT8G30on@Q<83o`0000CoTHC10onBQL84oi>6``CoU8S40_nERlH3oiG=n`;oUM3l00?oVGV^ohma
[On>Kj/00on>Kj/9ohe^ZPCoSVn[0on?L:/4oi1a[0?oTG>]1?nBMJh3oiAg/0CoUGRa1?nGN[44oiQl
/P04oiUm/onLgOgoW=gmoicMo@;oBlW00_m/g^02ohoVnPKoYM7g0_nTdOL4ojO6l0;oY/K`2?nW`^eJ
ojO0j`03o`000?nW`>_oYl3[01GoYl3[4oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Wooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006
ooooo`03o`000?oooooooooo01;ooooo1?nf`n@2ok>ig@03ojVfh_nV[=_oYZcK00?oYZcK1?nTXm@3
oj6KcP;oWY?800CoU9KCoi:AconBTLooTY7?1?nAS</3oi29b0CoT8K50on@QL<3o`0000?oTHC21?nA
Q<44oi:5`P;oThK30onBaoT4oiC:nP;oULgk0_nBM:l3ohma[@CoSVn[2_n=KZX3ohi_Z`CoSg2[0on@
LJ`4oi5c[@?oTWF^0onDMk05oiEh/@?oUgZa0_nHO;84oicKo@03oicMoOm^gn3oSnOi00?oSnOi00?o
SnKjojGAmonUdOL01?nUdOL6ojO6l0SoYl;]GOnW`>/00ol0003oYl3[ojO0j`0EojO0jaCooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`002Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooo
ooooo`0Cooooo`;o]/?T0_nZ`NX3ojVfhPGoYZcK0_nTXm@01?nHXmgoUYcHoiJLf?nFW=P4oiBFd`?o
TY7?0onAS</3oi29b0CoT8K50ol00003oi24`PCoTHC21?nAQ<42oi:5`P;oT<Ci1OnBaoT2oiC:nP;o
U7Vb0onBM:l4ohma[@?oSVn[2_n=KZX3ohi_Z`CoSg2[0on@LJ`4oi5c[@?oTWF^1?nDMk04oiEh/@;o
UgZa0onLeo`2oicKo@04ofoOh?n@j?WoT>Sioi3Xn@;oSnOi1?nVd_L2ojGAm`OoYlK`1onW`^eQojO0
j`03o`000?nW`>_oYl3[01GoYl3[4oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Wooooo0009ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP06oooo
o`03o`000?oooooooooo01Gooooo1?nZ`NX3ojVfhP;oYZcK0_nIZn<4oiRSg@?oUYcH0onDU]<3oi:A
c`?oTHc;0on@RLP2oi26a@;o000000CoT8K5oi25`on@QL?oT8G30on@Q<82oi64`P?oRKcg0on<`?P4
oi34n@;oT/Oi0onIOkD4oiAi/P?oTWB_0on?LJd3ohi_Z`[oSFjZ1?n>Kj/3ohm`Z`?oT76/1?nALjd4
oi9e[P?oU7N`0_nEN;44oigBnP;oW=Ol00CoEM3:ohoXn?n?j?SoSnSh0_n@j?T5ojKBm`;oYlO`1onW
a_06ojO2kFGoYl3[00?o0000ojO0jonW`>/05OnW`>/Cooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02Oooool000Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Gooooo0ol0000Fooooo`;oZ/7Z0_nJ_?04oiZcj@?oVJ_S0onHXmd4oiJLf0?oU9KC0onB
TLl3oi6<b`05oi29b?l0003o0000o`000?n@Q/D00_n2[_44oh>bl`?oQ[Of1On9_?L3ohc0n0;oT<Ci
0onMQ[X4oiUo]@?oU7Vb0onBM:l3ohma[@CoSVn[2On=KZX4ohi_Z`?oSg2[1?n@LJ`3oi5c[@CoTWF^
0_nDMk03oig<n0;oWM;j0_mMeM801?m`h=ooSnShohoXn?n?j?P4ojKCm`;oY];g1_nWao02ojO6l0So
Yl;]J?nW`>/00ol0003oYl3[ojO0j`0EojO0ja7ooooo0ol00007ooooo`03o`000?oooooooooo00Wo
oooo0009ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`04ooooo`03
o`000?oooooooooo01Sooooo0onJ_?04oiZcj@?oVJ_S0onHXmd2oiJLf004ohJZk?n5Z>coQJS/ohFX
k0?oPjO/00GoPZS]o`000?l0003o0000oh:Xk@03oh6[k`?oPZka1?n3/_<3ohJgmP;oRKcg0_nl]=80
0onXUlCoXhjooj>>_`02oj>>_`?oWHJj1?nIOkD3oiAi/P?oTWB_0on?LJd4ohi_Z`WoSFjZ1?n>Kj/4
ohm`Z`?oT76/0_nALjd2oi^kkPGoW<Cc0_nMc?P2ofKJg0;oLN3O0_n?jOL3ojODn0;oY]?g0onXb?06
ojO7l0WoYl;]J_nW`>/00ol0003oYl3[ojO0j`0EojO0j`kooooo1?l000000ooooooo0000ooooo`06
ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo0onJ_?02oiZcj@03ohZclOn9/>oo
RK3_00;oRK3_0on8[>d3ohJZk0?oQJS/0ol00005oh:Xk@?oPJ__0on2[_42oh>bl`;o?KoN1?no_]T0
1?nl]=;oZ9O4ojRGa?nXUl@3oj>>_`CoWHJj0onIOkD3oiAi/P?oTWB_0on?LJd4ohi_Z`[oSFjZ0on>
Kj/4ohm`Z`;oT76/0_nI/NP4oi^kkP;oW<Cc0om`gnH2og7QgP;oS^We0_nWe_P3ojODn0;oZ<Sa1OnX
b?02ojO7l0SoYl;]KonW`>/00ol0003oYl3[ojO0j`0EojO0j`[ooooo0ol00005ooooo`03o`000?oo
oooooooo00?ooooo00?oEEEEofIVI_l000002oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool2o`0001_ooooo0on:]o@3ohZcl@CoRK3_
0on8[>d2ohJZk0?o000000CoQJS/oh>Wk?n3YncoPjO/0_n2Z>d4ofS4oP?oG/Ok0_m?a_03ol76gP?o
_kkI00?o[Z3:ojRGa?nXUl@00_nXUl@3oj>>_`CoWHJj1?nIOkD3oiAi/P?oTWB_0on?LJd3ohi_Z`[o
SFjZ0on>Kj/2ohm`Z`?oUjOQ1?nI/NP2oi^kkP?oNn?`00CoL^7NohgZlon=j_?oSN[c0_nWf?P4ojOF
n003ojODn?nXb?7oZ<Sa00;oZ<Sa0_nXb?09ojO2kG?oYl3[00?o0000ojO0jonW`>/05?nW`>/6oooo
o`Co00002?ooool00ol0003oooooooooo`0Aooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo01_ooooo0on:]o@3
ohZcl@;oRK3_0_mn]_L01?ml]oWo0000o`000?l00002ogVinPGoMKcl0om_`?h2ofS4oP;o?L7F00Co
]^ofol3:h_o0b^;o`<[R1?o1a]h01?no_]Wo[Z3:ojjPb_n^X<X3ojRGa0CoXhjo0onMQ[X4oiUo]@?o
U7Vb0onBM:l3ohma[@?oSVn[1_n=KZX01?n?SLcoTYCCoi:DdonBU=<4oiBMfPGoUjOQ0_nI/NP3ohGS
n@05og_Sl?n;j_;oRn[boh_Zl_n=j_<01OnWf?P2ojOFn0?oZ<Wa0_nXb?42ojS3k@OoYl;]M_nW`>/0
0ol0003oYl3[ojO0j`0EojO0j`;ooooo0ol0000<ooooo`03o`000?oooooooooo017ooooo000Roooo
o`03o`000?oooooooooo01gooooo0on3]?D3oh6emP04ogjfmol0003o0000o`0000?oO;Oi0omi^OX2
ogFlo0CoHLci0_mBb^d00omdh^3o]^ofokK_mP05ol3:hP;o`LKN00?o/ZW?ojjPb_n^X<X00_n^X<X4
ojRGa0?oXhjo0_nMQ[X00onBO[[oSgbjohml^P02ohml^P?oS7Zj0on;Nk`3oh]m_P?oS8721?n=Q/L4
ohn=c0?oTYCC1?nDWMX2oiNWh@CoS^3m0_n5hoT01?mch]ooRn[boh_Zl_n;j_83ojOIn@;oYmSh1?nX
bo82ojS9l@KoZ<?]0_nW`^ekojO0j`03o`000?nW`>_oYl3[01GoYl3[00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0Nooooo`?oPkCe00?oPKGf
o`000?l000000_mn]_L3ogc0o0CoMLGo0_m]b_h2og7Hn@?oRNOf0_neioL2oko<i0Co`<[R00?o][3D
ok:YconbZLl00_nbZLl4ojjPbP;oZ9O400CoVXRnoiJ2_?nFP[coUX:l1?nBO[X3ohml^PCoS7Zj0on;
Nk`3oh]m_P?oS8720on=Q/L4ohn=c0CoTYCC0_nDWMX4oiCIoP;oS^3m0_meh^42ohWZl0?oYm_j0_nW
fOT3ojW<lP;oZ<_b2OnX`neoojO0j`03o`000?nW`>_oYl3[01GoYl3[4?ooool00ol0003ooooooooo
o`0@ooooo`008_ooool2o`00023ooooo0ol000000on5]OCoPK[ioh6jn@02oh6jn@?oO<3l0_meaOl2
ogoCo`CoU^7n00?oRNOfokGWmoneioL01?noc>@00oo0b^;o][3DokJ`e002okJ`e0Co/ZW?0_n^X<X0
0onOS/;oVXRnoiZ8_P02oiZ8_P?oUX:l0onBO[X3ohml^PCoS7Zj0on;Nk`3oh]m_P?oS8721?n=Q/L4
ohn=c0;oTYCC0onHc_/2oiCIoP;oMn?T0_n8jNh4ojOMnP;oYm_j0_nYc_<3ojW<lP;oZ<C^1onX`nf3
ojO0j`03o`000?nW`>_oYl3[01CoYl3[4?ooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0
003oooooooooo`0Looooo`?o000000?oooooohFem?n5]O@00_n5]O@2oh6jn@?oSL;i0_n8c?h3oicF
o0;oU^7n0oncg_H2okc<iP?o_lcT00?o^;OHokJ`e?nf/=@00onf/=@3ok:Yc`03ojBFa_nOS/;oWhk2
00;oWhk20onJR;h3oiJ2_0?oTWjj1?n?O;X3ohaj^P?oRg^l0on;OKh3ohb1`PCoSHK70_n?SL`3oiS1
m0?oV<kk0_mji>P2ohKYkP?oYmoj0_nWgOX3ojW?m0CoZLkc00?oZLcbojS4k_nXa>h00_nXa>h2ojS3
k@?oZ<7[Q?nW`>/00ol0003oYl3[ojO0j`0EojO0j`oooooo00?o0000ooooooooool04?ooool002;o
oooo00?o0000ooooooooool06Oooool3o`0000Kooooo1?nA^O82ohg2n@;oWlWf0onLe_`4ok7DlP03
ok?Nm_nlc>Ko_<cV00;o_<cV00Co_lcTokRgf?nh]mSo^;OH1Onf/=@01?nbZLooY9K6ojBFa_nTU/H3
oin>`P?oVXRn0onFP[`4oi9n^P?oSgbj1?n<N[X3oh]k_0?oRgfn0on<PL82ohf6a`?oUkC/1?nH`O@0
0onHc__oN^CXog[Tj002ohKYkP?oYmoj0_nYdOD5ojW?m0;oZLkc1OnXa>h2ojS1k0GoZ<7[Q?nW`>/0
0ol0003oYl3[ojO0j`0DojO0j`oooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000oooo
ooooool05_ooool3o`0000[ooooo0_nA^O82oj2nkPCoWlWf00?oW=Klok7Dl_nae?800_nae?82ok[9
iP?o_<cV00?o^K_KokRgf?nh]mP00onh]mP2okJ`e0;oZIg:1?nTU/H3oin>`PCoVXRn0onFP[`3oi9n
^P?oSgbj1?n<N[X2oh]k_004oi6Fe?nCW]_oTikKoi>Nf`CoUJSS1OnG]>`2oiS1m0;oO^G^0_n6jNh3
ojOQn`03ojOOn_nYdOGoZM7e00;oZM7e0_nYco@3ojS5kP?oZ<C^1_nX`N`2ojS1jhOoYl3[00?o0000
ojO0jonW`>/05?nW`>/>ooooo`03o`000?oooooooooo013ooooo000Rooooo`;o00005?ooool3o`00
00kooooo1?nP_^h2oio9mPCo[l[^00?o/MCbok[9i_njbNH00_njbNH01?nlc>Ko^K_KokVkfoni^m/3
okRgf003ojjUconYWL[oZIg:00?oZIg:0onTU/H4oin>`P?oVXRn0onFP[`2oi9n^P04oi2:bOn@S<co
T8c<oi2<c0CoT93?1?nAU]@3oi>Nf`CoUJSS0_nG]>`2oh;Um0?oQ^W_0onVh_/2ojOQn`?oZM?f0_nY
dOD2ojS6k`GoZ<G^00?oZ<C^ojS1k?nX`N`01?nX`Nb;ojO0j`03o`000?nW`>_oYl3[01CoYl3[3Ooo
ool00ol0003oooooooooo`0@ooooo`008Oooool2o`0001;ooooo0ol0000Booooo`;oX;k^0on^`NP2
ojo:kP?o^<KU0onjbNH2okZogPCo^K_K00Co^;OHojjUcon^YLoo[ZG?1?nYWLX4ojBFaP;oWhk200Co
V97:oiB=bOnDSLWoU8g90onBRlP4oi2:b@?oT8c<1?n@T<l3oi6Fe0CoTikK0_nEZ><2ohOSnP;oQnSb
1?nUi?/2ojKRn`?oZMGg0_nYdoH2ojW7k`CoZ<K_0_nXaNh6ojS1k8koYl3[00?o0000ojO0jonW`>/0
5OnW`>/<ooooo`03o`000?oooooooooo013ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00oooooo
0_l0000Fooooo`?o[/7X0onf`n@4okS6i@03ok[9i_nj_mko^[oN00;o^[oN0_ni^m/00ona[MCo[ZG?
ojjUc`02ojjUc`GoZIg:0_nTU/H00onLU/goV97:oiRAbP02oiRAbP?oU8g90onBRlP3oi2:b@?oT8c<
1On@T<l3oi6Fe0;oTikK0_n;g_h2ohWWmP?oY>Cl0_nUi?/4ojWHn0;oZMGg0_nYb?04ojW7k`;oZ<K_
0_nX`^`4ojS1k0;oYl3/T?nW`>/00ol0003oYl3[ojO0j`0DojO0j`gooooo00?o0000ooooooooool0
3oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00cooooo0ol0000Iooooo`03ojk1j?nf`nCo]/?T00?o]/?T
0_nha^D2ok[1h0?o^[oN00?o];CIok6]e?na[M@00_na[M@4ojjUc`;oZIg:0_nQW=04oibFc@?oV97:
0onDSLT3oi:;b0?oT8[91?n@S<`2oi2@c`CoSlcm0_n=e_l3ohcUnP04ohWWm_nTi?coY>ClojCTo0Co
ZMWi0_nYf?P2ojW9l0CoZLS`0_nYanl6ojS2k003ojS1k?nW`>coYl3/00?oYl3/T?nW`>/00ol0003o
Yl3[ojO0j`0DojO0j`cooooo00?o0000ooooooooool03oooool000Oooooo00Go410@oooooooooooo
oooooa0@400;ooooo`Go00001Oooool2o`0000[ooooo0ol0000Mooooo`Co]/?T0_ni`n84ok[1h004
okZog_nd]=Wo];CIokBdf@Co/JgD0_n^YLl00onUXmCoXIc@oj6Ld003oj6Ld0?oW9K=0onHTLX4oiB=
b@?oTX_80on@R/T2oi2<c0?oSl7h0_n?c?d4ohoRo@;oS>Gj0_nRi?`3ojSKn@;oZMWi0onYbo44ojW9
l0;oZLS`0_nX`nd6ojS2k0?oYl7/0_nW`>bBojO0j`03o`000?nW`>_oYl3[01GoYl3[2oooool00ol0
003oooooooooo`0?ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgM
gOoooooo00001_ooool00ol0003oooooooooo`06ooooo`?o00008Oooool00onf`nCo^L?RokW3hP03
okW3hP;o^/7P0_nf_=h4okBdf@;o/JgD00?oZ:_HojFSe?nUXm@00_nUXm@4oj6Ld0CoW9K=0onHTLX2
oiB=b@03oi6Zion?[ncoSjo/00;oSjo/1?n?]o82oho1n0CoTM_n0_n?h_d3oj3So004oj;To?nXfoWo
Z=_iojSKn@;oZ/cb1OnYbo42ojW9l0KoZ<?]0_nX`^`2ojS1k0?oYl7/U_nW`>/00ol0003oYl3[ojO0
j`0EojO0j`[ooooo00?o0000ooooooooool03oooool000Oooooo00Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool00oooool3o`0002Kooooo
0oni`n800ong`n?o][cNokJlgP03okJlgP;o];CI00?o[;;MojR[f?nXZmP00_nXZmP4ojFSe0CoXIc@
0_nLU/d00onFY^7oTjOSoi>Wh`02oi>Wh`?oTJ[W1?n?[n`2ohnglP?oTmCn0_nAfoh4oikQo@;oX>?l
0onWg?X00onXfoWoZ/cboj[<lP02oj[<lP;oZL_a0onYa>h6ojS3k@KoZ<7/00?oYl7/ojO0jonW`>/0
U_nW`>/00ol0003oYl3[ojO0j`0DojO0j`[ooooo00?o0000ooooooooool03oooool000Oooooo00Go
410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Gooooo00Co0000oooooooooooo
oooo0ol0000Zooooo`04okW3h_ng`n?o]l?SokO3h`?o][cN00?o[[[RojbbgOn//]d00_n//]d4ojR[
f0;oYJ?D0_nLZn44oiVXh@?oUZKQ1?nCYn<3oi6Zi`;oSjo/0onCc?/2oi?DoPCoW=km0_nNhOd3ojKL
nP;oYmcj0onZcO82oj[<lP;oZLG^1OnYa>h2ojS3k@SoZ<7/VonW`>/00ol0003oYl3[ojO0j`0DojO0
j`Wooooo00?o0000ooooooooool03oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000000Gooooo1?l0000^ooooo`Co]l?S00Co][cNojjjh_n^^^;o[[[R1?n//]d2
ojR[f003oj2`honLZn7oW:_Q00?oW:_Q1?nIZ>43oiJVh@;oTjOS0_nD_O<4oiC4m`;oTlck0onJf_d2
oicNo@CoY=_k0_nVg?X3ojW>l`;oZ/gb0_nYa^l4ojW5kP;oZLC^0_nX`^`7ojS1k9koYl3[00?o0000
ojO0jonW`>/05?nW`>/9ooooo`03o`000?oooooooooo00oooooo0007ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`04ooooo`;o0000<Oooool2okO3h`;o/<;W1?n^^^82
ojbbg@;oXkCU0onP/><5oib[h@;oVJSQ0_nG]^d3oiFil0CoU;gc0_nDa?L3oiWFo@;oV][m1?nRf_/2
ojCKn`?oZLod0_nYc_<2ojW7k`CoZLK_0_nYaNh6ojS2k0;oZ<7/XonW`>/00ol0003oYl3[ojO0j`0D
ojO0j`Sooooo00?o0000ooooooooool03oooool002;ooooo00?o0000ooooooooool0;oooool4ok32
i`;o[[[R0_nU^^P4oj>di@?oX;3S0_nLZn43oiVfk0CoUkK]0onE^O02oiBml`?oV=3k0_nIe_d3oj7G
n`;oX][k1?nXco@2ojW?m0;oZLS`1?nYanl2ojW6k`SoZ<;/YonW`>/00ol0003oYl3[ojO0j`0CojO0
j`Wooooo00?o0000ooooooooool03_ooool002?ooooo00?o0000ooooooooool0;oooool2ok32i`;o
Y/3/1?nU^^P2oj>di@;oWKS/1?nK]n/4oiVfk0;oUkK]0_nGa_L4oiO;nP;oV=3k0onOdoX2oj7Gn`?o
Ylod0_nXco@3ojW9l0CoZLS`0_nYanl2ojS3k@KoZ<;/0_nX`>^XojO0j`03o`000?nW`>_oYl3[01Co
Yl3[2?ooool00ol0003oooooooooo`0>ooooo`009?ooool00ol0003oooooooooo`0_ooooo`CoY/3/
0_nU^^P2oijkk@CoWKS/1?nK]n/2oiVfk0;oUl?e1?nGa_L2oiO;nP?oW]3i0_nOdoX2ojK>m@?oYlod
0onXbO44ojW9l0;oZLS`1_nX`nd2ojS2k0;oZ<7[1?nX`>^XojO0j`03o`000?nW`>_oYl3[01CoYl3[
1oooool00ol0003oooooooooo`0>ooooo`009Oooool2o`00033ooooo0_nV`>`2oinnkPCoW[_]0_nM
^>`3oiVnlPCoV<3c0onG`oD2oiO6m`?oW<ch0_nNd?T2ojC<m0CoY/ke00?oYlodojS9lOnXbO400onX
bO42ojW9l0;oZ<C]1_nX`nd2ojS1k0CoZ<7[0_nX`>^ZojO0j`03o`000?nW`>_oYl3[01CoYl3[1_oo
ool00ol0003oooooooooo`0>ooooo`009oooool00ol0003oooooooooo`0^ooooo`CoWkk^0_nN^nd3
oiZml0CoVKkb0_nH`?<2oic4m0CoW<Sf0_nLc?P2oj?:m0CoY<cd0_nVc_D3ojO9l@;oZ<Wa0onXa>h4
ojS4k@;oZ<?]1_nX`N`2ojS1jjkoYl3[00?o0000ojO0jonW`>/04onW`>/6ooooo`03o`000?oooooo
oooo00kooooo000Xooooo`03o`000?oooooooooo02kooooo0_nO_^h3oibmk`CoV[g`0_nI__82oic1
lPCoW<Cd0_nLb?H2oj;7l`CoXl[d0_nTc?@3ojO8l@;oYlWa1onXa>h2ojS4k@SoZ<7//OnW`>/00ol0
003oYl3[ojO0j`0DojO0j`Gooooo00?o0000ooooooooool03_ooool002Wooooo00?o0000oooooooo
ool0;oooool4oibmk`;oV[g`0_nL_o44oic1lP;oW<Cd0_nQaO84oj;7l`;oXl[d0onVao42ojO8l@;o
YlC^1_nXa>h3ojS2k0KoZ<7/]OnW`>/00ol0003oYl3[ojO0j`0DojO0j`Cooooo00?o0000oooooooo
ool03_ooool002[ooooo0_l0000aooooo`CoWKg_0onL_o42oic1lP?oX<;a0onQaO82oj;7l`?oYLKa
0_nVao46ojO4kP;oZ<C^1onX`^`2ojS1k0?oYl7[]_nW`>/00ol0003oYl3[ojO0j`0DojO0j`?ooooo
00?o0000ooooooooool03_ooool002cooooo00?o0000ooooooooool0;oooool2oifmk`;oX;k^1?nP
`?02oj32l@;oXl;_1?nTa?02ojG6l@;oYl?^1_nWa>h8ojS2k0CoYl7/0_nW`N^hojO0j`03o`000?nW
`>_oYl3[01CoYl3[0oooool00ol0003oooooooooo`0=ooooo`00;Oooool00ol0003oooooooooo`0_
ooooo`CoX;k^0_nP`?02oj?1kPCoXl;_0_nTa?02ojK2kPCoYl?^0_nWa>h2ojO2k@KoZ<;/1OnW`Nbl
ojO0j`03o`000?nW`>_oYl3[01CoYl3[0oooool00ol0003oooooooooo`0=ooooo`00;_ooool00ol0
003oooooooooo`0_ooooo`;oX;k^0_nS_nd4oj?1kP;oXl;_0_nU`Nd4ojK2kP;oYl?^1_nW`^d2ojS2
k0GoYl7/`?nW`>/00ol0003oYl3[ojO0j`0DojO0j`;ooooo00?o0000ooooooooool03Oooool002oo
oooo00?o0000ooooooooool0;oooool4oj>ok@;oXl7^0_nU`>d4ojG1k@;oY/;^0_nW`N`6ojO2k@Go
Yl7/a?nW`>/00ol0003oYl3[ojO0j`0CojO0j`;ooooo00?o0000ooooooooool03Oooool0033ooooo
0_l0000`ooooo`;oXko]0_nU_n`4ojG0k@;oYL7]0_nV`N`4ojO1k0;oYl;]1OnW`Nc7ojO0j`03o`00
0?nW`>_oYl3[01CoYl3[00?oooooo`000?ooool03_ooool003;ooooo00?o0000ooooooooool0;_oo
ool4ojFok0;oYL3]0_nV`>`4ojK1k0OoYl7/bonW`>/00ol0003oYl3[ojO0j`0CojO0j`03ooooool0
003ooooo00kooooo000cooooo`03o`000?oooooooooo02kooooo0_nU_n`2ojJok0CoY/3/0_nV`N`3
ojO0k0;oYl7/conW`>/00ol0003oYl3[ojO0j`0CojO0j`03o`000?oooooooooo00gooooo000doooo
o`03o`000?oooooooooo02kooooo1?nV_n`2ojK0k0GoYl3/donW`>/00ol0003oYl3[ojO0j`0AojO0
j`03ooooool0003ooooo00kooooo000eooooo`;o0000;oooool2ojJok0?oYl3[0_nW`>cFojO0j`03
o`000?nW`>_oYl3[00goYl3[1_ooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003ooooo
ooooo`0^ooooomcoYl3[00?o0000ojO0jonW`>/02OnW`>/9ooooo`03o`000?oooooooooo00cooooo
000hooooo`03o`000?oooooooooo02kooooog?nW`>/00ol0003oYl3[ojO0j`05ojO0j`cooooo00?o
0000ooooooooool03?ooool003Wooooo00?o0000ooooooooool0;_oooooLojO0j`03o`000?nW`>_o
Yl3[013ooooo00?o0000ooooooooool03?ooool003[ooooo0_l0000_ooooom_oYl3[00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0<ooooo`00??ooool00ol0003oooooooooo`0]ooooomKo
Yl3[1Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo000mooooo`03o`00
0?oooooooooo02goooood_nW`>/9ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3?ooool003kooooo00?o0000ooooooooool0;Oooooo:ojO0ja3ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0<ooooo`00?oooool2o`0002ooooooaOnW`>/Dooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool02oooool0047ooooo00?o0000ooooooooool0;Oooooo1ojO0
jaSooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`00@_ooool00ol0003o
ooooooooo`0]oooookcoYl3[7Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_o
oooo0013ooooo`03o`000?oooooooooo02gooooo^?nW`>/Pooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool004Cooooo00?o0000ooooooooool0;OoooondojO0jbCooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`00AOooool2o`0002oooooo[_nW`>/Y
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool004Oooooo00?o0000oooo
ooooool0;OoooonZojO0jbcooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;oooo
o`00B?ooool00ol0003oooooooooo`0]ooooojKoYl3[<?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00_ooooo0019ooooo`03o`000?oooooooooo02goooooX_nW`>/dooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool004[ooooo0_l0000^oooooigoYl3[>Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo001<ooooo`03o`000?oooooo
oooo02coooooVOnW`>/looooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool0
04gooooo00?o0000ooooooooool0;?oooonBojO0jd?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0:ooooo`00C_ooool00ol0003oooooooooo`0]ooooohgoYl3[Aoooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00[ooooo001?ooooo`;o0000;_oooon8ojO0jdcooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`00DOooool00ol0003ooooooooo
o`0/ooooohCoYl3[Coooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo001B
ooooo`03o`000?oooooooooo02_oooooPOnW`>]Cooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02_ooool005?ooooo00?o0000ooooooooool0:ooooommojO0jeOooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`09ooooo`00E?ooool2o`0002goooooN?nW`>]Jooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool005Kooooo00?o0000ooooooooool0
:ooooomdojO0jekooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`00Eooo
ool00ol0003oooooooooo`0[ooooofcoYl3[I_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Wooooo001Hooooo`03o`000?oooooooooo02coooooIonW`>]Zooooo`05o`000?oooooo
ooooooooool000002oooool005Wooooo00?o0000ooooooooool0;?oooomSojO0jfgooooo00Go0000
ooooooooooooooooo`00000;ooooo`00F_ooool2o`0002goooooGonW`>]aooooo`04o`000?oooooo
ooooo`0000_ooooo001Looooo`03o`000?oooooooooo02_oooooFonW`>]eooooo`03o`000?oooooo
000000_ooooo001Mooooo`03o`000?oooooooooo02_oooooEonW`>]hooooo`04o`000?oooooooooo
o`0000[ooooo001Nooooo`03o`000?oooooooooo02_oooooDonW`>]looooo`03o`000?oooooo0000
00[ooooo001Oooooo`;o0000;?oooom<ojO0jh?ooooo0_l0000:ooooo`00HOooool00ol0003ooooo
ooooo`0ZooooodSoYl3[QOooool3o`0000[ooooo001Rooooo`03o`000?oooooooooo02_ooooo@onW
`>^4ooooo`Co00003Oooool006?ooooo00?o0000ooooooooool0:oooooloojO0jh?ooooo1?l0000A
ooooo`00I?ooool2o`0002cooooo>onW`>^3ooooo`?o00005Oooool006Kooooo00?o0000oooooooo
ool0:ooooolcojO0jhGooooo1?l0000Hooooo`00Ioooool00ol0003oooooooooo`0Zoooooc3oYl3[
Q?ooool4o`0001cooooo001Xooooo`03o`000?oooooooooo02[ooooo;?nW`>^3ooooo`Co00008?oo
ool006Wooooo0_l0000/ooooobOoYl3[P_ooool4o`0002Cooooo001[ooooo`03o`000?oooooooooo
02[ooooo8onW`>^2ooooo`?o0000:?ooool006cooooo00?o0000ooooooooool0:_oooolMojO0jh?o
oooo1?l0000[ooooo`00KOooool00ol0003oooooooooo`0[oooooaSoYl3[P_ooool4o`0002oooooo
001^ooooo`03o`000?oooooooooo02[ooooo5OnW`>^1ooooo`Co0000<oooool006oooooo0_l0000[
oooooa7oYl3[P?ooool4o`0003Oooooo001aooooo`03o`000?oooooooooo02[ooooo2OnW`>^2oooo
o`Co0000>oooool007;ooooo00?o0000ooooooooool0:_ooool5ojO0jh;ooooo0ol0000oooooo`00
Loooool00ol0003oooooooooo`0Zooooo`03ojO0jooooooooooo07oooooo1?l00012ooooo`00M?oo
ool2o`0002[ooooo00?o0000ooooooooool0Noooool4o`0004Kooooo001fooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool0N?ooool4o`0004[ooooo001gooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0M?ooool4o`0004kooooo001hooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0LOooool3o`0005;ooooo001iooooo`;o00009?ooool00ol0003ooooo
ooooo`1]ooooo`Co0000EOooool007_ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`1Yooooo`Co0000FOooool007cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1U
ooooo`Co0000GOooool007gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Qoooo
o`Co0000HOooool007kooooo0_l0000Oooooo`03o`000?oooooooooo05gooooo1?l0001Uooooo`00
P?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05[ooooo0ol0001Yooooo`00POoo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Kooooo1?l0001/ooooo`00P_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05;ooooo1?l0001`ooooo`00Poooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo04kooooo1?l0001dooooo`00Q?ooool2o`0001Wo
oooo00?o0000ooooooooool0B_ooool4o`0007Sooooo0026ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0A_ooool4o`0007cooooo0027ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0@oooool3o`00083ooooo0028ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0?oooool4o`0008?ooooo0029ooooo`;o00005?ooool00ol0003oooooooooo`0koooo
o`Co0000Qoooool008_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0gooooo`Co
0000Roooool008cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0cooooo`Co0000
Soooool008gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0`ooooo`?o0000Tooo
ool008kooooo0_l0000?ooooo`03o`000?oooooooooo02cooooo1?l0002Fooooo`00T?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02Sooooo1?l0002Jooooo`00TOooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo02Cooooo1?l0002Nooooo`00T_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo027ooooo1?l0002Rooooo`00Toooool2o`0000Wooooo00?o
0000ooooooooool07Oooool4o`000:Kooooo002Eooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool06_ooool3o`000:[ooooo002Fooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool05_ooool4o`000:gooooo002Gooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool04_ooool4o`000;7ooooo002Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
3_ooool4o`000;Gooooo002Iooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000^Ooo
ool009_ooooo00Co0000oooooooooooo00002Oooool3o`000;gooooo002Looooo`03o`000?oooooo
000000Gooooo1?l00030ooooo`00WOooool2o`000003ooooool0003o000000;o0000a?ooool009ko
oooo0_l00038ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00[_ooool01OnHV9So0000o`000?m4
A4Co^[Zj00Wooooo00Gok^k^oc8b<_l0003o410@olc<c005ooooo`;o8B4Q1_ooool2o`000003oa0@
4?oooooooooo09Gooooo002^ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool6o`000006oooo
oomEEEGoMgMgoooooonHV9So8B4Q1Oooool2ob4Q8@Oooooo00?o0000ooooooooool0U_ooool00:ko
oooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000_ooooo1Ol0002Goooo
o`00[_ooool00ol0003oooooooooo`04ooooo`Ko000000Koooooo`000?nHV9SooooooiRHV?lQ8B4;
ooooo`04odA4A?oMgMgoooooo`0009Sooooo002^ooooo`03o`000?oooooooooo00_ooooo00Go0000
oeEEEOl0003o410@olc<c00;ooooo`04omgMgOmEEEGoooooo`0009Sooooo002/ooooo`03oa0@4?l0
003o000000?o00002_ooool00omEEEGoQhN7ooooo`0>ooooo`03ogMgMoo<c<co000009Sooooo002^
ooooo`03o`000?oooooooooo00_ooooo00?ogMgMoa0@4?nHV9P03_ooool00oo^k^koA4A4o`00002H
ooooo`00[_ooool00ol0003oooooooooo`0<ooooo`04olc<c?m4A4Co0000oa0@40gooooo00?oMgMg
o`000?ooool0Uoooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -17 0 ]
[.5 .82364 17 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69467 Mtetra
.4053 .69467 .41061 .69934 .41957 .69681 .41427 .69213 Mtetra
.41427 .69213 .41957 .69681 .42855 .69428 .42327 .68958 Mtetra
.42327 .68958 .42855 .69428 .43756 .69174 .43231 .68703 Mtetra
.43231 .68703 .43756 .69174 .4466 .68919 .44137 .68446 Mtetra
.44137 .68446 .4466 .68919 .45567 .68663 .45046 .68189 Mtetra
.45046 .68189 .45567 .68663 .46478 .68407 .45958 .67931 Mtetra
.45958 .67931 .46478 .68407 .47391 .68149 .46873 .67671 Mtetra
.46873 .67671 .47391 .68149 .48307 .67891 .47792 .67412 Mtetra
.47792 .67412 .48307 .67891 .49227 .67632 .48713 .67151 Mtetra
.48713 .67151 .49227 .67632 .50149 .67371 .49638 .66889 Mtetra
.49638 .66889 .50149 .67371 .51075 .6711 .50565 .66626 Mtetra
.50565 .66626 .51075 .6711 .52004 .66849 .51496 .66363 Mtetra
.51496 .66363 .52004 .66849 .52936 .66586 .5243 .66098 Mtetra
.5243 .66098 .52936 .66586 .53871 .66322 .53367 .65833 Mtetra
.53367 .65833 .53871 .66322 .54809 .66058 .54308 .65567 Mtetra
.54308 .65567 .54809 .66058 .55751 .65792 .55251 .653 Mtetra
.55251 .653 .55751 .65792 .56695 .65526 .56198 .65032 Mtetra
.56198 .65032 .56695 .65526 .57643 .65259 .57148 .64763 Mtetra
.57148 .64763 .57643 .65259 .58595 .6499 .58102 .64493 Mtetra
.58102 .64493 .58595 .6499 .59549 .64721 .59058 .64222 Mtetra
.59058 .64222 .59549 .64721 .60507 .64451 .60018 .6395 Mtetra
.60018 .6395 .60507 .64451 .61468 .6418 .60982 .63678 Mtetra
.60982 .63678 .61468 .6418 .62432 .63908 .61948 .63404 Mtetra
.61948 .63404 .62432 .63908 .634 .63636 .62918 .63129 Mtetra
.62918 .63129 .634 .63636 .64371 .63362 .63892 .62854 Mtetra
.63892 .62854 .64371 .63362 .65345 .63087 .64868 .62577 Mtetra
.64868 .62577 .65345 .63087 .66323 .62811 .65848 .623 Mtetra
.65848 .623 .66323 .62811 .67304 .62535 .66832 .62021 Mtetra
.66832 .62021 .67304 .62535 .68289 .62257 .67819 .61742 Mtetra
.67819 .61742 .68289 .62257 .69277 .61979 .68809 .61462 Mtetra
.68809 .61462 .69277 .61979 .70269 .61699 .69803 .6118 Mtetra
.69803 .6118 .70269 .61699 .71264 .61418 .70801 .60898 Mtetra
.70801 .60898 .71264 .61418 .72262 .61137 .71802 .60615 Mtetra
.71802 .60615 .72262 .61137 .73264 .60854 .72806 .6033 Mtetra
.72806 .6033 .73264 .60854 .7427 .60571 .73814 .60045 Mtetra
.73814 .60045 .7427 .60571 .75279 .60286 .74826 .59759 Mtetra
.74826 .59759 .75279 .60286 .76291 .60001 .75841 .59471 Mtetra
.75841 .59471 .76291 .60001 .77308 .59714 .7686 .59183 Mtetra
.7686 .59183 .77308 .59714 .78328 .59427 .77882 .58893 Mtetra
.77882 .58893 .78328 .59427 .79351 .59138 .78908 .58603 Mtetra
.78908 .58603 .79351 .59138 .80378 .58849 .79938 .58311 Mtetra
.79938 .58311 .80378 .58849 .81409 .58558 .80971 .58019 Mtetra
.80971 .58019 .81409 .58558 .82443 .58267 .82008 .57725 Mtetra
.82008 .57725 .82443 .58267 .83482 .57974 .83049 .57431 Mtetra
.83049 .57431 .83482 .57974 .84523 .5768 .84094 .57135 Mtetra
.84094 .57135 .84523 .5768 .85569 .57385 .85142 .56838 Mtetra
.85142 .56838 .85569 .57385 .86618 .57089 .86194 .5654 Mtetra
.86194 .5654 .86618 .57089 .87672 .56792 .8725 .56241 Mtetra
.8725 .56241 .87672 .56792 .88729 .56494 .8831 .55941 Mtetra
.8831 .55941 .88729 .56494 .89789 .56195 .89374 .5564 Mtetra
.89374 .5564 .89789 .56195 .90854 .55895 .90441 .55338 Mtetra
.90441 .55338 .90854 .55895 .91923 .55594 .91512 .55035 Mtetra
.91512 .55035 .91923 .55594 .92995 .55292 .92588 .5473 Mtetra
.92588 .5473 .92995 .55292 .94071 .54988 .93667 .54425 Mtetra
.93667 .54425 .94071 .54988 .95152 .54684 .9475 .54118 Mtetra
.9475 .54118 .95152 .54684 .96236 .54378 .95837 .53811 Mtetra
.95837 .53811 .96236 .54378 .97324 .54071 .96928 .53502 Mtetra
.96928 .53502 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.391 .69252 .39636 .6972 .4053 .69467 .39996 .68998 Mtetra
.39996 .68998 .4053 .69467 .41427 .69213 .40895 .68742 Mtetra
.40895 .68742 .41427 .69213 .42327 .68958 .41797 .68486 Mtetra
.41797 .68486 .42327 .68958 .43231 .68703 .42702 .68228 Mtetra
.42702 .68228 .43231 .68703 .44137 .68446 .4361 .6797 Mtetra
.4361 .6797 .44137 .68446 .45046 .68189 .44521 .67711 Mtetra
.44521 .67711 .45046 .68189 .45958 .67931 .45435 .67452 Mtetra
.45435 .67452 .45958 .67931 .46873 .67671 .46352 .67191 Mtetra
.46352 .67191 .46873 .67671 .47792 .67412 .47273 .66929 Mtetra
.47273 .66929 .47792 .67412 .48713 .67151 .48196 .66667 Mtetra
.48196 .66667 .48713 .67151 .49638 .66889 .49123 .66403 Mtetra
.49123 .66403 .49638 .66889 .50565 .66626 .50053 .66139 Mtetra
.50053 .66139 .50565 .66626 .51496 .66363 .50985 .65874 Mtetra
.50985 .65874 .51496 .66363 .5243 .66098 .51922 .65608 Mtetra
.51922 .65608 .5243 .66098 .53367 .65833 .52861 .65341 Mtetra
.52861 .65341 .53367 .65833 .54308 .65567 .53803 .65073 Mtetra
.53803 .65073 .54308 .65567 .55251 .653 .54749 .64804 Mtetra
.54749 .64804 .55251 .653 .56198 .65032 .55698 .64534 Mtetra
.55698 .64534 .56198 .65032 .57148 .64763 .5665 .64264 Mtetra
.5665 .64264 .57148 .64763 .58102 .64493 .57606 .63992 Mtetra
.57606 .63992 .58102 .64493 .59058 .64222 .58565 .6372 Mtetra
.58565 .6372 .59058 .64222 .60018 .6395 .59527 .63446 Mtetra
.59527 .63446 .60018 .6395 .60982 .63678 .60493 .63172 Mtetra
.60493 .63172 .60982 .63678 .61948 .63404 .61461 .62896 Mtetra
.61461 .62896 .61948 .63404 .62918 .63129 .62434 .6262 Mtetra
.62434 .6262 .62918 .63129 .63892 .62854 .63409 .62343 Mtetra
.63409 .62343 .63892 .62854 .64868 .62577 .64388 .62064 Mtetra
.64388 .62064 .64868 .62577 .65848 .623 .65371 .61785 Mtetra
.65371 .61785 .65848 .623 .66832 .62021 .66357 .61505 Mtetra
.66357 .61505 .66832 .62021 .67819 .61742 .67346 .61224 Mtetra
.67346 .61224 .67819 .61742 .68809 .61462 .68339 .60942 Mtetra
.68339 .60942 .68809 .61462 .69803 .6118 .69335 .60658 Mtetra
.69335 .60658 .69803 .6118 .70801 .60898 .70335 .60374 Mtetra
.70335 .60374 .70801 .60898 .71802 .60615 .71338 .60089 Mtetra
.71338 .60089 .71802 .60615 .72806 .6033 .72345 .59803 Mtetra
.72345 .59803 .72806 .6033 .73814 .60045 .73356 .59516 Mtetra
.73356 .59516 .73814 .60045 .74826 .59759 .7437 .59227 Mtetra
.7437 .59227 .74826 .59759 .75841 .59471 .75387 .58938 Mtetra
.75387 .58938 .75841 .59471 .7686 .59183 .76409 .58648 Mtetra
.76409 .58648 .7686 .59183 .77882 .58893 .77434 .58356 Mtetra
.77434 .58356 .77882 .58893 .78908 .58603 .78462 .58064 Mtetra
.78462 .58064 .78908 .58603 .79938 .58311 .79495 .57771 Mtetra
.79495 .57771 .79938 .58311 .80971 .58019 .80531 .57476 Mtetra
.80531 .57476 .80971 .58019 .82008 .57725 .81571 .57181 Mtetra
.81571 .57181 .82008 .57725 .83049 .57431 .82614 .56884 Mtetra
.82614 .56884 .83049 .57431 .84094 .57135 .83661 .56586 Mtetra
.83661 .56586 .84094 .57135 .85142 .56838 .84712 .56288 Mtetra
.84712 .56288 .85142 .56838 .86194 .5654 .85767 .55988 Mtetra
.85767 .55988 .86194 .5654 .8725 .56241 .86826 .55687 Mtetra
.86826 .55687 .8725 .56241 .8831 .55941 .87889 .55385 Mtetra
.87889 .55385 .8831 .55941 .89374 .5564 .88955 .55082 Mtetra
.88955 .55082 .89374 .5564 .90441 .55338 .90025 .54777 Mtetra
.90025 .54777 .90441 .55338 .91512 .55035 .911 .54472 Mtetra
.911 .54472 .91512 .55035 .92588 .5473 .92178 .54166 Mtetra
.92178 .54166 .92588 .5473 .93667 .54425 .9326 .53858 Mtetra
.9326 .53858 .93667 .54425 .9475 .54118 .94346 .53549 Mtetra
.94346 .53549 .9475 .54118 .95837 .53811 .95436 .53239 Mtetra
.95436 .53239 .95837 .53811 .96928 .53502 .9653 .52928 Mtetra
.9653 .52928 .96928 .53502 .98024 .53192 .97628 .52616 Mtetra
.38561 .68781 .391 .69252 .39996 .68998 .39459 .68525 Mtetra
.39459 .68525 .39996 .68998 .40895 .68742 .40359 .68268 Mtetra
.40359 .68268 .40895 .68742 .41797 .68486 .41263 .6801 Mtetra
.41263 .6801 .41797 .68486 .42702 .68228 .4217 .67751 Mtetra
.4217 .67751 .42702 .68228 .4361 .6797 .4308 .67492 Mtetra
.4308 .67492 .4361 .6797 .44521 .67711 .43993 .67231 Mtetra
.43993 .67231 .44521 .67711 .45435 .67452 .44909 .6697 Mtetra
.44909 .6697 .45435 .67452 .46352 .67191 .45828 .66707 Mtetra
.45828 .66707 .46352 .67191 .47273 .66929 .46751 .66444 Mtetra
.46751 .66444 .47273 .66929 .48196 .66667 .47676 .6618 Mtetra
.47676 .6618 .48196 .66667 .49123 .66403 .48605 .65915 Mtetra
.48605 .65915 .49123 .66403 .50053 .66139 .49537 .65649 Mtetra
.49537 .65649 .50053 .66139 .50985 .65874 .50472 .65382 Mtetra
.50472 .65382 .50985 .65874 .51922 .65608 .5141 .65114 Mtetra
.5141 .65114 .51922 .65608 .52861 .65341 .52351 .64846 Mtetra
.52351 .64846 .52861 .65341 .53803 .65073 .53296 .64576 Mtetra
.53296 .64576 .53803 .65073 .54749 .64804 .54244 .64305 Mtetra
.54244 .64305 .54749 .64804 .55698 .64534 .55195 .64034 Mtetra
.55195 .64034 .55698 .64534 .5665 .64264 .56149 .63762 Mtetra
.56149 .63762 .5665 .64264 .57606 .63992 .57107 .63488 Mtetra
.57107 .63488 .57606 .63992 .58565 .6372 .58068 .63214 Mtetra
.58068 .63214 .58565 .6372 .59527 .63446 .59032 .62939 Mtetra
.59032 .62939 .59527 .63446 .60493 .63172 .6 .62663 Mtetra
.6 .62663 .60493 .63172 .61461 .62896 .60971 .62385 Mtetra
.60971 .62385 .61461 .62896 .62434 .6262 .61946 .62107 Mtetra
.61946 .62107 .62434 .6262 .63409 .62343 .62924 .61828 Mtetra
.62924 .61828 .63409 .62343 .64388 .62064 .63905 .61548 Mtetra
.63905 .61548 .64388 .62064 .65371 .61785 .6489 .61267 Mtetra
.6489 .61267 .65371 .61785 .66357 .61505 .65878 .60985 Mtetra
.65878 .60985 .66357 .61505 .67346 .61224 .6687 .60702 Mtetra
.6687 .60702 .67346 .61224 .68339 .60942 .67865 .60418 Mtetra
.67865 .60418 .68339 .60942 .69335 .60658 .68864 .60133 Mtetra
.68864 .60133 .69335 .60658 .70335 .60374 .69866 .59847 Mtetra
.69866 .59847 .70335 .60374 .71338 .60089 .70872 .5956 Mtetra
.70872 .5956 .71338 .60089 .72345 .59803 .71881 .59272 Mtetra
.71881 .59272 .72345 .59803 .73356 .59516 .72894 .58983 Mtetra
.72894 .58983 .73356 .59516 .7437 .59227 .73911 .58692 Mtetra
.73911 .58692 .7437 .59227 .75387 .58938 .74931 .58401 Mtetra
.74931 .58401 .75387 .58938 .76409 .58648 .75955 .58109 Mtetra
.75955 .58109 .76409 .58648 .77434 .58356 .76982 .57816 Mtetra
.76982 .57816 .77434 .58356 .78462 .58064 .78014 .57521 Mtetra
.78014 .57521 .78462 .58064 .79495 .57771 .79049 .57226 Mtetra
.79049 .57226 .79495 .57771 .80531 .57476 .80087 .5693 Mtetra
.80087 .5693 .80531 .57476 .81571 .57181 .8113 .56632 Mtetra
.8113 .56632 .81571 .57181 .82614 .56884 .82176 .56334 Mtetra
.82176 .56334 .82614 .56884 .83661 .56586 .83226 .56034 Mtetra
.83226 .56034 .83661 .56586 .84712 .56288 .8428 .55733 Mtetra
.8428 .55733 .84712 .56288 .85767 .55988 .85337 .55431 Mtetra
.85337 .55431 .85767 .55988 .86826 .55687 .86399 .55128 Mtetra
.86399 .55128 .86826 .55687 .87889 .55385 .87464 .54824 Mtetra
.87464 .54824 .87889 .55385 .88955 .55082 .88533 .54519 Mtetra
.88533 .54519 .88955 .55082 .90025 .54777 .89607 .54213 Mtetra
.89607 .54213 .90025 .54777 .911 .54472 .90684 .53905 Mtetra
.90684 .53905 .911 .54472 .92178 .54166 .91765 .53597 Mtetra
.91765 .53597 .92178 .54166 .9326 .53858 .9285 .53287 Mtetra
.9285 .53287 .9326 .53858 .94346 .53549 .93939 .52976 Mtetra
.93939 .52976 .94346 .53549 .95436 .53239 .95032 .52664 Mtetra
.95032 .52664 .95436 .53239 .9653 .52928 .96129 .52351 Mtetra
.96129 .52351 .9653 .52928 .97628 .52616 .9723 .52037 Mtetra
.38018 .68308 .38561 .68781 .39459 .68525 .38918 .6805 Mtetra
.38918 .6805 .39459 .68525 .40359 .68268 .3982 .67791 Mtetra
.3982 .67791 .40359 .68268 .41263 .6801 .40726 .67532 Mtetra
.40726 .67532 .41263 .6801 .4217 .67751 .41635 .67271 Mtetra
.41635 .67271 .4217 .67751 .4308 .67492 .42547 .6701 Mtetra
.42547 .6701 .4308 .67492 .43993 .67231 .43462 .66748 Mtetra
.43462 .66748 .43993 .67231 .44909 .6697 .4438 .66485 Mtetra
.4438 .66485 .44909 .6697 .45828 .66707 .45301 .66221 Mtetra
.45301 .66221 .45828 .66707 .46751 .66444 .46225 .65956 Mtetra
.46225 .65956 .46751 .66444 .47676 .6618 .47153 .6569 Mtetra
.47153 .6569 .47676 .6618 .48605 .65915 .48083 .65423 Mtetra
.48083 .65423 .48605 .65915 .49537 .65649 .49017 .65156 Mtetra
.49017 .65156 .49537 .65649 .50472 .65382 .49954 .64887 Mtetra
.49954 .64887 .50472 .65382 .5141 .65114 .50895 .64618 Mtetra
.50895 .64618 .5141 .65114 .52351 .64846 .51838 .64347 Mtetra
.51838 .64347 .52351 .64846 .53296 .64576 .52785 .64076 Mtetra
.52785 .64076 .53296 .64576 .54244 .64305 .53735 .63804 Mtetra
.53735 .63804 .54244 .64305 .55195 .64034 .54688 .6353 Mtetra
.54688 .6353 .55195 .64034 .56149 .63762 .55645 .63256 Mtetra
.55645 .63256 .56149 .63762 .57107 .63488 .56605 .62981 Mtetra
.56605 .62981 .57107 .63488 .58068 .63214 .57568 .62705 Mtetra
.57568 .62705 .58068 .63214 .59032 .62939 .58535 .62428 Mtetra
.58535 .62428 .59032 .62939 .6 .62663 .59505 .6215 Mtetra
.59505 .6215 .6 .62663 .60971 .62385 .60478 .61871 Mtetra
.60478 .61871 .60971 .62385 .61946 .62107 .61455 .61591 Mtetra
.61455 .61591 .61946 .62107 .62924 .61828 .62435 .6131 Mtetra
.62435 .6131 .62924 .61828 .63905 .61548 .63419 .61028 Mtetra
.63419 .61028 .63905 .61548 .6489 .61267 .64406 .60746 Mtetra
.64406 .60746 .6489 .61267 .65878 .60985 .65396 .60462 Mtetra
.65396 .60462 .65878 .60985 .6687 .60702 .66391 .60177 Mtetra
.66391 .60177 .6687 .60702 .67865 .60418 .67388 .59891 Mtetra
.67388 .59891 .67865 .60418 .68864 .60133 .68389 .59604 Mtetra
.68389 .59604 .68864 .60133 .69866 .59847 .69394 .59316 Mtetra
.69394 .59316 .69866 .59847 .70872 .5956 .70402 .59027 Mtetra
.70402 .59027 .70872 .5956 .71881 .59272 .71414 .58737 Mtetra
.71414 .58737 .71881 .59272 .72894 .58983 .7243 .58446 Mtetra
.7243 .58446 .72894 .58983 .73911 .58692 .73449 .58154 Mtetra
.73449 .58154 .73911 .58692 .74931 .58401 .74472 .57861 Mtetra
.74472 .57861 .74931 .58401 .75955 .58109 .75498 .57567 Mtetra
.75498 .57567 .75955 .58109 .76982 .57816 .76528 .57272 Mtetra
.76528 .57272 .76982 .57816 .78014 .57521 .77562 .56975 Mtetra
.77562 .56975 .78014 .57521 .79049 .57226 .786 .56678 Mtetra
.786 .56678 .79049 .57226 .80087 .5693 .79641 .5638 Mtetra
.79641 .5638 .80087 .5693 .8113 .56632 .80686 .5608 Mtetra
.80686 .5608 .8113 .56632 .82176 .56334 .81735 .55779 Mtetra
.81735 .55779 .82176 .56334 .83226 .56034 .82788 .55478 Mtetra
.82788 .55478 .83226 .56034 .8428 .55733 .83844 .55175 Mtetra
.83844 .55175 .8428 .55733 .85337 .55431 .84905 .54871 Mtetra
.84905 .54871 .85337 .55431 .86399 .55128 .85969 .54566 Mtetra
.85969 .54566 .86399 .55128 .87464 .54824 .87037 .5426 Mtetra
.87037 .5426 .87464 .54824 .88533 .54519 .88109 .53953 Mtetra
.88109 .53953 .88533 .54519 .89607 .54213 .89185 .53644 Mtetra
.89185 .53644 .89607 .54213 .90684 .53905 .90265 .53335 Mtetra
.90265 .53335 .90684 .53905 .91765 .53597 .91349 .53024 Mtetra
.91349 .53024 .91765 .53597 .9285 .53287 .92437 .52712 Mtetra
.92437 .52712 .9285 .53287 .93939 .52976 .93529 .524 Mtetra
.93529 .524 .93939 .52976 .95032 .52664 .94625 .52085 Mtetra
.94625 .52085 .95032 .52664 .96129 .52351 .95725 .5177 Mtetra
.95725 .5177 .96129 .52351 .9723 .52037 .96829 .51454 Mtetra
.37472 .67831 .38018 .68308 .38918 .6805 .38373 .67572 Mtetra
.38373 .67572 .38918 .6805 .3982 .67791 .39278 .67311 Mtetra
.39278 .67311 .3982 .67791 .40726 .67532 .40186 .6705 Mtetra
.40186 .6705 .40726 .67532 .41635 .67271 .41096 .66788 Mtetra
.41096 .66788 .41635 .67271 .42547 .6701 .4201 .66525 Mtetra
.4201 .66525 .42547 .6701 .43462 .66748 .42927 .66261 Mtetra
.42927 .66261 .43462 .66748 .4438 .66485 .43847 .65996 Mtetra
.43847 .65996 .4438 .66485 .45301 .66221 .4477 .65731 Mtetra
.4477 .65731 .45301 .66221 .46225 .65956 .45697 .65464 Mtetra
.45697 .65464 .46225 .65956 .47153 .6569 .46626 .65197 Mtetra
.46626 .65197 .47153 .6569 .48083 .65423 .47559 .64928 Mtetra
.47559 .64928 .48083 .65423 .49017 .65156 .48495 .64659 Mtetra
.48495 .64659 .49017 .65156 .49954 .64887 .49434 .64389 Mtetra
.49434 .64389 .49954 .64887 .50895 .64618 .50376 .64118 Mtetra
.50376 .64118 .50895 .64618 .51838 .64347 .51322 .63846 Mtetra
.51322 .63846 .51838 .64347 .52785 .64076 .52271 .63572 Mtetra
.52271 .63572 .52785 .64076 .53735 .63804 .53223 .63298 Mtetra
.53223 .63298 .53735 .63804 .54688 .6353 .54178 .63024 Mtetra
.54178 .63024 .54688 .6353 .55645 .63256 .55137 .62748 Mtetra
.55137 .62748 .55645 .63256 .56605 .62981 .56099 .62471 Mtetra
.56099 .62471 .56605 .62981 .57568 .62705 .57065 .62193 Mtetra
.57065 .62193 .57568 .62705 .58535 .62428 .58034 .61914 Mtetra
.58034 .61914 .58535 .62428 .59505 .6215 .59006 .61634 Mtetra
.59006 .61634 .59505 .6215 .60478 .61871 .59982 .61354 Mtetra
.59982 .61354 .60478 .61871 .61455 .61591 .60961 .61072 Mtetra
.60961 .61072 .61455 .61591 .62435 .6131 .61943 .60789 Mtetra
.61943 .60789 .62435 .6131 .63419 .61028 .62929 .60505 Mtetra
.62929 .60505 .63419 .61028 .64406 .60746 .63919 .60221 Mtetra
.63919 .60221 .64406 .60746 .65396 .60462 .64912 .59935 Mtetra
.64912 .59935 .65396 .60462 .66391 .60177 .65908 .59648 Mtetra
.65908 .59648 .66391 .60177 .67388 .59891 .66908 .5936 Mtetra
.66908 .5936 .67388 .59891 .68389 .59604 .67912 .59072 Mtetra
.67912 .59072 .68389 .59604 .69394 .59316 .68919 .58782 Mtetra
.68919 .58782 .69394 .59316 .70402 .59027 .6993 .58491 Mtetra
.6993 .58491 .70402 .59027 .71414 .58737 .70944 .58199 Mtetra
.70944 .58199 .71414 .58737 .7243 .58446 .71962 .57906 Mtetra
.71962 .57906 .7243 .58446 .73449 .58154 .72984 .57612 Mtetra
.72984 .57612 .73449 .58154 .74472 .57861 .74009 .57317 Mtetra
.74009 .57317 .74472 .57861 .75498 .57567 .75038 .57021 Mtetra
.75038 .57021 .75498 .57567 .76528 .57272 .76071 .56724 Mtetra
.76071 .56724 .76528 .57272 .77562 .56975 .77107 .56426 Mtetra
.77107 .56426 .77562 .56975 .786 .56678 .78148 .56126 Mtetra
.78148 .56126 .786 .56678 .79641 .5638 .79192 .55826 Mtetra
.79192 .55826 .79641 .5638 .80686 .5608 .80239 .55524 Mtetra
.80239 .55524 .80686 .5608 .81735 .55779 .81291 .55222 Mtetra
.81291 .55222 .81735 .55779 .82788 .55478 .82346 .54918 Mtetra
.82346 .54918 .82788 .55478 .83844 .55175 .83406 .54613 Mtetra
.83406 .54613 .83844 .55175 .84905 .54871 .84469 .54307 Mtetra
.84469 .54307 .84905 .54871 .85969 .54566 .85536 .54 Mtetra
.85536 .54 .85969 .54566 .87037 .5426 .86607 .53692 Mtetra
.86607 .53692 .87037 .5426 .88109 .53953 .87682 .53383 Mtetra
.87682 .53383 .88109 .53953 .89185 .53644 .88761 .53072 Mtetra
.88761 .53072 .89185 .53644 .90265 .53335 .89844 .52761 Mtetra
.89844 .52761 .90265 .53335 .91349 .53024 .90931 .52448 Mtetra
.90931 .52448 .91349 .53024 .92437 .52712 .92022 .52134 Mtetra
.92022 .52134 .92437 .52712 .93529 .524 .93116 .51819 Mtetra
.93116 .51819 .93529 .524 .94625 .52085 .94216 .51503 Mtetra
.94216 .51503 .94625 .52085 .95725 .5177 .95319 .51185 Mtetra
.95319 .51185 .95725 .5177 .96829 .51454 .96426 .50866 Mtetra
.36922 .67351 .37472 .67831 .38373 .67572 .37826 .6709 Mtetra
.37826 .6709 .38373 .67572 .39278 .67311 .38732 .66828 Mtetra
.38732 .66828 .39278 .67311 .40186 .6705 .39642 .66566 Mtetra
.39642 .66566 .40186 .6705 .41096 .66788 .40554 .66302 Mtetra
.40554 .66302 .41096 .66788 .4201 .66525 .4147 .66037 Mtetra
.4147 .66037 .4201 .66525 .42927 .66261 .42389 .65772 Mtetra
.42389 .65772 .42927 .66261 .43847 .65996 .43311 .65505 Mtetra
.43311 .65505 .43847 .65996 .4477 .65731 .44236 .65238 Mtetra
.44236 .65238 .4477 .65731 .45697 .65464 .45165 .6497 Mtetra
.45165 .6497 .45697 .65464 .46626 .65197 .46096 .64701 Mtetra
.46096 .64701 .46626 .65197 .47559 .64928 .47031 .6443 Mtetra
.47031 .6443 .47559 .64928 .48495 .64659 .47969 .64159 Mtetra
.47969 .64159 .48495 .64659 .49434 .64389 .4891 .63887 Mtetra
.4891 .63887 .49434 .64389 .50376 .64118 .49855 .63615 Mtetra
.49855 .63615 .50376 .64118 .51322 .63846 .50802 .63341 Mtetra
.50802 .63341 .51322 .63846 .52271 .63572 .51753 .63066 Mtetra
.51753 .63066 .52271 .63572 .53223 .63298 .52708 .6279 Mtetra
.52708 .6279 .53223 .63298 .54178 .63024 .53665 .62513 Mtetra
.53665 .62513 .54178 .63024 .55137 .62748 .54626 .62236 Mtetra
.54626 .62236 .55137 .62748 .56099 .62471 .55591 .61957 Mtetra
.55591 .61957 .56099 .62471 .57065 .62193 .56558 .61677 Mtetra
.56558 .61677 .57065 .62193 .58034 .61914 .57529 .61397 Mtetra
.57529 .61397 .58034 .61914 .59006 .61634 .58504 .61115 Mtetra
.58504 .61115 .59006 .61634 .59982 .61354 .59482 .60833 Mtetra
.59482 .60833 .59982 .61354 .60961 .61072 .60463 .60549 Mtetra
.60463 .60549 .60961 .61072 .61943 .60789 .61448 .60265 Mtetra
.61448 .60265 .61943 .60789 .62929 .60505 .62437 .59979 Mtetra
.62437 .59979 .62929 .60505 .63919 .60221 .63428 .59692 Mtetra
.63428 .59692 .63919 .60221 .64912 .59935 .64424 .59405 Mtetra
.64424 .59405 .64912 .59935 .65908 .59648 .65423 .59116 Mtetra
.65423 .59116 .65908 .59648 .66908 .5936 .66425 .58826 Mtetra
.66425 .58826 .66908 .5936 .67912 .59072 .67431 .58536 Mtetra
.67431 .58536 .67912 .59072 .68919 .58782 .68441 .58244 Mtetra
.68441 .58244 .68919 .58782 .6993 .58491 .69454 .57951 Mtetra
.69454 .57951 .6993 .58491 .70944 .58199 .70471 .57657 Mtetra
.70471 .57657 .70944 .58199 .71962 .57906 .71491 .57363 Mtetra
.71491 .57363 .71962 .57906 .72984 .57612 .72516 .57067 Mtetra
.72516 .57067 .72984 .57612 .74009 .57317 .73544 .5677 Mtetra
.73544 .5677 .74009 .57317 .75038 .57021 .74575 .56471 Mtetra
.74575 .56471 .75038 .57021 .76071 .56724 .75611 .56172 Mtetra
.75611 .56172 .76071 .56724 .77107 .56426 .7665 .55872 Mtetra
.7665 .55872 .77107 .56426 .78148 .56126 .77693 .55571 Mtetra
.77693 .55571 .78148 .56126 .79192 .55826 .78739 .55268 Mtetra
.78739 .55268 .79192 .55826 .80239 .55524 .7979 .54965 Mtetra
.7979 .54965 .80239 .55524 .81291 .55222 .80844 .5466 Mtetra
.80844 .5466 .81291 .55222 .82346 .54918 .81902 .54354 Mtetra
.81902 .54354 .82346 .54918 .83406 .54613 .82964 .54047 Mtetra
.82964 .54047 .83406 .54613 .84469 .54307 .8403 .53739 Mtetra
.8403 .53739 .84469 .54307 .85536 .54 .851 .5343 Mtetra
.851 .5343 .85536 .54 .86607 .53692 .86174 .5312 Mtetra
.86174 .5312 .86607 .53692 .87682 .53383 .87252 .52809 Mtetra
.87252 .52809 .87682 .53383 .88761 .53072 .88334 .52496 Mtetra
.88334 .52496 .88761 .53072 .89844 .52761 .89419 .52182 Mtetra
.89419 .52182 .89844 .52761 .90931 .52448 .90509 .51867 Mtetra
.90509 .51867 .90931 .52448 .92022 .52134 .91603 .51551 Mtetra
.91603 .51551 .92022 .52134 .93116 .51819 .92701 .51234 Mtetra
.92701 .51234 .93116 .51819 .94216 .51503 .93803 .50916 Mtetra
.93803 .50916 .94216 .51503 .95319 .51185 .94909 .50596 Mtetra
.94909 .50596 .95319 .51185 .96426 .50866 .9602 .50275 Mtetra
.36369 .66869 .36922 .67351 .37826 .6709 .37275 .66606 Mtetra
.37275 .66606 .37826 .6709 .38732 .66828 .38183 .66342 Mtetra
.38183 .66342 .38732 .66828 .39642 .66566 .39094 .66078 Mtetra
.39094 .66078 .39642 .66566 .40554 .66302 .40009 .65813 Mtetra
.40009 .65813 .40554 .66302 .4147 .66037 .40927 .65546 Mtetra
.40927 .65546 .4147 .66037 .42389 .65772 .41848 .65279 Mtetra
.41848 .65279 .42389 .65772 .43311 .65505 .42772 .65011 Mtetra
.42772 .65011 .43311 .65505 .44236 .65238 .43699 .64742 Mtetra
.43699 .64742 .44236 .65238 .45165 .6497 .44629 .64472 Mtetra
.44629 .64472 .45165 .6497 .46096 .64701 .45563 .64201 Mtetra
.45563 .64201 .46096 .64701 .47031 .6443 .465 .63929 Mtetra
.465 .63929 .47031 .6443 .47969 .64159 .4744 .63657 Mtetra
.4744 .63657 .47969 .64159 .4891 .63887 .48383 .63383 Mtetra
.48383 .63383 .4891 .63887 .49855 .63615 .4933 .63108 Mtetra
.4933 .63108 .49855 .63615 .50802 .63341 .50279 .62833 Mtetra
.50279 .62833 .50802 .63341 .51753 .63066 .51233 .62556 Mtetra
.51233 .62556 .51753 .63066 .52708 .6279 .52189 .62279 Mtetra
.52189 .62279 .52708 .6279 .53665 .62513 .53149 .62 Mtetra
.53149 .62 .53665 .62513 .54626 .62236 .54112 .61721 Mtetra
.54112 .61721 .54626 .62236 .55591 .61957 .55079 .6144 Mtetra
.55079 .6144 .55591 .61957 .56558 .61677 .56049 .61159 Mtetra
.56049 .61159 .56558 .61677 .57529 .61397 .57022 .60876 Mtetra
.57022 .60876 .57529 .61397 .58504 .61115 .57999 .60593 Mtetra
.57999 .60593 .58504 .61115 .59482 .60833 .58979 .60308 Mtetra
.58979 .60308 .59482 .60833 .60463 .60549 .59963 .60023 Mtetra
.59963 .60023 .60463 .60549 .61448 .60265 .6095 .59737 Mtetra
.6095 .59737 .61448 .60265 .62437 .59979 .61941 .59449 Mtetra
.61941 .59449 .62437 .59979 .63428 .59692 .62935 .59161 Mtetra
.62935 .59161 .63428 .59692 .64424 .59405 .63933 .58871 Mtetra
.63933 .58871 .64424 .59405 .65423 .59116 .64934 .58581 Mtetra
.64934 .58581 .65423 .59116 .66425 .58826 .65939 .58289 Mtetra
.65939 .58289 .66425 .58826 .67431 .58536 .66947 .57996 Mtetra
.66947 .57996 .67431 .58536 .68441 .58244 .67959 .57703 Mtetra
.67959 .57703 .68441 .58244 .69454 .57951 .68975 .57408 Mtetra
.68975 .57408 .69454 .57951 .70471 .57657 .69995 .57112 Mtetra
.69995 .57112 .70471 .57657 .71491 .57363 .71018 .56815 Mtetra
.71018 .56815 .71491 .57363 .72516 .57067 .72044 .56517 Mtetra
.72044 .56517 .72516 .57067 .73544 .5677 .73075 .56218 Mtetra
.73075 .56218 .73544 .5677 .74575 .56471 .74109 .55918 Mtetra
.74109 .55918 .74575 .56471 .75611 .56172 .75147 .55617 Mtetra
.75147 .55617 .75611 .56172 .7665 .55872 .76189 .55315 Mtetra
.76189 .55315 .7665 .55872 .77693 .55571 .77234 .55012 Mtetra
.77234 .55012 .77693 .55571 .78739 .55268 .78284 .54707 Mtetra
.78284 .54707 .78739 .55268 .7979 .54965 .79337 .54401 Mtetra
.79337 .54401 .7979 .54965 .80844 .5466 .80394 .54095 Mtetra
.80394 .54095 .80844 .5466 .81902 .54354 .81455 .53787 Mtetra
.81455 .53787 .81902 .54354 .82964 .54047 .8252 .53478 Mtetra
.8252 .53478 .82964 .54047 .8403 .53739 .83589 .53168 Mtetra
.83589 .53168 .8403 .53739 .851 .5343 .84661 .52857 Mtetra
.84661 .52857 .851 .5343 .86174 .5312 .85738 .52544 Mtetra
.85738 .52544 .86174 .5312 .87252 .52809 .86819 .52231 Mtetra
.86819 .52231 .87252 .52809 .88334 .52496 .87903 .51916 Mtetra
.87903 .51916 .88334 .52496 .89419 .52182 .88992 .516 Mtetra
.88992 .516 .89419 .52182 .90509 .51867 .90085 .51283 Mtetra
.90085 .51283 .90509 .51867 .91603 .51551 .91182 .50965 Mtetra
.91182 .50965 .91603 .51551 .92701 .51234 .92283 .50645 Mtetra
.92283 .50645 .92701 .51234 .93803 .50916 .93388 .50324 Mtetra
.93388 .50324 .93803 .50916 .94909 .50596 .94497 .50003 Mtetra
.94497 .50003 .94909 .50596 .9602 .50275 .9561 .4968 Mtetra
.35813 .66383 .36369 .66869 .37275 .66606 .3672 .66119 Mtetra
.3672 .66119 .37275 .66606 .38183 .66342 .3763 .65854 Mtetra
.3763 .65854 .38183 .66342 .39094 .66078 .38544 .65587 Mtetra
.38544 .65587 .39094 .66078 .40009 .65813 .3946 .6532 Mtetra
.3946 .6532 .40009 .65813 .40927 .65546 .4038 .65052 Mtetra
.4038 .65052 .40927 .65546 .41848 .65279 .41303 .64783 Mtetra
.41303 .64783 .41848 .65279 .42772 .65011 .42229 .64514 Mtetra
.42229 .64514 .42772 .65011 .43699 .64742 .43158 .64243 Mtetra
.43158 .64243 .43699 .64742 .44629 .64472 .4409 .63971 Mtetra
.4409 .63971 .44629 .64472 .45563 .64201 .45026 .63699 Mtetra
.45026 .63699 .45563 .64201 .465 .63929 .45965 .63425 Mtetra
.45965 .63425 .465 .63929 .4744 .63657 .46907 .63151 Mtetra
.46907 .63151 .4744 .63657 .48383 .63383 .47853 .62875 Mtetra
.47853 .62875 .48383 .63383 .4933 .63108 .48801 .62599 Mtetra
.48801 .62599 .4933 .63108 .50279 .62833 .49753 .62321 Mtetra
.49753 .62321 .50279 .62833 .51233 .62556 .50709 .62043 Mtetra
.50709 .62043 .51233 .62556 .52189 .62279 .51667 .61764 Mtetra
.51667 .61764 .52189 .62279 .53149 .62 .52629 .61483 Mtetra
.52629 .61483 .53149 .62 .54112 .61721 .53595 .61202 Mtetra
.53595 .61202 .54112 .61721 .55079 .6144 .54563 .6092 Mtetra
.54563 .6092 .55079 .6144 .56049 .61159 .55536 .60636 Mtetra
.55536 .60636 .56049 .61159 .57022 .60876 .56511 .60352 Mtetra
.56511 .60352 .57022 .60876 .57999 .60593 .5749 .60067 Mtetra
.5749 .60067 .57999 .60593 .58979 .60308 .58473 .59781 Mtetra
.58473 .59781 .58979 .60308 .59963 .60023 .59459 .59493 Mtetra
.59459 .59493 .59963 .60023 .6095 .59737 .60448 .59205 Mtetra
.60448 .59205 .6095 .59737 .61941 .59449 .61441 .58916 Mtetra
.61441 .58916 .61941 .59449 .62935 .59161 .62438 .58625 Mtetra
.62438 .58625 .62935 .59161 .63933 .58871 .63438 .58334 Mtetra
.63438 .58334 .63933 .58871 .64934 .58581 .64442 .58041 Mtetra
.64442 .58041 .64934 .58581 .65939 .58289 .65449 .57748 Mtetra
.65449 .57748 .65939 .58289 .66947 .57996 .6646 .57453 Mtetra
.6646 .57453 .66947 .57996 .67959 .57703 .67475 .57158 Mtetra
.67475 .57158 .67959 .57703 .68975 .57408 .68493 .56861 Mtetra
.68493 .56861 .68975 .57408 .69995 .57112 .69515 .56563 Mtetra
.69515 .56563 .69995 .57112 .71018 .56815 .70541 .56264 Mtetra
.70541 .56264 .71018 .56815 .72044 .56517 .7157 .55965 Mtetra
.7157 .55965 .72044 .56517 .73075 .56218 .72603 .55664 Mtetra
.72603 .55664 .73075 .56218 .74109 .55918 .7364 .55361 Mtetra
.7364 .55361 .74109 .55918 .75147 .55617 .7468 .55058 Mtetra
.7468 .55058 .75147 .55617 .76189 .55315 .75725 .54754 Mtetra
.75725 .54754 .76189 .55315 .77234 .55012 .76773 .54449 Mtetra
.76773 .54449 .77234 .55012 .78284 .54707 .77825 .54142 Mtetra
.77825 .54142 .78284 .54707 .79337 .54401 .78881 .53834 Mtetra
.78881 .53834 .79337 .54401 .80394 .54095 .79941 .53526 Mtetra
.79941 .53526 .80394 .54095 .81455 .53787 .81005 .53216 Mtetra
.81005 .53216 .81455 .53787 .8252 .53478 .82072 .52905 Mtetra
.82072 .52905 .8252 .53478 .83589 .53168 .83144 .52592 Mtetra
.83144 .52592 .83589 .53168 .84661 .52857 .84219 .52279 Mtetra
.84219 .52279 .84661 .52857 .85738 .52544 .85299 .51964 Mtetra
.85299 .51964 .85738 .52544 .86819 .52231 .86383 .51649 Mtetra
.86383 .51649 .86819 .52231 .87903 .51916 .8747 .51332 Mtetra
.8747 .51332 .87903 .51916 .88992 .516 .88562 .51014 Mtetra
.88562 .51014 .88992 .516 .90085 .51283 .89658 .50694 Mtetra
.89658 .50694 .90085 .51283 .91182 .50965 .90758 .50374 Mtetra
.90758 .50374 .91182 .50965 .92283 .50645 .91862 .50052 Mtetra
.91862 .50052 .92283 .50645 .93388 .50324 .9297 .49729 Mtetra
.9297 .49729 .93388 .50324 .94497 .50003 .94082 .49405 Mtetra
.94082 .49405 .94497 .50003 .9561 .4968 .95198 .4908 Mtetra
.35253 .65894 .35813 .66383 .3672 .66119 .36162 .65628 Mtetra
.36162 .65628 .3672 .66119 .3763 .65854 .37074 .65361 Mtetra
.37074 .65361 .3763 .65854 .38544 .65587 .3799 .65094 Mtetra
.3799 .65094 .38544 .65587 .3946 .6532 .38908 .64825 Mtetra
.38908 .64825 .3946 .6532 .4038 .65052 .3983 .64555 Mtetra
.3983 .64555 .4038 .65052 .41303 .64783 .40755 .64285 Mtetra
.40755 .64285 .41303 .64783 .42229 .64514 .41683 .64013 Mtetra
.41683 .64013 .42229 .64514 .43158 .64243 .42614 .63741 Mtetra
.42614 .63741 .43158 .64243 .4409 .63971 .43548 .63467 Mtetra
.43548 .63467 .4409 .63971 .45026 .63699 .44486 .63193 Mtetra
.44486 .63193 .45026 .63699 .45965 .63425 .45427 .62918 Mtetra
.45427 .62918 .45965 .63425 .46907 .63151 .46371 .62641 Mtetra
.46371 .62641 .46907 .63151 .47853 .62875 .47319 .62364 Mtetra
.47319 .62364 .47853 .62875 .48801 .62599 .48269 .62086 Mtetra
.48269 .62086 .48801 .62599 .49753 .62321 .49224 .61807 Mtetra
.49224 .61807 .49753 .62321 .50709 .62043 .50181 .61527 Mtetra
.50181 .61527 .50709 .62043 .51667 .61764 .51142 .61245 Mtetra
.51142 .61245 .51667 .61764 .52629 .61483 .52106 .60963 Mtetra
.52106 .60963 .52629 .61483 .53595 .61202 .53074 .6068 Mtetra
.53074 .6068 .53595 .61202 .54563 .6092 .54045 .60396 Mtetra
.54045 .60396 .54563 .6092 .55536 .60636 .55019 .60111 Mtetra
.55019 .60111 .55536 .60636 .56511 .60352 .55997 .59825 Mtetra
.55997 .59825 .56511 .60352 .5749 .60067 .56978 .59538 Mtetra
.56978 .59538 .5749 .60067 .58473 .59781 .57963 .59249 Mtetra
.57963 .59249 .58473 .59781 .59459 .59493 .58952 .5896 Mtetra
.58952 .5896 .59459 .59493 .60448 .59205 .59944 .5867 Mtetra
.59944 .5867 .60448 .59205 .61441 .58916 .60939 .58379 Mtetra
.60939 .58379 .61441 .58916 .62438 .58625 .61938 .58087 Mtetra
.61938 .58087 .62438 .58625 .63438 .58334 .62941 .57793 Mtetra
.62941 .57793 .63438 .58334 .64442 .58041 .63947 .57499 Mtetra
.63947 .57499 .64442 .58041 .65449 .57748 .64957 .57203 Mtetra
.64957 .57203 .65449 .57748 .6646 .57453 .6597 .56907 Mtetra
.6597 .56907 .6646 .57453 .67475 .57158 .66987 .56609 Mtetra
.66987 .56609 .67475 .57158 .68493 .56861 .68008 .56311 Mtetra
.68008 .56311 .68493 .56861 .69515 .56563 .69032 .56011 Mtetra
.69032 .56011 .69515 .56563 .70541 .56264 .7006 .5571 Mtetra
.7006 .5571 .70541 .56264 .7157 .55965 .71092 .55408 Mtetra
.71092 .55408 .7157 .55965 .72603 .55664 .72128 .55105 Mtetra
.72128 .55105 .72603 .55664 .7364 .55361 .73168 .54801 Mtetra
.73168 .54801 .7364 .55361 .7468 .55058 .74211 .54496 Mtetra
.74211 .54496 .7468 .55058 .75725 .54754 .75258 .54189 Mtetra
.75258 .54189 .75725 .54754 .76773 .54449 .76309 .53882 Mtetra
.76309 .53882 .76773 .54449 .77825 .54142 .77364 .53573 Mtetra
.77364 .53573 .77825 .54142 .78881 .53834 .78422 .53263 Mtetra
.78422 .53263 .78881 .53834 .79941 .53526 .79485 .52952 Mtetra
.79485 .52952 .79941 .53526 .81005 .53216 .80551 .5264 Mtetra
.80551 .5264 .81005 .53216 .82072 .52905 .81622 .52327 Mtetra
.81622 .52327 .82072 .52905 .83144 .52592 .82696 .52013 Mtetra
.82696 .52013 .83144 .52592 .84219 .52279 .83775 .51697 Mtetra
.83775 .51697 .84219 .52279 .85299 .51964 .84857 .51381 Mtetra
.84857 .51381 .85299 .51964 .86383 .51649 .85944 .51063 Mtetra
.85944 .51063 .86383 .51649 .8747 .51332 .87034 .50744 Mtetra
.87034 .50744 .8747 .51332 .88562 .51014 .88129 .50423 Mtetra
.88129 .50423 .88562 .51014 .89658 .50694 .89227 .50102 Mtetra
.89227 .50102 .89658 .50694 .90758 .50374 .9033 .49779 Mtetra
.9033 .49779 .90758 .50374 .91862 .50052 .91437 .49455 Mtetra
.91437 .49455 .91862 .50052 .9297 .49729 .92549 .4913 Mtetra
.92549 .4913 .9297 .49729 .94082 .49405 .93664 .48804 Mtetra
.93664 .48804 .94082 .49405 .95198 .4908 .94784 .48476 Mtetra
.34689 .65403 .35253 .65894 .36162 .65628 .356 .65135 Mtetra
.356 .65135 .36162 .65628 .37074 .65361 .36515 .64866 Mtetra
.36515 .64866 .37074 .65361 .3799 .65094 .37432 .64597 Mtetra
.37432 .64597 .3799 .65094 .38908 .64825 .38352 .64326 Mtetra
.38352 .64326 .38908 .64825 .3983 .64555 .39276 .64055 Mtetra
.39276 .64055 .3983 .64555 .40755 .64285 .40203 .63783 Mtetra
.40203 .63783 .40755 .64285 .41683 .64013 .41133 .63509 Mtetra
.41133 .63509 .41683 .64013 .42614 .63741 .42066 .63235 Mtetra
.42066 .63235 .42614 .63741 .43548 .63467 .43003 .6296 Mtetra
.43003 .6296 .43548 .63467 .44486 .63193 .43942 .62684 Mtetra
.43942 .62684 .44486 .63193 .45427 .62918 .44885 .62407 Mtetra
.44885 .62407 .45427 .62918 .46371 .62641 .45832 .62129 Mtetra
.45832 .62129 .46371 .62641 .47319 .62364 .46781 .6185 Mtetra
.46781 .6185 .47319 .62364 .48269 .62086 .47734 .6157 Mtetra
.47734 .6157 .48269 .62086 .49224 .61807 .4869 .61289 Mtetra
.4869 .61289 .49224 .61807 .50181 .61527 .4965 .61007 Mtetra
.4965 .61007 .50181 .61527 .51142 .61245 .50613 .60724 Mtetra
.50613 .60724 .51142 .61245 .52106 .60963 .5158 .6044 Mtetra
.5158 .6044 .52106 .60963 .53074 .6068 .52549 .60155 Mtetra
.52549 .60155 .53074 .6068 .54045 .60396 .53523 .59869 Mtetra
.53523 .59869 .54045 .60396 .55019 .60111 .54499 .59582 Mtetra
.54499 .59582 .55019 .60111 .55997 .59825 .5548 .59294 Mtetra
.5548 .59294 .55997 .59825 .56978 .59538 .56463 .59005 Mtetra
.56463 .59005 .56978 .59538 .57963 .59249 .5745 .58715 Mtetra
.5745 .58715 .57963 .59249 .58952 .5896 .58441 .58424 Mtetra
.58441 .58424 .58952 .5896 .59944 .5867 .59435 .58132 Mtetra
.59435 .58132 .59944 .5867 .60939 .58379 .60433 .57838 Mtetra
.60433 .57838 .60939 .58379 .61938 .58087 .61435 .57544 Mtetra
.61435 .57544 .61938 .58087 .62941 .57793 .6244 .57249 Mtetra
.6244 .57249 .62941 .57793 .63947 .57499 .63448 .56952 Mtetra
.63448 .56952 .63947 .57499 .64957 .57203 .6446 .56655 Mtetra
.6446 .56655 .64957 .57203 .6597 .56907 .65476 .56357 Mtetra
.65476 .56357 .6597 .56907 .66987 .56609 .66496 .56057 Mtetra
.66496 .56057 .66987 .56609 .68008 .56311 .67519 .55756 Mtetra
.67519 .55756 .68008 .56311 .69032 .56011 .68546 .55455 Mtetra
.68546 .55455 .69032 .56011 .7006 .5571 .69577 .55152 Mtetra
.69577 .55152 .7006 .5571 .71092 .55408 .70612 .54848 Mtetra
.70612 .54848 .71092 .55408 .72128 .55105 .7165 .54543 Mtetra
.7165 .54543 .72128 .55105 .73168 .54801 .72692 .54236 Mtetra
.72692 .54236 .73168 .54801 .74211 .54496 .73738 .53929 Mtetra
.73738 .53929 .74211 .54496 .75258 .54189 .74788 .53621 Mtetra
.74788 .53621 .75258 .54189 .76309 .53882 .75841 .53311 Mtetra
.75841 .53311 .76309 .53882 .77364 .53573 .76899 .53 Mtetra
.76899 .53 .77364 .53573 .78422 .53263 .7796 .52688 Mtetra
.7796 .52688 .78422 .53263 .79485 .52952 .79026 .52375 Mtetra
.79026 .52375 .79485 .52952 .80551 .5264 .80095 .52061 Mtetra
.80095 .52061 .80551 .5264 .81622 .52327 .81168 .51746 Mtetra
.81168 .51746 .81622 .52327 .82696 .52013 .82245 .51429 Mtetra
.82245 .51429 .82696 .52013 .83775 .51697 .83327 .51112 Mtetra
.83327 .51112 .83775 .51697 .84857 .51381 .84412 .50793 Mtetra
.84412 .50793 .84857 .51381 .85944 .51063 .85501 .50473 Mtetra
.85501 .50473 .85944 .51063 .87034 .50744 .86595 .50151 Mtetra
.86595 .50151 .87034 .50744 .88129 .50423 .87693 .49829 Mtetra
.87693 .49829 .88129 .50423 .89227 .50102 .88794 .49505 Mtetra
.88794 .49505 .89227 .50102 .9033 .49779 .899 .4918 Mtetra
.899 .4918 .9033 .49779 .91437 .49455 .9101 .48854 Mtetra
.9101 .48854 .91437 .49455 .92549 .4913 .92125 .48527 Mtetra
.92125 .48527 .92549 .4913 .93664 .48804 .93243 .48198 Mtetra
.93243 .48198 .93664 .48804 .94784 .48476 .94366 .47868 Mtetra
.34122 .64908 .34689 .65403 .356 .65135 .35035 .64638 Mtetra
.35035 .64638 .356 .65135 .36515 .64866 .35951 .64368 Mtetra
.35951 .64368 .36515 .64866 .37432 .64597 .36871 .64097 Mtetra
.36871 .64097 .37432 .64597 .38352 .64326 .37793 .63825 Mtetra
.37793 .63825 .38352 .64326 .39276 .64055 .38719 .63551 Mtetra
.38719 .63551 .39276 .64055 .40203 .63783 .39647 .63277 Mtetra
.39647 .63277 .40203 .63783 .41133 .63509 .40579 .63002 Mtetra
.40579 .63002 .41133 .63509 .42066 .63235 .41515 .62726 Mtetra
.41515 .62726 .42066 .63235 .43003 .6296 .42453 .62449 Mtetra
.42453 .62449 .43003 .6296 .43942 .62684 .43395 .62172 Mtetra
.43395 .62172 .43942 .62684 .44885 .62407 .4434 .61893 Mtetra
.4434 .61893 .44885 .62407 .45832 .62129 .45289 .61613 Mtetra
.45289 .61613 .45832 .62129 .46781 .6185 .4624 .61332 Mtetra
.4624 .61332 .46781 .6185 .47734 .6157 .47195 .6105 Mtetra
.47195 .6105 .47734 .6157 .4869 .61289 .48154 .60767 Mtetra
.48154 .60767 .4869 .61289 .4965 .61007 .49116 .60484 Mtetra
.49116 .60484 .4965 .61007 .50613 .60724 .50081 .60199 Mtetra
.50081 .60199 .50613 .60724 .5158 .6044 .5105 .59913 Mtetra
.5105 .59913 .5158 .6044 .52549 .60155 .52022 .59626 Mtetra
.52022 .59626 .52549 .60155 .53523 .59869 .52997 .59338 Mtetra
.52997 .59338 .53523 .59869 .54499 .59582 .53976 .59049 Mtetra
.53976 .59049 .54499 .59582 .5548 .59294 .54959 .58759 Mtetra
.54959 .58759 .5548 .59294 .56463 .59005 .55945 .58469 Mtetra
.55945 .58469 .56463 .59005 .5745 .58715 .56934 .58177 Mtetra
.56934 .58177 .5745 .58715 .58441 .58424 .57927 .57884 Mtetra
.57927 .57884 .58441 .58424 .59435 .58132 .58924 .57589 Mtetra
.58924 .57589 .59435 .58132 .60433 .57838 .59924 .57294 Mtetra
.59924 .57294 .60433 .57838 .61435 .57544 .60928 .56998 Mtetra
.60928 .56998 .61435 .57544 .6244 .57249 .61935 .56701 Mtetra
.61935 .56701 .6244 .57249 .63448 .56952 .62946 .56403 Mtetra
.62946 .56403 .63448 .56952 .6446 .56655 .63961 .56103 Mtetra
.63961 .56103 .6446 .56655 .65476 .56357 .64979 .55803 Mtetra
.64979 .55803 .65476 .56357 .66496 .56057 .66002 .55501 Mtetra
.66002 .55501 .66496 .56057 .67519 .55756 .67027 .55198 Mtetra
.67027 .55198 .67519 .55756 .68546 .55455 .68057 .54895 Mtetra
.68057 .54895 .68546 .55455 .69577 .55152 .6909 .5459 Mtetra
.6909 .5459 .69577 .55152 .70612 .54848 .70127 .54284 Mtetra
.70127 .54284 .70612 .54848 .7165 .54543 .71168 .53976 Mtetra
.71168 .53976 .7165 .54543 .72692 .54236 .72213 .53668 Mtetra
.72213 .53668 .72692 .54236 .73738 .53929 .73262 .53359 Mtetra
.73262 .53359 .73738 .53929 .74788 .53621 .74314 .53048 Mtetra
.74314 .53048 .74788 .53621 .75841 .53311 .75371 .52737 Mtetra
.75371 .52737 .75841 .53311 .76899 .53 .76431 .52424 Mtetra
.76431 .52424 .76899 .53 .7796 .52688 .77495 .5211 Mtetra
.77495 .5211 .7796 .52688 .79026 .52375 .78563 .51794 Mtetra
.78563 .51794 .79026 .52375 .80095 .52061 .79635 .51478 Mtetra
.79635 .51478 .80095 .52061 .81168 .51746 .80711 .51161 Mtetra
.80711 .51161 .81168 .51746 .82245 .51429 .81792 .50842 Mtetra
.81792 .50842 .82245 .51429 .83327 .51112 .82876 .50522 Mtetra
.82876 .50522 .83327 .51112 .84412 .50793 .83964 .50201 Mtetra
.83964 .50201 .84412 .50793 .85501 .50473 .85056 .49879 Mtetra
.85056 .49879 .85501 .50473 .86595 .50151 .86153 .49555 Mtetra
.86153 .49555 .86595 .50151 .87693 .49829 .87253 .4923 Mtetra
.87253 .4923 .87693 .49829 .88794 .49505 .88358 .48904 Mtetra
.88358 .48904 .88794 .49505 .899 .4918 .89467 .48577 Mtetra
.89467 .48577 .899 .4918 .9101 .48854 .9058 .48249 Mtetra
.9058 .48249 .9101 .48854 .92125 .48527 .91698 .47919 Mtetra
.91698 .47919 .92125 .48527 .93243 .48198 .92819 .47588 Mtetra
.92819 .47588 .93243 .48198 .94366 .47868 .93945 .47256 Mtetra
.33552 .6441 .34122 .64908 .35035 .64638 .34467 .64139 Mtetra
.34467 .64139 .35035 .64638 .35951 .64368 .35385 .63866 Mtetra
.35385 .63866 .35951 .64368 .36871 .64097 .36306 .63594 Mtetra
.36306 .63594 .36871 .64097 .37793 .63825 .3723 .6332 Mtetra
.3723 .6332 .37793 .63825 .38719 .63551 .38158 .63045 Mtetra
.38158 .63045 .38719 .63551 .39647 .63277 .39089 .62769 Mtetra
.39089 .62769 .39647 .63277 .40579 .63002 .40023 .62492 Mtetra
.40023 .62492 .40579 .63002 .41515 .62726 .4096 .62214 Mtetra
.4096 .62214 .41515 .62726 .42453 .62449 .41901 .61936 Mtetra
.41901 .61936 .42453 .62449 .43395 .62172 .42844 .61656 Mtetra
.42844 .61656 .43395 .62172 .4434 .61893 .43792 .61375 Mtetra
.43792 .61375 .4434 .61893 .45289 .61613 .44742 .61094 Mtetra
.44742 .61094 .45289 .61613 .4624 .61332 .45696 .60811 Mtetra
.45696 .60811 .4624 .61332 .47195 .6105 .46653 .60527 Mtetra
.46653 .60527 .47195 .6105 .48154 .60767 .47614 .60243 Mtetra
.47614 .60243 .48154 .60767 .49116 .60484 .48578 .59957 Mtetra
.48578 .59957 .49116 .60484 .50081 .60199 .49545 .5967 Mtetra
.49545 .5967 .50081 .60199 .5105 .59913 .50516 .59383 Mtetra
.50516 .59383 .5105 .59913 .52022 .59626 .5149 .59094 Mtetra
.5149 .59094 .52022 .59626 .52997 .59338 .52468 .58804 Mtetra
.52468 .58804 .52997 .59338 .53976 .59049 .5345 .58513 Mtetra
.5345 .58513 .53976 .59049 .54959 .58759 .54434 .58222 Mtetra
.54434 .58222 .54959 .58759 .55945 .58469 .55423 .57929 Mtetra
.55423 .57929 .55945 .58469 .56934 .58177 .56414 .57635 Mtetra
.56414 .57635 .56934 .58177 .57927 .57884 .5741 .5734 Mtetra
.5741 .5734 .57927 .57884 .58924 .57589 .58409 .57044 Mtetra
.58409 .57044 .58924 .57589 .59924 .57294 .59412 .56747 Mtetra
.59412 .56747 .59924 .57294 .60928 .56998 .60418 .56449 Mtetra
.60418 .56449 .60928 .56998 .61935 .56701 .61428 .56149 Mtetra
.61428 .56149 .61935 .56701 .62946 .56403 .62441 .55849 Mtetra
.62441 .55849 .62946 .56403 .63961 .56103 .63458 .55547 Mtetra
.63458 .55547 .63961 .56103 .64979 .55803 .64479 .55245 Mtetra
.64479 .55245 .64979 .55803 .66002 .55501 .65504 .54941 Mtetra
.65504 .54941 .66002 .55501 .67027 .55198 .66532 .54637 Mtetra
.66532 .54637 .67027 .55198 .68057 .54895 .67564 .54331 Mtetra
.67564 .54331 .68057 .54895 .6909 .5459 .686 .54024 Mtetra
.686 .54024 .6909 .5459 .70127 .54284 .6964 .53716 Mtetra
.6964 .53716 .70127 .54284 .71168 .53976 .70684 .53406 Mtetra
.70684 .53406 .71168 .53976 .72213 .53668 .71731 .53096 Mtetra
.71731 .53096 .72213 .53668 .73262 .53359 .72782 .52785 Mtetra
.72782 .52785 .73262 .53359 .74314 .53048 .73838 .52472 Mtetra
.73838 .52472 .74314 .53048 .75371 .52737 .74897 .52158 Mtetra
.74897 .52158 .75371 .52737 .76431 .52424 .7596 .51843 Mtetra
.7596 .51843 .76431 .52424 .77495 .5211 .77027 .51527 Mtetra
.77027 .51527 .77495 .5211 .78563 .51794 .78098 .5121 Mtetra
.78098 .5121 .78563 .51794 .79635 .51478 .79173 .50891 Mtetra
.79173 .50891 .79635 .51478 .80711 .51161 .80251 .50571 Mtetra
.80251 .50571 .80711 .51161 .81792 .50842 .81335 .5025 Mtetra
.81335 .5025 .81792 .50842 .82876 .50522 .82422 .49928 Mtetra
.82422 .49928 .82876 .50522 .83964 .50201 .83513 .49605 Mtetra
.83513 .49605 .83964 .50201 .85056 .49879 .84608 .4928 Mtetra
.84608 .4928 .85056 .49879 .86153 .49555 .85707 .48955 Mtetra
.85707 .48955 .86153 .49555 .87253 .4923 .86811 .48627 Mtetra
.86811 .48627 .87253 .4923 .88358 .48904 .87919 .48299 Mtetra
.87919 .48299 .88358 .48904 .89467 .48577 .89031 .4797 Mtetra
.89031 .4797 .89467 .48577 .9058 .48249 .90147 .47639 Mtetra
.90147 .47639 .9058 .48249 .91698 .47919 .91268 .47307 Mtetra
.91268 .47307 .91698 .47919 .92819 .47588 .92392 .46974 Mtetra
.92392 .46974 .92819 .47588 .93945 .47256 .93521 .46639 Mtetra
.32977 .63908 .33552 .6441 .34467 .64139 .33894 .63636 Mtetra
.33894 .63636 .34467 .64139 .35385 .63866 .34814 .63362 Mtetra
.34814 .63362 .35385 .63866 .36306 .63594 .35737 .63087 Mtetra
.35737 .63087 .36306 .63594 .3723 .6332 .36664 .62811 Mtetra
.36664 .62811 .3723 .6332 .38158 .63045 .37593 .62535 Mtetra
.37593 .62535 .38158 .63045 .39089 .62769 .38526 .62257 Mtetra
.38526 .62257 .39089 .62769 .40023 .62492 .39462 .61979 Mtetra
.39462 .61979 .40023 .62492 .4096 .62214 .40402 .61699 Mtetra
.40402 .61699 .4096 .62214 .41901 .61936 .41344 .61418 Mtetra
.41344 .61418 .41901 .61936 .42844 .61656 .4229 .61137 Mtetra
.4229 .61137 .42844 .61656 .43792 .61375 .43239 .60854 Mtetra
.43239 .60854 .43792 .61375 .44742 .61094 .44192 .60571 Mtetra
.44192 .60571 .44742 .61094 .45696 .60811 .45148 .60286 Mtetra
.45148 .60286 .45696 .60811 .46653 .60527 .46108 .60001 Mtetra
.46108 .60001 .46653 .60527 .47614 .60243 .4707 .59714 Mtetra
.4707 .59714 .47614 .60243 .48578 .59957 .48037 .59427 Mtetra
.48037 .59427 .48578 .59957 .49545 .5967 .49006 .59138 Mtetra
.49006 .59138 .49545 .5967 .50516 .59383 .49979 .58849 Mtetra
.49979 .58849 .50516 .59383 .5149 .59094 .50956 .58558 Mtetra
.50956 .58558 .5149 .59094 .52468 .58804 .51936 .58267 Mtetra
.51936 .58267 .52468 .58804 .5345 .58513 .52919 .57974 Mtetra
.52919 .57974 .5345 .58513 .54434 .58222 .53907 .5768 Mtetra
.53907 .5768 .54434 .58222 .55423 .57929 .54897 .57385 Mtetra
.54897 .57385 .55423 .57929 .56414 .57635 .55891 .57089 Mtetra
.55891 .57089 .56414 .57635 .5741 .5734 .56889 .56792 Mtetra
.56889 .56792 .5741 .5734 .58409 .57044 .57891 .56494 Mtetra
.57891 .56494 .58409 .57044 .59412 .56747 .58896 .56195 Mtetra
.58896 .56195 .59412 .56747 .60418 .56449 .59904 .55895 Mtetra
.59904 .55895 .60418 .56449 .61428 .56149 .60917 .55594 Mtetra
.60917 .55594 .61428 .56149 .62441 .55849 .61933 .55292 Mtetra
.61933 .55292 .62441 .55849 .63458 .55547 .62952 .54988 Mtetra
.62952 .54988 .63458 .55547 .64479 .55245 .63976 .54684 Mtetra
.63976 .54684 .64479 .55245 .65504 .54941 .65003 .54378 Mtetra
.65003 .54378 .65504 .54941 .66532 .54637 .66034 .54071 Mtetra
.66034 .54071 .66532 .54637 .67564 .54331 .67069 .53763 Mtetra
.67069 .53763 .67564 .54331 .686 .54024 .68107 .53454 Mtetra
.68107 .53454 .686 .54024 .6964 .53716 .69149 .53144 Mtetra
.69149 .53144 .6964 .53716 .70684 .53406 .70196 .52833 Mtetra
.70196 .52833 .70684 .53406 .71731 .53096 .71246 .5252 Mtetra
.71246 .5252 .71731 .53096 .72782 .52785 .723 .52206 Mtetra
.723 .52206 .72782 .52785 .73838 .52472 .73358 .51892 Mtetra
.73358 .51892 .73838 .52472 .74897 .52158 .74419 .51576 Mtetra
.74419 .51576 .74897 .52158 .7596 .51843 .75485 .51258 Mtetra
.75485 .51258 .7596 .51843 .77027 .51527 .76555 .5094 Mtetra
.76555 .5094 .77027 .51527 .78098 .5121 .77629 .50621 Mtetra
.77629 .50621 .78098 .5121 .79173 .50891 .78707 .503 Mtetra
.78707 .503 .79173 .50891 .80251 .50571 .79788 .49978 Mtetra
.79788 .49978 .80251 .50571 .81335 .5025 .80874 .49655 Mtetra
.80874 .49655 .81335 .5025 .82422 .49928 .81964 .4933 Mtetra
.81964 .4933 .82422 .49928 .83513 .49605 .83058 .49005 Mtetra
.83058 .49005 .83513 .49605 .84608 .4928 .84157 .48678 Mtetra
.84157 .48678 .84608 .4928 .85707 .48955 .85259 .4835 Mtetra
.85259 .4835 .85707 .48955 .86811 .48627 .86366 .4802 Mtetra
.86366 .4802 .86811 .48627 .87919 .48299 .87477 .4769 Mtetra
.87477 .4769 .87919 .48299 .89031 .4797 .88592 .47358 Mtetra
.88592 .47358 .89031 .4797 .90147 .47639 .89711 .47025 Mtetra
.89711 .47025 .90147 .47639 .91268 .47307 .90834 .46691 Mtetra
.90834 .46691 .91268 .47307 .92392 .46974 .91962 .46355 Mtetra
.91962 .46355 .92392 .46974 .93521 .46639 .93095 .46018 Mtetra
.32399 .63404 .32977 .63908 .33894 .63636 .33318 .63129 Mtetra
.33318 .63129 .33894 .63636 .34814 .63362 .3424 .62854 Mtetra
.3424 .62854 .34814 .63362 .35737 .63087 .35165 .62577 Mtetra
.35165 .62577 .35737 .63087 .36664 .62811 .36094 .623 Mtetra
.36094 .623 .36664 .62811 .37593 .62535 .37025 .62021 Mtetra
.37025 .62021 .37593 .62535 .38526 .62257 .3796 .61742 Mtetra
.3796 .61742 .38526 .62257 .39462 .61979 .38898 .61462 Mtetra
.38898 .61462 .39462 .61979 .40402 .61699 .3984 .6118 Mtetra
.3984 .6118 .40402 .61699 .41344 .61418 .40784 .60898 Mtetra
.40784 .60898 .41344 .61418 .4229 .61137 .41732 .60615 Mtetra
.41732 .60615 .4229 .61137 .43239 .60854 .42684 .6033 Mtetra
.42684 .6033 .43239 .60854 .44192 .60571 .43639 .60045 Mtetra
.43639 .60045 .44192 .60571 .45148 .60286 .44597 .59759 Mtetra
.44597 .59759 .45148 .60286 .46108 .60001 .45558 .59471 Mtetra
.45558 .59471 .46108 .60001 .4707 .59714 .46523 .59183 Mtetra
.46523 .59183 .4707 .59714 .48037 .59427 .47492 .58893 Mtetra
.47492 .58893 .48037 .59427 .49006 .59138 .48463 .58603 Mtetra
.48463 .58603 .49006 .59138 .49979 .58849 .49439 .58311 Mtetra
.49439 .58311 .49979 .58849 .50956 .58558 .50418 .58019 Mtetra
.50418 .58019 .50956 .58558 .51936 .58267 .514 .57725 Mtetra
.514 .57725 .51936 .58267 .52919 .57974 .52386 .57431 Mtetra
.52386 .57431 .52919 .57974 .53907 .5768 .53375 .57135 Mtetra
.53375 .57135 .53907 .5768 .54897 .57385 .54368 .56838 Mtetra
.54368 .56838 .54897 .57385 .55891 .57089 .55365 .5654 Mtetra
.55365 .5654 .55891 .57089 .56889 .56792 .56365 .56241 Mtetra
.56365 .56241 .56889 .56792 .57891 .56494 .57369 .55941 Mtetra
.57369 .55941 .57891 .56494 .58896 .56195 .58376 .5564 Mtetra
.58376 .5564 .58896 .56195 .59904 .55895 .59387 .55338 Mtetra
.59387 .55338 .59904 .55895 .60917 .55594 .60402 .55035 Mtetra
.60402 .55035 .60917 .55594 .61933 .55292 .61421 .5473 Mtetra
.61421 .5473 .61933 .55292 .62952 .54988 .62443 .54425 Mtetra
.62443 .54425 .62952 .54988 .63976 .54684 .63469 .54118 Mtetra
.63469 .54118 .63976 .54684 .65003 .54378 .64498 .53811 Mtetra
.64498 .53811 .65003 .54378 .66034 .54071 .65532 .53502 Mtetra
.65532 .53502 .66034 .54071 .67069 .53763 .66569 .53192 Mtetra
.66569 .53192 .67069 .53763 .68107 .53454 .6761 .52881 Mtetra
.6761 .52881 .68107 .53454 .69149 .53144 .68655 .52568 Mtetra
.68655 .52568 .69149 .53144 .70196 .52833 .69704 .52255 Mtetra
.69704 .52255 .70196 .52833 .71246 .5252 .70757 .5194 Mtetra
.70757 .5194 .71246 .5252 .723 .52206 .71814 .51624 Mtetra
.71814 .51624 .723 .52206 .73358 .51892 .72874 .51307 Mtetra
.72874 .51307 .73358 .51892 .74419 .51576 .73939 .50989 Mtetra
.73939 .50989 .74419 .51576 .75485 .51258 .75008 .5067 Mtetra
.75008 .5067 .75485 .51258 .76555 .5094 .7608 .50349 Mtetra
.7608 .50349 .76555 .5094 .77629 .50621 .77157 .50027 Mtetra
.77157 .50027 .77629 .50621 .78707 .503 .78237 .49704 Mtetra
.78237 .49704 .78707 .503 .79788 .49978 .79322 .4938 Mtetra
.79322 .4938 .79788 .49978 .80874 .49655 .80411 .49055 Mtetra
.80411 .49055 .80874 .49655 .81964 .4933 .81504 .48728 Mtetra
.81504 .48728 .81964 .4933 .83058 .49005 .82601 .484 Mtetra
.82601 .484 .83058 .49005 .84157 .48678 .83702 .48071 Mtetra
.83702 .48071 .84157 .48678 .85259 .4835 .84808 .47741 Mtetra
.84808 .47741 .85259 .4835 .86366 .4802 .85917 .47409 Mtetra
.85917 .47409 .86366 .4802 .87477 .4769 .87031 .47076 Mtetra
.87031 .47076 .87477 .4769 .88592 .47358 .88149 .46742 Mtetra
.88149 .46742 .88592 .47358 .89711 .47025 .89272 .46407 Mtetra
.89272 .46407 .89711 .47025 .90834 .46691 .90398 .4607 Mtetra
.90398 .4607 .90834 .46691 .91962 .46355 .91529 .45732 Mtetra
.91529 .45732 .91962 .46355 .93095 .46018 .92665 .45393 Mtetra
.31818 .62896 .32399 .63404 .33318 .63129 .32738 .6262 Mtetra
.32738 .6262 .33318 .63129 .3424 .62854 .33662 .62343 Mtetra
.33662 .62343 .3424 .62854 .35165 .62577 .34589 .62064 Mtetra
.34589 .62064 .35165 .62577 .36094 .623 .3552 .61785 Mtetra
.3552 .61785 .36094 .623 .37025 .62021 .36453 .61505 Mtetra
.36453 .61505 .37025 .62021 .3796 .61742 .3739 .61224 Mtetra
.3739 .61224 .3796 .61742 .38898 .61462 .3833 .60942 Mtetra
.3833 .60942 .38898 .61462 .3984 .6118 .39274 .60658 Mtetra
.39274 .60658 .3984 .6118 .40784 .60898 .40221 .60374 Mtetra
.40221 .60374 .40784 .60898 .41732 .60615 .41171 .60089 Mtetra
.41171 .60089 .41732 .60615 .42684 .6033 .42124 .59803 Mtetra
.42124 .59803 .42684 .6033 .43639 .60045 .43081 .59516 Mtetra
.43081 .59516 .43639 .60045 .44597 .59759 .44042 .59227 Mtetra
.44042 .59227 .44597 .59759 .45558 .59471 .45005 .58938 Mtetra
.45005 .58938 .45558 .59471 .46523 .59183 .45972 .58648 Mtetra
.45972 .58648 .46523 .59183 .47492 .58893 .46943 .58356 Mtetra
.46943 .58356 .47492 .58893 .48463 .58603 .47917 .58064 Mtetra
.47917 .58064 .48463 .58603 .49439 .58311 .48895 .57771 Mtetra
.48895 .57771 .49439 .58311 .50418 .58019 .49876 .57476 Mtetra
.49876 .57476 .50418 .58019 .514 .57725 .5086 .57181 Mtetra
.5086 .57181 .514 .57725 .52386 .57431 .51849 .56884 Mtetra
.51849 .56884 .52386 .57431 .53375 .57135 .5284 .56586 Mtetra
.5284 .56586 .53375 .57135 .54368 .56838 .53836 .56288 Mtetra
.53836 .56288 .54368 .56838 .55365 .5654 .54835 .55988 Mtetra
.54835 .55988 .55365 .5654 .56365 .56241 .55837 .55687 Mtetra
.55837 .55687 .56365 .56241 .57369 .55941 .56843 .55385 Mtetra
.56843 .55385 .57369 .55941 .58376 .5564 .57853 .55082 Mtetra
.57853 .55082 .58376 .5564 .59387 .55338 .58867 .54777 Mtetra
.58867 .54777 .59387 .55338 .60402 .55035 .59884 .54472 Mtetra
.59884 .54472 .60402 .55035 .61421 .5473 .60905 .54166 Mtetra
.60905 .54166 .61421 .5473 .62443 .54425 .6193 .53858 Mtetra
.6193 .53858 .62443 .54425 .63469 .54118 .62958 .53549 Mtetra
.62958 .53549 .63469 .54118 .64498 .53811 .63991 .53239 Mtetra
.63991 .53239 .64498 .53811 .65532 .53502 .65027 .52928 Mtetra
.65027 .52928 .65532 .53502 .66569 .53192 .66067 .52616 Mtetra
.66067 .52616 .66569 .53192 .6761 .52881 .6711 .52303 Mtetra
.6711 .52303 .6761 .52881 .68655 .52568 .68158 .51989 Mtetra
.68158 .51989 .68655 .52568 .69704 .52255 .6921 .51673 Mtetra
.6921 .51673 .69704 .52255 .70757 .5194 .70265 .51356 Mtetra
.70265 .51356 .70757 .5194 .71814 .51624 .71324 .51038 Mtetra
.71324 .51038 .71814 .51624 .72874 .51307 .72388 .50719 Mtetra
.72388 .50719 .72874 .51307 .73939 .50989 .73455 .50399 Mtetra
.73455 .50399 .73939 .50989 .75008 .5067 .74527 .50077 Mtetra
.74527 .50077 .75008 .5067 .7608 .50349 .75602 .49754 Mtetra
.75602 .49754 .7608 .50349 .77157 .50027 .76681 .4943 Mtetra
.76681 .4943 .77157 .50027 .78237 .49704 .77765 .49105 Mtetra
.77765 .49105 .78237 .49704 .79322 .4938 .78852 .48779 Mtetra
.78852 .48779 .79322 .4938 .80411 .49055 .79944 .48451 Mtetra
.79944 .48451 .80411 .49055 .81504 .48728 .8104 .48122 Mtetra
.8104 .48122 .81504 .48728 .82601 .484 .8214 .47792 Mtetra
.8214 .47792 .82601 .484 .83702 .48071 .83244 .4746 Mtetra
.83244 .4746 .83702 .48071 .84808 .47741 .84353 .47128 Mtetra
.84353 .47128 .84808 .47741 .85917 .47409 .85465 .46794 Mtetra
.85465 .46794 .85917 .47409 .87031 .47076 .86582 .46458 Mtetra
.86582 .46458 .87031 .47076 .88149 .46742 .87704 .46122 Mtetra
.87704 .46122 .88149 .46742 .89272 .46407 .88829 .45784 Mtetra
.88829 .45784 .89272 .46407 .90398 .4607 .89959 .45445 Mtetra
.89959 .45445 .90398 .4607 .91529 .45732 .91093 .45104 Mtetra
.91093 .45104 .91529 .45732 .92665 .45393 .92232 .44763 Mtetra
.31232 .62385 .31818 .62896 .32738 .6262 .32155 .62107 Mtetra
.32155 .62107 .32738 .6262 .33662 .62343 .33081 .61828 Mtetra
.33081 .61828 .33662 .62343 .34589 .62064 .3401 .61548 Mtetra
.3401 .61548 .34589 .62064 .3552 .61785 .34942 .61267 Mtetra
.34942 .61267 .3552 .61785 .36453 .61505 .35878 .60985 Mtetra
.35878 .60985 .36453 .61505 .3739 .61224 .36817 .60702 Mtetra
.36817 .60702 .3739 .61224 .3833 .60942 .37759 .60418 Mtetra
.37759 .60418 .3833 .60942 .39274 .60658 .38704 .60133 Mtetra
.38704 .60133 .39274 .60658 .40221 .60374 .39653 .59847 Mtetra
.39653 .59847 .40221 .60374 .41171 .60089 .40606 .5956 Mtetra
.40606 .5956 .41171 .60089 .42124 .59803 .41561 .59272 Mtetra
.41561 .59272 .42124 .59803 .43081 .59516 .4252 .58983 Mtetra
.4252 .58983 .43081 .59516 .44042 .59227 .43483 .58692 Mtetra
.43483 .58692 .44042 .59227 .45005 .58938 .44449 .58401 Mtetra
.44449 .58401 .45005 .58938 .45972 .58648 .45418 .58109 Mtetra
.45418 .58109 .45972 .58648 .46943 .58356 .46391 .57816 Mtetra
.46391 .57816 .46943 .58356 .47917 .58064 .47367 .57521 Mtetra
.47367 .57521 .47917 .58064 .48895 .57771 .48347 .57226 Mtetra
.48347 .57226 .48895 .57771 .49876 .57476 .4933 .5693 Mtetra
.4933 .5693 .49876 .57476 .5086 .57181 .50317 .56632 Mtetra
.50317 .56632 .5086 .57181 .51849 .56884 .51308 .56334 Mtetra
.51308 .56334 .51849 .56884 .5284 .56586 .52302 .56034 Mtetra
.52302 .56034 .5284 .56586 .53836 .56288 .533 .55733 Mtetra
.533 .55733 .53836 .56288 .54835 .55988 .54301 .55431 Mtetra
.54301 .55431 .54835 .55988 .55837 .55687 .55306 .55128 Mtetra
.55306 .55128 .55837 .55687 .56843 .55385 .56314 .54824 Mtetra
.56314 .54824 .56843 .55385 .57853 .55082 .57327 .54519 Mtetra
.57327 .54519 .57853 .55082 .58867 .54777 .58343 .54213 Mtetra
.58343 .54213 .58867 .54777 .59884 .54472 .59363 .53905 Mtetra
.59363 .53905 .59884 .54472 .60905 .54166 .60386 .53597 Mtetra
.60386 .53597 .60905 .54166 .6193 .53858 .61413 .53287 Mtetra
.61413 .53287 .6193 .53858 .62958 .53549 .62444 .52976 Mtetra
.62444 .52976 .62958 .53549 .63991 .53239 .63479 .52664 Mtetra
.63479 .52664 .63991 .53239 .65027 .52928 .64518 .52351 Mtetra
.64518 .52351 .65027 .52928 .66067 .52616 .6556 .52037 Mtetra
.6556 .52037 .66067 .52616 .6711 .52303 .66607 .51722 Mtetra
.66607 .51722 .6711 .52303 .68158 .51989 .67657 .51405 Mtetra
.67657 .51405 .68158 .51989 .6921 .51673 .68711 .51087 Mtetra
.68711 .51087 .6921 .51673 .70265 .51356 .6977 .50768 Mtetra
.6977 .50768 .70265 .51356 .71324 .51038 .70832 .50448 Mtetra
.70832 .50448 .71324 .51038 .72388 .50719 .71898 .50127 Mtetra
.71898 .50127 .72388 .50719 .73455 .50399 .72968 .49804 Mtetra
.72968 .49804 .73455 .50399 .74527 .50077 .74042 .4948 Mtetra
.74042 .4948 .74527 .50077 .75602 .49754 .7512 .49155 Mtetra
.7512 .49155 .75602 .49754 .76681 .4943 .76203 .48829 Mtetra
.76203 .48829 .76681 .4943 .77765 .49105 .77289 .48501 Mtetra
.77289 .48501 .77765 .49105 .78852 .48779 .7838 .48173 Mtetra
.7838 .48173 .78852 .48779 .79944 .48451 .79474 .47843 Mtetra
.79474 .47843 .79944 .48451 .8104 .48122 .80573 .47511 Mtetra
.80573 .47511 .8104 .48122 .8214 .47792 .81676 .47179 Mtetra
.81676 .47179 .8214 .47792 .83244 .4746 .82783 .46845 Mtetra
.82783 .46845 .83244 .4746 .84353 .47128 .83895 .4651 Mtetra
.83895 .4651 .84353 .47128 .85465 .46794 .85011 .46174 Mtetra
.85011 .46174 .85465 .46794 .86582 .46458 .86131 .45836 Mtetra
.86131 .45836 .86582 .46458 .87704 .46122 .87255 .45497 Mtetra
.87255 .45497 .87704 .46122 .88829 .45784 .88384 .45157 Mtetra
.88384 .45157 .88829 .45784 .89959 .45445 .89517 .44815 Mtetra
.89517 .44815 .89959 .45445 .91093 .45104 .90654 .44472 Mtetra
.90654 .44472 .91093 .45104 .92232 .44763 .91796 .44128 Mtetra
.30643 .61871 .31232 .62385 .32155 .62107 .31568 .61591 Mtetra
.31568 .61591 .32155 .62107 .33081 .61828 .32495 .6131 Mtetra
.32495 .6131 .33081 .61828 .3401 .61548 .33427 .61028 Mtetra
.33427 .61028 .3401 .61548 .34942 .61267 .34361 .60746 Mtetra
.34361 .60746 .34942 .61267 .35878 .60985 .35299 .60462 Mtetra
.35299 .60462 .35878 .60985 .36817 .60702 .36239 .60177 Mtetra
.36239 .60177 .36817 .60702 .37759 .60418 .37184 .59891 Mtetra
.37184 .59891 .37759 .60418 .38704 .60133 .38131 .59604 Mtetra
.38131 .59604 .38704 .60133 .39653 .59847 .39082 .59316 Mtetra
.39082 .59316 .39653 .59847 .40606 .5956 .40037 .59027 Mtetra
.40037 .59027 .40606 .5956 .41561 .59272 .40995 .58737 Mtetra
.40995 .58737 .41561 .59272 .4252 .58983 .41956 .58446 Mtetra
.41956 .58446 .4252 .58983 .43483 .58692 .4292 .58154 Mtetra
.4292 .58154 .43483 .58692 .44449 .58401 .43888 .57861 Mtetra
.43888 .57861 .44449 .58401 .45418 .58109 .4486 .57567 Mtetra
.4486 .57567 .45418 .58109 .46391 .57816 .45835 .57272 Mtetra
.45835 .57272 .46391 .57816 .47367 .57521 .46814 .56975 Mtetra
.46814 .56975 .47367 .57521 .48347 .57226 .47796 .56678 Mtetra
.47796 .56678 .48347 .57226 .4933 .5693 .48781 .5638 Mtetra
.48781 .5638 .4933 .5693 .50317 .56632 .49771 .5608 Mtetra
.49771 .5608 .50317 .56632 .51308 .56334 .50763 .55779 Mtetra
.50763 .55779 .51308 .56334 .52302 .56034 .5176 .55478 Mtetra
.5176 .55478 .52302 .56034 .533 .55733 .5276 .55175 Mtetra
.5276 .55175 .533 .55733 .54301 .55431 .53764 .54871 Mtetra
.53764 .54871 .54301 .55431 .55306 .55128 .54771 .54566 Mtetra
.54771 .54566 .55306 .55128 .56314 .54824 .55782 .5426 Mtetra
.55782 .5426 .56314 .54824 .57327 .54519 .56797 .53953 Mtetra
.56797 .53953 .57327 .54519 .58343 .54213 .57815 .53644 Mtetra
.57815 .53644 .58343 .54213 .59363 .53905 .58837 .53335 Mtetra
.58837 .53335 .59363 .53905 .60386 .53597 .59864 .53024 Mtetra
.59864 .53024 .60386 .53597 .61413 .53287 .60893 .52712 Mtetra
.60893 .52712 .61413 .53287 .62444 .52976 .61927 .524 Mtetra
.61927 .524 .62444 .52976 .63479 .52664 .62964 .52085 Mtetra
.62964 .52085 .63479 .52664 .64518 .52351 .64006 .5177 Mtetra
.64006 .5177 .64518 .52351 .6556 .52037 .65051 .51454 Mtetra
.65051 .51454 .6556 .52037 .66607 .51722 .661 .51136 Mtetra
.661 .51136 .66607 .51722 .67657 .51405 .67153 .50817 Mtetra
.67153 .50817 .67657 .51405 .68711 .51087 .6821 .50497 Mtetra
.6821 .50497 .68711 .51087 .6977 .50768 .69271 .50176 Mtetra
.69271 .50176 .6977 .50768 .70832 .50448 .70336 .49854 Mtetra
.70336 .49854 .70832 .50448 .71898 .50127 .71405 .4953 Mtetra
.71405 .4953 .71898 .50127 .72968 .49804 .72477 .49205 Mtetra
.72477 .49205 .72968 .49804 .74042 .4948 .73554 .48879 Mtetra
.73554 .48879 .74042 .4948 .7512 .49155 .74636 .48552 Mtetra
.74636 .48552 .7512 .49155 .76203 .48829 .75721 .48223 Mtetra
.75721 .48223 .76203 .48829 .77289 .48501 .7681 .47893 Mtetra
.7681 .47893 .77289 .48501 .7838 .48173 .77903 .47562 Mtetra
.77903 .47562 .7838 .48173 .79474 .47843 .79001 .4723 Mtetra
.79001 .4723 .79474 .47843 .80573 .47511 .80103 .46897 Mtetra
.80103 .46897 .80573 .47511 .81676 .47179 .81209 .46562 Mtetra
.81209 .46562 .81676 .47179 .82783 .46845 .82319 .46226 Mtetra
.82319 .46226 .82783 .46845 .83895 .4651 .83434 .45888 Mtetra
.83434 .45888 .83895 .4651 .85011 .46174 .84552 .45549 Mtetra
.84552 .45549 .85011 .46174 .86131 .45836 .85676 .45209 Mtetra
.85676 .45209 .86131 .45836 .87255 .45497 .86803 .44868 Mtetra
.86803 .44868 .87255 .45497 .88384 .45157 .87935 .44525 Mtetra
.87935 .44525 .88384 .45157 .89517 .44815 .89071 .44181 Mtetra
.89071 .44181 .89517 .44815 .90654 .44472 .90212 .43836 Mtetra
.90212 .43836 .90654 .44472 .91796 .44128 .91357 .43489 Mtetra
.3005 .61354 .30643 .61871 .31568 .61591 .30977 .61072 Mtetra
.30977 .61072 .31568 .61591 .32495 .6131 .31906 .60789 Mtetra
.31906 .60789 .32495 .6131 .33427 .61028 .32839 .60505 Mtetra
.32839 .60505 .33427 .61028 .34361 .60746 .33776 .60221 Mtetra
.33776 .60221 .34361 .60746 .35299 .60462 .34715 .59935 Mtetra
.34715 .59935 .35299 .60462 .36239 .60177 .35658 .59648 Mtetra
.35658 .59648 .36239 .60177 .37184 .59891 .36605 .5936 Mtetra
.36605 .5936 .37184 .59891 .38131 .59604 .37555 .59072 Mtetra
.37555 .59072 .38131 .59604 .39082 .59316 .38508 .58782 Mtetra
.38508 .58782 .39082 .59316 .40037 .59027 .39464 .58491 Mtetra
.39464 .58491 .40037 .59027 .40995 .58737 .40424 .58199 Mtetra
.40424 .58199 .40995 .58737 .41956 .58446 .41387 .57906 Mtetra
.41387 .57906 .41956 .58446 .4292 .58154 .42354 .57612 Mtetra
.42354 .57612 .4292 .58154 .43888 .57861 .43324 .57317 Mtetra
.43324 .57317 .43888 .57861 .4486 .57567 .44298 .57021 Mtetra
.44298 .57021 .4486 .57567 .45835 .57272 .45276 .56724 Mtetra
.45276 .56724 .45835 .57272 .46814 .56975 .46256 .56426 Mtetra
.46256 .56426 .46814 .56975 .47796 .56678 .47241 .56126 Mtetra
.47241 .56126 .47796 .56678 .48781 .5638 .48229 .55826 Mtetra
.48229 .55826 .48781 .5638 .49771 .5608 .4922 .55524 Mtetra
.4922 .55524 .49771 .5608 .50763 .55779 .50215 .55222 Mtetra
.50215 .55222 .50763 .55779 .5176 .55478 .51214 .54918 Mtetra
.51214 .54918 .5176 .55478 .5276 .55175 .52217 .54613 Mtetra
.52217 .54613 .5276 .55175 .53764 .54871 .53223 .54307 Mtetra
.53223 .54307 .53764 .54871 .54771 .54566 .54232 .54 Mtetra
.54232 .54 .54771 .54566 .55782 .5426 .55246 .53692 Mtetra
.55246 .53692 .55782 .5426 .56797 .53953 .56263 .53383 Mtetra
.56263 .53383 .56797 .53953 .57815 .53644 .57284 .53072 Mtetra
.57284 .53072 .57815 .53644 .58837 .53335 .58309 .52761 Mtetra
.58309 .52761 .58837 .53335 .59864 .53024 .59337 .52448 Mtetra
.59337 .52448 .59864 .53024 .60893 .52712 .6037 .52134 Mtetra
.6037 .52134 .60893 .52712 .61927 .524 .61406 .51819 Mtetra
.61406 .51819 .61927 .524 .62964 .52085 .62446 .51503 Mtetra
.62446 .51503 .62964 .52085 .64006 .5177 .6349 .51185 Mtetra
.6349 .51185 .64006 .5177 .65051 .51454 .64538 .50866 Mtetra
.64538 .50866 .65051 .51454 .661 .51136 .65589 .50547 Mtetra
.65589 .50547 .661 .51136 .67153 .50817 .66645 .50226 Mtetra
.66645 .50226 .67153 .50817 .6821 .50497 .67705 .49903 Mtetra
.67705 .49903 .6821 .50497 .69271 .50176 .68768 .4958 Mtetra
.68768 .4958 .69271 .50176 .70336 .49854 .69836 .49255 Mtetra
.69836 .49255 .70336 .49854 .71405 .4953 .70908 .48929 Mtetra
.70908 .48929 .71405 .4953 .72477 .49205 .71984 .48602 Mtetra
.71984 .48602 .72477 .49205 .73554 .48879 .73063 .48274 Mtetra
.73063 .48274 .73554 .48879 .74636 .48552 .74147 .47944 Mtetra
.74147 .47944 .74636 .48552 .75721 .48223 .75235 .47613 Mtetra
.75235 .47613 .75721 .48223 .7681 .47893 .76328 .47281 Mtetra
.76328 .47281 .7681 .47893 .77903 .47562 .77424 .46948 Mtetra
.77424 .46948 .77903 .47562 .79001 .4723 .78524 .46613 Mtetra
.78524 .46613 .79001 .4723 .80103 .46897 .79629 .46277 Mtetra
.79629 .46277 .80103 .46897 .81209 .46562 .80738 .4594 Mtetra
.80738 .4594 .81209 .46562 .82319 .46226 .81852 .45602 Mtetra
.81852 .45602 .82319 .46226 .83434 .45888 .82969 .45262 Mtetra
.82969 .45262 .83434 .45888 .84552 .45549 .84091 .44921 Mtetra
.84091 .44921 .84552 .45549 .85676 .45209 .85217 .44578 Mtetra
.85217 .44578 .85676 .45209 .86803 .44868 .86348 .44234 Mtetra
.86348 .44234 .86803 .44868 .87935 .44525 .87483 .43889 Mtetra
.87483 .43889 .87935 .44525 .89071 .44181 .88623 .43543 Mtetra
.88623 .43543 .89071 .44181 .90212 .43836 .89766 .43195 Mtetra
.89766 .43195 .90212 .43836 .91357 .43489 .90915 .42846 Mtetra
.29453 .60833 .3005 .61354 .30977 .61072 .30382 .60549 Mtetra
.30382 .60549 .30977 .61072 .31906 .60789 .31314 .60265 Mtetra
.31314 .60265 .31906 .60789 .32839 .60505 .32249 .59979 Mtetra
.32249 .59979 .32839 .60505 .33776 .60221 .33187 .59692 Mtetra
.33187 .59692 .33776 .60221 .34715 .59935 .34129 .59405 Mtetra
.34129 .59405 .34715 .59935 .35658 .59648 .35074 .59116 Mtetra
.35074 .59116 .35658 .59648 .36605 .5936 .36022 .58826 Mtetra
.36022 .58826 .36605 .5936 .37555 .59072 .36974 .58536 Mtetra
.36974 .58536 .37555 .59072 .38508 .58782 .37929 .58244 Mtetra
.37929 .58244 .38508 .58782 .39464 .58491 .38888 .57951 Mtetra
.38888 .57951 .39464 .58491 .40424 .58199 .3985 .57657 Mtetra
.3985 .57657 .40424 .58199 .41387 .57906 .40815 .57363 Mtetra
.40815 .57363 .41387 .57906 .42354 .57612 .41784 .57067 Mtetra
.41784 .57067 .42354 .57612 .43324 .57317 .42757 .5677 Mtetra
.42757 .5677 .43324 .57317 .44298 .57021 .43733 .56471 Mtetra
.43733 .56471 .44298 .57021 .45276 .56724 .44712 .56172 Mtetra
.44712 .56172 .45276 .56724 .46256 .56426 .45695 .55872 Mtetra
.45695 .55872 .46256 .56426 .47241 .56126 .46682 .55571 Mtetra
.46682 .55571 .47241 .56126 .48229 .55826 .47672 .55268 Mtetra
.47672 .55268 .48229 .55826 .4922 .55524 .48666 .54965 Mtetra
.48666 .54965 .4922 .55524 .50215 .55222 .49664 .5466 Mtetra
.49664 .5466 .50215 .55222 .51214 .54918 .50665 .54354 Mtetra
.50665 .54354 .51214 .54918 .52217 .54613 .5167 .54047 Mtetra
.5167 .54047 .52217 .54613 .53223 .54307 .52678 .53739 Mtetra
.52678 .53739 .53223 .54307 .54232 .54 .5369 .5343 Mtetra
.5369 .5343 .54232 .54 .55246 .53692 .54706 .5312 Mtetra
.54706 .5312 .55246 .53692 .56263 .53383 .55726 .52809 Mtetra
.55726 .52809 .56263 .53383 .57284 .53072 .56749 .52496 Mtetra
.56749 .52496 .57284 .53072 .58309 .52761 .57777 .52182 Mtetra
.57777 .52182 .58309 .52761 .59337 .52448 .58808 .51867 Mtetra
.58808 .51867 .59337 .52448 .6037 .52134 .59843 .51551 Mtetra
.59843 .51551 .6037 .52134 .61406 .51819 .60881 .51234 Mtetra
.60881 .51234 .61406 .51819 .62446 .51503 .61924 .50916 Mtetra
.61924 .50916 .62446 .51503 .6349 .51185 .62971 .50596 Mtetra
.62971 .50596 .6349 .51185 .64538 .50866 .64021 .50275 Mtetra
.64021 .50275 .64538 .50866 .65589 .50547 .65075 .49953 Mtetra
.65075 .49953 .65589 .50547 .66645 .50226 .66134 .4963 Mtetra
.66134 .4963 .66645 .50226 .67705 .49903 .67196 .49305 Mtetra
.67196 .49305 .67705 .49903 .68768 .4958 .68263 .4898 Mtetra
.68263 .4898 .68768 .4958 .69836 .49255 .69333 .48653 Mtetra
.69333 .48653 .69836 .49255 .70908 .48929 .70408 .48325 Mtetra
.70408 .48325 .70908 .48929 .71984 .48602 .71486 .47995 Mtetra
.71486 .47995 .71984 .48602 .73063 .48274 .72569 .47664 Mtetra
.72569 .47664 .73063 .48274 .74147 .47944 .73656 .47333 Mtetra
.73656 .47333 .74147 .47944 .75235 .47613 .74746 .46999 Mtetra
.74746 .46999 .75235 .47613 .76328 .47281 .75842 .46665 Mtetra
.75842 .46665 .76328 .47281 .77424 .46948 .76941 .46329 Mtetra
.76941 .46329 .77424 .46948 .78524 .46613 .78044 .45992 Mtetra
.78044 .45992 .78524 .46613 .79629 .46277 .79152 .45654 Mtetra
.79152 .45654 .79629 .46277 .80738 .4594 .80264 .45314 Mtetra
.80264 .45314 .80738 .4594 .81852 .45602 .81381 .44973 Mtetra
.81381 .44973 .81852 .45602 .82969 .45262 .82501 .44631 Mtetra
.82501 .44631 .82969 .45262 .84091 .44921 .83626 .44287 Mtetra
.83626 .44287 .84091 .44921 .85217 .44578 .84756 .43942 Mtetra
.84756 .43942 .85217 .44578 .86348 .44234 .8589 .43596 Mtetra
.8589 .43596 .86348 .44234 .87483 .43889 .87028 .43248 Mtetra
.87028 .43248 .87483 .43889 .88623 .43543 .88171 .42899 Mtetra
.88171 .42899 .88623 .43543 .89766 .43195 .89318 .42549 Mtetra
.89318 .42549 .89766 .43195 .90915 .42846 .90469 .42197 Mtetra
.28853 .60308 .29453 .60833 .30382 .60549 .29783 .60023 Mtetra
.29783 .60023 .30382 .60549 .31314 .60265 .30717 .59737 Mtetra
.30717 .59737 .31314 .60265 .32249 .59979 .31654 .59449 Mtetra
.31654 .59449 .32249 .59979 .33187 .59692 .32594 .59161 Mtetra
.32594 .59161 .33187 .59692 .34129 .59405 .33538 .58871 Mtetra
.33538 .58871 .34129 .59405 .35074 .59116 .34485 .58581 Mtetra
.34485 .58581 .35074 .59116 .36022 .58826 .35435 .58289 Mtetra
.35435 .58289 .36022 .58826 .36974 .58536 .36389 .57996 Mtetra
.36389 .57996 .36974 .58536 .37929 .58244 .37347 .57703 Mtetra
.37347 .57703 .37929 .58244 .38888 .57951 .38307 .57408 Mtetra
.38307 .57408 .38888 .57951 .3985 .57657 .39272 .57112 Mtetra
.39272 .57112 .3985 .57657 .40815 .57363 .40239 .56815 Mtetra
.40239 .56815 .40815 .57363 .41784 .57067 .41211 .56517 Mtetra
.41211 .56517 .41784 .57067 .42757 .5677 .42185 .56218 Mtetra
.42185 .56218 .42757 .5677 .43733 .56471 .43163 .55918 Mtetra
.43163 .55918 .43733 .56471 .44712 .56172 .44145 .55617 Mtetra
.44145 .55617 .44712 .56172 .45695 .55872 .45131 .55315 Mtetra
.45131 .55315 .45695 .55872 .46682 .55571 .4612 .55012 Mtetra
.4612 .55012 .46682 .55571 .47672 .55268 .47112 .54707 Mtetra
.47112 .54707 .47672 .55268 .48666 .54965 .48108 .54401 Mtetra
.48108 .54401 .48666 .54965 .49664 .5466 .49108 .54095 Mtetra
.49108 .54095 .49664 .5466 .50665 .54354 .50112 .53787 Mtetra
.50112 .53787 .50665 .54354 .5167 .54047 .51119 .53478 Mtetra
.51119 .53478 .5167 .54047 .52678 .53739 .5213 .53168 Mtetra
.5213 .53168 .52678 .53739 .5369 .5343 .53144 .52857 Mtetra
.53144 .52857 .5369 .5343 .54706 .5312 .54163 .52544 Mtetra
.54163 .52544 .54706 .5312 .55726 .52809 .55185 .52231 Mtetra
.55185 .52231 .55726 .52809 .56749 .52496 .56211 .51916 Mtetra
.56211 .51916 .56749 .52496 .57777 .52182 .57241 .516 Mtetra
.57241 .516 .57777 .52182 .58808 .51867 .58274 .51283 Mtetra
.58274 .51283 .58808 .51867 .59843 .51551 .59312 .50965 Mtetra
.59312 .50965 .59843 .51551 .60881 .51234 .60353 .50645 Mtetra
.60353 .50645 .60881 .51234 .61924 .50916 .61398 .50324 Mtetra
.61398 .50324 .61924 .50916 .62971 .50596 .62448 .50003 Mtetra
.62448 .50003 .62971 .50596 .64021 .50275 .63501 .4968 Mtetra
.63501 .4968 .64021 .50275 .65075 .49953 .64558 .49355 Mtetra
.64558 .49355 .65075 .49953 .66134 .4963 .65619 .4903 Mtetra
.65619 .4903 .66134 .4963 .67196 .49305 .66684 .48703 Mtetra
.66684 .48703 .67196 .49305 .68263 .4898 .67753 .48375 Mtetra
.67753 .48375 .68263 .4898 .69333 .48653 .68826 .48046 Mtetra
.68826 .48046 .69333 .48653 .70408 .48325 .69904 .47715 Mtetra
.69904 .47715 .70408 .48325 .71486 .47995 .70985 .47384 Mtetra
.70985 .47384 .71486 .47995 .72569 .47664 .72071 .47051 Mtetra
.72071 .47051 .72569 .47664 .73656 .47333 .7316 .46716 Mtetra
.7316 .46716 .73656 .47333 .74746 .46999 .74254 .46381 Mtetra
.74254 .46381 .74746 .46999 .75842 .46665 .75352 .46044 Mtetra
.75352 .46044 .75842 .46665 .76941 .46329 .76455 .45706 Mtetra
.76455 .45706 .76941 .46329 .78044 .45992 .77561 .45366 Mtetra
.77561 .45366 .78044 .45992 .79152 .45654 .78672 .45026 Mtetra
.78672 .45026 .79152 .45654 .80264 .45314 .79787 .44684 Mtetra
.79787 .44684 .80264 .45314 .81381 .44973 .80906 .4434 Mtetra
.80906 .4434 .81381 .44973 .82501 .44631 .8203 .43995 Mtetra
.8203 .43995 .82501 .44631 .83626 .44287 .83158 .43649 Mtetra
.83158 .43649 .83626 .44287 .84756 .43942 .84291 .43302 Mtetra
.84291 .43302 .84756 .43942 .8589 .43596 .85428 .42953 Mtetra
.85428 .42953 .8589 .43596 .87028 .43248 .86569 .42603 Mtetra
.86569 .42603 .87028 .43248 .88171 .42899 .87715 .42251 Mtetra
.87715 .42251 .88171 .42899 .89318 .42549 .88866 .41899 Mtetra
.88866 .41899 .89318 .42549 .90469 .42197 .90021 .41544 Mtetra
.28248 .59781 .28853 .60308 .29783 .60023 .2918 .59493 Mtetra
.2918 .59493 .29783 .60023 .30717 .59737 .30116 .59205 Mtetra
.30116 .59205 .30717 .59737 .31654 .59449 .31055 .58916 Mtetra
.31055 .58916 .31654 .59449 .32594 .59161 .31998 .58625 Mtetra
.31998 .58625 .32594 .59161 .33538 .58871 .32943 .58334 Mtetra
.32943 .58334 .33538 .58871 .34485 .58581 .33892 .58041 Mtetra
.33892 .58041 .34485 .58581 .35435 .58289 .34845 .57748 Mtetra
.34845 .57748 .35435 .58289 .36389 .57996 .35801 .57453 Mtetra
.35801 .57453 .36389 .57996 .37347 .57703 .3676 .57158 Mtetra
.3676 .57158 .37347 .57703 .38307 .57408 .37723 .56861 Mtetra
.37723 .56861 .38307 .57408 .39272 .57112 .3869 .56563 Mtetra
.3869 .56563 .39272 .57112 .40239 .56815 .3966 .56264 Mtetra
.3966 .56264 .40239 .56815 .41211 .56517 .40633 .55965 Mtetra
.40633 .55965 .41211 .56517 .42185 .56218 .4161 .55664 Mtetra
.4161 .55664 .42185 .56218 .43163 .55918 .4259 .55361 Mtetra
.4259 .55361 .43163 .55918 .44145 .55617 .43574 .55058 Mtetra
.43574 .55058 .44145 .55617 .45131 .55315 .44562 .54754 Mtetra
.44562 .54754 .45131 .55315 .4612 .55012 .45553 .54449 Mtetra
.45553 .54449 .4612 .55012 .47112 .54707 .46548 .54142 Mtetra
.46548 .54142 .47112 .54707 .48108 .54401 .47547 .53834 Mtetra
.47547 .53834 .48108 .54401 .49108 .54095 .48549 .53526 Mtetra
.48549 .53526 .49108 .54095 .50112 .53787 .49555 .53216 Mtetra
.49555 .53216 .50112 .53787 .51119 .53478 .50564 .52905 Mtetra
.50564 .52905 .51119 .53478 .5213 .53168 .51578 .52592 Mtetra
.51578 .52592 .5213 .53168 .53144 .52857 .52595 .52279 Mtetra
.52595 .52279 .53144 .52857 .54163 .52544 .53616 .51964 Mtetra
.53616 .51964 .54163 .52544 .55185 .52231 .5464 .51649 Mtetra
.5464 .51649 .55185 .52231 .56211 .51916 .55669 .51332 Mtetra
.55669 .51332 .56211 .51916 .57241 .516 .56701 .51014 Mtetra
.56701 .51014 .57241 .516 .58274 .51283 .57737 .50694 Mtetra
.57737 .50694 .58274 .51283 .59312 .50965 .58777 .50374 Mtetra
.58777 .50374 .59312 .50965 .60353 .50645 .59821 .50052 Mtetra
.59821 .50052 .60353 .50645 .61398 .50324 .60869 .49729 Mtetra
.60869 .49729 .61398 .50324 .62448 .50003 .61921 .49405 Mtetra
.61921 .49405 .62448 .50003 .63501 .4968 .62977 .4908 Mtetra
.62977 .4908 .63501 .4968 .64558 .49355 .64037 .48753 Mtetra
.64037 .48753 .64558 .49355 .65619 .4903 .65101 .48426 Mtetra
.65101 .48426 .65619 .4903 .66684 .48703 .66168 .48097 Mtetra
.66168 .48097 .66684 .48703 .67753 .48375 .6724 .47766 Mtetra
.6724 .47766 .67753 .48375 .68826 .48046 .68316 .47435 Mtetra
.68316 .47435 .68826 .48046 .69904 .47715 .69396 .47102 Mtetra
.69396 .47102 .69904 .47715 .70985 .47384 .70481 .46768 Mtetra
.70481 .46768 .70985 .47384 .72071 .47051 .71569 .46433 Mtetra
.71569 .46433 .72071 .47051 .7316 .46716 .72662 .46096 Mtetra
.72662 .46096 .7316 .46716 .74254 .46381 .73758 .45758 Mtetra
.73758 .45758 .74254 .46381 .75352 .46044 .74859 .45419 Mtetra
.74859 .45419 .75352 .46044 .76455 .45706 .75965 .45078 Mtetra
.75965 .45078 .76455 .45706 .77561 .45366 .77074 .44736 Mtetra
.77074 .44736 .77561 .45366 .78672 .45026 .78188 .44393 Mtetra
.78188 .44393 .78672 .45026 .79787 .44684 .79306 .44049 Mtetra
.79306 .44049 .79787 .44684 .80906 .4434 .80429 .43703 Mtetra
.80429 .43703 .80906 .4434 .8203 .43995 .81556 .43355 Mtetra
.81556 .43355 .8203 .43995 .83158 .43649 .82687 .43007 Mtetra
.82687 .43007 .83158 .43649 .84291 .43302 .83823 .42657 Mtetra
.83823 .42657 .84291 .43302 .85428 .42953 .84963 .42306 Mtetra
.84963 .42306 .85428 .42953 .86569 .42603 .86108 .41953 Mtetra
.86108 .41953 .86569 .42603 .87715 .42251 .87257 .41599 Mtetra
.87257 .41599 .87715 .42251 .88866 .41899 .8841 .41243 Mtetra
.8841 .41243 .88866 .41899 .90021 .41544 .89569 .40886 Mtetra
.27639 .59249 .28248 .59781 .2918 .59493 .28574 .5896 Mtetra
.28574 .5896 .2918 .59493 .30116 .59205 .29511 .5867 Mtetra
.29511 .5867 .30116 .59205 .31055 .58916 .30452 .58379 Mtetra
.30452 .58379 .31055 .58916 .31998 .58625 .31397 .58087 Mtetra
.31397 .58087 .31998 .58625 .32943 .58334 .32345 .57793 Mtetra
.32345 .57793 .32943 .58334 .33892 .58041 .33296 .57499 Mtetra
.33296 .57499 .33892 .58041 .34845 .57748 .34251 .57203 Mtetra
.34251 .57203 .34845 .57748 .35801 .57453 .35209 .56907 Mtetra
.35209 .56907 .35801 .57453 .3676 .57158 .3617 .56609 Mtetra
.3617 .56609 .3676 .57158 .37723 .56861 .37135 .56311 Mtetra
.37135 .56311 .37723 .56861 .3869 .56563 .38104 .56011 Mtetra
.38104 .56011 .3869 .56563 .3966 .56264 .39076 .5571 Mtetra
.39076 .5571 .3966 .56264 .40633 .55965 .40052 .55408 Mtetra
.40052 .55408 .40633 .55965 .4161 .55664 .41031 .55105 Mtetra
.41031 .55105 .4161 .55664 .4259 .55361 .42013 .54801 Mtetra
.42013 .54801 .4259 .55361 .43574 .55058 .43 .54496 Mtetra
.43 .54496 .43574 .55058 .44562 .54754 .4399 .54189 Mtetra
.4399 .54189 .44562 .54754 .45553 .54449 .44983 .53882 Mtetra
.44983 .53882 .45553 .54449 .46548 .54142 .4598 .53573 Mtetra
.4598 .53573 .46548 .54142 .47547 .53834 .46981 .53263 Mtetra
.46981 .53263 .47547 .53834 .48549 .53526 .47986 .52952 Mtetra
.47986 .52952 .48549 .53526 .49555 .53216 .48994 .5264 Mtetra
.48994 .5264 .49555 .53216 .50564 .52905 .50006 .52327 Mtetra
.50006 .52327 .50564 .52905 .51578 .52592 .51022 .52013 Mtetra
.51022 .52013 .51578 .52592 .52595 .52279 .52041 .51697 Mtetra
.52041 .51697 .52595 .52279 .53616 .51964 .53065 .51381 Mtetra
.53065 .51381 .53616 .51964 .5464 .51649 .54092 .51063 Mtetra
.54092 .51063 .5464 .51649 .55669 .51332 .55123 .50744 Mtetra
.55123 .50744 .55669 .51332 .56701 .51014 .56158 .50423 Mtetra
.56158 .50423 .56701 .51014 .57737 .50694 .57197 .50102 Mtetra
.57197 .50102 .57737 .50694 .58777 .50374 .58239 .49779 Mtetra
.58239 .49779 .58777 .50374 .59821 .50052 .59286 .49455 Mtetra
.59286 .49455 .59821 .50052 .60869 .49729 .60336 .4913 Mtetra
.60336 .4913 .60869 .49729 .61921 .49405 .61391 .48804 Mtetra
.61391 .48804 .61921 .49405 .62977 .4908 .62449 .48476 Mtetra
.62449 .48476 .62977 .4908 .64037 .48753 .63512 .48147 Mtetra
.63512 .48147 .64037 .48753 .65101 .48426 .64578 .47817 Mtetra
.64578 .47817 .65101 .48426 .66168 .48097 .65649 .47486 Mtetra
.65649 .47486 .66168 .48097 .6724 .47766 .66724 .47153 Mtetra
.66724 .47153 .6724 .47766 .68316 .47435 .67803 .46819 Mtetra
.67803 .46819 .68316 .47435 .69396 .47102 .68886 .46484 Mtetra
.68886 .46484 .69396 .47102 .70481 .46768 .69973 .46148 Mtetra
.69973 .46148 .70481 .46768 .71569 .46433 .71064 .4581 Mtetra
.71064 .4581 .71569 .46433 .72662 .46096 .72159 .45471 Mtetra
.72159 .45471 .72662 .46096 .73758 .45758 .73259 .45131 Mtetra
.73259 .45131 .73758 .45758 .74859 .45419 .74363 .44789 Mtetra
.74363 .44789 .74859 .45419 .75965 .45078 .75471 .44446 Mtetra
.75471 .44446 .75965 .45078 .77074 .44736 .76584 .44102 Mtetra
.76584 .44102 .77074 .44736 .78188 .44393 .77701 .43756 Mtetra
.77701 .43756 .78188 .44393 .79306 .44049 .78822 .43409 Mtetra
.78822 .43409 .79306 .44049 .80429 .43703 .79948 .43061 Mtetra
.79948 .43061 .80429 .43703 .81556 .43355 .81078 .42711 Mtetra
.81078 .42711 .81556 .43355 .82687 .43007 .82212 .4236 Mtetra
.82212 .4236 .82687 .43007 .83823 .42657 .83351 .42007 Mtetra
.83351 .42007 .83823 .42657 .84963 .42306 .84494 .41653 Mtetra
.84494 .41653 .84963 .42306 .86108 .41953 .85642 .41298 Mtetra
.85642 .41298 .86108 .41953 .87257 .41599 .86795 .40941 Mtetra
.86795 .40941 .87257 .41599 .8841 .41243 .87952 .40583 Mtetra
.87952 .40583 .8841 .41243 .89569 .40886 .89113 .40224 Mtetra
.27027 .58715 .27639 .59249 .28574 .5896 .27963 .58424 Mtetra
.27963 .58424 .28574 .5896 .29511 .5867 .28903 .58132 Mtetra
.28903 .58132 .29511 .5867 .30452 .58379 .29846 .57838 Mtetra
.29846 .57838 .30452 .58379 .31397 .58087 .30792 .57544 Mtetra
.30792 .57544 .31397 .58087 .32345 .57793 .31742 .57249 Mtetra
.31742 .57249 .32345 .57793 .33296 .57499 .32696 .56953 Mtetra
.32696 .56953 .33296 .57499 .34251 .57203 .33652 .56655 Mtetra
.33652 .56655 .34251 .57203 .35209 .56907 .34613 .56357 Mtetra
.34613 .56357 .35209 .56907 .3617 .56609 .35576 .56057 Mtetra
.35576 .56057 .3617 .56609 .37135 .56311 .36543 .55756 Mtetra
.36543 .55756 .37135 .56311 .38104 .56011 .37514 .55455 Mtetra
.37514 .55455 .38104 .56011 .39076 .5571 .38488 .55152 Mtetra
.38488 .55152 .39076 .5571 .40052 .55408 .39466 .54848 Mtetra
.39466 .54848 .40052 .55408 .41031 .55105 .40448 .54543 Mtetra
.40448 .54543 .41031 .55105 .42013 .54801 .41432 .54236 Mtetra
.41432 .54236 .42013 .54801 .43 .54496 .42421 .53929 Mtetra
.42421 .53929 .43 .54496 .4399 .54189 .43413 .53621 Mtetra
.43413 .53621 .4399 .54189 .44983 .53882 .44409 .53311 Mtetra
.44409 .53311 .44983 .53882 .4598 .53573 .45409 .53 Mtetra
.45409 .53 .4598 .53573 .46981 .53263 .46412 .52688 Mtetra
.46412 .52688 .46981 .53263 .47986 .52952 .47419 .52375 Mtetra
.47419 .52375 .47986 .52952 .48994 .5264 .4843 .52061 Mtetra
.4843 .52061 .48994 .5264 .50006 .52327 .49444 .51746 Mtetra
.49444 .51746 .50006 .52327 .51022 .52013 .50462 .51429 Mtetra
.50462 .51429 .51022 .52013 .52041 .51697 .51484 .51112 Mtetra
.51484 .51112 .52041 .51697 .53065 .51381 .5251 .50793 Mtetra
.5251 .50793 .53065 .51381 .54092 .51063 .5354 .50473 Mtetra
.5354 .50473 .54092 .51063 .55123 .50744 .54573 .50151 Mtetra
.54573 .50151 .55123 .50744 .56158 .50423 .55611 .49829 Mtetra
.55611 .49829 .56158 .50423 .57197 .50102 .56652 .49505 Mtetra
.56652 .49505 .57197 .50102 .58239 .49779 .57697 .4918 Mtetra
.57697 .4918 .58239 .49779 .59286 .49455 .58747 .48854 Mtetra
.58747 .48854 .59286 .49455 .60336 .4913 .598 .48527 Mtetra
.598 .48527 .60336 .4913 .61391 .48804 .60857 .48198 Mtetra
.60857 .48198 .61391 .48804 .62449 .48476 .61918 .47868 Mtetra
.61918 .47868 .62449 .48476 .63512 .48147 .62983 .47537 Mtetra
.62983 .47537 .63512 .48147 .64578 .47817 .64053 .47205 Mtetra
.64053 .47205 .64578 .47817 .65649 .47486 .65126 .46871 Mtetra
.65126 .46871 .65649 .47486 .66724 .47153 .66204 .46536 Mtetra
.66204 .46536 .66724 .47153 .67803 .46819 .67285 .462 Mtetra
.67285 .462 .67803 .46819 .68886 .46484 .68371 .45862 Mtetra
.68371 .45862 .68886 .46484 .69973 .46148 .69461 .45523 Mtetra
.69461 .45523 .69973 .46148 .71064 .4581 .70555 .45183 Mtetra
.70555 .45183 .71064 .4581 .72159 .45471 .71654 .44842 Mtetra
.71654 .44842 .72159 .45471 .73259 .45131 .72756 .44499 Mtetra
.72756 .44499 .73259 .45131 .74363 .44789 .73863 .44155 Mtetra
.73863 .44155 .74363 .44789 .75471 .44446 .74974 .43809 Mtetra
.74974 .43809 .75471 .44446 .76584 .44102 .7609 .43462 Mtetra
.7609 .43462 .76584 .44102 .77701 .43756 .7721 .43114 Mtetra
.7721 .43114 .77701 .43756 .78822 .43409 .78334 .42765 Mtetra
.78334 .42765 .78822 .43409 .79948 .43061 .79463 .42414 Mtetra
.79463 .42414 .79948 .43061 .81078 .42711 .80596 .42062 Mtetra
.80596 .42062 .81078 .42711 .82212 .4236 .81734 .41708 Mtetra
.81734 .41708 .82212 .4236 .83351 .42007 .82876 .41353 Mtetra
.82876 .41353 .83351 .42007 .84494 .41653 .84023 .40996 Mtetra
.84023 .40996 .84494 .41653 .85642 .41298 .85174 .40639 Mtetra
.85174 .40639 .85642 .41298 .86795 .40941 .8633 .40279 Mtetra
.8633 .40279 .86795 .40941 .87952 .40583 .8749 .39919 Mtetra
.8749 .39919 .87952 .40583 .89113 .40224 .88655 .39556 Mtetra
.2641 .58177 .27027 .58715 .27963 .58424 .27348 .57884 Mtetra
.27348 .57884 .27963 .58424 .28903 .58132 .2829 .5759 Mtetra
.2829 .5759 .28903 .58132 .29846 .57838 .29235 .57294 Mtetra
.29235 .57294 .29846 .57838 .30792 .57544 .30184 .56998 Mtetra
.30184 .56998 .30792 .57544 .31742 .57249 .31136 .56701 Mtetra
.31136 .56701 .31742 .57249 .32696 .56953 .32091 .56403 Mtetra
.32091 .56403 .32696 .56953 .33652 .56655 .3305 .56103 Mtetra
.3305 .56103 .33652 .56655 .34613 .56357 .34012 .55803 Mtetra
.34012 .55803 .34613 .56357 .35576 .56057 .34978 .55501 Mtetra
.34978 .55501 .35576 .56057 .36543 .55756 .35947 .55198 Mtetra
.35947 .55198 .36543 .55756 .37514 .55455 .3692 .54895 Mtetra
.3692 .54895 .37514 .55455 .38488 .55152 .37897 .5459 Mtetra
.37897 .5459 .38488 .55152 .39466 .54848 .38877 .54284 Mtetra
.38877 .54284 .39466 .54848 .40448 .54543 .3986 .53976 Mtetra
.3986 .53976 .40448 .54543 .41432 .54236 .40848 .53668 Mtetra
.40848 .53668 .41432 .54236 .42421 .53929 .41839 .53359 Mtetra
.41839 .53359 .42421 .53929 .43413 .53621 .42833 .53048 Mtetra
.42833 .53048 .43413 .53621 .44409 .53311 .43831 .52737 Mtetra
.43831 .52737 .44409 .53311 .45409 .53 .44833 .52424 Mtetra
.44833 .52424 .45409 .53 .46412 .52688 .45839 .5211 Mtetra
.45839 .5211 .46412 .52688 .47419 .52375 .46848 .51794 Mtetra
.46848 .51794 .47419 .52375 .4843 .52061 .47861 .51478 Mtetra
.47861 .51478 .4843 .52061 .49444 .51746 .48878 .51161 Mtetra
.48878 .51161 .49444 .51746 .50462 .51429 .49899 .50842 Mtetra
.49899 .50842 .50462 .51429 .51484 .51112 .50923 .50522 Mtetra
.50923 .50522 .51484 .51112 .5251 .50793 .51952 .50201 Mtetra
.51952 .50201 .5251 .50793 .5354 .50473 .52984 .49879 Mtetra
.52984 .49879 .5354 .50473 .54573 .50151 .5402 .49555 Mtetra
.5402 .49555 .54573 .50151 .55611 .49829 .5506 .4923 Mtetra
.5506 .4923 .55611 .49829 .56652 .49505 .56104 .48904 Mtetra
.56104 .48904 .56652 .49505 .57697 .4918 .57152 .48577 Mtetra
.57152 .48577 .57697 .4918 .58747 .48854 .58203 .48249 Mtetra
.58203 .48249 .58747 .48854 .598 .48527 .59259 .47919 Mtetra
.59259 .47919 .598 .48527 .60857 .48198 .60319 .47588 Mtetra
.60319 .47588 .60857 .48198 .61918 .47868 .61383 .47256 Mtetra
.61383 .47256 .61918 .47868 .62983 .47537 .62451 .46922 Mtetra
.62451 .46922 .62983 .47537 .64053 .47205 .63523 .46587 Mtetra
.63523 .46587 .64053 .47205 .65126 .46871 .64599 .46251 Mtetra
.64599 .46251 .65126 .46871 .66204 .46536 .6568 .45914 Mtetra
.6568 .45914 .66204 .46536 .67285 .462 .66764 .45575 Mtetra
.66764 .45575 .67285 .462 .68371 .45862 .67853 .45235 Mtetra
.67853 .45235 .68371 .45862 .69461 .45523 .68946 .44894 Mtetra
.68946 .44894 .69461 .45523 .70555 .45183 .70043 .44552 Mtetra
.70043 .44552 .70555 .45183 .71654 .44842 .71144 .44208 Mtetra
.71144 .44208 .71654 .44842 .72756 .44499 .7225 .43862 Mtetra
.7225 .43862 .72756 .44499 .73863 .44155 .7336 .43516 Mtetra
.7336 .43516 .73863 .44155 .74974 .43809 .74474 .43168 Mtetra
.74474 .43168 .74974 .43809 .7609 .43462 .75593 .42819 Mtetra
.75593 .42819 .7609 .43462 .7721 .43114 .76716 .42468 Mtetra
.76716 .42468 .7721 .43114 .78334 .42765 .77843 .42116 Mtetra
.77843 .42116 .78334 .42765 .79463 .42414 .78975 .41762 Mtetra
.78975 .41762 .79463 .42414 .80596 .42062 .80111 .41408 Mtetra
.80111 .41408 .80596 .42062 .81734 .41708 .81252 .41051 Mtetra
.81252 .41051 .81734 .41708 .82876 .41353 .82397 .40694 Mtetra
.82397 .40694 .82876 .41353 .84023 .40996 .83547 .40335 Mtetra
.83547 .40335 .84023 .40996 .85174 .40639 .84702 .39974 Mtetra
.84702 .39974 .85174 .40639 .8633 .40279 .85861 .39612 Mtetra
.85861 .39612 .8633 .40279 .8749 .39919 .87025 .39249 Mtetra
.87025 .39249 .8749 .39919 .88655 .39556 .88193 .38884 Mtetra
.25789 .57635 .2641 .58177 .27348 .57884 .26729 .5734 Mtetra
.26729 .5734 .27348 .57884 .2829 .5759 .27673 .57044 Mtetra
.27673 .57044 .2829 .5759 .29235 .57294 .2862 .56747 Mtetra
.656 .752 .92 r
.2862 .56747 .29235 .57294 .30184 .56998 .29571 .56449 Mtetra
.29571 .56449 .30184 .56998 .31136 .56701 .30525 .5615 Mtetra
.30525 .5615 .31136 .56701 .32091 .56403 .31483 .55849 Mtetra
.656 .751 .92 r
.31483 .55849 .32091 .56403 .3305 .56103 .32444 .55548 Mtetra
.32444 .55548 .3305 .56103 .34012 .55803 .33408 .55245 Mtetra
.33408 .55245 .34012 .55803 .34978 .55501 .34376 .54941 Mtetra
.34376 .54941 .34978 .55501 .35947 .55198 .35348 .54637 Mtetra
.35348 .54637 .35947 .55198 .3692 .54895 .36323 .54331 Mtetra
.36323 .54331 .3692 .54895 .37897 .5459 .37301 .54024 Mtetra
.37301 .54024 .37897 .5459 .38877 .54284 .38284 .53716 Mtetra
.38284 .53716 .38877 .54284 .3986 .53976 .39269 .53406 Mtetra
.39269 .53406 .3986 .53976 .40848 .53668 .40259 .53096 Mtetra
.40259 .53096 .40848 .53668 .41839 .53359 .41252 .52785 Mtetra
.41252 .52785 .41839 .53359 .42833 .53048 .42249 .52472 Mtetra
.42249 .52472 .42833 .53048 .43831 .52737 .43249 .52158 Mtetra
.43249 .52158 .43831 .52737 .44833 .52424 .44254 .51843 Mtetra
.44254 .51843 .44833 .52424 .45839 .5211 .45262 .51527 Mtetra
.45262 .51527 .45839 .5211 .46848 .51794 .46273 .5121 Mtetra
.46273 .5121 .46848 .51794 .47861 .51478 .47289 .50891 Mtetra
.47289 .50891 .47861 .51478 .48878 .51161 .48308 .50571 Mtetra
.48308 .50571 .48878 .51161 .49899 .50842 .49331 .5025 Mtetra
.49331 .5025 .49899 .50842 .50923 .50522 .50358 .49928 Mtetra
.50358 .49928 .50923 .50522 .51952 .50201 .51389 .49605 Mtetra
.51389 .49605 .51952 .50201 .52984 .49879 .52424 .4928 Mtetra
.52424 .4928 .52984 .49879 .5402 .49555 .53463 .48955 Mtetra
.53463 .48955 .5402 .49555 .5506 .4923 .54505 .48627 Mtetra
.54505 .48627 .5506 .4923 .56104 .48904 .55552 .48299 Mtetra
.55552 .48299 .56104 .48904 .57152 .48577 .56602 .4797 Mtetra
.56602 .4797 .57152 .48577 .58203 .48249 .57657 .47639 Mtetra
.57657 .47639 .58203 .48249 .59259 .47919 .58715 .47307 Mtetra
.58715 .47307 .59259 .47919 .60319 .47588 .59778 .46974 Mtetra
.59778 .46974 .60319 .47588 .61383 .47256 .60844 .46639 Mtetra
.60844 .46639 .61383 .47256 .62451 .46922 .61915 .46303 Mtetra
.61915 .46303 .62451 .46922 .63523 .46587 .6299 .45966 Mtetra
.6299 .45966 .63523 .46587 .64599 .46251 .64069 .45628 Mtetra
.64069 .45628 .64599 .46251 .6568 .45914 .65152 .45288 Mtetra
.65152 .45288 .6568 .45914 .66764 .45575 .66239 .44947 Mtetra
.66239 .44947 .66764 .45575 .67853 .45235 .67331 .44604 Mtetra
.67331 .44604 .67853 .45235 .68946 .44894 .68427 .44261 Mtetra
.68427 .44261 .68946 .44894 .70043 .44552 .69527 .43916 Mtetra
.69527 .43916 .70043 .44552 .71144 .44208 .70631 .43569 Mtetra
.70631 .43569 .71144 .44208 .7225 .43862 .7174 .43222 Mtetra
.7174 .43222 .7225 .43862 .7336 .43516 .72853 .42872 Mtetra
.72853 .42872 .7336 .43516 .74474 .43168 .7397 .42522 Mtetra
.7397 .42522 .74474 .43168 .75593 .42819 .75092 .4217 Mtetra
.75092 .4217 .75593 .42819 .76716 .42468 .76218 .41817 Mtetra
.76218 .41817 .76716 .42468 .77843 .42116 .77348 .41462 Mtetra
.77348 .41462 .77843 .42116 .78975 .41762 .78483 .41106 Mtetra
.78483 .41106 .78975 .41762 .80111 .41408 .79623 .40749 Mtetra
.79623 .40749 .80111 .41408 .81252 .41051 .80767 .4039 Mtetra
.80767 .4039 .81252 .41051 .82397 .40694 .81915 .4003 Mtetra
.81915 .4003 .82397 .40694 .83547 .40335 .83069 .39668 Mtetra
.656 .752 .92 r
.83069 .39668 .83547 .40335 .84702 .39974 .84226 .39305 Mtetra
.84226 .39305 .84702 .39974 .85861 .39612 .85389 .38941 Mtetra
.85389 .38941 .85861 .39612 .87025 .39249 .86556 .38574 Mtetra
.656 .751 .92 r
.86556 .38574 .87025 .39249 .88193 .38884 .87727 .38207 Mtetra
.25164 .57089 .25789 .57635 .26729 .5734 .26107 .56793 Mtetra
.26107 .56793 .26729 .5734 .27673 .57044 .27052 .56495 Mtetra
.656 .752 .92 r
.27052 .56495 .27673 .57044 .2862 .56747 .28002 .56197 Mtetra
.28002 .56197 .2862 .56747 .29571 .56449 .28954 .55896 Mtetra
.28954 .55896 .29571 .56449 .30525 .5615 .2991 .55595 Mtetra
.2991 .55595 .30525 .5615 .31483 .55849 .3087 .55292 Mtetra
.3087 .55292 .31483 .55849 .32444 .55548 .31833 .54989 Mtetra
.31833 .54989 .32444 .55548 .33408 .55245 .328 .54684 Mtetra
.328 .54684 .33408 .55245 .34376 .54941 .3377 .54378 Mtetra
.656 .751 .92 r
.3377 .54378 .34376 .54941 .35348 .54637 .34744 .54071 Mtetra
.34744 .54071 .35348 .54637 .36323 .54331 .35721 .53763 Mtetra
.35721 .53763 .36323 .54331 .37301 .54024 .36702 .53454 Mtetra
.36702 .53454 .37301 .54024 .38284 .53716 .37686 .53144 Mtetra
.37686 .53144 .38284 .53716 .39269 .53406 .38674 .52833 Mtetra
.38674 .52833 .39269 .53406 .40259 .53096 .39666 .5252 Mtetra
.39666 .5252 .40259 .53096 .41252 .52785 .40662 .52206 Mtetra
.40662 .52206 .41252 .52785 .42249 .52472 .41661 .51892 Mtetra
.41661 .51892 .42249 .52472 .43249 .52158 .42664 .51576 Mtetra
.42664 .51576 .43249 .52158 .44254 .51843 .4367 .51258 Mtetra
.4367 .51258 .44254 .51843 .45262 .51527 .44681 .5094 Mtetra
.44681 .5094 .45262 .51527 .46273 .5121 .45695 .50621 Mtetra
.45695 .50621 .46273 .5121 .47289 .50891 .46713 .503 Mtetra
.46713 .503 .47289 .50891 .48308 .50571 .47734 .49978 Mtetra
.47734 .49978 .48308 .50571 .49331 .5025 .4876 .49655 Mtetra
.4876 .49655 .49331 .5025 .50358 .49928 .49789 .4933 Mtetra
.49789 .4933 .50358 .49928 .51389 .49605 .50823 .49005 Mtetra
.50823 .49005 .51389 .49605 .52424 .4928 .5186 .48678 Mtetra
.5186 .48678 .52424 .4928 .53463 .48955 .52901 .4835 Mtetra
.52901 .4835 .53463 .48955 .54505 .48627 .53946 .4802 Mtetra
.53946 .4802 .54505 .48627 .55552 .48299 .54996 .4769 Mtetra
.54996 .4769 .55552 .48299 .56602 .4797 .56049 .47358 Mtetra
.56049 .47358 .56602 .4797 .57657 .47639 .57106 .47025 Mtetra
.57106 .47025 .57657 .47639 .58715 .47307 .58167 .46691 Mtetra
.58167 .46691 .58715 .47307 .59778 .46974 .59232 .46355 Mtetra
.59232 .46355 .59778 .46974 .60844 .46639 .60302 .46018 Mtetra
.60302 .46018 .60844 .46639 .61915 .46303 .61375 .4568 Mtetra
.61375 .4568 .61915 .46303 .6299 .45966 .62453 .4534 Mtetra
.62453 .4534 .6299 .45966 .64069 .45628 .63535 .44999 Mtetra
.63535 .44999 .64069 .45628 .65152 .45288 .64621 .44657 Mtetra
.64621 .44657 .65152 .45288 .66239 .44947 .65711 .44314 Mtetra
.65711 .44314 .66239 .44947 .67331 .44604 .66805 .43969 Mtetra
.66805 .43969 .67331 .44604 .68427 .44261 .67904 .43623 Mtetra
.67904 .43623 .68427 .44261 .69527 .43916 .69007 .43275 Mtetra
.69007 .43275 .69527 .43916 .70631 .43569 .70114 .42926 Mtetra
.70114 .42926 .70631 .43569 .7174 .43222 .71226 .42576 Mtetra
.71226 .42576 .7174 .43222 .72853 .42872 .72342 .42224 Mtetra
.72342 .42224 .72853 .42872 .7397 .42522 .73462 .41871 Mtetra
.73462 .41871 .7397 .42522 .75092 .4217 .74587 .41517 Mtetra
.74587 .41517 .75092 .4217 .76218 .41817 .75716 .41161 Mtetra
.75716 .41161 .76218 .41817 .77348 .41462 .7685 .40804 Mtetra
.7685 .40804 .77348 .41462 .78483 .41106 .77988 .40446 Mtetra
.77988 .40446 .78483 .41106 .79623 .40749 .79131 .40086 Mtetra
.79131 .40086 .79623 .40749 .80767 .4039 .80278 .39725 Mtetra
.656 .752 .92 r
.80278 .39725 .80767 .4039 .81915 .4003 .8143 .39362 Mtetra
.8143 .39362 .81915 .4003 .83069 .39668 .82586 .38998 Mtetra
.82586 .38998 .83069 .39668 .84226 .39305 .83747 .38632 Mtetra
.83747 .38632 .84226 .39305 .85389 .38941 .84913 .38264 Mtetra
.84913 .38264 .85389 .38941 .86556 .38574 .86084 .37895 Mtetra
.86084 .37895 .86556 .38574 .87727 .38207 .87259 .37524 Mtetra
.655 .751 .921 r
.24535 .5654 .25164 .57089 .26107 .56793 .25479 .56243 Mtetra
.655 .752 .921 r
.25479 .56243 .26107 .56793 .27052 .56495 .26427 .55944 Mtetra
.26427 .55944 .27052 .56495 .28002 .56197 .27378 .55644 Mtetra
.656 .752 .921 r
.27378 .55644 .28002 .56197 .28954 .55896 .28333 .55342 Mtetra
.28333 .55342 .28954 .55896 .2991 .55595 .29291 .55038 Mtetra
.29291 .55038 .2991 .55595 .3087 .55292 .30253 .54733 Mtetra
.30253 .54733 .3087 .55292 .31833 .54989 .31218 .54427 Mtetra
.31218 .54427 .31833 .54989 .328 .54684 .32187 .5412 Mtetra
.32187 .5412 .328 .54684 .3377 .54378 .33159 .53812 Mtetra
.656 .752 .92 r
.33159 .53812 .3377 .54378 .34744 .54071 .34135 .53503 Mtetra
.34135 .53503 .34744 .54071 .35721 .53763 .35115 .53192 Mtetra
.35115 .53192 .35721 .53763 .36702 .53454 .36098 .52881 Mtetra
.36098 .52881 .36702 .53454 .37686 .53144 .37085 .52568 Mtetra
.656 .751 .92 r
.37085 .52568 .37686 .53144 .38674 .52833 .38075 .52255 Mtetra
.38075 .52255 .38674 .52833 .39666 .5252 .39069 .5194 Mtetra
.39069 .5194 .39666 .5252 .40662 .52206 .40067 .51624 Mtetra
.40067 .51624 .40662 .52206 .41661 .51892 .41068 .51307 Mtetra
.41068 .51307 .41661 .51892 .42664 .51576 .42074 .50989 Mtetra
.42074 .50989 .42664 .51576 .4367 .51258 .43083 .5067 Mtetra
.43083 .5067 .4367 .51258 .44681 .5094 .44095 .50349 Mtetra
.44095 .50349 .44681 .5094 .45695 .50621 .45112 .50027 Mtetra
.45112 .50027 .45695 .50621 .46713 .503 .46132 .49704 Mtetra
.46132 .49704 .46713 .503 .47734 .49978 .47157 .4938 Mtetra
.47157 .4938 .47734 .49978 .4876 .49655 .48185 .49055 Mtetra
.48185 .49055 .4876 .49655 .49789 .4933 .49217 .48728 Mtetra
.49217 .48728 .49789 .4933 .50823 .49005 .50253 .484 Mtetra
.50253 .484 .50823 .49005 .5186 .48678 .51292 .48071 Mtetra
.51292 .48071 .5186 .48678 .52901 .4835 .52336 .47741 Mtetra
.52336 .47741 .52901 .4835 .53946 .4802 .53384 .47409 Mtetra
.53384 .47409 .53946 .4802 .54996 .4769 .54436 .47076 Mtetra
.54436 .47076 .54996 .4769 .56049 .47358 .55491 .46742 Mtetra
.55491 .46742 .56049 .47358 .57106 .47025 .56551 .46407 Mtetra
.56551 .46407 .57106 .47025 .58167 .46691 .57615 .4607 Mtetra
.57615 .4607 .58167 .46691 .59232 .46355 .58683 .45732 Mtetra
.58683 .45732 .59232 .46355 .60302 .46018 .59755 .45393 Mtetra
.59755 .45393 .60302 .46018 .61375 .4568 .60832 .45052 Mtetra
.60832 .45052 .61375 .4568 .62453 .4534 .61912 .4471 Mtetra
.61912 .4471 .62453 .4534 .63535 .44999 .62997 .44367 Mtetra
.62997 .44367 .63535 .44999 .64621 .44657 .64085 .44022 Mtetra
.64085 .44022 .64621 .44657 .65711 .44314 .65178 .43676 Mtetra
.65178 .43676 .65711 .44314 .66805 .43969 .66276 .43329 Mtetra
.66276 .43329 .66805 .43969 .67904 .43623 .67377 .4298 Mtetra
.67377 .4298 .67904 .43623 .69007 .43275 .68483 .4263 Mtetra
.68483 .4263 .69007 .43275 .70114 .42926 .69594 .42279 Mtetra
.69594 .42279 .70114 .42926 .71226 .42576 .70708 .41926 Mtetra
.70708 .41926 .71226 .42576 .72342 .42224 .71827 .41572 Mtetra
.71827 .41572 .72342 .42224 .73462 .41871 .72951 .41216 Mtetra
.72951 .41216 .73462 .41871 .74587 .41517 .74079 .4086 Mtetra
.656 .752 .92 r
.74079 .4086 .74587 .41517 .75716 .41161 .75211 .40501 Mtetra
.656 .752 .921 r
.75211 .40501 .75716 .41161 .7685 .40804 .76348 .40142 Mtetra
.76348 .40142 .7685 .40804 .77988 .40446 .77489 .39781 Mtetra
.77489 .39781 .77988 .40446 .79131 .40086 .78635 .39419 Mtetra
.78635 .39419 .79131 .40086 .80278 .39725 .79786 .39056 Mtetra
.79786 .39056 .80278 .39725 .8143 .39362 .80941 .3869 Mtetra
.80941 .3869 .8143 .39362 .82586 .38998 .82101 .38323 Mtetra
.82101 .38323 .82586 .38998 .83747 .38632 .83265 .37955 Mtetra
.83265 .37955 .83747 .38632 .84913 .38264 .84434 .37584 Mtetra
.84434 .37584 .84913 .38264 .86084 .37895 .85608 .37211 Mtetra
.656 .752 .92 r
.85608 .37211 .86084 .37895 .87259 .37524 .86786 .36837 Mtetra
.654 .751 .921 r
.23902 .55988 .24535 .5654 .25479 .56243 .24848 .5569 Mtetra
.655 .752 .921 r
.24848 .5569 .25479 .56243 .26427 .55944 .25798 .55391 Mtetra
.655 .752 .922 r
.25798 .55391 .26427 .55944 .27378 .55644 .26751 .55089 Mtetra
.655 .753 .922 r
.26751 .55089 .27378 .55644 .28333 .55342 .27708 .54786 Mtetra
.656 .753 .922 r
.27708 .54786 .28333 .55342 .29291 .55038 .28668 .54481 Mtetra
.28668 .54481 .29291 .55038 .30253 .54733 .29632 .54173 Mtetra
.656 .753 .921 r
.29632 .54173 .30253 .54733 .31218 .54427 .30599 .53864 Mtetra
.30599 .53864 .31218 .54427 .32187 .5412 .3157 .53554 Mtetra
.3157 .53554 .32187 .5412 .33159 .53812 .32545 .53243 Mtetra
.656 .752 .921 r
.32545 .53243 .33159 .53812 .34135 .53503 .33523 .52931 Mtetra
.33523 .52931 .34135 .53503 .35115 .53192 .34505 .52618 Mtetra
.656 .752 .92 r
.34505 .52618 .35115 .53192 .36098 .52881 .3549 .52304 Mtetra
.3549 .52304 .36098 .52881 .37085 .52568 .36479 .51989 Mtetra
.36479 .51989 .37085 .52568 .38075 .52255 .37472 .51673 Mtetra
.656 .751 .92 r
.37472 .51673 .38075 .52255 .39069 .5194 .38468 .51356 Mtetra
.38468 .51356 .39069 .5194 .40067 .51624 .39468 .51038 Mtetra
.39468 .51038 .40067 .51624 .41068 .51307 .40472 .50719 Mtetra
.40472 .50719 .41068 .51307 .42074 .50989 .4148 .50398 Mtetra
.4148 .50398 .42074 .50989 .43083 .5067 .42491 .50077 Mtetra
.42491 .50077 .43083 .5067 .44095 .50349 .43506 .49754 Mtetra
.43506 .49754 .44095 .50349 .45112 .50027 .44525 .4943 Mtetra
.44525 .4943 .45112 .50027 .46132 .49704 .45548 .49105 Mtetra
.45548 .49105 .46132 .49704 .47157 .4938 .46575 .48778 Mtetra
.46575 .48778 .47157 .4938 .48185 .49055 .47605 .48451 Mtetra
.47605 .48451 .48185 .49055 .49217 .48728 .4864 .48122 Mtetra
.4864 .48122 .49217 .48728 .50253 .484 .49678 .47792 Mtetra
.49678 .47792 .50253 .484 .51292 .48071 .50721 .4746 Mtetra
.50721 .4746 .51292 .48071 .52336 .47741 .51767 .47128 Mtetra
.51767 .47128 .52336 .47741 .53384 .47409 .52817 .46794 Mtetra
.52817 .46794 .53384 .47409 .54436 .47076 .53872 .46458 Mtetra
.53872 .46458 .54436 .47076 .55491 .46742 .5493 .46122 Mtetra
.5493 .46122 .55491 .46742 .56551 .46407 .55993 .45784 Mtetra
.55993 .45784 .56551 .46407 .57615 .4607 .57059 .45445 Mtetra
.57059 .45445 .57615 .4607 .58683 .45732 .5813 .45104 Mtetra
.5813 .45104 .58683 .45732 .59755 .45393 .59205 .44763 Mtetra
.59205 .44763 .59755 .45393 .60832 .45052 .60284 .44419 Mtetra
.60284 .44419 .60832 .45052 .61912 .4471 .61367 .44075 Mtetra
.61367 .44075 .61912 .4471 .62997 .44367 .62455 .43729 Mtetra
.62455 .43729 .62997 .44367 .64085 .44022 .63546 .43382 Mtetra
.63546 .43382 .64085 .44022 .65178 .43676 .64642 .43034 Mtetra
.64642 .43034 .65178 .43676 .66276 .43329 .65743 .42684 Mtetra
.65743 .42684 .66276 .43329 .67377 .4298 .66847 .42333 Mtetra
.66847 .42333 .67377 .4298 .68483 .4263 .67956 .4198 Mtetra
.67956 .4198 .68483 .4263 .69594 .42279 .69069 .41626 Mtetra
.69069 .41626 .69594 .42279 .70708 .41926 .70187 .41271 Mtetra
.70187 .41271 .70708 .41926 .71827 .41572 .71309 .40914 Mtetra
.71309 .40914 .71827 .41572 .72951 .41216 .72436 .40557 Mtetra
.72436 .40557 .72951 .41216 .74079 .4086 .73567 .40198 Mtetra
.655 .752 .921 r
.73567 .40198 .74079 .4086 .75211 .40501 .74702 .39838 Mtetra
.74702 .39838 .75211 .40501 .76348 .40142 .75842 .39476 Mtetra
.75842 .39476 .76348 .40142 .77489 .39781 .76987 .39114 Mtetra
.76987 .39114 .77489 .39781 .78635 .39419 .78136 .3875 Mtetra
.655 .753 .921 r
.78136 .3875 .78635 .39419 .79786 .39056 .7929 .38384 Mtetra
.655 .753 .922 r
.7929 .38384 .79786 .39056 .80941 .3869 .80449 .38017 Mtetra
.656 .753 .922 r
.80449 .38017 .80941 .3869 .82101 .38323 .81612 .37647 Mtetra
.81612 .37647 .82101 .38323 .83265 .37955 .82779 .37275 Mtetra
.656 .753 .921 r
.82779 .37275 .83265 .37955 .84434 .37584 .83952 .36901 Mtetra
.657 .753 .921 r
.83952 .36901 .84434 .37584 .85608 .37211 .85129 .36524 Mtetra
.657 .753 .92 r
.85129 .36524 .85608 .37211 .86786 .36837 .8631 .36144 Mtetra
.653 .751 .922 r
.23264 .55431 .23902 .55988 .24848 .5569 .24212 .55136 Mtetra
.653 .752 .922 r
.24212 .55136 .24848 .5569 .25798 .55391 .25164 .54838 Mtetra
.654 .754 .923 r
.25164 .54838 .25798 .55391 .26751 .55089 .26119 .54537 Mtetra
.655 .755 .923 r
.26119 .54537 .26751 .55089 .27708 .54786 .27077 .54233 Mtetra
.655 .756 .923 r
.27077 .54233 .27708 .54786 .28668 .54481 .2804 .53926 Mtetra
.656 .756 .923 r
.2804 .53926 .28668 .54481 .29632 .54173 .29006 .53616 Mtetra
.657 .756 .923 r
.29006 .53616 .29632 .54173 .30599 .53864 .29976 .53304 Mtetra
.29976 .53304 .30599 .53864 .3157 .53554 .30949 .52991 Mtetra
.657 .755 .922 r
.30949 .52991 .3157 .53554 .32545 .53243 .31926 .52676 Mtetra
.657 .754 .922 r
.31926 .52676 .32545 .53243 .33523 .52931 .32906 .5236 Mtetra
.32906 .5236 .33523 .52931 .34505 .52618 .3389 .52043 Mtetra
.656 .753 .921 r
.3389 .52043 .34505 .52618 .3549 .52304 .34878 .51726 Mtetra
.34878 .51726 .3549 .52304 .36479 .51989 .35869 .51408 Mtetra
.656 .752 .921 r
.35869 .51408 .36479 .51989 .37472 .51673 .36864 .51089 Mtetra
.36864 .51089 .37472 .51673 .38468 .51356 .37863 .5077 Mtetra
.37863 .5077 .38468 .51356 .39468 .51038 .38865 .50449 Mtetra
.656 .752 .92 r
.38865 .50449 .39468 .51038 .40472 .50719 .39872 .50127 Mtetra
.39872 .50127 .40472 .50719 .4148 .50398 .40882 .49804 Mtetra
.40882 .49804 .4148 .50398 .42491 .50077 .41895 .4948 Mtetra
.41895 .4948 .42491 .50077 .43506 .49754 .42913 .49155 Mtetra
.656 .751 .92 r
.42913 .49155 .43506 .49754 .44525 .4943 .43934 .48829 Mtetra
.43934 .48829 .44525 .4943 .45548 .49105 .4496 .48501 Mtetra
.4496 .48501 .45548 .49105 .46575 .48778 .45989 .48173 Mtetra
.45989 .48173 .46575 .48778 .47605 .48451 .47022 .47843 Mtetra
.47022 .47843 .47605 .48451 .4864 .48122 .48059 .47511 Mtetra
.48059 .47511 .4864 .48122 .49678 .47792 .491 .47179 Mtetra
.491 .47179 .49678 .47792 .50721 .4746 .50145 .46845 Mtetra
.50145 .46845 .50721 .4746 .51767 .47128 .51194 .4651 Mtetra
.51194 .4651 .51767 .47128 .52817 .46794 .52247 .46174 Mtetra
.52247 .46174 .52817 .46794 .53872 .46458 .53304 .45836 Mtetra
.53304 .45836 .53872 .46458 .5493 .46122 .54365 .45497 Mtetra
.54365 .45497 .5493 .46122 .55993 .45784 .5543 .45157 Mtetra
.5543 .45157 .55993 .45784 .57059 .45445 .565 .44815 Mtetra
.565 .44815 .57059 .45445 .5813 .45104 .57573 .44472 Mtetra
.57573 .44472 .5813 .45104 .59205 .44763 .58651 .44128 Mtetra
.58651 .44128 .59205 .44763 .60284 .44419 .59732 .43783 Mtetra
.59732 .43783 .60284 .44419 .61367 .44075 .60819 .43436 Mtetra
.60819 .43436 .61367 .44075 .62455 .43729 .61909 .43088 Mtetra
.61909 .43088 .62455 .43729 .63546 .43382 .63003 .42738 Mtetra
.63003 .42738 .63546 .43382 .64642 .43034 .64102 .42387 Mtetra
.64102 .42387 .64642 .43034 .65743 .42684 .65205 .42035 Mtetra
.656 .752 .92 r
.65205 .42035 .65743 .42684 .66847 .42333 .66313 .41681 Mtetra
.66313 .41681 .66847 .42333 .67956 .4198 .67425 .41326 Mtetra
.656 .752 .921 r
.67425 .41326 .67956 .4198 .69069 .41626 .68541 .4097 Mtetra
.655 .752 .921 r
.68541 .4097 .69069 .41626 .70187 .41271 .69662 .40613 Mtetra
.69662 .40613 .70187 .41271 .71309 .40914 .70787 .40255 Mtetra
.70787 .40255 .71309 .40914 .72436 .40557 .71917 .39895 Mtetra
.71917 .39895 .72436 .40557 .73567 .40198 .73051 .39535 Mtetra
.655 .753 .922 r
.73051 .39535 .73567 .40198 .74702 .39838 .7419 .39174 Mtetra
.7419 .39174 .74702 .39838 .75842 .39476 .75333 .38812 Mtetra
.655 .754 .923 r
.75333 .38812 .75842 .39476 .76987 .39114 .76481 .38448 Mtetra
.654 .754 .923 r
.76481 .38448 .76987 .39114 .78136 .3875 .77634 .38083 Mtetra
.655 .755 .923 r
.77634 .38083 .78136 .3875 .7929 .38384 .78791 .37716 Mtetra
.655 .755 .924 r
.78791 .37716 .7929 .38384 .80449 .38017 .79953 .37346 Mtetra
.656 .756 .924 r
.79953 .37346 .80449 .38017 .81612 .37647 .8112 .36973 Mtetra
.657 .756 .923 r
.8112 .36973 .81612 .37647 .82779 .37275 .82291 .36596 Mtetra
.657 .756 .922 r
.82291 .36596 .82779 .37275 .83952 .36901 .83466 .36216 Mtetra
.658 .755 .922 r
.83466 .36216 .83952 .36901 .85129 .36524 .84646 .35833 Mtetra
.659 .754 .921 r
.84646 .35833 .85129 .36524 .8631 .36144 .85831 .35446 Mtetra
.649 .75 .923 r
.22623 .54871 .23264 .55431 .24212 .55136 .23572 .54581 Mtetra
.65 .753 .925 r
.23572 .54581 .24212 .55136 .25164 .54838 .24525 .54288 Mtetra
.651 .756 .926 r
.24525 .54288 .25164 .54838 .26119 .54537 .25481 .53991 Mtetra
.652 .758 .927 r
.25481 .53991 .26119 .54537 .27077 .54233 .26442 .5369 Mtetra
.654 .76 .927 r
.26442 .5369 .27077 .54233 .2804 .53926 .27406 .53383 Mtetra
.656 .761 .927 r
.27406 .53383 .2804 .53926 .29006 .53616 .28374 .53072 Mtetra
.657 .762 .927 r
.28374 .53072 .29006 .53616 .29976 .53304 .29347 .52756 Mtetra
.658 .761 .926 r
.29347 .52756 .29976 .53304 .30949 .52991 .30322 .52437 Mtetra
.658 .76 .925 r
.30322 .52437 .30949 .52991 .31926 .52676 .31302 .52117 Mtetra
.658 .759 .924 r
.31302 .52117 .31926 .52676 .32906 .5236 .32285 .51795 Mtetra
.658 .758 .924 r
.32285 .51795 .32906 .5236 .3389 .52043 .33271 .51473 Mtetra
.658 .756 .923 r
.33271 .51473 .3389 .52043 .34878 .51726 .34261 .5115 Mtetra
.657 .755 .922 r
.34261 .5115 .34878 .51726 .35869 .51408 .35255 .50827 Mtetra
.657 .754 .921 r
.35255 .50827 .35869 .51408 .36864 .51089 .36252 .50504 Mtetra
.657 .753 .921 r
.36252 .50504 .36864 .51089 .37863 .5077 .37254 .5018 Mtetra
.656 .753 .921 r
.37254 .5018 .37863 .5077 .38865 .50449 .38258 .49856 Mtetra
.656 .752 .921 r
.38258 .49856 .38865 .50449 .39872 .50127 .39267 .49532 Mtetra
.656 .752 .92 r
.39267 .49532 .39872 .50127 .40882 .49804 .40279 .49206 Mtetra
.40279 .49206 .40882 .49804 .41895 .4948 .41295 .48879 Mtetra
.656 .751 .92 r
.41295 .48879 .41895 .4948 .42913 .49155 .42315 .48552 Mtetra
.42315 .48552 .42913 .49155 .43934 .48829 .43339 .48223 Mtetra
.43339 .48223 .43934 .48829 .4496 .48501 .44367 .47893 Mtetra
.44367 .47893 .4496 .48501 .45989 .48173 .45399 .47562 Mtetra
.45399 .47562 .45989 .48173 .47022 .47843 .46434 .4723 Mtetra
.46434 .4723 .47022 .47843 .48059 .47511 .47474 .46896 Mtetra
.47474 .46896 .48059 .47511 .491 .47179 .48517 .46561 Mtetra
.48517 .46561 .491 .47179 .50145 .46845 .49565 .46225 Mtetra
.49565 .46225 .50145 .46845 .51194 .4651 .50617 .45888 Mtetra
.50617 .45888 .51194 .4651 .52247 .46174 .51672 .45549 Mtetra
.51672 .45549 .52247 .46174 .53304 .45836 .52732 .45209 Mtetra
.52732 .45209 .53304 .45836 .54365 .45497 .53796 .44867 Mtetra
.53796 .44867 .54365 .45497 .5543 .45157 .54864 .44525 Mtetra
.54864 .44525 .5543 .45157 .565 .44815 .55936 .44181 Mtetra
.55936 .44181 .565 .44815 .57573 .44472 .57012 .43835 Mtetra
.57012 .43835 .57573 .44472 .58651 .44128 .58092 .43489 Mtetra
.58092 .43489 .58651 .44128 .59732 .43783 .59177 .43141 Mtetra
.59177 .43141 .59732 .43783 .60819 .43436 .60266 .42791 Mtetra
.60266 .42791 .60819 .43436 .61909 .43088 .61359 .42441 Mtetra
.61359 .42441 .61909 .43088 .63003 .42738 .62456 .42089 Mtetra
.62456 .42089 .63003 .42738 .64102 .42387 .63558 .41735 Mtetra
.63558 .41735 .64102 .42387 .65205 .42035 .64664 .41381 Mtetra
.655 .751 .92 r
.64664 .41381 .65205 .42035 .66313 .41681 .65775 .41025 Mtetra
.655 .752 .921 r
.65775 .41025 .66313 .41681 .67425 .41326 .6689 .40669 Mtetra
.6689 .40669 .67425 .41326 .68541 .4097 .68009 .40311 Mtetra
.68009 .40311 .68541 .4097 .69662 .40613 .69133 .39953 Mtetra
.654 .752 .922 r
.69133 .39953 .69662 .40613 .70787 .40255 .70262 .39594 Mtetra
.654 .753 .922 r
.70262 .39594 .70787 .40255 .71917 .39895 .71395 .39235 Mtetra
.654 .754 .923 r
.71395 .39235 .71917 .39895 .73051 .39535 .72532 .38875 Mtetra
.653 .755 .924 r
.72532 .38875 .73051 .39535 .7419 .39174 .73674 .38515 Mtetra
.653 .756 .925 r
.73674 .38515 .7419 .39174 .75333 .38812 .74821 .38154 Mtetra
.653 .757 .926 r
.74821 .38154 .75333 .38812 .76481 .38448 .75973 .37792 Mtetra
.653 .759 .927 r
.75973 .37792 .76481 .38448 .77634 .38083 .77129 .37427 Mtetra
.654 .76 .928 r
.77129 .37427 .77634 .38083 .78791 .37716 .7829 .37059 Mtetra
.655 .761 .928 r
.7829 .37059 .78791 .37716 .79953 .37346 .79455 .36686 Mtetra
.656 .761 .927 r
.79455 .36686 .79953 .37346 .8112 .36973 .80625 .36308 Mtetra
.658 .761 .926 r
.80625 .36308 .8112 .36973 .82291 .36596 .81799 .35923 Mtetra
.659 .76 .925 r
.81799 .35923 .82291 .36596 .83466 .36216 .82978 .35534 Mtetra
.66 .759 .923 r
.82978 .35534 .83466 .36216 .84646 .35833 .8416 .35141 Mtetra
.661 .757 .921 r
.8416 .35141 .84646 .35833 .85831 .35446 .85348 .34743 Mtetra
.644 .748 .925 r
.21976 .54307 .22623 .54871 .23572 .54581 .22927 .54027 Mtetra
.645 .753 .928 r
.22927 .54027 .23572 .54581 .24525 .54288 .2388 .53744 Mtetra
.646 .757 .93 r
.2388 .53744 .24525 .54288 .25481 .53991 .24838 .53455 Mtetra
.648 .762 .932 r
.24838 .53455 .25481 .53991 .26442 .5369 .258 .5316 Mtetra
.651 .766 .933 r
.258 .5316 .26442 .5369 .27406 .53383 .26767 .52857 Mtetra
.654 .768 .933 r
.26767 .52857 .27406 .53383 .28374 .53072 .27737 .52547 Mtetra
.656 .77 .933 r
.27737 .52547 .28374 .53072 .29347 .52756 .28711 .52229 Mtetra
.658 .771 .932 r
.28711 .52229 .29347 .52756 .30322 .52437 .29689 .51906 Mtetra
.659 .77 .931 r
.29689 .51906 .30322 .52437 .31302 .52117 .30671 .51579 Mtetra
.66 .769 .93 r
.30671 .51579 .31302 .52117 .32285 .51795 .31657 .51249 Mtetra
.66 .767 .929 r
.31657 .51249 .32285 .51795 .33271 .51473 .32646 .50919 Mtetra
.66 .764 .927 r
.32646 .50919 .33271 .51473 .34261 .5115 .33639 .50588 Mtetra
.659 .762 .926 r
.33639 .50588 .34261 .5115 .35255 .50827 .34636 .50258 Mtetra
.659 .76 .925 r
.34636 .50258 .35255 .50827 .36252 .50504 .35636 .49928 Mtetra
.658 .758 .924 r
.35636 .49928 .36252 .50504 .37254 .5018 .36639 .49598 Mtetra
.658 .757 .923 r
.36639 .49598 .37254 .5018 .38258 .49856 .37647 .49269 Mtetra
.657 .756 .923 r
.37647 .49269 .38258 .49856 .39267 .49532 .38658 .48939 Mtetra
.657 .755 .922 r
.38658 .48939 .39267 .49532 .40279 .49206 .39673 .4861 Mtetra
.656 .754 .922 r
.39673 .4861 .40279 .49206 .41295 .48879 .40691 .48279 Mtetra
.656 .753 .921 r
.40691 .48279 .41295 .48879 .42315 .48552 .41714 .47948 Mtetra
.41714 .47948 .42315 .48552 .43339 .48223 .4274 .47617 Mtetra
.4274 .47617 .43339 .48223 .44367 .47893 .4377 .47284 Mtetra
.656 .752 .921 r
.4377 .47284 .44367 .47893 .45399 .47562 .44804 .4695 Mtetra
.44804 .4695 .45399 .47562 .46434 .4723 .45843 .46615 Mtetra
.45843 .46615 .46434 .4723 .47474 .46896 .46885 .46278 Mtetra
.46885 .46278 .47474 .46896 .48517 .46561 .47931 .45941 Mtetra
.47931 .45941 .48517 .46561 .49565 .46225 .48981 .45602 Mtetra
.48981 .45602 .49565 .46225 .50617 .45888 .50035 .45262 Mtetra
.50035 .45262 .50617 .45888 .51672 .45549 .51093 .44921 Mtetra
.51093 .44921 .51672 .45549 .52732 .45209 .52156 .44579 Mtetra
.52156 .44579 .52732 .45209 .53796 .44867 .53222 .44235 Mtetra
.53222 .44235 .53796 .44867 .54864 .44525 .54293 .4389 Mtetra
.54293 .4389 .54864 .44525 .55936 .44181 .55368 .43544 Mtetra
.55368 .43544 .55936 .44181 .57012 .43835 .56447 .43196 Mtetra
.56447 .43196 .57012 .43835 .58092 .43489 .5753 .42847 Mtetra
.5753 .42847 .58092 .43489 .59177 .43141 .58618 .42497 Mtetra
.58618 .42497 .59177 .43141 .60266 .42791 .59709 .42145 Mtetra
.655 .752 .921 r
.59709 .42145 .60266 .42791 .61359 .42441 .60805 .41793 Mtetra
.60805 .41793 .61359 .42441 .62456 .42089 .61906 .41439 Mtetra
.655 .753 .922 r
.61906 .41439 .62456 .42089 .63558 .41735 .6301 .41084 Mtetra
.6301 .41084 .63558 .41735 .64664 .41381 .6412 .40729 Mtetra
.6412 .40729 .64664 .41381 .65775 .41025 .65233 .40373 Mtetra
.654 .754 .923 r
.65233 .40373 .65775 .41025 .6689 .40669 .66351 .40016 Mtetra
.654 .755 .924 r
.66351 .40016 .6689 .40669 .68009 .40311 .67474 .39659 Mtetra
.653 .755 .925 r
.67474 .39659 .68009 .40311 .69133 .39953 .68601 .39302 Mtetra
.652 .757 .926 r
.68601 .39302 .69133 .39953 .70262 .39594 .69733 .38945 Mtetra
.652 .758 .927 r
.69733 .38945 .70262 .39594 .71395 .39235 .7087 .38589 Mtetra
.651 .759 .929 r
.7087 .38589 .71395 .39235 .72532 .38875 .72011 .38233 Mtetra
.65 .761 .931 r
.72011 .38233 .72532 .38875 .73674 .38515 .73157 .37876 Mtetra
.65 .763 .932 r
.73157 .37876 .73674 .38515 .74821 .38154 .74307 .37518 Mtetra
.65 .766 .933 r
.74307 .37518 .74821 .38154 .75973 .37792 .75463 .37157 Mtetra
.651 .768 .934 r
.75463 .37157 .75973 .37792 .77129 .37427 .76623 .36792 Mtetra
.653 .769 .934 r
.76623 .36792 .77129 .37427 .7829 .37059 .77787 .36421 Mtetra
.655 .77 .934 r
.77787 .36421 .7829 .37059 .79455 .36686 .78956 .36042 Mtetra
.658 .77 .932 r
.78956 .36042 .79455 .36686 .80625 .36308 .80128 .35655 Mtetra
.661 .769 .93 r
.80128 .35655 .80625 .36308 .81799 .35923 .81305 .35259 Mtetra
.663 .767 .927 r
.81305 .35259 .81799 .35923 .82978 .35534 .82486 .34856 Mtetra
.665 .764 .924 r
.82486 .34856 .82978 .35534 .8416 .35141 .83671 .34448 Mtetra
.666 .76 .92 r
.83671 .34448 .8416 .35141 .85348 .34743 .84861 .34035 Mtetra
.636 .746 .928 r
.21326 .53739 .21976 .54307 .22927 .54027 .22276 .53475 Mtetra
.636 .753 .932 r
.22276 .53475 .22927 .54027 .2388 .53744 .23231 .53208 Mtetra
.637 .76 .937 r
.23231 .53208 .2388 .53744 .24838 .53455 .24189 .52935 Mtetra
.639 .767 .94 r
.24189 .52935 .24838 .53455 .258 .5316 .25152 .52654 Mtetra
.643 .774 .943 r
.25152 .52654 .258 .5316 .26767 .52857 .2612 .52364 Mtetra
.647 .78 .945 r
.2612 .52364 .26767 .52857 .27737 .52547 .27091 .52062 Mtetra
.651 .786 .946 r
.27091 .52062 .27737 .52547 .28711 .52229 .28068 .51748 Mtetra
.655 .789 .946 r
.28068 .51748 .28711 .52229 .29689 .51906 .29048 .51425 Mtetra
.659 .79 .944 r
.29048 .51425 .29689 .51906 .30671 .51579 .30033 .51092 Mtetra
.661 .789 .943 r
.30033 .51092 .30671 .51579 .31657 .51249 .31022 .50753 Mtetra
.663 .787 .94 r
.31022 .50753 .31657 .51249 .32646 .50919 .32014 .5041 Mtetra
.663 .783 .938 r
.32014 .5041 .32646 .50919 .33639 .50588 .3301 .50066 Mtetra
.663 .779 .935 r
.3301 .50066 .33639 .50588 .34636 .50258 .3401 .49722 Mtetra
.663 .775 .933 r
.3401 .49722 .34636 .50258 .35636 .49928 .35013 .49378 Mtetra
.662 .77 .93 r
.35013 .49378 .35636 .49928 .36639 .49598 .3602 .49037 Mtetra
.661 .766 .928 r
.3602 .49037 .36639 .49598 .37647 .49269 .3703 .48697 Mtetra
.66 .763 .926 r
.3703 .48697 .37647 .49269 .38658 .48939 .38044 .48358 Mtetra
.659 .76 .925 r
.38044 .48358 .38658 .48939 .39673 .4861 .39061 .4802 Mtetra
.658 .758 .924 r
.39061 .4802 .39673 .4861 .40691 .48279 .40082 .47683 Mtetra
.658 .757 .923 r
.40082 .47683 .40691 .48279 .41714 .47948 .41107 .47347 Mtetra
.657 .755 .922 r
.41107 .47347 .41714 .47948 .4274 .47617 .42136 .4701 Mtetra
.657 .754 .922 r
.42136 .4701 .4274 .47617 .4377 .47284 .43169 .46673 Mtetra
.657 .753 .921 r
.43169 .46673 .4377 .47284 .44804 .4695 .44206 .46335 Mtetra
.656 .753 .921 r
.44206 .46335 .44804 .4695 .45843 .46615 .45247 .45996 Mtetra
.45247 .45996 .45843 .46615 .46885 .46278 .46291 .45657 Mtetra
.656 .752 .921 r
.46291 .45657 .46885 .46278 .47931 .45941 .4734 .45317 Mtetra
.4734 .45317 .47931 .45941 .48981 .45602 .48393 .44975 Mtetra
.48393 .44975 .48981 .45602 .50035 .45262 .4945 .44633 Mtetra
.656 .752 .92 r
.4945 .44633 .50035 .45262 .51093 .44921 .50511 .44289 Mtetra
.50511 .44289 .51093 .44921 .52156 .44579 .51576 .43944 Mtetra
.656 .752 .921 r
.51576 .43944 .52156 .44579 .53222 .44235 .52645 .43598 Mtetra
.52645 .43598 .53222 .44235 .54293 .4389 .53718 .4325 Mtetra
.53718 .4325 .54293 .4389 .55368 .43544 .54796 .42902 Mtetra
.655 .752 .921 r
.54796 .42902 .55368 .43544 .56447 .43196 .55878 .42552 Mtetra
.55878 .42552 .56447 .43196 .5753 .42847 .56964 .42202 Mtetra
.56964 .42202 .5753 .42847 .58618 .42497 .58054 .4185 Mtetra
.655 .752 .922 r
.58054 .4185 .58618 .42497 .59709 .42145 .59149 .41497 Mtetra
.655 .753 .922 r
.59149 .41497 .59709 .42145 .60805 .41793 .60248 .41144 Mtetra
.654 .753 .923 r
.60248 .41144 .60805 .41793 .61906 .41439 .61351 .40791 Mtetra
.654 .754 .923 r
.61351 .40791 .61906 .41439 .6301 .41084 .62459 .40437 Mtetra
.653 .755 .925 r
.62459 .40437 .6301 .41084 .6412 .40729 .63571 .40083 Mtetra
.652 .756 .926 r
.63571 .40083 .6412 .40729 .65233 .40373 .64688 .3973 Mtetra
.651 .758 .928 r
.64688 .3973 .65233 .40373 .66351 .40016 .6581 .39378 Mtetra
.65 .76 .93 r
.6581 .39378 .66351 .40016 .67474 .39659 .66936 .39027 Mtetra
.649 .763 .932 r
.66936 .39027 .67474 .39659 .68601 .39302 .68067 .38678 Mtetra
.647 .766 .935 r
.68067 .38678 .68601 .39302 .69733 .38945 .69202 .3833 Mtetra
.646 .769 .938 r
.69202 .3833 .69733 .38945 .7087 .38589 .70343 .37982 Mtetra
.644 .773 .942 r
.70343 .37982 .7087 .38589 .72011 .38233 .71488 .37635 Mtetra
.644 .777 .944 r
.71488 .37635 .72011 .38233 .73157 .37876 .72639 .37286 Mtetra
.644 .781 .947 r
.72639 .37286 .73157 .37876 .74307 .37518 .73793 .36933 Mtetra
.646 .785 .948 r
.73793 .36933 .74307 .37518 .75463 .37157 .74953 .36574 Mtetra
.649 .788 .948 r
.74953 .36574 .75463 .37157 .76623 .36792 .76116 .36204 Mtetra
.653 .788 .947 r
.76116 .36204 .76623 .36792 .77787 .36421 .77284 .35824 Mtetra
.658 .788 .944 r
.77284 .35824 .77787 .36421 .78956 .36042 .78455 .35431 Mtetra
.663 .786 .94 r
.78455 .35431 .78956 .36042 .80128 .35655 .7963 .35026 Mtetra
.667 .782 .935 r
.7963 .35026 .80128 .35655 .81305 .35259 .80809 .3461 Mtetra
.67 .777 .93 r
.80809 .3461 .81305 .35259 .82486 .34856 .81992 .34186 Mtetra
.671 .771 .925 r
.81992 .34186 .82486 .34856 .83671 .34448 .83179 .33755 Mtetra
.672 .765 .92 r
.83179 .33755 .83671 .34448 .84861 .34035 .8437 .33321 Mtetra
.627 .744 .931 r
.20671 .53168 .21326 .53739 .22276 .53475 .21622 .5292 Mtetra
.626 .75 .936 r
.21622 .5292 .22276 .53475 .23231 .53208 .22576 .52672 Mtetra
.626 .758 .942 r
.22576 .52672 .23231 .53208 .24189 .52935 .23535 .52419 Mtetra
.628 .767 .946 r
.23535 .52419 .24189 .52935 .25152 .52654 .24498 .5216 Mtetra
.631 .776 .951 r
.24498 .5216 .25152 .52654 .2612 .52364 .25466 .51889 Mtetra
.635 .786 .954 r
.25466 .51889 .2612 .52364 .27091 .52062 .26439 .51606 Mtetra
.641 .796 .957 r
.26439 .51606 .27091 .52062 .28068 .51748 .27416 .51306 Mtetra
.647 .803 .958 r
.27416 .51306 .28068 .51748 .29048 .51425 .28399 .50991 Mtetra
.654 .809 .958 r
.28399 .50991 .29048 .51425 .30033 .51092 .29386 .50659 Mtetra
.659 .811 .956 r
.29386 .50659 .30033 .51092 .31022 .50753 .30377 .50316 Mtetra
.663 .811 .954 r
.30377 .50316 .31022 .50753 .32014 .5041 .31373 .49963 Mtetra
.666 .809 .952 r
.31373 .49963 .32014 .5041 .3301 .50066 .32373 .49605 Mtetra
.667 .804 .949 r
.32373 .49605 .3301 .50066 .3401 .49722 .33376 .49244 Mtetra
.667 .799 .946 r
.33376 .49244 .3401 .49722 .35013 .49378 .34382 .48884 Mtetra
.666 .793 .943 r
.34382 .48884 .35013 .49378 .3602 .49037 .35392 .48526 Mtetra
.665 .788 .94 r
.35392 .48526 .3602 .49037 .3703 .48697 .36406 .4817 Mtetra
.663 .782 .937 r
.36406 .4817 .3703 .48697 .38044 .48358 .37423 .47817 Mtetra
.662 .777 .935 r
.37423 .47817 .38044 .48358 .39061 .4802 .38444 .47467 Mtetra
.661 .773 .933 r
.38444 .47467 .39061 .4802 .40082 .47683 .39468 .47118 Mtetra
.66 .77 .931 r
.39468 .47118 .40082 .47683 .41107 .47347 .40496 .46772 Mtetra
.659 .767 .929 r
.40496 .46772 .41107 .47347 .42136 .4701 .41528 .46427 Mtetra
.658 .765 .928 r
.41528 .46427 .42136 .4701 .43169 .46673 .42563 .46082 Mtetra
.658 .763 .927 r
.42563 .46082 .43169 .46673 .44206 .46335 .43603 .45738 Mtetra
.657 .761 .926 r
.43603 .45738 .44206 .46335 .45247 .45996 .44646 .45395 Mtetra
.657 .76 .926 r
.44646 .45395 .45247 .45996 .46291 .45657 .45693 .4505 Mtetra
.656 .759 .925 r
.45693 .4505 .46291 .45657 .4734 .45317 .46745 .44706 Mtetra
.656 .758 .925 r
.46745 .44706 .4734 .45317 .48393 .44975 .478 .44361 Mtetra
.478 .44361 .48393 .44975 .4945 .44633 .4886 .44015 Mtetra
.4886 .44015 .4945 .44633 .50511 .44289 .49923 .43668 Mtetra
.656 .757 .925 r
.49923 .43668 .50511 .44289 .51576 .43944 .50991 .43321 Mtetra
.655 .757 .925 r
.50991 .43321 .51576 .43944 .52645 .43598 .52063 .42973 Mtetra
.52063 .42973 .52645 .43598 .53718 .4325 .53139 .42624 Mtetra
.53139 .42624 .53718 .4325 .54796 .42902 .5422 .42274 Mtetra
.654 .758 .926 r
.5422 .42274 .54796 .42902 .55878 .42552 .55304 .41924 Mtetra
.55304 .41924 .55878 .42552 .56964 .42202 .56393 .41573 Mtetra
.654 .759 .927 r
.56393 .41573 .56964 .42202 .58054 .4185 .57487 .41222 Mtetra
.653 .76 .928 r
.57487 .41222 .58054 .4185 .59149 .41497 .58584 .4087 Mtetra
.652 .761 .929 r
.58584 .4087 .59149 .41497 .60248 .41144 .59687 .4052 Mtetra
.651 .762 .931 r
.59687 .4052 .60248 .41144 .61351 .40791 .60793 .4017 Mtetra
.65 .764 .933 r
.60793 .4017 .61351 .40791 .62459 .40437 .61904 .39821 Mtetra
.648 .766 .935 r
.61904 .39821 .62459 .40437 .63571 .40083 .6302 .39473 Mtetra
.647 .769 .938 r
.6302 .39473 .63571 .40083 .64688 .3973 .64141 .39128 Mtetra
.645 .772 .941 r
.64141 .39128 .64688 .3973 .6581 .39378 .65266 .38786 Mtetra
.642 .775 .944 r
.65266 .38786 .6581 .39378 .66936 .39027 .66396 .38446 Mtetra
.64 .78 .948 r
.66396 .38446 .66936 .39027 .68067 .38678 .67531 .38109 Mtetra
.637 .784 .952 r
.67531 .38109 .68067 .38678 .69202 .3833 .68671 .37774 Mtetra
.635 .79 .956 r
.68671 .37774 .69202 .3833 .70343 .37982 .69816 .37438 Mtetra
.634 .795 .959 r
.69816 .37438 .70343 .37982 .71488 .37635 .70966 .37101 Mtetra
.635 .8 .962 r
.70966 .37101 .71488 .37635 .72639 .37286 .7212 .36757 Mtetra
.638 .804 .963 r
.7212 .36757 .72639 .37286 .73793 .36933 .73279 .36404 Mtetra
.643 .807 .962 r
.73279 .36404 .73793 .36933 .74953 .36574 .74442 .36039 Mtetra
.65 .808 .959 r
.74442 .36039 .74953 .36574 .76116 .36204 .75608 .35656 Mtetra
.657 .807 .955 r
.75608 .35656 .76116 .36204 .77284 .35824 .76779 .35256 Mtetra
.665 .803 .949 r
.76779 .35256 .77284 .35824 .78455 .35431 .77952 .34839 Mtetra
.671 .798 .942 r
.77952 .34839 .78455 .35431 .7963 .35026 .79129 .34408 Mtetra
.675 .79 .936 r
.79129 .34408 .7963 .35026 .80809 .3461 .8031 .33965 Mtetra
.678 .783 .929 r
.8031 .33965 .80809 .3461 .81992 .34186 .81494 .33515 Mtetra
.679 .775 .923 r
.81494 .33515 .81992 .34186 .83179 .33755 .82683 .33059 Mtetra
.679 .768 .918 r
.82683 .33059 .83179 .33755 .8437 .33321 .83876 .32602 Mtetra
.621 .742 .933 r
.20012 .52592 .20671 .53168 .21622 .5292 .20963 .52354 Mtetra
.618 .746 .937 r
.20963 .52354 .21622 .5292 .22576 .52672 .21918 .52119 Mtetra
.616 .751 .942 r
.21918 .52119 .22576 .52672 .23535 .52419 .22877 .51885 Mtetra
.615 .758 .947 r
.22877 .51885 .23535 .52419 .24498 .5216 .2384 .5165 Mtetra
.614 .768 .953 r
.2384 .5165 .24498 .5216 .25466 .51889 .24807 .51411 Mtetra
.615 .781 .96 r
.24807 .51411 .25466 .51889 .26439 .51606 .2578 .51162 Mtetra
.619 .796 .967 r
.2578 .51162 .26439 .51606 .27416 .51306 .26757 .50898 Mtetra
.624 .812 .973 r
.26757 .50898 .27416 .51306 .28399 .50991 .27739 .50615 Mtetra
.631 .828 .976 r
.27739 .50615 .28399 .50991 .29386 .50659 .28727 .50309 Mtetra
.638 .841 .978 r
.28727 .50309 .29386 .50659 .30377 .50316 .29721 .49983 Mtetra
.646 .85 .978 r
.29721 .49983 .30377 .50316 .31373 .49963 .30719 .49636 Mtetra
.653 .855 .977 r
.30719 .49636 .31373 .49963 .32373 .49605 .31722 .49275 Mtetra
.658 .856 .975 r
.31722 .49275 .32373 .49605 .33376 .49244 .32728 .48902 Mtetra
.663 .852 .973 r
.32728 .48902 .33376 .49244 .34382 .48884 .33739 .48523 Mtetra
.665 .846 .969 r
.33739 .48523 .34382 .48884 .35392 .48526 .34754 .48142 Mtetra
.667 .839 .966 r
.34754 .48142 .35392 .48526 .36406 .4817 .35771 .47761 Mtetra
.667 .83 .962 r
.35771 .47761 .36406 .4817 .37423 .47817 .36792 .47383 Mtetra
.667 .821 .958 r
.36792 .47383 .37423 .47817 .38444 .47467 .37817 .47008 Mtetra
.665 .812 .954 r
.37817 .47008 .38444 .47467 .39468 .47118 .38845 .46638 Mtetra
.664 .804 .95 r
.38845 .46638 .39468 .47118 .40496 .46772 .39877 .46271 Mtetra
.663 .797 .946 r
.39877 .46271 .40496 .46772 .41528 .46427 .40912 .45908 Mtetra
.662 .791 .943 r
.40912 .45908 .41528 .46427 .42563 .46082 .41951 .45549 Mtetra
.66 .785 .941 r
.41951 .45549 .42563 .46082 .43603 .45738 .42993 .45191 Mtetra
.659 .781 .939 r
.42993 .45191 .43603 .45738 .44646 .45395 .4404 .44836 Mtetra
.658 .778 .937 r
.4404 .44836 .44646 .45395 .45693 .4505 .4509 .44483 Mtetra
.658 .775 .936 r
.4509 .44483 .45693 .4505 .46745 .44706 .46144 .44131 Mtetra
.657 .773 .935 r
.46144 .44131 .46745 .44706 .478 .44361 .47203 .43779 Mtetra
.656 .771 .934 r
.47203 .43779 .478 .44361 .4886 .44015 .48265 .43428 Mtetra
.655 .77 .934 r
.48265 .43428 .4886 .44015 .49923 .43668 .49332 .43078 Mtetra
.655 .769 .933 r
.49332 .43078 .49923 .43668 .50991 .43321 .50402 .42728 Mtetra
.654 .769 .934 r
.50402 .42728 .50991 .43321 .52063 .42973 .51477 .42379 Mtetra
.653 .769 .934 r
.51477 .42379 .52063 .42973 .53139 .42624 .52556 .4203 Mtetra
.652 .77 .935 r
.52556 .4203 .53139 .42624 .5422 .42274 .5364 .41681 Mtetra
.651 .771 .936 r
.5364 .41681 .5422 .42274 .55304 .41924 .54727 .41334 Mtetra
.65 .772 .938 r
.54727 .41334 .55304 .41924 .56393 .41573 .55819 .40988 Mtetra
.648 .774 .94 r
.55819 .40988 .56393 .41573 .57487 .41222 .56916 .40643 Mtetra
.646 .777 .943 r
.56916 .40643 .57487 .41222 .58584 .4087 .58017 .403 Mtetra
.644 .78 .946 r
.58017 .403 .58584 .4087 .59687 .4052 .59123 .3996 Mtetra
.641 .784 .95 r
.59123 .3996 .59687 .4052 .60793 .4017 .60233 .39623 Mtetra
.638 .789 .955 r
.60233 .39623 .60793 .4017 .61904 .39821 .61348 .3929 Mtetra
.634 .795 .96 r
.61348 .3929 .61904 .39821 .6302 .39473 .62468 .3896 Mtetra
.629 .801 .965 r
.62468 .3896 .6302 .39473 .64141 .39128 .63593 .38635 Mtetra
.624 .808 .971 r
.63593 .38635 .64141 .39128 .65266 .38786 .64723 .38314 Mtetra
.618 .815 .976 r
.64723 .38314 .65266 .38786 .66396 .38446 .65857 .37995 Mtetra
.613 .823 .981 r
.65857 .37995 .66396 .38446 .67531 .38109 .66997 .37677 Mtetra
.609 .83 .984 r
.66997 .37677 .67531 .38109 .68671 .37774 .68142 .37356 Mtetra
.608 .837 .987 r
.68142 .37356 .68671 .37774 .69816 .37438 .69292 .37029 Mtetra
.611 .842 .987 r
.69292 .37029 .69816 .37438 .70966 .37101 .70446 .3669 Mtetra
.619 .845 .986 r
.70446 .3669 .70966 .37101 .7212 .36757 .71604 .36335 Mtetra
.631 .847 .982 r
.71604 .36335 .7212 .36757 .73279 .36404 .72766 .3596 Mtetra
.645 .843 .976 r
.72766 .3596 .73279 .36404 .74442 .36039 .73931 .35562 Mtetra
.66 .837 .968 r
.73931 .35562 .74442 .36039 .75608 .35656 .75099 .35141 Mtetra
.671 .827 .958 r
.75099 .35141 .75608 .35656 .76779 .35256 .76271 .347 Mtetra
.679 .814 .948 r
.76271 .347 .76779 .35256 .77952 .34839 .77445 .34242 Mtetra
.684 .802 .938 r
.77445 .34242 .77952 .34839 .79129 .34408 .78623 .33773 Mtetra
.685 .79 .929 r
.78623 .33773 .79129 .34408 .8031 .33965 .79805 .333 Mtetra
.686 .781 .923 r
.79805 .333 .8031 .33965 .81494 .33515 .80992 .32824 Mtetra
.685 .773 .918 r
.80992 .32824 .81494 .33515 .82683 .33059 .82183 .32349 Mtetra
.683 .767 .915 r
.82183 .32349 .82683 .33059 .83876 .32602 .83378 .31877 Mtetra
.624 .743 .932 r
.19348 .52013 .20012 .52592 .20963 .52354 .20301 .51767 Mtetra
.619 .74 .933 r
.20301 .51767 .20963 .52354 .21918 .52119 .21258 .51531 Mtetra
.615 .739 .934 r
.21258 .51531 .21918 .52119 .22877 .51885 .22219 .51303 Mtetra
.61 .74 .938 r
.22219 .51303 .22877 .51885 .2384 .5165 .23182 .51083 Mtetra
.603 .744 .944 r
.23182 .51083 .2384 .5165 .24807 .51411 .24149 .50871 Mtetra
.6 .754 .952 r
.24149 .50871 .24807 .51411 .2578 .51162 .2512 .5066 Mtetra
.598 .769 .961 r
.2512 .5066 .2578 .51162 .26757 .50898 .26096 .50442 Mtetra
.599 .788 .971 r
.26096 .50442 .26757 .50898 .27739 .50615 .27077 .5021 Mtetra
.604 .811 .979 r
.27077 .5021 .27739 .50615 .28727 .50309 .28064 .49953 Mtetra
.611 .833 .985 r
.28064 .49953 .28727 .50309 .29721 .49983 .29057 .4967 Mtetra
.62 .853 .987 r
.29057 .4967 .29721 .49983 .30719 .49636 .30056 .49355 Mtetra
.629 .868 .987 r
.30056 .49355 .30719 .49636 .31722 .49275 .3106 .49013 Mtetra
.638 .879 .986 r
.3106 .49013 .31722 .49275 .32728 .48902 .3207 .48648 Mtetra
.646 .884 .984 r
.3207 .48648 .32728 .48902 .33739 .48523 .33084 .48265 Mtetra
.652 .885 .982 r
.33084 .48265 .33739 .48523 .34754 .48142 .34103 .47871 Mtetra
.657 .882 .981 r
.34103 .47871 .34754 .48142 .35771 .47761 .35125 .47471 Mtetra
.661 .876 .979 r
.35125 .47471 .35771 .47761 .36792 .47383 .36151 .4707 Mtetra
.663 .869 .977 r
.36151 .4707 .36792 .47383 .37817 .47008 .3718 .46671 Mtetra
.664 .86 .974 r
.3718 .46671 .37817 .47008 .38845 .46638 .38212 .46275 Mtetra
.664 .851 .972 r
.38212 .46275 .38845 .46638 .39877 .46271 .39248 .45885 Mtetra
.663 .843 .969 r
.39248 .45885 .39877 .46271 .40912 .45908 .40287 .455 Mtetra
.662 .835 .966 r
.40287 .455 .40912 .45908 .41951 .45549 .4133 .4512 Mtetra
.66 .827 .964 r
.4133 .4512 .41951 .45549 .42993 .45191 .42376 .44745 Mtetra
.659 .821 .961 r
.42376 .44745 .42993 .45191 .4404 .44836 .43426 .44374 Mtetra
.658 .815 .959 r
.43426 .44374 .4404 .44836 .4509 .44483 .4448 .44008 Mtetra
.656 .811 .958 r
.4448 .44008 .4509 .44483 .46144 .44131 .45537 .43645 Mtetra
.655 .807 .956 r
.45537 .43645 .46144 .44131 .47203 .43779 .46599 .43285 Mtetra
.653 .805 .956 r
.46599 .43285 .47203 .43779 .48265 .43428 .47665 .42928 Mtetra
.652 .803 .955 r
.47665 .42928 .48265 .43428 .49332 .43078 .48734 .42573 Mtetra
.65 .801 .955 r
.48734 .42573 .49332 .43078 .50402 .42728 .49808 .42221 Mtetra
.648 .801 .956 r
.49808 .42221 .50402 .42728 .51477 .42379 .50886 .41871 Mtetra
.646 .801 .957 r
.50886 .41871 .51477 .42379 .52556 .4203 .51969 .41524 Mtetra
.644 .802 .959 r
.51969 .41524 .52556 .4203 .5364 .41681 .53055 .41179 Mtetra
.641 .803 .961 r
.53055 .41179 .5364 .41681 .54727 .41334 .54146 .40837 Mtetra
.638 .806 .963 r
.54146 .40837 .54727 .41334 .55819 .40988 .55242 .40499 Mtetra
.634 .808 .966 r
.55242 .40499 .55819 .40988 .56916 .40643 .56342 .40165 Mtetra
.63 .812 .97 r
.56342 .40165 .56916 .40643 .58017 .403 .57447 .39836 Mtetra
.624 .816 .974 r
.57447 .39836 .58017 .403 .59123 .3996 .58556 .39511 Mtetra
.618 .821 .979 r
.58556 .39511 .59123 .3996 .60233 .39623 .59671 .39192 Mtetra
.61 .827 .983 r
.59671 .39192 .60233 .39623 .61348 .3929 .6079 .38879 Mtetra
.602 .833 .988 r
.6079 .38879 .61348 .3929 .62468 .3896 .61915 .3857 Mtetra
.592 .839 .991 r
.61915 .3857 .62468 .3896 .63593 .38635 .63044 .38266 Mtetra
.584 .845 .994 r
.63044 .38266 .63593 .38635 .64723 .38314 .64179 .37963 Mtetra
.577 .851 .996 r
.64179 .37963 .64723 .38314 .65857 .37995 .65319 .37659 Mtetra
.574 .856 .996 r
.65319 .37659 .65857 .37995 .66997 .37677 .66464 .37349 Mtetra
.577 .862 .996 r
.66464 .37349 .66997 .37677 .68142 .37356 .67613 .37028 Mtetra
.587 .866 .995 r
.67613 .37028 .68142 .37356 .69292 .37029 .68766 .36689 Mtetra
.605 .869 .992 r
.68766 .36689 .69292 .37029 .70446 .3669 .69924 .36325 Mtetra
.627 .868 .988 r
.69924 .36325 .70446 .3669 .71604 .36335 .71084 .35933 Mtetra
.651 .863 .98 r
.71084 .35933 .71604 .36335 .72766 .3596 .72248 .35508 Mtetra
.67 .851 .969 r
.72248 .35508 .72766 .3596 .73931 .35562 .73414 .35055 Mtetra
.685 .835 .955 r
.73414 .35055 .73931 .35562 .75099 .35141 .74582 .34576 Mtetra
.693 .817 .941 r
.74582 .34576 .75099 .35141 .76271 .347 .75754 .34081 Mtetra
.696 .799 .929 r
.75754 .34081 .76271 .347 .77445 .34242 .76929 .33579 Mtetra
.695 .785 .92 r
.76929 .33579 .77445 .34242 .78623 .33773 .78109 .33076 Mtetra
.691 .773 .914 r
.78109 .33076 .78623 .33773 .79805 .333 .79293 .32582 Mtetra
.688 .766 .911 r
.79293 .32582 .79805 .333 .80992 .32824 .80482 .32095 Mtetra
.684 .762 .91 r
.80482 .32095 .80992 .32824 .82183 .32349 .81677 .31617 Mtetra
.681 .76 .911 r
.81677 .31617 .82183 .32349 .83378 .31877 .82876 .31146 Mtetra
.643 .748 .926 r
.18679 .51429 .19348 .52013 .20301 .51767 .19639 .51142 Mtetra
.638 .733 .917 r
.19639 .51142 .20301 .51767 .21258 .51531 .20601 .50865 Mtetra
.632 .719 .91 r
.20601 .50865 .21258 .51531 .22219 .51303 .21566 .50603 Mtetra
.624 .706 .905 r
.21566 .50603 .22219 .51303 .23182 .51083 .22533 .5036 Mtetra
.613 .696 .903 r
.22533 .5036 .23182 .51083 .24149 .50871 .23502 .50143 Mtetra
.604 .692 .905 r
.23502 .50143 .24149 .50871 .2512 .5066 .24473 .49944 Mtetra
.595 .694 .911 r
.24473 .49944 .2512 .5066 .26096 .50442 .25447 .49763 Mtetra
.59 .704 .922 r
.25447 .49763 .26096 .50442 .27077 .5021 .26425 .49587 Mtetra
.588 .723 .937 r
.26425 .49587 .27077 .5021 .28064 .49953 .27409 .49405 Mtetra
.588 .752 .956 r
.27409 .49405 .28064 .49953 .29057 .4967 .28397 .49207 Mtetra
.592 .787 .973 r
.28397 .49207 .29057 .4967 .30056 .49355 .29393 .48981 Mtetra
.593 .823 .987 r
.29393 .48981 .30056 .49355 .3106 .49013 .30395 .48725 Mtetra
.594 .857 .994 r
.30395 .48725 .3106 .49013 .3207 .48648 .31403 .48431 Mtetra
.59 .883 .992 r
.31403 .48431 .3207 .48648 .33084 .48265 .32417 .48106 Mtetra
.586 .901 .984 r
.32417 .48106 .33084 .48265 .34103 .47871 .33437 .47752 Mtetra
.583 .912 .976 r
.33437 .47752 .34103 .47871 .35125 .47471 .34462 .47375 Mtetra
.581 .918 .969 r
.34462 .47375 .35125 .47471 .36151 .4707 .35491 .46983 Mtetra
.582 .92 .965 r
.35491 .46983 .36151 .4707 .3718 .46671 .36524 .46581 Mtetra
.585 .921 .966 r
.36524 .46581 .3718 .46671 .38212 .46275 .37561 .46174 Mtetra
.591 .921 .968 r
.37561 .46174 .38212 .46275 .39248 .45885 .38602 .45765 Mtetra
.596 .919 .972 r
.38602 .45765 .39248 .45885 .40287 .455 .39646 .45359 Mtetra
.601 .916 .977 r
.39646 .45359 .40287 .455 .4133 .4512 .40694 .44957 Mtetra
.606 .911 .981 r
.40694 .44957 .4133 .4512 .42376 .44745 .41745 .4456 Mtetra
.609 .906 .984 r
.41745 .4456 .42376 .44745 .43426 .44374 .42799 .44168 Mtetra
.611 .901 .986 r
.42799 .44168 .43426 .44374 .4448 .44008 .43858 .43783 Mtetra
.612 .896 .988 r
.43858 .43783 .4448 .44008 .45537 .43645 .4492 .43404 Mtetra
.612 .891 .989 r
.4492 .43404 .45537 .43645 .46599 .43285 .45985 .43032 Mtetra
.61 .887 .99 r
.45985 .43032 .46599 .43285 .47665 .42928 .47055 .42665 Mtetra
.608 .883 .991 r
.47055 .42665 .47665 .42928 .48734 .42573 .48129 .42305 Mtetra
.604 .881 .991 r
.48129 .42305 .48734 .42573 .49808 .42221 .49207 .4195 Mtetra
.599 .879 .992 r
.49207 .4195 .49808 .42221 .50886 .41871 .50289 .41602 Mtetra
.592 .878 .993 r
.50289 .41602 .50886 .41871 .51969 .41524 .51375 .41259 Mtetra
.584 .878 .993 r
.51375 .41259 .51969 .41524 .53055 .41179 .52466 .40923 Mtetra
.574 .878 .993 r
.52466 .40923 .53055 .41179 .54146 .40837 .53561 .40593 Mtetra
.562 .878 .992 r
.53561 .40593 .54146 .40837 .55242 .40499 .54661 .40269 Mtetra
.548 .879 .991 r
.54661 .40269 .55242 .40499 .56342 .40165 .55766 .39952 Mtetra
.533 .878 .987 r
.55766 .39952 .56342 .40165 .57447 .39836 .56875 .39641 Mtetra
.515 .877 .982 r
.56875 .39641 .57447 .39836 .58556 .39511 .5799 .39335 Mtetra
.498 .875 .976 r
.5799 .39335 .58556 .39511 .59671 .39192 .59109 .39033 Mtetra
.481 .872 .968 r
.59109 .39033 .59671 .39192 .6079 .38879 .60234 .38733 Mtetra
.47 .871 .961 r
.60234 .38733 .6079 .38879 .61915 .3857 .61363 .38432 Mtetra
.465 .871 .957 r
.61363 .38432 .61915 .3857 .63044 .38266 .62498 .38127 Mtetra
.473 .875 .958 r
.62498 .38127 .63044 .38266 .64179 .37963 .63637 .37811 Mtetra
.494 .882 .964 r
.63637 .37811 .64179 .37963 .65319 .37659 .64781 .37478 Mtetra
.529 .891 .975 r
.64781 .37478 .65319 .37659 .66464 .37349 .65929 .37123 Mtetra
.575 .898 .985 r
.65929 .37123 .66464 .37349 .67613 .37028 .6708 .36738 Mtetra
.621 .894 .988 r
.6708 .36738 .67613 .37028 .68766 .36689 .68235 .3632 Mtetra
.661 .879 .979 r
.68235 .3632 .68766 .36689 .69924 .36325 .69392 .35864 Mtetra
.688 .852 .961 r
.69392 .35864 .69924 .36325 .71084 .35933 .70551 .35375 Mtetra
.703 .821 .938 r
.70551 .35375 .71084 .35933 .72248 .35508 .71713 .34857 Mtetra
.707 .79 .916 r
.71713 .34857 .72248 .35508 .73414 .35055 .72877 .3432 Mtetra
.706 .763 .897 r
.72877 .3432 .73414 .35055 .74582 .34576 .74045 .33777 Mtetra
.701 .744 .884 r
.74045 .33777 .74582 .34576 .75754 .34081 .75217 .33239 Mtetra
.694 .729 .878 r
.75217 .33239 .75754 .34081 .76929 .33579 .76395 .32718 Mtetra
.687 .722 .877 r
.76395 .32718 .76929 .33579 .78109 .33076 .77577 .32216 Mtetra
.679 .72 .88 r
.77577 .32216 .78109 .33076 .79293 .32582 .78767 .3174 Mtetra
.674 .724 .887 r
.78767 .3174 .79293 .32582 .80482 .32095 .79962 .31283 Mtetra
.67 .732 .896 r
.79962 .31283 .80482 .32095 .81677 .31617 .81163 .30841 Mtetra
.666 .742 .907 r
.81163 .30841 .81677 .31617 .82876 .31146 .82371 .3041 Mtetra
.67 .755 .914 r
.18006 .50842 .18679 .51429 .19639 .51142 .18974 .50486 Mtetra
.666 .732 .899 r
.18974 .50486 .19639 .51142 .20601 .50865 .19945 .50138 Mtetra
.657 .709 .886 r
.19945 .50138 .20601 .50865 .21566 .50603 .20918 .49808 Mtetra
.646 .687 .874 r
.20918 .49808 .21566 .50603 .22533 .5036 .21892 .49504 Mtetra
.631 .666 .866 r
.21892 .49504 .22533 .5036 .23502 .50143 .22866 .49238 Mtetra
.616 .649 .86 r
.22866 .49238 .23502 .50143 .24473 .49944 .2384 .49011 Mtetra
.599 .636 .859 r
.2384 .49011 .24473 .49944 .25447 .49763 .24815 .48829 Mtetra
.586 .631 .863 r
.24815 .48829 .25447 .49763 .26425 .49587 .25792 .48681 Mtetra
.574 .633 .873 r
.25792 .48681 .26425 .49587 .27409 .49405 .26771 .48561 Mtetra
.567 .648 .889 r
.26771 .48561 .27409 .49405 .28397 .49207 .27755 .48449 Mtetra
.565 .673 .911 r
.27755 .48449 .28397 .49207 .29393 .48981 .28744 .4833 Mtetra
.566 .709 .938 r
.28744 .4833 .29393 .48981 .30395 .48725 .2974 .48189 Mtetra
.571 .755 .964 r
.2974 .48189 .30395 .48725 .31403 .48431 .30743 .4801 Mtetra
.574 .801 .985 r
.30743 .4801 .31403 .48431 .32417 .48106 .31753 .47791 Mtetra
.576 .844 .995 r
.31753 .47791 .32417 .48106 .33437 .47752 .32771 .47526 Mtetra
.57 .876 .994 r
.32771 .47526 .33437 .47752 .34462 .47375 .33795 .47223 Mtetra
.563 .897 .983 r
.33795 .47223 .34462 .47375 .35491 .46983 .34825 .46884 Mtetra
.554 .908 .968 r
.34825 .46884 .35491 .46983 .36524 .46581 .35861 .46519 Mtetra
.545 .913 .954 r
.35861 .46519 .36524 .46581 .37561 .46174 .36901 .46134 Mtetra
.54 .915 .943 r
.36901 .46134 .37561 .46174 .38602 .45765 .37946 .45736 Mtetra
.536 .915 .938 r
.37946 .45736 .38602 .45765 .39646 .45359 .38994 .45331 Mtetra
.534 .915 .936 r
.38994 .45331 .39646 .45359 .40694 .44957 .40046 .44924 Mtetra
.533 .914 .937 r
.40046 .44924 .40694 .44957 .41745 .4456 .41102 .44518 Mtetra
.533 .913 .94 r
.41102 .44518 .41745 .4456 .42799 .44168 .42162 .44116 Mtetra
.532 .911 .943 r
.42162 .44116 .42799 .44168 .43858 .43783 .43225 .4372 Mtetra
.531 .909 .947 r
.43225 .4372 .43858 .43783 .4492 .43404 .44292 .4333 Mtetra
.529 .907 .95 r
.44292 .4333 .4492 .43404 .45985 .43032 .45362 .42948 Mtetra
.525 .904 .953 r
.45362 .42948 .45985 .43032 .47055 .42665 .46436 .42575 Mtetra
.519 .9 .954 r
.46436 .42575 .47055 .42665 .48129 .42305 .47515 .42209 Mtetra
.512 .897 .954 r
.47515 .42209 .48129 .42305 .49207 .4195 .48597 .41853 Mtetra
.502 .893 .953 r
.48597 .41853 .49207 .4195 .50289 .41602 .49684 .41505 Mtetra
.491 .888 .951 r
.49684 .41505 .50289 .41602 .51375 .41259 .50775 .41165 Mtetra
.478 .883 .947 r
.50775 .41165 .51375 .41259 .52466 .40923 .5187 .40834 Mtetra
.464 .877 .942 r
.5187 .40834 .52466 .40923 .53561 .40593 .52971 .40511 Mtetra
.448 .871 .935 r
.52971 .40511 .53561 .40593 .54661 .40269 .54075 .40194 Mtetra
.433 .865 .928 r
.54075 .40194 .54661 .40269 .55766 .39952 .55185 .39884 Mtetra
.421 .859 .921 r
.55185 .39884 .55766 .39952 .56875 .39641 .563 .39577 Mtetra
.412 .855 .916 r
.563 .39577 .56875 .39641 .5799 .39335 .57419 .39272 Mtetra
.411 .855 .914 r
.57419 .39272 .5799 .39335 .59109 .39033 .58544 .38964 Mtetra
.42 .859 .918 r
.58544 .38964 .59109 .39033 .60234 .38733 .59673 .3865 Mtetra
.442 .869 .929 r
.59673 .3865 .60234 .38733 .61363 .38432 .60807 .38322 Mtetra
.479 .884 .946 r
.60807 .38322 .61363 .38432 .62498 .38127 .61945 .37974 Mtetra
.53 .898 .966 r
.61945 .37974 .62498 .38127 .63637 .37811 .63088 .37599 Mtetra
.588 .907 .981 r
.63088 .37599 .63637 .37811 .64781 .37478 .64234 .37187 Mtetra
.642 .9 .984 r
.64234 .37187 .64781 .37478 .65929 .37123 .65382 .36736 Mtetra
.686 .878 .97 r
.65382 .36736 .65929 .37123 .6708 .36738 .66533 .36237 Mtetra
.711 .842 .945 r
.66533 .36237 .6708 .36738 .68235 .3632 .67686 .35696 Mtetra
.723 .802 .914 r
.67686 .35696 .68235 .3632 .69392 .35864 .6884 .35115 Mtetra
.723 .764 .885 r
.6884 .35115 .69392 .35864 .70551 .35375 .69997 .3451 Mtetra
.717 .73 .861 r
.69997 .3451 .70551 .35375 .71713 .34857 .71156 .33897 Mtetra
.708 .705 .845 r
.71156 .33897 .71713 .34857 .72877 .3432 .72319 .33291 Mtetra
.696 .685 .835 r
.72319 .33291 .72877 .3432 .74045 .33777 .73487 .32713 Mtetra
.686 .674 .833 r
.73487 .32713 .74045 .33777 .75217 .33239 .74661 .32169 Mtetra
.674 .668 .836 r
.74661 .32169 .75217 .33239 .76395 .32718 .75843 .31672 Mtetra
.665 .67 .844 r
.75843 .31672 .76395 .32718 .77577 .32216 .77032 .31215 Mtetra
.657 .676 .857 r
.77032 .31215 .77577 .32216 .78767 .3174 .78229 .30797 Mtetra
.65 .688 .872 r
.78229 .30797 .78767 .3174 .79962 .31283 .79433 .30406 Mtetra
.646 .704 .889 r
.79433 .30406 .79962 .31283 .81163 .30841 .80644 .30033 Mtetra
.643 .724 .907 r
.80644 .30033 .81163 .30841 .82371 .3041 .81861 .29669 Mtetra
.697 .76 .9 r
.17328 .5025 .18006 .50842 .18974 .50486 .18306 .49817 Mtetra
.694 .736 .884 r
.18306 .49817 .18974 .50486 .19945 .50138 .19288 .49383 Mtetra
.686 .711 .867 r
.19288 .49383 .19945 .50138 .20918 .49808 .20271 .48959 Mtetra
.675 .684 .851 r
.20271 .48959 .20918 .49808 .21892 .49504 .21256 .48553 Mtetra
.662 .657 .835 r
.21256 .48553 .21892 .49504 .22866 .49238 .22241 .48175 Mtetra
.645 .628 .819 r
.22241 .48175 .22866 .49238 .2384 .49011 .23225 .47838 Mtetra
.627 .601 .805 r
.23225 .47838 .2384 .49011 .24815 .48829 .24209 .47553 Mtetra
.609 .577 .792 r
.24209 .47553 .24815 .48829 .25792 .48681 .25193 .47321 Mtetra
.591 .556 .783 r
.25193 .47321 .25792 .48681 .26771 .48561 .26175 .47149 Mtetra
.578 .542 .779 r
.26175 .47149 .26771 .48561 .27755 .48449 .27159 .47023 Mtetra
.567 .535 .779 r
.27159 .47023 .27755 .48449 .28744 .4833 .28145 .46936 Mtetra
.561 .536 .785 r
.28145 .46936 .28744 .4833 .2974 .48189 .29135 .46867 Mtetra
.56 .547 .797 r
.29135 .46867 .2974 .48189 .30743 .4801 .30131 .46798 Mtetra
.564 .568 .816 r
.30131 .46798 .30743 .4801 .31753 .47791 .31133 .46716 Mtetra
.572 .598 .841 r
.31133 .46716 .31753 .47791 .32771 .47526 .32142 .46603 Mtetra
.581 .638 .872 r
.32142 .46603 .32771 .47526 .33795 .47223 .33158 .46457 Mtetra
.593 .687 .907 r
.33158 .46457 .33795 .47223 .34825 .46884 .34182 .46269 Mtetra
.601 .741 .943 r
.34182 .46269 .34825 .46884 .35861 .46519 .35212 .46044 Mtetra
.604 .795 .972 r
.35212 .46044 .35861 .46519 .36901 .46134 .36249 .45782 Mtetra
.596 .841 .991 r
.36249 .45782 .36901 .46134 .37946 .45736 .37292 .45491 Mtetra
.578 .876 .994 r
.37292 .45491 .37946 .45736 .38994 .45331 .38341 .45174 Mtetra
.55 .894 .981 r
.38341 .45174 .38994 .45331 .40046 .44924 .39394 .44838 Mtetra
.516 .897 .957 r
.39394 .44838 .40046 .44924 .41102 .44518 .40452 .44488 Mtetra
.48 .891 .926 r
.40452 .44488 .41102 .44518 .42162 .44116 .41515 .44128 Mtetra
.446 .878 .895 r
.41515 .44128 .42162 .44116 .43225 .4372 .42582 .43764 Mtetra
.416 .864 .868 r
.42582 .43764 .43225 .4372 .44292 .4333 .43653 .43396 Mtetra
.39 .85 .844 r
.43653 .43396 .44292 .4333 .45362 .42948 .44728 .43029 Mtetra
.369 .838 .826 r
.44728 .43029 .45362 .42948 .46436 .42575 .45807 .42664 Mtetra
.353 .828 .814 r
.45807 .42664 .46436 .42575 .47515 .42209 .46891 .42302 Mtetra
.342 .821 .806 r
.46891 .42302 .47515 .42209 .48597 .41853 .47979 .41943 Mtetra
.337 .818 .804 r
.47979 .41943 .48597 .41853 .49684 .41505 .49071 .41588 Mtetra
.337 .818 .808 r
.49071 .41588 .49684 .41505 .50775 .41165 .50167 .41236 Mtetra
.344 .823 .818 r
.50167 .41236 .50775 .41165 .5187 .40834 .51268 .40886 Mtetra
.36 .832 .835 r
.51268 .40886 .5187 .40834 .52971 .40511 .52373 .40536 Mtetra
.385 .847 .859 r
.52373 .40536 .52971 .40511 .54075 .40194 .53483 .40184 Mtetra
.422 .866 .89 r
.53483 .40184 .54075 .40194 .55185 .39884 .54598 .39826 Mtetra
.469 .886 .924 r
.54598 .39826 .55185 .39884 .563 .39577 .55717 .39459 Mtetra
.524 .901 .957 r
.55717 .39459 .563 .39577 .57419 .39272 .5684 .39077 Mtetra
.582 .906 .98 r
.5684 .39077 .57419 .39272 .58544 .38964 .57968 .38675 Mtetra
.634 .894 .986 r
.57968 .38675 .58544 .38964 .59673 .3865 .59099 .38248 Mtetra
.673 .864 .972 r
.59099 .38248 .59673 .3865 .60807 .38322 .60234 .3779 Mtetra
.697 .823 .942 r
.60234 .3779 .60807 .38322 .61945 .37974 .61372 .37294 Mtetra
.708 .776 .905 r
.61372 .37294 .61945 .37974 .63088 .37599 .62513 .36759 Mtetra
.711 .731 .866 r
.62513 .36759 .63088 .37599 .64234 .37187 .63655 .36181 Mtetra
.707 .691 .832 r
.63655 .36181 .64234 .37187 .65382 .36736 .648 .35567 Mtetra
.701 .658 .804 r
.648 .35567 .65382 .36736 .66533 .36237 .65947 .34921 Mtetra
.694 .632 .783 r
.65947 .34921 .66533 .36237 .67686 .35696 .67095 .34259 Mtetra
.685 .612 .768 r
.67095 .34259 .67686 .35696 .6884 .35115 .68247 .33597 Mtetra
.677 .598 .76 r
.68247 .33597 .6884 .35115 .69997 .3451 .69402 .32953 Mtetra
.668 .589 .758 r
.69402 .32953 .69997 .3451 .71156 .33897 .70562 .32348 Mtetra
.66 .586 .761 r
.70562 .32348 .71156 .33897 .72319 .33291 .71729 .3179 Mtetra
.651 .587 .77 r
.71729 .3179 .72319 .33291 .73487 .32713 .72903 .31292 Mtetra
.644 .594 .784 r
.72903 .31292 .73487 .32713 .74661 .32169 .74086 .30849 Mtetra
.636 .605 .802 r
.74086 .30849 .74661 .32169 .75843 .31672 .75277 .30461 Mtetra
.63 .621 .823 r
.75277 .30461 .75843 .31672 .77032 .31215 .76476 .30114 Mtetra
.625 .64 .846 r
.76476 .30114 .77032 .31215 .78229 .30797 .77683 .29796 Mtetra
.62 .661 .868 r
.77683 .29796 .78229 .30797 .79433 .30406 .78898 .29498 Mtetra
.617 .684 .891 r
.78898 .29498 .79433 .30406 .80644 .30033 .8012 .2921 Mtetra
.615 .709 .912 r
.8012 .2921 .80644 .30033 .81861 .29669 .81347 .28921 Mtetra
.715 .763 .89 r
.16646 .49655 .17328 .5025 .18306 .49817 .17632 .49164 Mtetra
.715 .746 .877 r
.17632 .49164 .18306 .49817 .19288 .49383 .18622 .4866 Mtetra
.711 .727 .862 r
.18622 .4866 .19288 .49383 .20271 .48959 .19616 .4815 Mtetra
.705 .704 .846 r
.19616 .4815 .20271 .48959 .21256 .48553 .20612 .4764 Mtetra
.696 .678 .828 r
.20612 .4764 .21256 .48553 .22241 .48175 .2161 .47134 Mtetra
.682 .648 .81 r
.2161 .47134 .22241 .48175 .23225 .47838 .22609 .4665 Mtetra
.665 .617 .791 r
.22609 .4665 .23225 .47838 .24209 .47553 .23608 .46202 Mtetra
.644 .584 .772 r
.23608 .46202 .24209 .47553 .25193 .47321 .24604 .45809 Mtetra
.622 .553 .757 r
.24604 .45809 .25193 .47321 .26175 .47149 .25598 .4549 Mtetra
.601 .527 .743 r
.25598 .4549 .26175 .47149 .27159 .47023 .2659 .45247 Mtetra
.58 .504 .734 r
.2659 .45247 .27159 .47023 .28145 .46936 .2758 .4509 Mtetra
.564 .489 .729 r
.2758 .4509 .28145 .46936 .29135 .46867 .28569 .45 Mtetra
.551 .48 .728 r
.28569 .45 .29135 .46867 .30131 .46798 .2956 .44969 Mtetra
.543 .479 .733 r
.2956 .44969 .30131 .46798 .31133 .46716 .30554 .44969 Mtetra
.54 .485 .743 r
.30554 .44969 .31133 .46716 .32142 .46603 .31553 .4498 Mtetra
.541 .499 .758 r
.31553 .4498 .32142 .46603 .33158 .46457 .32559 .44982 Mtetra
.547 .521 .778 r
.32559 .44982 .33158 .46457 .34182 .46269 .33573 .44957 Mtetra
.555 .549 .803 r
.33573 .44957 .34182 .46269 .35212 .46044 .34594 .44898 Mtetra
.567 .585 .831 r
.34594 .44898 .35212 .46044 .36249 .45782 .35624 .44796 Mtetra
.579 .625 .862 r
.35624 .44796 .36249 .45782 .37292 .45491 .36661 .44653 Mtetra
.591 .67 .894 r
.36661 .44653 .37292 .45491 .38341 .45174 .37705 .44468 Mtetra
.601 .714 .924 r
.37705 .44468 .38341 .45174 .39394 .44838 .38756 .44248 Mtetra
.607 .757 .95 r
.38756 .44248 .39394 .44838 .40452 .44488 .39813 .43995 Mtetra
.61 .795 .97 r
.39813 .43995 .40452 .44488 .41515 .44128 .40876 .43716 Mtetra
.608 .827 .984 r
.40876 .43716 .41515 .44128 .42582 .43764 .41944 .43415 Mtetra
.603 .851 .991 r
.41944 .43415 .42582 .43764 .43653 .43396 .43017 .43097 Mtetra
.596 .868 .993 r
.43017 .43097 .43653 .43396 .44728 .43029 .44096 .42764 Mtetra
.59 .879 .993 r
.44096 .42764 .44728 .43029 .45807 .42664 .45178 .42421 Mtetra
.587 .886 .991 r
.45178 .42421 .45807 .42664 .46891 .42302 .46266 .42068 Mtetra
.587 .89 .99 r
.46266 .42068 .46891 .42302 .47979 .41943 .47358 .41707 Mtetra
.592 .891 .989 r
.47358 .41707 .47979 .41943 .49071 .41588 .48454 .41338 Mtetra
.602 .891 .99 r
.48454 .41338 .49071 .41588 .50167 .41236 .49555 .4096 Mtetra
.617 .888 .989 r
.49555 .4096 .50167 .41236 .51268 .40886 .5066 .4057 Mtetra
.635 .88 .986 r
.5066 .4057 .51268 .40886 .52373 .40536 .5177 .40166 Mtetra
.655 .866 .979 r
.5177 .40166 .52373 .40536 .53483 .40184 .52884 .39745 Mtetra
.674 .846 .965 r
.52884 .39745 .53483 .40184 .54598 .39826 .54002 .39301 Mtetra
.69 .819 .944 r
.54002 .39301 .54598 .39826 .55717 .39459 .55123 .3883 Mtetra
.701 .787 .917 r
.55123 .3883 .55717 .39459 .5684 .39077 .56248 .38325 Mtetra
.707 .751 .886 r
.56248 .38325 .5684 .39077 .57968 .38675 .57377 .37784 Mtetra
.709 .715 .854 r
.57377 .37784 .57968 .38675 .59099 .38248 .58508 .37199 Mtetra
.707 .68 .822 r
.58508 .37199 .59099 .38248 .60234 .3779 .59641 .36572 Mtetra
.703 .649 .793 r
.59641 .36572 .60234 .3779 .61372 .37294 .60776 .359 Mtetra
.696 .621 .769 r
.60776 .359 .61372 .37294 .62513 .36759 .61912 .35192 Mtetra
.689 .598 .748 r
.61912 .35192 .62513 .36759 .63655 .36181 .6305 .34455 Mtetra
.681 .578 .733 r
.6305 .34455 .63655 .36181 .648 .35567 .6419 .33707 Mtetra
.672 .562 .722 r
.6419 .33707 .648 .35567 .65947 .34921 .65332 .32969 Mtetra
.663 .55 .716 r
.65332 .32969 .65947 .34921 .67095 .34259 .66478 .32262 Mtetra
.653 .54 .714 r
.66478 .32262 .67095 .34259 .68247 .33597 .67629 .31613 Mtetra
.643 .536 .718 r
.67629 .31613 .68247 .33597 .69402 .32953 .68787 .31034 Mtetra
.632 .535 .726 r
.68787 .31034 .69402 .32953 .70562 .32348 .69953 .30542 Mtetra
.623 .539 .739 r
.69953 .30542 .70562 .32348 .71729 .3179 .71128 .30129 Mtetra
.613 .549 .758 r
.71128 .30129 .71729 .3179 .72903 .31292 .72313 .29792 Mtetra
.606 .564 .781 r
.72313 .29792 .72903 .31292 .74086 .30849 .73507 .29512 Mtetra
.6 .584 .807 r
.73507 .29512 .74086 .30849 .75277 .30461 .7471 .2927 Mtetra
.595 .608 .835 r
.7471 .2927 .75277 .30461 .76476 .30114 .7592 .29052 Mtetra
.594 .634 .861 r
.7592 .29052 .76476 .30114 .77683 .29796 .77138 .28837 Mtetra
.592 .659 .885 r
.77138 .28837 .77683 .29796 .78898 .29498 .78363 .28623 Mtetra
.591 .682 .904 r
.78363 .28623 .78898 .29498 .8012 .2921 .79593 .28402 Mtetra
.592 .704 .921 r
.79593 .28402 .8012 .2921 .81347 .28921 .8083 .28168 Mtetra
.71 .762 .893 r
.15958 .49055 .16646 .49655 .17632 .49164 .16946 .48579 Mtetra
.716 .769 .894 r
.16946 .48579 .17632 .49164 .18622 .4866 .17937 .48084 Mtetra
.722 .773 .894 r
.17937 .48084 .18622 .4866 .19616 .4815 .18934 .47571 Mtetra
.727 .774 .89 r
.18934 .47571 .19616 .4815 .20612 .4764 .19934 .47037 Mtetra
.732 .768 .881 r
.19934 .47037 .20612 .4764 .2161 .47134 .2094 .46477 Mtetra
.731 .753 .869 r
.2094 .46477 .2161 .47134 .22609 .4665 .21949 .45906 Mtetra
.725 .728 .853 r
.21949 .45906 .22609 .4665 .23608 .46202 .22961 .45328 Mtetra
.711 .694 .832 r
.22961 .45328 .23608 .46202 .24604 .45809 .23974 .44767 Mtetra
.691 .654 .808 r
.23974 .44767 .24604 .45809 .25598 .4549 .24986 .4424 Mtetra
.666 .61 .782 r
.24986 .4424 .25598 .4549 .2659 .45247 .25997 .43764 Mtetra
.64 .567 .757 r
.25997 .43764 .2659 .45247 .2758 .4509 .27005 .43359 Mtetra
.616 .53 .734 r
.27005 .43359 .2758 .4509 .28569 .45 .28011 .43029 Mtetra
.593 .497 .715 r
.28011 .43029 .28569 .45 .2956 .44969 .29014 .42781 Mtetra
.577 .473 .699 r
.29014 .42781 .2956 .44969 .30554 .44969 .30018 .42601 Mtetra
.564 .455 .688 r
.30018 .42601 .30554 .44969 .31553 .4498 .31022 .42482 Mtetra
.557 .444 .68 r
.31022 .42482 .31553 .4498 .32559 .44982 .32029 .42404 Mtetra
.552 .437 .676 r
.32029 .42404 .32559 .44982 .33573 .44957 .3304 .42349 Mtetra
.551 .435 .675 r
.3304 .42349 .33573 .44957 .34594 .44898 .34056 .42301 Mtetra
.552 .437 .676 r
.34056 .42301 .34594 .44898 .35624 .44796 .35079 .42247 Mtetra
.555 .441 .679 r
.35079 .42247 .35624 .44796 .36661 .44653 .36108 .42176 Mtetra
.559 .448 .684 r
.36108 .42176 .36661 .44653 .37705 .44468 .37145 .4208 Mtetra
.565 .456 .689 r
.37145 .4208 .37705 .44468 .38756 .44248 .38188 .41956 Mtetra
.571 .466 .696 r
.38188 .41956 .38756 .44248 .39813 .43995 .39238 .418 Mtetra
.578 .476 .703 r
.39238 .418 .39813 .43995 .40876 .43716 .40295 .41612 Mtetra
.584 .487 .71 r
.40295 .41612 .40876 .43716 .41944 .43415 .41358 .41393 Mtetra
.591 .497 .716 r
.41358 .41393 .41944 .43415 .43017 .43097 .42427 .41143 Mtetra
.598 .507 .722 r
.42427 .41143 .43017 .43097 .44096 .42764 .43502 .40863 Mtetra
.604 .515 .726 r
.43502 .40863 .44096 .42764 .45178 .42421 .44583 .40554 Mtetra
.61 .521 .729 r
.44583 .40554 .45178 .42421 .46266 .42068 .45668 .40217 Mtetra
.615 .526 .73 r
.45668 .40217 .46266 .42068 .47358 .41707 .46759 .39852 Mtetra
.62 .529 .729 r
.46759 .39852 .47358 .41707 .48454 .41338 .47855 .3946 Mtetra
.624 .529 .727 r
.47855 .3946 .48454 .41338 .49555 .4096 .48955 .39039 Mtetra
.627 .528 .723 r
.48955 .39039 .49555 .4096 .5066 .4057 .50059 .38589 Mtetra
.63 .526 .717 r
.50059 .38589 .5066 .4057 .5177 .40166 .51168 .38109 Mtetra
.632 .522 .711 r
.51168 .38109 .5177 .40166 .52884 .39745 .5228 .37597 Mtetra
.633 .517 .703 r
.5228 .37597 .52884 .39745 .54002 .39301 .53395 .37053 Mtetra
.634 .511 .696 r
.53395 .37053 .54002 .39301 .55123 .3883 .54514 .36475 Mtetra
.634 .506 .689 r
.54514 .36475 .55123 .3883 .56248 .38325 .55636 .35865 Mtetra
.634 .501 .683 r
.55636 .35865 .56248 .38325 .57377 .37784 .5676 .35225 Mtetra
.634 .496 .677 r
.5676 .35225 .57377 .37784 .58508 .37199 .57886 .34559 Mtetra
.634 .493 .673 r
.57886 .34559 .58508 .37199 .59641 .36572 .59015 .33874 Mtetra
.633 .49 .67 r
.59015 .33874 .59641 .36572 .60776 .359 .60146 .33182 Mtetra
.631 .488 .669 r
.60146 .33182 .60776 .359 .61912 .35192 .61279 .32495 Mtetra
.629 .488 .671 r
.61279 .32495 .61912 .35192 .6305 .34455 .62416 .31832 Mtetra
.627 .489 .675 r
.62416 .31832 .6305 .34455 .6419 .33707 .63557 .3121 Mtetra
.623 .492 .683 r
.63557 .3121 .6419 .33707 .65332 .32969 .64704 .30648 Mtetra
.619 .499 .695 r
.64704 .30648 .65332 .32969 .66478 .32262 .65857 .30156 Mtetra
.612 .509 .712 r
.65857 .30156 .66478 .32262 .67629 .31613 .67018 .29749 Mtetra
.606 .524 .736 r
.67018 .29749 .67629 .31613 .68787 .31034 .68187 .29417 Mtetra
.598 .544 .766 r
.68187 .29417 .68787 .31034 .69953 .30542 .69366 .2916 Mtetra
.589 .571 .801 r
.69366 .2916 .69953 .30542 .71128 .30129 .70555 .28956 Mtetra
.58 .603 .84 r
.70555 .28956 .71128 .30129 .72313 .29792 .71751 .28788 Mtetra
.571 .636 .876 r
.71751 .28788 .72313 .29792 .73507 .29512 .72956 .28636 Mtetra
.567 .669 .907 r
.72956 .28636 .73507 .29512 .7471 .2927 .74168 .28479 Mtetra
.565 .695 .928 r
.74168 .28479 .7471 .2927 .7592 .29052 .75386 .28311 Mtetra
.571 .715 .939 r
.75386 .28311 .7592 .29052 .77138 .28837 .76609 .28116 Mtetra
.578 .726 .944 r
.76609 .28116 .77138 .28837 .78363 .28623 .77837 .279 Mtetra
.586 .73 .943 r
.77837 .279 .78363 .28623 .79593 .28402 .7907 .27664 Mtetra
.594 .73 .938 r
.7907 .27664 .79593 .28402 .8083 .28168 .80308 .27409 Mtetra
.684 .758 .907 r
.15266 .48451 .15958 .49055 .16946 .48579 .16247 .48049 Mtetra
.691 .785 .922 r
.16247 .48049 .16946 .48579 .17937 .48084 .17234 .47631 Mtetra
.701 .814 .935 r
.17234 .47631 .17937 .48084 .18934 .47571 .18225 .47187 Mtetra
.714 .842 .943 r
.18225 .47187 .18934 .47571 .19934 .47037 .19224 .46706 Mtetra
.731 .864 .943 r
.19224 .46706 .19934 .47037 .2094 .46477 .2023 .46179 Mtetra
.748 .877 .939 r
.2023 .46179 .2094 .46477 .21949 .45906 .21243 .45604 Mtetra
.766 .876 .927 r
.21243 .45604 .21949 .45906 .22961 .45328 .22263 .44975 Mtetra
.776 .858 .911 r
.22263 .44975 .22961 .45328 .23974 .44767 .23288 .44306 Mtetra
.778 .821 .887 r
.23288 .44306 .23974 .44767 .24986 .4424 .24319 .43603 Mtetra
.764 .767 .856 r
.24319 .43603 .24986 .4424 .25997 .43764 .25351 .42894 Mtetra
.739 .705 .82 r
.25351 .42894 .25997 .43764 .27005 .43359 .26384 .422 Mtetra
.706 .642 .783 r
.26384 .422 .27005 .43359 .28011 .43029 .27415 .41549 Mtetra
.672 .586 .75 r
.27415 .41549 .28011 .43029 .29014 .42781 .28443 .40968 Mtetra
.642 .539 .722 r
.28443 .40968 .29014 .42781 .30018 .42601 .29468 .40467 Mtetra
.615 .5 .699 r
.29468 .40467 .30018 .42601 .31022 .42482 .30488 .4006 Mtetra
.595 .472 .682 r
.30488 .4006 .31022 .42482 .32029 .42404 .31507 .39736 Mtetra
.579 .451 .67 r
.31507 .39736 .32029 .42404 .3304 .42349 .32526 .39492 Mtetra
.568 .436 .661 r
.32526 .39492 .3304 .42349 .34056 .42301 .33545 .39307 Mtetra
.561 .427 .655 r
.33545 .39307 .34056 .42301 .35079 .42247 .34567 .39166 Mtetra
.557 .421 .652 r
.34567 .39166 .35079 .42247 .36108 .42176 .35592 .3905 Mtetra
.555 .419 .65 r
.35592 .3905 .36108 .42176 .37145 .4208 .36623 .38944 Mtetra
.556 .419 .65 r
.36623 .38944 .37145 .4208 .38188 .41956 .3766 .38836 Mtetra
.558 .421 .651 r
.3766 .38836 .38188 .41956 .39238 .418 .38703 .38712 Mtetra
.561 .425 .653 r
.38703 .38712 .39238 .418 .40295 .41612 .39752 .38566 Mtetra
.565 .429 .655 r
.39752 .38566 .40295 .41612 .41358 .41393 .40808 .3839 Mtetra
.57 .434 .657 r
.40808 .3839 .41358 .41393 .42427 .41143 .41871 .3818 Mtetra
.575 .439 .659 r
.41871 .3818 .42427 .41143 .43502 .40863 .4294 .37933 Mtetra
.58 .444 .66 r
.4294 .37933 .43502 .40863 .44583 .40554 .44015 .37646 Mtetra
.586 .449 .661 r
.44015 .37646 .44583 .40554 .45668 .40217 .45095 .37319 Mtetra
.591 .453 .662 r
.45095 .37319 .45668 .40217 .46759 .39852 .46181 .36949 Mtetra
.596 .456 .661 r
.46181 .36949 .46759 .39852 .47855 .3946 .47273 .36539 Mtetra
.6 .459 .661 r
.47273 .36539 .47855 .3946 .48955 .39039 .48368 .36086 Mtetra
.604 .46 .659 r
.48368 .36086 .48955 .39039 .50059 .38589 .49468 .35594 Mtetra
.607 .461 .657 r
.49468 .35594 .50059 .38589 .51168 .38109 .50572 .35064 Mtetra
.61 .461 .655 r
.50572 .35064 .51168 .38109 .5228 .37597 .51679 .34499 Mtetra
.612 .461 .653 r
.51679 .34499 .5228 .37597 .53395 .37053 .5279 .33903 Mtetra
.613 .46 .651 r
.5279 .33903 .53395 .37053 .54514 .36475 .53903 .33283 Mtetra
.614 .459 .649 r
.53903 .33283 .54514 .36475 .55636 .35865 .55019 .32647 Mtetra
.613 .459 .648 r
.55019 .32647 .55636 .35865 .5676 .35225 .56138 .32008 Mtetra
.612 .458 .648 r
.56138 .32008 .5676 .35225 .57886 .34559 .57259 .31378 Mtetra
.61 .458 .65 r
.57259 .31378 .57886 .34559 .59015 .33874 .58384 .30772 Mtetra
.607 .458 .653 r
.58384 .30772 .59015 .33874 .60146 .33182 .59513 .30211 Mtetra
.604 .46 .659 r
.59513 .30211 .60146 .33182 .61279 .32495 .60647 .29709 Mtetra
.598 .463 .669 r
.60647 .29709 .61279 .32495 .62416 .31832 .61787 .29288 Mtetra
.591 .47 .683 r
.61787 .29288 .62416 .31832 .63557 .3121 .62935 .28952 Mtetra
.582 .48 .703 r
.62935 .28952 .63557 .3121 .64704 .30648 .64091 .28713 Mtetra
.572 .497 .732 r
.64091 .28713 .64704 .30648 .65857 .30156 .65257 .28557 Mtetra
.558 .523 .772 r
.65257 .28557 .65857 .30156 .67018 .29749 .66432 .28472 Mtetra
.542 .562 .825 r
.66432 .28472 .67018 .29749 .68187 .29417 .67617 .28434 Mtetra
.52 .614 .886 r
.67617 .28434 .68187 .29417 .69366 .2916 .68811 .28411 Mtetra
.492 .671 .943 r
.68811 .28411 .69366 .2916 .70555 .28956 .70012 .28384 Mtetra
.469 .725 .981 r
.70012 .28384 .70555 .28956 .71751 .28788 .7122 .28322 Mtetra
.457 .763 .995 r
.7122 .28322 .71751 .28788 .72956 .28636 .72432 .28219 Mtetra
.474 .792 .999 r
.72432 .28219 .72956 .28636 .74168 .28479 .73648 .28061 Mtetra
.507 .809 .999 r
.73648 .28061 .74168 .28479 .75386 .28311 .74868 .27854 Mtetra
.55 .815 .995 r
.74868 .27854 .75386 .28311 .76609 .28116 .76091 .27597 Mtetra
.585 .807 .984 r
.76091 .27597 .76609 .28116 .77837 .279 .77317 .27304 Mtetra
.609 .789 .967 r
.77317 .27304 .77837 .279 .7907 .27664 .78547 .26982 Mtetra
.624 .765 .947 r
.78547 .26982 .7907 .27664 .80308 .27409 .79782 .26643 Mtetra
.639 .747 .927 r
.14569 .47843 .15266 .48451 .16247 .48049 .1554 .47549 Mtetra
.639 .786 .953 r
.1554 .47549 .16247 .48049 .17234 .47631 .16516 .47246 Mtetra
.637 .83 .975 r
.16516 .47246 .17234 .47631 .18225 .47187 .17498 .46922 Mtetra
.633 .875 .987 r
.17498 .46922 .18225 .47187 .19224 .46706 .18487 .46567 Mtetra
.624 .913 .981 r
.18487 .46567 .19224 .46706 .2023 .46179 .19483 .46169 Mtetra
.603 .937 .949 r
.19483 .46169 .2023 .46179 .21243 .45604 .20488 .4572 Mtetra
.575 .941 .892 r
.20488 .4572 .21243 .45604 .22263 .44975 .21502 .45209 Mtetra
.539 .924 .819 r
.21502 .45209 .22263 .44975 .23288 .44306 .22524 .44636 Mtetra
.517 .904 .753 r
.22524 .44636 .23288 .44306 .24319 .43603 .23555 .43999 Mtetra
.504 .888 .708 r
.23555 .43999 .24319 .43603 .25351 .42894 .24591 .43311 Mtetra
.52 .893 .699 r
.24591 .43311 .25351 .42894 .26384 .422 .25633 .42582 Mtetra
.563 .919 .732 r
.25633 .42582 .26384 .422 .27415 .41549 .26678 .41837 Mtetra
.632 .959 .802 r
.26678 .41837 .27415 .41549 .28443 .40968 .27723 .41094 Mtetra
.711 .984 .887 r
.27723 .41094 .28443 .40968 .29468 .40467 .28768 .40377 Mtetra
.757 .955 .938 r
.28768 .40377 .29468 .40467 .30488 .4006 .29812 .39705 Mtetra
.757 .868 .929 r
.29812 .39705 .30488 .4006 .31507 .39736 .30854 .39086 Mtetra
.725 .765 .885 r
.30854 .39086 .31507 .39736 .32526 .39492 .31894 .3853 Mtetra
.688 .675 .832 r
.31894 .3853 .32526 .39492 .33545 .39307 .32934 .38032 Mtetra
.656 .606 .787 r
.32934 .38032 .33545 .39307 .34567 .39166 .33973 .37589 Mtetra
.632 .557 .752 r
.33973 .37589 .34567 .39166 .35592 .3905 .35013 .37191 Mtetra
.615 .521 .725 r
.35013 .37191 .35592 .3905 .36623 .38944 .36055 .36829 Mtetra
.603 .496 .705 r
.36055 .36829 .36623 .38944 .3766 .38836 .371 .36493 Mtetra
.595 .477 .689 r
.371 .36493 .3766 .38836 .38703 .38712 .38148 .36174 Mtetra
.589 .465 .678 r
.38148 .36174 .38703 .38712 .39752 .38566 .392 .35864 Mtetra
.586 .456 .669 r
.392 .35864 .39752 .38566 .40808 .3839 .40257 .35555 Mtetra
.584 .449 .663 r
.40257 .35555 .40808 .3839 .41871 .3818 .41318 .3524 Mtetra
.584 .446 .659 r
.41318 .3524 .41871 .3818 .4294 .37933 .42384 .34915 Mtetra
.584 .443 .655 r
.42384 .34915 .4294 .37933 .44015 .37646 .43455 .34575 Mtetra
.586 .443 .653 r
.43455 .34575 .44015 .37646 .45095 .37319 .44531 .34219 Mtetra
.587 .443 .652 r
.44531 .34219 .45095 .37319 .46181 .36949 .45612 .33845 Mtetra
.589 .444 .652 r
.45612 .33845 .46181 .36949 .47273 .36539 .46697 .33453 Mtetra
.591 .446 .653 r
.46697 .33453 .47273 .36539 .48368 .36086 .47787 .33045 Mtetra
.594 .449 .655 r
.47787 .33045 .48368 .36086 .49468 .35594 .48881 .32622 Mtetra
.596 .454 .658 r
.48881 .32622 .49468 .35594 .50572 .35064 .4998 .32188 Mtetra
.598 .459 .662 r
.4998 .32188 .50572 .35064 .51679 .34499 .51082 .31748 Mtetra
.601 .465 .668 r
.51082 .31748 .51679 .34499 .5279 .33903 .52188 .3131 Mtetra
.603 .474 .677 r
.52188 .3131 .5279 .33903 .53903 .33283 .53299 .30879 Mtetra
.605 .484 .688 r
.53299 .30879 .53903 .33283 .55019 .32647 .54414 .30465 Mtetra
.607 .498 .704 r
.54414 .30465 .55019 .32647 .56138 .32008 .55533 .30078 Mtetra
.608 .517 .726 r
.55533 .30078 .56138 .32008 .57259 .31378 .56657 .29727 Mtetra
.607 .543 .757 r
.56657 .29727 .57259 .31378 .58384 .30772 .57787 .29422 Mtetra
.602 .579 .8 r
.57787 .29422 .58384 .30772 .59513 .30211 .58924 .29174 Mtetra
.586 .631 .863 r
.58924 .29174 .59513 .30211 .60647 .29709 .60068 .28985 Mtetra
.54 .699 .943 r
.60068 .28985 .60647 .29709 .61787 .29288 .61219 .28861 Mtetra
.42 .756 .995 r
.61219 .28861 .61787 .29288 .62935 .28952 .6238 .28792 Mtetra
.179 .696 .885 r
.6238 .28792 .62935 .28952 .64091 .28713 .63549 .2877 Mtetra
.057 0 0 r
.63549 .2877 .64091 .28713 .65257 .28557 .64727 .28775 Mtetra
.186 0 0 r
.64727 .28775 .65257 .28557 .66432 .28472 .65913 .28785 Mtetra
.23 0 0 r
.65913 .28785 .66432 .28472 .67617 .28434 .67107 .28779 Mtetra
.217 0 0 r
.67107 .28779 .67617 .28434 .68811 .28411 .68306 .2873 Mtetra
.164 0 0 r
.68306 .2873 .68811 .28411 .70012 .28384 .69511 .28631 Mtetra
.061 0 0 r
.69511 .28631 .70012 .28384 .7122 .28322 .70719 .28465 Mtetra
0 0 0 r
.70719 .28465 .7122 .28322 .72432 .28219 .7193 .28236 Mtetra
.269 .776 .805 r
.7193 .28236 .72432 .28219 .73648 .28061 .73143 .27942 Mtetra
.437 .867 .929 r
.73143 .27942 .73648 .28061 .74868 .27854 .74359 .27595 Mtetra
.558 .893 .984 r
.74359 .27595 .74868 .27854 .76091 .27597 .75578 .27203 Mtetra
.625 .874 .988 r
.75578 .27203 .76091 .27597 .77317 .27304 .76799 .26778 Mtetra
.657 .837 .969 r
.76799 .26778 .77317 .27304 .78547 .26982 .78024 .26331 Mtetra
.669 .796 .943 r
.78024 .26331 .78547 .26982 .79782 .26643 .79252 .25872 Mtetra
.583 .731 .945 r
.13868 .4723 .14569 .47843 .1554 .47549 .14828 .47046 Mtetra
.568 .767 .972 r
.14828 .47046 .1554 .47549 .16516 .47246 .15793 .46861 Mtetra
.545 .806 .994 r
.15793 .46861 .16516 .47246 .17498 .46922 .16763 .46669 Mtetra
.506 .84 .998 r
.16763 .46669 .17498 .46922 .18487 .46567 .17739 .46461 Mtetra
.435 .852 .959 r
.17739 .46461 .18487 .46567 .19483 .46169 .18722 .46233 Mtetra
.323 .81 .844 r
.18722 .46233 .19483 .46169 .20488 .4572 .19712 .45973 Mtetra
0 0 0 r
.19712 .45973 .20488 .4572 .21502 .45209 .2071 .45672 Mtetra
.2071 .45672 .21502 .45209 .22524 .44636 .21718 .45319 Mtetra
.043 0 0 r
.21718 .45319 .22524 .44636 .23555 .43999 .22735 .44902 Mtetra
.104 0 0 r
.22735 .44902 .23555 .43999 .24591 .43311 .23761 .44415 Mtetra
.135 0 0 r
.23761 .44415 .24591 .43311 .25633 .42582 .24797 .43848 Mtetra
.147 0 .009 r
.24797 .43848 .25633 .42582 .26678 .41837 .25842 .43204 Mtetra
.139 0 .028 r
.25842 .43204 .26678 .41837 .27723 .41094 .26895 .42485 Mtetra
.117 0 .022 r
.26895 .42485 .27723 .41094 .28768 .40377 .27954 .41709 Mtetra
.074 0 0 r
.27954 .41709 .28768 .40377 .29812 .39705 .29017 .40892 Mtetra
.003 0 0 r
.29017 .40892 .29812 .39705 .30854 .39086 .30083 .40058 Mtetra
0 0 0 r
.30083 .40058 .30854 .39086 .31894 .3853 .31149 .3923 Mtetra
.31149 .3923 .31894 .3853 .32934 .38032 .32215 .38423 Mtetra
.54 .902 .703 r
.32215 .38423 .32934 .38032 .33973 .37589 .33279 .37652 Mtetra
.728 .984 .902 r
.33279 .37652 .33973 .37589 .35013 .37191 .34343 .36923 Mtetra
.773 .907 .933 r
.34343 .36923 .35013 .37191 .36055 .36829 .35406 .36242 Mtetra
.749 .795 .89 r
.35406 .36242 .36055 .36829 .371 .36493 .36468 .35606 Mtetra
.714 .705 .841 r
.36468 .35606 .371 .36493 .38148 .36174 .37531 .35017 Mtetra
.684 .641 .801 r
.37531 .35017 .38148 .36174 .392 .35864 .38594 .34469 Mtetra
.662 .596 .771 r
.38594 .34469 .392 .35864 .40257 .35555 .39659 .3396 Mtetra
.645 .564 .75 r
.39659 .3396 .40257 .35555 .41318 .3524 .40726 .33483 Mtetra
.632 .542 .734 r
.40726 .33483 .41318 .3524 .42384 .34915 .41795 .33035 Mtetra
.623 .527 .724 r
.41795 .33035 .42384 .34915 .43455 .34575 .42867 .32613 Mtetra
.616 .516 .718 r
.42867 .32613 .43455 .34575 .44531 .34219 .43943 .32214 Mtetra
.611 .51 .715 r
.43943 .32214 .44531 .34219 .45612 .33845 .45022 .31836 Mtetra
.607 .508 .716 r
.45022 .31836 .45612 .33845 .46697 .33453 .46105 .3148 Mtetra
.604 .509 .72 r
.46105 .3148 .46697 .33453 .47787 .33045 .47192 .31147 Mtetra
.601 .514 .727 r
.47192 .31147 .47787 .33045 .48881 .32622 .48283 .30839 Mtetra
.598 .522 .74 r
.48283 .30839 .48881 .32622 .4998 .32188 .49379 .30561 Mtetra
.595 .537 .759 r
.49379 .30561 .4998 .32188 .51082 .31748 .5048 .30317 Mtetra
.589 .558 .787 r
.5048 .30317 .51082 .31748 .52188 .3131 .51586 .30111 Mtetra
.579 .591 .829 r
.51586 .30111 .52188 .3131 .53299 .30879 .52698 .29948 Mtetra
.556 .641 .89 r
.52698 .29948 .53299 .30879 .54414 .30465 .53816 .29832 Mtetra
.493 .708 .966 r
.53816 .29832 .54414 .30465 .55533 .30078 .54941 .29764 Mtetra
.307 .735 .972 r
.54941 .29764 .55533 .30078 .56657 .29727 .56074 .29745 Mtetra
.043 0 0 r
.56074 .29745 .56657 .29727 .57787 .29422 .57215 .2977 Mtetra
.298 0 0 r
.57215 .2977 .57787 .29422 .58924 .29174 .58364 .29833 Mtetra
.403 0 0 r
.58364 .29833 .58924 .29174 .60068 .28985 .59522 .29919 Mtetra
.444 0 .084 r
.59522 .29919 .60068 .28985 .61219 .28861 .60688 .30012 Mtetra
.458 .035 .147 r
.60688 .30012 .61219 .28861 .6238 .28792 .61862 .30089 Mtetra
.456 .048 .177 r
.61862 .30089 .6238 .28792 .63549 .2877 .63044 .30125 Mtetra
.444 .043 .183 r
.63044 .30125 .63549 .2877 .64727 .28775 .64232 .30105 Mtetra
.421 .019 .168 r
.64232 .30105 .64727 .28775 .65913 .28785 .65424 .30008 Mtetra
.386 0 .131 r
.65424 .30008 .65913 .28785 .67107 .28779 .6662 .29832 Mtetra
.331 0 .065 r
.6662 .29832 .67107 .28779 .68306 .2873 .6782 .29574 Mtetra
.25 0 0 r
.6782 .29574 .68306 .2873 .69511 .28631 .69021 .29243 Mtetra
.12 0 0 r
.69021 .29243 .69511 .28631 .70719 .28465 .70224 .28846 Mtetra
0 0 0 r
.70224 .28846 .70719 .28465 .7193 .28236 .7143 .28394 Mtetra
.314 .791 .706 r
.7143 .28394 .7193 .28236 .73143 .27942 .72638 .27899 Mtetra
.521 .917 .893 r
.72638 .27899 .73143 .27942 .74359 .27595 .73848 .2737 Mtetra
.64 .935 .966 r
.73848 .2737 .74359 .27595 .75578 .27203 .7506 .26818 Mtetra
.691 .902 .971 r
.7506 .26818 .75578 .27203 .76799 .26778 .76276 .26251 Mtetra
.709 .856 .952 r
.76276 .26251 .76799 .26778 .78024 .26331 .77495 .25674 Mtetra
.71 .811 .928 r
.77495 .25674 .78024 .26331 .79252 .25872 .78718 .25095 Mtetra
.544 .717 .953 r
.13161 .46613 .13868 .4723 .14828 .47046 .14115 .46491 Mtetra
.528 .735 .969 r
.14115 .46491 .14828 .47046 .15793 .46861 .15074 .46374 Mtetra
.509 .755 .984 r
.15074 .46374 .15793 .46861 .16763 .46669 .16037 .46259 Mtetra
.484 .776 .996 r
.16037 .46259 .16763 .46669 .17739 .46461 .17006 .46142 Mtetra
.445 .795 .998 r
.17006 .46142 .17739 .46461 .18722 .46233 .1798 .46022 Mtetra
.392 .805 .977 r
.1798 .46022 .18722 .46233 .19712 .45973 .1896 .45888 Mtetra
.313 .791 .914 r
.1896 .45888 .19712 .45973 .2071 .45672 .19948 .45734 Mtetra
.212 .737 .792 r
.19948 .45734 .2071 .45672 .21718 .45319 .20943 .45549 Mtetra
0 0 0 r
.20943 .45549 .21718 .45319 .22735 .44902 .21947 .45322 Mtetra
.002 0 0 r
.21947 .45322 .22735 .44902 .23761 .44415 .2296 .45042 Mtetra
.08 0 0 r
.2296 .45042 .23761 .44415 .24797 .43848 .23984 .44699 Mtetra
.141 0 0 r
.23984 .44699 .24797 .43848 .25842 .43204 .25016 .44289 Mtetra
.183 0 0 r
.25016 .44289 .25842 .43204 .26895 .42485 .26059 .43806 Mtetra
.218 0 .058 r
.26059 .43806 .26895 .42485 .27954 .41709 .27109 .43258 Mtetra
.244 0 .116 r
.27109 .43258 .27954 .41709 .29017 .40892 .28167 .42651 Mtetra
.267 0 .161 r
.28167 .42651 .29017 .40892 .30083 .40058 .2923 .42001 Mtetra
.286 0 .194 r
.2923 .42001 .30083 .40058 .31149 .3923 .30297 .4132 Mtetra
.302 0 .218 r
.30297 .4132 .31149 .3923 .32215 .38423 .31368 .40625 Mtetra
.317 0 .236 r
.31368 .40625 .32215 .38423 .33279 .37652 .3244 .3993 Mtetra
.328 .001 .249 r
.3244 .3993 .33279 .37652 .34343 .36923 .33514 .39244 Mtetra
.339 .013 .257 r
.33514 .39244 .34343 .36923 .35406 .36242 .34588 .38577 Mtetra
.347 .021 .263 r
.34588 .38577 .35406 .36242 .36468 .35606 .35664 .37934 Mtetra
.354 .027 .266 r
.35664 .37934 .36468 .35606 .37531 .35017 .36741 .37318 Mtetra
.36 .032 .266 r
.36741 .37318 .37531 .35017 .38594 .34469 .37818 .36734 Mtetra
.366 .036 .266 r
.37818 .36734 .38594 .34469 .39659 .3396 .38897 .36183 Mtetra
.372 .039 .265 r
.38897 .36183 .39659 .3396 .40726 .33483 .39978 .35665 Mtetra
.378 .043 .265 r
.39978 .35665 .40726 .33483 .41795 .33035 .41061 .35183 Mtetra
.385 .047 .264 r
.41061 .35183 .41795 .33035 .42867 .32613 .42146 .34735 Mtetra
.392 .052 .265 r
.42146 .34735 .42867 .32613 .43943 .32214 .43234 .34321 Mtetra
.4 .058 .267 r
.43234 .34321 .43943 .32214 .45022 .31836 .44326 .33943 Mtetra
.408 .066 .27 r
.44326 .33943 .45022 .31836 .46105 .3148 .45421 .336 Mtetra
.417 .075 .275 r
.45421 .336 .46105 .3148 .47192 .31147 .4652 .33291 Mtetra
.426 .084 .281 r
.4652 .33291 .47192 .31147 .48283 .30839 .47623 .33018 Mtetra
.435 .094 .287 r
.47623 .33018 .48283 .30839 .49379 .30561 .48731 .3278 Mtetra
.444 .104 .293 r
.48731 .3278 .49379 .30561 .5048 .30317 .49844 .32577 Mtetra
.452 .113 .299 r
.49844 .32577 .5048 .30317 .51586 .30111 .50963 .32408 Mtetra
.46 .121 .304 r
.50963 .32408 .51586 .30111 .52698 .29948 .52089 .3227 Mtetra
.466 .128 .308 r
.52089 .3227 .52698 .29948 .53816 .29832 .5322 .32162 Mtetra
.47 .132 .31 r
.5322 .32162 .53816 .29832 .54941 .29764 .54359 .32079 Mtetra
.473 .133 .309 r
.54359 .32079 .54941 .29764 .56074 .29745 .55505 .32016 Mtetra
.474 .132 .305 r
.55505 .32016 .56074 .29745 .57215 .2977 .56658 .31963 Mtetra
.472 .126 .298 r
.56658 .31963 .57215 .2977 .58364 .29833 .57818 .31911 Mtetra
.466 .114 .285 r
.57818 .31911 .58364 .29833 .59522 .29919 .58986 .31845 Mtetra
.454 .095 .265 r
.58986 .31845 .59522 .29919 .60688 .30012 .6016 .31749 Mtetra
.435 .066 .236 r
.6016 .31749 .60688 .30012 .61862 .30089 .6134 .3161 Mtetra
.405 .021 .193 r
.6134 .3161 .61862 .30089 .63044 .30125 .62525 .3141 Mtetra
.36 0 .13 r
.62525 .3141 .63044 .30125 .64232 .30105 .63714 .31144 Mtetra
.29 0 .038 r
.63714 .31144 .64232 .30105 .65424 .30008 .64907 .30803 Mtetra
.185 0 0 r
.64907 .30803 .65424 .30008 .6662 .29832 .66102 .30393 Mtetra
.027 0 0 r
.66102 .30393 .6662 .29832 .6782 .29574 .67299 .29916 Mtetra
0 0 0 r
.67299 .29916 .6782 .29574 .69021 .29243 .68498 .29384 Mtetra
.409 .851 .751 r
.68498 .29384 .69021 .29243 .70224 .28846 .69699 .28808 Mtetra
.58 .943 .895 r
.69699 .28808 .70224 .28846 .7143 .28394 .70902 .28199 Mtetra
.675 .953 .952 r
.70902 .28199 .7143 .28394 .72638 .27899 .72107 .27567 Mtetra
.717 .926 .961 r
.72107 .27567 .72638 .27899 .73848 .2737 .73315 .26921 Mtetra
.732 .89 .952 r
.73315 .26921 .73848 .2737 .7506 .26818 .74526 .26269 Mtetra
.736 .856 .937 r
.74526 .26269 .7506 .26818 .76276 .26251 .7574 .25615 Mtetra
.734 .827 .922 r
.7574 .25615 .76276 .26251 .77495 .25674 .76958 .24961 Mtetra
.73 .801 .908 r
.76958 .24961 .77495 .25674 .78718 .25095 .7818 .24311 Mtetra
.537 .715 .954 r
.12449 .45992 .13161 .46613 .14115 .46491 .13404 .45877 Mtetra
.53 .716 .958 r
.13404 .45877 .14115 .46491 .15074 .46374 .14363 .45771 Mtetra
.521 .717 .962 r
.14363 .45771 .15074 .46374 .16037 .46259 .15326 .45673 Mtetra
.512 .72 .967 r
.15326 .45673 .16037 .46259 .17006 .46142 .16293 .45582 Mtetra
.498 .726 .974 r
.16293 .45582 .17006 .46142 .1798 .46022 .17264 .455 Mtetra
.485 .736 .982 r
.17264 .455 .1798 .46022 .1896 .45888 .18241 .45421 Mtetra
.467 .75 .991 r
.18241 .45421 .1896 .45888 .19948 .45734 .19223 .4534 Mtetra
.442 .768 .997 r
.19223 .4534 .19948 .45734 .20943 .45549 .20211 .45252 Mtetra
.401 .785 .991 r
.20211 .45252 .20943 .45549 .21947 .45322 .21206 .45153 Mtetra
.325 .783 .948 r
.21206 .45153 .21947 .45322 .2296 .45042 .22207 .45038 Mtetra
.196 .725 .822 r
.22207 .45038 .2296 .45042 .23984 .44699 .23216 .44906 Mtetra
0 0 0 r
.23216 .44906 .23984 .44699 .25016 .44289 .24231 .44752 Mtetra
.146 0 0 r
.24231 .44752 .25016 .44289 .26059 .43806 .25254 .44576 Mtetra
.259 0 0 r
.25254 .44576 .26059 .43806 .27109 .43258 .26284 .44371 Mtetra
.326 0 .067 r
.26284 .44371 .27109 .43258 .28167 .42651 .27321 .44133 Mtetra
.365 0 .165 r
.27321 .44133 .28167 .42651 .2923 .42001 .28366 .43858 Mtetra
.389 .03 .229 r
.28366 .43858 .2923 .42001 .30297 .4132 .29419 .43542 Mtetra
.404 .065 .273 r
.29419 .43542 .30297 .4132 .31368 .40625 .30478 .43189 Mtetra
.415 .089 .302 r
.30478 .43189 .31368 .40625 .3244 .3993 .31544 .42798 Mtetra
.422 .107 .323 r
.31544 .42798 .3244 .3993 .33514 .39244 .32616 .42378 Mtetra
.428 .12 .338 r
.32616 .42378 .33514 .39244 .34588 .38577 .33694 .41932 Mtetra
.432 .129 .35 r
.33694 .41932 .34588 .38577 .35664 .37934 .34776 .41468 Mtetra
.436 .137 .358 r
.34776 .41468 .35664 .37934 .36741 .37318 .35862 .40993 Mtetra
.439 .143 .364 r
.35862 .40993 .36741 .37318 .37818 .36734 .36952 .40514 Mtetra
.442 .148 .368 r
.36952 .40514 .37818 .36734 .38897 .36183 .38045 .40038 Mtetra
.446 .152 .372 r
.38045 .40038 .38897 .36183 .39978 .35665 .39142 .39572 Mtetra
.449 .156 .375 r
.39142 .39572 .39978 .35665 .41061 .35183 .40242 .39123 Mtetra
.452 .16 .377 r
.40242 .39123 .41061 .35183 .42146 .34735 .41345 .38695 Mtetra
.456 .163 .378 r
.41345 .38695 .42146 .34735 .43234 .34321 .42451 .38291 Mtetra
.459 .166 .38 r
.42451 .38291 .43234 .34321 .44326 .33943 .43561 .37914 Mtetra
.463 .169 .381 r
.43561 .37914 .44326 .33943 .45421 .336 .44675 .37563 Mtetra
.466 .172 .381 r
.44675 .37563 .45421 .336 .4652 .33291 .45793 .37237 Mtetra
.468 .173 .381 r
.45793 .37237 .4652 .33291 .47623 .33018 .46916 .36932 Mtetra
.469 .174 .381 r
.46916 .36932 .47623 .33018 .48731 .3278 .48044 .36645 Mtetra
.47 .173 .379 r
.48044 .36645 .48731 .3278 .49844 .32577 .49177 .36367 Mtetra
.469 .171 .377 r
.49177 .36367 .49844 .32577 .50963 .32408 .50315 .36094 Mtetra
.467 .167 .373 r
.50315 .36094 .50963 .32408 .52089 .3227 .51459 .35817 Mtetra
.464 .161 .367 r
.51459 .35817 .52089 .3227 .5322 .32162 .52609 .35528 Mtetra
.458 .152 .358 r
.52609 .35528 .5322 .32162 .54359 .32079 .53764 .35221 Mtetra
.45 .139 .346 r
.53764 .35221 .54359 .32079 .55505 .32016 .54924 .34889 Mtetra
.438 .12 .329 r
.54924 .34889 .55505 .32016 .56658 .31963 .56089 .34526 Mtetra
.42 .094 .305 r
.56089 .34526 .56658 .31963 .57818 .31911 .57259 .34125 Mtetra
.394 .056 .269 r
.57259 .34125 .57818 .31911 .58986 .31845 .58433 .33685 Mtetra
.356 0 .216 r
.58433 .33685 .58986 .31845 .6016 .31749 .59611 .33203 Mtetra
.295 0 .133 r
.59611 .33203 .6016 .31749 .6134 .3161 .60793 .32683 Mtetra
.196 0 .001 r
.60793 .32683 .6134 .3161 .62525 .3141 .61977 .32128 Mtetra
.032 0 0 r
.61977 .32128 .62525 .3141 .63714 .31144 .63165 .31542 Mtetra
0 0 0 r
.63165 .31542 .63714 .31144 .64907 .30803 .64355 .30932 Mtetra
.481 .893 .785 r
.64355 .30932 .64907 .30803 .66102 .30393 .65548 .303 Mtetra
.65 .961 .925 r
.65548 .303 .66102 .30393 .67299 .29916 .66743 .29647 Mtetra
.719 .942 .956 r
.66743 .29647 .67299 .29916 .68498 .29384 .67941 .28978 Mtetra
.743 .903 .949 r
.67941 .28978 .68498 .29384 .69699 .28808 .69142 .28295 Mtetra
.749 .868 .935 r
.69142 .28295 .69699 .28808 .70902 .28199 .70345 .27604 Mtetra
.748 .841 .921 r
.70345 .27604 .70902 .28199 .72107 .27567 .71551 .2691 Mtetra
.745 .821 .911 r
.71551 .2691 .72107 .27567 .73315 .26921 .72761 .26218 Mtetra
.74 .806 .904 r
.72761 .26218 .73315 .26921 .74526 .26269 .73974 .25533 Mtetra
.736 .795 .9 r
.73974 .25533 .74526 .26269 .7574 .25615 .75191 .24855 Mtetra
.733 .788 .897 r
.75191 .24855 .7574 .25615 .76958 .24961 .76412 .24184 Mtetra
.729 .783 .895 r
.76412 .24184 .76958 .24961 .7818 .24311 .77637 .23521 Mtetra
.573 .728 .947 r
.11732 .45366 .12449 .45992 .13404 .45877 .12696 .45192 Mtetra
.572 .708 .934 r
.12696 .45192 .13404 .45877 .14363 .45771 .13662 .45028 Mtetra
.569 .689 .921 r
.13662 .45028 .14363 .45771 .15326 .45673 .14632 .44878 Mtetra
.563 .671 .911 r
.14632 .44878 .15326 .45673 .16293 .45582 .15605 .44744 Mtetra
.555 .656 .903 r
.15605 .44744 .16293 .45582 .17264 .455 .16581 .4463 Mtetra
.548 .644 .897 r
.16581 .4463 .17264 .455 .18241 .45421 .1756 .44535 Mtetra
.54 .637 .895 r
.1756 .44535 .18241 .45421 .19223 .4534 .18542 .44457 Mtetra
.532 .636 .898 r
.18542 .44457 .19223 .4534 .20211 .45252 .19529 .44391 Mtetra
.525 .64 .905 r
.19529 .44391 .20211 .45252 .21206 .45153 .2052 .44335 Mtetra
.518 .65 .917 r
.2052 .44335 .21206 .45153 .22207 .45038 .21517 .44283 Mtetra
.51 .667 .933 r
.21517 .44283 .22207 .45038 .23216 .44906 .22519 .4423 Mtetra
.501 .691 .953 r
.22519 .4423 .23216 .44906 .24231 .44752 .23528 .4417 Mtetra
.488 .72 .974 r
.23528 .4417 .24231 .44752 .25254 .44576 .24543 .44097 Mtetra
.47 .753 .991 r
.24543 .44097 .25254 .44576 .26284 .44371 .25567 .44006 Mtetra
.445 .785 .998 r
.25567 .44006 .26284 .44371 .27321 .44133 .26597 .4389 Mtetra
.404 .807 .983 r
.26597 .4389 .27321 .44133 .28366 .43858 .27636 .43745 Mtetra
.344 .807 .931 r
.27636 .43745 .28366 .43858 .29419 .43542 .28682 .43566 Mtetra
.259 .769 .831 r
.28682 .43566 .29419 .43542 .30478 .43189 .29736 .43356 Mtetra
.16 .693 .692 r
.29736 .43356 .30478 .43189 .31544 .42798 .30798 .43113 Mtetra
0 0 0 r
.30798 .43113 .31544 .42798 .32616 .42378 .31866 .42842 Mtetra
.032 0 0 r
.31866 .42842 .32616 .42378 .33694 .41932 .32941 .42544 Mtetra
.106 0 0 r
.32941 .42544 .33694 .41932 .34776 .41468 .34022 .42224 Mtetra
.163 0 0 r
.34022 .42224 .34776 .41468 .35862 .40993 .35108 .41885 Mtetra
.207 0 0 r
.35108 .41885 .35862 .40993 .36952 .40514 .362 .41531 Mtetra
.241 0 0 r
.362 .41531 .36952 .40514 .38045 .40038 .37297 .41166 Mtetra
.266 0 .033 r
.37297 .41166 .38045 .40038 .39142 .39572 .38398 .40793 Mtetra
.285 0 .067 r
.38398 .40793 .39142 .39572 .40242 .39123 .39505 .40415 Mtetra
.299 0 .091 r
.39505 .40415 .40242 .39123 .41345 .38695 .40616 .40035 Mtetra
.309 0 .106 r
.40616 .40035 .41345 .38695 .42451 .38291 .41731 .39656 Mtetra
.314 0 .114 r
.41731 .39656 .42451 .38291 .43561 .37914 .42851 .39278 Mtetra
.315 0 .115 r
.42851 .39278 .43561 .37914 .44675 .37563 .43975 .389 Mtetra
.312 0 .108 r
.43975 .389 .44675 .37563 .45793 .37237 .45105 .38524 Mtetra
.303 0 .093 r
.45105 .38524 .45793 .37237 .46916 .36932 .46238 .38145 Mtetra
.288 0 .068 r
.46238 .38145 .46916 .36932 .48044 .36645 .47377 .37762 Mtetra
.265 0 .033 r
.47377 .37762 .48044 .36645 .49177 .36367 .48521 .3737 Mtetra
.23 0 0 r
.48521 .3737 .49177 .36367 .50315 .36094 .49669 .36967 Mtetra
.181 0 0 r
.49669 .36967 .50315 .36094 .51459 .35817 .50823 .36549 Mtetra
.11 0 0 r
.50823 .36549 .51459 .35817 .52609 .35528 .51981 .36111 Mtetra
.012 0 0 r
.51981 .36111 .52609 .35528 .53764 .35221 .53143 .3565 Mtetra
0 0 0 r
.53143 .3565 .53764 .35221 .54924 .34889 .5431 .35162 Mtetra
.5431 .35162 .54924 .34889 .56089 .34526 .55481 .34644 Mtetra
.455 .883 .807 r
.55481 .34644 .56089 .34526 .57259 .34125 .56655 .34093 Mtetra
.592 .945 .912 r
.56655 .34093 .57259 .34125 .58433 .33685 .57833 .33507 Mtetra
.681 .95 .956 r
.57833 .33507 .58433 .33685 .59611 .33203 .59014 .32887 Mtetra
.727 .922 .958 r
.59014 .32887 .59611 .33203 .60793 .32683 .60197 .32237 Mtetra
.747 .883 .942 r
.60197 .32237 .60793 .32683 .61977 .32128 .61383 .31559 Mtetra
.752 .843 .92 r
.61383 .31559 .61977 .32128 .63165 .31542 .62571 .30861 Mtetra
.751 .808 .898 r
.62571 .30861 .63165 .31542 .64355 .30932 .63762 .30149 Mtetra
.745 .777 .879 r
.63762 .30149 .64355 .30932 .65548 .303 .64955 .29428 Mtetra
.739 .752 .863 r
.64955 .29428 .65548 .303 .66743 .29647 .66151 .28705 Mtetra
.732 .733 .852 r
.66151 .28705 .66743 .29647 .67941 .28978 .6735 .27985 Mtetra
.726 .72 .844 r
.6735 .27985 .67941 .28978 .69142 .28295 .68553 .27273 Mtetra
.721 .712 .841 r
.68553 .27273 .69142 .28295 .70345 .27604 .69759 .26572 Mtetra
.716 .709 .842 r
.69759 .26572 .70345 .27604 .71551 .2691 .70969 .25889 Mtetra
.713 .711 .846 r
.70969 .25889 .71551 .2691 .72761 .26218 .72183 .25223 Mtetra
.71 .716 .854 r
.72183 .25223 .72761 .26218 .73974 .25533 .73403 .24578 Mtetra
.709 .726 .864 r
.73403 .24578 .73974 .25533 .75191 .24855 .74627 .23949 Mtetra
.708 .739 .876 r
.74627 .23949 .75191 .24855 .76412 .24184 .75856 .23332 Mtetra
.709 .755 .889 r
.75856 .23332 .76412 .24184 .77637 .23521 .7709 .22725 Mtetra
.628 .744 .931 r
.1101 .44736 .11732 .45366 .12696 .45192 .11988 .44456 Mtetra
.625 .71 .907 r
.11988 .44456 .12696 .45192 .13662 .45028 .12969 .44187 Mtetra
.618 .679 .885 r
.12969 .44187 .13662 .45028 .14632 .44878 .13952 .43932 Mtetra
.609 .649 .865 r
.13952 .43932 .14632 .44878 .15605 .44744 .14937 .43699 Mtetra
.597 .622 .848 r
.14937 .43699 .15605 .44744 .16581 .4463 .15923 .43496 Mtetra
.586 .599 .833 r
.15923 .43496 .16581 .4463 .1756 .44535 .1691 .43321 Mtetra
.574 .579 .821 r
.1691 .43321 .1756 .44535 .18542 .44457 .17899 .43177 Mtetra
.565 .564 .811 r
.17899 .43177 .18542 .44457 .19529 .44391 .18891 .4306 Mtetra
.558 .552 .804 r
.18891 .4306 .19529 .44391 .2052 .44335 .19885 .42964 Mtetra
.554 .545 .799 r
.19885 .42964 .2052 .44335 .21517 .44283 .20884 .42879 Mtetra
.554 .54 .794 r
.20884 .42879 .21517 .44283 .22519 .4423 .21888 .42795 Mtetra
.556 .538 .79 r
.21888 .42795 .22519 .4423 .23528 .4417 .22899 .42703 Mtetra
.562 .537 .785 r
.22899 .42703 .23528 .4417 .24543 .44097 .23917 .42592 Mtetra
.567 .535 .779 r
.23917 .42592 .24543 .44097 .25567 .44006 .24943 .42461 Mtetra
.573 .534 .773 r
.24943 .42461 .25567 .44006 .26597 .4389 .25976 .42306 Mtetra
.578 .532 .768 r
.25976 .42306 .26597 .4389 .27636 .43745 .27015 .42132 Mtetra
.581 .531 .764 r
.27015 .42132 .27636 .43745 .28682 .43566 .28062 .41941 Mtetra
.584 .532 .762 r
.28062 .41941 .28682 .43566 .29736 .43356 .29114 .41737 Mtetra
.586 .534 .763 r
.29114 .41737 .29736 .43356 .30798 .43113 .30173 .41524 Mtetra
.588 .539 .768 r
.30173 .41524 .30798 .43113 .31866 .42842 .31237 .41304 Mtetra
.591 .547 .775 r
.31237 .41304 .31866 .42842 .32941 .42544 .32307 .41078 Mtetra
.594 .559 .785 r
.32307 .41078 .32941 .42544 .34022 .42224 .33382 .40845 Mtetra
.598 .574 .798 r
.33382 .40845 .34022 .42224 .35108 .41885 .34463 .40603 Mtetra
.603 .592 .814 r
.34463 .40603 .35108 .41885 .362 .41531 .35551 .40349 Mtetra
.609 .614 .831 r
.35551 .40349 .362 .41531 .37297 .41166 .36644 .40081 Mtetra
.616 .637 .848 r
.36644 .40081 .37297 .41166 .38398 .40793 .37743 .39793 Mtetra
.625 .661 .865 r
.37743 .39793 .38398 .40793 .39505 .40415 .38848 .39485 Mtetra
.633 .682 .878 r
.38848 .39485 .39505 .40415 .40616 .40035 .39959 .39154 Mtetra
.642 .698 .887 r
.39959 .39154 .40616 .40035 .41731 .39656 .41075 .38798 Mtetra
.651 .709 .89 r
.41075 .38798 .41731 .39656 .42851 .39278 .42198 .38417 Mtetra
.658 .712 .887 r
.42198 .38417 .42851 .39278 .43975 .389 .43325 .3801 Mtetra
.665 .707 .879 r
.43325 .3801 .43975 .389 .45105 .38524 .44458 .37579 Mtetra
.669 .696 .866 r
.44458 .37579 .45105 .38524 .46238 .38145 .45596 .37123 Mtetra
.671 .68 .85 r
.45596 .37123 .46238 .38145 .47377 .37762 .46738 .36647 Mtetra
.67 .661 .832 r
.46738 .36647 .47377 .37762 .48521 .3737 .47885 .36151 Mtetra
.668 .641 .814 r
.47885 .36151 .48521 .3737 .49669 .36967 .49036 .3564 Mtetra
.664 .622 .797 r
.49036 .3564 .49669 .36967 .50823 .36549 .50191 .35116 Mtetra
.66 .605 .783 r
.50191 .35116 .50823 .36549 .51981 .36111 .5135 .34583 Mtetra
.656 .591 .771 r
.5135 .34583 .51981 .36111 .53143 .3565 .52513 .34042 Mtetra
.653 .581 .761 r
.52513 .34042 .53143 .3565 .5431 .35162 .5368 .33494 Mtetra
.651 .574 .755 r
.5368 .33494 .5431 .35162 .55481 .34644 .5485 .32938 Mtetra
.651 .57 .751 r
.5485 .32938 .55481 .34644 .56655 .34093 .56025 .32372 Mtetra
.652 .57 .749 r
.56025 .32372 .56655 .34093 .57833 .33507 .57202 .31793 Mtetra
.655 .572 .749 r
.57202 .31793 .57833 .33507 .59014 .32887 .58384 .31195 Mtetra
.66 .577 .751 r
.58384 .31195 .59014 .32887 .60197 .32237 .59568 .30577 Mtetra
.666 .584 .754 r
.59568 .30577 .60197 .32237 .61383 .31559 .60756 .29933 Mtetra
.672 .591 .757 r
.60756 .29933 .61383 .31559 .62571 .30861 .61946 .29267 Mtetra
.677 .598 .76 r
.61946 .29267 .62571 .30861 .63762 .30149 .63138 .28581 Mtetra
.68 .603 .763 r
.63138 .28581 .63762 .30149 .64955 .29428 .64333 .27884 Mtetra
.682 .607 .766 r
.64333 .27884 .64955 .29428 .66151 .28705 .65532 .27188 Mtetra
.681 .611 .77 r
.65532 .27188 .66151 .28705 .6735 .27985 .66734 .26502 Mtetra
.68 .615 .776 r
.66734 .26502 .6735 .27985 .68553 .27273 .6794 .25837 Mtetra
.678 .621 .784 r
.6794 .25837 .68553 .27273 .69759 .26572 .69151 .25198 Mtetra
.675 .629 .795 r
.69151 .25198 .69759 .26572 .70969 .25889 .70367 .24591 Mtetra
.674 .641 .809 r
.70367 .24591 .70969 .25889 .72183 .25223 .71589 .24012 Mtetra
.672 .656 .825 r
.71589 .24012 .72183 .25223 .73403 .24578 .72818 .23463 Mtetra
.673 .676 .845 r
.72818 .23463 .73403 .24578 .74627 .23949 .74052 .22936 Mtetra
.674 .7 .866 r
.74052 .22936 .74627 .23949 .75856 .23332 .75293 .22425 Mtetra
.675 .728 .89 r
.75293 .22425 .75856 .23332 .7709 .22725 .76539 .21923 Mtetra
.682 .757 .908 r
.10283 .44102 .1101 .44736 .11988 .44456 .1128 .43687 Mtetra
.675 .717 .88 r
.1128 .43687 .11988 .44456 .12969 .44187 .12279 .43278 Mtetra
.664 .679 .854 r
.12279 .43278 .12969 .44187 .13952 .43932 .1328 .4288 Mtetra
.652 .644 .829 r
.1328 .4288 .13952 .43932 .14937 .43699 .14283 .425 Mtetra
.638 .612 .807 r
.14283 .425 .14937 .43699 .15923 .43496 .15286 .42145 Mtetra
.624 .582 .786 r
.15286 .42145 .15923 .43496 .1691 .43321 .1629 .41816 Mtetra
.611 .555 .768 r
.1629 .41816 .1691 .43321 .17899 .43177 .17295 .41519 Mtetra
.599 .532 .751 r
.17295 .41519 .17899 .43177 .18891 .4306 .183 .41251 Mtetra
.589 .512 .735 r
.183 .41251 .18891 .4306 .19885 .42964 .19308 .41012 Mtetra
.581 .495 .722 r
.19308 .41012 .19885 .42964 .20884 .42879 .20317 .40795 Mtetra
.574 .481 .712 r
.20317 .40795 .20884 .42879 .21888 .42795 .2133 .40597 Mtetra
.57 .471 .703 r
.2133 .40597 .21888 .42795 .22899 .42703 .22346 .40411 Mtetra
.568 .464 .696 r
.22346 .40411 .22899 .42703 .23917 .42592 .23367 .4023 Mtetra
.566 .459 .692 r
.23367 .4023 .23917 .42592 .24943 .42461 .24393 .40051 Mtetra
.565 .456 .689 r
.24393 .40051 .24943 .42461 .25976 .42306 .25424 .39871 Mtetra
.565 .455 .687 r
.25424 .39871 .25976 .42306 .27015 .42132 .26461 .39689 Mtetra
.566 .456 .687 r
.26461 .39689 .27015 .42132 .28062 .41941 .27503 .39504 Mtetra
.566 .457 .688 r
.27503 .39504 .28062 .41941 .29114 .41737 .28551 .39315 Mtetra
.567 .458 .689 r
.28551 .39315 .29114 .41737 .30173 .41524 .29604 .39122 Mtetra
.569 .461 .691 r
.29604 .39122 .30173 .41524 .31237 .41304 .30664 .38922 Mtetra
.57 .463 .693 r
.30664 .38922 .31237 .41304 .32307 .41078 .31729 .38715 Mtetra
.572 .466 .694 r
.31729 .38715 .32307 .41078 .33382 .40845 .328 .38499 Mtetra
.574 .468 .696 r
.328 .38499 .33382 .40845 .34463 .40603 .33877 .38271 Mtetra
.577 .471 .697 r
.33877 .38271 .34463 .40603 .35551 .40349 .3496 .38029 Mtetra
.58 .474 .698 r
.3496 .38029 .35551 .40349 .36644 .40081 .3605 .37768 Mtetra
.583 .477 .699 r
.3605 .37768 .36644 .40081 .37743 .39793 .37146 .37486 Mtetra
.587 .48 .699 r
.37146 .37486 .37743 .39793 .38848 .39485 .38248 .37181 Mtetra
.592 .483 .699 r
.38248 .37181 .38848 .39485 .39959 .39154 .39356 .3685 Mtetra
.596 .486 .699 r
.39356 .3685 .39959 .39154 .41075 .38798 .4047 .36492 Mtetra
.6 .489 .699 r
.4047 .36492 .41075 .38798 .42198 .38417 .4159 .36106 Mtetra
.604 .492 .699 r
.4159 .36106 .42198 .38417 .43325 .3801 .42715 .35693 Mtetra
.608 .494 .698 r
.42715 .35693 .43325 .3801 .44458 .37579 .43845 .35252 Mtetra
.611 .496 .697 r
.43845 .35252 .44458 .37579 .45596 .37123 .44981 .34785 Mtetra
.614 .497 .696 r
.44981 .34785 .45596 .37123 .46738 .36647 .46121 .34295 Mtetra
.617 .498 .695 r
.46121 .34295 .46738 .36647 .47885 .36151 .47265 .33782 Mtetra
.619 .499 .694 r
.47265 .33782 .47885 .36151 .49036 .3564 .48414 .33251 Mtetra
.62 .499 .693 r
.48414 .33251 .49036 .3564 .50191 .35116 .49566 .32704 Mtetra
.621 .498 .691 r
.49566 .32704 .50191 .35116 .5135 .34583 .50723 .32145 Mtetra
.622 .497 .69 r
.50723 .32145 .5135 .34583 .52513 .34042 .51883 .31576 Mtetra
.622 .496 .688 r
.51883 .31576 .52513 .34042 .5368 .33494 .53047 .30998 Mtetra
.621 .494 .686 r
.53047 .30998 .5368 .33494 .5485 .32938 .54214 .30414 Mtetra
.621 .493 .685 r
.54214 .30414 .5485 .32938 .56025 .32372 .55385 .29824 Mtetra
.621 .491 .683 r
.55385 .29824 .56025 .32372 .57202 .31793 .5656 .2923 Mtetra
.621 .491 .682 r
.5656 .2923 .57202 .31793 .58384 .31195 .57738 .28631 Mtetra
.621 .491 .683 r
.57738 .28631 .58384 .31195 .59568 .30577 .5892 .28029 Mtetra
.622 .492 .684 r
.5892 .28029 .59568 .30577 .60756 .29933 .60105 .27425 Mtetra
.623 .495 .686 r
.60105 .27425 .60756 .29933 .61946 .29267 .61294 .26822 Mtetra
.624 .5 .691 r
.61294 .26822 .61946 .29267 .63138 .28581 .62487 .26225 Mtetra
.625 .506 .697 r
.62487 .26225 .63138 .28581 .64333 .27884 .63684 .25638 Mtetra
.626 .513 .705 r
.63684 .25638 .64333 .27884 .65532 .27188 .64886 .2507 Mtetra
.628 .523 .716 r
.64886 .2507 .65532 .27188 .66734 .26502 .66093 .24524 Mtetra
.628 .535 .729 r
.66093 .24524 .66734 .26502 .6794 .25837 .67306 .24008 Mtetra
.629 .549 .745 r
.67306 .24008 .6794 .25837 .69151 .25198 .68524 .23521 Mtetra
.629 .565 .764 r
.68524 .23521 .69151 .25198 .70367 .24591 .6975 .23066 Mtetra
.629 .585 .785 r
.6975 .23066 .70367 .24591 .71589 .24012 .70983 .22639 Mtetra
.629 .607 .809 r
.70983 .22639 .71589 .24012 .72818 .23463 .72222 .22237 Mtetra
.63 .634 .836 r
.72222 .22237 .72818 .23463 .74052 .22936 .73469 .21852 Mtetra
.63 .665 .865 r
.73469 .21852 .74052 .22936 .75293 .22425 .74722 .2148 Mtetra
.63 .7 .896 r
.74722 .2148 .75293 .22425 .76539 .21923 .75983 .21113 Mtetra
.723 .764 .885 r
.09551 .43462 .10283 .44102 .1128 .43687 .10566 .42916 Mtetra
.713 .727 .861 r
.10566 .42916 .1128 .43687 .12279 .43278 .11584 .42371 Mtetra
.702 .692 .838 r
.11584 .42371 .12279 .43278 .1328 .4288 .12604 .4183 Mtetra
.689 .659 .815 r
.12604 .4183 .1328 .4288 .14283 .425 .13626 .41299 Mtetra
.676 .628 .794 r
.13626 .41299 .14283 .425 .15286 .42145 .14648 .40781 Mtetra
.662 .599 .774 r
.14648 .40781 .15286 .42145 .1629 .41816 .15672 .40283 Mtetra
.648 .572 .756 r
.15672 .40283 .1629 .41816 .17295 .41519 .16695 .39807 Mtetra
.634 .546 .738 r
.16695 .39807 .17295 .41519 .183 .41251 .17719 .39358 Mtetra
.621 .523 .722 r
.17719 .39358 .183 .41251 .19308 .41012 .18743 .3894 Mtetra
.609 .503 .708 r
.18743 .3894 .19308 .41012 .20317 .40795 .19767 .38554 Mtetra
.598 .485 .696 r
.19767 .38554 .20317 .40795 .2133 .40597 .20792 .38204 Mtetra
.588 .471 .687 r
.20792 .38204 .2133 .40597 .22346 .40411 .21817 .37888 Mtetra
.58 .459 .679 r
.21817 .37888 .22346 .40411 .23367 .4023 .22843 .37608 Mtetra
.573 .45 .674 r
.22843 .37608 .23367 .4023 .24393 .40051 .23871 .37356 Mtetra
.568 .444 .67 r
.23871 .37356 .24393 .40051 .25424 .39871 .24902 .37128 Mtetra
.565 .44 .668 r
.24902 .37128 .25424 .39871 .26461 .39689 .25937 .36913 Mtetra
.564 .438 .667 r
.25937 .36913 .26461 .39689 .27503 .39504 .26976 .36704 Mtetra
.564 .437 .666 r
.26976 .36704 .27503 .39504 .28551 .39315 .2802 .36494 Mtetra
.565 .437 .665 r
.2802 .36494 .28551 .39315 .29604 .39122 .29071 .36276 Mtetra
.566 .437 .664 r
.29071 .36276 .29604 .39122 .30664 .38922 .30127 .36047 Mtetra
.568 .437 .663 r
.30127 .36047 .30664 .38922 .31729 .38715 .3119 .35804 Mtetra
.569 .437 .661 r
.3119 .35804 .31729 .38715 .328 .38499 .32258 .35545 Mtetra
.571 .437 .659 r
.32258 .35545 .328 .38499 .33877 .38271 .33333 .35269 Mtetra
.572 .436 .657 r
.33333 .35269 .33877 .38271 .3496 .38029 .34414 .34977 Mtetra
.574 .436 .655 r
.34414 .34977 .3496 .38029 .3605 .37768 .355 .34668 Mtetra
.575 .435 .653 r
.355 .34668 .3605 .37768 .37146 .37486 .36593 .34343 Mtetra
.576 .435 .652 r
.36593 .34343 .37146 .37486 .38248 .37181 .3769 .34 Mtetra
.578 .435 .65 r
.3769 .34 .38248 .37181 .39356 .3685 .38794 .33642 Mtetra
.579 .435 .649 r
.38794 .33642 .39356 .3685 .4047 .36492 .39903 .33267 Mtetra
.581 .436 .649 r
.39903 .33267 .4047 .36492 .4159 .36106 .41017 .32876 Mtetra
.582 .437 .649 r
.41017 .32876 .4159 .36106 .42715 .35693 .42136 .3247 Mtetra
.584 .438 .649 r
.42136 .3247 .42715 .35693 .43845 .35252 .4326 .32046 Mtetra
.586 .441 .65 r
.4326 .32046 .43845 .35252 .44981 .34785 .44389 .31607 Mtetra
.589 .443 .651 r
.44389 .31607 .44981 .34785 .46121 .34295 .45522 .3115 Mtetra
.591 .446 .653 r
.45522 .3115 .46121 .34295 .47265 .33782 .46661 .30676 Mtetra
.594 .449 .654 r
.46661 .30676 .47265 .33782 .48414 .33251 .47803 .30185 Mtetra
.597 .453 .656 r
.47803 .30185 .48414 .33251 .49566 .32704 .48951 .29677 Mtetra
.599 .456 .658 r
.48951 .29677 .49566 .32704 .50723 .32145 .50102 .29151 Mtetra
.602 .459 .659 r
.50102 .29151 .50723 .32145 .51883 .31576 .51257 .28609 Mtetra
.604 .462 .661 r
.51257 .28609 .51883 .31576 .53047 .30998 .52416 .28052 Mtetra
.606 .464 .662 r
.52416 .28052 .53047 .30998 .54214 .30414 .53579 .27483 Mtetra
.607 .465 .662 r
.53579 .27483 .54214 .30414 .55385 .29824 .54746 .26905 Mtetra
.608 .466 .663 r
.54746 .26905 .55385 .29824 .5656 .2923 .55916 .26325 Mtetra
.607 .467 .664 r
.55916 .26325 .5656 .2923 .57738 .28631 .5709 .25751 Mtetra
.606 .467 .666 r
.5709 .25751 .57738 .28631 .5892 .28029 .58268 .25189 Mtetra
.604 .467 .668 r
.58268 .25189 .5892 .28029 .60105 .27425 .59451 .24651 Mtetra
.602 .469 .672 r
.59451 .24651 .60105 .27425 .61294 .26822 .60638 .24142 Mtetra
.6 .472 .678 r
.60638 .24142 .61294 .26822 .62487 .26225 .61831 .23669 Mtetra
.598 .477 .686 r
.61831 .23669 .62487 .26225 .63684 .25638 .6303 .2323 Mtetra
.596 .485 .697 r
.6303 .2323 .63684 .25638 .64886 .2507 .64236 .22828 Mtetra
.595 .495 .71 r
.64236 .22828 .64886 .2507 .66093 .24524 .65448 .22459 Mtetra
.594 .507 .726 r
.65448 .22459 .66093 .24524 .67306 .24008 .66668 .22122 Mtetra
.593 .523 .745 r
.66668 .22122 .67306 .24008 .68524 .23521 .67896 .21813 Mtetra
.592 .541 .767 r
.67896 .21813 .68524 .23521 .6975 .23066 .69131 .21527 Mtetra
.592 .563 .791 r
.69131 .21527 .6975 .23066 .70983 .22639 .70373 .21261 Mtetra
.591 .587 .817 r
.70373 .21261 .70983 .22639 .72222 .22237 .71624 .2101 Mtetra
.589 .614 .845 r
.71624 .2101 .72222 .22237 .73469 .21852 .72883 .20769 Mtetra
.587 .645 .875 r
.72883 .20769 .73469 .21852 .74722 .2148 .74149 .20533 Mtetra
.583 .678 .906 r
.74149 .20533 .74722 .2148 .75983 .21113 .75422 .20298 Mtetra
.744 .767 .872 r
.08813 .42819 .09551 .43462 .10566 .42916 .09842 .42189 Mtetra
.737 .744 .857 r
.09842 .42189 .10566 .42916 .11584 .42371 .10873 .41557 Mtetra
.73 .722 .843 r
.10873 .41557 .11584 .42371 .12604 .4183 .11906 .40925 Mtetra
.721 .7 .829 r
.11906 .40925 .12604 .4183 .13626 .41299 .12941 .40298 Mtetra
.712 .678 .815 r
.12941 .40298 .13626 .41299 .14648 .40781 .13977 .39678 Mtetra
.701 .656 .802 r
.13977 .39678 .14648 .40781 .15672 .40283 .15014 .3907 Mtetra
.69 .634 .789 r
.15014 .3907 .15672 .40283 .16695 .39807 .16052 .3848 Mtetra
.677 .613 .776 r
.16052 .3848 .16695 .39807 .17719 .39358 .17089 .3791 Mtetra
.665 .592 .763 r
.17089 .3791 .17719 .39358 .18743 .3894 .18126 .37367 Mtetra
.653 .571 .751 r
.18126 .37367 .18743 .3894 .19767 .38554 .19163 .3685 Mtetra
.64 .552 .739 r
.19163 .3685 .19767 .38554 .20792 .38204 .202 .36364 Mtetra
.629 .533 .727 r
.202 .36364 .20792 .38204 .21817 .37888 .21238 .35907 Mtetra
.618 .516 .716 r
.21238 .35907 .21817 .37888 .22843 .37608 .22276 .35477 Mtetra
.609 .5 .704 r
.22276 .35477 .22843 .37608 .23871 .37356 .23316 .3507 Mtetra
.602 .486 .694 r
.23316 .3507 .23871 .37356 .24902 .37128 .24358 .3468 Mtetra
.595 .473 .683 r
.24358 .3468 .24902 .37128 .25937 .36913 .25402 .34302 Mtetra
.59 .462 .674 r
.25402 .34302 .25937 .36913 .26976 .36704 .26451 .33931 Mtetra
.586 .453 .666 r
.26451 .33931 .26976 .36704 .2802 .36494 .27503 .33562 Mtetra
.583 .444 .658 r
.27503 .33562 .2802 .36494 .29071 .36276 .2856 .33193 Mtetra
.581 .437 .651 r
.2856 .33193 .29071 .36276 .30127 .36047 .29621 .32823 Mtetra
.578 .432 .646 r
.29621 .32823 .30127 .36047 .3119 .35804 .30686 .3245 Mtetra
.576 .427 .641 r
.30686 .3245 .3119 .35804 .32258 .35545 .31755 .32074 Mtetra
.575 .422 .637 r
.31755 .32074 .32258 .35545 .33333 .35269 .3283 .31697 Mtetra
.574 .419 .634 r
.3283 .31697 .33333 .35269 .34414 .34977 .33908 .31317 Mtetra
.573 .416 .631 r
.33908 .31317 .34414 .34977 .355 .34668 .34991 .30935 Mtetra
.572 .414 .629 r
.34991 .30935 .355 .34668 .36593 .34343 .36079 .30551 Mtetra
.571 .412 .627 r
.36079 .30551 .36593 .34343 .3769 .34 .37171 .30164 Mtetra
.571 .411 .626 r
.37171 .30164 .3769 .34 .38794 .33642 .38268 .29774 Mtetra
.571 .41 .625 r
.38268 .29774 .38794 .33642 .39903 .33267 .39369 .29381 Mtetra
.39369 .29381 .39903 .33267 .41017 .32876 .40475 .28985 Mtetra
.40475 .28985 .41017 .32876 .42136 .3247 .41585 .28585 Mtetra
.571 .411 .625 r
.41585 .28585 .42136 .3247 .4326 .32046 .42701 .28182 Mtetra
.572 .412 .626 r
.42701 .28182 .4326 .32046 .44389 .31607 .4382 .27776 Mtetra
.572 .413 .627 r
.4382 .27776 .44389 .31607 .45522 .3115 .44945 .27368 Mtetra
.573 .415 .629 r
.44945 .27368 .45522 .3115 .46661 .30676 .46074 .26957 Mtetra
.574 .417 .631 r
.46074 .26957 .46661 .30676 .47803 .30185 .47208 .26543 Mtetra
.575 .42 .633 r
.47208 .26543 .47803 .30185 .48951 .29677 .48346 .26128 Mtetra
.577 .424 .637 r
.48346 .26128 .48951 .29677 .50102 .29151 .49489 .2571 Mtetra
.579 .428 .641 r
.49489 .2571 .50102 .29151 .51257 .28609 .50637 .25289 Mtetra
.581 .433 .646 r
.50637 .25289 .51257 .28609 .52416 .28052 .5179 .24865 Mtetra
.583 .439 .651 r
.5179 .24865 .52416 .28052 .53579 .27483 .52947 .2444 Mtetra
.586 .446 .658 r
.52947 .2444 .53579 .27483 .54746 .26905 .5411 .24015 Mtetra
.588 .454 .665 r
.5411 .24015 .54746 .26905 .55916 .26325 .55277 .23592 Mtetra
.591 .462 .674 r
.55277 .23592 .55916 .26325 .5709 .25751 .56449 .23175 Mtetra
.592 .471 .684 r
.56449 .23175 .5709 .25751 .58268 .25189 .57627 .2277 Mtetra
.593 .481 .695 r
.57627 .2277 .58268 .25189 .59451 .24651 .5881 .22383 Mtetra
.593 .49 .706 r
.5881 .22383 .59451 .24651 .60638 .24142 .59998 .22019 Mtetra
.592 .5 .719 r
.59998 .22019 .60638 .24142 .61831 .23669 .61194 .21683 Mtetra
.59 .51 .733 r
.61194 .21683 .61831 .23669 .6303 .2323 .62396 .21377 Mtetra
.587 .521 .748 r
.62396 .21377 .6303 .2323 .64236 .22828 .63606 .21101 Mtetra
.583 .533 .764 r
.63606 .21101 .64236 .22828 .65448 .22459 .64823 .20855 Mtetra
.579 .546 .782 r
.64823 .20855 .65448 .22459 .66668 .22122 .66048 .20635 Mtetra
.575 .56 .8 r
.66048 .20635 .66668 .22122 .67896 .21813 .67282 .20437 Mtetra
.57 .576 .82 r
.67282 .20437 .67896 .21813 .69131 .21527 .68524 .20258 Mtetra
.566 .593 .84 r
.68524 .20258 .69131 .21527 .70373 .21261 .69774 .20092 Mtetra
.561 .612 .861 r
.69774 .20092 .70373 .21261 .71624 .2101 .71032 .19934 Mtetra
.557 .632 .881 r
.71032 .19934 .71624 .2101 .72883 .20769 .72299 .19781 Mtetra
.552 .652 .902 r
.72299 .19781 .72883 .20769 .74149 .20533 .73574 .1963 Mtetra
.547 .674 .922 r
.73574 .1963 .74149 .20533 .75422 .20298 .74857 .19475 Mtetra
.75 .767 .867 r
.0807 .4217 .08813 .42819 .09842 .42189 .09106 .41509 Mtetra
.749 .759 .861 r
.09106 .41509 .09842 .42189 .10873 .41557 .10144 .40843 Mtetra
.746 .751 .856 r
.10144 .40843 .10873 .41557 .11906 .40925 .11184 .40174 Mtetra
.743 .742 .85 r
.11184 .40174 .11906 .40925 .12941 .40298 .12226 .39506 Mtetra
.739 .731 .844 r
.12226 .39506 .12941 .40298 .13977 .39678 .1327 .38839 Mtetra
.733 .72 .838 r
.1327 .38839 .13977 .39678 .15014 .3907 .14316 .38179 Mtetra
.727 .707 .832 r
.14316 .38179 .15014 .3907 .16052 .3848 .15362 .3753 Mtetra
.719 .693 .825 r
.15362 .3753 .16052 .3848 .17089 .3791 .16408 .36894 Mtetra
.71 .678 .817 r
.16408 .36894 .17089 .3791 .18126 .37367 .17455 .36274 Mtetra
.701 .661 .807 r
.17455 .36274 .18126 .37367 .19163 .3685 .18503 .3567 Mtetra
.691 .642 .796 r
.18503 .3567 .19163 .3685 .202 .36364 .19551 .35082 Mtetra
.681 .623 .784 r
.19551 .35082 .202 .36364 .21238 .35907 .20601 .34506 Mtetra
.672 .603 .77 r
.20601 .34506 .21238 .35907 .22276 .35477 .21653 .33938 Mtetra
.662 .582 .754 r
.21653 .33938 .22276 .35477 .23316 .3507 .22707 .33375 Mtetra
.653 .561 .738 r
.22707 .33375 .23316 .3507 .24358 .3468 .23763 .32815 Mtetra
.644 .541 .723 r
.23763 .32815 .24358 .3468 .25402 .34302 .24822 .3226 Mtetra
.635 .522 .709 r
.24822 .3226 .25402 .34302 .26451 .33931 .25883 .3171 Mtetra
.626 .506 .696 r
.25883 .3171 .26451 .33931 .27503 .33562 .26947 .31168 Mtetra
.619 .491 .685 r
.26947 .31168 .27503 .33562 .2856 .33193 .28013 .30636 Mtetra
.612 .479 .676 r
.28013 .30636 .2856 .33193 .29621 .32823 .29081 .30116 Mtetra
.606 .468 .668 r
.29081 .30116 .29621 .32823 .30686 .3245 .30152 .2961 Mtetra
.6 .459 .661 r
.30152 .2961 .30686 .3245 .31755 .32074 .31225 .29119 Mtetra
.595 .452 .656 r
.31225 .29119 .31755 .32074 .3283 .31697 .323 .28642 Mtetra
.591 .446 .652 r
.323 .28642 .3283 .31697 .33908 .31317 .33379 .28181 Mtetra
.588 .441 .649 r
.33379 .28181 .33908 .31317 .34991 .30935 .3446 .27733 Mtetra
.585 .437 .646 r
.3446 .27733 .34991 .30935 .36079 .30551 .35544 .27297 Mtetra
.583 .434 .645 r
.35544 .27297 .36079 .30551 .37171 .30164 .36632 .26872 Mtetra
.581 .431 .643 r
.36632 .26872 .37171 .30164 .38268 .29774 .37724 .26455 Mtetra
.579 .43 .642 r
.37724 .26455 .38268 .29774 .39369 .29381 .3882 .26047 Mtetra
.578 .428 .642 r
.3882 .26047 .39369 .29381 .40475 .28985 .39919 .25645 Mtetra
.577 .428 .642 r
.39919 .25645 .40475 .28985 .41585 .28585 .41023 .25251 Mtetra
.576 .427 .642 r
.41023 .25251 .41585 .28585 .42701 .28182 .42131 .24865 Mtetra
.575 .427 .643 r
.42131 .24865 .42701 .28182 .4382 .27776 .43244 .24488 Mtetra
.574 .428 .645 r
.43244 .24488 .4382 .27776 .44945 .27368 .44361 .24121 Mtetra
.573 .429 .647 r
.44361 .24121 .44945 .27368 .46074 .26957 .45483 .23767 Mtetra
.572 .43 .649 r
.45483 .23767 .46074 .26957 .47208 .26543 .46609 .23426 Mtetra
.571 .432 .653 r
.46609 .23426 .47208 .26543 .48346 .26128 .4774 .23101 Mtetra
.571 .435 .657 r
.4774 .23101 .48346 .26128 .49489 .2571 .48877 .22791 Mtetra
.57 .439 .663 r
.48877 .22791 .49489 .2571 .50637 .25289 .50019 .22496 Mtetra
.57 .445 .67 r
.50019 .22496 .50637 .25289 .5179 .24865 .51167 .22215 Mtetra
.57 .452 .679 r
.51167 .22215 .5179 .24865 .52947 .2444 .5232 .21946 Mtetra
.571 .461 .689 r
.5232 .21946 .52947 .2444 .5411 .24015 .53479 .21689 Mtetra
.573 .472 .702 r
.53479 .21689 .5411 .24015 .55277 .23592 .54645 .21439 Mtetra
.575 .486 .717 r
.54645 .21439 .55277 .23592 .56449 .23175 .55817 .21196 Mtetra
.577 .502 .733 r
.55817 .21196 .56449 .23175 .57627 .2277 .56996 .20957 Mtetra
.579 .519 .752 r
.56996 .20957 .57627 .2277 .5881 .22383 .58181 .20721 Mtetra
.58 .537 .771 r
.58181 .20721 .5881 .22383 .59998 .22019 .59373 .20492 Mtetra
.58 .555 .791 r
.59373 .20492 .59998 .22019 .61194 .21683 .60572 .20271 Mtetra
.578 .572 .81 r
.60572 .20271 .61194 .21683 .62396 .21377 .61778 .20063 Mtetra
.574 .587 .828 r
.61778 .20063 .62396 .21377 .63606 .21101 .62992 .19871 Mtetra
.568 .6 .845 r
.62992 .19871 .63606 .21101 .64823 .20855 .64213 .19696 Mtetra
.561 .612 .861 r
.64213 .19696 .64823 .20855 .66048 .20635 .65443 .19538 Mtetra
.554 .623 .875 r
.65443 .19538 .66048 .20635 .67282 .20437 .66681 .19395 Mtetra
.547 .634 .889 r
.66681 .19395 .67282 .20437 .68524 .20258 .67928 .19263 Mtetra
.541 .644 .9 r
.67928 .19263 .68524 .20258 .69774 .20092 .69183 .19139 Mtetra
.537 .654 .911 r
.69183 .19139 .69774 .20092 .71032 .19934 .70447 .19018 Mtetra
.533 .663 .92 r
.70447 .19018 .71032 .19934 .72299 .19781 .71719 .18897 Mtetra
.53 .672 .928 r
.71719 .18897 .72299 .19781 .73574 .1963 .72999 .18774 Mtetra
.528 .681 .936 r
.72999 .18774 .73574 .1963 .74857 .19475 .74288 .18646 Mtetra
.742 .767 .873 r
.07322 .41517 .0807 .4217 .09106 .41509 .08355 .4089 Mtetra
.746 .778 .879 r
.08355 .4089 .09106 .41509 .10144 .40843 .09392 .40256 Mtetra
.75 .788 .884 r
.09392 .40256 .10144 .40843 .11184 .40174 .10431 .39616 Mtetra
.753 .798 .889 r
.10431 .39616 .11184 .40174 .12226 .39506 .11473 .38971 Mtetra
.756 .806 .893 r
.11473 .38971 .12226 .39506 .1327 .38839 .12519 .38319 Mtetra
.757 .812 .896 r
.12519 .38319 .1327 .38839 .14316 .38179 .13566 .37664 Mtetra
.758 .815 .898 r
.13566 .37664 .14316 .38179 .15362 .3753 .14616 .3701 Mtetra
.756 .814 .898 r
.14616 .3701 .15362 .3753 .16408 .36894 .15667 .36358 Mtetra
.754 .81 .898 r
.15667 .36358 .16408 .36894 .17455 .36274 .1672 .35713 Mtetra
.75 .803 .895 r
.1672 .35713 .17455 .36274 .18503 .3567 .17775 .35075 Mtetra
.745 .793 .891 r
.17775 .35075 .18503 .3567 .19551 .35082 .18831 .34445 Mtetra
.74 .781 .886 r
.18831 .34445 .19551 .35082 .20601 .34506 .19888 .33824 Mtetra
.734 .768 .88 r
.19888 .33824 .20601 .34506 .21653 .33938 .20946 .33213 Mtetra
.728 .755 .874 r
.20946 .33213 .21653 .33938 .22707 .33375 .22007 .3261 Mtetra
.723 .744 .869 r
.22007 .3261 .22707 .33375 .23763 .32815 .23069 .32018 Mtetra
.717 .735 .865 r
.23069 .32018 .23763 .32815 .24822 .3226 .24132 .31438 Mtetra
.712 .728 .863 r
.24132 .31438 .24822 .3226 .25883 .3171 .25197 .3087 Mtetra
.707 .723 .863 r
.25197 .3087 .25883 .3171 .26947 .31168 .26264 .30316 Mtetra
.702 .719 .863 r
.26264 .30316 .26947 .31168 .28013 .30636 .27333 .29776 Mtetra
.697 .717 .864 r
.27333 .29776 .28013 .30636 .29081 .30116 .28404 .2925 Mtetra
.693 .715 .866 r
.28404 .2925 .29081 .30116 .30152 .2961 .29477 .28739 Mtetra
.688 .713 .867 r
.29477 .28739 .30152 .2961 .31225 .29119 .30552 .28242 Mtetra
.683 .71 .869 r
.30552 .28242 .31225 .29119 .323 .28642 .3163 .2776 Mtetra
.679 .708 .87 r
.3163 .2776 .323 .28642 .33379 .28181 .32711 .27291 Mtetra
.674 .705 .871 r
.32711 .27291 .33379 .28181 .3446 .27733 .33795 .26835 Mtetra
.67 .703 .872 r
.33795 .26835 .3446 .27733 .35544 .27297 .34882 .26391 Mtetra
.666 .7 .872 r
.34882 .26391 .35544 .27297 .36632 .26872 .35972 .25958 Mtetra
.662 .698 .873 r
.35972 .25958 .36632 .26872 .37724 .26455 .37066 .25536 Mtetra
.658 .695 .873 r
.37066 .25536 .37724 .26455 .3882 .26047 .38164 .25122 Mtetra
.655 .694 .874 r
.38164 .25122 .3882 .26047 .39919 .25645 .39266 .24718 Mtetra
.651 .692 .875 r
.39266 .24718 .39919 .25645 .41023 .25251 .40372 .24322 Mtetra
.648 .691 .877 r
.40372 .24322 .41023 .25251 .42131 .24865 .41482 .23936 Mtetra
.644 .691 .879 r
.41482 .23936 .42131 .24865 .43244 .24488 .42597 .2356 Mtetra
.64 .69 .881 r
.42597 .2356 .43244 .24488 .44361 .24121 .43716 .23195 Mtetra
.635 .69 .884 r
.43716 .23195 .44361 .24121 .45483 .23767 .4484 .22842 Mtetra
.63 .689 .886 r
.4484 .22842 .45483 .23767 .46609 .23426 .45969 .22502 Mtetra
.625 .688 .888 r
.45969 .22502 .46609 .23426 .4774 .23101 .47102 .22176 Mtetra
.619 .686 .891 r
.47102 .22176 .4774 .23101 .48877 .22791 .48241 .21865 Mtetra
.613 .684 .893 r
.48241 .21865 .48877 .22791 .50019 .22496 .49385 .21569 Mtetra
.607 .682 .895 r
.49385 .21569 .50019 .22496 .51167 .22215 .50535 .21288 Mtetra
.601 .68 .897 r
.50535 .21288 .51167 .22215 .5232 .21946 .51691 .21022 Mtetra
.595 .679 .899 r
.51691 .21022 .5232 .21946 .53479 .21689 .52852 .2077 Mtetra
.589 .678 .903 r
.52852 .2077 .53479 .21689 .54645 .21439 .54021 .20532 Mtetra
.582 .68 .907 r
.54021 .20532 .54645 .21439 .55817 .21196 .55195 .20308 Mtetra
.576 .683 .914 r
.55195 .20308 .55817 .21196 .56996 .20957 .56377 .20096 Mtetra
.569 .689 .922 r
.56377 .20096 .56996 .20957 .58181 .20721 .57565 .19894 Mtetra
.561 .697 .931 r
.57565 .19894 .58181 .20721 .59373 .20492 .58761 .19703 Mtetra
.553 .706 .942 r
.58761 .19703 .59373 .20492 .60572 .20271 .59964 .19522 Mtetra
.543 .715 .952 r
.59964 .19522 .60572 .20271 .61778 .20063 .61174 .1935 Mtetra
.532 .723 .961 r
.61174 .1935 .61778 .20063 .62992 .19871 .62393 .19187 Mtetra
.522 .73 .969 r
.62393 .19187 .62992 .19871 .64213 .19696 .63619 .19033 Mtetra
.514 .734 .974 r
.63619 .19033 .64213 .19696 .65443 .19538 .64853 .18885 Mtetra
.508 .736 .976 r
.64853 .18885 .65443 .19538 .66681 .19395 .66095 .18741 Mtetra
.507 .736 .977 r
.66095 .18741 .66681 .19395 .67928 .19263 .67345 .18598 Mtetra
.51 .734 .975 r
.67345 .18598 .67928 .19263 .69183 .19139 .68603 .18452 Mtetra
.516 .731 .971 r
.68603 .18452 .69183 .19139 .70447 .19018 .69869 .18301 Mtetra
.523 .725 .965 r
.69869 .18301 .70447 .19018 .71719 .18897 .71142 .18144 Mtetra
.531 .717 .958 r
.71142 .18144 .71719 .18897 .72999 .18774 .72424 .1798 Mtetra
.538 .709 .95 r
.72424 .1798 .72999 .18774 .74288 .18646 .73713 .1781 Mtetra
.719 .764 .888 r
.06568 .40859 .07322 .41517 .08355 .4089 .07592 .40317 Mtetra
.726 .791 .904 r
.07592 .40317 .08355 .4089 .09392 .40256 .0862 .39766 Mtetra
.732 .819 .919 r
.0862 .39766 .09392 .40256 .10431 .39616 .09652 .39206 Mtetra
.737 .847 .932 r
.09652 .39206 .10431 .39616 .11473 .38971 .10688 .38635 Mtetra
.741 .874 .942 r
.10688 .38635 .11473 .38971 .12519 .38319 .11728 .38051 Mtetra
.742 .897 .948 r
.11728 .38051 .12519 .38319 .13566 .37664 .12772 .37456 Mtetra
.741 .916 .952 r
.12772 .37456 .13566 .37664 .14616 .3701 .1382 .36851 Mtetra
.737 .932 .953 r
.1382 .36851 .14616 .3701 .15667 .36358 .14871 .36239 Mtetra
.731 .943 .953 r
.14871 .36239 .15667 .36358 .1672 .35713 .15925 .35623 Mtetra
.723 .95 .951 r
.15925 .35623 .1672 .35713 .17775 .35075 .16981 .35008 Mtetra
.713 .955 .95 r
.16981 .35008 .17775 .35075 .18831 .34445 .1804 .34397 Mtetra
.7 .958 .948 r
.1804 .34397 .18831 .34445 .19888 .33824 .19099 .33797 Mtetra
.682 .959 .945 r
.19099 .33797 .19888 .33824 .20946 .33213 .2016 .3321 Mtetra
.658 .958 .939 r
.2016 .3321 .20946 .33213 .22007 .3261 .21222 .32641 Mtetra
.625 .953 .927 r
.21222 .32641 .22007 .3261 .23069 .32018 .22285 .32092 Mtetra
.582 .942 .905 r
.22285 .32092 .23069 .32018 .24132 .31438 .23349 .31562 Mtetra
.528 .921 .87 r
.23349 .31562 .24132 .31438 .25197 .3087 .24415 .3105 Mtetra
.466 .89 .822 r
.24415 .3105 .25197 .3087 .26264 .30316 .25482 .30553 Mtetra
.4 .849 .765 r
.25482 .30553 .26264 .30316 .27333 .29776 .26552 .30068 Mtetra
.335 .802 .703 r
.26552 .30068 .27333 .29776 .28404 .2925 .27625 .29593 Mtetra
0 0 0 r
.27625 .29593 .28404 .2925 .29477 .28739 .28701 .29127 Mtetra
.28701 .29127 .29477 .28739 .30552 .28242 .2978 .28667 Mtetra
.2978 .28667 .30552 .28242 .3163 .2776 .30863 .28214 Mtetra
.30863 .28214 .3163 .2776 .32711 .27291 .31949 .27767 Mtetra
.31949 .27767 .32711 .27291 .33795 .26835 .33038 .27326 Mtetra
.33038 .27326 .33795 .26835 .34882 .26391 .34132 .26891 Mtetra
.34132 .26891 .34882 .26391 .35972 .25958 .35229 .26463 Mtetra
.35229 .26463 .35972 .25958 .37066 .25536 .3633 .26042 Mtetra
.3633 .26042 .37066 .25536 .38164 .25122 .37435 .25628 Mtetra
.37435 .25628 .38164 .25122 .39266 .24718 .38544 .25221 Mtetra
.38544 .25221 .39266 .24718 .40372 .24322 .39657 .24822 Mtetra
.39657 .24822 .40372 .24322 .41482 .23936 .40775 .2443 Mtetra
.40775 .2443 .41482 .23936 .42597 .2356 .41897 .24044 Mtetra
.41897 .24044 .42597 .2356 .43716 .23195 .43024 .23666 Mtetra
.43024 .23666 .43716 .23195 .4484 .22842 .44155 .23294 Mtetra
.44155 .23294 .4484 .22842 .45969 .22502 .45292 .22928 Mtetra
.45292 .22928 .45969 .22502 .47102 .22176 .46433 .22568 Mtetra
.46433 .22568 .47102 .22176 .48241 .21865 .4758 .22215 Mtetra
.4758 .22215 .48241 .21865 .49385 .21569 .48732 .21869 Mtetra
.48732 .21869 .49385 .21569 .50535 .21288 .49889 .21531 Mtetra
.49889 .21531 .50535 .21288 .51691 .21022 .51052 .21204 Mtetra
.51052 .21204 .51691 .21022 .52852 .2077 .5222 .20889 Mtetra
.212 .733 .73 r
.5222 .20889 .52852 .2077 .54021 .20532 .53394 .20589 Mtetra
.244 .758 .783 r
.53394 .20589 .54021 .20532 .55195 .20308 .54575 .20309 Mtetra
.27 .776 .827 r
.54575 .20309 .55195 .20308 .56377 .20096 .55762 .20047 Mtetra
.287 .786 .861 r
.55762 .20047 .56377 .20096 .57565 .19894 .56956 .19807 Mtetra
.299 .79 .885 r
.56956 .19807 .57565 .19894 .58761 .19703 .58157 .19585 Mtetra
.307 .791 .901 r
.58157 .19585 .58761 .19703 .59964 .19522 .59365 .19378 Mtetra
.315 .792 .915 r
.59365 .19378 .59964 .19522 .61174 .1935 .6058 .1918 Mtetra
.326 .795 .928 r
.6058 .1918 .61174 .1935 .62393 .19187 .61803 .18989 Mtetra
.344 .8 .943 r
.61803 .18989 .62393 .19187 .63619 .19033 .63034 .18798 Mtetra
.37 .808 .959 r
.63034 .18798 .63619 .19033 .64853 .18885 .64272 .18604 Mtetra
.402 .814 .976 r
.64272 .18604 .64853 .18885 .66095 .18741 .65517 .18404 Mtetra
.44 .818 .991 r
.65517 .18404 .66095 .18741 .67345 .18598 .66769 .18193 Mtetra
.477 .816 .999 r
.66769 .18193 .67345 .18598 .68603 .18452 .68028 .17971 Mtetra
.512 .807 .999 r
.68028 .17971 .68603 .18452 .69869 .18301 .69294 .17736 Mtetra
.54 .79 .99 r
.69294 .17736 .69869 .18301 .71142 .18144 .70567 .17489 Mtetra
.561 .769 .976 r
.70567 .17489 .71142 .18144 .72424 .1798 .71847 .17233 Mtetra
.575 .744 .957 r
.71847 .17233 .72424 .1798 .73713 .1781 .73134 .16968 Mtetra
.677 .756 .911 r
.05808 .40196 .06568 .40859 .07592 .40317 .06817 .39782 Mtetra
.681 .799 .938 r
.06817 .39782 .07592 .40317 .0862 .39766 .0783 .39359 Mtetra
.68 .843 .961 r
.0783 .39359 .0862 .39766 .09652 .39206 .08847 .38927 Mtetra
.672 .886 .977 r
.08847 .38927 .09652 .39206 .10688 .38635 .0987 .38483 Mtetra
.652 .92 .977 r
.0987 .38483 .10688 .38635 .11728 .38051 .10898 .38024 Mtetra
.612 .938 .954 r
.10898 .38024 .11728 .38051 .12772 .37456 .11931 .37553 Mtetra
.552 .93 .902 r
.11931 .37553 .12772 .37456 .1382 .36851 .12969 .37068 Mtetra
.47 .892 .821 r
.12969 .37068 .1382 .36851 .14871 .36239 .14011 .36575 Mtetra
.375 .827 .716 r
.14011 .36575 .14871 .36239 .15925 .35623 .15057 .36074 Mtetra
0 0 0 r
.15057 .36074 .15925 .35623 .16981 .35008 .16107 .3557 Mtetra
.16107 .3557 .16981 .35008 .1804 .34397 .1716 .35065 Mtetra
.1716 .35065 .1804 .34397 .19099 .33797 .18216 .34563 Mtetra
.18216 .34563 .19099 .33797 .2016 .3321 .19275 .34067 Mtetra
.035 0 0 r
.19275 .34067 .2016 .3321 .21222 .32641 .20336 .33576 Mtetra
.08 0 0 r
.20336 .33576 .21222 .32641 .22285 .32092 .21401 .33093 Mtetra
.113 0 0 r
.21401 .33093 .22285 .32092 .23349 .31562 .22468 .32614 Mtetra
.137 0 0 r
.22468 .32614 .23349 .31562 .24415 .3105 .23538 .32139 Mtetra
.153 0 0 r
.23538 .32139 .24415 .3105 .25482 .30553 .24612 .31666 Mtetra
.164 0 0 r
.24612 .31666 .25482 .30553 .26552 .30068 .2569 .31196 Mtetra
.171 0 0 r
.2569 .31196 .26552 .30068 .27625 .29593 .26771 .30726 Mtetra
.176 0 0 r
.26771 .30726 .27625 .29593 .28701 .29127 .27856 .30258 Mtetra
.178 0 0 r
.27856 .30258 .28701 .29127 .2978 .28667 .28944 .29793 Mtetra
.18 0 0 r
.28944 .29793 .2978 .28667 .30863 .28214 .30036 .29331 Mtetra
.182 0 0 r
.30036 .29331 .30863 .28214 .31949 .27767 .31131 .28873 Mtetra
.184 0 0 r
.31131 .28873 .31949 .27767 .33038 .27326 .32231 .28422 Mtetra
.187 0 0 r
.32231 .28422 .33038 .27326 .34132 .26891 .33334 .27977 Mtetra
.19 0 0 r
.33334 .27977 .34132 .26891 .35229 .26463 .3444 .27541 Mtetra
.195 0 0 r
.3444 .27541 .35229 .26463 .3633 .26042 .35551 .27114 Mtetra
.2 0 0 r
.35551 .27114 .3633 .26042 .37435 .25628 .36665 .26695 Mtetra
.205 0 0 r
.36665 .26695 .37435 .25628 .38544 .25221 .37783 .26287 Mtetra
.211 0 0 r
.37783 .26287 .38544 .25221 .39657 .24822 .38906 .25888 Mtetra
.218 0 0 r
.38906 .25888 .39657 .24822 .40775 .2443 .40033 .25499 Mtetra
.225 0 0 r
.40033 .25499 .40775 .2443 .41897 .24044 .41164 .25119 Mtetra
.231 0 0 r
.41164 .25119 .41897 .24044 .43024 .23666 .423 .24746 Mtetra
.238 0 0 r
.423 .24746 .43024 .23666 .44155 .23294 .43441 .24382 Mtetra
.244 0 0 r
.43441 .24382 .44155 .23294 .45292 .22928 .44587 .24023 Mtetra
.249 0 0 r
.44587 .24023 .45292 .22928 .46433 .22568 .45738 .23669 Mtetra
.253 0 0 r
.45738 .23669 .46433 .22568 .4758 .22215 .46895 .23318 Mtetra
.255 0 0 r
.46895 .23318 .4758 .22215 .48732 .21869 .48057 .22969 Mtetra
.256 0 0 r
.48057 .22969 .48732 .21869 .49889 .21531 .49224 .22623 Mtetra
.49224 .22623 .49889 .21531 .51052 .21204 .50397 .22278 Mtetra
.254 0 0 r
.50397 .22278 .51052 .21204 .5222 .20889 .51576 .21934 Mtetra
.249 0 0 r
.51576 .21934 .5222 .20889 .53394 .20589 .52761 .21594 Mtetra
.242 0 0 r
.52761 .21594 .53394 .20589 .54575 .20309 .53951 .21257 Mtetra
.231 0 0 r
.53951 .21257 .54575 .20309 .55762 .20047 .55147 .20925 Mtetra
.216 0 0 r
.55147 .20925 .55762 .20047 .56956 .19807 .5635 .206 Mtetra
.193 0 0 r
.5635 .206 .56956 .19807 .58157 .19585 .57558 .20282 Mtetra
.162 0 0 r
.57558 .20282 .58157 .19585 .59365 .19378 .58774 .19969 Mtetra
.12 0 0 r
.58774 .19969 .59365 .19378 .6058 .1918 .59995 .19658 Mtetra
.063 0 0 r
.59995 .19658 .6058 .1918 .61803 .18989 .61223 .19348 Mtetra
0 0 0 r
.61223 .19348 .61803 .18989 .63034 .18798 .62458 .19034 Mtetra
.62458 .19034 .63034 .18798 .64272 .18604 .63698 .18713 Mtetra
.218 .737 .728 r
.63698 .18713 .64272 .18604 .65517 .18404 .64945 .18381 Mtetra
.337 .818 .85 r
.64945 .18381 .65517 .18404 .66769 .18193 .66198 .18037 Mtetra
.444 .867 .939 r
.66198 .18037 .66769 .18193 .68028 .17971 .67457 .17679 Mtetra
.528 .879 .986 r
.67457 .17679 .68028 .17971 .69294 .17736 .68722 .17305 Mtetra
.584 .86 .995 r
.68722 .17305 .69294 .17736 .70567 .17489 .69992 .1692 Mtetra
.615 .825 .981 r
.69992 .1692 .70567 .17489 .71847 .17233 .71268 .16523 Mtetra
.631 .784 .955 r
.71268 .16523 .71847 .17233 .73134 .16968 .7255 .16118 Mtetra
.615 .74 .936 r
.05043 .39529 .05808 .40196 .06817 .39782 .06033 .39256 Mtetra
.608 .788 .967 r
.06033 .39256 .06817 .39782 .0783 .39359 .07028 .38977 Mtetra
.591 .834 .991 r
.07028 .38977 .0783 .39359 .08847 .38927 .08029 .38689 Mtetra
.556 .871 .994 r
.08029 .38689 .08847 .38927 .0987 .38483 .09035 .38391 Mtetra
.497 .885 .963 r
.09035 .38391 .0987 .38483 .10898 .38024 .10047 .38078 Mtetra
.408 .859 .884 r
.10047 .38078 .10898 .38024 .11931 .37553 .11066 .37754 Mtetra
.298 .79 .761 r
.11066 .37754 .11931 .37553 .12969 .37068 .1209 .37417 Mtetra
0 0 0 r
.1209 .37417 .12969 .37068 .14011 .36575 .1312 .3707 Mtetra
.1312 .3707 .14011 .36575 .15057 .36074 .14154 .36714 Mtetra
.02 0 0 r
.14154 .36714 .15057 .36074 .16107 .3557 .15194 .36352 Mtetra
.092 0 0 r
.15194 .36352 .16107 .3557 .1716 .35065 .16239 .35984 Mtetra
.146 0 0 r
.16239 .35984 .1716 .35065 .18216 .34563 .17288 .3561 Mtetra
.186 0 0 r
.17288 .3561 .18216 .34563 .19275 .34067 .18342 .3523 Mtetra
.214 0 0 r
.18342 .3523 .19275 .34067 .20336 .33576 .19402 .3484 Mtetra
.233 0 .013 r
.19402 .3484 .20336 .33576 .21401 .33093 .20467 .34438 Mtetra
.246 0 .038 r
.20467 .34438 .21401 .33093 .22468 .32614 .21537 .34023 Mtetra
.253 0 .055 r
.21537 .34023 .22468 .32614 .23538 .32139 .22612 .33595 Mtetra
.257 0 .067 r
.22612 .33595 .23538 .32139 .24612 .31666 .23693 .33155 Mtetra
.26 0 .075 r
.23693 .33155 .24612 .31666 .2569 .31196 .24779 .32705 Mtetra
.261 0 .08 r
.24779 .32705 .2569 .31196 .26771 .30726 .25869 .32247 Mtetra
.263 0 .083 r
.25869 .32247 .26771 .30726 .27856 .30258 .26963 .31786 Mtetra
.264 0 .085 r
.26963 .31786 .27856 .30258 .28944 .29793 .28061 .31322 Mtetra
.266 0 .087 r
.28061 .31322 .28944 .29793 .30036 .29331 .29164 .30859 Mtetra
.268 0 .089 r
.29164 .30859 .30036 .29331 .31131 .28873 .3027 .304 Mtetra
.271 0 .09 r
.3027 .304 .31131 .28873 .32231 .28422 .3138 .29947 Mtetra
.275 0 .092 r
.3138 .29947 .32231 .28422 .33334 .27977 .32493 .295 Mtetra
.279 0 .094 r
.32493 .295 .33334 .27977 .3444 .27541 .33611 .29062 Mtetra
.283 0 .096 r
.33611 .29062 .3444 .27541 .35551 .27114 .34732 .28633 Mtetra
.288 0 .099 r
.34732 .28633 .35551 .27114 .36665 .26695 .35857 .28214 Mtetra
.292 0 .101 r
.35857 .28214 .36665 .26695 .37783 .26287 .36986 .27804 Mtetra
.297 0 .103 r
.36986 .27804 .37783 .26287 .38906 .25888 .3812 .27404 Mtetra
.301 0 .105 r
.3812 .27404 .38906 .25888 .40033 .25499 .39258 .27013 Mtetra
.305 0 .107 r
.39258 .27013 .40033 .25499 .41164 .25119 .404 .26632 Mtetra
.309 0 .109 r
.404 .26632 .41164 .25119 .423 .24746 .41548 .26259 Mtetra
.312 0 .11 r
.41548 .26259 .423 .24746 .43441 .24382 .427 .25893 Mtetra
.314 0 .111 r
.427 .25893 .43441 .24382 .44587 .24023 .43857 .25533 Mtetra
.316 0 .112 r
.43857 .25533 .44587 .24023 .45738 .23669 .4502 .25176 Mtetra
.317 0 .112 r
.4502 .25176 .45738 .23669 .46895 .23318 .46188 .24821 Mtetra
.316 0 .111 r
.46188 .24821 .46895 .23318 .48057 .22969 .47362 .24464 Mtetra
.314 0 .109 r
.47362 .24464 .48057 .22969 .49224 .22623 .48541 .24102 Mtetra
.31 0 .104 r
.48541 .24102 .49224 .22623 .50397 .22278 .49727 .23733 Mtetra
.304 0 .097 r
.49727 .23733 .50397 .22278 .51576 .21934 .50917 .23354 Mtetra
.295 0 .087 r
.50917 .23354 .51576 .21934 .52761 .21594 .52114 .22963 Mtetra
.283 0 .071 r
.52114 .22963 .52761 .21594 .53951 .21257 .53316 .22557 Mtetra
.267 0 .049 r
.53316 .22557 .53951 .21257 .55147 .20925 .54523 .22138 Mtetra
.246 0 .02 r
.54523 .22138 .55147 .20925 .5635 .206 .55736 .21707 Mtetra
.218 0 0 r
.55736 .21707 .5635 .206 .57558 .20282 .56953 .21266 Mtetra
.183 0 0 r
.56953 .21266 .57558 .20282 .58774 .19969 .58177 .20818 Mtetra
.135 0 0 r
.58177 .20818 .58774 .19969 .59995 .19658 .59405 .20363 Mtetra
.073 0 0 r
.59405 .20363 .59995 .19658 .61223 .19348 .60639 .19901 Mtetra
0 0 0 r
.60639 .19901 .61223 .19348 .62458 .19034 .61878 .19433 Mtetra
.61878 .19433 .62458 .19034 .63698 .18713 .63122 .18955 Mtetra
.63122 .18955 .63698 .18713 .64945 .18381 .64371 .18466 Mtetra
.383 .843 .792 r
.64371 .18466 .64945 .18381 .66198 .18037 .65624 .17964 Mtetra
.508 .909 .905 r
.65624 .17964 .66198 .18037 .67457 .17679 .66883 .17448 Mtetra
.6 .926 .966 r
.66883 .17448 .67457 .17679 .68722 .17305 .68146 .16917 Mtetra
.655 .903 .981 r
.68146 .16917 .68722 .17305 .69992 .1692 .69413 .16375 Mtetra
.681 .861 .968 r
.69413 .16375 .69992 .1692 .71268 .16523 .70685 .15822 Mtetra
.69 .812 .941 r
.70685 .15822 .71268 .16523 .7255 .16118 .71961 .15261 Mtetra
.541 .716 .954 r
.04273 .38856 .05043 .39529 .06033 .39256 .05245 .38712 Mtetra
.523 .756 .981 r
.05245 .38712 .06033 .39256 .07028 .38977 .06223 .38562 Mtetra
.495 .792 .998 r
.06223 .38562 .07028 .38977 .08029 .38689 .07208 .38402 Mtetra
.451 .817 .994 r
.07208 .38402 .08029 .38689 .09035 .38391 .082 .38232 Mtetra
.392 .823 .96 r
.082 .38232 .09035 .38391 .10047 .38078 .09198 .38046 Mtetra
.314 .799 .89 r
.09198 .38046 .10047 .38078 .11066 .37754 .10204 .37846 Mtetra
.227 .747 .788 r
.10204 .37846 .11066 .37754 .1209 .37417 .11217 .37631 Mtetra
0 0 0 r
.11217 .37631 .1209 .37417 .1312 .3707 .12236 .37402 Mtetra
.12236 .37402 .1312 .3707 .14154 .36714 .13262 .3716 Mtetra
.008 0 0 r
.13262 .3716 .14154 .36714 .15194 .36352 .14295 .36905 Mtetra
.064 0 0 r
.14295 .36905 .15194 .36352 .16239 .35984 .15334 .36638 Mtetra
.107 0 0 r
.15334 .36638 .16239 .35984 .17288 .3561 .16379 .3636 Mtetra
.141 0 0 r
.16379 .3636 .17288 .3561 .18342 .3523 .1743 .3607 Mtetra
.169 0 0 r
.1743 .3607 .18342 .3523 .19402 .3484 .18487 .35768 Mtetra
.191 0 0 r
.18487 .35768 .19402 .3484 .20467 .34438 .1955 .35453 Mtetra
.21 0 0 r
.1955 .35453 .20467 .34438 .21537 .34023 .2062 .35126 Mtetra
.228 0 0 r
.2062 .35126 .21537 .34023 .22612 .33595 .21695 .34787 Mtetra
.244 0 0 r
.21695 .34787 .22612 .33595 .23693 .33155 .22776 .34438 Mtetra
.259 0 .028 r
.22776 .34438 .23693 .33155 .24779 .32705 .23862 .34079 Mtetra
.273 0 .055 r
.23862 .34079 .24779 .32705 .25869 .32247 .24954 .33711 Mtetra
.286 0 .079 r
.24954 .33711 .25869 .32247 .26963 .31786 .26051 .33336 Mtetra
.297 0 .101 r
.26051 .33336 .26963 .31786 .28061 .31322 .27154 .32954 Mtetra
.307 0 .12 r
.27154 .32954 .28061 .31322 .29164 .30859 .28261 .32567 Mtetra
.315 0 .135 r
.28261 .32567 .29164 .30859 .3027 .304 .29373 .32175 Mtetra
.322 0 .149 r
.29373 .32175 .3027 .304 .3138 .29947 .3049 .3178 Mtetra
.328 0 .159 r
.3049 .3178 .3138 .29947 .32493 .295 .31612 .31381 Mtetra
.333 0 .168 r
.31612 .31381 .32493 .295 .33611 .29062 .3274 .30979 Mtetra
.336 0 .174 r
.3274 .30979 .33611 .29062 .34732 .28633 .33871 .30574 Mtetra
.338 0 .178 r
.33871 .30574 .34732 .28633 .35857 .28214 .35008 .30167 Mtetra
.338 0 .18 r
.35008 .30167 .35857 .28214 .36986 .27804 .3615 .29756 Mtetra
.338 0 .179 r
.3615 .29756 .36986 .27804 .3812 .27404 .37297 .29342 Mtetra
.337 0 .177 r
.37297 .29342 .3812 .27404 .39258 .27013 .38449 .28925 Mtetra
.334 0 .173 r
.38449 .28925 .39258 .27013 .404 .26632 .39606 .28505 Mtetra
.33 0 .166 r
.39606 .28505 .404 .26632 .41548 .26259 .40767 .28082 Mtetra
.324 0 .158 r
.40767 .28082 .41548 .26259 .427 .25893 .41934 .27655 Mtetra
.317 0 .146 r
.41934 .27655 .427 .25893 .43857 .25533 .43106 .27225 Mtetra
.308 0 .132 r
.43106 .27225 .43857 .25533 .4502 .25176 .44283 .26789 Mtetra
.297 0 .115 r
.44283 .26789 .4502 .25176 .46188 .24821 .45466 .26348 Mtetra
.283 0 .094 r
.45466 .26348 .46188 .24821 .47362 .24464 .46653 .259 Mtetra
.267 0 .07 r
.46653 .259 .47362 .24464 .48541 .24102 .47845 .25445 Mtetra
.247 0 .042 r
.47845 .25445 .48541 .24102 .49727 .23733 .49043 .2498 Mtetra
.224 0 .01 r
.49043 .2498 .49727 .23733 .50917 .23354 .50246 .24505 Mtetra
.198 0 0 r
.50246 .24505 .50917 .23354 .52114 .22963 .51453 .24019 Mtetra
.167 0 0 r
.51453 .24019 .52114 .22963 .53316 .22557 .52666 .2352 Mtetra
.132 0 0 r
.52666 .2352 .53316 .22557 .54523 .22138 .53883 .23008 Mtetra
.091 0 0 r
.53883 .23008 .54523 .22138 .55736 .21707 .55105 .22482 Mtetra
.045 0 0 r
.55105 .22482 .55736 .21707 .56953 .21266 .56332 .21944 Mtetra
0 0 0 r
.56332 .21944 .56953 .21266 .58177 .20818 .57563 .21393 Mtetra
.57563 .21393 .58177 .20818 .59405 .20363 .58799 .20829 Mtetra
.58799 .20829 .59405 .20363 .60639 .19901 .60039 .20252 Mtetra
.60039 .20252 .60639 .19901 .61878 .19433 .61283 .19662 Mtetra
.356 .811 .691 r
.61283 .19662 .61878 .19433 .63122 .18955 .62531 .19057 Mtetra
.466 .888 .799 r
.62531 .19057 .63122 .18955 .64371 .18466 .63783 .18436 Mtetra
.566 .938 .886 r
.63783 .18436 .64371 .18466 .65624 .17964 .65039 .17799 Mtetra
.644 .954 .94 r
.65039 .17799 .65624 .17964 .66883 .17448 .66298 .17145 Mtetra
.696 .941 .962 r
.66298 .17145 .66883 .17448 .68146 .16917 .6756 .16475 Mtetra
.723 .908 .959 r
.6756 .16475 .68146 .16917 .69413 .16375 .68826 .15792 Mtetra
.734 .866 .943 r
.68826 .15792 .69413 .16375 .70685 .15822 .70095 .15099 Mtetra
.734 .822 .919 r
.70095 .15099 .70685 .15822 .71961 .15261 .71368 .14397 Mtetra
.467 .687 .962 r
.03496 .38178 .04273 .38856 .05245 .38712 .04455 .38134 Mtetra
.447 .715 .981 r
.04455 .38134 .05245 .38712 .06223 .38562 .0542 .38083 Mtetra
.42 .74 .992 r
.0542 .38083 .06223 .38562 .07208 .38402 .06393 .38023 Mtetra
.387 .76 .992 r
.06393 .38023 .07208 .38402 .082 .38232 .07373 .3795 Mtetra
.349 .771 .976 r
.07373 .3795 .082 .38232 .09198 .38046 .08361 .37861 Mtetra
.303 .77 .941 r
.08361 .37861 .09198 .38046 .10204 .37846 .09357 .37756 Mtetra
.251 .754 .888 r
.09357 .37756 .10204 .37846 .11217 .37631 .1036 .37634 Mtetra
.197 .726 .82 r
.1036 .37634 .11217 .37631 .12236 .37402 .11372 .37493 Mtetra
.145 .689 .745 r
.11372 .37493 .12236 .37402 .13262 .3716 .12392 .37335 Mtetra
0 0 0 r
.12392 .37335 .13262 .3716 .14295 .36905 .13419 .3716 Mtetra
.13419 .3716 .14295 .36905 .15334 .36638 .14454 .36968 Mtetra
.14454 .36968 .15334 .36638 .16379 .3636 .15496 .36762 Mtetra
.022 0 0 r
.15496 .36762 .16379 .3636 .1743 .3607 .16544 .36542 Mtetra
.055 0 0 r
.16544 .36542 .1743 .3607 .18487 .35768 .176 .36312 Mtetra
.089 0 0 r
.176 .36312 .18487 .35768 .1955 .35453 .18661 .36073 Mtetra
.121 0 0 r
.18661 .36073 .1955 .35453 .2062 .35126 .19728 .35827 Mtetra
.154 0 0 r
.19728 .35827 .2062 .35126 .21695 .34787 .20802 .35576 Mtetra
.183 0 0 r
.20802 .35576 .21695 .34787 .22776 .34438 .21881 .35319 Mtetra
.21 0 0 r
.21881 .35319 .22776 .34438 .23862 .34079 .22966 .35055 Mtetra
.233 0 0 r
.22966 .35055 .23862 .34079 .24954 .33711 .24058 .34783 Mtetra
.252 0 0 r
.24058 .34783 .24954 .33711 .26051 .33336 .25155 .34502 Mtetra
.267 0 0 r
.25155 .34502 .26051 .33336 .27154 .32954 .26259 .3421 Mtetra
.28 0 .028 r
.26259 .3421 .27154 .32954 .28261 .32567 .27369 .33907 Mtetra
.289 0 .051 r
.27369 .33907 .28261 .32567 .29373 .32175 .28485 .3359 Mtetra
.295 0 .07 r
.28485 .3359 .29373 .32175 .3049 .3178 .29608 .33259 Mtetra
.299 0 .084 r
.29608 .33259 .3049 .3178 .31612 .31381 .30737 .32913 Mtetra
.301 0 .095 r
.30737 .32913 .31612 .31381 .3274 .30979 .31872 .32552 Mtetra
.301 0 .102 r
.31872 .32552 .3274 .30979 .33871 .30574 .33013 .32173 Mtetra
.299 0 .106 r
.33013 .32173 .33871 .30574 .35008 .30167 .34161 .31778 Mtetra
.296 0 .106 r
.34161 .31778 .35008 .30167 .3615 .29756 .35314 .31366 Mtetra
.29 0 .103 r
.35314 .31366 .3615 .29756 .37297 .29342 .36473 .30937 Mtetra
.282 0 .097 r
.36473 .30937 .37297 .29342 .38449 .28925 .37638 .30491 Mtetra
.273 0 .088 r
.37638 .30491 .38449 .28925 .39606 .28505 .38808 .30028 Mtetra
.261 0 .075 r
.38808 .30028 .39606 .28505 .40767 .28082 .39984 .29548 Mtetra
.246 0 .058 r
.39984 .29548 .40767 .28082 .41934 .27655 .41164 .29054 Mtetra
.228 0 .036 r
.41164 .29054 .41934 .27655 .43106 .27225 .4235 .28544 Mtetra
.207 0 .009 r
.4235 .28544 .43106 .27225 .44283 .26789 .43541 .28021 Mtetra
.182 0 0 r
.43541 .28021 .44283 .26789 .45466 .26348 .44736 .27486 Mtetra
.152 0 0 r
.44736 .27486 .45466 .26348 .46653 .259 .45937 .26939 Mtetra
.117 0 0 r
.45937 .26939 .46653 .259 .47845 .25445 .47141 .26382 Mtetra
.077 0 0 r
.47141 .26382 .47845 .25445 .49043 .2498 .4835 .25817 Mtetra
.032 0 0 r
.4835 .25817 .49043 .2498 .50246 .24505 .49564 .25244 Mtetra
0 0 0 r
.49564 .25244 .50246 .24505 .51453 .24019 .50782 .24664 Mtetra
.50782 .24664 .51453 .24019 .52666 .2352 .52004 .24077 Mtetra
.52004 .24077 .52666 .2352 .53883 .23008 .5323 .23483 Mtetra
.5323 .23483 .53883 .23008 .55105 .22482 .54461 .22879 Mtetra
.54461 .22879 .55105 .22482 .56332 .21944 .55695 .22264 Mtetra
.324 .779 .634 r
.55695 .22264 .56332 .21944 .57563 .21393 .56934 .21634 Mtetra
.396 .835 .705 r
.56934 .21634 .57563 .21393 .58799 .20829 .58177 .20987 Mtetra
.47 .885 .773 r
.58177 .20987 .58799 .20829 .60039 .20252 .59423 .20323 Mtetra
.542 .927 .835 r
.59423 .20323 .60039 .20252 .61283 .19662 .60672 .1964 Mtetra
.609 .955 .886 r
.60672 .1964 .61283 .19662 .62531 .19057 .61925 .18937 Mtetra
.666 .966 .923 r
.61925 .18937 .62531 .19057 .63783 .18436 .63181 .18215 Mtetra
.709 .962 .943 r
.63181 .18215 .63783 .18436 .65039 .17799 .64439 .17473 Mtetra
.738 .945 .949 r
.64439 .17473 .65039 .17799 .66298 .17145 .657 .16713 Mtetra
.756 .919 .945 r
.657 .16713 .66298 .17145 .6756 .16475 .66964 .15935 Mtetra
.764 .888 .933 r
.66964 .15935 .6756 .16475 .68826 .15792 .6823 .15142 Mtetra
.766 .855 .917 r
.6823 .15142 .68826 .15792 .70095 .15099 .69498 .14338 Mtetra
.762 .821 .899 r
.69498 .14338 .70095 .15099 .71368 .14397 .70769 .13525 Mtetra
.42 .667 .963 r
.02714 .37496 .03496 .38178 .04455 .38134 .03665 .37506 Mtetra
.411 .683 .973 r
.03665 .37506 .04455 .38134 .0542 .38083 .04624 .37508 Mtetra
.403 .699 .981 r
.04624 .37508 .0542 .38083 .06393 .38023 .0559 .37499 Mtetra
.395 .715 .987 r
.0559 .37499 .06393 .38023 .07373 .3795 .06564 .37476 Mtetra
.389 .73 .991 r
.06564 .37476 .07373 .3795 .08361 .37861 .07547 .37438 Mtetra
.382 .745 .991 r
.07547 .37438 .08361 .37861 .09357 .37756 .08538 .37384 Mtetra
.375 .759 .989 r
.08538 .37384 .09357 .37756 .1036 .37634 .09537 .37312 Mtetra
.367 .771 .984 r
.09537 .37312 .1036 .37634 .11372 .37493 .10545 .37221 Mtetra
.359 .781 .975 r
.10545 .37221 .11372 .37493 .12392 .37335 .11561 .37112 Mtetra
.348 .788 .962 r
.11561 .37112 .12392 .37335 .13419 .3716 .12586 .36984 Mtetra
.336 .792 .946 r
.12586 .36984 .13419 .3716 .14454 .36968 .13618 .36839 Mtetra
.321 .792 .927 r
.13618 .36839 .14454 .36968 .15496 .36762 .14658 .36678 Mtetra
.302 .787 .903 r
.14658 .36678 .15496 .36762 .16544 .36542 .15705 .36503 Mtetra
.278 .777 .874 r
.15705 .36503 .16544 .36542 .176 .36312 .16759 .36318 Mtetra
.248 .761 .839 r
.16759 .36318 .176 .36312 .18661 .36073 .1782 .36126 Mtetra
.214 .738 .798 r
.1782 .36126 .18661 .36073 .19728 .35827 .18887 .35929 Mtetra
.175 .711 .752 r
.18887 .35929 .19728 .35827 .20802 .35576 .19959 .35729 Mtetra
.138 .68 .703 r
.19959 .35729 .20802 .35576 .21881 .35319 .21039 .35524 Mtetra
0 0 0 r
.21039 .35524 .21881 .35319 .22966 .35055 .22124 .35312 Mtetra
.22124 .35312 .22966 .35055 .24058 .34783 .23216 .35091 Mtetra
.23216 .35091 .24058 .34783 .25155 .34502 .24315 .34858 Mtetra
.24315 .34858 .25155 .34502 .26259 .3421 .25421 .34612 Mtetra
.25421 .34612 .26259 .3421 .27369 .33907 .26534 .3435 Mtetra
.002 0 0 r
.26534 .3435 .27369 .33907 .28485 .3359 .27654 .34071 Mtetra
.008 0 0 r
.27654 .34071 .28485 .3359 .29608 .33259 .28781 .33771 Mtetra
.009 0 0 r
.28781 .33771 .29608 .33259 .30737 .32913 .29915 .3345 Mtetra
.005 0 0 r
.29915 .3345 .30737 .32913 .31872 .32552 .31056 .33107 Mtetra
0 0 0 r
.31056 .33107 .31872 .32552 .33013 .32173 .32204 .3274 Mtetra
.32204 .3274 .33013 .32173 .34161 .31778 .33359 .3235 Mtetra
.33359 .3235 .34161 .31778 .35314 .31366 .3452 .31936 Mtetra
.3452 .31936 .35314 .31366 .36473 .30937 .35687 .31497 Mtetra
.35687 .31497 .36473 .30937 .37638 .30491 .36861 .31035 Mtetra
.36861 .31035 .37638 .30491 .38808 .30028 .3804 .30549 Mtetra
.3804 .30549 .38808 .30028 .39984 .29548 .39225 .3004 Mtetra
.39225 .3004 .39984 .29548 .41164 .29054 .40415 .29509 Mtetra
.40415 .29509 .41164 .29054 .4235 .28544 .4161 .28958 Mtetra
.4161 .28958 .4235 .28544 .43541 .28021 .4281 .28388 Mtetra
.4281 .28388 .43541 .28021 .44736 .27486 .44015 .27802 Mtetra
.349 .803 .672 r
.44015 .27802 .44736 .27486 .45937 .26939 .45224 .272 Mtetra
.398 .839 .72 r
.45224 .272 .45937 .26939 .47141 .26382 .46438 .26587 Mtetra
.446 .872 .765 r
.46438 .26587 .47141 .26382 .4835 .25817 .47656 .25963 Mtetra
.49 .9 .808 r
.47656 .25963 .4835 .25817 .49564 .25244 .48877 .25332 Mtetra
.531 .922 .845 r
.48877 .25332 .49564 .25244 .50782 .24664 .50103 .24695 Mtetra
.567 .938 .877 r
.50103 .24695 .50782 .24664 .52004 .24077 .51332 .24053 Mtetra
.6 .949 .903 r
.51332 .24053 .52004 .24077 .5323 .23483 .52566 .23405 Mtetra
.628 .956 .923 r
.52566 .23405 .5323 .23483 .54461 .22879 .53803 .22749 Mtetra
.655 .958 .938 r
.53803 .22749 .54461 .22879 .55695 .22264 .55044 .22082 Mtetra
.679 .957 .947 r
.55044 .22082 .55695 .22264 .56934 .21634 .56289 .21399 Mtetra
.701 .953 .953 r
.56289 .21399 .56934 .21634 .58177 .20987 .57537 .20699 Mtetra
.72 .946 .954 r
.57537 .20699 .58177 .20987 .59423 .20323 .58789 .1998 Mtetra
.736 .935 .953 r
.58789 .1998 .59423 .20323 .60672 .1964 .60044 .19241 Mtetra
.75 .923 .948 r
.60044 .19241 .60672 .1964 .61925 .18937 .61301 .1848 Mtetra
.76 .909 .941 r
.61301 .1848 .61925 .18937 .63181 .18215 .62561 .17699 Mtetra
.767 .893 .933 r
.62561 .17699 .63181 .18215 .64439 .17473 .63823 .16898 Mtetra
.772 .877 .924 r
.63823 .16898 .64439 .17473 .657 .16713 .65088 .16079 Mtetra
.775 .861 .913 r
.65088 .16079 .657 .16713 .66964 .15935 .66354 .15242 Mtetra
.776 .844 .903 r
.66354 .15242 .66964 .15935 .6823 .15142 .67623 .14389 Mtetra
.775 .828 .893 r
.67623 .14389 .6823 .15142 .69498 .14338 .68893 .13523 Mtetra
.773 .811 .883 r
.68893 .13523 .69498 .14338 .70769 .13525 .70165 .12647 Mtetra
.424 .669 .963 r
.01926 .36808 .02714 .37496 .03665 .37506 .02879 .36811 Mtetra
.437 .673 .962 r
.02879 .36811 .03665 .37506 .04624 .37508 .0384 .36801 Mtetra
.45 .675 .96 r
.0384 .36801 .04624 .37508 .0559 .37499 .04809 .36777 Mtetra
.463 .677 .957 r
.04809 .36777 .0559 .37499 .06564 .37476 .05786 .36741 Mtetra
.475 .678 .954 r
.05786 .36741 .06564 .37476 .07547 .37438 .06772 .36691 Mtetra
.486 .679 .951 r
.06772 .36691 .07547 .37438 .08538 .37384 .07765 .36627 Mtetra
.496 .681 .949 r
.07765 .36627 .08538 .37384 .09537 .37312 .08766 .3655 Mtetra
.506 .684 .947 r
.08766 .3655 .09537 .37312 .10545 .37221 .09775 .36459 Mtetra
.514 .688 .946 r
.09775 .36459 .10545 .37221 .11561 .37112 .10792 .36354 Mtetra
.521 .694 .947 r
.10792 .36354 .11561 .37112 .12586 .36984 .11816 .36235 Mtetra
.528 .7 .948 r
.11816 .36235 .12586 .36984 .13618 .36839 .12848 .36102 Mtetra
.535 .708 .951 r
.12848 .36102 .13618 .36839 .14658 .36678 .13888 .35955 Mtetra
.541 .715 .953 r
.13888 .35955 .14658 .36678 .15705 .36503 .14935 .35793 Mtetra
.547 .723 .955 r
.14935 .35793 .15705 .36503 .16759 .36318 .1599 .35617 Mtetra
.553 .729 .957 r
.1599 .35617 .16759 .36318 .1782 .36126 .17052 .35427 Mtetra
.561 .733 .956 r
.17052 .35427 .1782 .36126 .18887 .35929 .18122 .35222 Mtetra
.569 .734 .953 r
.18122 .35222 .18887 .35929 .19959 .35729 .19198 .35002 Mtetra
.578 .732 .948 r
.19198 .35002 .19959 .35729 .21039 .35524 .20282 .34767 Mtetra
.586 .727 .941 r
.20282 .34767 .21039 .35524 .22124 .35312 .21373 .34518 Mtetra
.594 .72 .931 r
.21373 .34518 .22124 .35312 .23216 .35091 .22471 .34253 Mtetra
.602 .71 .921 r
.22471 .34253 .23216 .35091 .24315 .34858 .23576 .33974 Mtetra
.608 .7 .909 r
.23576 .33974 .24315 .34858 .25421 .34612 .24688 .33679 Mtetra
.614 .69 .898 r
.24688 .33679 .25421 .34612 .26534 .3435 .25807 .33369 Mtetra
.618 .681 .887 r
.25807 .33369 .26534 .3435 .27654 .34071 .26932 .33044 Mtetra
.622 .672 .877 r
.26932 .33044 .27654 .34071 .28781 .33771 .28063 .32704 Mtetra
.626 .665 .868 r
.28063 .32704 .28781 .33771 .29915 .3345 .29202 .32348 Mtetra
.63 .66 .861 r
.29202 .32348 .29915 .3345 .31056 .33107 .30346 .31977 Mtetra
.633 .656 .855 r
.30346 .31977 .31056 .33107 .32204 .3274 .31497 .3159 Mtetra
.636 .654 .85 r
.31497 .3159 .32204 .3274 .33359 .3235 .32653 .31188 Mtetra
.64 .654 .848 r
.32653 .31188 .33359 .3235 .3452 .31936 .33816 .3077 Mtetra
.644 .656 .847 r
.33816 .3077 .3452 .31936 .35687 .31497 .34985 .30336 Mtetra
.648 .659 .847 r
.34985 .30336 .35687 .31497 .36861 .31035 .36159 .29887 Mtetra
.653 .664 .849 r
.36159 .29887 .36861 .31035 .3804 .30549 .37339 .29421 Mtetra
.658 .672 .852 r
.37339 .29421 .3804 .30549 .39225 .3004 .38525 .2894 Mtetra
.663 .681 .856 r
.38525 .2894 .39225 .3004 .40415 .29509 .39716 .28444 Mtetra
.669 .691 .862 r
.39716 .28444 .40415 .29509 .4161 .28958 .40912 .27931 Mtetra
.675 .703 .868 r
.40912 .27931 .4161 .28958 .4281 .28388 .42114 .27402 Mtetra
.681 .716 .875 r
.42114 .27402 .4281 .28388 .44015 .27802 .4332 .26858 Mtetra
.688 .73 .882 r
.4332 .26858 .44015 .27802 .45224 .272 .44532 .26297 Mtetra
.694 .743 .889 r
.44532 .26297 .45224 .272 .46438 .26587 .45748 .25721 Mtetra
.7 .756 .895 r
.45748 .25721 .46438 .26587 .47656 .25963 .46968 .25129 Mtetra
.706 .767 .9 r
.46968 .25129 .47656 .25963 .48877 .25332 .48194 .24521 Mtetra
.711 .776 .903 r
.48194 .24521 .48877 .25332 .50103 .24695 .49423 .23897 Mtetra
.716 .783 .905 r
.49423 .23897 .50103 .24695 .51332 .24053 .50657 .23257 Mtetra
.72 .786 .904 r
.50657 .23257 .51332 .24053 .52566 .23405 .51894 .22601 Mtetra
.724 .786 .901 r
.51894 .22601 .52566 .23405 .53803 .22749 .53136 .21929 Mtetra
.727 .783 .897 r
.53136 .21929 .53803 .22749 .55044 .22082 .54381 .21241 Mtetra
.73 .78 .892 r
.54381 .21241 .55044 .22082 .56289 .21399 .5563 .20537 Mtetra
.732 .776 .888 r
.5563 .20537 .56289 .21399 .57537 .20699 .56882 .19818 Mtetra
.735 .772 .883 r
.56882 .19818 .57537 .20699 .58789 .1998 .58138 .19082 Mtetra
.737 .77 .879 r
.58138 .19082 .58789 .1998 .60044 .19241 .59396 .18331 Mtetra
.74 .769 .876 r
.59396 .18331 .60044 .19241 .61301 .1848 .60658 .17564 Mtetra
.743 .77 .874 r
.60658 .17564 .61301 .1848 .62561 .17699 .61922 .16782 Mtetra
.747 .771 .873 r
.61922 .16782 .62561 .17699 .63823 .16898 .63189 .15984 Mtetra
.751 .774 .872 r
.63189 .15984 .63823 .16898 .65088 .16079 .64458 .1517 Mtetra
.755 .778 .872 r
.64458 .1517 .65088 .16079 .66354 .15242 .6573 .14341 Mtetra
.759 .783 .873 r
.6573 .14341 .66354 .15242 .67623 .14389 .67003 .13496 Mtetra
.763 .787 .873 r
.67003 .13496 .67623 .14389 .68893 .13523 .68279 .12636 Mtetra
.767 .791 .873 r
.68279 .12636 .68893 .13523 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Sooooo`03olC:gol0003ooooo01Gooooo00?o
0000ooooooooool0DOooool0063ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`0Mooooo`?o00000_ooool00ol0003oooooooooo`1Oooooo`?oa<[O00?o
0000olC:goooool05Oooool00ol0003oooooooooo`1@ooooo`00H?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol0000Looooo`;o0000IOooool00oo3bMooa<[OolC:g`02olC:g`03o`000?o5
cn;ooooo01Cooooo00?o0000ooooool00000DOooool0063ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0001[ooooo0ol0001Vooooo`?o`lWO0oo4b]l00ol0003oaLoR
olG?hP0Fooooo`03o`000?oooooooooo04oooooo001Pooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool0000Hooooo`;o0000J?ooool5ol?9g`03olC:goo5cn;o000000?o
aLoR5_ooool00ol0003oooooooooo`1>ooooo`00H?ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l000005Oooool3o`0000;ooooo00?o0000ooooooooool0Hoooool00oo2b=oo
`lWOol?9g`03ol?9g`04olKCi?o5cn;oaLoRo`0000;oaLoR00?o`m;Vooooooooool05?ooool00ol0
003oooooooooo`1>ooooo`00H?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4
A?l000004oooool2o`0006[ooooo0oo2b=l3ol?9g`?oa]?T00?oaLoRo`000?o5cn800oo3d^HFoooo
o`03o`000?oooooooooo04gooooo001Pooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omg
MgOo0000ooooo`0?ooooo`?o0000Joooool5ol;8g`03ol?9goo6dnCoa]?T00?oa]?T00?o0000ol?B
i_o3d^H00oo3d^HFooooo`03o`000?oooooooooo04cooooo0022ooooo`;o0000K?ooool00oo1amoo
`/SOol;8g`03ol;8g`;oa]SW1?o6dn@00oo4f^[o0000ol?BiP03ol?BiP03ok_Bjooooooooooo01Co
oooo00?o0000ooooooooool0C?ooool007oooooo0ol00002ooooo`03o`000?oooooooooo06Oooooo
1?o1aml3ol;8g`Coa]SW00Ooa]?TolCJj_o4f^[oa=[Zo`000?o4f^[o`m;V00Co^m;[5?ooool3o`00
04gooooo001looooo`?o0000KOooool00oo0a]oo`LOOol77g`04ol77g`03ol;8goo6f>Ooa]SW00;o
a]SW0_o3hnh3olCJjP03o`000?nkgO7o^m;[00Co^m;[5oooool00ol0003oooooooooo`1:ooooo`00
N_ooool2o`0006oooooo0oo0a]l4ol77g`;oa]cY0oo6f>L4ol?SkP05olCJj_nkgO7o^mgao`000?nk
gO400_nkd^/3ok3?l1Kooooo00?o0000ooooooooool0B_ooool007Oooooo0ol0001`ooooo`Go`<KO
00?o`LOOolKLjOo6g>T00oo6g>T00oo6f>Oo`n?^ol?SkP02ol?SkP06okWXmOnkgO7o^mgaok_MlOl0
003o[]cg1_n`co0Fooooo`03o`000?oooooooooo04Wooooo001eooooo`;o00000_ooool00ol0003o
ooooooooo`1/ooooo`03oko5goo0a]oo`<KO00?o`<KO0_o5h>`4olKLj@;o`N_a0oo3hnh3okWXm@03
ok_MlOn^g?Oo000000;o[]cg1?n`co000onQb?Coooooooooo`0Eooooo`03o`000?oooooooooo04So
oooo001booooo`?o00001Oooool00ol0003oooooooooo`1Zooooo`?o_lGO0oo0a]l4olGPk003olKL
jOo1jo7o`N_a00?o`N_a00Co`n?^okWXmOnij?Go^NSe0_nWio/00on^g?Oo0000ojkLm`02ojkLm`03
ok3?l?nQb?CoXLSd00;oXLSd5_ooool00ol0003oooooooooo`18ooooo`00L?ooool2o`0007Cooooo
1OnoaMl00oo0a]ooaN3/olGPk002olGPk0;o_?7b1?o1jo42ok;`mP03okWXmOnWio_oYnOk00?oYnOk
00?o0000ojkLmonMdo/00_nMdo/5oj78m1Kooooo00?o0000ooooooooool0Aoooool003Sooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00023ooooo0ol0001dooooo`;o_/GO
1?noaMl2olCTkP?oaN3/1?nllO801?o1jo7o/_3fok;`m_nbl?H3oiW]m`;oYnOk0_nEg?h00ol0003o
WM?koigCn`03oigCn`;oXLSd0_nC__@Eooooo`?o0000B?ooool003Sooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A401kooooo0_l00003oooo
o`03o`000?oooooooooo06oooooo1OnnaMl00onoaMooa>C^olCTkP03olCTkP03olGPk?nllO;o_?7b
00;o_?7b0_nTm?001?nbl?KoVNggoiW]monIkOL3ohOQo0?oUMcn00Co0000oiGLo_nMdo_oWM?k0on?
a?T4oi>nm1Kooooo00?o0000ooooooooool01_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`;o000000?o410@ooooooooool0:Oooool003Sooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^01cooooo0ol0001eooooo`03okg4h?nnaMoo_/GO00?o_/GO
0_o2j?04olCTkP?o]OKa00?o_?7bojCdl?nTm?000_n2j>L4og7Ml0CoQn7l0_nEg?h00ol0003oR/[m
oh[:o@05oho4n@CoTkkd5_ooool00ol0003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0:_ooool003Sooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Sooooo0ol0001fooooo`Co_LCP0onnaMl4ol;Xl003
olCTk_nem_7o]OKa00;o]OKa00?oT?3Rof;Gb_mRelX00omFdMT2og7Ml0?oN]3o1On3c_l01?l0003o
R/[moh[:oOn:b_d2oho4n@;oQkOe1On9]O<Fooooo`03o`000?oooooooooo00Cooooo00Go410@oooo
oooooooooooooa0@400;ooooo`Go0000:oooool003Sooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo01Gooooo0ol0001fooooo`03okc5hOnma>3o_LCP00Co_LCP00?o_/GO
ol;Xl?o2j?000_o2j?03oj[gk004okGflOn@l>;oH]O:of;GbP?oE]7I1?m`dOd4og[@o`;oPlko0_n4
^oP00ol0003oQKWgohFim`02ohFim`CoQkOe1On9]O<Eooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002cooooo000hooooo`05oa0@
4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Aooooo`?o00000oooool00ol0003o
ooooooooo`1booooo`?o_<GQ1?nma>03oko/lP03ol;Xl?nZmncoZ_O/00;oZ_O/0_l00002oek>m@Co
I]3i0_m`dOd3oh6lnPCoP[_i0on4^oP00ol0003oQKWgohFim`03ohFim`CoQkOe0_n9]O<2ohN^kaKo
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEE
EOoooooo0000;?ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41004Oooool2o`0007[ooooo1OnlaN400onma>3o_ncboko/lP02oko/lP?oVoCR00?o
Z_O/oeS<lOmHc?400_mNc_D3oh>kn@CoP[ci1On1_?X4oh:kn@;oQ;_h00Co0000ohBkn?n5^OOoQKWg
0_n8ZN/4ohN/k@GoQjk_5_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00omgMgOoc<c<o`00000/ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c00>ooooo`?o0000N_ooool00onlaN;o_<GQokc5h@03okc5
h@;o_>oc0onok?83oi_dhP03ohRim_n5^_SoQK[h00;oQK[h1On3^oT4oh:ln@;oPKcj0_n<X^<4ohZT
iP;oRJOY00?o0000ohVWjOn8ZN/01?n8ZN/4ohN/k@GoQjk_5?ooool2o`0000Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002cooooo001Iooooo`?o0000N_ooool4okc5
hP?o_<GQ1?nlko<00onok?;oVoCRoi_dhP04ohRimPCoQK[h0_n3^oT2ohnLg0CoSIoO1On<X^<4ohZT
iP04ohVWjOl0003oRJOYohVWj@GoR:W[1?n7[>d2ohN^k`;oS:c/4oooool01?l0003oooooooooool0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0[ooooo`00E_oo
ool3o`0000?ooooo00?o0000ooooooooool0M?ooool00olg003o^lKSokc5hP05okc5hP03okc5hOnl
ko?o_>oc00;o_>oc0_n:kMD2oh^gl`;oR;Wf0_nBU]<4oi6If0GoSicL1?n=Wml4ohbRh`GoRZCV00Co
0000ohVWjOn9YnWoRJOY0_n8ZN/2ohjQh@CoSJKV1On<[>`Fooooo`03o`000?oooooooooo043ooooo
001Dooooo`;o0000NOooool2oc/00003ocL00?nka^?o^lKS00;o^lKS1?nlaN83okSbm003okc_lon:
kMGoR^gE00;oRkOc0_nCT/l5oi:Fd`CoTIWH1?n?W=`5ohfOg`CoS:;S0_n:Y>H2oi2Ge`04o`000?n?
W=coSicLohnLg0GoSZ7Q1?n=Y^H4ohb/k1Kooooo00?o0000ooooooooool0@?ooool0057ooooo0ol0
001fooooo`03ocJk^_ln`/So?@0000?o>`0000?o^/OTok_6honka^<01?nka^<00onlaN;o^?;dokSb
m002okSbm004ogSRaOnDS/[oU8k:oiB>bPGoTi;?1?nBU]<5oi6If0CoSicL0_n=Wml2oi>?c0CoTI?A
1?n@UmL00ol0003oSicLohnLg002ohnLg0CoSZ7Q0_n=Y^H2oiJUg`GoUJgW5_ooool00ol0003ooooo
ooooo`0oooooo`00C_ooool5o`0007?ooooo00Co0000ocJk^_lo003o?`000olm0002oc/000?o^/OT
1?nka^<3ok?cl`03okSbm?nDRLGoU8W500;oU8W50onDS/X4oi>Bc`GoTYKC0_nAVMP2oiF8``CoU8_8
1OnCSl`3oi6Cd@CoT9OG00?o0000ohnLg?n?W=`00_n?W=`2ohjQh@;oUYgH1OnFYMl5oiF]iaKooooo
00?o0000ooooooooool0?_ooool004cooooo0_l00005ooooo`03o`000?oooooooooo06gooooo00?o
0000od400?m100001?lo0002ocd00003oc/00?m400co^/OT00Co^/OT00?o^lKSok?clonclo<00_nc
lo<2oiB4`0CoU8W50onDS/X5oi>Bc`;oTYKC0_nFQKl5oiF8``CoU8_81?nCSl`4oi6Cd@?oT9OG00?o
0000ohnLg?n?W=`00_nGU]45oiJMf0GoUZGO0_nE[NL2oj6ciAKooooo00?o0000ooooooooool0?_oo
ool004Wooooo0ol0001cooooo`03o`000?m1003o@@0000Co@@000olo00000olm003oB00Bod@03002
ok[8i@Co^/OT0on]m?800onclo?oU8C0oiB4`002oiB4`0CoU8W51?nDS/X2oi>Bc`;oUh:k1OnFQKl4
oiF8``CoU8_81OnCSl`3oi6Cd@;oT9OG0_nGT<X00ol0003oUiKAoiNFd@02oiNFd@CoUYgH1?nFYMl0
0onQZ]goXK?Uoj6ci@03oj6ciACooooo0ol0000oooooo`008_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^023ooooo0_l0001booooo`;o00002?m100000olo003oB`0Fod/05P02odP04PGo^/SU00?o^/OT
ojgdl_n]m?800_n]m?82oi>0^`CoU8C01OnDRLD2oiB>bP03oiMo^?nGP[_oUh:k00?oUh:k1?nFQKl4
oiF8``GoU8_80_nCSl`2oiN5_P?oUh[41?nGT<X00ol0003oUiKAoiNFd@02oiNFd@GoUYgH00?oUZGO
oj6ZgOnQZ]d00_nQZ]d5oj6ciAGooooo00?o0000ooooooooool0?Oooool002;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Mooooo`?o00000_ooool00ol0003oooooooooo`1/ooooo`03o`000?m1003o
@@0000Oo@@000_m=01P4od/05P;o^LWV1?njb>D3ojOel003ojgdl_nCP;_oTh2k00;oTh2k1OnDQ<02
oiB9a@;oUgfd1?nGOkP4oiN2^`CoUXFo1OnER<<3oiB;b003oiR1^OnGQKkoUhFn00?oUhFn0onGR/@3
oiN@bP03o`000?nGU]7oUiKA00?oUiKA0_nFWMP2oj6RePKoXJ[M0_nQ/nD3ojbjhaGooooo00?o0000
ooooooooool0??ooool002;ooooo00Go410@oooooooooooooooooa0@400Kooooo`;o0000L?ooool2
o`000003od000?m1003o@@0000Go@@000_m?01X4odd060;oB`0F1OnibNH00onjb>GoYoG`ojOel002
ojOel0;oTgbg1OnCP;/3oiB4`003oiMk/OnGOKCoUgfd00;oUgfd1?nGOkP4oiN2^`GoUXFo1?nER<<0
0onDRlSoV86ioiR1^@02oiR1^@CoUhFn0onGR/@3oiN@bP04o`000?nGT<[oUiKAoiNFd@;oXI_?1OnQ
X]H4oj6Zg@03ojbcgOn/^^?o[;[S00Co[;[S5Oooool00ol0003oooooooooo`0kooooo`008_ooool0
1Ol0003ooooooooooooooooo000001Sooooo0ol0001^ooooo`;o00000_lo0003od0000Co@@0000?o
D00Kodl06_m?01X00_m?01X3odd06003od/05_nhbNOo^LWV00Co^LWV0onPm>`00onWmO3oTWRcoi=l
]`03oi=l]`CoTh2k00CoU8C0oiMk/OnGNk7oUg^a1OnGOK@3oiMo^0GoUh:k1?nFQKl2oiF8``;oV7je
1OnHPKT4oiN5_PCoUh[40_nGT<X00ol0003oXIG8oj6Kc`04oj6Kc`GoXJ;F00?oXJ[MojbcgOn//md0
0_n//md4ojbjh`03okG1hooooooooooo01?ooooo00?o0000ooooooooool0>oooool002;ooooo00Go
0000ooooooooooooooooo`00000Fooooo`?o0000KOooool00ol0003o?P00och00003ocl000?o@000
00?o@@00oe007?m@01`00om@01/3odl06P?oC@0H1?nhbNL3okW9iP?oX?C/1?nBN;<3oi=l]`;oTh2k
0_nGN:l5oiMk/@CoUgfd1?nGOkP4oiN2^`;oUXFo0_nHO;85oiQn]@CoV86i1OnGQKh2oiN:a004oj6@
`onQULSoXIG8o`0000;oXIG81?nQVll4oj6ReP03ojb]f?n//mgo[;?M00Co[;?M00?o[;[SokG1hone
`N<00_ne`N<Eooooo`03o`000?oooooooooo03[ooooo000Rooooo`05oa0@4?ooooooooooooooool@
41004oooool3o`0000;ooooo00?o0000ooooooooool0Ioooool2o`000003oc`00?ln003o?P0000;o
?P000_lo00000om0003oD@0Loe407004oe0070;oD00K1?m?01X00om=01So]lSWokS9i`05okS9i`03
okW9i_nPm>coX?C/00;oTWJ`1?nBN;<2oi=l]`03oiMf[?nGN:ooUgR_00;oUgR_1OnGNk44oiMm]0Co
Ugnh0_nGP[/2oiUj[`CoV7bb1OnHO[D5oiR1^@CoUhFn00KoUh[4oj6@`onQT<?oXI33oj6Eb?l00002
oj6Eb0GoXI_?00?oXJ;Fojb]f?n/[MP00_n/[MP4ojbcg@03okFmh?ne`N?o]L7S00?o]L7S5_ooool0
0ol0003oooooooooo`0iooooo`008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg013ooooo0ol0001/
ooooo`;o000000Co>`00oc`00?ll003o?0000oln00000olo003oD00Loe407003oe4070?oD00L0om@
01/3odl06PCo]lSW1?nhbNL2oiWbi`CoTWJ`0_nBN;<2oiIdZP?oUgJ/1OnGN:l4oiMk/@GoUgfd0_nG
OkP00onIN:goVGZ_oiUj[`02oiUj[`GoV7bb1?nHO[D5oiR1^@;oUhFn0_nQS;h4oj6@``03oj6Eb?l0
003oXIG800;oXIG80_nQVll2ojbWd`Ko[:gH00?o[;?MokFmh?ne_N000_ne_N03okG1h`;o^/SU5?oo
ool2o`0003_ooooo000Rooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool2o`0006_ooooo1?l0
0003oc/000;o?0000_ln0004oe0070?oD@0L0om@01`4oe006`03odl06_nfa^Oo]lSW00Go]lSW00?o
^<WWoiWbionIl^L00_nALjd3oi9f/003oiIbZ?nFM:[oUWBZ00;oUWBZ1?nGMZ`4oiMh[`GoUg^a1?nG
OK@00onGOkSoVGR]oiUh[@05oiUj[`CoV7bb1OnHO[D3oiR1^@03oj28^_nQS;koXHbn00?oXHbn0onQ
T<<01OnQULSo0000oj6Eb?nQULSo[:C?00Go[:OC1?n/[MP00one^Mgo]KgPokFmh004okFmh003okG1
honjb>Go^/SU00;o^/SU5Oooool00ol0003oooooooooo`0hooooo`00<_ooool5o`0006Sooooo1Ol0
00001?li003o>`00oc/00?lk0003oc`000GoD00L1?mA01`3oe007003oe006om4017oA00A00Co]/KW
1?ngb>L2oi7`h005oi5aZonALjgoTG>]oi5c[OnBM[000onFLZP5oiIdZP?oUgJ/1?nGN:l5oiMk/@;o
Ugfd0_nJN:`4oiUh[@CoVGZ_1?nHO;85oiQn]@03oiR1^OnPR;[oX8Rj00;oX8Rj1?nQS;h3oj6@``;o
00001?n/Y<l5ojbWd`03ojb]f?ne^Mgo]KWM00;o]KWM1?ne_N000onkbNGo^/SUok[8i@02ok[8i@03
ok[=j?oooooooooo01Cooooo00?o0000ooooooooool0=oooool0033ooooo0_l0001/ooooo`;o0000
0_lg0003ocT000;o>`0000?o?000odl07?m?01`01_m@01`4oe407005oe007?m801SoA00Aod@04Ond
a>H01_nfa^L00ongb>OoTO3Poi7`h003oi5aZ`;oTG>]00?oUG2VoiIbZ?nFLZP00onFLZP4oiIdZP?o
UgJ/1OnGN:l3oiMk/@03oiYgZonJN:coVWR/00;oVWR/1?nIN:d4oiUj[`GoV7bb0onHO[D00onPQKOo
X8Rjoj28^P03oj28^PCoXHbn0ol000000on/XL_o0000ojbTc`03ojbTc`Co[:OC00?o]KOJokFigOne
^Md01?ne^Md00one_N3o^lWUok_9i@02ok_9i@03ok[8iOnjcNSo^/gX00;o^/gX5Oooool00ol0003o
ooooooooo`0gooooo`00;Oooool3o`0006_ooooo00?o0000ocH00?lf00000olg0003ocT00003oc/0
0?m?01_oC`0L00?oC`0L1_m@01`00omA01coC00Mod`07@03odP060Co]<CV1?nfa^L00on7k=SoTG2Y
oi5`Z@02oi5aZ`;oU6jU0onEL:H5oiIbZ0CoUWBZ0onGMZ`5oiMh[`04oiMk/OnJMj_oVWN[oiYgZ`Go
VWR/0onIN:d4oiUj[`GoV7bb00?oV7jeoj25]onPQKL00_nPQKL4oj28^P06oj6<__l0003o0000o`00
0?nQS;koXI330on/XL/00ol0003o[:C?ojbTc`02ojbTc`03ojbWdone]m[o]KOJ00;o]KOJ1?ne^Md0
0onlbnKo^lWUok_9i@02ok_9i@03ok_Ck?njcNSo^/gX00Co^/gX5Oooool00ol0003oooooooooo`0f
ooooo`00;?ooool2o`0006[ooooo00?o0000oc@00?lf00000olf0002ocL00003ocT00?m>01_oCP0K
00?oC`0K0om?01`4oe0070;oCP0Q1?m<01d00om801So/l7UokC4iP05okC4iP03okK6ionBKjSoTG2Y
00;oTG2Y00?oU6fToiA^YOnDKZD00_nDKZD4oiE`YPCoUW:X1?nFM:X4oiMf[0?oUgR_00?oVgNZoiYg
ZonJMj/00onJMj/4oiYh[0?oVGR]1OnINZl3oiQl/P03oj23]?nPQKOoX8Fg00?oX8Fg0_nPR;X3o`00
00?oXHbn00?o[Ik8ojbQbon/XL/00_n/XL/01On/Y<oo0000ojbTcon/Y<oo][KH00Ko]KOJ00?o]KWM
okc;i_nlbnH00_nlbnH2ok_9i@?o^m?/1?njcNP2okG?kAGooooo00?o0000ooooooooool0=Oooool0
02cooooo0ol0001Vooooo`?o00000_ld0003ocH00003ocL00?m=01[oCP0K00?oCP0K0_m?01/4odl0
7003oe007?mA02GoCP0Q00?oCP0Q0om<01d4ok?1i@Co]<CV00CoONK>oi9_Z?nBKjSoTG2Y0onDKJ@4
oiA^Y@CoUG2V1?nFLZP4oiIdZPCoUgJ/00CoUgR_oi]gZ_nKMj[oVgNZ1OnJMj/4oiYh[0CoVGR]1?nI
NZl01?nHO;;oX8>doj23]?nPPk@4oj25]`?o00000onPR;X01?nQS;ko[Ik8ojfNb?n]W/P5ojbQb`03
ojbTcol0003o][KH00;o][KH1?ne]mX00onmc^Oo_<_Vokc;iP03okc;iP03ok_9iOnkdnco^m?/00?o
^m?/00?o^/gXokG?kOnecnd00onecndDooooo`03o`000?oooooooooo03Gooooo000/ooooo`04o`00
0?oooooo0000o`0006?ooooo0_l00002oc<000;o=0000_lf00001?m<01[oC@0Jodd06_m=01X3odh0
6`?oC`0K0_m?01`01?mB02SoD@0Uoe409OmA02D3odh08@;oC00M0_na_^<5ok?1i@03okC4i_mmi/ko
TVjW00;oTVnX00?oTfbSoiA]Y?nDKJ@00_nDKJ@4oiA^Y@CoUG2V1?nFLZP5oiIdZP;oUgJ/00?oVgNY
oi]gZ_nKMjX00onKMjX4oiYgZ`CoVWR/1?nIN:d2oiUj[`;oWh6b1OnPPk@3o`0000;oX8Fg0onPR;X0
0on^WLKo[Ik8ojfNb003ojfNb0?o[:7;00?o]kGGokJff?l000001?nf]]P00one]m[o_LkWokg>i`02
okg>i`?o_<_V0_nlfnl4ok_Ck0;o]M_c1?necnd00on[bo7oooooooooo`0Aooooo`03o`000?oooooo
000000Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`00
0?l@413oc<c<01Wooooo000/ooooo`;o00000_ooool00ol0003oooooooooo`1Nooooo`03o`000?la
003o<`0000?o<`000_ld0003od`06P;oC@0J0om>01/4odl06`?oDP0X0_mA02D4odh08@Go/KkS0onc
`ND01?mbgl?oTVjWoi=[X_nCJj83oi=/X`GoU6fT0onDKZD4oiE`YPGoUW:X1?nFM:X00onGMZcoVgNY
oi]gZ@05oi]gZPCoVWN[1OnJN:`2oiUh[@03oimo/?nOPK;oWh6b00;oWh6b0_nPPk@3o`0000GoX8Fg
00?oX8RjojjMa_n^WLH00_n^WLH4ojfNb0;o[:7;0ong]ML01Onf]]So0000okJff?nf]]So_];Y00Ko
_LkW00?o_<_VokcKkonlfnl00_nlfnl00onkdnco]M_cokGKl`03okGKl`03okG?kOn[bo7oZl_a00;o
Zl_a5Oooool00ol0003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0Iooooo`00:oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05Wooooo0_l000001?l`003o<@00oc400?la0003oc<00003oc@00?m:01Wo
C00J00;oC00J0om=01X3odh06`03odl06omD02[oE00Z00?oDP0X0omA02D2odh08@;o/;[Q1_na_^<0
0onc`NGoTVZQoi=[XP03oi=[XP?oTfbS1OnDKJ@4oiA^Y@?oUG2V1OnFLZP3oiIdZPGoVgNY1?nKMjX4
oiYgZ`GoVWR/00?oVGR]oimo/?nOOk001?nOPK82o`0000?oX8>d1?nPQKL00on^W<Go[Yg6ojjMaP03
ojjMaPCo[Ik800?o[:7;okNeeong]ML00_ng]ML2okJff004o`000?nnd^Wo_];YokkBj@Co_LkW0_nk
ho<2okcKk`Co/>Kh0_nefo<2ojSFn0GoZl_a5Oooool00ol0003oooooooooo`05ooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001Wooooo000[ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0EOooool4o`0000;o<0000_la00000olc003oB@0I
odT06@03odX06@;oC00J1?m=01X00om>01_oE@0/oe@0:P03oe@0:P?oDP0X0_mA02D00on^]moo/;[Q
ok2jh@03ok2jh@Co/KkS0onBJZ44oi=[XPCoTfbS1?nDKJ@4oiA^Y@CoUG2V1?nFLZP00onFM:[oVgNY
oi]gZ@05oi]gZ@CoVgNZ1OnJMj/3oiYh[003oimn[onOOk3oWgn`00;oWgn`0ol000000onOPK;oX8>d
oj23]003oj23]0;oX8Fg0on^W<D4ojjMaP?o[Ik800?o^;KGokNeeong]ML01?ng]ML00onf]]So0000
okkBj@03okkBj@04okg>ionkho?o^n?cok_Sl`;oXnog1?n`i_P00onOgocoZ=KhojSFn003ojSFn0;o
Zl_a0onO`o8Eooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?nHV9SooooooiRHV?lQ8B406Oooool002_ooooo0ol00005ooooo`03o`000?oooooooooo
05?ooooo0_l00002obl000;o<00000?o<@00odP06?m901T00om901T2odX06@?oC00J00?oC@0JoeH0
;OmF02d00omE02`3oe@0:P?oDP0X00?oD@0Uojjggon^]ml00_n^]ml5ok2jh@03ok6nhonBJZ7oTVZQ
00?oTVZQ1?nCJj84oi=/X`CoU6fT1?nDKZD4oiE`YP;oUW:X2_nKMjT4oi]gZPGoVWN[00GoVWR/oimn
[onOOZooWgj_oimo/003o`0000CoWh6b1OnPPk@00onPQKOo[Yc5ojjLa@02ojjLa@Go[Yg600Co[Ik8
okRfeonh]]Oo^;KG1?ng]ML2okoGj`04okkBjOl0003o_];YokkBj@;o]ngf00?o^n?coj?_monSkoL0
0onSkoL00on`i_SoWmoloioOo002oioOo0;oZ=Kh0onKbOL5oio3lQGooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Ioooo
o`00:oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo053ooooo00?o0000obl00?l_
00000_l_0002oc0000?oB00H0om901T3odX06@03od`06_mF02goEP0]00?oEP0]0_mE02`4oe@0:P;o
DP0X00?o[;?Nojjggon^]ml01?n^]ml2ok2jh@03oi9YX?nBJZ7oTVZQ00KoTVZQ0onCJj84oi=/X`Co
U6fT1?nDKZD3oiE`YP03oi]fZOnKMjWoVgNY00[oVgNY1OnKMjX3oiYgZ`03oimm[onOOZooWgj_00?o
00000onOOk05oin1/P?oX8>d00?o[Y_4ojjLaOn^W<D00on^W<D4ojjMaP03okVhf?nh]]Oo^;KG00?o
^;KG00?o]kGGokoGjonoen/00onoen/01?nnd^Wo0000okO]m_ngkOH3ohGZi0;oXnog1?n>i?/2oioO
o0;oULkk1OnKbOL2oio3lP;oV;[`5Oooool00ol0003oooooooooo`03ooooo`05oa0@4?oooooooooo
ooooool@41002oooool00omEEEGoQhN7ooooo`0Kooooo`00:oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo04cooooo00?o0000obh00?l_00001?l_00000ol`003oA`0HodP06002odP0
60?oB@0I0_m:01T00omF02koEP0]oeH0;@04oeH0;@?oE@0/1?mD02X4ojbcgPCo[[OO1?nBJJ08oi9Z
X@CoTf^R0onCK:<5oiA]Y0?oU6jU00CoUG2Voi]fZOnKMZWoVgJY3?nKMjT5oi]gZP03oiYgZonOOJoo
Wgf_00?o00000onOOZl3oimo/0GoWh6b00?oX8>dojjKa?n^Vl@00_n^Vl@5ojjLa@03ojjMa_ni^=So
^KSH00;o^KSH0onh]]L2okoNk`Co_mO[0on/lo<00ol0003oQN[TohGZi004ofoMk@;oS^Ck0on<d?h4
oiG>n`;oVlWg0onF^_44oiRjl1?ooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool00ooMgMgo410@oiRHV00Kooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo04Wooooo00Co0000obh00?l^003o;P000_l_0002odH05`?oA`0H0_m801P4odT06@?oEP0^
1_mF02d3oeD0;003oe@0:_n[/=coZk3L00Ko[;?N00?o[[OOoi9YX?nBJJ001?nBJJ08oi9ZX@CoTf^R
0onCK:<5oiA]Y0;oU6jU00?oVWJYoi]fZOnKMZT00onKMZT<oi]gZ@?oVgNZ00CoWWf^o`000?l0003o
00000_nOOJl4oimn[`CoWgn`0onOPK800on^V/?o[Y_4ojjKa003ojjKa0Co[Yc500?o^k_JokVhf?ni
^=P01?ni^=P00onh]]Oo_mk_okoNk`02okoNk`07okoGjon/lo?o[??cojcclom@b[CoA<K>o`000002
ogW:o`GoPLoo0_n<d?h2oi:gl0GoTkWa1OnF^_44oiRjl1Gooooo00Wo0000ooooooooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410Iooooo`004?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo0ol0000:oooo
o`03o`000?oooooooooo04Kooooo00?o0000obh00?l^00000_l^00000om501OoAP0GodH05`02odH0
5`;oA`0H0om801P00om901WoEP0]oeH0;@03oeH0;PKoEP0]0_mE02`00onY[]_oZk3Loj^`g003oj^`
g0Co[;?N00?o0000oi9YX?nBJJ001_nBJJ07oi9ZX@CoTf^R1?nCK:<4oiA]Y003oiA^YOnJMZWoVWJY
00GoVgJY3?nKMjT01?nKMj[o0000o`000?l00005oimm[`CoWgj_1?nOOk000onOPK;o[Y[3ojjJ``02
ojjJ``Go[Y_400?o[Yc5ok^kf_nk^mX00_nk^mX4okVhf003okkWl_nog^oo_mk_00;o_mk_0_nDlND0
0ol0003oM<?nogC3oP03ogC3oP03o`000?mib_ooNL[o00;oPLoo0on@/Nd4oi:gl0GoTkWa0_nF^_42
oiN^i`CoUkC[5Oooool00ol0003oooooooooo`0_ooooo`002?ooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`Go00001Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo04;ooooo00?o0000obd00?l^00001?l^0002odD05`?oAP0G0om701P00om801SoEP0/oeH0;@03
oeH0;@?oEP0^1_mF02d4ojV^f`GoZk3L00Co[;?No`000?nBJIooTVVO2?nBJJ07oi9ZX@CoTf^R1?nC
K:<3oiA]Y003oiYeZ?nJMZWoVWJY00;oVWJY1?nKMZT;oi]gZ@;o00001?nNOJh4oimm[`GoWgj_0_nO
Ok000on]VL;o[Y[3ojjJ``03ojjJ``Co[Y_400?o_L3Lok^kf_nk^mX01?nk^mX00oni^=So_^ObokkW
lP02okkWlP03okoNkonDlNGoU?7U00CoN;Wk0_md`oh2oi:Rh004oi6[j?l0003oTJ_Xoi6[j0GoT;7]
1?nB]o02oi>il@;oUjSR1OnG[^L4oiNdjaGooooo00?o0000ooooooooool0;_ooool0013ooooo00Go
0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0oooooo`04o`000?l]003o;@00obd000?o;P0000?oA00FodD0
5om501L00om601L2odL06004oeD0:omF02coEP0/oeH0;0?oEP0]0omF02h5oeH0;@03ojR/f_nY[]_o
ZJkK00?oZJkK1?n[/=`00onBJ9ooTVVOoi9YW`02oi9YW`SoTVVP1onBJZ44oi=[XPCoTfbS00CoU6fT
oiYeZ?nJMJSoVWFX1?nJMZT4oi]fZ@SoVgNY0ol00006oiim[PCoWgf_1OnOOZl01?nOOk3o[IW2ojfI
`_n]VL84ojjJ``?o[Y_40onm`=`4ok^kfP;o^?7d0_nnio82ofSI`003ogf[lOnFT/goUY;=00CoU9[G
1OnBX^001?l0003oTJ_Xoi6[j?nAZnP2oi2ak@;oV9_E1?nHX]`5oiNXhPCoUjkW0_nG]>/3oifejAGo
oooo00?o0000ooooooooool0;Oooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0loooo
o`03o`000?l]003o;@0000;o;@0000?o;P00od@05_m401H00_m401H2odD05`?oAP0G0omE02/2oeH0
;0CoEP0]0omF02h2oeH0;@03odX06_m801SoZ:cJ00;oZ:cJ1OnY[]/01?n[/=coTVROoi9XWonBJ9l4
oi9YW`SoTVVP2?nBJZ43oi=[XP;oTfbS0_nIM:P5oiYeZ0?oVWJY1?nKMZT5oi]gZ@?o00002OnNOJh5
oimm[`?oWgj_00?o[9O1ojfI`_n]VL800_n]VL85ojjJ``03ojjKa?nm`=co_L3L00?o_L3L00Go^k_J
okSam?nhlOCo^?7do`000002ohFMhP03oiV;a?nFT/goUY;=00?oUY;=1?nDV]L4oi:Rh004oi6[j?l0
003oVIG>oiVEcPGoV9_E1?nHX]`4oiNXhP;oUjkW0_nM[n@6oifejACooooo00?o0000ooooooooool0
;Oooool0013ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo
0_l0000?ooooo`;o0000>_ooool00ol[003o;@00obd00003obd000GoA00F0om501L00om601OoD`0X
oeD0:`02oeD0:`?oEP0/0omF02d4oeH0;P03odX06_nWZMWoYjWI00GoZ:cJ0onY[]/6oi9XW`?oTVVO
2?nBJJ08oi9ZX@;oTf^R00?oV7>WoiUdZ?nIM:P00_nIM:P5oiYeZ0?oVWJY1OnKMZT01OnKMjWo0000
o`000?l0003oVgNY00_oWWf^1OnOOJl00onOOZoo[9O1ojbG`@02ojbG`@?o[IW21?n^V/<2okk6h@Co
_L3L0onVm^`00onhlOCoVhJloi^6_004oiV;a0CoUY;=1OnDV]L2oi:Rh004oi^@aonIULkoVIG>o`00
00;oVIG>1?nHVmD5oiRRg0;oUjSR00?oWZWNoif_i?nM[n@00onM[n@4oifej@03ojBij?oooooooooo
01?ooooo00?o0000ooooooooool0;?ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000000Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0eoooo
o`?o:`000ol]00000om301GoA00Fod@05P03od@05P;oA@0G00CoDP0Voe<0:?mC02SoD`0X0omE02/3
oeH0;0?oEP0]00?oEP0^ojFXf?nUZ=P01OnWZMT5ojR/fP03ojV^fonBJ9ooTVRO00GoTVRO0onBJIl8
oi9YX0SoTVZQ00?oTf^RoiQcYonHLjL01OnIM:P4oiYeZ0?oVWJY0onKMZT3o`0000;oVgNY00?oWWj_
oiim[_nNOJh02onNOJh3oimm[`03ojZE`On/Ul7o[9O100?o[9O11?n]VL800on^V/?o_/KQokk6h@03
okk6h@03okg0g?nVm^coY_K/00;oY_K/1?nKQ[`4oiV;a0GoUY;=0_nDV]L2oib<`PCoVi370_nIULh0
0ol0003oVIG>oiRKe@04oiRKe@;oV:;L0_nOXmP4oijYgPGoWJoT00?oWKGYojBij?nT^NP00_nT^NPC
ooooo`;o0000;_ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003o
oooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0booooo`05obT00?l[003o
:`00ob/00?l]00001?m301D5od@05P?oDP0V0_mC02P3oeD0:`?oEP0/0_mF02d00onTYmSoYJSHojFX
f003ojFXf0GoYjWI0_nX[=X:oi9XW`CoTVVO2?nBJJ06oi9ZX@03oiQbYonHLjOoV7>W00;oV7>W1?nI
M:P4oiYeZ0?oVWJY0ol00002oi]fZ@04oi]gZOnNOZooWWj_oiin[`goWWf^00?oWgf_ojZE`OnZUL40
0_nZUL44ojbG`@?o[IW20_o0c^D4okk6h@?oNnC800CoY_K/oib2]_nLP[KoW8:f1?nKQ[`4oiV;a0;o
UY;=0_nORKd4oib<`PCoVi370_nIULh00ol0003oVIG>oiVEcP02oiRKe@;oXIkB1OnOXmP4oijYgP;o
WJoT0onU]><4ojBij1Gooooo00?o0000ooooooooool0:oooool002Wooooo0_l0000Dooooo`03o`00
0?oooooooooo02kooooo00Co9`00obT00?lY003o:@000_l[0005od<05@CoA00F00CoD00Roe809_mB
02KoDP0V0omC02P3oeD0:`;oEP0/00?oC@0JojBWf?nTYmP00_nTYmP4ojFXf0CoYjWI0_nBJJ0;oi9X
W`CoTVVO2?nBJJ04oi9ZX@?oV7:W1?nHLjL4oiUdZ0CoVWFX0ol000001?nJMZWoVgJYoi]fZOnKMZT6
oiin[`_oWWf^00?oZ9?0ojZE`OnZUL400onZUL45ojbG`@03ojfI`_o0c^Go`<kU00;o`<kU00Go_/KQ
og_Tb?mki<SoNnC8oiio/@05oib2]PCoVhJl0onIRl@00onQR;WoWhVmoin9_@03oin9_@CoW8c21?nK
T<L2oiVEcP03o`000?nRV/goXIkB00CoXIkB1?nOXmP2oijYgP;oY[3O1_nU]><2ojBij0;oZ[gX5Ooo
ool00ol0003oooooooooo`0Zooooo`00:Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo02cooooo0_lW0002obT00003ob/00?m201Co@`0E00Co@`0E0_m401H01?m>01koD00Roe008_m@
0283oe809P?oD`0X0omE02/00om=01[oXjOIojBWf004ojBWf0GoYJSH00?oYjWIoi9YX?nBJJ000_nB
JJ0;oi9XW`CoTVVO2?nBJJ02oi9ZX@03oiMbYonHLZOoV7:W00?oV7:W0onHLjL4oiUdZ0;oVWFX0_l0
00001OnJMJSoVWJYoiYfZOnJMZWoVgJY00SoWWj_2OnNOJh4ojRC`0CoZYG11?n/Ul42ol3Gj`?o`<kU
00?o0000oimm[_nNOk401?nNOk44oib2]PCoVhJl00?oVH_4oj68^OnQR;T00_nQR;T4oin9_@CoW8c2
0onKT<L01_nTV<SoXY[=oj:JcOnRV/go0000oj:Jc@GoXIkB0_nOXmP00onX[M_oY[3OojJ`g`03ojJ`
g`CoYKCS00?oZk_UojZmj?nZ_NP00onZ_NPDooooo`03o`000?oooooooooo02[ooooo000Yooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0:?ooool2ob<000;o9`0000?o:@00od804om2
01@00_m201@5od<05@?oCP0N0_m@0283oe809P?oD`0X00?oE@0[oj:WfOnRYmT01?nSYmT5ojBWf0;o
YJSH1onBJJ0;oi9XW`CoTVVO1onBJJ001?nFLJKoUg:WoiMbYonGLZL5oiQbY`?oV7>W0onIM:P3o`00
00?oVWFX0_nJMZT00onOO[3oWWj_oiin[`07oiin[`OoWWf^00?oYi:oojRC`?nXTl000onXTl05ojZE
`@03ojbG`Oo0en_o`=O[00?o`=O[00?o`<kUoimm[_nOOJh00_nOOJh4oiio/@GoW8:f0_nKQ[`00onT
RKOoXHRioj68^@03oj68^@CoWhVm1?nLS<800onKT<OoY9S8ojBHb002ojBHb0?oXY[=00?o0000oj6N
d_nQW]800_nQW]800onZZmSoZ:gKojR]f`02ojR]f`GoY[3O00?oYKCSoj^kiOn[^nD00_n[^nD3ojZm
j0;o[/;Y5?ooool00ol0003oooooooooo`0Yooooo`00:Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo02Cooooo00Co7000ob<00?lS003o8`000_lW0003od804`;o@P0D1?m301D01?m<
01WoCP0Nodh07_m>01h2oe008PCoDP0V00?oD`0Xoj:Wf_nRYmT01?nRYmT4oj>Wf@?oY:OH0onBJJ47
oi9YX0coTVRO0onBJIl5oi9YX0?oUW6V1?nGLZL4oiQbY`?oV7>W0ol00002oiUdZ0?oVWFX00CoWgn`
oimn/?nOO[3oWgj`2OnNOZl6oiim[P?oYi:o1?nXTl04ojZE`@;o_n;a1?o0en/2oj1m[0CoWgf^1?nN
Ok45oib2]P04oi^6_?nTRKOoY8VgojB9]`CoXHRi1OnORKd2oib<`P03ojJFaOnTV<SoY9S800?oY9S8
0onRV/d00ol0003oXY[=oj6NdP04ojZ[f0CoZ:gK0_nV/=l2ojbih`GoZk_U00?oZ[gXojk2jOn^`^T0
0on^`^TDooooo`03o`000?oooooooooo02Sooooo000Yooooo`?o00005oooool00ol0003ooooooooo
o`0Rooooo`;o70000_lS00000olW003o@@0Aod804`02od804`;o@P0D0_m301D01?m901CoC00Iod`0
6Om<01T3odh07P;oD00R00?oDP0Vod/04Om;01401?nRYmX4oj:Wf@GoXjOI00?oY:OHoi9ZXOnBJJ40
0_nBJJ48oi9YX0_oTVRO0onBJIl2oi9YX0;oUW2V1OnFLJH3oiMbY`CoV7:W0ol000000onHLjOoVGBX
oiUdZ002oiUdZ004oiYeZ?nOOk3oWgn`oimo/0CoWgj`2OnNOZl3oiim[P03ojJA_onWT[ooYi:o00;o
Yi:o1OnXTl02ojZE`@Co_n;a00?o`=O[oj1m[?nPOJ`00onPOJ`3oimm[PGoWWna0onLP[H00onWR[Ko
Y8VgojB9]`02ojB9]`GoXHRi0onORKd00onXU/;oYYK5ojJFa@02ojJFa@GoY9S80_nRV/d00on/ZmKo
0000ojZ[f004ojZ[f0;oZ:gK0_n]^>45ojbih`;oZk_U0on_`nP4ojk2j@03ojk4j_oooooooooo017o
oooo0_l0000Zooooo`00:Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01oooooo
00Go5000oa`00?lL003o8`00od003P03od404@;o@P0C0om201@3odT050;oC00I0om>01h01?m@02;o
B@0=od/04Om;0142oj6Xg0CoXZOJ1OnRYmT2oj>Wf@CoTVZQ0onBJJ48oi9YX0_oTVRO0_nBJIl00onE
L:KoUW2VoiI`YP02oiI`YPGoUW6V0onGLZL01?nHLZOo0000o`000?l00004oiQcY`?oVGBX00?oWWn`
oimo/?nOOk000onOOk03oimn/0WoWWj_00?oWWf^ojJA_onVTKl00_nVTKl3ojNB_`GoZ9?000?oZYG1
okoRlOnoh_400_noh_42oj5lZ`GoX7f/0onOOJh5oiio/@03oib2]_nWR[KoYhZf00;oYhZf0onTRKL5
oj68^@03oin9_OnXU/;oZ9K200;oZ9K20onVU/D4ojBHb003ojn/eOn/ZmKo[:_F00;o[:_F00Go0000
ojZ[f?nZZmSoZZ_Hojnhh005ojfhh@?o[;WS0_n`a>T5ojo3j003ojk2jOn^a>[o[/CZ00;o[/CZ5?oo
ool00ol0003oooooooooo`0Wooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`Go00001Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01gooooo00Co
5000oa`00?lL003o70000_m000h2od404@?o@P0C00?o@P0DodD03_m901@00_m901@2od`06@CoCP0N
0_nPZ]h5oj6Xg0CoXZOJ0_nRYmT4oi9[XPCoTVZQ1?nBJJ47oi9YX0[oTVRO00CoU6nVoiE`Y_nEL:Ko
UG2V1OnFL:H4oiIaYP04oiMbYol0003o0000o`0000CoV7:W0onHLjL01?nIM:SoWWn`oiio/?nNOk05
oimo/0?oWgj`2?nNOZl00onVTL3oYY6oojJA_`03ojJA_`CoYi:o0onXTl03ok[/m@03okoRlOnQO:_o
XGb[00?oXGb[1?nPOJ`4oimm[P?oWWna00?oZHbgojN:]_nWR[H00onWR[H4ojB9]`?oXHRi00?oZiK2
ojRF`_nXU/800onXU/84ojJFa@03ojBHb?n_[=Go[jcE00;o[jcE0on/ZmH00ol0003o[:_FojZ[f003
ojnhh0Go[KSQ00?o[;WSok34jOn`a>T00_n`a>T2ojo3j0;o[lG[1On^a>XEooooo`03o`000?oooooo
oooo02Kooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06_oo
ool00ol8003o5000oa`00002och02@;o@00>0_m101400om201?o@P07od801`03odD03P;oB@0D0om<
01T00om>01koWjcPoin/h004oj2ZgPGoXJSL0_nRYmX4oi=/X`?oTV^R1?nBJZ44oi9YX@OoTVVP2?nB
J9l3oiA_YPCoUG2V1?nFL:H2oiIaYP?o00000_nGLZL5oiQbY`;oV7>W00?oWWnaoiio/?nNOk000onN
Ok04oimo/0?oWgj`1_nNOZl4ojJA`0CoYY6o1?nWT[l00onXTl3o^^ceok[/m@02ok[/m@03oiYeZ?nQ
O:_oXGb[00CoXGb[1?nPOJ`4oimm[P03oiio/OnYS;OoZHbg00;oZHbg1?nWR[H4ojB9]`03oj68^On[
U/;oZiK200;oZiK21?nXU/83ojJFa@03ok:_eOn_[=Go[jcE00?o[jcE1?n/ZmH00ol0003o[kSPojnh
h003ojnhh0;o[KSQ0_n`aNT4ok34j@03ojo7k?n_aN_o[lG[00?o[lG[0_n^a>X3ojg4jaCooooo00?o
0000ooooooooool09_ooool000Kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP06ooooo`;o00007Oooool00ol0003oooooooooo`0Gooooo`;o200000?o
>`03och02Oln00T00_ln00T00om000ko@@0Aoch00004od801`;oA@0>0om901@2oij^h`GoWjcP1?nP
Z]h2oj6Xg003oi=^YOnCKJCoTffT00;oTffT0onCK:<4oi9[XP?oTVZQ1?nBJJ47oi9YX0KoTVRO1_nD
KjH3oiE`YPCoUW2V0_l00002oiIaYPCoUg:W1?nHLZL00onHLjOoWWnaoiio/@05oiio/0CoWgn`1?nO
O[03oiin[`03ojJB`OnVTL3oYY7000?oYY701OnVTKl2ojNB_`?o[_?d00?o^^ceoi]eYonJMJP01onQ
O:/5oj1m[0;oWgf^00?o[8nhojV<]onYS;L00onYS;L5ojN:]P;oY8Vg00?o[IW2oj^F`_n[U/800on[
U/85ojRF`P04ojJFaOnb[mGo/ZoEok:_e@Go[jcE00Go[:_Fok6jh?na^^3o/K[Po`000003ojnhh0;o
/LS[1?n`aNT00on`a>Wo[lO/ojo7k002ojo7k0?o[lG[0_n]a^`5ojg4jaCooooo00?o0000oooooooo
ool09Oooool000kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Go
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Dooooo`?o20000_lk00<3och02@;o
@00>0_ln0003od801`;oA@0>00?oB@0Doif`iOnN[^<01?nN[^<5oin/h0;oX:[N1?nCKZD4oi=]Y0?o
TfbS1?nBJj83oi9ZX@CoTVVQ1onBJJ02oi9XW`[oU6nV0onEL:H01?nFL:Ko0000o`000?l00005oiIa
YP?oUg:W0_nHLZL6oiio/@CoWWn`1OnOOk03oimn/003oiin[onVT/7oYY;100;oYY;11?nVTL05ojJA
_`04ojNB_on^loCo[_?dojkcm0;oVgFW00?oXWf[oj5lZonQO:/01_nQO:/5oj1m[004oimm[_n/SkSo
[8nhojb?^0CoZHbg1OnWR[H01?nTRKOo[IW2ojfI`_n]VL84oj^F`PCoZ9K200?o]KCHok:_eOnb[mD0
0onb[mD2ojn/e@;o/kkR1Ona^^000ol0003o/LS[ok78j`03ok78j`;o/<GY0_n_b^d5ojo7k003ojo5
jon]a^co[LK/00;o[LK/0_n]a>/2ojc3jaGooooo00?o0000ooooooooool09?ooool000kooooo00Go
0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0
7_ooool2o`00017ooooo0_l000000ol8003o=P00ocH00002oc/00`?o?P0900Co@00>ocX00?ln003o
?P000om200L2oi^cj0CoWK3U1OnN[^<2oin/h003oiEaZ?nDKjKoU6nV00;oU6nV0onCKZD4oi=]Y0?o
TfbS1?nBJj84oi9ZX@?oTVVQ1_nBJJ000onCKjKoU6nVoiA_YP0:oiA_YP04oiE`Y_l0003o0000o`00
00?oUW2V1OnFLJH2oiMbY`03oieo/OnNOk7oWWna00KoWWna1?nNOk05oimo/0;oWgj`00?oYiC2ojJB
`OnVT/400onVT/45ojJA`0;oYY6o0onGlNT2oiaeYP04oi]eYonROJ_oXWf[oj9mZ`SoXGb[1?nPOJ`0
0on^Tk_o[8nhojb?^002ojb?^0GoZHbg0onWR[H00on_W<Co[IW2ojfI`P02ojfI`PGoZiK200?oZ9K2
okFdf?ne]=P00_ne]=P3ok:_e@03okC3iOnc_^;o/kkR00?o/kkR0_na^^02ok;<k@03o`000?nab>_o
/LS[00;o/LS[00?o[lg`ojo:kOn_b^d00on_b^d2ojo7k0;o[LS]1?n]a^`00on[aNco[<?[ojc3j`03
ojc3ja?ooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Go
c<c<ob4Q8Ol0003o8B4Qolc<c009ooooo`003_ooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool2o`00027ooooo00?o0000ooooooooool03?ooool2o`000003obl0
0?lf003o=P0000;o=P0000Co>`03och02Oln00Wo=@000olj00000oln003o@P07oiZej`05oi^cj0Co
WK3U0_nN[^<00onFLj[oUG6XoiEaZ002oiEaZ0CoU6nV1?nCKZD3oi=]Y0?oTfbS1?nBJj84oi9ZX@?o
TVVQ0_nBJJ05oi=_YP[oU6nV0ol00002oiE`YPGoUW2V1?nFLJH00onGLZOoWGnaoieo/@08oiio/@Go
WWn`0onOOk000onWUlGoYiC2ojND`P02ojND`PCoYY;11?nVTL03ogCRcP05oiOajOnLMJGoW7FVoiae
Y_nROZ`01OnROJ/8oj5lZ`;oX7f/0on^Tk/3ojb?^0GoZHbg00?oYhZfojnLa?n_W<@00_n_W<@3ojfI
`PCoZiK200?o]k[LokFdf?ne]=P00one]=P00onb[mGo]<?UokC3i@02okC3i@?o/kkR0_nadO04ok;<
k@03o`000?nab>_o[lg`00?o[lg`0_n_b^d3ojc:k`Co[LS]00?o[LK/oj_5k?n[aN`00_n[aN`3ojc3
j`;oZ/;[5?ooool00ol0003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@09ooooo`003_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`;o00008oooool00ol0003ooooo
ooooo`09ooooo`?o00000_l_0003ocH000;o>`030ole00000olj003oV;S^oiRhkP04oiZej`GoVk?X
0_nM/>D00onGMZcoUW>ZoiIcZP02oiIcZP?oUG6X1?nDKjH4oi=^Y@?oTffT1?nCK:<3oi9[XPCoTVZQ
0_nBJJ400onCKjOoTfnVoi=_YP06oi=_YPKoU6nV0ol00002oiA_YPCoUG2V1?nFL:H3oiIaYP03oieo
/_nMOk7oWGna00;oWGna1onNOk45oiio/003oimo/?nWUlGoYiO500;oYiO50onWU<85ojJB`@04ojJA
`?mdh/koM>;>ogCRcPCoW7FU00?oW7FVoj9n[?nROZ`01OnROJ/8oj5lZ`03oj1m[?n^Tk_o[Y>k00;o
[Y>k1?n/SkP3ojV<]`03ok6Qb?n_W<Co[ic400?o[ic41?n]VL800on[U/;o]k[LokNjg002okNjg0?o
]KCH0_ndb^X5okC3i@03ok>nh_nadO3o/M7`00;o/M7`0_nbc>d2ojg@lP04o`000?n_cO3o[lg`ojo=
l0;oZlca1On/b^l2ojg8k@;oZlK^1On[aN`00on/`n_oZ/;[oj[2j`02oj[2jaCooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00
0009ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c004ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool2o`000003obD0
0?l_003o;`0000?o=P0000Co>`03oc000?le003o=@000_nF^_04oiRhkPCoV[G[0_nK/nP2oiQi[PCo
UgJ/0onFLjX4oiEaZ0?oU6nV1?nCKZD4oi=]Y0?oTfbS0onBJj82oi9ZX@;oTVnW0onCKjL8oi=_YP?o
U6nV0ol00006oiA_YP?oUG2V1?nFL:H01?nFLJKoWGnboieo/_nMOk84oieo/@SoWWna0onNOk000onX
V/SoYiO5ojNGa@03ojNGa@?oYiC21?nVT/400ol0003oW7FUoiaeY@05oiaeY@03oj9n[OnROZcoXWj/
00;oXWj/1?nROJ/7oj5lZ`03ok2I_on^Tk_o[Y>k00?o[Y>k1?n/SkP00onYS;Oo/J78ok6Qb002ok6Q
b0Co[ic40on]VL82okW3hPGo]k[L00?o]KCHokC:j_ndb^X00_ndb^X2okC3i@;o[mGd1?nadO02oj_C
m@Co[M3b00?o0000oj_<lOn[c?400on[c?42ojc:k`;oZ/S_1On[a^h2oj_5k0;oZ/?/1?nZ`^/00onY
`N_oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;
ooooo`05oc8b<_nHV9SooooooiRHV?lb<S802Oooool002Oooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`04ooooo`04o`000?lG003o9@00obD000;o;`0000?o=P00oi6klonA^o<01?nC
^o84oiJjl0CoV;S^0_nJ]N/2oiYl/@CoV7V^0onGMZ`3oiIcZPCoUG6X0onDKjH4oi=^Y@CoTffT0onC
K:<2oi9[XP03oi9_Z?nBKjOoTVnW00;oTVnW1?nCKjL7oi=_YP?o00002OnDKjH3oiE`YP;oUW2V0_nL
O[84oieo/PCoWGna2?nNOk400onNOk3oZ9[8ojRJb002ojRJb0CoYiO51?nWU<800onVT/7oWGFVoiee
YP02oieeYPCoW7FU0onROZd4oj9n[0CoXWf[1_nQO:/3ok2I_`Go[Y>k0_n/SkP00oncZ<go/J78ok6Q
b003ok6Qb0Go[ic400?o[IW2okW3h_ni`n800_ni`n82okNjg0;o/m;`1?ndb^X2oj_In0Co[mGd00?o
/M7`oj_CmOn[doD00on[doD2ojg@lP03oj[=l_l0003oZlca00?oZlca00?oZLW`oj[8konZb>l00onZ
b>l2oj_6kP;oZLC]1OnZ`n`00onZ`^_oZL7[ojW1j`02ojW1jaCooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c009ooooo`00
9oooool2o`0002Kooooo00?o0000ooooooooool00_ooool2oaL000;o9@000on?^o@4oi6kl`CoTk_b
0_nF^_02ojbJa@;oZIC100?oVgndoiYl/OnJO;400_nJO;44oiQi[P?oUgJ/0onFLjX4oiEaZ0CoU6nV
0onCKZD4oi=]Y0;oTfbS1?nBKjP5oi9_Y`?oTfnW1OnCKjH2o`0000coU6nV0_nEL:H00onKO[;oW7jb
oian/P02oian/PCoWGnb1?nMOk47oiio/@03ojVOc?nXV/SoZ9[800?oZ9[81OnWUlD2ojND`P03oiae
Y_nMMJKoWGFV00?oWGFV0_nLMJD00onRP:koXWj]oj9n[@03oj9n[@?oXWj/1OnROJ/3oj5lZ`03ok:N
a?n`VKoo/9Vo00;o/9Vo1On^Tk/01?n/SkSo/jS=ok>XcOncZ<d5ok6Qb0;o[ic40_nicNT4okW3hP;o
/=[f1?ncd_000ondb^[oZmWhoj_In003oj_In0;o[mGd0onXe_L2oj_Cm@;oZ<kd1?nZcO800ol0003o
ZlcaojW9l003ojW9l0;oZ/S_0onYa>h4ojW4k@;oZ/?/0onX`^`4ojW1jaGooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4009
ooooo`009oooool00ol0003oooooooooo`0Vooooo`04o`000?ooooooS;Wdohbim0CoSK[d1?n?^o@4
oi6kl`;oTk_b0_n^WlP2ojbJa@04oij4]onKOkCoVgndoi]o]0CoVWba1?nHNJh3oiMf[0?oUW>Z1?nE
LJP4oiA_YP?oTfjU0_nCKJ@2oi5_Z@OoTVnX1?nBKjL3oi=_Y`;oTfnV0ol00002oi=_YP_oU6nV00Co
VWfboi]n/_nKO[;oVgjb1OnLO[84oieo/PCoWGna0onNOk400on[Y=3oZIo<ojVOc002ojVOc0CoZ9[8
1?nWUlD00onLMZOoW7FVoiaeYP02oiaeYPCoWGFV00?oW7FUoj:0[_nRP:h01OnROZd3oj9n[0GoXWf[
00?oXGb[ok:Na?nbW/@00_nbW/@3ok2I_`Co[Y>k00?o];3Dok>XcOncZ<d00_ncZ<d4ok6Qb0;o]]Oa
1?nicNT00oni`n;o/=[fok3JmP03ok3JmP;o/m;`0onVg?X2oj_In0;oYMOi1?nXe_L2ojK>m@CoZ<kd
0_nZcO82ojS9l@04o`000?nYbO3oZLW`ojW9l0;oZ<G^1OnYa>h2ojW4k@OoZ<;/0_nY`N/2ojS1ja;o
oooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o
000000Wooooo000Wooooo`03o`000?oooooooooo027ooooo0_n8]O<4ohZgl`CoS;Wd1?n=^_@2ohnk
m0;o=[c<0_n`Y</4ojjOb004oj68^_nNQ;OoWXBgoij4]`CoVgnd1?nJO;43oiQi[P?oUgJ/1?nFLjX3
oiEaZ0CoU6nV0_nCKZD5oi5_Z@OoTVnX1?nBKjL2oi=_Y`?o00001_nCKjH8oiA_YP?oVWfb1?nKO[84
oian/PCoWGnb1?nMOk400onNOk7oZjC@oj^Td002oj^Td0?oZIo<1OnXV/P01?nWUlGoW7JWoiafYonL
MZL4oiaeYP?oWGFV00?oXX6`oj:0[_nRP:h00_nRP:h4oj9n[@CoXWj/0onROJ/00oncY/_o/Yk4ok:N
a003ok:Na0Co/9Vo00?o[Y>kokB`e?nd/=@00_nd/=@4ok>Xc@03ok6Qb?nfeo7o]]Oa00?o]]Oa0_ni
cNT3ojWQnP;o/=[f0_nPg_`4ojKLnP;oXMSk1?nUeoT00onXe_OoY/keojK>m@03ojK>m@;oZ<kd0_nW
bO83ojS9l@03o`000?nXbO7oZLW`00CoZ<G^0_nYa>h2ojS2k@OoZ<;/0_nX`N`5ojS1jaCooooo00Wo
0000ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413o
ZJVY00Wooooo000Vooooo`?o00006oooool2ohFalPCoQk?b1?n8]O<4ohZgl`;oS;Wd0om7a]l00one
[M7o/jW>ok>YcP02ok>YcPCo/:C;00Co[Yo8oj68^_nQR;[oXHRj1?nNQ;L3oi]o]0CoVWba1?nHNJh3
oiMf[0?oUW>Z0_nELJP00on@Kj[oT6nYoi1_Z@02oi1_Z@OoTFnY1onBKjP3oi9_Y`?o000000?oTfnW
oi=_Y_nCKjH01_nCKjH6oiA_YP03oiUm/_nJOK;oVWfb00?oVWfb0onKO[84oian/PCoWGnb0onMOk40
0on[ZMCoZjC@oj^Td003oj^Td0CoZIo<0_nXV/P7oiafY`?oW7FV00CoWGFVoj:1/?nRPK3oXX6`1?nR
P:h4oj9n[@CoXWj/00?oXWf[ok>VboncY//00_ncY//4ok:Na0?o/9Vo00?o][_MokB`e?nd/=@00ond
/=@3ok>Xc@;o[n3h1?nfeo400onNi?coZN7jojWQnP02ojWQnP;oV]km1?nPg_`00onVg?[oXMSkoj7H
n`03oj7Hn`;oYMOi0onTc_H2ojK>m@;oY/Wb1OnWbO82ojS9l@03ojO5kol0003oZ<G^00?oZ<G^00?o
Yl;]ojS2kOnX`^d00onX`^d2ojS2k0OoZ<7/0_nX`N/2ojS0jaGooooo00?o0000ooooooooool07_oo
ool002Kooooo00?o0000ooooooooool03oooool00oml[O?oOZkbogj^lP02ogj^lPCoPJob0on3/?83
ohFalPCoQk?b1?n8]O<2ohZgl`;oCLWW00?o`M3Uol7?iOne[M400one[M44ok>YcP;o/:C;00?oXhfm
oj68^_nQR;X00_nQR;X4oij4]`?oVgnd1?nJO;44oiQi[P?oUgJ/0_nFLjX4oi1_ZPCoT6nY1onAKjT7
oi9_Z0?o000000?oTVnWoi=_YonCKjL00_nCKjL7oi=_YP;oU6nV0_nHO;83oiUm/PGoVWfb0onKO[85
oian/P?oWGnb00?oWGnaoj^Ye?n[ZM@00_n[ZM@4oj^Td0?oZIo<0_nKMZP8oiafY`;oW7FV00?oXX:b
oj:1/?nRPK000onRPK03oj:0[PGoXWj]0_nROZ`00ond[];o/jK;ok>Vb`03ok>Vb`Go/Yk400Co/9Vo
okJkgOnf^mgo][_M1Ond/=@00oncZ<go[n3hojoPn002ojoPn003okKGlOnNi?coW^Cl00;oW^Cl00?o
ZN7joi[NoOnJg_d00onJg_d2oj3No0?oW]Sl0_nQf?/3oj?=mP;oY<kf0onUb?84ojK9lP;oYlWb0onW
a>l3ojO5k`03o`000?nXaNkoYl;]00?oYl;]0onX`^d8ojS1k0OoZ<3[5?ooool00ol0003ooooooooo
o`0Nooooo`006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooom/ZoH00_m/
ZoH3ofn/mP?oLjce0omf[O@3ogV]m0?oO:gc1?mn[_84oh6_lP?oPk3b0on5/O82ohNclPCoE/[b0_mB
b^d3ol7@i@03okRadone[M7o]JgA00?o]JgA0oncZLh00onWT/3oXhfmoj>=_@02oj>=_@CoXHRj0onN
Q;L4oi]o]0?oVWba0_nHNJh2oi1`Z`?oT72Z1on@KjX4oi1_Z@OoTFnY0onBKjP3o`0000GoTVnW0onC
KjL6oi=_YP03oiMk/_nHO;;oV7bb00;oV7bb1?nIOK84oiYm/PCoVgjb1?nLO[82oieo/P;oZjkI1?n[
ZM@5oj^Td004ojVOc?nKMZSoVgJXoi]fZ0SoW7JW00?oW7FVoj:2/_nRP[801OnRPK03oj:0[PGoXWj]
00CoXWj/okB^d_nd[];o]:kB1?ncY//4ok:Na003okG6ionf^mgo][_M00?o][_M0_nd/=@3ojCVn`;o
[n3h1?nCiO`2oikTo0?oU]gn0_nJg_d3oicGo0;oW]Sl0onRc?H3oj?=mP;oY<Ob1OnUb?82ojK9lP;o
Y/C_1OnWa>l2ojO5k`03ojO2kOl0003oYl;]00CoYl;]00?oZ<;]ojS1k?nX`N`01?nX`N`2ojO0j`Oo
Z<3[0_nW`>/Dooooo`03o`000?oooooooooo01gooooo000Kooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01_ooool00ol0003oooooooooo`03ofb[mP?oKjcf0omc[?D3ogJ]m0?oNJgd0oml[O<4ogj^lP;o
PJob0omMaO/4oe_7n@;oFLWf1?nmj_<3ol;@i@04ol7@iOnh/M?o^;7CokRad`Go]JgA00Co/jW>ojNB
`?nWT/3oYi;00onSSKd4oj68^PCoWXBg0onKOk@2oiYl/@03oi5aZon@L:_oT72[00;oT72[0on@L:X7
oi1_ZPCoT6nY1onAKjT3o`0000CoTVnX1?nBKjL3oi=_Y`;oTfnV0_nFN[83oiMk/PGoV7bb0onIOK84
oiYm/PCoVgjb0_nLO[82oj^bg@GoZjkI1?n[ZM@2oj^Td0;oVWFX1OnKMZP6oiafY`03oj:4/onRP[;o
XX:b00;oXX:b1?nRPK04oj:0[P?oXWj]00?o]KOJokB^d_nd[]800_nd[]85ok>Vb`03ok:Na?nea^Oo
]LKW00;o]LKW0onf^md3oiKXn`;oY>Kk0on7i?T2oi?Uo0?oTmcn0_nFgOh4oi_Fo0;oW=Ol0_nRboD5
oj;<mP03oj?=m_nTao;oY<Ob00;oY<Ob0_nUb?82ojK4kPGoY/C_0_nWa>l5ojO2k@04o`000?nW`^go
Yl;]ojO2k@;oYl7/1_nX`N`4ojO0j`;oZ<3[1onW`>/Cooooo`;o00007_ooool001_ooooo00Go410@
oooooooooooooooooa0@4006ooooo`;o00000_ooool3of^ZmP?oJJki1?mW/_/3ofFgo0CoHk[m0omQ
__d3oeo2o@;oGLGk0olb^M42oic`m0?o_NGb00?o_N[col;@iOo2d>D00_o2d>D00onj]=Co^;7CokRa
d`02okRad`Co]JgA00?oZYO3ojNB`?nWT/000_nWT/03oj>=_@CoXHRj1?nNQ;L2oi]o]004oi9c[?nA
LJ_oTG6[oi5aZ`CoT72[0on@L:X7oi1_ZPCoT6nY1?nAKjT3o`0000OoTVnX1?nBKjL2oi=_Y`03oiEj
/_nFN[;oUWZb00;oUWZb1?nGNk84oiQl/P?oVGfb1OnJOK82oi]n/P03ojZdhOn[/]goZk;M00?oZk;M
1On[[]T2oj^Ye0;oVGFY0onJMJP5oi]fZ0CoW7JW0onRQ;<4oj:2/PCoXX6`1?nRP:h00onROZgo]KOJ
okFgfP02okFgfPCo]:kB0_ncY//3ok;Bl@Co]LKW00Co][_MoiKXnonFj?_oU^Sk0omnhOH2ohOTn@Co
T]_n0_nCg?h3oi_Dn`;oVmKl0_nRb_@5oj;;m@;oX/cf0onTa_42ojC7lP?oY/?^1?nVa>h2ojK4k`Wo
Yl;]00?oYl7/o`000?nW`N`01?nW`N`2ojS1k0;oYl3/3_nW`>/Booooo`03o`000?oooooo000001ko
oooo000Kooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`?o
Jj[f0omY[_T4ofNbn`?oIKOl0_mS^_d3oeW5n@;oCLG`0om@c><2ofSKhP;oW?3d1?nmiO84ol7?i@04
ol;@iOnj]=Co^[CDokZde0Co^;7C00?o]JgAojZG`onZUl<00_nZUl<3ojNB`0CoXhfm0_nQR;X00onF
N:ooU7F]oiAe[@02oiAe[@?oTW>/1?nALJ/3oi1`Z`?oT72Z1on@KjX4oi1_Z@;oTFnY0_l00003oi5_
Z@OoTVnX0_nBKjL2oiAi/P?oUGZb1?nFN[84oiMk/PCoV7bb1?nIOK84oiYm/P04oi]n/_nZ]>7oZ[CQ
ojZdh@GoZk;M0_n[[]T2oiQdZ@CoVGFY1?nJMJP4oi]fZ0;oW7JW00?oXHFfoj:4/onRQ;<00onRQ;<3
oj:2/PGoXX6`0_nRP:h00ond`>;o]KOJokFgfP03okFgfP?o]:kB0_n/gOP5ok;Bl@;o]LKW00?oQnGg
ogWOmOmigoD00_migoD2ogkQmP?oTmWn0_nBfoh3oicBn`;oVmCk0onSb?<4oj;:m0;oX/_e0onTaO43
ojC6l@;oY/;^1OnV`nh2ojK4kP;oYl7]1_nW`^d6ojO1k003o`000?nW`NcoYl7/00OoYl3/3_nW`>/D
ooooo`03o`000?oooooooooo01_ooooo000Kooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`03ooooo`CoMjof0omb]o/4of^mo@?oHl;m0_mIaOT3ofCBm@?oOn;f0_nVjoX4
okgOl@03okgUl_o1cnGo`LoU00;o`LoU00?o^kSFokZde?nj]=@00onj]=@2okRad`03ojfLa_nZUl?o
ZYO300?oZYO31?nWT/02oj>=_@04oiUl/_nFN:ooUWR_oiIh[`CoU7F]1?nBLj`3oi5aZ`CoT72[0on@
L:X6oi1_ZP?oT6nY0ol00005oi5_Z@KoTVnX00?oTgRboiAi/_nDNK800_nDNK84oiEj/P?oUWZb1?nG
Nk85oiQl/P?oVGfb0_nJOK82ojRfh`GoZ[CQ0_n[/]d3oiMcZ@?oV7BY1?nIMJT4oiYeZ0?oVgJX00?o
XHJgoj65]_nQQKH00_nQQKH4oj:4/`CoXX:b1?nRPK001?nRP:ko]<3RokC0h_nd`>85okFgfP03okB^
d_n/gOSo[=gh00;o[=gh0_nbd_42og[RlP?oMmkd0_migoD4oiGHoP;oTmWn0onNd?T2oicBn`;oXlOb
1OnSb?<2oj;:m0;oYLC`1OnTaO400onTa_7oY/;^ojK2kP02ojK2kP;oY/?^0_nW`N`5ojO1k@;oYl;]
2OnW`N`00ol0003oYl3/ojO0k006ojO0k0ooYl3[5Oooool00ol0003oooooooooo`0Jooooo`006ooo
ool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool01Oooool4ogN_mP?oL[Ok
0_m[_Od4ogk:o`;oLm7n0on>g_h3ojcRnP03ojK[n_nmgo7o_Moa00;o_Moa0oo1c^@00oo1cnGo^kSF
ok^heP02ok^heP?o^[CD00?o/:;9ojfLa_n]W<H00_n]W<H4ojZG``CoYi;000?oXhfmoiUl/_nIO;80
1?nFN:l3oiAe[@CoTW>/0onALJ/4oi1`Z`?oT72Z1_n@KjX3o`0000;oT6nY1OnAKjT00onBMk7oTWNb
oi9g/P02oi9g/P?oTgRb1?nDNK84oiEj/PCoUWZb1?nGNk84oiQl/P;oVGfb00?oY[GSojRfhonX]^<0
0onX]^<3ojZdh@;oUW:Y1?nGLjT3oiQdZ@GoVGFY0onJMJP01?nKMZSoXHJgoj66]onQQ[L4oj65]PCo
XXBc1?nRP[82oj:1/0?o/lWZ1?nd`>82okFgfPCoX^Cl0_n/gOP00omag^goN=kfogSNmP02ogSNmP;o
Mmkd0onGe_d2oiGHoP?oWlkh0_nNd?T3ojC6l@CoXlOb0_nSb?<2ojG4k`GoYLC`0_nTaO42ojK2k@Co
Y/;^1_nW`N`2ojO1k@WoYl7/0_nW`>/3ojO0k004o`000?nW`>coYl3/ojO0k1CoYl3[5?ooool00ol0
003oooooooooo`0Jooooo`006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00007oooo
o`;oMjof0_n:]o@5ohG1n`;oO/[o0onGeOd00on>g_ko[>;jojcRnP02ojcRnPCo_=S^00?o_Moaol7>
i?o1c^@00_o1c^@00onm^mSo^kSFok^heP03ok^heP04okZde?n`X/Wo/:;9ok2Rb@?o[Ic61OnZUl<2
ojNB`003oi^0]OnIO;;oVGbb00;oVGbb0onFN:l3oiAe[@CoTW>/0onALJ/4oi1`Z`?oT72Z0on@KjX3
o`000003oi1_Z_n@KjWoT6nY00;oT6nY0_nAKjT01?nAM[7oTWNaoi9g/OnBMk44oi9g/PCoTgRb1?nD
NK83oiEj/PCoUWZb1?nGNk82oiQl/P;oY;;S1?nV]N<5ojRfh`04ojZdhOnFLZWoUW:YoiIbZ@CoUg>Y
1?nHM:T4oiUeZ@;oVWFX00?oX8Nioj66]onQQ[L00_nQQ[L4oj65]PGoXXBc0_nRP[82ok3Al@Go/lWZ
0_nd`>83oiCWnP;oX^Cl0_m[fn/3og_Om`;oN=kf0onJeO`2oiOFo@CoXLgg0_nOc_P2ojG5l0GoY<Ka
0_nSao82ojK3kPCoYLC_0_nUa?07ojK2k@03ojK2k_nW`NcoYl7/00GoYl7/0_nW`>`6ojO1k0OoYl3[
0_nW`>`00onW`>_o0000ojO0j`0FojO0jaCooooo00?o0000ooooooooool06Oooool001_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo00Oooooo1?n:]o@2ohG1n`CoVlWg
0_nGeOd4ojkGmP03ojcRn_nlf>ko_=S^00;o_=S^0_o0c><3ol7>i0?o_K_H0onk^=H00oncYlgo/:;9
ok2Rb@02ok2Rb@Co[Ic60_nZUl<2oij5^0?oVh2e1?nIO;83oiIh[`CoU7F]0onBLj`3oi5aZ`CoT72[
0on@L:X3o`0000?oT6nZ00?oTGF`oi5f/?nAM[000_nAM[03oi5f/@CoTWNa1?nBMk83oi=h/PCoU7Vb
1?nEN[83oiIj/P?oUg^b00?oXZkPojBbhonT/^<00onT/^<4ojJeh`;oZ;KS0onDLJP3oiIbZ@GoUg>Y
0onHM:T2oiUeZ@;oWhNj1?nPQkT4oj66]`CoXHFf1?nRQ;<00onRP[;o/=7aok3Al@02ok3Al@;o/lWZ
0on6i_@2oiCWnP;oJM[Y0omogoT2og_Om`CoW=?k0_nJeO`3oj;;m@;oXLgg0_nUa?05ojG5l0;oY<Ka
0_nV`^h5ojK3kP;oYLC_0_nV`Nd7ojK2k@SoYl7/1?nW`>`2ojO1k0koYl3[00?o0000ojO0jonW`>/0
5?nW`>/Dooooo`03o`000?oooooooooo01Wooooo000Uooooo`03o`000?oooooooooo00Sooooo0_n:
]o@4oifmk`;oVlWg1?n^c?02ojkGmP?o^m7[00?o_=S^ol3<hoo0c><00oo0c><00oo1c^Co_K_Hokfk
f003okfkf004ok^he_ncYlgo/jO=ok>Wc@?o/:;90on]W<H00onRRkcoWXFhoij5^002oij5^0CoVh2e
0onIO;83oiIh[`CoU7F]1?nBLj`3oi5aZ`?oT72[0ol00002oi1_ZP;oT7B`0onAMK04oi5f/0CoTGJa
0onBMk44oi9g/P?oTgRb1?nDNK84oiEj/P?oUWZb00?oUg^boj:^h?nR[^000_nR[^05ojBbh`;oY[GS
0_nCL:P4oiAaZ0?oUW:Y1OnGLjT2oiQdZ@03oij7^_nOQk[oWhNj00;oWhNj1?nPQkT4oj66]`CoXHFf
0_nRQ;<2ojcHm`Co/=7a0omhh^`2ohKVm0;oJM[Z0on3h?/2ogoOn@?oW];j0_nLdo/3oj?9m0?oX/_e
0_nUa>l4ojG4l0;oYLG`0onV`^d4ojK2kP;oY/?^0onW`N`4ojK1k@;oY/;]0_nW`>`7ojO1k0KoYl3/
4OnW`>/00ol0003oYl3[ojO0j`0EojO0ja;ooooo00?o0000ooooool000006_ooool002Gooooo00?o
0000ooooooooool02_ooool3oifmk`;o[L7Y1?n^c?02okW:i`?o^m7[0onobN83ol3<h`;o_[gI1?nm
^mP00onf[M3o/jO=ok>Wc@02ok>Wc@Co/:;900Co[Ic6oj:;_?nRRkcoXX^l0onNQKP4oi^0]@?oVGbb
1?nFN:l3oiAe[@CoTW>/0onALJ/3o`0000?oT7B_1?n@M;04oi5e/0?oTGJ`1?nAM[43oi9g/@CoTWNb
1?nCN;83oiAi/P;oUGZb0_nMXmT5oinYg@CoXZkP0_nT/^<3oi5_Z0?oTg2X1?nDLJP4oiIbZ@CoUg>Y
00CoV7BYoij7^_nNQk[oWXNj0onOQkX4oj27^@CoXHJg0onQQKH2ojOMnPCo[=Sg00Co/=7aogSRk?mh
h^coN>;/0_m[fn/3ohSPo0;oPn3k1?nOd?T2oikBnP;oY<Sc1OnSbO@00onRboGoYLC_ojG4k`02ojG4
k`;oYLC`0_nV`Nd5ojK2k@;oY/;^1onW`N`2ojK1k@KoYl3/0_nW`N`3ojO0j`GoYl3/5?nW`>/00ol0
003oYl3[ojO0j`0EojO0jaCooooo00?o0000ooooooooool05oooool002Gooooo0_l0000<ooooo`03
oifmkon]`NWo[L7Y00;o[L7Y00?o[/c`okW:ionib^L00onib^L00onkdN_o_lWRoko9hP03oko9hP03
ol3<honn_MWo_[gI00;o_[gI00?o_K_HokJ]d?nf[M000_nf[M04ok>Wc@;o/:;900?oYI;1oj:;_?nR
Rk`00_nRRk`4oij5^0?oVh2e1?nIO;83oiIh[`?oU7F]0_nBLj`2oi1e/@03oi1d/?l0003o000000Ko
T7B_1On@M;03oi5e/0CoTGJ`0onAM[43oi9g/@GoTWNb0onCN;82oiAi/P03oi^Me?nMXmWoWJ?I00?o
WJ?I1OnOZMd2oj:^h0?oT6fW0onAKjP3oi=`Z0GoU76X0onFLZT2oiMcZ@;oWHJj1?nNQkX4oin7^PCo
X8Ni0onQQ[L00onQQKKoYmgjojOMnP03ojOMnP;o[=Sg0_m/gN<2ofkMk@?oS>7m0_n8h?`3oj7?n0;o
Wm3i0onTao84ojC8l`;oXlWd0_nV`nh4ojG4k`;oYl7/1?nV`Nd2ojK2k@WoYl7/0_nW`>/7ojO0k0Oo
Yl3[0_nW`>`GojO0j`03o`000?nW`>_oYl3[01GoYl3[4oooool00ol0003oooooooooo`0Gooooo`00
9?ooool00ol0003oooooooooo`0=ooooo`?o[L7Y0onh`n<3okW:i`;o_/OQ1?nobN82okk0f`?o_[gI
00?o^;?DokJ]d?nf[M000onf[M03ok>Wc@03ojVIa_nUT/7oYI;100;oYI;10onRRk`4oij5^0CoVh2e
0onIO;82oiIh[`04oi5h/onAM[;oTGJboi5f/P;oT7Fa0ol00002oi1d/0OoT7B_1?n@M;03oi5e/0Co
TGJ`0onAM[44oi9g/@CoTWNb0_nCN;800onJUm3oVigDoi^Me002oi^Me0CoWJ?I1?nOZMd2ohm/Y`Co
T6fW1?nAKjP3oi=`Z0CoU76X0_nFLZT00onLQK[oWHJjoif6^P02oif6^PCoWXNj1?nOQkX4oj27^@;o
XHJg0onRhO`2ojOMnP;oH]SK0_mbg^l3ohoPo@;oS>7m1?nRc_L2oj7?n0;oYLKa1OnTao82ojC8l`Ko
Y/?^00?oYLC_ojO1k?nW`N`00onW`N`2ojK1k@;oYl3/1_nW`N`7ojO0j`;oYl3/9OnW`>/00ol0003o
Yl3[ojO0j`0DojO0jaCooooo00?o0000ooooooooool05_ooool002Cooooo00?o0000ooooooooool0
3_ooool00on]`NWo^<?SokS3h`03okS3h`03okW:ionnan7o_/OQ00;o_/OQ00?o_lWRokk0fonn`=/0
0onn`=/01?nn_MWo^;?DokRce?nh/m@5okJ]d004ok>WcOnYVLKoZIW6ojVIaP?oYI;11?nRRk`3oij5
^0CoVh2e0_nIO;801?nBNkKoTGRcoi5h/onAN;<2oi5f/P?o00000_n@MK44oi1d/0KoT7B_1?n@M;03
oi5e/0CoTGJ`1?nAM[43oi9g/@;oTWNb0_nIT/`4oiZGd0CoVigD1?nMXmT00onOZMgoSV^Vohm/Y`02
ohm/Y`CoT6fW1?nAKjP3oi=`Z0;oU76X0_nJPkT4oib5^P?oWHJj1OnNQkX3oin7^P;oX8Ni1?nMhod2
oj;Qo0;oG=CE0_mfh?43oi;PoP;oSn3m0onSc_H2oj;>m`?oYLK`1?nUa_42ojC7lP;oY/;]1onV`nh6
ojO1k0KoYl3/0_nW`N`aojO0j`03o`000?nW`>_oYl3[01GoYl3[5?ooool00ol0003oooooooooo`0E
ooooo`009?ooool3o`0000oooooo1?nh`n<2okg4g`?o_/OQ0ono`]`3okk0f`03okZheonh/mCo^;?D
00?o^;?D0_nf[M02ojfPb`CoZIW60onUT/44oj:;_0;oWXFh00?oUX>loiAn^?nDO[P00_nDO[P3oi9k
]P;oTGRc0ol00002oi5f/P?oT7Fa1?n@M;06oi1d[`CoT7B`1?nAMK03oi5f/0CoTGJa0_nBMk400onH
SlSoVI;<oiVBc003oiVBc0?oVYO@1OnKWM@2oifSf@CoSV^V0on?K:L3oi1]Y`CoTFnX0_nCL:P00onI
PKSoVX>ioiZ3^@03oiZ3^@?oW8Fj1?nMQ[X4oij7^P;oWhNj0onJi?d2oigSo@;oF=;A0_mjh_84oiGP
oP;oT^3n0onTcOH2oj?>mP;oY/G`1OnUa_02ojG6l@;oYl;]1?nV`^d2ojK3kP?oYl3/1OnW`N`7ojO0
k3GoYl3[00?o0000ojO0jonW`>/05OnW`>/Booooo`;o00002Oooool4o`000003oa0@4?oooooooooo
00Oooooo000Tooooo`03o`000?oooooooooo013ooooo00?o^<?Sokg4gonma=l00onma=l00onnan7o
_l;Loko2g003oko2g004okk0fonj^=Oo^[SGokZhe`?o^;?D00?o/:S@ojfPbon]X</00on]X</3ojVI
aPCoYI;10_nRRk`01?nIR<3oUX>loiJ3_?nFPk`4oiAn^0;oTW^f0ol00002oi5h/`?oTGJb1?n@MK43
oi1d/0OoT7B_1?n@M;03oi5e/0;oTGJ`00?oUXW4oiN<a_nGS<H00_nGS<H4oiR?b0CoVI;<1?nJUm02
oi^Me0SoSV^V0on?K:L3oi1]Y`;oTFnX0_nGOkL4oiV1^0CoVX>i0onLQKX4oif6^P?oWXNj0onGi?d2
oi[To@;oE]7>0_mmho<3oiOPoP;oUN3n0onTcOD2ojC=mP?oY/G_1?nVaO02ojG6l0OoYl;]0_nV`^d7
ojO0k0;oYl7/1onW`>`hojO0j`03o`000?nW`>_oYl3[01GoYl3[4oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo01;ooooo0onma=l2oko4g@Co_l;L00?o_;kK
okZheonj^=L00onj^=L01?nh/mCo/:S@ok2Xd?n`Z=04ojfPb`CoZIW60_nUT/400onLS/CoVHS0oiV8
`002oiV8`0?oUX>l0_nDO[P3o`0000;oTW^f0onAN;<3oi5f/PCoT7Fa1?n@M;06oi1d[`CoT7B`0_nA
MK000onFR<?oUXW4oiJ9a002oiJ9a0CoUhc60onHSlP5oiVBc0;oVYO@2on>JjH2ohm/Y`04oi=i/onE
O;GoUGbeoiEl]@GoUgng0onIPKP4oiZ3^@CoW8Fj0onMQ[X01?nNQk[oUnCmoiOToOnGi?d2oeKAc@;o
P>Cc1?nIhOd2oiOPoP;oYLgd0onTcOD7ojK5k`;oY/G`2?nW`^d9ojO0k0;oYl3[1onW`>`jojO0j`03
o`000?nW`>_oYl3[01GoYl3[5?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wo
oooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A006ooooo`03o`000?oooooooooo01?ooooo00?o_LCOoko4gOnoa=d00_noa=d00ono
`]co_;kKokbnf`02okbnf`?o^[SG00?o/k7Fok2Xd?n`Z=000on`Z=04ojfPb`;oZIW600?oWiC9oib>
a?nLS/@00_nLS/@3oiV8`0;oUX>l0ol00002oiAn^0?oTW^f0onAN;<4oi5f/P?oT7Fa1?n@M;05oi1d
[`03oiB7`onER<?oUHS300;oUHS31?nFR<<3oiJ9a0CoUhc61?nHSlP2oiVBc0;oSffW2?n>JjH00on@
M;3oTWNboi9g/P02oi9g/P?oTgVc1?nEO;D4oiMo]`?oVH6h1OnJPkT3oib5^P;oWHJj0_nFhod2oeOB
cP;oPnGd0onJhOd2oiWQo@OoYLgd00?oY<geojK5konVaNl01?nVaNl9ojO2k@;oYl3[1onW`>`6ojO0
j`;oYl3/?onW`>/00ol0003oYl3[ojO0j`0EojO0ja?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`09ooooo`002Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h01_ooool00ol0003oooooooooo`0Eooooo`?o_lCM0onna=l4okbnf`04okZheonc/MKo/k7F
ok>aePGo/:S@0_n]X</00onSW<koWiC9oinDb@02oinDb@?oW8k40onIR<02o`000003oiJ3_?nDO[So
U7jh00;oU7jh1?nBNkH3oi5h/`?oTGJb0on@MK42oi1d/0;oTXS50onCR<@4oiB7``CoUHS30onFR<<3
oiJ9a0GoUhc60_nHSlP00on=KjcoSFn]ohe_[@02ohe_[@?oSW2]0on?LZl3oi1d/0CoTWNb1?nCNK<3
oiEl]@CoUgng1?nIPKP4oiZ3^@;oW8Fj0_nFh_d2oe[Cd0;oQ>Kd0onKh_d2oi[Qo@;oY/gd1onUcO@3
ojO4k`;oY/G_0_nW`N`6ojO2k@OoYl3[0_nW`>a<ojO0j`03o`000?nW`>_oYl3[01GoYl3[4oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05o`000?oooooooooo
ooooool000003Oooool00onHV9So8B4Qonk^kP05ooooo`?o00005_ooool00onoa=go_/COokk4g`03
okk4g`;o_;kK00?o][[Lok>ae_nc/MH00onc/MH2ok2Xd0;oYZCD1?nSW<h3oinDb@?oW8k40ol00000
1?nIR<3oUX>loiJ3_?nFPk`3oiAn^0CoTW^f0onAN;<2oi5f/P04ohn9b?nAR<OoTHS7oi68a`GoTXS5
0onCR<@3oiB7``CoUHS30onFR<<4oiJ9a0;oUhc60_n=Kjd3ohe_[0CoSFn]0on>L:d3ohmb[`CoT7B`
1?nBMk83oi=i/`?oUGbe1OnGOkL3oiV1^0;oVX>i1?nGhOh01?nFh_goQ^OcohKWlon4i_@3oi_Ro@Oo
Y/gd0_nUcO@6ojO4k`KoYl7/0_nW`^eIojO0j`03o`000?nW`>_oYl3[01GoYl3[4Oooool3o`0000Oo
oooo00?o0000ooooooooool02Oooool000Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool06?ooool3okk4g`03okW3h_nf^]co][[L00;o
][[L0onc/MH00onY[M[oYZCDojJTe003ojJTe0?oXic>0onOU<T3o`000004oib>a?nIR<3oVHS0oiV8
`0?oUX>l0_nDO[P00on=RlcoSH[;ohf:b`02ohf:b`?oSXW:1?n?RLP3oi68a`CoTXS50onCR<@3oiB7
``CoUHS31?nFR<<2oiJ9a0;oSW6^0on=Kjd4ohe_[0?oSFn]1?n>L:d3ohmb[`?oT7B`1?nBMk83oi=i
/`CoUGbe1?nGOkL2oiV1^0?oV=kn0_nGhOh2ohOXl`;oQ^Oc0_nLhod2ojO>m0OoY/gd0_nWa>h5ojO4
k`OoYl7/G?nW`>/00ol0003oYl3[ojO0j`0EojO0j`kooooo1?l000000ooooooo0000ooooo`06oooo
o`03o`000?oooooooooo00Wooooo0009ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo00Co_/COokW3h_ni`n;o^L?R1?nf^]`0
1?nc/MKoZJgJojV]f_nY[MX4ojJTe0?oXic>0ol000001?nOU<WoW8k4oib>a?nBU=83oi2@c`?oSXg=
1?n=Rl`4ohf:b`?oSXW:0on?RLP3oi68a`CoTXS50onCR<@4oiB7``CoUHS30_nFR<<2oi1d/0CoSW6^
0on=Kjd3ohe_[0?oSFn]1?n>L:d3ohmb[`?oT7B`1?nBMk84oi=i/`?oUGbe0_nGOkL4oi[Io@;oV=kn
00CoHmWHohOXlon7j??oQnSc0onLi?d00onLhogoYlkdojO>m002ojO>m0;oY/gd0onWaNl4ojO4kP;o
YlC_1_nW`NaPojO0j`03o`000?nW`>_oYl3[01GoYl3[2_ooool3o`0000Gooooo00?o0000oooooooo
ool00oooool00omEEEGoIVIVo`00000;ooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`;o00006oooool4okW3hP;o][[L0_n/]n44ojV]
fP?oYZCD0ol000001?nHWmWoUYWEoiJIeOnFVMD4oi:DdP?oT93?0on>SLd3ohf;c0CoSH[;0on>RLX3
ohn9b0?oTHS71OnBR<D3oi>8a0;oU8O30_mHc^h01?nGOkOoTgVboi=i/_nCNK83oi1d/0CoSW6^0on=
Kjd3ohe_[0CoSFn]0on>L:d3ohmb[`?oT7B`1OnBMk83oi=i/`;oUGbe0onKdo/2oi[Io@;oJ]gN0_n7
j?84oicUo0;oW>Cm1OnWc_@7ojO5k`;oYlC^1onW`NaSojO0j`03o`000?nW`>_oYl3[01CoYl3[1_oo
ool4o`0000Sooooo00?o0000ooooooooool04Oooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`0Kooooo`;o^L?R
0_n^`NP4ojbgh@?oZJgJ0ol000000onKY]goV9oIoiROf@02oiROf@?oUYWE0onBU=83oi2@c`?oSXg=
0on=Rl`4ohf:b`CoSXW:0on?RLP3oi68a`;oTXS51?mab?l2ofO>n`04oif7^onGOkOoUgngoiMo]`?o
TgVb1?n@M;03ohia[P?oSFn]0on=Kj`4ohe_[@?oSW2]1?n?LZl3oi1d/0CoTWNb0_nCNK<3oic;n0;o
Vm?k0_mbh>D2ohSYl@?oW>Kl0_nLiO`4ojO?m@;oYlkd0_nXaNl6ojO5k`;oYl;/1onW`NaUojO0j`03
o`000?nW`>_oYl3[01GoYl3[0_ooool3o`0000cooooo00?o0000ooooooooool04Oooool002;ooooo
00?o0000ooooooooool07Oooool4ojk1j0;o[;OQ00GoWkGXo`000?l0003o0000oij]hP04oi^Vg@?o
V9oI0onFVMD4oi:DdP?oT93?0on>SLd3ohf;c0CoSH[;0_n>RLX2oh2`l`?oO;Si1Omh`?d2og78o`04
oj>A`OnMQk_oWHNkoif7^`?oUgng0onCNK84oi1d/0?oSW6^0on=Kjd3ohe_[0CoSFn]1?n>L:d3ohmb
[`?oT7B`0_nBMk84oi_1l`;oW<_h0_mji>d2ohSYl0?oVnOk0_nLi_`3ojS@m@;oYloe0onXa^l4ojS5
k`;oYlG_1_nW`^`2ojO1k6[oYl3[00?o0000ojO0jonW`>/05OnW`>/00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo01kooooo0_n^`NP2oj2nkP;o
00000_nO]NP3oij]hPCoVjKM0onHWmT3oiJIe@;oTYCB00CoRZ?UohRRiOn8X^GoR:;U1On6XnL3ohBV
jP?oPZ[^1?n0/?<3ogbhn@;oN<3m0_nZW<P3oj>A`@CoWHNk0onGOkL3oi=i/P?oT7B`1?n>LJh3ohe_
[@?oSFn/0on=Kjd4ohi`[@;oSg:_00?oUj_ToiVfk?nI]^`00onI]^`2oi_1l`?oQ>Gd0on8jNl01?n8
jO3oVnOkoi_WnonKio/3ojSBmP;oZ=3e0_nXanl5ojS6k`;oZ<G_2?nW`^a^ojO0j`03o`000?nW`>_o
Yl3[01GoYl3[4?ooool00ol0003oooooooooo`0@ooooo`008_ooool2o`00023ooooo0ol000000onP
_^koWkGXoinej002oinej0?oWZgR0_nKY]d01?n@ZnWoSZOWohjWion>YnL4ohbTi@?oRZ?U0on8X^D5
ohJSi`?oQ:KZ0on2Z^h2oh2`l`Co/:O>1?nZW<P4oj>A`@?oWHNk0onGOkL3oi=i/P?oT7B`1?n>LJh3
ohe_[@?oSFn/0_n=Kjd00onAUMCoU9oLoiBOg002oiBOg0CoUj_T0onI]^`3ohcTn`04ohCUm?n8jNoo
R>W_ohSYk`;oVnWk0onXdoH3ojSBmP;oZ<O`1?nXanl2ojS6k`WoYl;/L_nW`>/00ol0003oYl3[ojO0
j`0DojO0ja3ooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool07?ooool3
o`000003oooooonP_^koX;k^00;oX;k^0_nO]NP2oi:ek`?oTK3[0on@ZnT3ohjWi`CoS:CU0on:XnD3
ohRRi@;oQZ?W1?mVb?d2oe?8lP03olCPkOo6fnWo][7D00;o][7D0on`Ylh5ojZLb0;oXi7100CoU86k
oi1m^_n@OK[oT7fj0on=N[X3oh]j^`?oRWbn1?n:Ol83ohb5a`?oSXc=1?nAUM@4oiBOg0CoUj_T00Co
VKK/ohcTnon<i?_oS>Ck0_n8j^l2oiWZnP;oZMGg1OnXdoH00onXd_KoZ<O`ojS7l002ojS7l0;oZ<O_
0_nX`^d6ojO2k7KoYl3[00?o0000ojO0jonW`>/05OnW`>/?ooooo`03o`000?oooooooooo013ooooo
000Rooooo`03o`000?oooooooooo01Wooooo0ol00006ooooo`?oT[[b1?nB]Nl3oi6`j`?oT:_Y0on>
YnL2ohbTi@;oO;ck1Omg_od3og74o`;oI/Sm0oo4h>d00oni^][o][7DokJae002okJae0Co/:O>0_nZ
W<P2oiV6_PCoU86k0on@OKX3ohej^P?oRgZk0on:O;h3ohYo`PCoS8G70on>S<d4oi6Ee0CoU9oL0_nG
Zn@2oi?PoP;oRN[`0onHjoP00onIj_[oZMGgojWEm`02ojWEm`;oZ=?f1?nXb?02ojS7l0KoZ<;]0_nW
`^ajojO0j`03o`000?nW`>_oYl3[01CoYl3[3oooool00ol0003oooooooooo`0@ooooo`008_ooool0
0ol0003oooooooooo`0Fooooo`?o00002_ooool3oi:jlP;oT[G_0_n7]oD3ohFgmP?oPkSg1?mo^OT3
ogbln`;oMkom0om@b^T2oi[_lP?o_n3`00Coa>3]okVjf_ni^][o^K[J1?nf/M@2ok2WcP03oin=`OnI
Q[koVHJn00;oVHJn1?nDPK/3oi1m^P?oSGZj0on;N[/3ohYl_PCoRWo20on<QLL4ohj<c@;oTIGD0_nJ
boP4oiSGo@;oR^[a0onGjoL2oiS[n0?oZMOh0_nYeOL3ojW:l@;oZ<S`0_nX`nd7ojS2kGkoYl3[00?o
0000ojO0jonW`>/05?nW`>/>ooooo`03o`000?oooooooooo013ooooo000Rooooo`;o00005?ooool3
o`0000kooooo0on9]o@4ohNgm@?oQKOf0on3^?L2ognin@CoLL_o0_mTc_X00omBcmSoV^oboi[_lP04
okoPl0;o^l3N1?ni^]X2okJae003ojBEaOnOSL7oWhg100;oWhg11?nIQ[h3oiB1^`?oT7fj0on=N[X3
oh]j^`?oRWbn1?n:Ol84ohb5a`;oSXc=0_nI_O44oi[;n003oiSGoOn:j_7oR^[a00?oUn_g1?nYfOP2
ojWGn0;oZLcb0onYb_46ojS3k@;oZ<;]PonW`>/00ol0003oYl3[ojO0j`0DojO0j`gooooo00?o0000
ooooooooool04?ooool0027ooooo0_l0000Booooo`?o00004_ooool3ohVgm0;oQkOe0_n7_?P4oh;1
n`CoNlKn0_mabol2ofoJm@;oWnWk1?nkgO400onoh?3o^l3Nok_0gP02ok_0gP;o^K[J00?oZYg:ojBE
aOnTULD00_nTULD3oin=`@CoVHJn1?nDPK/3oi1m^P?oSGZj0on;N[/3ohYl_P?oRWo20_n<QLL3oiN_
j0CoVKga0_nJboP2oh_Ym0;oUN_g0onYg?T2ojWIn0?oZLgc1?nYc?800onYb_7oZ<?]ojS3k@04ojS3
k@;oZ<3[Q?nW`>/00ol0003oYl3[ojO0j`0EojO0j`cooooo00?o0000ooooooooool04?ooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool03oooool2o`0001Kooooo1?n;]o<3ohNln0;oP/7k1?n;c_h2oh7G
o`;oX]ol0onfeo42ok_Ml@?o^lCQ0onk`=h00on^YLooZYg:ojZMbP02ojZMbP?oY9G50onOSL44oiV6
_PCoU86k0on@OKX3ohej^P;oRgZk00CoT97@oi:IeonBVMOoTYWG1?nDXml5oiN_j0;oVKga0_n=j?L2
oiC[m`?oZMkj0_nYg?T2oj[?m0GoZLgc0_nYc?83ojS4k@;oZ<?]0_nX`N`4ojS0jhCoYl3[00?o0000
ojO0jonW`>/05?nW`>/=ooooo`03o`000?oooooooooo00oooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<
ooooo`?o00006Oooool2oh^gl`?oUK_a1?nAa?P2oh_>oP?oXmCi00CoX]olokKGlOnfeo7o]]Oa0onj
a^<4ok_4h@04ok_0g_n^YLoo[ZG?ojjUc`?oZYg:1?nTULD3oin=`@;oVHJn00?oTh[7oi68aonAR<L0
0_nAR<L3ohn9b0?oShc<1?n@TM03oi:Ie`CoU:?O0_nG[nP3oi3Un`?oU>_h00CoU>_gojWNn_nYg_[o
ZMkj0_nZd_D4oj[?m0;oZLgc1?nXaNh2ojS4k@KoZ<7/0_nX`>^6ojO0j`03o`000?nW`>_oYl3[01Co
Yl3[3?ooool00ol0003oooooooooo`0?ooooo`001oooool01Ol@413ooooooooooooooooo410@00_o
oooo1Ol00005ooooo`;o00002_ooool3o`0001gooooo1OnE^o42oi74n0?oXlWc0_nSe?T3ok?@k`03
okKGlOnja^?o^/KS00?o^/KS0_nka>400onb[M?o[ZG?ojjUc`02ojjUc`CoZYg:0_nTULD01?nKTl[o
Uhk8oiN>b?nGS/P4oi>:a`?oTHS71?n?RLP3ohn<c0?oT97@1?nBVML2oiBSg`CoTN3n00CoT>GkoiC[
n?nDjoSoU>_h0onYh?X00onYg_[oZ];eoj[Bm@02oj[Bm@;oZ/od0_nYaNh4ojS5kPSoZ<7/ROnW`>/0
0ol0003oYl3[ojO0j`0EojO0j`_ooooo00?o0000ooooooooool03oooool000Oooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000ooooooooool01_oo
ool3o`00027ooooo0_nE^o43oj>ok@?oXlWc0_n`b>`3ok?@k`;o^<GT1?nja^<00ond]=So/ZgCok:]
d`02ok:]d`Co[ZG?0_nZWLX00onPVLkoVi?:oi^CbP02oi^CbP?oUhk80onCR/L4oi68a`?oShW80on?
S<`4oi2Ad0;oTYWG0onCf?h2oi7PoP;oUNWi1?nXhO/2ojWPnP?oZ]Cf0_nZd_D2ojW6k`CoZLG^00?o
Z<G^ojS1k?nX`N`01OnX`Nb=ojO0j`03o`000?nW`>_oYl3[01GoYl3[2_ooool00ol0003ooooooooo
o`0?ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo0000
1_ooool00ol0003oooooooooo`03ooooo`?o00009_ooool4oj>ok@03oj?9lon`b>co/<S/00;o/<S/
00?o/m3_okS5i?nhaN@00_nhaN@00onja^?o];CHokBdf002okBdf0Co/ZgC0_n^YLl00onUX=7oX9W>
oj2IcP02oj2IcP?oVi?:0onGS/P3oi>:a`CoTHS71?n?RLP3ohn<c0;oT97@0onBcO`2oi?HoP;oU^Kk
0onVh_/2ojSQn`CoZ]Kg0_nZe?H2ojW8k`CoZLK_0_nYaNh3ojS2k0;oZ<7/T_nW`>/00ol0003oYl3[
ojO0j`0DojO0j`[ooooo00?o0000ooooooooool03oooool000Oooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03ogMgMoo<c<co000000Gooooo00Co0000oooooooooooooooo0ol0000Zooooo`;o
Xko]0on_`^P2ok38k0;o]lCT0onhaN@2okJjg0Go];CH0_nb[M<00onYZ=GoYJ3AojFPd@02ojFPd@?o
X9W>0onKTlX4oiN>b0?oTh[70onAR<L2ohn9b0?oT;G`1?nB`OH2oi;=o0;oUn;m0onUh_/2ojKRn`?o
Z]Sh0_nZe_L3oj[9l0CoZLS_0_nYa^l5ojS2k0;oYl7/U?nW`>/00ol0003oYl3[ojO0j`0DojO0j`Wo
oooo00?o0000ooooooooool03oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
onk^k_m4A4Co000000Gooooo1?l0000^ooooo`?o[l;X0_ne`n@4okO4i003okS5i?nf^]co][[L00;o
][[L0ond]=P00on/[mWoZJSEojVXe@02ojVXe@?oYJ3A1?nPVLh3oi^CbP;oUhk800?oTZ;Ooi6UhonA
YN<00_nAYN<3oi2/j@GoT;G`0_nB`OH3oiSKoP04oiORoOnUh__oYN;kojGRn`?oZM[i0_nZf?P2oj[;
l@GoZ/W`0_nYb>l3ojS3k@;oZ<;/0_nX`N`4ojO1k9?oYl3[00?o0000ojO0jonW`>/05?nW`>/9oooo
o`03o`000?oooooooooo00oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omg
MgOo0000ooooo`04ooooo`;o0000<Oooool00on_`^So]L?TokG3i002okG3i0;o]lCT0_ng_^05okJj
g004okBdf?n/[mWo[:oIojb_f@CoZJSE0onUX=42oj2IcP04oiVRfonFXMcoUZ7LoiJQg0CoTZ;O1?nA
YN<3oi2/j@;oT;G`1?nGd_`2oiSKoP;oXn7l0onXfoT2ojWJn@;oZ/cb1?nZbo42oj[9l0?oZLC]0onX
`nd6ojS1k0;oYl7/UOnW`>/00ol0003oYl3[ojO0j`0DojO0j`Sooooo00?o0000ooooooooool03ooo
ool002;ooooo00?o0000ooooooooool0;oooool3okG3i0;o]l?S1?ng_^02okJjg0?o[kKM1?n/[mT2
ojVXe@04oj6ZgOnMY]coWJKLoifVg0CoVJ;K0onFXM`4oi:Rg`;oTJGS0_nF`?@5oiO9n@;oUm;l0onQ
g_`01?nShOcoZ=_iojSKnOnXfoT2oj[=lPCoZ/cb0_nZbo42ojW5kPGoZLC]00?oZ<?]ojS1k?nX`N`0
1?nX`NbIojO0j`03o`000?nW`>_oYl3[01?oYl3[2Oooool00ol0003oooooooooo`0>ooooo`008ooo
ool00ol0003oooooooooo`0_ooooo`03okG3i?ng`n?o]l?S00;o]l?S0_ng_^03ok6lhPCo[kKM0_n/
[mT00onU[mooXJ[Moj6Zg@02oj6Zg@?oWJKL1?nIX]/3oiJQg0;oTZ;O0_nF^Nl4oiK0m0;oUlWi1?nN
f_`2oj7No0?oYm[j00?oZ=_ioj[=l_nZcO800_nZcO82oj[<lP;oZLK^1?nYaNh2ojW4k@KoZ<7/W?nW
`>/00ol0003oYl3[ojO0j`0DojO0j`Sooooo00?o0000ooooooooool03_ooool002Cooooo00?o0000
ooooooooool0;oooool3okO3h`;o//;V1Ona_>82ojnfg@03ojReh_nU[mooYJoO00;oYJoO1?nQZ]d3
oifVg0;oVJ;K0_nH/NT3oiNdk0CoU[W_0_nF`?@4oicEo0;oW][l0onUfOX2ojOJnP?oZ/oc0_nZcO82
ojW7k`CoZLK^0_nYaNh3ojS2k0;oZ<7/XOnW`>/00ol0003oYl3[ojO0j`0DojO0j`Oooooo00?o0000
ooooooooool03_ooool002Gooooo0_l0000`ooooo`03okO3honb`^Ko//;V00;o//;V0_na_>82ojZk
iPCoZ;GR1?nU[ml2oj6Zg@03oibbionJ/NOoV[7W00;oV[7W1?nH/NT3oiNdk0;oU[W_0onJcoX2oicE
o0CoXmOj0_nUfOX3ojW?m0;oZ/oc0_nYb?04ojW7k`;oZLK^1OnX`^`2ojS0jj?oYl3[00?o0000ojO0
jonW`>/05?nW`>/6ooooo`03o`000?oooooooooo00kooooo000Wooooo`03o`000?oooooooooo02ko
oooo0onb`^H3oj_1j@?oZ[_V1?nX]N82ojF_g`;oWkCW0onL/^L4oiZai`;oV;7Y0_nIa?H4oiW9n0;o
V/oj0onQdoT2oj?GnPCoZ<od0_nYco@2ojW9l0CoZLS`0_nYanl3ojS3k@;oZ<;/0_nX`N/4ojS0jj?o
Yl3[00?o0000ojO0jonW`>/04onW`>/6ooooo`03o`000?oooooooooo00kooooo000Xooooo`03o`00
0?oooooooooo02kooooo00?o//;Voj_1jOn[`NT00on[`NT3ojZkiP;oZ;GR0_nQ^>P4oindi`?oW;;W
0_nJ/NL2oiW1l`CoVLCf0_nIbOP3oio?n@;oXM?i1?nWcoD2ojS?m0;oZLWa1?nYbO02ojW8l0GoZ<?]
0_nX`N`4ojS1j`;oZ<3[Y?nW`>/00ol0003oYl3[ojO0j`0DojO0j`Gooooo00?o0000ooooooooool0
3_ooool002Wooooo00?o0000ooooooooool0;oooool2oj_1j@?oY;o]0onS^nX4oj6hj0;oWkCW0_nL
_O04oiZnl@?oVL7c0_nIa?H3oik;m`;oWloi0onUcOD2ojO?m@?oZ<[a1?nYbO42ojW9l0;oZ<C]1OnX
`nd4ojS1k0;oZ<7[Z?nW`>/00ol0003oYl3[ojO0j`0DojO0j`Cooooo00?o0000ooooooooool03_oo
ool002[ooooo0_l0000aooooo`CoY;o]0onS^nX2oj6hj0;oWKg_1?nL_O02oiZnl@;oWLCc1?nMaoD2
oik;m`?oY<_d0_nUcOD2ojO9lPGoZ<[a0_nYbO42ojS4kPCoZ<C]0_nX`nd5ojS1k:coYl3[00?o0000
ojO0jonW`>/05?nW`>/3ooooo`03o`000?oooooooooo00kooooo000/ooooo`03o`000?oooooooooo
02oooooo0_nT_nd2oinnkP?oW[g^1?nM_Nl2oibml0;oWL;b1?nMa?<2oig7m@?oX/Wd0_nTbo@2ojK9
lPCoYlWb0_nXb_43ojS5kPCoZ<C^0_nXa>d3ojS2k0;oZ<7//?nW`>/00ol0003oYl3[ojO0j`0DojO0
j`?ooooo00?o0000ooooooooool03Oooool002gooooo00?o0000ooooooooool0;oooool4oinnkP?o
W[g^0_nM_Nl2oig0l@CoWL;b0_nMa?<3oj76l`;oX/Wd0_nUao44ojK9lP;oYlWb1onXaNh2ojS4kPGo
Z<;/0_nX`NbaojO0j`03o`000?nW`>_oYl3[01CoYl3[0oooool00ol0003oooooooooo`0=ooooo`00
;_ooool00ol0003oooooooooo`0_ooooo`;oWkk^0_nN_Nh4oijnk`?oWL3a0_nM`_83oj34lP;oXLKc
0_nTa_44ojG7l@;oY/Wb0_nWaNh6ojS5kPKoZ<;/1_nX`NbaojO0j`03o`000?nW`>_oYl3[01CoYl3[
0_ooool00ol0003oooooooooo`0=ooooo`00;oooool00ol0003oooooooooo`0_ooooo`CoW[g^0_nN
_^l2oj2ok`CoX<;a0_nPa?82oj?4l0CoY<Ka0_nUao42ojO4kPCoYlG^0_nXaNh3ojS2k@;oZ<;/2OnX
`NbcojO0j`03o`000?nW`>_oYl3[01?oYl3[0_ooool00ol0003oooooooooo`0=ooooo`00<?ooool2
o`00033ooooo0_nN_Nh2oj2nkPCoX;o_0_nP`_42oj?2k`CoXlC`0_nTa_42ojK4kPCoYlC^0_nWaNh3
ojS3k@;oZ<;]2?nX`NbgojO0j`03o`000?nW`>_oYl3[01CoYl3[00?oooooo`000?ooool03_ooool0
03;ooooo00?o0000ooooooooool0;_ooool4oj2nkP;oX;o_0_nR`>h4oj?2k`;oXlC`0_nU`nh4ojK4
kP;oYlC^0onW`^d2ojS3k@SoZ<7/^onW`>/00ol0003oYl3[ojO0j`0CojO0j`03ooooool0003ooooo
00kooooo000cooooo`03o`000?oooooooooo02kooooo0_nP_^h2oj:nk@CoX/3^0_nS`^l2ojG1kPCo
YL?^0_nVa>h5ojO2k@;oYl7/1_nX`NboojO0j`03o`000?nW`>_oYl3[01?oYl3[00?o0000oooooooo
ool03Oooool003Cooooo00?o0000ooooooooool0;_ooool4oj:nk@;oX/3^0onU`>d3ojG1kP;oYL?^
0onV`^d2ojO2k@KoYl7/0_nX`Nc3ojO0j`03o`000?nW`>_oYl3[017oYl3[00?oooooo`000?ooool0
3_ooool003Gooooo0_l0000_ooooo`;oX[k]0onT_n`2ojG0k@;oY/3/1?nV`Nd2ojK2k@SoYl7/0_nW
`>c4ojO0j`03o`000?nW`>_oYl3[00goYl3[1_ooool00ol0003oooooooooo`0<ooooo`00=oooool0
0ol0003oooooooooo`0^ooooo`;oY;o/0_nV_n`4ojK0k0;oY/7]2?nW`N`6ojO0k<CoYl3[00?o0000
ojO0jonW`>/02OnW`>/9ooooo`03o`000?oooooooooo00cooooo000hooooo`03o`000?oooooooooo
02kooooo1?nV_n`2ojK0k0;oYl3/1_nW`N`8ojO0k<KoYl3[00?o0000ojO0jonW`>/01OnW`>/<oooo
o`03o`000?oooooooooo00cooooo000iooooo`03o`000?oooooooooo02kooooo0_nV_n`6ojO0k0;o
Yl7/2?nW`>c:ojO0j`03o`000?nW`>_oYl3[013ooooo00?o0000ooooooooool03?ooool003[ooooo
0_l0000_ooooo`KoYl3/0_nW`>/6ojO0k<goYl3[00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0<ooooo`00??ooool00ol0003oooooooooo`0]ooooo`;oYl3/1_nW`>/2ojO0k<coYl3[1Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo000mooooo`03o`000?oooooo
oooo02goooood_nW`>/9ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool0
03kooooo00?o0000ooooooooool0;Oooooo:ojO0ja3ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0<ooooo`00?oooool2o`0002ooooooaOnW`>/Dooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool02oooool0047ooooo00?o0000ooooooooool0;Oooooo1ojO0jaSooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`00@_ooool00ol0003ooooooooo
o`0]oooookcoYl3[7Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0013
ooooo`03o`000?oooooooooo02gooooo^?nW`>/Pooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool004Cooooo00?o0000ooooooooool0;OoooondojO0jbCooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`00AOooool2o`0002oooooo[_nW`>/Yooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool004Oooooo00?o0000ooooooooool0
;OoooonZojO0jbcooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`00B?oo
ool00ol0003oooooooooo`0]ooooojKoYl3[<?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00_ooooo0019ooooo`03o`000?oooooooooo02goooooX_nW`>/dooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool004[ooooo0_l0000^oooooigoYl3[>Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo001<ooooo`03o`000?oooooooooo02co
ooooVOnW`>/looooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool004gooooo
00?o0000ooooooooool0;?oooonBojO0jd?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0:ooooo`00C_ooool00ol0003oooooooooo`0]ooooohgoYl3[Aoooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00[ooooo001?ooooo`;o0000;_oooon8ojO0jdcooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`00DOooool00ol0003oooooooooo`0/oooo
ohCoYl3[Coooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo001Booooo`03
o`000?oooooooooo02_oooooPOnW`>]Cooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02_ooool005?ooooo00?o0000ooooooooool0:ooooommojO0jeOooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`09ooooo`00E?ooool2o`0002goooooN?nW`>]Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02Oooool005Kooooo00?o0000ooooooooool0:ooooomd
ojO0jekooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`00Eoooool00ol0
003oooooooooo`0[ooooofcoYl3[I_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Wooooo001Hooooo`03o`000?oooooooooo02coooooIonW`>]Zooooo`05o`000?oooooooooooooo
ool000002oooool005Wooooo00?o0000ooooooooool0;?oooomSojO0jfgooooo00Go0000oooooooo
ooooooooo`00000;ooooo`00F_ooool2o`0002goooooGonW`>]aooooo`04o`000?ooooooooooo`00
00_ooooo001Looooo`03o`000?oooooooooo02_oooooFonW`>]eooooo`03o`000?oooooo000000_o
oooo001Mooooo`03o`000?oooooooooo02_oooooEonW`>]hooooo`04o`000?ooooooooooo`0000[o
oooo001Nooooo`03o`000?oooooooooo02_oooooDonW`>]looooo`03o`000?oooooo000000[ooooo
001Oooooo`;o0000;?oooom<ojO0jh?ooooo0_l0000:ooooo`00HOooool00ol0003oooooooooo`0Z
ooooodSoYl3[QOooool3o`0000[ooooo001Rooooo`03o`000?oooooooooo02_ooooo@onW`>^4oooo
o`Co00003Oooool006?ooooo00?o0000ooooooooool0:oooooloojO0jh?ooooo1?l0000Aooooo`00
I?ooool2o`0002cooooo>onW`>^3ooooo`?o00005Oooool006Kooooo00?o0000ooooooooool0:ooo
oolcojO0jhGooooo1?l0000Hooooo`00Ioooool00ol0003oooooooooo`0Zoooooc3oYl3[Q?ooool4
o`0001cooooo001Xooooo`03o`000?oooooooooo02[ooooo;?nW`>^3ooooo`Co00008?ooool006Wo
oooo0_l0000/ooooobOoYl3[P_ooool4o`0002Cooooo001[ooooo`03o`000?oooooooooo02[ooooo
8onW`>^2ooooo`?o0000:?ooool006cooooo00?o0000ooooooooool0:_oooolMojO0jh?ooooo1?l0
000[ooooo`00KOooool00ol0003oooooooooo`0[oooooaSoYl3[P_ooool4o`0002oooooo001^oooo
o`03o`000?oooooooooo02[ooooo5OnW`>^1ooooo`Co0000<oooool006oooooo0_l0000[oooooa7o
Yl3[P?ooool4o`0003Oooooo001aooooo`03o`000?oooooooooo02[ooooo2OnW`>^2ooooo`Co0000
>oooool007;ooooo00?o0000ooooooooool0:_ooool5ojO0jh;ooooo0ol0000oooooo`00Loooool0
0ol0003oooooooooo`0Zooooo`03ojO0jooooooooooo07oooooo1?l00012ooooo`00M?ooool2o`00
02[ooooo00?o0000ooooooooool0Noooool4o`0004Kooooo001fooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0N?ooool4o`0004[ooooo001gooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0M?ooool4o`0004kooooo001hooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0LOooool3o`0005;ooooo001iooooo`;o00009?ooool00ol0003oooooooooo`1]
ooooo`Co0000EOooool007_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Yoooo
o`Co0000FOooool007cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Uooooo`Co
0000GOooool007gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Qooooo`Co0000
HOooool007kooooo0_l0000Oooooo`03o`000?oooooooooo05gooooo1?l0001Uooooo`00P?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo05[ooooo0ol0001Yooooo`00POooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo05Kooooo1?l0001/ooooo`00P_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo05;ooooo1?l0001`ooooo`00Poooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo04kooooo1?l0001dooooo`00Q?ooool2o`0001Wooooo00?o
0000ooooooooool0B_ooool4o`0007Sooooo0026ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0A_ooool4o`0007cooooo0027ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0@oooool3o`00083ooooo0028ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0?oooool4o`0008?ooooo0029ooooo`;o00005?ooool00ol0003oooooooooo`0kooooo`Co0000
Qoooool008_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0gooooo`Co0000Rooo
ool008cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0cooooo`Co0000Soooool0
08gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0`ooooo`?o0000Toooool008ko
oooo0_l0000?ooooo`03o`000?oooooooooo02cooooo1?l0002Fooooo`00T?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo02Sooooo1?l0002Jooooo`00TOooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo02Cooooo1?l0002Nooooo`00T_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo027ooooo1?l0002Rooooo`00Toooool2o`0000Wooooo00?o0000oooo
ooooool07Oooool4o`000:Kooooo002Eooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool06_ooool3o`000:[ooooo002Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
5_ooool4o`000:gooooo002Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_oo
ool4o`000;7ooooo002Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool4
o`000;Gooooo002Iooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000^Oooool009_o
oooo00Co0000oooooooooooo00002Oooool3o`000;gooooo002Looooo`03o`000?oooooo000000Go
oooo1?l00030ooooo`00WOooool2o`000003ooooool0003o000000;o0000a?ooool009kooooo0_l0
0038ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00[_ooool01OnHV9So0000o`000?m4A4Co^[Zj
00_ooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Cooooo1Ol0002Gooooo`00[_ooool01Ol@413o
^[Zjonk^k_mgMgOo410@00;ooooo1_l00003ooooo`03oeEEEOnYZJWooooo00Gooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@0Uoooool00:kooooo00?o0000ooooooooool03Oooool00onY
ZJWoEEEEooooo`0<ooooo`03oiRHV?lQ8B7ok^k^09Sooooo002^ooooo`03o`000?oooooooooo00Co
oooo1_l00004ooooo`03ob4Q8Ooooooooooo00cooooo00?oV9RHob4Q8Oo^k^h0Uoooool00:kooooo
00?o0000ooooooooool03_ooool00omEEEGoc<c<ooooo`0=ooooo`03ogMgMomVIVKooooo09Kooooo
002/ooooo`03oa0@4?l0003o000000?o00003Oooool00onYZJWoMgMgooooo`0>ooooo`03o`000?oo
oooooooo09Gooooo002^ooooo`03o`000?oooooooooo00_ooooo00Go410@oooooooooooooooooc8b
<P0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100Uoooool00:kooooo00?o0000ooooooooool02ooo
ool5o`0000_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02Gooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -14 0 ]
[.5 .82364 14 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8.) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69467 Mtetra
.4053 .69467 .41061 .69934 .41957 .69681 .41427 .69213 Mtetra
.41427 .69213 .41957 .69681 .42855 .69428 .42327 .68958 Mtetra
.42327 .68958 .42855 .69428 .43756 .69174 .43231 .68703 Mtetra
.43231 .68703 .43756 .69174 .4466 .68919 .44137 .68446 Mtetra
.44137 .68446 .4466 .68919 .45567 .68663 .45046 .68189 Mtetra
.45046 .68189 .45567 .68663 .46478 .68407 .45958 .67931 Mtetra
.45958 .67931 .46478 .68407 .47391 .68149 .46873 .67671 Mtetra
.46873 .67671 .47391 .68149 .48307 .67891 .47792 .67412 Mtetra
.47792 .67412 .48307 .67891 .49227 .67632 .48713 .67151 Mtetra
.48713 .67151 .49227 .67632 .50149 .67371 .49638 .66889 Mtetra
.49638 .66889 .50149 .67371 .51075 .6711 .50565 .66626 Mtetra
.50565 .66626 .51075 .6711 .52004 .66849 .51496 .66363 Mtetra
.51496 .66363 .52004 .66849 .52936 .66586 .5243 .66098 Mtetra
.5243 .66098 .52936 .66586 .53871 .66322 .53367 .65833 Mtetra
.53367 .65833 .53871 .66322 .54809 .66058 .54308 .65567 Mtetra
.54308 .65567 .54809 .66058 .55751 .65792 .55251 .653 Mtetra
.55251 .653 .55751 .65792 .56695 .65526 .56198 .65032 Mtetra
.56198 .65032 .56695 .65526 .57643 .65259 .57148 .64763 Mtetra
.57148 .64763 .57643 .65259 .58595 .6499 .58102 .64493 Mtetra
.58102 .64493 .58595 .6499 .59549 .64721 .59058 .64222 Mtetra
.59058 .64222 .59549 .64721 .60507 .64451 .60018 .6395 Mtetra
.60018 .6395 .60507 .64451 .61468 .6418 .60982 .63678 Mtetra
.60982 .63678 .61468 .6418 .62432 .63908 .61948 .63404 Mtetra
.61948 .63404 .62432 .63908 .634 .63636 .62918 .63129 Mtetra
.62918 .63129 .634 .63636 .64371 .63362 .63892 .62854 Mtetra
.63892 .62854 .64371 .63362 .65345 .63087 .64868 .62577 Mtetra
.64868 .62577 .65345 .63087 .66323 .62811 .65848 .623 Mtetra
.65848 .623 .66323 .62811 .67304 .62535 .66832 .62021 Mtetra
.66832 .62021 .67304 .62535 .68289 .62257 .67819 .61742 Mtetra
.67819 .61742 .68289 .62257 .69277 .61979 .68809 .61462 Mtetra
.68809 .61462 .69277 .61979 .70269 .61699 .69803 .6118 Mtetra
.69803 .6118 .70269 .61699 .71264 .61418 .70801 .60898 Mtetra
.70801 .60898 .71264 .61418 .72262 .61137 .71802 .60615 Mtetra
.71802 .60615 .72262 .61137 .73264 .60854 .72806 .6033 Mtetra
.72806 .6033 .73264 .60854 .7427 .60571 .73814 .60045 Mtetra
.73814 .60045 .7427 .60571 .75279 .60286 .74826 .59759 Mtetra
.74826 .59759 .75279 .60286 .76291 .60001 .75841 .59471 Mtetra
.75841 .59471 .76291 .60001 .77308 .59714 .7686 .59183 Mtetra
.7686 .59183 .77308 .59714 .78328 .59427 .77882 .58893 Mtetra
.77882 .58893 .78328 .59427 .79351 .59138 .78908 .58603 Mtetra
.78908 .58603 .79351 .59138 .80378 .58849 .79938 .58311 Mtetra
.79938 .58311 .80378 .58849 .81409 .58558 .80971 .58019 Mtetra
.80971 .58019 .81409 .58558 .82443 .58267 .82008 .57725 Mtetra
.82008 .57725 .82443 .58267 .83482 .57974 .83049 .57431 Mtetra
.83049 .57431 .83482 .57974 .84523 .5768 .84094 .57135 Mtetra
.84094 .57135 .84523 .5768 .85569 .57385 .85142 .56838 Mtetra
.85142 .56838 .85569 .57385 .86618 .57089 .86194 .5654 Mtetra
.86194 .5654 .86618 .57089 .87672 .56792 .8725 .56241 Mtetra
.8725 .56241 .87672 .56792 .88729 .56494 .8831 .55941 Mtetra
.8831 .55941 .88729 .56494 .89789 .56195 .89374 .5564 Mtetra
.89374 .5564 .89789 .56195 .90854 .55895 .90441 .55338 Mtetra
.90441 .55338 .90854 .55895 .91923 .55594 .91512 .55035 Mtetra
.91512 .55035 .91923 .55594 .92995 .55292 .92588 .5473 Mtetra
.92588 .5473 .92995 .55292 .94071 .54988 .93667 .54425 Mtetra
.93667 .54425 .94071 .54988 .95152 .54684 .9475 .54118 Mtetra
.9475 .54118 .95152 .54684 .96236 .54378 .95837 .53811 Mtetra
.95837 .53811 .96236 .54378 .97324 .54071 .96928 .53502 Mtetra
.96928 .53502 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.391 .69252 .39636 .6972 .4053 .69467 .39996 .68998 Mtetra
.39996 .68998 .4053 .69467 .41427 .69213 .40895 .68742 Mtetra
.40895 .68742 .41427 .69213 .42327 .68958 .41797 .68486 Mtetra
.41797 .68486 .42327 .68958 .43231 .68703 .42702 .68228 Mtetra
.42702 .68228 .43231 .68703 .44137 .68446 .4361 .6797 Mtetra
.4361 .6797 .44137 .68446 .45046 .68189 .44521 .67711 Mtetra
.44521 .67711 .45046 .68189 .45958 .67931 .45435 .67452 Mtetra
.45435 .67452 .45958 .67931 .46873 .67671 .46352 .67191 Mtetra
.46352 .67191 .46873 .67671 .47792 .67412 .47273 .66929 Mtetra
.47273 .66929 .47792 .67412 .48713 .67151 .48196 .66667 Mtetra
.48196 .66667 .48713 .67151 .49638 .66889 .49123 .66403 Mtetra
.49123 .66403 .49638 .66889 .50565 .66626 .50053 .66139 Mtetra
.50053 .66139 .50565 .66626 .51496 .66363 .50985 .65874 Mtetra
.50985 .65874 .51496 .66363 .5243 .66098 .51922 .65608 Mtetra
.51922 .65608 .5243 .66098 .53367 .65833 .52861 .65341 Mtetra
.52861 .65341 .53367 .65833 .54308 .65567 .53803 .65073 Mtetra
.53803 .65073 .54308 .65567 .55251 .653 .54749 .64804 Mtetra
.54749 .64804 .55251 .653 .56198 .65032 .55698 .64534 Mtetra
.55698 .64534 .56198 .65032 .57148 .64763 .5665 .64264 Mtetra
.5665 .64264 .57148 .64763 .58102 .64493 .57606 .63992 Mtetra
.57606 .63992 .58102 .64493 .59058 .64222 .58565 .6372 Mtetra
.58565 .6372 .59058 .64222 .60018 .6395 .59527 .63446 Mtetra
.59527 .63446 .60018 .6395 .60982 .63678 .60493 .63172 Mtetra
.60493 .63172 .60982 .63678 .61948 .63404 .61461 .62896 Mtetra
.61461 .62896 .61948 .63404 .62918 .63129 .62434 .6262 Mtetra
.62434 .6262 .62918 .63129 .63892 .62854 .63409 .62343 Mtetra
.63409 .62343 .63892 .62854 .64868 .62577 .64388 .62064 Mtetra
.64388 .62064 .64868 .62577 .65848 .623 .65371 .61785 Mtetra
.65371 .61785 .65848 .623 .66832 .62021 .66357 .61505 Mtetra
.66357 .61505 .66832 .62021 .67819 .61742 .67346 .61224 Mtetra
.67346 .61224 .67819 .61742 .68809 .61462 .68339 .60942 Mtetra
.68339 .60942 .68809 .61462 .69803 .6118 .69335 .60658 Mtetra
.69335 .60658 .69803 .6118 .70801 .60898 .70335 .60374 Mtetra
.70335 .60374 .70801 .60898 .71802 .60615 .71338 .60089 Mtetra
.71338 .60089 .71802 .60615 .72806 .6033 .72345 .59803 Mtetra
.72345 .59803 .72806 .6033 .73814 .60045 .73356 .59516 Mtetra
.73356 .59516 .73814 .60045 .74826 .59759 .7437 .59227 Mtetra
.7437 .59227 .74826 .59759 .75841 .59471 .75387 .58938 Mtetra
.75387 .58938 .75841 .59471 .7686 .59183 .76409 .58648 Mtetra
.76409 .58648 .7686 .59183 .77882 .58893 .77434 .58356 Mtetra
.77434 .58356 .77882 .58893 .78908 .58603 .78462 .58064 Mtetra
.78462 .58064 .78908 .58603 .79938 .58311 .79495 .57771 Mtetra
.79495 .57771 .79938 .58311 .80971 .58019 .80531 .57476 Mtetra
.80531 .57476 .80971 .58019 .82008 .57725 .81571 .57181 Mtetra
.81571 .57181 .82008 .57725 .83049 .57431 .82614 .56884 Mtetra
.82614 .56884 .83049 .57431 .84094 .57135 .83661 .56586 Mtetra
.83661 .56586 .84094 .57135 .85142 .56838 .84712 .56288 Mtetra
.84712 .56288 .85142 .56838 .86194 .5654 .85767 .55988 Mtetra
.85767 .55988 .86194 .5654 .8725 .56241 .86826 .55687 Mtetra
.86826 .55687 .8725 .56241 .8831 .55941 .87889 .55385 Mtetra
.87889 .55385 .8831 .55941 .89374 .5564 .88955 .55082 Mtetra
.88955 .55082 .89374 .5564 .90441 .55338 .90025 .54777 Mtetra
.90025 .54777 .90441 .55338 .91512 .55035 .911 .54472 Mtetra
.911 .54472 .91512 .55035 .92588 .5473 .92178 .54166 Mtetra
.92178 .54166 .92588 .5473 .93667 .54425 .9326 .53858 Mtetra
.9326 .53858 .93667 .54425 .9475 .54118 .94346 .53549 Mtetra
.94346 .53549 .9475 .54118 .95837 .53811 .95436 .53239 Mtetra
.95436 .53239 .95837 .53811 .96928 .53502 .9653 .52928 Mtetra
.9653 .52928 .96928 .53502 .98024 .53192 .97628 .52616 Mtetra
.38561 .68781 .391 .69252 .39996 .68998 .39459 .68525 Mtetra
.39459 .68525 .39996 .68998 .40895 .68742 .40359 .68268 Mtetra
.40359 .68268 .40895 .68742 .41797 .68486 .41263 .6801 Mtetra
.41263 .6801 .41797 .68486 .42702 .68228 .4217 .67751 Mtetra
.4217 .67751 .42702 .68228 .4361 .6797 .4308 .67492 Mtetra
.4308 .67492 .4361 .6797 .44521 .67711 .43993 .67231 Mtetra
.43993 .67231 .44521 .67711 .45435 .67452 .44909 .6697 Mtetra
.44909 .6697 .45435 .67452 .46352 .67191 .45828 .66707 Mtetra
.45828 .66707 .46352 .67191 .47273 .66929 .46751 .66444 Mtetra
.46751 .66444 .47273 .66929 .48196 .66667 .47676 .6618 Mtetra
.47676 .6618 .48196 .66667 .49123 .66403 .48605 .65915 Mtetra
.48605 .65915 .49123 .66403 .50053 .66139 .49537 .65649 Mtetra
.49537 .65649 .50053 .66139 .50985 .65874 .50472 .65382 Mtetra
.50472 .65382 .50985 .65874 .51922 .65608 .5141 .65114 Mtetra
.5141 .65114 .51922 .65608 .52861 .65341 .52351 .64846 Mtetra
.52351 .64846 .52861 .65341 .53803 .65073 .53296 .64576 Mtetra
.53296 .64576 .53803 .65073 .54749 .64804 .54244 .64305 Mtetra
.54244 .64305 .54749 .64804 .55698 .64534 .55195 .64034 Mtetra
.55195 .64034 .55698 .64534 .5665 .64264 .56149 .63762 Mtetra
.56149 .63762 .5665 .64264 .57606 .63992 .57107 .63488 Mtetra
.57107 .63488 .57606 .63992 .58565 .6372 .58068 .63214 Mtetra
.58068 .63214 .58565 .6372 .59527 .63446 .59032 .62939 Mtetra
.59032 .62939 .59527 .63446 .60493 .63172 .6 .62663 Mtetra
.6 .62663 .60493 .63172 .61461 .62896 .60971 .62385 Mtetra
.60971 .62385 .61461 .62896 .62434 .6262 .61946 .62107 Mtetra
.61946 .62107 .62434 .6262 .63409 .62343 .62924 .61828 Mtetra
.62924 .61828 .63409 .62343 .64388 .62064 .63905 .61548 Mtetra
.63905 .61548 .64388 .62064 .65371 .61785 .6489 .61267 Mtetra
.6489 .61267 .65371 .61785 .66357 .61505 .65878 .60985 Mtetra
.65878 .60985 .66357 .61505 .67346 .61224 .6687 .60702 Mtetra
.6687 .60702 .67346 .61224 .68339 .60942 .67865 .60418 Mtetra
.67865 .60418 .68339 .60942 .69335 .60658 .68864 .60133 Mtetra
.68864 .60133 .69335 .60658 .70335 .60374 .69866 .59847 Mtetra
.69866 .59847 .70335 .60374 .71338 .60089 .70872 .5956 Mtetra
.70872 .5956 .71338 .60089 .72345 .59803 .71881 .59272 Mtetra
.71881 .59272 .72345 .59803 .73356 .59516 .72894 .58983 Mtetra
.72894 .58983 .73356 .59516 .7437 .59227 .73911 .58692 Mtetra
.73911 .58692 .7437 .59227 .75387 .58938 .74931 .58401 Mtetra
.74931 .58401 .75387 .58938 .76409 .58648 .75955 .58109 Mtetra
.75955 .58109 .76409 .58648 .77434 .58356 .76982 .57816 Mtetra
.76982 .57816 .77434 .58356 .78462 .58064 .78014 .57521 Mtetra
.78014 .57521 .78462 .58064 .79495 .57771 .79049 .57226 Mtetra
.79049 .57226 .79495 .57771 .80531 .57476 .80087 .5693 Mtetra
.80087 .5693 .80531 .57476 .81571 .57181 .8113 .56632 Mtetra
.8113 .56632 .81571 .57181 .82614 .56884 .82176 .56334 Mtetra
.82176 .56334 .82614 .56884 .83661 .56586 .83226 .56034 Mtetra
.83226 .56034 .83661 .56586 .84712 .56288 .8428 .55733 Mtetra
.8428 .55733 .84712 .56288 .85767 .55988 .85337 .55431 Mtetra
.85337 .55431 .85767 .55988 .86826 .55687 .86399 .55128 Mtetra
.86399 .55128 .86826 .55687 .87889 .55385 .87464 .54824 Mtetra
.87464 .54824 .87889 .55385 .88955 .55082 .88533 .54519 Mtetra
.88533 .54519 .88955 .55082 .90025 .54777 .89607 .54213 Mtetra
.89607 .54213 .90025 .54777 .911 .54472 .90684 .53905 Mtetra
.90684 .53905 .911 .54472 .92178 .54166 .91765 .53597 Mtetra
.91765 .53597 .92178 .54166 .9326 .53858 .9285 .53287 Mtetra
.9285 .53287 .9326 .53858 .94346 .53549 .93939 .52976 Mtetra
.93939 .52976 .94346 .53549 .95436 .53239 .95032 .52664 Mtetra
.95032 .52664 .95436 .53239 .9653 .52928 .96129 .52351 Mtetra
.96129 .52351 .9653 .52928 .97628 .52616 .9723 .52037 Mtetra
.38018 .68308 .38561 .68781 .39459 .68525 .38918 .6805 Mtetra
.38918 .6805 .39459 .68525 .40359 .68268 .3982 .67791 Mtetra
.3982 .67791 .40359 .68268 .41263 .6801 .40726 .67532 Mtetra
.40726 .67532 .41263 .6801 .4217 .67751 .41635 .67271 Mtetra
.41635 .67271 .4217 .67751 .4308 .67492 .42547 .6701 Mtetra
.42547 .6701 .4308 .67492 .43993 .67231 .43462 .66748 Mtetra
.43462 .66748 .43993 .67231 .44909 .6697 .4438 .66485 Mtetra
.4438 .66485 .44909 .6697 .45828 .66707 .45301 .66221 Mtetra
.45301 .66221 .45828 .66707 .46751 .66444 .46225 .65956 Mtetra
.46225 .65956 .46751 .66444 .47676 .6618 .47153 .6569 Mtetra
.47153 .6569 .47676 .6618 .48605 .65915 .48083 .65423 Mtetra
.48083 .65423 .48605 .65915 .49537 .65649 .49017 .65156 Mtetra
.49017 .65156 .49537 .65649 .50472 .65382 .49954 .64887 Mtetra
.49954 .64887 .50472 .65382 .5141 .65114 .50895 .64618 Mtetra
.50895 .64618 .5141 .65114 .52351 .64846 .51838 .64347 Mtetra
.51838 .64347 .52351 .64846 .53296 .64576 .52785 .64076 Mtetra
.52785 .64076 .53296 .64576 .54244 .64305 .53735 .63804 Mtetra
.53735 .63804 .54244 .64305 .55195 .64034 .54688 .6353 Mtetra
.54688 .6353 .55195 .64034 .56149 .63762 .55645 .63256 Mtetra
.55645 .63256 .56149 .63762 .57107 .63488 .56605 .62981 Mtetra
.56605 .62981 .57107 .63488 .58068 .63214 .57568 .62705 Mtetra
.57568 .62705 .58068 .63214 .59032 .62939 .58535 .62428 Mtetra
.58535 .62428 .59032 .62939 .6 .62663 .59505 .6215 Mtetra
.59505 .6215 .6 .62663 .60971 .62385 .60478 .61871 Mtetra
.60478 .61871 .60971 .62385 .61946 .62107 .61455 .61591 Mtetra
.61455 .61591 .61946 .62107 .62924 .61828 .62435 .6131 Mtetra
.62435 .6131 .62924 .61828 .63905 .61548 .63419 .61028 Mtetra
.63419 .61028 .63905 .61548 .6489 .61267 .64406 .60746 Mtetra
.64406 .60746 .6489 .61267 .65878 .60985 .65396 .60462 Mtetra
.65396 .60462 .65878 .60985 .6687 .60702 .66391 .60177 Mtetra
.66391 .60177 .6687 .60702 .67865 .60418 .67388 .59891 Mtetra
.67388 .59891 .67865 .60418 .68864 .60133 .68389 .59604 Mtetra
.68389 .59604 .68864 .60133 .69866 .59847 .69394 .59316 Mtetra
.69394 .59316 .69866 .59847 .70872 .5956 .70402 .59027 Mtetra
.70402 .59027 .70872 .5956 .71881 .59272 .71414 .58737 Mtetra
.71414 .58737 .71881 .59272 .72894 .58983 .7243 .58446 Mtetra
.7243 .58446 .72894 .58983 .73911 .58692 .73449 .58154 Mtetra
.73449 .58154 .73911 .58692 .74931 .58401 .74472 .57861 Mtetra
.74472 .57861 .74931 .58401 .75955 .58109 .75498 .57567 Mtetra
.75498 .57567 .75955 .58109 .76982 .57816 .76528 .57272 Mtetra
.76528 .57272 .76982 .57816 .78014 .57521 .77562 .56975 Mtetra
.77562 .56975 .78014 .57521 .79049 .57226 .786 .56678 Mtetra
.786 .56678 .79049 .57226 .80087 .5693 .79641 .5638 Mtetra
.79641 .5638 .80087 .5693 .8113 .56632 .80686 .5608 Mtetra
.80686 .5608 .8113 .56632 .82176 .56334 .81735 .55779 Mtetra
.81735 .55779 .82176 .56334 .83226 .56034 .82788 .55478 Mtetra
.82788 .55478 .83226 .56034 .8428 .55733 .83844 .55175 Mtetra
.83844 .55175 .8428 .55733 .85337 .55431 .84905 .54871 Mtetra
.84905 .54871 .85337 .55431 .86399 .55128 .85969 .54566 Mtetra
.85969 .54566 .86399 .55128 .87464 .54824 .87037 .5426 Mtetra
.87037 .5426 .87464 .54824 .88533 .54519 .88109 .53953 Mtetra
.88109 .53953 .88533 .54519 .89607 .54213 .89185 .53644 Mtetra
.89185 .53644 .89607 .54213 .90684 .53905 .90265 .53335 Mtetra
.90265 .53335 .90684 .53905 .91765 .53597 .91349 .53024 Mtetra
.91349 .53024 .91765 .53597 .9285 .53287 .92437 .52712 Mtetra
.92437 .52712 .9285 .53287 .93939 .52976 .93529 .524 Mtetra
.93529 .524 .93939 .52976 .95032 .52664 .94625 .52085 Mtetra
.94625 .52085 .95032 .52664 .96129 .52351 .95725 .5177 Mtetra
.95725 .5177 .96129 .52351 .9723 .52037 .96829 .51454 Mtetra
.37472 .67831 .38018 .68308 .38918 .6805 .38373 .67572 Mtetra
.38373 .67572 .38918 .6805 .3982 .67791 .39278 .67311 Mtetra
.39278 .67311 .3982 .67791 .40726 .67532 .40186 .6705 Mtetra
.40186 .6705 .40726 .67532 .41635 .67271 .41096 .66788 Mtetra
.41096 .66788 .41635 .67271 .42547 .6701 .4201 .66525 Mtetra
.4201 .66525 .42547 .6701 .43462 .66748 .42927 .66261 Mtetra
.42927 .66261 .43462 .66748 .4438 .66485 .43847 .65996 Mtetra
.43847 .65996 .4438 .66485 .45301 .66221 .4477 .65731 Mtetra
.4477 .65731 .45301 .66221 .46225 .65956 .45697 .65464 Mtetra
.45697 .65464 .46225 .65956 .47153 .6569 .46626 .65197 Mtetra
.46626 .65197 .47153 .6569 .48083 .65423 .47559 .64928 Mtetra
.47559 .64928 .48083 .65423 .49017 .65156 .48495 .64659 Mtetra
.48495 .64659 .49017 .65156 .49954 .64887 .49434 .64389 Mtetra
.49434 .64389 .49954 .64887 .50895 .64618 .50376 .64118 Mtetra
.50376 .64118 .50895 .64618 .51838 .64347 .51322 .63846 Mtetra
.51322 .63846 .51838 .64347 .52785 .64076 .52271 .63572 Mtetra
.52271 .63572 .52785 .64076 .53735 .63804 .53223 .63298 Mtetra
.53223 .63298 .53735 .63804 .54688 .6353 .54178 .63024 Mtetra
.54178 .63024 .54688 .6353 .55645 .63256 .55137 .62748 Mtetra
.55137 .62748 .55645 .63256 .56605 .62981 .56099 .62471 Mtetra
.56099 .62471 .56605 .62981 .57568 .62705 .57065 .62193 Mtetra
.57065 .62193 .57568 .62705 .58535 .62428 .58034 .61914 Mtetra
.58034 .61914 .58535 .62428 .59505 .6215 .59006 .61634 Mtetra
.59006 .61634 .59505 .6215 .60478 .61871 .59982 .61354 Mtetra
.59982 .61354 .60478 .61871 .61455 .61591 .60961 .61072 Mtetra
.60961 .61072 .61455 .61591 .62435 .6131 .61943 .60789 Mtetra
.61943 .60789 .62435 .6131 .63419 .61028 .62929 .60505 Mtetra
.62929 .60505 .63419 .61028 .64406 .60746 .63919 .60221 Mtetra
.63919 .60221 .64406 .60746 .65396 .60462 .64912 .59935 Mtetra
.64912 .59935 .65396 .60462 .66391 .60177 .65908 .59648 Mtetra
.65908 .59648 .66391 .60177 .67388 .59891 .66908 .5936 Mtetra
.66908 .5936 .67388 .59891 .68389 .59604 .67912 .59072 Mtetra
.67912 .59072 .68389 .59604 .69394 .59316 .68919 .58782 Mtetra
.68919 .58782 .69394 .59316 .70402 .59027 .6993 .58491 Mtetra
.6993 .58491 .70402 .59027 .71414 .58737 .70944 .58199 Mtetra
.70944 .58199 .71414 .58737 .7243 .58446 .71962 .57906 Mtetra
.71962 .57906 .7243 .58446 .73449 .58154 .72984 .57612 Mtetra
.72984 .57612 .73449 .58154 .74472 .57861 .74009 .57317 Mtetra
.74009 .57317 .74472 .57861 .75498 .57567 .75038 .57021 Mtetra
.75038 .57021 .75498 .57567 .76528 .57272 .76071 .56724 Mtetra
.76071 .56724 .76528 .57272 .77562 .56975 .77107 .56426 Mtetra
.77107 .56426 .77562 .56975 .786 .56678 .78148 .56126 Mtetra
.78148 .56126 .786 .56678 .79641 .5638 .79192 .55826 Mtetra
.79192 .55826 .79641 .5638 .80686 .5608 .80239 .55524 Mtetra
.80239 .55524 .80686 .5608 .81735 .55779 .81291 .55222 Mtetra
.81291 .55222 .81735 .55779 .82788 .55478 .82346 .54918 Mtetra
.82346 .54918 .82788 .55478 .83844 .55175 .83406 .54613 Mtetra
.83406 .54613 .83844 .55175 .84905 .54871 .84469 .54307 Mtetra
.84469 .54307 .84905 .54871 .85969 .54566 .85536 .54 Mtetra
.85536 .54 .85969 .54566 .87037 .5426 .86607 .53692 Mtetra
.86607 .53692 .87037 .5426 .88109 .53953 .87682 .53383 Mtetra
.87682 .53383 .88109 .53953 .89185 .53644 .88761 .53072 Mtetra
.88761 .53072 .89185 .53644 .90265 .53335 .89844 .52761 Mtetra
.89844 .52761 .90265 .53335 .91349 .53024 .90931 .52448 Mtetra
.90931 .52448 .91349 .53024 .92437 .52712 .92022 .52134 Mtetra
.92022 .52134 .92437 .52712 .93529 .524 .93116 .51819 Mtetra
.93116 .51819 .93529 .524 .94625 .52085 .94216 .51503 Mtetra
.94216 .51503 .94625 .52085 .95725 .5177 .95319 .51185 Mtetra
.95319 .51185 .95725 .5177 .96829 .51454 .96426 .50866 Mtetra
.36922 .67351 .37472 .67831 .38373 .67572 .37826 .6709 Mtetra
.37826 .6709 .38373 .67572 .39278 .67311 .38732 .66828 Mtetra
.38732 .66828 .39278 .67311 .40186 .6705 .39642 .66566 Mtetra
.39642 .66566 .40186 .6705 .41096 .66788 .40554 .66302 Mtetra
.40554 .66302 .41096 .66788 .4201 .66525 .4147 .66037 Mtetra
.4147 .66037 .4201 .66525 .42927 .66261 .42389 .65772 Mtetra
.42389 .65772 .42927 .66261 .43847 .65996 .43311 .65505 Mtetra
.43311 .65505 .43847 .65996 .4477 .65731 .44236 .65238 Mtetra
.44236 .65238 .4477 .65731 .45697 .65464 .45165 .6497 Mtetra
.45165 .6497 .45697 .65464 .46626 .65197 .46096 .64701 Mtetra
.46096 .64701 .46626 .65197 .47559 .64928 .47031 .6443 Mtetra
.47031 .6443 .47559 .64928 .48495 .64659 .47969 .64159 Mtetra
.47969 .64159 .48495 .64659 .49434 .64389 .4891 .63887 Mtetra
.4891 .63887 .49434 .64389 .50376 .64118 .49855 .63615 Mtetra
.49855 .63615 .50376 .64118 .51322 .63846 .50802 .63341 Mtetra
.50802 .63341 .51322 .63846 .52271 .63572 .51753 .63066 Mtetra
.51753 .63066 .52271 .63572 .53223 .63298 .52708 .6279 Mtetra
.52708 .6279 .53223 .63298 .54178 .63024 .53665 .62513 Mtetra
.53665 .62513 .54178 .63024 .55137 .62748 .54626 .62236 Mtetra
.54626 .62236 .55137 .62748 .56099 .62471 .55591 .61957 Mtetra
.55591 .61957 .56099 .62471 .57065 .62193 .56558 .61677 Mtetra
.56558 .61677 .57065 .62193 .58034 .61914 .57529 .61397 Mtetra
.57529 .61397 .58034 .61914 .59006 .61634 .58504 .61115 Mtetra
.58504 .61115 .59006 .61634 .59982 .61354 .59482 .60833 Mtetra
.59482 .60833 .59982 .61354 .60961 .61072 .60463 .60549 Mtetra
.60463 .60549 .60961 .61072 .61943 .60789 .61448 .60265 Mtetra
.61448 .60265 .61943 .60789 .62929 .60505 .62437 .59979 Mtetra
.62437 .59979 .62929 .60505 .63919 .60221 .63428 .59692 Mtetra
.63428 .59692 .63919 .60221 .64912 .59935 .64424 .59405 Mtetra
.64424 .59405 .64912 .59935 .65908 .59648 .65423 .59116 Mtetra
.65423 .59116 .65908 .59648 .66908 .5936 .66425 .58826 Mtetra
.66425 .58826 .66908 .5936 .67912 .59072 .67431 .58536 Mtetra
.67431 .58536 .67912 .59072 .68919 .58782 .68441 .58244 Mtetra
.68441 .58244 .68919 .58782 .6993 .58491 .69454 .57951 Mtetra
.69454 .57951 .6993 .58491 .70944 .58199 .70471 .57657 Mtetra
.70471 .57657 .70944 .58199 .71962 .57906 .71491 .57363 Mtetra
.71491 .57363 .71962 .57906 .72984 .57612 .72516 .57067 Mtetra
.72516 .57067 .72984 .57612 .74009 .57317 .73544 .5677 Mtetra
.73544 .5677 .74009 .57317 .75038 .57021 .74575 .56471 Mtetra
.74575 .56471 .75038 .57021 .76071 .56724 .75611 .56172 Mtetra
.75611 .56172 .76071 .56724 .77107 .56426 .7665 .55872 Mtetra
.7665 .55872 .77107 .56426 .78148 .56126 .77693 .55571 Mtetra
.77693 .55571 .78148 .56126 .79192 .55826 .78739 .55268 Mtetra
.78739 .55268 .79192 .55826 .80239 .55524 .7979 .54965 Mtetra
.7979 .54965 .80239 .55524 .81291 .55222 .80844 .5466 Mtetra
.80844 .5466 .81291 .55222 .82346 .54918 .81902 .54354 Mtetra
.81902 .54354 .82346 .54918 .83406 .54613 .82964 .54047 Mtetra
.82964 .54047 .83406 .54613 .84469 .54307 .8403 .53739 Mtetra
.8403 .53739 .84469 .54307 .85536 .54 .851 .5343 Mtetra
.851 .5343 .85536 .54 .86607 .53692 .86174 .5312 Mtetra
.86174 .5312 .86607 .53692 .87682 .53383 .87252 .52809 Mtetra
.87252 .52809 .87682 .53383 .88761 .53072 .88334 .52496 Mtetra
.88334 .52496 .88761 .53072 .89844 .52761 .89419 .52182 Mtetra
.89419 .52182 .89844 .52761 .90931 .52448 .90509 .51867 Mtetra
.90509 .51867 .90931 .52448 .92022 .52134 .91603 .51551 Mtetra
.91603 .51551 .92022 .52134 .93116 .51819 .92701 .51234 Mtetra
.92701 .51234 .93116 .51819 .94216 .51503 .93803 .50916 Mtetra
.93803 .50916 .94216 .51503 .95319 .51185 .94909 .50596 Mtetra
.94909 .50596 .95319 .51185 .96426 .50866 .9602 .50275 Mtetra
.36369 .66869 .36922 .67351 .37826 .6709 .37275 .66606 Mtetra
.37275 .66606 .37826 .6709 .38732 .66828 .38183 .66342 Mtetra
.38183 .66342 .38732 .66828 .39642 .66566 .39094 .66078 Mtetra
.39094 .66078 .39642 .66566 .40554 .66302 .40009 .65813 Mtetra
.40009 .65813 .40554 .66302 .4147 .66037 .40927 .65546 Mtetra
.40927 .65546 .4147 .66037 .42389 .65772 .41848 .65279 Mtetra
.41848 .65279 .42389 .65772 .43311 .65505 .42772 .65011 Mtetra
.42772 .65011 .43311 .65505 .44236 .65238 .43699 .64742 Mtetra
.43699 .64742 .44236 .65238 .45165 .6497 .44629 .64472 Mtetra
.44629 .64472 .45165 .6497 .46096 .64701 .45563 .64201 Mtetra
.45563 .64201 .46096 .64701 .47031 .6443 .465 .63929 Mtetra
.465 .63929 .47031 .6443 .47969 .64159 .4744 .63657 Mtetra
.4744 .63657 .47969 .64159 .4891 .63887 .48383 .63383 Mtetra
.48383 .63383 .4891 .63887 .49855 .63615 .4933 .63108 Mtetra
.4933 .63108 .49855 .63615 .50802 .63341 .50279 .62833 Mtetra
.50279 .62833 .50802 .63341 .51753 .63066 .51233 .62556 Mtetra
.51233 .62556 .51753 .63066 .52708 .6279 .52189 .62279 Mtetra
.52189 .62279 .52708 .6279 .53665 .62513 .53149 .62 Mtetra
.53149 .62 .53665 .62513 .54626 .62236 .54112 .61721 Mtetra
.54112 .61721 .54626 .62236 .55591 .61957 .55079 .6144 Mtetra
.55079 .6144 .55591 .61957 .56558 .61677 .56049 .61159 Mtetra
.56049 .61159 .56558 .61677 .57529 .61397 .57022 .60876 Mtetra
.57022 .60876 .57529 .61397 .58504 .61115 .57999 .60593 Mtetra
.57999 .60593 .58504 .61115 .59482 .60833 .58979 .60308 Mtetra
.58979 .60308 .59482 .60833 .60463 .60549 .59963 .60023 Mtetra
.59963 .60023 .60463 .60549 .61448 .60265 .6095 .59737 Mtetra
.6095 .59737 .61448 .60265 .62437 .59979 .61941 .59449 Mtetra
.61941 .59449 .62437 .59979 .63428 .59692 .62935 .59161 Mtetra
.62935 .59161 .63428 .59692 .64424 .59405 .63933 .58871 Mtetra
.63933 .58871 .64424 .59405 .65423 .59116 .64934 .58581 Mtetra
.64934 .58581 .65423 .59116 .66425 .58826 .65939 .58289 Mtetra
.65939 .58289 .66425 .58826 .67431 .58536 .66947 .57996 Mtetra
.66947 .57996 .67431 .58536 .68441 .58244 .67959 .57703 Mtetra
.67959 .57703 .68441 .58244 .69454 .57951 .68975 .57408 Mtetra
.68975 .57408 .69454 .57951 .70471 .57657 .69995 .57112 Mtetra
.69995 .57112 .70471 .57657 .71491 .57363 .71018 .56815 Mtetra
.71018 .56815 .71491 .57363 .72516 .57067 .72044 .56517 Mtetra
.72044 .56517 .72516 .57067 .73544 .5677 .73075 .56218 Mtetra
.73075 .56218 .73544 .5677 .74575 .56471 .74109 .55918 Mtetra
.74109 .55918 .74575 .56471 .75611 .56172 .75147 .55617 Mtetra
.75147 .55617 .75611 .56172 .7665 .55872 .76189 .55315 Mtetra
.76189 .55315 .7665 .55872 .77693 .55571 .77234 .55012 Mtetra
.77234 .55012 .77693 .55571 .78739 .55268 .78284 .54707 Mtetra
.78284 .54707 .78739 .55268 .7979 .54965 .79337 .54401 Mtetra
.79337 .54401 .7979 .54965 .80844 .5466 .80394 .54095 Mtetra
.80394 .54095 .80844 .5466 .81902 .54354 .81455 .53787 Mtetra
.81455 .53787 .81902 .54354 .82964 .54047 .8252 .53478 Mtetra
.8252 .53478 .82964 .54047 .8403 .53739 .83589 .53168 Mtetra
.83589 .53168 .8403 .53739 .851 .5343 .84661 .52857 Mtetra
.84661 .52857 .851 .5343 .86174 .5312 .85738 .52544 Mtetra
.85738 .52544 .86174 .5312 .87252 .52809 .86819 .52231 Mtetra
.86819 .52231 .87252 .52809 .88334 .52496 .87903 .51916 Mtetra
.87903 .51916 .88334 .52496 .89419 .52182 .88992 .516 Mtetra
.88992 .516 .89419 .52182 .90509 .51867 .90085 .51283 Mtetra
.90085 .51283 .90509 .51867 .91603 .51551 .91182 .50965 Mtetra
.91182 .50965 .91603 .51551 .92701 .51234 .92283 .50645 Mtetra
.92283 .50645 .92701 .51234 .93803 .50916 .93388 .50324 Mtetra
.93388 .50324 .93803 .50916 .94909 .50596 .94497 .50003 Mtetra
.94497 .50003 .94909 .50596 .9602 .50275 .9561 .4968 Mtetra
.35813 .66383 .36369 .66869 .37275 .66606 .3672 .66119 Mtetra
.3672 .66119 .37275 .66606 .38183 .66342 .3763 .65854 Mtetra
.3763 .65854 .38183 .66342 .39094 .66078 .38544 .65587 Mtetra
.38544 .65587 .39094 .66078 .40009 .65813 .3946 .6532 Mtetra
.3946 .6532 .40009 .65813 .40927 .65546 .4038 .65052 Mtetra
.4038 .65052 .40927 .65546 .41848 .65279 .41303 .64783 Mtetra
.41303 .64783 .41848 .65279 .42772 .65011 .42229 .64514 Mtetra
.42229 .64514 .42772 .65011 .43699 .64742 .43158 .64243 Mtetra
.43158 .64243 .43699 .64742 .44629 .64472 .4409 .63971 Mtetra
.4409 .63971 .44629 .64472 .45563 .64201 .45026 .63699 Mtetra
.45026 .63699 .45563 .64201 .465 .63929 .45965 .63425 Mtetra
.45965 .63425 .465 .63929 .4744 .63657 .46907 .63151 Mtetra
.46907 .63151 .4744 .63657 .48383 .63383 .47853 .62875 Mtetra
.47853 .62875 .48383 .63383 .4933 .63108 .48801 .62599 Mtetra
.48801 .62599 .4933 .63108 .50279 .62833 .49753 .62321 Mtetra
.49753 .62321 .50279 .62833 .51233 .62556 .50709 .62043 Mtetra
.50709 .62043 .51233 .62556 .52189 .62279 .51667 .61764 Mtetra
.51667 .61764 .52189 .62279 .53149 .62 .52629 .61483 Mtetra
.52629 .61483 .53149 .62 .54112 .61721 .53595 .61202 Mtetra
.53595 .61202 .54112 .61721 .55079 .6144 .54563 .6092 Mtetra
.54563 .6092 .55079 .6144 .56049 .61159 .55536 .60636 Mtetra
.55536 .60636 .56049 .61159 .57022 .60876 .56511 .60352 Mtetra
.56511 .60352 .57022 .60876 .57999 .60593 .5749 .60067 Mtetra
.5749 .60067 .57999 .60593 .58979 .60308 .58473 .59781 Mtetra
.58473 .59781 .58979 .60308 .59963 .60023 .59459 .59493 Mtetra
.59459 .59493 .59963 .60023 .6095 .59737 .60448 .59205 Mtetra
.60448 .59205 .6095 .59737 .61941 .59449 .61441 .58916 Mtetra
.61441 .58916 .61941 .59449 .62935 .59161 .62438 .58625 Mtetra
.62438 .58625 .62935 .59161 .63933 .58871 .63438 .58334 Mtetra
.63438 .58334 .63933 .58871 .64934 .58581 .64442 .58041 Mtetra
.64442 .58041 .64934 .58581 .65939 .58289 .65449 .57748 Mtetra
.65449 .57748 .65939 .58289 .66947 .57996 .6646 .57453 Mtetra
.6646 .57453 .66947 .57996 .67959 .57703 .67475 .57158 Mtetra
.67475 .57158 .67959 .57703 .68975 .57408 .68493 .56861 Mtetra
.68493 .56861 .68975 .57408 .69995 .57112 .69515 .56563 Mtetra
.69515 .56563 .69995 .57112 .71018 .56815 .70541 .56264 Mtetra
.70541 .56264 .71018 .56815 .72044 .56517 .7157 .55965 Mtetra
.7157 .55965 .72044 .56517 .73075 .56218 .72603 .55664 Mtetra
.72603 .55664 .73075 .56218 .74109 .55918 .7364 .55361 Mtetra
.7364 .55361 .74109 .55918 .75147 .55617 .7468 .55058 Mtetra
.7468 .55058 .75147 .55617 .76189 .55315 .75725 .54754 Mtetra
.75725 .54754 .76189 .55315 .77234 .55012 .76773 .54449 Mtetra
.76773 .54449 .77234 .55012 .78284 .54707 .77825 .54142 Mtetra
.77825 .54142 .78284 .54707 .79337 .54401 .78881 .53834 Mtetra
.78881 .53834 .79337 .54401 .80394 .54095 .79941 .53526 Mtetra
.79941 .53526 .80394 .54095 .81455 .53787 .81005 .53216 Mtetra
.81005 .53216 .81455 .53787 .8252 .53478 .82072 .52905 Mtetra
.82072 .52905 .8252 .53478 .83589 .53168 .83144 .52592 Mtetra
.83144 .52592 .83589 .53168 .84661 .52857 .84219 .52279 Mtetra
.84219 .52279 .84661 .52857 .85738 .52544 .85299 .51964 Mtetra
.85299 .51964 .85738 .52544 .86819 .52231 .86383 .51649 Mtetra
.86383 .51649 .86819 .52231 .87903 .51916 .8747 .51332 Mtetra
.8747 .51332 .87903 .51916 .88992 .516 .88562 .51014 Mtetra
.88562 .51014 .88992 .516 .90085 .51283 .89658 .50694 Mtetra
.89658 .50694 .90085 .51283 .91182 .50965 .90758 .50374 Mtetra
.90758 .50374 .91182 .50965 .92283 .50645 .91862 .50052 Mtetra
.91862 .50052 .92283 .50645 .93388 .50324 .9297 .49729 Mtetra
.9297 .49729 .93388 .50324 .94497 .50003 .94082 .49405 Mtetra
.94082 .49405 .94497 .50003 .9561 .4968 .95198 .4908 Mtetra
.35253 .65894 .35813 .66383 .3672 .66119 .36162 .65628 Mtetra
.36162 .65628 .3672 .66119 .3763 .65854 .37074 .65361 Mtetra
.37074 .65361 .3763 .65854 .38544 .65587 .3799 .65094 Mtetra
.3799 .65094 .38544 .65587 .3946 .6532 .38908 .64825 Mtetra
.38908 .64825 .3946 .6532 .4038 .65052 .3983 .64555 Mtetra
.3983 .64555 .4038 .65052 .41303 .64783 .40755 .64285 Mtetra
.40755 .64285 .41303 .64783 .42229 .64514 .41683 .64013 Mtetra
.41683 .64013 .42229 .64514 .43158 .64243 .42614 .63741 Mtetra
.42614 .63741 .43158 .64243 .4409 .63971 .43548 .63467 Mtetra
.43548 .63467 .4409 .63971 .45026 .63699 .44486 .63193 Mtetra
.44486 .63193 .45026 .63699 .45965 .63425 .45427 .62918 Mtetra
.45427 .62918 .45965 .63425 .46907 .63151 .46371 .62641 Mtetra
.46371 .62641 .46907 .63151 .47853 .62875 .47319 .62364 Mtetra
.47319 .62364 .47853 .62875 .48801 .62599 .48269 .62086 Mtetra
.48269 .62086 .48801 .62599 .49753 .62321 .49224 .61807 Mtetra
.49224 .61807 .49753 .62321 .50709 .62043 .50181 .61527 Mtetra
.50181 .61527 .50709 .62043 .51667 .61764 .51142 .61245 Mtetra
.51142 .61245 .51667 .61764 .52629 .61483 .52106 .60963 Mtetra
.52106 .60963 .52629 .61483 .53595 .61202 .53074 .6068 Mtetra
.53074 .6068 .53595 .61202 .54563 .6092 .54045 .60396 Mtetra
.54045 .60396 .54563 .6092 .55536 .60636 .55019 .60111 Mtetra
.55019 .60111 .55536 .60636 .56511 .60352 .55997 .59825 Mtetra
.55997 .59825 .56511 .60352 .5749 .60067 .56978 .59538 Mtetra
.56978 .59538 .5749 .60067 .58473 .59781 .57963 .59249 Mtetra
.57963 .59249 .58473 .59781 .59459 .59493 .58952 .5896 Mtetra
.58952 .5896 .59459 .59493 .60448 .59205 .59944 .5867 Mtetra
.59944 .5867 .60448 .59205 .61441 .58916 .60939 .58379 Mtetra
.60939 .58379 .61441 .58916 .62438 .58625 .61938 .58087 Mtetra
.61938 .58087 .62438 .58625 .63438 .58334 .62941 .57793 Mtetra
.62941 .57793 .63438 .58334 .64442 .58041 .63947 .57499 Mtetra
.63947 .57499 .64442 .58041 .65449 .57748 .64957 .57203 Mtetra
.64957 .57203 .65449 .57748 .6646 .57453 .6597 .56907 Mtetra
.6597 .56907 .6646 .57453 .67475 .57158 .66987 .56609 Mtetra
.66987 .56609 .67475 .57158 .68493 .56861 .68008 .56311 Mtetra
.68008 .56311 .68493 .56861 .69515 .56563 .69032 .56011 Mtetra
.69032 .56011 .69515 .56563 .70541 .56264 .7006 .5571 Mtetra
.7006 .5571 .70541 .56264 .7157 .55965 .71092 .55408 Mtetra
.71092 .55408 .7157 .55965 .72603 .55664 .72128 .55105 Mtetra
.72128 .55105 .72603 .55664 .7364 .55361 .73168 .54801 Mtetra
.73168 .54801 .7364 .55361 .7468 .55058 .74211 .54496 Mtetra
.74211 .54496 .7468 .55058 .75725 .54754 .75258 .54189 Mtetra
.75258 .54189 .75725 .54754 .76773 .54449 .76309 .53882 Mtetra
.76309 .53882 .76773 .54449 .77825 .54142 .77364 .53573 Mtetra
.77364 .53573 .77825 .54142 .78881 .53834 .78422 .53263 Mtetra
.78422 .53263 .78881 .53834 .79941 .53526 .79485 .52952 Mtetra
.79485 .52952 .79941 .53526 .81005 .53216 .80551 .5264 Mtetra
.80551 .5264 .81005 .53216 .82072 .52905 .81622 .52327 Mtetra
.81622 .52327 .82072 .52905 .83144 .52592 .82696 .52013 Mtetra
.82696 .52013 .83144 .52592 .84219 .52279 .83775 .51697 Mtetra
.83775 .51697 .84219 .52279 .85299 .51964 .84857 .51381 Mtetra
.84857 .51381 .85299 .51964 .86383 .51649 .85944 .51063 Mtetra
.85944 .51063 .86383 .51649 .8747 .51332 .87034 .50744 Mtetra
.87034 .50744 .8747 .51332 .88562 .51014 .88129 .50423 Mtetra
.88129 .50423 .88562 .51014 .89658 .50694 .89227 .50102 Mtetra
.89227 .50102 .89658 .50694 .90758 .50374 .9033 .49779 Mtetra
.9033 .49779 .90758 .50374 .91862 .50052 .91437 .49455 Mtetra
.91437 .49455 .91862 .50052 .9297 .49729 .92549 .4913 Mtetra
.92549 .4913 .9297 .49729 .94082 .49405 .93664 .48804 Mtetra
.93664 .48804 .94082 .49405 .95198 .4908 .94784 .48476 Mtetra
.34689 .65403 .35253 .65894 .36162 .65628 .356 .65135 Mtetra
.356 .65135 .36162 .65628 .37074 .65361 .36515 .64866 Mtetra
.36515 .64866 .37074 .65361 .3799 .65094 .37432 .64597 Mtetra
.37432 .64597 .3799 .65094 .38908 .64825 .38352 .64326 Mtetra
.38352 .64326 .38908 .64825 .3983 .64555 .39276 .64055 Mtetra
.39276 .64055 .3983 .64555 .40755 .64285 .40203 .63783 Mtetra
.40203 .63783 .40755 .64285 .41683 .64013 .41133 .63509 Mtetra
.41133 .63509 .41683 .64013 .42614 .63741 .42066 .63235 Mtetra
.42066 .63235 .42614 .63741 .43548 .63467 .43003 .6296 Mtetra
.43003 .6296 .43548 .63467 .44486 .63193 .43942 .62684 Mtetra
.43942 .62684 .44486 .63193 .45427 .62918 .44885 .62407 Mtetra
.44885 .62407 .45427 .62918 .46371 .62641 .45832 .62129 Mtetra
.45832 .62129 .46371 .62641 .47319 .62364 .46781 .6185 Mtetra
.46781 .6185 .47319 .62364 .48269 .62086 .47734 .6157 Mtetra
.47734 .6157 .48269 .62086 .49224 .61807 .4869 .61289 Mtetra
.4869 .61289 .49224 .61807 .50181 .61527 .4965 .61007 Mtetra
.4965 .61007 .50181 .61527 .51142 .61245 .50613 .60724 Mtetra
.50613 .60724 .51142 .61245 .52106 .60963 .5158 .6044 Mtetra
.5158 .6044 .52106 .60963 .53074 .6068 .52549 .60155 Mtetra
.52549 .60155 .53074 .6068 .54045 .60396 .53523 .59869 Mtetra
.53523 .59869 .54045 .60396 .55019 .60111 .54499 .59582 Mtetra
.54499 .59582 .55019 .60111 .55997 .59825 .5548 .59294 Mtetra
.5548 .59294 .55997 .59825 .56978 .59538 .56463 .59005 Mtetra
.56463 .59005 .56978 .59538 .57963 .59249 .5745 .58715 Mtetra
.5745 .58715 .57963 .59249 .58952 .5896 .58441 .58424 Mtetra
.58441 .58424 .58952 .5896 .59944 .5867 .59435 .58132 Mtetra
.59435 .58132 .59944 .5867 .60939 .58379 .60433 .57838 Mtetra
.60433 .57838 .60939 .58379 .61938 .58087 .61435 .57544 Mtetra
.61435 .57544 .61938 .58087 .62941 .57793 .6244 .57249 Mtetra
.6244 .57249 .62941 .57793 .63947 .57499 .63448 .56952 Mtetra
.63448 .56952 .63947 .57499 .64957 .57203 .6446 .56655 Mtetra
.6446 .56655 .64957 .57203 .6597 .56907 .65476 .56357 Mtetra
.65476 .56357 .6597 .56907 .66987 .56609 .66496 .56057 Mtetra
.66496 .56057 .66987 .56609 .68008 .56311 .67519 .55756 Mtetra
.67519 .55756 .68008 .56311 .69032 .56011 .68546 .55455 Mtetra
.68546 .55455 .69032 .56011 .7006 .5571 .69577 .55152 Mtetra
.69577 .55152 .7006 .5571 .71092 .55408 .70612 .54848 Mtetra
.70612 .54848 .71092 .55408 .72128 .55105 .7165 .54543 Mtetra
.7165 .54543 .72128 .55105 .73168 .54801 .72692 .54236 Mtetra
.72692 .54236 .73168 .54801 .74211 .54496 .73738 .53929 Mtetra
.73738 .53929 .74211 .54496 .75258 .54189 .74788 .53621 Mtetra
.74788 .53621 .75258 .54189 .76309 .53882 .75841 .53311 Mtetra
.75841 .53311 .76309 .53882 .77364 .53573 .76899 .53 Mtetra
.76899 .53 .77364 .53573 .78422 .53263 .7796 .52688 Mtetra
.7796 .52688 .78422 .53263 .79485 .52952 .79026 .52375 Mtetra
.79026 .52375 .79485 .52952 .80551 .5264 .80095 .52061 Mtetra
.80095 .52061 .80551 .5264 .81622 .52327 .81168 .51746 Mtetra
.81168 .51746 .81622 .52327 .82696 .52013 .82245 .51429 Mtetra
.82245 .51429 .82696 .52013 .83775 .51697 .83327 .51112 Mtetra
.83327 .51112 .83775 .51697 .84857 .51381 .84412 .50793 Mtetra
.84412 .50793 .84857 .51381 .85944 .51063 .85501 .50473 Mtetra
.85501 .50473 .85944 .51063 .87034 .50744 .86595 .50151 Mtetra
.86595 .50151 .87034 .50744 .88129 .50423 .87693 .49829 Mtetra
.87693 .49829 .88129 .50423 .89227 .50102 .88794 .49505 Mtetra
.88794 .49505 .89227 .50102 .9033 .49779 .899 .4918 Mtetra
.899 .4918 .9033 .49779 .91437 .49455 .9101 .48854 Mtetra
.9101 .48854 .91437 .49455 .92549 .4913 .92125 .48527 Mtetra
.92125 .48527 .92549 .4913 .93664 .48804 .93243 .48198 Mtetra
.93243 .48198 .93664 .48804 .94784 .48476 .94366 .47868 Mtetra
.34122 .64908 .34689 .65403 .356 .65135 .35035 .64638 Mtetra
.35035 .64638 .356 .65135 .36515 .64866 .35951 .64368 Mtetra
.35951 .64368 .36515 .64866 .37432 .64597 .36871 .64097 Mtetra
.36871 .64097 .37432 .64597 .38352 .64326 .37793 .63825 Mtetra
.37793 .63825 .38352 .64326 .39276 .64055 .38719 .63551 Mtetra
.38719 .63551 .39276 .64055 .40203 .63783 .39647 .63277 Mtetra
.39647 .63277 .40203 .63783 .41133 .63509 .40579 .63002 Mtetra
.40579 .63002 .41133 .63509 .42066 .63235 .41515 .62726 Mtetra
.41515 .62726 .42066 .63235 .43003 .6296 .42453 .62449 Mtetra
.42453 .62449 .43003 .6296 .43942 .62684 .43395 .62172 Mtetra
.43395 .62172 .43942 .62684 .44885 .62407 .4434 .61893 Mtetra
.4434 .61893 .44885 .62407 .45832 .62129 .45289 .61613 Mtetra
.45289 .61613 .45832 .62129 .46781 .6185 .4624 .61332 Mtetra
.4624 .61332 .46781 .6185 .47734 .6157 .47195 .6105 Mtetra
.47195 .6105 .47734 .6157 .4869 .61289 .48154 .60767 Mtetra
.48154 .60767 .4869 .61289 .4965 .61007 .49116 .60484 Mtetra
.49116 .60484 .4965 .61007 .50613 .60724 .50081 .60199 Mtetra
.50081 .60199 .50613 .60724 .5158 .6044 .5105 .59913 Mtetra
.5105 .59913 .5158 .6044 .52549 .60155 .52022 .59626 Mtetra
.52022 .59626 .52549 .60155 .53523 .59869 .52997 .59338 Mtetra
.52997 .59338 .53523 .59869 .54499 .59582 .53976 .59049 Mtetra
.53976 .59049 .54499 .59582 .5548 .59294 .54959 .58759 Mtetra
.54959 .58759 .5548 .59294 .56463 .59005 .55945 .58469 Mtetra
.55945 .58469 .56463 .59005 .5745 .58715 .56934 .58177 Mtetra
.56934 .58177 .5745 .58715 .58441 .58424 .57927 .57884 Mtetra
.57927 .57884 .58441 .58424 .59435 .58132 .58924 .57589 Mtetra
.58924 .57589 .59435 .58132 .60433 .57838 .59924 .57294 Mtetra
.59924 .57294 .60433 .57838 .61435 .57544 .60928 .56998 Mtetra
.60928 .56998 .61435 .57544 .6244 .57249 .61935 .56701 Mtetra
.61935 .56701 .6244 .57249 .63448 .56952 .62946 .56403 Mtetra
.62946 .56403 .63448 .56952 .6446 .56655 .63961 .56103 Mtetra
.63961 .56103 .6446 .56655 .65476 .56357 .64979 .55803 Mtetra
.64979 .55803 .65476 .56357 .66496 .56057 .66002 .55501 Mtetra
.66002 .55501 .66496 .56057 .67519 .55756 .67027 .55198 Mtetra
.67027 .55198 .67519 .55756 .68546 .55455 .68057 .54895 Mtetra
.68057 .54895 .68546 .55455 .69577 .55152 .6909 .5459 Mtetra
.6909 .5459 .69577 .55152 .70612 .54848 .70127 .54284 Mtetra
.70127 .54284 .70612 .54848 .7165 .54543 .71168 .53976 Mtetra
.71168 .53976 .7165 .54543 .72692 .54236 .72213 .53668 Mtetra
.72213 .53668 .72692 .54236 .73738 .53929 .73262 .53359 Mtetra
.73262 .53359 .73738 .53929 .74788 .53621 .74314 .53048 Mtetra
.74314 .53048 .74788 .53621 .75841 .53311 .75371 .52737 Mtetra
.75371 .52737 .75841 .53311 .76899 .53 .76431 .52424 Mtetra
.76431 .52424 .76899 .53 .7796 .52688 .77495 .5211 Mtetra
.77495 .5211 .7796 .52688 .79026 .52375 .78563 .51794 Mtetra
.78563 .51794 .79026 .52375 .80095 .52061 .79635 .51478 Mtetra
.79635 .51478 .80095 .52061 .81168 .51746 .80711 .51161 Mtetra
.80711 .51161 .81168 .51746 .82245 .51429 .81792 .50842 Mtetra
.81792 .50842 .82245 .51429 .83327 .51112 .82876 .50522 Mtetra
.82876 .50522 .83327 .51112 .84412 .50793 .83964 .50201 Mtetra
.83964 .50201 .84412 .50793 .85501 .50473 .85056 .49879 Mtetra
.85056 .49879 .85501 .50473 .86595 .50151 .86153 .49555 Mtetra
.86153 .49555 .86595 .50151 .87693 .49829 .87253 .4923 Mtetra
.87253 .4923 .87693 .49829 .88794 .49505 .88358 .48904 Mtetra
.88358 .48904 .88794 .49505 .899 .4918 .89467 .48577 Mtetra
.89467 .48577 .899 .4918 .9101 .48854 .9058 .48249 Mtetra
.9058 .48249 .9101 .48854 .92125 .48527 .91698 .47919 Mtetra
.91698 .47919 .92125 .48527 .93243 .48198 .92819 .47588 Mtetra
.92819 .47588 .93243 .48198 .94366 .47868 .93945 .47256 Mtetra
.33552 .6441 .34122 .64908 .35035 .64638 .34467 .64139 Mtetra
.34467 .64139 .35035 .64638 .35951 .64368 .35385 .63866 Mtetra
.35385 .63866 .35951 .64368 .36871 .64097 .36306 .63594 Mtetra
.36306 .63594 .36871 .64097 .37793 .63825 .3723 .6332 Mtetra
.3723 .6332 .37793 .63825 .38719 .63551 .38158 .63045 Mtetra
.38158 .63045 .38719 .63551 .39647 .63277 .39089 .62769 Mtetra
.39089 .62769 .39647 .63277 .40579 .63002 .40023 .62492 Mtetra
.40023 .62492 .40579 .63002 .41515 .62726 .4096 .62214 Mtetra
.4096 .62214 .41515 .62726 .42453 .62449 .41901 .61936 Mtetra
.41901 .61936 .42453 .62449 .43395 .62172 .42844 .61656 Mtetra
.42844 .61656 .43395 .62172 .4434 .61893 .43792 .61375 Mtetra
.43792 .61375 .4434 .61893 .45289 .61613 .44742 .61094 Mtetra
.44742 .61094 .45289 .61613 .4624 .61332 .45696 .60811 Mtetra
.45696 .60811 .4624 .61332 .47195 .6105 .46653 .60527 Mtetra
.46653 .60527 .47195 .6105 .48154 .60767 .47614 .60243 Mtetra
.47614 .60243 .48154 .60767 .49116 .60484 .48578 .59957 Mtetra
.48578 .59957 .49116 .60484 .50081 .60199 .49545 .5967 Mtetra
.49545 .5967 .50081 .60199 .5105 .59913 .50516 .59383 Mtetra
.50516 .59383 .5105 .59913 .52022 .59626 .5149 .59094 Mtetra
.5149 .59094 .52022 .59626 .52997 .59338 .52468 .58804 Mtetra
.52468 .58804 .52997 .59338 .53976 .59049 .5345 .58513 Mtetra
.5345 .58513 .53976 .59049 .54959 .58759 .54434 .58222 Mtetra
.54434 .58222 .54959 .58759 .55945 .58469 .55423 .57929 Mtetra
.55423 .57929 .55945 .58469 .56934 .58177 .56414 .57635 Mtetra
.56414 .57635 .56934 .58177 .57927 .57884 .5741 .5734 Mtetra
.5741 .5734 .57927 .57884 .58924 .57589 .58409 .57044 Mtetra
.58409 .57044 .58924 .57589 .59924 .57294 .59412 .56747 Mtetra
.59412 .56747 .59924 .57294 .60928 .56998 .60418 .56449 Mtetra
.60418 .56449 .60928 .56998 .61935 .56701 .61428 .56149 Mtetra
.61428 .56149 .61935 .56701 .62946 .56403 .62441 .55849 Mtetra
.62441 .55849 .62946 .56403 .63961 .56103 .63458 .55547 Mtetra
.63458 .55547 .63961 .56103 .64979 .55803 .64479 .55245 Mtetra
.64479 .55245 .64979 .55803 .66002 .55501 .65504 .54941 Mtetra
.65504 .54941 .66002 .55501 .67027 .55198 .66532 .54637 Mtetra
.66532 .54637 .67027 .55198 .68057 .54895 .67564 .54331 Mtetra
.67564 .54331 .68057 .54895 .6909 .5459 .686 .54024 Mtetra
.686 .54024 .6909 .5459 .70127 .54284 .6964 .53716 Mtetra
.6964 .53716 .70127 .54284 .71168 .53976 .70684 .53406 Mtetra
.70684 .53406 .71168 .53976 .72213 .53668 .71731 .53096 Mtetra
.71731 .53096 .72213 .53668 .73262 .53359 .72782 .52785 Mtetra
.72782 .52785 .73262 .53359 .74314 .53048 .73838 .52472 Mtetra
.73838 .52472 .74314 .53048 .75371 .52737 .74897 .52158 Mtetra
.74897 .52158 .75371 .52737 .76431 .52424 .7596 .51843 Mtetra
.7596 .51843 .76431 .52424 .77495 .5211 .77027 .51527 Mtetra
.77027 .51527 .77495 .5211 .78563 .51794 .78098 .5121 Mtetra
.78098 .5121 .78563 .51794 .79635 .51478 .79173 .50891 Mtetra
.79173 .50891 .79635 .51478 .80711 .51161 .80251 .50571 Mtetra
.80251 .50571 .80711 .51161 .81792 .50842 .81335 .5025 Mtetra
.81335 .5025 .81792 .50842 .82876 .50522 .82422 .49928 Mtetra
.82422 .49928 .82876 .50522 .83964 .50201 .83513 .49605 Mtetra
.83513 .49605 .83964 .50201 .85056 .49879 .84608 .4928 Mtetra
.84608 .4928 .85056 .49879 .86153 .49555 .85707 .48955 Mtetra
.85707 .48955 .86153 .49555 .87253 .4923 .86811 .48627 Mtetra
.86811 .48627 .87253 .4923 .88358 .48904 .87919 .48299 Mtetra
.87919 .48299 .88358 .48904 .89467 .48577 .89031 .4797 Mtetra
.89031 .4797 .89467 .48577 .9058 .48249 .90147 .47639 Mtetra
.90147 .47639 .9058 .48249 .91698 .47919 .91268 .47307 Mtetra
.91268 .47307 .91698 .47919 .92819 .47588 .92392 .46974 Mtetra
.92392 .46974 .92819 .47588 .93945 .47256 .93521 .46639 Mtetra
.32977 .63908 .33552 .6441 .34467 .64139 .33894 .63636 Mtetra
.33894 .63636 .34467 .64139 .35385 .63866 .34814 .63362 Mtetra
.34814 .63362 .35385 .63866 .36306 .63594 .35737 .63087 Mtetra
.35737 .63087 .36306 .63594 .3723 .6332 .36664 .62811 Mtetra
.36664 .62811 .3723 .6332 .38158 .63045 .37593 .62535 Mtetra
.37593 .62535 .38158 .63045 .39089 .62769 .38526 .62257 Mtetra
.38526 .62257 .39089 .62769 .40023 .62492 .39462 .61979 Mtetra
.39462 .61979 .40023 .62492 .4096 .62214 .40402 .61699 Mtetra
.40402 .61699 .4096 .62214 .41901 .61936 .41344 .61418 Mtetra
.41344 .61418 .41901 .61936 .42844 .61656 .4229 .61137 Mtetra
.4229 .61137 .42844 .61656 .43792 .61375 .43239 .60854 Mtetra
.43239 .60854 .43792 .61375 .44742 .61094 .44192 .60571 Mtetra
.44192 .60571 .44742 .61094 .45696 .60811 .45148 .60286 Mtetra
.45148 .60286 .45696 .60811 .46653 .60527 .46108 .60001 Mtetra
.46108 .60001 .46653 .60527 .47614 .60243 .4707 .59714 Mtetra
.4707 .59714 .47614 .60243 .48578 .59957 .48037 .59427 Mtetra
.48037 .59427 .48578 .59957 .49545 .5967 .49006 .59138 Mtetra
.49006 .59138 .49545 .5967 .50516 .59383 .49979 .58849 Mtetra
.49979 .58849 .50516 .59383 .5149 .59094 .50956 .58558 Mtetra
.50956 .58558 .5149 .59094 .52468 .58804 .51936 .58267 Mtetra
.51936 .58267 .52468 .58804 .5345 .58513 .52919 .57974 Mtetra
.52919 .57974 .5345 .58513 .54434 .58222 .53907 .5768 Mtetra
.53907 .5768 .54434 .58222 .55423 .57929 .54897 .57385 Mtetra
.54897 .57385 .55423 .57929 .56414 .57635 .55891 .57089 Mtetra
.55891 .57089 .56414 .57635 .5741 .5734 .56889 .56792 Mtetra
.56889 .56792 .5741 .5734 .58409 .57044 .57891 .56494 Mtetra
.57891 .56494 .58409 .57044 .59412 .56747 .58896 .56195 Mtetra
.58896 .56195 .59412 .56747 .60418 .56449 .59904 .55895 Mtetra
.59904 .55895 .60418 .56449 .61428 .56149 .60917 .55594 Mtetra
.60917 .55594 .61428 .56149 .62441 .55849 .61933 .55292 Mtetra
.61933 .55292 .62441 .55849 .63458 .55547 .62952 .54988 Mtetra
.62952 .54988 .63458 .55547 .64479 .55245 .63976 .54684 Mtetra
.63976 .54684 .64479 .55245 .65504 .54941 .65003 .54378 Mtetra
.65003 .54378 .65504 .54941 .66532 .54637 .66034 .54071 Mtetra
.66034 .54071 .66532 .54637 .67564 .54331 .67069 .53763 Mtetra
.67069 .53763 .67564 .54331 .686 .54024 .68107 .53454 Mtetra
.68107 .53454 .686 .54024 .6964 .53716 .69149 .53144 Mtetra
.69149 .53144 .6964 .53716 .70684 .53406 .70196 .52833 Mtetra
.70196 .52833 .70684 .53406 .71731 .53096 .71246 .5252 Mtetra
.71246 .5252 .71731 .53096 .72782 .52785 .723 .52206 Mtetra
.723 .52206 .72782 .52785 .73838 .52472 .73358 .51892 Mtetra
.73358 .51892 .73838 .52472 .74897 .52158 .74419 .51576 Mtetra
.74419 .51576 .74897 .52158 .7596 .51843 .75485 .51258 Mtetra
.75485 .51258 .7596 .51843 .77027 .51527 .76555 .5094 Mtetra
.76555 .5094 .77027 .51527 .78098 .5121 .77629 .50621 Mtetra
.77629 .50621 .78098 .5121 .79173 .50891 .78707 .503 Mtetra
.78707 .503 .79173 .50891 .80251 .50571 .79788 .49978 Mtetra
.79788 .49978 .80251 .50571 .81335 .5025 .80874 .49655 Mtetra
.80874 .49655 .81335 .5025 .82422 .49928 .81964 .4933 Mtetra
.81964 .4933 .82422 .49928 .83513 .49605 .83058 .49005 Mtetra
.83058 .49005 .83513 .49605 .84608 .4928 .84157 .48678 Mtetra
.84157 .48678 .84608 .4928 .85707 .48955 .85259 .4835 Mtetra
.85259 .4835 .85707 .48955 .86811 .48627 .86366 .4802 Mtetra
.86366 .4802 .86811 .48627 .87919 .48299 .87477 .4769 Mtetra
.87477 .4769 .87919 .48299 .89031 .4797 .88592 .47358 Mtetra
.88592 .47358 .89031 .4797 .90147 .47639 .89711 .47025 Mtetra
.89711 .47025 .90147 .47639 .91268 .47307 .90834 .46691 Mtetra
.90834 .46691 .91268 .47307 .92392 .46974 .91962 .46355 Mtetra
.91962 .46355 .92392 .46974 .93521 .46639 .93095 .46018 Mtetra
.32399 .63404 .32977 .63908 .33894 .63636 .33318 .63129 Mtetra
.33318 .63129 .33894 .63636 .34814 .63362 .3424 .62854 Mtetra
.3424 .62854 .34814 .63362 .35737 .63087 .35165 .62577 Mtetra
.35165 .62577 .35737 .63087 .36664 .62811 .36094 .623 Mtetra
.36094 .623 .36664 .62811 .37593 .62535 .37025 .62021 Mtetra
.37025 .62021 .37593 .62535 .38526 .62257 .3796 .61742 Mtetra
.3796 .61742 .38526 .62257 .39462 .61979 .38898 .61462 Mtetra
.38898 .61462 .39462 .61979 .40402 .61699 .3984 .6118 Mtetra
.3984 .6118 .40402 .61699 .41344 .61418 .40784 .60898 Mtetra
.40784 .60898 .41344 .61418 .4229 .61137 .41732 .60615 Mtetra
.41732 .60615 .4229 .61137 .43239 .60854 .42684 .6033 Mtetra
.42684 .6033 .43239 .60854 .44192 .60571 .43639 .60045 Mtetra
.43639 .60045 .44192 .60571 .45148 .60286 .44597 .59759 Mtetra
.44597 .59759 .45148 .60286 .46108 .60001 .45558 .59471 Mtetra
.45558 .59471 .46108 .60001 .4707 .59714 .46523 .59183 Mtetra
.46523 .59183 .4707 .59714 .48037 .59427 .47492 .58893 Mtetra
.47492 .58893 .48037 .59427 .49006 .59138 .48463 .58603 Mtetra
.48463 .58603 .49006 .59138 .49979 .58849 .49439 .58311 Mtetra
.49439 .58311 .49979 .58849 .50956 .58558 .50418 .58019 Mtetra
.50418 .58019 .50956 .58558 .51936 .58267 .514 .57725 Mtetra
.514 .57725 .51936 .58267 .52919 .57974 .52386 .57431 Mtetra
.52386 .57431 .52919 .57974 .53907 .5768 .53375 .57135 Mtetra
.53375 .57135 .53907 .5768 .54897 .57385 .54368 .56838 Mtetra
.54368 .56838 .54897 .57385 .55891 .57089 .55365 .5654 Mtetra
.55365 .5654 .55891 .57089 .56889 .56792 .56365 .56241 Mtetra
.56365 .56241 .56889 .56792 .57891 .56494 .57369 .55941 Mtetra
.57369 .55941 .57891 .56494 .58896 .56195 .58376 .5564 Mtetra
.58376 .5564 .58896 .56195 .59904 .55895 .59387 .55338 Mtetra
.59387 .55338 .59904 .55895 .60917 .55594 .60402 .55035 Mtetra
.60402 .55035 .60917 .55594 .61933 .55292 .61421 .5473 Mtetra
.61421 .5473 .61933 .55292 .62952 .54988 .62443 .54425 Mtetra
.62443 .54425 .62952 .54988 .63976 .54684 .63469 .54118 Mtetra
.63469 .54118 .63976 .54684 .65003 .54378 .64498 .53811 Mtetra
.64498 .53811 .65003 .54378 .66034 .54071 .65532 .53502 Mtetra
.65532 .53502 .66034 .54071 .67069 .53763 .66569 .53192 Mtetra
.66569 .53192 .67069 .53763 .68107 .53454 .6761 .52881 Mtetra
.6761 .52881 .68107 .53454 .69149 .53144 .68655 .52568 Mtetra
.68655 .52568 .69149 .53144 .70196 .52833 .69704 .52255 Mtetra
.69704 .52255 .70196 .52833 .71246 .5252 .70757 .5194 Mtetra
.70757 .5194 .71246 .5252 .723 .52206 .71814 .51624 Mtetra
.71814 .51624 .723 .52206 .73358 .51892 .72874 .51307 Mtetra
.72874 .51307 .73358 .51892 .74419 .51576 .73939 .50989 Mtetra
.73939 .50989 .74419 .51576 .75485 .51258 .75008 .5067 Mtetra
.75008 .5067 .75485 .51258 .76555 .5094 .7608 .50349 Mtetra
.7608 .50349 .76555 .5094 .77629 .50621 .77157 .50027 Mtetra
.77157 .50027 .77629 .50621 .78707 .503 .78237 .49704 Mtetra
.78237 .49704 .78707 .503 .79788 .49978 .79322 .4938 Mtetra
.79322 .4938 .79788 .49978 .80874 .49655 .80411 .49055 Mtetra
.80411 .49055 .80874 .49655 .81964 .4933 .81504 .48728 Mtetra
.81504 .48728 .81964 .4933 .83058 .49005 .82601 .484 Mtetra
.82601 .484 .83058 .49005 .84157 .48678 .83702 .48071 Mtetra
.83702 .48071 .84157 .48678 .85259 .4835 .84808 .47741 Mtetra
.84808 .47741 .85259 .4835 .86366 .4802 .85917 .47409 Mtetra
.85917 .47409 .86366 .4802 .87477 .4769 .87031 .47076 Mtetra
.87031 .47076 .87477 .4769 .88592 .47358 .88149 .46742 Mtetra
.88149 .46742 .88592 .47358 .89711 .47025 .89272 .46407 Mtetra
.89272 .46407 .89711 .47025 .90834 .46691 .90398 .4607 Mtetra
.90398 .4607 .90834 .46691 .91962 .46355 .91529 .45732 Mtetra
.91529 .45732 .91962 .46355 .93095 .46018 .92665 .45393 Mtetra
.31818 .62896 .32399 .63404 .33318 .63129 .32738 .6262 Mtetra
.32738 .6262 .33318 .63129 .3424 .62854 .33662 .62343 Mtetra
.33662 .62343 .3424 .62854 .35165 .62577 .34589 .62064 Mtetra
.34589 .62064 .35165 .62577 .36094 .623 .3552 .61785 Mtetra
.3552 .61785 .36094 .623 .37025 .62021 .36453 .61505 Mtetra
.36453 .61505 .37025 .62021 .3796 .61742 .3739 .61224 Mtetra
.3739 .61224 .3796 .61742 .38898 .61462 .3833 .60942 Mtetra
.3833 .60942 .38898 .61462 .3984 .6118 .39274 .60658 Mtetra
.39274 .60658 .3984 .6118 .40784 .60898 .40221 .60374 Mtetra
.40221 .60374 .40784 .60898 .41732 .60615 .41171 .60089 Mtetra
.41171 .60089 .41732 .60615 .42684 .6033 .42124 .59803 Mtetra
.42124 .59803 .42684 .6033 .43639 .60045 .43081 .59516 Mtetra
.43081 .59516 .43639 .60045 .44597 .59759 .44042 .59227 Mtetra
.44042 .59227 .44597 .59759 .45558 .59471 .45005 .58938 Mtetra
.45005 .58938 .45558 .59471 .46523 .59183 .45972 .58648 Mtetra
.45972 .58648 .46523 .59183 .47492 .58893 .46943 .58356 Mtetra
.46943 .58356 .47492 .58893 .48463 .58603 .47917 .58064 Mtetra
.47917 .58064 .48463 .58603 .49439 .58311 .48895 .57771 Mtetra
.48895 .57771 .49439 .58311 .50418 .58019 .49876 .57476 Mtetra
.49876 .57476 .50418 .58019 .514 .57725 .5086 .57181 Mtetra
.5086 .57181 .514 .57725 .52386 .57431 .51849 .56884 Mtetra
.51849 .56884 .52386 .57431 .53375 .57135 .5284 .56586 Mtetra
.5284 .56586 .53375 .57135 .54368 .56838 .53836 .56288 Mtetra
.53836 .56288 .54368 .56838 .55365 .5654 .54835 .55988 Mtetra
.54835 .55988 .55365 .5654 .56365 .56241 .55837 .55687 Mtetra
.55837 .55687 .56365 .56241 .57369 .55941 .56843 .55385 Mtetra
.56843 .55385 .57369 .55941 .58376 .5564 .57853 .55082 Mtetra
.57853 .55082 .58376 .5564 .59387 .55338 .58867 .54777 Mtetra
.58867 .54777 .59387 .55338 .60402 .55035 .59884 .54472 Mtetra
.59884 .54472 .60402 .55035 .61421 .5473 .60905 .54166 Mtetra
.60905 .54166 .61421 .5473 .62443 .54425 .6193 .53858 Mtetra
.6193 .53858 .62443 .54425 .63469 .54118 .62958 .53549 Mtetra
.62958 .53549 .63469 .54118 .64498 .53811 .63991 .53239 Mtetra
.63991 .53239 .64498 .53811 .65532 .53502 .65027 .52928 Mtetra
.65027 .52928 .65532 .53502 .66569 .53192 .66067 .52616 Mtetra
.66067 .52616 .66569 .53192 .6761 .52881 .6711 .52303 Mtetra
.6711 .52303 .6761 .52881 .68655 .52568 .68158 .51989 Mtetra
.68158 .51989 .68655 .52568 .69704 .52255 .6921 .51673 Mtetra
.6921 .51673 .69704 .52255 .70757 .5194 .70265 .51356 Mtetra
.70265 .51356 .70757 .5194 .71814 .51624 .71324 .51038 Mtetra
.71324 .51038 .71814 .51624 .72874 .51307 .72388 .50719 Mtetra
.72388 .50719 .72874 .51307 .73939 .50989 .73455 .50399 Mtetra
.73455 .50399 .73939 .50989 .75008 .5067 .74527 .50077 Mtetra
.74527 .50077 .75008 .5067 .7608 .50349 .75602 .49754 Mtetra
.75602 .49754 .7608 .50349 .77157 .50027 .76681 .4943 Mtetra
.76681 .4943 .77157 .50027 .78237 .49704 .77765 .49105 Mtetra
.77765 .49105 .78237 .49704 .79322 .4938 .78852 .48779 Mtetra
.78852 .48779 .79322 .4938 .80411 .49055 .79944 .48451 Mtetra
.79944 .48451 .80411 .49055 .81504 .48728 .8104 .48122 Mtetra
.8104 .48122 .81504 .48728 .82601 .484 .8214 .47792 Mtetra
.8214 .47792 .82601 .484 .83702 .48071 .83244 .4746 Mtetra
.83244 .4746 .83702 .48071 .84808 .47741 .84353 .47128 Mtetra
.84353 .47128 .84808 .47741 .85917 .47409 .85465 .46794 Mtetra
.85465 .46794 .85917 .47409 .87031 .47076 .86582 .46458 Mtetra
.86582 .46458 .87031 .47076 .88149 .46742 .87704 .46122 Mtetra
.87704 .46122 .88149 .46742 .89272 .46407 .88829 .45784 Mtetra
.88829 .45784 .89272 .46407 .90398 .4607 .89959 .45445 Mtetra
.89959 .45445 .90398 .4607 .91529 .45732 .91093 .45104 Mtetra
.91093 .45104 .91529 .45732 .92665 .45393 .92232 .44763 Mtetra
.31232 .62385 .31818 .62896 .32738 .6262 .32155 .62107 Mtetra
.32155 .62107 .32738 .6262 .33662 .62343 .33081 .61828 Mtetra
.33081 .61828 .33662 .62343 .34589 .62064 .3401 .61548 Mtetra
.3401 .61548 .34589 .62064 .3552 .61785 .34942 .61267 Mtetra
.34942 .61267 .3552 .61785 .36453 .61505 .35878 .60985 Mtetra
.35878 .60985 .36453 .61505 .3739 .61224 .36817 .60702 Mtetra
.36817 .60702 .3739 .61224 .3833 .60942 .37759 .60418 Mtetra
.37759 .60418 .3833 .60942 .39274 .60658 .38704 .60133 Mtetra
.38704 .60133 .39274 .60658 .40221 .60374 .39653 .59847 Mtetra
.39653 .59847 .40221 .60374 .41171 .60089 .40606 .5956 Mtetra
.40606 .5956 .41171 .60089 .42124 .59803 .41561 .59272 Mtetra
.41561 .59272 .42124 .59803 .43081 .59516 .4252 .58983 Mtetra
.4252 .58983 .43081 .59516 .44042 .59227 .43483 .58692 Mtetra
.43483 .58692 .44042 .59227 .45005 .58938 .44449 .58401 Mtetra
.44449 .58401 .45005 .58938 .45972 .58648 .45418 .58109 Mtetra
.45418 .58109 .45972 .58648 .46943 .58356 .46391 .57816 Mtetra
.46391 .57816 .46943 .58356 .47917 .58064 .47367 .57521 Mtetra
.47367 .57521 .47917 .58064 .48895 .57771 .48347 .57226 Mtetra
.48347 .57226 .48895 .57771 .49876 .57476 .4933 .5693 Mtetra
.4933 .5693 .49876 .57476 .5086 .57181 .50317 .56632 Mtetra
.50317 .56632 .5086 .57181 .51849 .56884 .51308 .56334 Mtetra
.51308 .56334 .51849 .56884 .5284 .56586 .52302 .56034 Mtetra
.52302 .56034 .5284 .56586 .53836 .56288 .533 .55733 Mtetra
.533 .55733 .53836 .56288 .54835 .55988 .54301 .55431 Mtetra
.54301 .55431 .54835 .55988 .55837 .55687 .55306 .55128 Mtetra
.55306 .55128 .55837 .55687 .56843 .55385 .56314 .54824 Mtetra
.56314 .54824 .56843 .55385 .57853 .55082 .57327 .54519 Mtetra
.57327 .54519 .57853 .55082 .58867 .54777 .58343 .54213 Mtetra
.58343 .54213 .58867 .54777 .59884 .54472 .59363 .53905 Mtetra
.59363 .53905 .59884 .54472 .60905 .54166 .60386 .53597 Mtetra
.60386 .53597 .60905 .54166 .6193 .53858 .61413 .53287 Mtetra
.61413 .53287 .6193 .53858 .62958 .53549 .62444 .52976 Mtetra
.62444 .52976 .62958 .53549 .63991 .53239 .63479 .52664 Mtetra
.63479 .52664 .63991 .53239 .65027 .52928 .64518 .52351 Mtetra
.64518 .52351 .65027 .52928 .66067 .52616 .6556 .52037 Mtetra
.6556 .52037 .66067 .52616 .6711 .52303 .66607 .51722 Mtetra
.66607 .51722 .6711 .52303 .68158 .51989 .67657 .51405 Mtetra
.67657 .51405 .68158 .51989 .6921 .51673 .68711 .51087 Mtetra
.68711 .51087 .6921 .51673 .70265 .51356 .6977 .50768 Mtetra
.6977 .50768 .70265 .51356 .71324 .51038 .70832 .50448 Mtetra
.70832 .50448 .71324 .51038 .72388 .50719 .71898 .50127 Mtetra
.71898 .50127 .72388 .50719 .73455 .50399 .72968 .49804 Mtetra
.72968 .49804 .73455 .50399 .74527 .50077 .74042 .4948 Mtetra
.74042 .4948 .74527 .50077 .75602 .49754 .7512 .49155 Mtetra
.7512 .49155 .75602 .49754 .76681 .4943 .76203 .48829 Mtetra
.76203 .48829 .76681 .4943 .77765 .49105 .77289 .48501 Mtetra
.77289 .48501 .77765 .49105 .78852 .48779 .7838 .48173 Mtetra
.7838 .48173 .78852 .48779 .79944 .48451 .79474 .47843 Mtetra
.79474 .47843 .79944 .48451 .8104 .48122 .80573 .47511 Mtetra
.80573 .47511 .8104 .48122 .8214 .47792 .81676 .47179 Mtetra
.81676 .47179 .8214 .47792 .83244 .4746 .82783 .46845 Mtetra
.82783 .46845 .83244 .4746 .84353 .47128 .83895 .4651 Mtetra
.83895 .4651 .84353 .47128 .85465 .46794 .85011 .46174 Mtetra
.85011 .46174 .85465 .46794 .86582 .46458 .86131 .45836 Mtetra
.86131 .45836 .86582 .46458 .87704 .46122 .87255 .45497 Mtetra
.87255 .45497 .87704 .46122 .88829 .45784 .88384 .45157 Mtetra
.88384 .45157 .88829 .45784 .89959 .45445 .89517 .44815 Mtetra
.89517 .44815 .89959 .45445 .91093 .45104 .90654 .44472 Mtetra
.90654 .44472 .91093 .45104 .92232 .44763 .91796 .44128 Mtetra
.30643 .61871 .31232 .62385 .32155 .62107 .31568 .61591 Mtetra
.31568 .61591 .32155 .62107 .33081 .61828 .32495 .6131 Mtetra
.32495 .6131 .33081 .61828 .3401 .61548 .33427 .61028 Mtetra
.33427 .61028 .3401 .61548 .34942 .61267 .34361 .60746 Mtetra
.34361 .60746 .34942 .61267 .35878 .60985 .35299 .60462 Mtetra
.35299 .60462 .35878 .60985 .36817 .60702 .36239 .60177 Mtetra
.36239 .60177 .36817 .60702 .37759 .60418 .37184 .59891 Mtetra
.37184 .59891 .37759 .60418 .38704 .60133 .38131 .59604 Mtetra
.38131 .59604 .38704 .60133 .39653 .59847 .39082 .59316 Mtetra
.39082 .59316 .39653 .59847 .40606 .5956 .40037 .59027 Mtetra
.40037 .59027 .40606 .5956 .41561 .59272 .40995 .58737 Mtetra
.40995 .58737 .41561 .59272 .4252 .58983 .41956 .58446 Mtetra
.41956 .58446 .4252 .58983 .43483 .58692 .4292 .58154 Mtetra
.4292 .58154 .43483 .58692 .44449 .58401 .43888 .57861 Mtetra
.43888 .57861 .44449 .58401 .45418 .58109 .4486 .57567 Mtetra
.4486 .57567 .45418 .58109 .46391 .57816 .45835 .57272 Mtetra
.45835 .57272 .46391 .57816 .47367 .57521 .46814 .56975 Mtetra
.46814 .56975 .47367 .57521 .48347 .57226 .47796 .56678 Mtetra
.47796 .56678 .48347 .57226 .4933 .5693 .48781 .5638 Mtetra
.48781 .5638 .4933 .5693 .50317 .56632 .49771 .5608 Mtetra
.49771 .5608 .50317 .56632 .51308 .56334 .50763 .55779 Mtetra
.50763 .55779 .51308 .56334 .52302 .56034 .5176 .55478 Mtetra
.5176 .55478 .52302 .56034 .533 .55733 .5276 .55175 Mtetra
.5276 .55175 .533 .55733 .54301 .55431 .53764 .54871 Mtetra
.53764 .54871 .54301 .55431 .55306 .55128 .54771 .54566 Mtetra
.54771 .54566 .55306 .55128 .56314 .54824 .55782 .5426 Mtetra
.55782 .5426 .56314 .54824 .57327 .54519 .56797 .53953 Mtetra
.56797 .53953 .57327 .54519 .58343 .54213 .57815 .53644 Mtetra
.57815 .53644 .58343 .54213 .59363 .53905 .58837 .53335 Mtetra
.58837 .53335 .59363 .53905 .60386 .53597 .59864 .53024 Mtetra
.59864 .53024 .60386 .53597 .61413 .53287 .60893 .52712 Mtetra
.60893 .52712 .61413 .53287 .62444 .52976 .61927 .524 Mtetra
.61927 .524 .62444 .52976 .63479 .52664 .62964 .52085 Mtetra
.62964 .52085 .63479 .52664 .64518 .52351 .64006 .5177 Mtetra
.64006 .5177 .64518 .52351 .6556 .52037 .65051 .51454 Mtetra
.65051 .51454 .6556 .52037 .66607 .51722 .661 .51136 Mtetra
.661 .51136 .66607 .51722 .67657 .51405 .67153 .50817 Mtetra
.67153 .50817 .67657 .51405 .68711 .51087 .6821 .50497 Mtetra
.6821 .50497 .68711 .51087 .6977 .50768 .69271 .50176 Mtetra
.69271 .50176 .6977 .50768 .70832 .50448 .70336 .49854 Mtetra
.70336 .49854 .70832 .50448 .71898 .50127 .71405 .4953 Mtetra
.71405 .4953 .71898 .50127 .72968 .49804 .72477 .49205 Mtetra
.72477 .49205 .72968 .49804 .74042 .4948 .73554 .48879 Mtetra
.73554 .48879 .74042 .4948 .7512 .49155 .74636 .48552 Mtetra
.74636 .48552 .7512 .49155 .76203 .48829 .75721 .48223 Mtetra
.75721 .48223 .76203 .48829 .77289 .48501 .7681 .47893 Mtetra
.7681 .47893 .77289 .48501 .7838 .48173 .77903 .47562 Mtetra
.77903 .47562 .7838 .48173 .79474 .47843 .79001 .4723 Mtetra
.79001 .4723 .79474 .47843 .80573 .47511 .80103 .46897 Mtetra
.80103 .46897 .80573 .47511 .81676 .47179 .81209 .46562 Mtetra
.81209 .46562 .81676 .47179 .82783 .46845 .82319 .46226 Mtetra
.82319 .46226 .82783 .46845 .83895 .4651 .83434 .45888 Mtetra
.83434 .45888 .83895 .4651 .85011 .46174 .84552 .45549 Mtetra
.84552 .45549 .85011 .46174 .86131 .45836 .85676 .45209 Mtetra
.85676 .45209 .86131 .45836 .87255 .45497 .86803 .44868 Mtetra
.86803 .44868 .87255 .45497 .88384 .45157 .87935 .44525 Mtetra
.87935 .44525 .88384 .45157 .89517 .44815 .89071 .44181 Mtetra
.89071 .44181 .89517 .44815 .90654 .44472 .90212 .43836 Mtetra
.90212 .43836 .90654 .44472 .91796 .44128 .91357 .43489 Mtetra
.3005 .61354 .30643 .61871 .31568 .61591 .30977 .61072 Mtetra
.30977 .61072 .31568 .61591 .32495 .6131 .31906 .60789 Mtetra
.31906 .60789 .32495 .6131 .33427 .61028 .32839 .60505 Mtetra
.32839 .60505 .33427 .61028 .34361 .60746 .33776 .60221 Mtetra
.33776 .60221 .34361 .60746 .35299 .60462 .34715 .59935 Mtetra
.34715 .59935 .35299 .60462 .36239 .60177 .35658 .59648 Mtetra
.35658 .59648 .36239 .60177 .37184 .59891 .36605 .5936 Mtetra
.36605 .5936 .37184 .59891 .38131 .59604 .37555 .59072 Mtetra
.37555 .59072 .38131 .59604 .39082 .59316 .38508 .58782 Mtetra
.38508 .58782 .39082 .59316 .40037 .59027 .39464 .58491 Mtetra
.39464 .58491 .40037 .59027 .40995 .58737 .40424 .58199 Mtetra
.40424 .58199 .40995 .58737 .41956 .58446 .41387 .57906 Mtetra
.41387 .57906 .41956 .58446 .4292 .58154 .42354 .57612 Mtetra
.42354 .57612 .4292 .58154 .43888 .57861 .43324 .57317 Mtetra
.43324 .57317 .43888 .57861 .4486 .57567 .44298 .57021 Mtetra
.44298 .57021 .4486 .57567 .45835 .57272 .45276 .56724 Mtetra
.45276 .56724 .45835 .57272 .46814 .56975 .46256 .56426 Mtetra
.46256 .56426 .46814 .56975 .47796 .56678 .47241 .56126 Mtetra
.47241 .56126 .47796 .56678 .48781 .5638 .48229 .55826 Mtetra
.48229 .55826 .48781 .5638 .49771 .5608 .4922 .55524 Mtetra
.4922 .55524 .49771 .5608 .50763 .55779 .50215 .55222 Mtetra
.50215 .55222 .50763 .55779 .5176 .55478 .51214 .54918 Mtetra
.51214 .54918 .5176 .55478 .5276 .55175 .52217 .54613 Mtetra
.52217 .54613 .5276 .55175 .53764 .54871 .53223 .54307 Mtetra
.53223 .54307 .53764 .54871 .54771 .54566 .54232 .54 Mtetra
.54232 .54 .54771 .54566 .55782 .5426 .55246 .53692 Mtetra
.55246 .53692 .55782 .5426 .56797 .53953 .56263 .53383 Mtetra
.56263 .53383 .56797 .53953 .57815 .53644 .57284 .53072 Mtetra
.57284 .53072 .57815 .53644 .58837 .53335 .58309 .52761 Mtetra
.58309 .52761 .58837 .53335 .59864 .53024 .59337 .52448 Mtetra
.59337 .52448 .59864 .53024 .60893 .52712 .6037 .52134 Mtetra
.6037 .52134 .60893 .52712 .61927 .524 .61406 .51819 Mtetra
.61406 .51819 .61927 .524 .62964 .52085 .62446 .51503 Mtetra
.62446 .51503 .62964 .52085 .64006 .5177 .6349 .51185 Mtetra
.6349 .51185 .64006 .5177 .65051 .51454 .64538 .50866 Mtetra
.64538 .50866 .65051 .51454 .661 .51136 .65589 .50547 Mtetra
.65589 .50547 .661 .51136 .67153 .50817 .66645 .50226 Mtetra
.66645 .50226 .67153 .50817 .6821 .50497 .67705 .49903 Mtetra
.67705 .49903 .6821 .50497 .69271 .50176 .68768 .4958 Mtetra
.68768 .4958 .69271 .50176 .70336 .49854 .69836 .49255 Mtetra
.69836 .49255 .70336 .49854 .71405 .4953 .70908 .48929 Mtetra
.70908 .48929 .71405 .4953 .72477 .49205 .71984 .48602 Mtetra
.71984 .48602 .72477 .49205 .73554 .48879 .73063 .48274 Mtetra
.73063 .48274 .73554 .48879 .74636 .48552 .74147 .47944 Mtetra
.74147 .47944 .74636 .48552 .75721 .48223 .75235 .47613 Mtetra
.75235 .47613 .75721 .48223 .7681 .47893 .76328 .47281 Mtetra
.76328 .47281 .7681 .47893 .77903 .47562 .77424 .46948 Mtetra
.77424 .46948 .77903 .47562 .79001 .4723 .78524 .46613 Mtetra
.78524 .46613 .79001 .4723 .80103 .46897 .79629 .46277 Mtetra
.79629 .46277 .80103 .46897 .81209 .46562 .80738 .4594 Mtetra
.80738 .4594 .81209 .46562 .82319 .46226 .81852 .45602 Mtetra
.81852 .45602 .82319 .46226 .83434 .45888 .82969 .45262 Mtetra
.82969 .45262 .83434 .45888 .84552 .45549 .84091 .44921 Mtetra
.84091 .44921 .84552 .45549 .85676 .45209 .85217 .44578 Mtetra
.85217 .44578 .85676 .45209 .86803 .44868 .86348 .44234 Mtetra
.86348 .44234 .86803 .44868 .87935 .44525 .87483 .43889 Mtetra
.87483 .43889 .87935 .44525 .89071 .44181 .88623 .43543 Mtetra
.88623 .43543 .89071 .44181 .90212 .43836 .89766 .43195 Mtetra
.89766 .43195 .90212 .43836 .91357 .43489 .90915 .42846 Mtetra
.29453 .60833 .3005 .61354 .30977 .61072 .30382 .60549 Mtetra
.30382 .60549 .30977 .61072 .31906 .60789 .31314 .60265 Mtetra
.31314 .60265 .31906 .60789 .32839 .60505 .32249 .59979 Mtetra
.32249 .59979 .32839 .60505 .33776 .60221 .33187 .59692 Mtetra
.33187 .59692 .33776 .60221 .34715 .59935 .34129 .59405 Mtetra
.34129 .59405 .34715 .59935 .35658 .59648 .35074 .59116 Mtetra
.35074 .59116 .35658 .59648 .36605 .5936 .36022 .58826 Mtetra
.36022 .58826 .36605 .5936 .37555 .59072 .36974 .58536 Mtetra
.36974 .58536 .37555 .59072 .38508 .58782 .37929 .58244 Mtetra
.37929 .58244 .38508 .58782 .39464 .58491 .38888 .57951 Mtetra
.38888 .57951 .39464 .58491 .40424 .58199 .3985 .57657 Mtetra
.3985 .57657 .40424 .58199 .41387 .57906 .40815 .57363 Mtetra
.40815 .57363 .41387 .57906 .42354 .57612 .41784 .57067 Mtetra
.41784 .57067 .42354 .57612 .43324 .57317 .42757 .5677 Mtetra
.42757 .5677 .43324 .57317 .44298 .57021 .43733 .56471 Mtetra
.43733 .56471 .44298 .57021 .45276 .56724 .44712 .56172 Mtetra
.44712 .56172 .45276 .56724 .46256 .56426 .45695 .55872 Mtetra
.45695 .55872 .46256 .56426 .47241 .56126 .46682 .55571 Mtetra
.46682 .55571 .47241 .56126 .48229 .55826 .47672 .55268 Mtetra
.47672 .55268 .48229 .55826 .4922 .55524 .48666 .54965 Mtetra
.48666 .54965 .4922 .55524 .50215 .55222 .49664 .5466 Mtetra
.49664 .5466 .50215 .55222 .51214 .54918 .50665 .54354 Mtetra
.50665 .54354 .51214 .54918 .52217 .54613 .5167 .54047 Mtetra
.5167 .54047 .52217 .54613 .53223 .54307 .52678 .53739 Mtetra
.52678 .53739 .53223 .54307 .54232 .54 .5369 .5343 Mtetra
.5369 .5343 .54232 .54 .55246 .53692 .54706 .5312 Mtetra
.54706 .5312 .55246 .53692 .56263 .53383 .55726 .52809 Mtetra
.55726 .52809 .56263 .53383 .57284 .53072 .56749 .52496 Mtetra
.56749 .52496 .57284 .53072 .58309 .52761 .57777 .52182 Mtetra
.57777 .52182 .58309 .52761 .59337 .52448 .58808 .51867 Mtetra
.58808 .51867 .59337 .52448 .6037 .52134 .59843 .51551 Mtetra
.59843 .51551 .6037 .52134 .61406 .51819 .60881 .51234 Mtetra
.60881 .51234 .61406 .51819 .62446 .51503 .61924 .50916 Mtetra
.61924 .50916 .62446 .51503 .6349 .51185 .62971 .50596 Mtetra
.62971 .50596 .6349 .51185 .64538 .50866 .64021 .50275 Mtetra
.64021 .50275 .64538 .50866 .65589 .50547 .65075 .49953 Mtetra
.65075 .49953 .65589 .50547 .66645 .50226 .66134 .4963 Mtetra
.66134 .4963 .66645 .50226 .67705 .49903 .67196 .49305 Mtetra
.67196 .49305 .67705 .49903 .68768 .4958 .68263 .4898 Mtetra
.68263 .4898 .68768 .4958 .69836 .49255 .69333 .48653 Mtetra
.69333 .48653 .69836 .49255 .70908 .48929 .70408 .48325 Mtetra
.70408 .48325 .70908 .48929 .71984 .48602 .71486 .47995 Mtetra
.71486 .47995 .71984 .48602 .73063 .48274 .72569 .47664 Mtetra
.72569 .47664 .73063 .48274 .74147 .47944 .73656 .47333 Mtetra
.73656 .47333 .74147 .47944 .75235 .47613 .74746 .46999 Mtetra
.74746 .46999 .75235 .47613 .76328 .47281 .75842 .46665 Mtetra
.75842 .46665 .76328 .47281 .77424 .46948 .76941 .46329 Mtetra
.76941 .46329 .77424 .46948 .78524 .46613 .78044 .45992 Mtetra
.78044 .45992 .78524 .46613 .79629 .46277 .79152 .45654 Mtetra
.79152 .45654 .79629 .46277 .80738 .4594 .80264 .45314 Mtetra
.80264 .45314 .80738 .4594 .81852 .45602 .81381 .44973 Mtetra
.81381 .44973 .81852 .45602 .82969 .45262 .82501 .44631 Mtetra
.82501 .44631 .82969 .45262 .84091 .44921 .83626 .44287 Mtetra
.83626 .44287 .84091 .44921 .85217 .44578 .84756 .43942 Mtetra
.84756 .43942 .85217 .44578 .86348 .44234 .8589 .43596 Mtetra
.8589 .43596 .86348 .44234 .87483 .43889 .87028 .43248 Mtetra
.87028 .43248 .87483 .43889 .88623 .43543 .88171 .42899 Mtetra
.88171 .42899 .88623 .43543 .89766 .43195 .89318 .42549 Mtetra
.89318 .42549 .89766 .43195 .90915 .42846 .90469 .42197 Mtetra
.28853 .60308 .29453 .60833 .30382 .60549 .29783 .60023 Mtetra
.29783 .60023 .30382 .60549 .31314 .60265 .30717 .59737 Mtetra
.30717 .59737 .31314 .60265 .32249 .59979 .31654 .59449 Mtetra
.31654 .59449 .32249 .59979 .33187 .59692 .32594 .59161 Mtetra
.32594 .59161 .33187 .59692 .34129 .59405 .33538 .58871 Mtetra
.33538 .58871 .34129 .59405 .35074 .59116 .34485 .58581 Mtetra
.34485 .58581 .35074 .59116 .36022 .58826 .35435 .58289 Mtetra
.35435 .58289 .36022 .58826 .36974 .58536 .36389 .57996 Mtetra
.36389 .57996 .36974 .58536 .37929 .58244 .37347 .57703 Mtetra
.37347 .57703 .37929 .58244 .38888 .57951 .38307 .57408 Mtetra
.38307 .57408 .38888 .57951 .3985 .57657 .39272 .57112 Mtetra
.39272 .57112 .3985 .57657 .40815 .57363 .40239 .56815 Mtetra
.40239 .56815 .40815 .57363 .41784 .57067 .41211 .56517 Mtetra
.41211 .56517 .41784 .57067 .42757 .5677 .42185 .56218 Mtetra
.42185 .56218 .42757 .5677 .43733 .56471 .43163 .55918 Mtetra
.43163 .55918 .43733 .56471 .44712 .56172 .44145 .55617 Mtetra
.44145 .55617 .44712 .56172 .45695 .55872 .45131 .55315 Mtetra
.45131 .55315 .45695 .55872 .46682 .55571 .4612 .55012 Mtetra
.4612 .55012 .46682 .55571 .47672 .55268 .47112 .54707 Mtetra
.47112 .54707 .47672 .55268 .48666 .54965 .48108 .54401 Mtetra
.48108 .54401 .48666 .54965 .49664 .5466 .49108 .54095 Mtetra
.49108 .54095 .49664 .5466 .50665 .54354 .50112 .53787 Mtetra
.50112 .53787 .50665 .54354 .5167 .54047 .51119 .53478 Mtetra
.51119 .53478 .5167 .54047 .52678 .53739 .5213 .53168 Mtetra
.5213 .53168 .52678 .53739 .5369 .5343 .53144 .52857 Mtetra
.53144 .52857 .5369 .5343 .54706 .5312 .54163 .52544 Mtetra
.54163 .52544 .54706 .5312 .55726 .52809 .55185 .52231 Mtetra
.55185 .52231 .55726 .52809 .56749 .52496 .56211 .51916 Mtetra
.56211 .51916 .56749 .52496 .57777 .52182 .57241 .516 Mtetra
.57241 .516 .57777 .52182 .58808 .51867 .58274 .51283 Mtetra
.58274 .51283 .58808 .51867 .59843 .51551 .59312 .50965 Mtetra
.59312 .50965 .59843 .51551 .60881 .51234 .60353 .50645 Mtetra
.60353 .50645 .60881 .51234 .61924 .50916 .61398 .50324 Mtetra
.61398 .50324 .61924 .50916 .62971 .50596 .62448 .50003 Mtetra
.62448 .50003 .62971 .50596 .64021 .50275 .63501 .4968 Mtetra
.63501 .4968 .64021 .50275 .65075 .49953 .64558 .49355 Mtetra
.64558 .49355 .65075 .49953 .66134 .4963 .65619 .4903 Mtetra
.65619 .4903 .66134 .4963 .67196 .49305 .66684 .48703 Mtetra
.66684 .48703 .67196 .49305 .68263 .4898 .67753 .48375 Mtetra
.67753 .48375 .68263 .4898 .69333 .48653 .68826 .48046 Mtetra
.68826 .48046 .69333 .48653 .70408 .48325 .69904 .47715 Mtetra
.69904 .47715 .70408 .48325 .71486 .47995 .70985 .47384 Mtetra
.70985 .47384 .71486 .47995 .72569 .47664 .72071 .47051 Mtetra
.72071 .47051 .72569 .47664 .73656 .47333 .7316 .46716 Mtetra
.7316 .46716 .73656 .47333 .74746 .46999 .74254 .46381 Mtetra
.74254 .46381 .74746 .46999 .75842 .46665 .75352 .46044 Mtetra
.75352 .46044 .75842 .46665 .76941 .46329 .76455 .45706 Mtetra
.76455 .45706 .76941 .46329 .78044 .45992 .77561 .45366 Mtetra
.77561 .45366 .78044 .45992 .79152 .45654 .78672 .45026 Mtetra
.78672 .45026 .79152 .45654 .80264 .45314 .79787 .44684 Mtetra
.79787 .44684 .80264 .45314 .81381 .44973 .80906 .4434 Mtetra
.80906 .4434 .81381 .44973 .82501 .44631 .8203 .43995 Mtetra
.8203 .43995 .82501 .44631 .83626 .44287 .83158 .43649 Mtetra
.83158 .43649 .83626 .44287 .84756 .43942 .84291 .43302 Mtetra
.84291 .43302 .84756 .43942 .8589 .43596 .85428 .42953 Mtetra
.85428 .42953 .8589 .43596 .87028 .43248 .86569 .42603 Mtetra
.86569 .42603 .87028 .43248 .88171 .42899 .87715 .42252 Mtetra
.87715 .42252 .88171 .42899 .89318 .42549 .88866 .41899 Mtetra
.88866 .41899 .89318 .42549 .90469 .42197 .90021 .41544 Mtetra
.28248 .59781 .28853 .60308 .29783 .60023 .2918 .59493 Mtetra
.2918 .59493 .29783 .60023 .30717 .59737 .30116 .59205 Mtetra
.30116 .59205 .30717 .59737 .31654 .59449 .31055 .58916 Mtetra
.31055 .58916 .31654 .59449 .32594 .59161 .31997 .58625 Mtetra
.31997 .58625 .32594 .59161 .33538 .58871 .32943 .58334 Mtetra
.32943 .58334 .33538 .58871 .34485 .58581 .33892 .58042 Mtetra
.33892 .58042 .34485 .58581 .35435 .58289 .34845 .57748 Mtetra
.34845 .57748 .35435 .58289 .36389 .57996 .35801 .57453 Mtetra
.35801 .57453 .36389 .57996 .37347 .57703 .3676 .57158 Mtetra
.3676 .57158 .37347 .57703 .38307 .57408 .37723 .56861 Mtetra
.37723 .56861 .38307 .57408 .39272 .57112 .3869 .56563 Mtetra
.3869 .56563 .39272 .57112 .40239 .56815 .3966 .56264 Mtetra
.3966 .56264 .40239 .56815 .41211 .56517 .40633 .55965 Mtetra
.40633 .55965 .41211 .56517 .42185 .56218 .4161 .55664 Mtetra
.4161 .55664 .42185 .56218 .43163 .55918 .4259 .55361 Mtetra
.4259 .55361 .43163 .55918 .44145 .55617 .43574 .55058 Mtetra
.43574 .55058 .44145 .55617 .45131 .55315 .44562 .54754 Mtetra
.44562 .54754 .45131 .55315 .4612 .55012 .45553 .54449 Mtetra
.45553 .54449 .4612 .55012 .47112 .54707 .46548 .54142 Mtetra
.46548 .54142 .47112 .54707 .48108 .54401 .47547 .53834 Mtetra
.47547 .53834 .48108 .54401 .49108 .54095 .48549 .53526 Mtetra
.48549 .53526 .49108 .54095 .50112 .53787 .49555 .53216 Mtetra
.49555 .53216 .50112 .53787 .51119 .53478 .50564 .52905 Mtetra
.50564 .52905 .51119 .53478 .5213 .53168 .51578 .52592 Mtetra
.51578 .52592 .5213 .53168 .53144 .52857 .52595 .52279 Mtetra
.52595 .52279 .53144 .52857 .54163 .52544 .53616 .51964 Mtetra
.53616 .51964 .54163 .52544 .55185 .52231 .5464 .51649 Mtetra
.5464 .51649 .55185 .52231 .56211 .51916 .55669 .51332 Mtetra
.55669 .51332 .56211 .51916 .57241 .516 .56701 .51014 Mtetra
.56701 .51014 .57241 .516 .58274 .51283 .57737 .50694 Mtetra
.57737 .50694 .58274 .51283 .59312 .50965 .58777 .50374 Mtetra
.58777 .50374 .59312 .50965 .60353 .50645 .59821 .50052 Mtetra
.59821 .50052 .60353 .50645 .61398 .50324 .60869 .49729 Mtetra
.60869 .49729 .61398 .50324 .62448 .50003 .61921 .49405 Mtetra
.61921 .49405 .62448 .50003 .63501 .4968 .62977 .4908 Mtetra
.62977 .4908 .63501 .4968 .64558 .49355 .64037 .48753 Mtetra
.64037 .48753 .64558 .49355 .65619 .4903 .65101 .48426 Mtetra
.65101 .48426 .65619 .4903 .66684 .48703 .66168 .48097 Mtetra
.66168 .48097 .66684 .48703 .67753 .48375 .6724 .47766 Mtetra
.6724 .47766 .67753 .48375 .68826 .48046 .68316 .47435 Mtetra
.68316 .47435 .68826 .48046 .69904 .47715 .69396 .47102 Mtetra
.69396 .47102 .69904 .47715 .70985 .47384 .70481 .46768 Mtetra
.70481 .46768 .70985 .47384 .72071 .47051 .71569 .46433 Mtetra
.71569 .46433 .72071 .47051 .7316 .46716 .72662 .46096 Mtetra
.72662 .46096 .7316 .46716 .74254 .46381 .73758 .45758 Mtetra
.73758 .45758 .74254 .46381 .75352 .46044 .74859 .45419 Mtetra
.74859 .45419 .75352 .46044 .76455 .45706 .75965 .45078 Mtetra
.75965 .45078 .76455 .45706 .77561 .45366 .77074 .44736 Mtetra
.77074 .44736 .77561 .45366 .78672 .45026 .78188 .44393 Mtetra
.78188 .44393 .78672 .45026 .79787 .44684 .79306 .44049 Mtetra
.79306 .44049 .79787 .44684 .80906 .4434 .80429 .43703 Mtetra
.80429 .43703 .80906 .4434 .8203 .43995 .81556 .43356 Mtetra
.81556 .43356 .8203 .43995 .83158 .43649 .82687 .43007 Mtetra
.82687 .43007 .83158 .43649 .84291 .43302 .83823 .42657 Mtetra
.83823 .42657 .84291 .43302 .85428 .42953 .84963 .42306 Mtetra
.84963 .42306 .85428 .42953 .86569 .42603 .86108 .41953 Mtetra
.86108 .41953 .86569 .42603 .87715 .42252 .87257 .41599 Mtetra
.87257 .41599 .87715 .42252 .88866 .41899 .8841 .41243 Mtetra
.8841 .41243 .88866 .41899 .90021 .41544 .89569 .40886 Mtetra
.27639 .59249 .28248 .59781 .2918 .59493 .28574 .5896 Mtetra
.28574 .5896 .2918 .59493 .30116 .59205 .29511 .5867 Mtetra
.29511 .5867 .30116 .59205 .31055 .58916 .30452 .58379 Mtetra
.30452 .58379 .31055 .58916 .31997 .58625 .31397 .58087 Mtetra
.31397 .58087 .31997 .58625 .32943 .58334 .32345 .57793 Mtetra
.32345 .57793 .32943 .58334 .33892 .58042 .33296 .57499 Mtetra
.33296 .57499 .33892 .58042 .34845 .57748 .34251 .57203 Mtetra
.34251 .57203 .34845 .57748 .35801 .57453 .35209 .56907 Mtetra
.35209 .56907 .35801 .57453 .3676 .57158 .3617 .56609 Mtetra
.3617 .56609 .3676 .57158 .37723 .56861 .37135 .56311 Mtetra
.37135 .56311 .37723 .56861 .3869 .56563 .38104 .56011 Mtetra
.38104 .56011 .3869 .56563 .3966 .56264 .39076 .5571 Mtetra
.39076 .5571 .3966 .56264 .40633 .55965 .40052 .55408 Mtetra
.40052 .55408 .40633 .55965 .4161 .55664 .41031 .55105 Mtetra
.41031 .55105 .4161 .55664 .4259 .55361 .42013 .54801 Mtetra
.42013 .54801 .4259 .55361 .43574 .55058 .43 .54496 Mtetra
.43 .54496 .43574 .55058 .44562 .54754 .4399 .54189 Mtetra
.4399 .54189 .44562 .54754 .45553 .54449 .44983 .53882 Mtetra
.44983 .53882 .45553 .54449 .46548 .54142 .4598 .53573 Mtetra
.4598 .53573 .46548 .54142 .47547 .53834 .46981 .53263 Mtetra
.46981 .53263 .47547 .53834 .48549 .53526 .47986 .52952 Mtetra
.47986 .52952 .48549 .53526 .49555 .53216 .48994 .5264 Mtetra
.48994 .5264 .49555 .53216 .50564 .52905 .50006 .52327 Mtetra
.50006 .52327 .50564 .52905 .51578 .52592 .51022 .52013 Mtetra
.51022 .52013 .51578 .52592 .52595 .52279 .52041 .51697 Mtetra
.52041 .51697 .52595 .52279 .53616 .51964 .53065 .51381 Mtetra
.53065 .51381 .53616 .51964 .5464 .51649 .54092 .51063 Mtetra
.54092 .51063 .5464 .51649 .55669 .51332 .55123 .50744 Mtetra
.55123 .50744 .55669 .51332 .56701 .51014 .56158 .50423 Mtetra
.56158 .50423 .56701 .51014 .57737 .50694 .57197 .50102 Mtetra
.57197 .50102 .57737 .50694 .58777 .50374 .58239 .49779 Mtetra
.58239 .49779 .58777 .50374 .59821 .50052 .59286 .49455 Mtetra
.59286 .49455 .59821 .50052 .60869 .49729 .60336 .4913 Mtetra
.60336 .4913 .60869 .49729 .61921 .49405 .61391 .48804 Mtetra
.61391 .48804 .61921 .49405 .62977 .4908 .62449 .48476 Mtetra
.62449 .48476 .62977 .4908 .64037 .48753 .63512 .48147 Mtetra
.63512 .48147 .64037 .48753 .65101 .48426 .64578 .47817 Mtetra
.64578 .47817 .65101 .48426 .66168 .48097 .65649 .47486 Mtetra
.65649 .47486 .66168 .48097 .6724 .47766 .66724 .47153 Mtetra
.66724 .47153 .6724 .47766 .68316 .47435 .67803 .46819 Mtetra
.67803 .46819 .68316 .47435 .69396 .47102 .68886 .46484 Mtetra
.68886 .46484 .69396 .47102 .70481 .46768 .69973 .46148 Mtetra
.69973 .46148 .70481 .46768 .71569 .46433 .71064 .4581 Mtetra
.71064 .4581 .71569 .46433 .72662 .46096 .72159 .45471 Mtetra
.72159 .45471 .72662 .46096 .73758 .45758 .73259 .45131 Mtetra
.73259 .45131 .73758 .45758 .74859 .45419 .74363 .44789 Mtetra
.74363 .44789 .74859 .45419 .75965 .45078 .75471 .44446 Mtetra
.75471 .44446 .75965 .45078 .77074 .44736 .76584 .44102 Mtetra
.76584 .44102 .77074 .44736 .78188 .44393 .77701 .43756 Mtetra
.77701 .43756 .78188 .44393 .79306 .44049 .78822 .43409 Mtetra
.78822 .43409 .79306 .44049 .80429 .43703 .79948 .43061 Mtetra
.79948 .43061 .80429 .43703 .81556 .43356 .81078 .42711 Mtetra
.81078 .42711 .81556 .43356 .82687 .43007 .82212 .4236 Mtetra
.82212 .4236 .82687 .43007 .83823 .42657 .83351 .42008 Mtetra
.83351 .42008 .83823 .42657 .84963 .42306 .84495 .41654 Mtetra
.84495 .41654 .84963 .42306 .86108 .41953 .85642 .41299 Mtetra
.85642 .41299 .86108 .41953 .87257 .41599 .86795 .40942 Mtetra
.86795 .40942 .87257 .41599 .8841 .41243 .87952 .40584 Mtetra
.87952 .40584 .8841 .41243 .89569 .40886 .89113 .40224 Mtetra
.27027 .58715 .27639 .59249 .28574 .5896 .27963 .58424 Mtetra
.27963 .58424 .28574 .5896 .29511 .5867 .28903 .58132 Mtetra
.656 .752 .92 r
.28903 .58132 .29511 .5867 .30452 .58379 .29846 .57839 Mtetra
.29846 .57839 .30452 .58379 .31397 .58087 .30792 .57545 Mtetra
.30792 .57545 .31397 .58087 .32345 .57793 .31742 .5725 Mtetra
.31742 .5725 .32345 .57793 .33296 .57499 .32695 .56953 Mtetra
.32695 .56953 .33296 .57499 .34251 .57203 .33652 .56656 Mtetra
.33652 .56656 .34251 .57203 .35209 .56907 .34612 .56357 Mtetra
.34612 .56357 .35209 .56907 .3617 .56609 .35576 .56057 Mtetra
.656 .751 .92 r
.35576 .56057 .3617 .56609 .37135 .56311 .36543 .55756 Mtetra
.36543 .55756 .37135 .56311 .38104 .56011 .37514 .55455 Mtetra
.37514 .55455 .38104 .56011 .39076 .5571 .38488 .55152 Mtetra
.38488 .55152 .39076 .5571 .40052 .55408 .39466 .54848 Mtetra
.39466 .54848 .40052 .55408 .41031 .55105 .40448 .54543 Mtetra
.40448 .54543 .41031 .55105 .42013 .54801 .41432 .54236 Mtetra
.41432 .54236 .42013 .54801 .43 .54496 .42421 .53929 Mtetra
.42421 .53929 .43 .54496 .4399 .54189 .43413 .53621 Mtetra
.43413 .53621 .4399 .54189 .44983 .53882 .44409 .53311 Mtetra
.44409 .53311 .44983 .53882 .4598 .53573 .45409 .53 Mtetra
.45409 .53 .4598 .53573 .46981 .53263 .46412 .52688 Mtetra
.46412 .52688 .46981 .53263 .47986 .52952 .47419 .52375 Mtetra
.47419 .52375 .47986 .52952 .48994 .5264 .4843 .52061 Mtetra
.4843 .52061 .48994 .5264 .50006 .52327 .49444 .51746 Mtetra
.49444 .51746 .50006 .52327 .51022 .52013 .50462 .51429 Mtetra
.50462 .51429 .51022 .52013 .52041 .51697 .51484 .51112 Mtetra
.51484 .51112 .52041 .51697 .53065 .51381 .5251 .50793 Mtetra
.5251 .50793 .53065 .51381 .54092 .51063 .5354 .50473 Mtetra
.5354 .50473 .54092 .51063 .55123 .50744 .54573 .50151 Mtetra
.54573 .50151 .55123 .50744 .56158 .50423 .55611 .49829 Mtetra
.55611 .49829 .56158 .50423 .57197 .50102 .56652 .49505 Mtetra
.56652 .49505 .57197 .50102 .58239 .49779 .57697 .4918 Mtetra
.57697 .4918 .58239 .49779 .59286 .49455 .58747 .48854 Mtetra
.58747 .48854 .59286 .49455 .60336 .4913 .598 .48527 Mtetra
.598 .48527 .60336 .4913 .61391 .48804 .60857 .48198 Mtetra
.60857 .48198 .61391 .48804 .62449 .48476 .61918 .47868 Mtetra
.61918 .47868 .62449 .48476 .63512 .48147 .62983 .47537 Mtetra
.62983 .47537 .63512 .48147 .64578 .47817 .64053 .47205 Mtetra
.64053 .47205 .64578 .47817 .65649 .47486 .65126 .46871 Mtetra
.65126 .46871 .65649 .47486 .66724 .47153 .66204 .46536 Mtetra
.66204 .46536 .66724 .47153 .67803 .46819 .67285 .462 Mtetra
.67285 .462 .67803 .46819 .68886 .46484 .68371 .45862 Mtetra
.68371 .45862 .68886 .46484 .69973 .46148 .69461 .45523 Mtetra
.69461 .45523 .69973 .46148 .71064 .4581 .70555 .45183 Mtetra
.70555 .45183 .71064 .4581 .72159 .45471 .71654 .44842 Mtetra
.71654 .44842 .72159 .45471 .73259 .45131 .72756 .44499 Mtetra
.72756 .44499 .73259 .45131 .74363 .44789 .73863 .44155 Mtetra
.73863 .44155 .74363 .44789 .75471 .44446 .74974 .43809 Mtetra
.74974 .43809 .75471 .44446 .76584 .44102 .7609 .43463 Mtetra
.7609 .43463 .76584 .44102 .77701 .43756 .7721 .43114 Mtetra
.7721 .43114 .77701 .43756 .78822 .43409 .78334 .42765 Mtetra
.78334 .42765 .78822 .43409 .79948 .43061 .79463 .42414 Mtetra
.79463 .42414 .79948 .43061 .81078 .42711 .80596 .42062 Mtetra
.656 .752 .92 r
.80596 .42062 .81078 .42711 .82212 .4236 .81734 .41709 Mtetra
.81734 .41709 .82212 .4236 .83351 .42008 .82876 .41354 Mtetra
.82876 .41354 .83351 .42008 .84495 .41654 .84023 .40997 Mtetra
.84023 .40997 .84495 .41654 .85642 .41299 .85174 .4064 Mtetra
.85174 .4064 .85642 .41299 .86795 .40942 .8633 .4028 Mtetra
.8633 .4028 .86795 .40942 .87952 .40584 .8749 .39919 Mtetra
.8749 .39919 .87952 .40584 .89113 .40224 .88655 .39556 Mtetra
.655 .751 .92 r
.2641 .58177 .27027 .58715 .27963 .58424 .27348 .57885 Mtetra
.655 .752 .921 r
.27348 .57885 .27963 .58424 .28903 .58132 .2829 .57591 Mtetra
.656 .752 .921 r
.2829 .57591 .28903 .58132 .29846 .57839 .29235 .57297 Mtetra
.29235 .57297 .29846 .57839 .30792 .57545 .30184 .57001 Mtetra
.30184 .57001 .30792 .57545 .31742 .5725 .31136 .56703 Mtetra
.31136 .56703 .31742 .5725 .32695 .56953 .32091 .56404 Mtetra
.32091 .56404 .32695 .56953 .33652 .56656 .3305 .56105 Mtetra
.656 .752 .92 r
.3305 .56105 .33652 .56656 .34612 .56357 .34012 .55804 Mtetra
.34012 .55804 .34612 .56357 .35576 .56057 .34978 .55502 Mtetra
.34978 .55502 .35576 .56057 .36543 .55756 .35947 .55199 Mtetra
.35947 .55199 .36543 .55756 .37514 .55455 .3692 .54895 Mtetra
.656 .751 .92 r
.3692 .54895 .37514 .55455 .38488 .55152 .37897 .5459 Mtetra
.37897 .5459 .38488 .55152 .39466 .54848 .38877 .54284 Mtetra
.38877 .54284 .39466 .54848 .40448 .54543 .3986 .53976 Mtetra
.3986 .53976 .40448 .54543 .41432 .54236 .40848 .53668 Mtetra
.40848 .53668 .41432 .54236 .42421 .53929 .41839 .53359 Mtetra
.41839 .53359 .42421 .53929 .43413 .53621 .42833 .53048 Mtetra
.42833 .53048 .43413 .53621 .44409 .53311 .43831 .52737 Mtetra
.43831 .52737 .44409 .53311 .45409 .53 .44833 .52424 Mtetra
.44833 .52424 .45409 .53 .46412 .52688 .45839 .5211 Mtetra
.45839 .5211 .46412 .52688 .47419 .52375 .46848 .51794 Mtetra
.46848 .51794 .47419 .52375 .4843 .52061 .47861 .51478 Mtetra
.47861 .51478 .4843 .52061 .49444 .51746 .48878 .51161 Mtetra
.48878 .51161 .49444 .51746 .50462 .51429 .49899 .50842 Mtetra
.49899 .50842 .50462 .51429 .51484 .51112 .50923 .50522 Mtetra
.50923 .50522 .51484 .51112 .5251 .50793 .51952 .50201 Mtetra
.51952 .50201 .5251 .50793 .5354 .50473 .52984 .49879 Mtetra
.52984 .49879 .5354 .50473 .54573 .50151 .5402 .49555 Mtetra
.5402 .49555 .54573 .50151 .55611 .49829 .5506 .4923 Mtetra
.5506 .4923 .55611 .49829 .56652 .49505 .56104 .48904 Mtetra
.56104 .48904 .56652 .49505 .57697 .4918 .57152 .48577 Mtetra
.57152 .48577 .57697 .4918 .58747 .48854 .58203 .48249 Mtetra
.58203 .48249 .58747 .48854 .598 .48527 .59259 .47919 Mtetra
.59259 .47919 .598 .48527 .60857 .48198 .60319 .47588 Mtetra
.60319 .47588 .60857 .48198 .61918 .47868 .61383 .47256 Mtetra
.61383 .47256 .61918 .47868 .62983 .47537 .62451 .46922 Mtetra
.62451 .46922 .62983 .47537 .64053 .47205 .63523 .46587 Mtetra
.63523 .46587 .64053 .47205 .65126 .46871 .64599 .46251 Mtetra
.64599 .46251 .65126 .46871 .66204 .46536 .6568 .45914 Mtetra
.6568 .45914 .66204 .46536 .67285 .462 .66764 .45575 Mtetra
.66764 .45575 .67285 .462 .68371 .45862 .67853 .45235 Mtetra
.67853 .45235 .68371 .45862 .69461 .45523 .68946 .44894 Mtetra
.68946 .44894 .69461 .45523 .70555 .45183 .70043 .44552 Mtetra
.70043 .44552 .70555 .45183 .71654 .44842 .71144 .44208 Mtetra
.71144 .44208 .71654 .44842 .72756 .44499 .7225 .43863 Mtetra
.7225 .43863 .72756 .44499 .73863 .44155 .7336 .43516 Mtetra
.7336 .43516 .73863 .44155 .74974 .43809 .74474 .43168 Mtetra
.74474 .43168 .74974 .43809 .7609 .43463 .75593 .42819 Mtetra
.75593 .42819 .7609 .43463 .7721 .43114 .76716 .42468 Mtetra
.76716 .42468 .7721 .43114 .78334 .42765 .77843 .42117 Mtetra
.656 .752 .92 r
.77843 .42117 .78334 .42765 .79463 .42414 .78975 .41764 Mtetra
.656 .752 .921 r
.78975 .41764 .79463 .42414 .80596 .42062 .80111 .41409 Mtetra
.80111 .41409 .80596 .42062 .81734 .41709 .81252 .41053 Mtetra
.81252 .41053 .81734 .41709 .82876 .41354 .82398 .40696 Mtetra
.82398 .40696 .82876 .41354 .84023 .40997 .83548 .40337 Mtetra
.83548 .40337 .84023 .40997 .85174 .4064 .84702 .39977 Mtetra
.84702 .39977 .85174 .4064 .8633 .4028 .85861 .39614 Mtetra
.656 .752 .92 r
.85861 .39614 .8633 .4028 .8749 .39919 .87025 .3925 Mtetra
.87025 .3925 .8749 .39919 .88655 .39556 .88193 .38884 Mtetra
.655 .751 .921 r
.25789 .57635 .2641 .58177 .27348 .57885 .26729 .57342 Mtetra
.655 .752 .921 r
.26729 .57342 .27348 .57885 .2829 .57591 .27673 .57048 Mtetra
.27673 .57048 .2829 .57591 .29235 .57297 .2862 .56752 Mtetra
.2862 .56752 .29235 .57297 .30184 .57001 .29571 .56454 Mtetra
.656 .753 .921 r
.29571 .56454 .30184 .57001 .31136 .56703 .30525 .56155 Mtetra
.30525 .56155 .31136 .56703 .32091 .56404 .31482 .55854 Mtetra
.31482 .55854 .32091 .56404 .3305 .56105 .32443 .55552 Mtetra
.656 .752 .921 r
.32443 .55552 .3305 .56105 .34012 .55804 .33408 .55248 Mtetra
.33408 .55248 .34012 .55804 .34978 .55502 .34376 .54944 Mtetra
.34376 .54944 .34978 .55502 .35947 .55199 .35347 .54638 Mtetra
.656 .752 .92 r
.35347 .54638 .35947 .55199 .3692 .54895 .36323 .54332 Mtetra
.36323 .54332 .3692 .54895 .37897 .5459 .37301 .54024 Mtetra
.37301 .54024 .37897 .5459 .38877 .54284 .38283 .53716 Mtetra
.38283 .53716 .38877 .54284 .3986 .53976 .39269 .53407 Mtetra
.656 .751 .92 r
.39269 .53407 .3986 .53976 .40848 .53668 .40259 .53096 Mtetra
.40259 .53096 .40848 .53668 .41839 .53359 .41252 .52785 Mtetra
.41252 .52785 .41839 .53359 .42833 .53048 .42249 .52472 Mtetra
.42249 .52472 .42833 .53048 .43831 .52737 .43249 .52158 Mtetra
.43249 .52158 .43831 .52737 .44833 .52424 .44254 .51843 Mtetra
.44254 .51843 .44833 .52424 .45839 .5211 .45262 .51527 Mtetra
.45262 .51527 .45839 .5211 .46848 .51794 .46273 .5121 Mtetra
.46273 .5121 .46848 .51794 .47861 .51478 .47289 .50891 Mtetra
.47289 .50891 .47861 .51478 .48878 .51161 .48308 .50571 Mtetra
.48308 .50571 .48878 .51161 .49899 .50842 .49331 .5025 Mtetra
.49331 .5025 .49899 .50842 .50923 .50522 .50358 .49928 Mtetra
.50358 .49928 .50923 .50522 .51952 .50201 .51389 .49605 Mtetra
.51389 .49605 .51952 .50201 .52984 .49879 .52424 .4928 Mtetra
.52424 .4928 .52984 .49879 .5402 .49555 .53463 .48955 Mtetra
.53463 .48955 .5402 .49555 .5506 .4923 .54505 .48627 Mtetra
.54505 .48627 .5506 .4923 .56104 .48904 .55552 .48299 Mtetra
.55552 .48299 .56104 .48904 .57152 .48577 .56602 .4797 Mtetra
.56602 .4797 .57152 .48577 .58203 .48249 .57657 .47639 Mtetra
.57657 .47639 .58203 .48249 .59259 .47919 .58715 .47307 Mtetra
.58715 .47307 .59259 .47919 .60319 .47588 .59778 .46974 Mtetra
.59778 .46974 .60319 .47588 .61383 .47256 .60844 .46639 Mtetra
.60844 .46639 .61383 .47256 .62451 .46922 .61915 .46303 Mtetra
.61915 .46303 .62451 .46922 .63523 .46587 .6299 .45966 Mtetra
.6299 .45966 .63523 .46587 .64599 .46251 .64069 .45628 Mtetra
.64069 .45628 .64599 .46251 .6568 .45914 .65152 .45288 Mtetra
.65152 .45288 .6568 .45914 .66764 .45575 .66239 .44947 Mtetra
.66239 .44947 .66764 .45575 .67853 .45235 .67331 .44604 Mtetra
.67331 .44604 .67853 .45235 .68946 .44894 .68427 .44261 Mtetra
.68427 .44261 .68946 .44894 .70043 .44552 .69527 .43916 Mtetra
.69527 .43916 .70043 .44552 .71144 .44208 .70631 .43569 Mtetra
.70631 .43569 .71144 .44208 .7225 .43863 .7174 .43222 Mtetra
.7174 .43222 .7225 .43863 .7336 .43516 .72853 .42873 Mtetra
.72853 .42873 .7336 .43516 .74474 .43168 .7397 .42523 Mtetra
.656 .752 .92 r
.7397 .42523 .74474 .43168 .75593 .42819 .75092 .42171 Mtetra
.656 .752 .921 r
.75092 .42171 .75593 .42819 .76716 .42468 .76218 .41819 Mtetra
.655 .752 .921 r
.76218 .41819 .76716 .42468 .77843 .42117 .77348 .41465 Mtetra
.77348 .41465 .77843 .42117 .78975 .41764 .78484 .4111 Mtetra
.78484 .4111 .78975 .41764 .80111 .41409 .79623 .40753 Mtetra
.79623 .40753 .80111 .41409 .81252 .41053 .80767 .40395 Mtetra
.80767 .40395 .81252 .41053 .82398 .40696 .81916 .40036 Mtetra
.656 .753 .921 r
.81916 .40036 .82398 .40696 .83548 .40337 .83069 .39674 Mtetra
.83069 .39674 .83548 .40337 .84702 .39977 .84227 .3931 Mtetra
.84227 .3931 .84702 .39977 .85861 .39614 .85389 .38945 Mtetra
.656 .752 .921 r
.85389 .38945 .85861 .39614 .87025 .3925 .86556 .38577 Mtetra
.657 .752 .92 r
.86556 .38577 .87025 .3925 .88193 .38884 .87727 .38207 Mtetra
.654 .751 .921 r
.25164 .57089 .25789 .57635 .26729 .57342 .26106 .56797 Mtetra
.654 .752 .922 r
.26106 .56797 .26729 .57342 .27673 .57048 .27052 .56503 Mtetra
.654 .753 .922 r
.27052 .56503 .27673 .57048 .2862 .56752 .28001 .56207 Mtetra
.655 .754 .922 r
.28001 .56207 .2862 .56752 .29571 .56454 .28953 .55909 Mtetra
.656 .754 .922 r
.28953 .55909 .29571 .56454 .30525 .56155 .29909 .55607 Mtetra
.29909 .55607 .30525 .56155 .31482 .55854 .30869 .55304 Mtetra
.30869 .55304 .31482 .55854 .32443 .55552 .31832 .54999 Mtetra
.657 .754 .922 r
.31832 .54999 .32443 .55552 .33408 .55248 .32799 .54692 Mtetra
.657 .753 .921 r
.32799 .54692 .33408 .55248 .34376 .54944 .33769 .54384 Mtetra
.656 .753 .921 r
.33769 .54384 .34376 .54944 .35347 .54638 .34743 .54076 Mtetra
.34743 .54076 .35347 .54638 .36323 .54332 .35721 .53766 Mtetra
.656 .752 .921 r
.35721 .53766 .36323 .54332 .37301 .54024 .36702 .53456 Mtetra
.656 .752 .92 r
.36702 .53456 .37301 .54024 .38283 .53716 .37686 .53145 Mtetra
.37686 .53145 .38283 .53716 .39269 .53407 .38674 .52833 Mtetra
.38674 .52833 .39269 .53407 .40259 .53096 .39666 .5252 Mtetra
.656 .751 .92 r
.39666 .5252 .40259 .53096 .41252 .52785 .40662 .52207 Mtetra
.40662 .52207 .41252 .52785 .42249 .52472 .41661 .51892 Mtetra
.41661 .51892 .42249 .52472 .43249 .52158 .42664 .51576 Mtetra
.42664 .51576 .43249 .52158 .44254 .51843 .4367 .51258 Mtetra
.4367 .51258 .44254 .51843 .45262 .51527 .44681 .5094 Mtetra
.44681 .5094 .45262 .51527 .46273 .5121 .45695 .5062 Mtetra
.45695 .5062 .46273 .5121 .47289 .50891 .46713 .503 Mtetra
.46713 .503 .47289 .50891 .48308 .50571 .47734 .49978 Mtetra
.47734 .49978 .48308 .50571 .49331 .5025 .4876 .49655 Mtetra
.4876 .49655 .49331 .5025 .50358 .49928 .49789 .4933 Mtetra
.49789 .4933 .50358 .49928 .51389 .49605 .50823 .49005 Mtetra
.50823 .49005 .51389 .49605 .52424 .4928 .5186 .48678 Mtetra
.5186 .48678 .52424 .4928 .53463 .48955 .52901 .4835 Mtetra
.52901 .4835 .53463 .48955 .54505 .48627 .53946 .4802 Mtetra
.53946 .4802 .54505 .48627 .55552 .48299 .54996 .4769 Mtetra
.54996 .4769 .55552 .48299 .56602 .4797 .56049 .47358 Mtetra
.56049 .47358 .56602 .4797 .57657 .47639 .57106 .47025 Mtetra
.57106 .47025 .57657 .47639 .58715 .47307 .58167 .46691 Mtetra
.58167 .46691 .58715 .47307 .59778 .46974 .59232 .46355 Mtetra
.59232 .46355 .59778 .46974 .60844 .46639 .60302 .46018 Mtetra
.60302 .46018 .60844 .46639 .61915 .46303 .61375 .4568 Mtetra
.61375 .4568 .61915 .46303 .6299 .45966 .62453 .4534 Mtetra
.62453 .4534 .6299 .45966 .64069 .45628 .63535 .44999 Mtetra
.63535 .44999 .64069 .45628 .65152 .45288 .64621 .44657 Mtetra
.64621 .44657 .65152 .45288 .66239 .44947 .65711 .44314 Mtetra
.65711 .44314 .66239 .44947 .67331 .44604 .66805 .43969 Mtetra
.66805 .43969 .67331 .44604 .68427 .44261 .67904 .43623 Mtetra
.67904 .43623 .68427 .44261 .69527 .43916 .69007 .43275 Mtetra
.69007 .43275 .69527 .43916 .70631 .43569 .70114 .42927 Mtetra
.70114 .42927 .70631 .43569 .7174 .43222 .71226 .42577 Mtetra
.71226 .42577 .7174 .43222 .72853 .42873 .72342 .42226 Mtetra
.655 .752 .921 r
.72342 .42226 .72853 .42873 .7397 .42523 .73462 .41873 Mtetra
.73462 .41873 .7397 .42523 .75092 .42171 .74587 .4152 Mtetra
.74587 .4152 .75092 .42171 .76218 .41819 .75716 .41166 Mtetra
.75716 .41166 .76218 .41819 .77348 .41465 .7685 .40811 Mtetra
.655 .753 .922 r
.7685 .40811 .77348 .41465 .78484 .4111 .77989 .40454 Mtetra
.77989 .40454 .78484 .4111 .79623 .40753 .79132 .40096 Mtetra
.79132 .40096 .79623 .40753 .80767 .40395 .80279 .39737 Mtetra
.655 .754 .922 r
.80279 .39737 .80767 .40395 .81916 .40036 .81431 .39375 Mtetra
.656 .754 .922 r
.81431 .39375 .81916 .40036 .83069 .39674 .82588 .3901 Mtetra
.82588 .3901 .83069 .39674 .84227 .3931 .83749 .38643 Mtetra
.657 .754 .922 r
.83749 .38643 .84227 .3931 .85389 .38945 .84914 .38273 Mtetra
.657 .754 .921 r
.84914 .38273 .85389 .38945 .86556 .38577 .86084 .379 Mtetra
.658 .753 .92 r
.86084 .379 .86556 .38577 .87727 .38207 .87259 .37524 Mtetra
.652 .75 .922 r
.24535 .5654 .25164 .57089 .26106 .56797 .25479 .56251 Mtetra
.652 .752 .923 r
.25479 .56251 .26106 .56797 .27052 .56503 .26426 .55959 Mtetra
.653 .754 .924 r
.26426 .55959 .27052 .56503 .28001 .56207 .27377 .55664 Mtetra
.654 .755 .924 r
.27377 .55664 .28001 .56207 .28953 .55909 .28331 .55366 Mtetra
.655 .756 .924 r
.28331 .55366 .28953 .55909 .29909 .55607 .2929 .55064 Mtetra
.656 .757 .924 r
.2929 .55064 .29909 .55607 .30869 .55304 .30251 .54758 Mtetra
.657 .757 .924 r
.30251 .54758 .30869 .55304 .31832 .54999 .31217 .5445 Mtetra
.657 .757 .923 r
.31217 .5445 .31832 .54999 .32799 .54692 .32186 .54139 Mtetra
.657 .756 .923 r
.32186 .54139 .32799 .54692 .33769 .54384 .33159 .53828 Mtetra
.657 .756 .922 r
.33159 .53828 .33769 .54384 .34743 .54076 .34135 .53515 Mtetra
.657 .755 .922 r
.34135 .53515 .34743 .54076 .35721 .53766 .35114 .53201 Mtetra
.657 .754 .922 r
.35114 .53201 .35721 .53766 .36702 .53456 .36098 .52887 Mtetra
.657 .753 .921 r
.36098 .52887 .36702 .53456 .37686 .53145 .37085 .52573 Mtetra
.656 .753 .921 r
.37085 .52573 .37686 .53145 .38674 .52833 .38075 .52258 Mtetra
.656 .752 .921 r
.38075 .52258 .38674 .52833 .39666 .5252 .39069 .51942 Mtetra
.39069 .51942 .39666 .5252 .40662 .52207 .40067 .51626 Mtetra
.656 .752 .92 r
.40067 .51626 .40662 .52207 .41661 .51892 .41068 .51308 Mtetra
.41068 .51308 .41661 .51892 .42664 .51576 .42074 .5099 Mtetra
.42074 .5099 .42664 .51576 .4367 .51258 .43083 .5067 Mtetra
.43083 .5067 .4367 .51258 .44681 .5094 .44095 .50349 Mtetra
.656 .751 .92 r
.44095 .50349 .44681 .5094 .45695 .5062 .45112 .50028 Mtetra
.45112 .50028 .45695 .5062 .46713 .503 .46132 .49705 Mtetra
.46132 .49705 .46713 .503 .47734 .49978 .47157 .4938 Mtetra
.47157 .4938 .47734 .49978 .4876 .49655 .48185 .49055 Mtetra
.48185 .49055 .4876 .49655 .49789 .4933 .49217 .48728 Mtetra
.49217 .48728 .49789 .4933 .50823 .49005 .50253 .484 Mtetra
.50253 .484 .50823 .49005 .5186 .48678 .51292 .48071 Mtetra
.51292 .48071 .5186 .48678 .52901 .4835 .52336 .47741 Mtetra
.52336 .47741 .52901 .4835 .53946 .4802 .53384 .47409 Mtetra
.53384 .47409 .53946 .4802 .54996 .4769 .54436 .47076 Mtetra
.54436 .47076 .54996 .4769 .56049 .47358 .55491 .46742 Mtetra
.55491 .46742 .56049 .47358 .57106 .47025 .56551 .46407 Mtetra
.56551 .46407 .57106 .47025 .58167 .46691 .57615 .4607 Mtetra
.57615 .4607 .58167 .46691 .59232 .46355 .58683 .45732 Mtetra
.58683 .45732 .59232 .46355 .60302 .46018 .59755 .45393 Mtetra
.59755 .45393 .60302 .46018 .61375 .4568 .60832 .45052 Mtetra
.60832 .45052 .61375 .4568 .62453 .4534 .61912 .4471 Mtetra
.61912 .4471 .62453 .4534 .63535 .44999 .62997 .44367 Mtetra
.62997 .44367 .63535 .44999 .64621 .44657 .64085 .44022 Mtetra
.64085 .44022 .64621 .44657 .65711 .44314 .65178 .43676 Mtetra
.65178 .43676 .65711 .44314 .66805 .43969 .66276 .43329 Mtetra
.656 .752 .92 r
.66276 .43329 .66805 .43969 .67904 .43623 .67377 .42981 Mtetra
.656 .752 .921 r
.67377 .42981 .67904 .43623 .69007 .43275 .68483 .42631 Mtetra
.655 .752 .921 r
.68483 .42631 .69007 .43275 .70114 .42927 .69594 .42281 Mtetra
.69594 .42281 .70114 .42927 .71226 .42577 .70708 .41929 Mtetra
.70708 .41929 .71226 .42577 .72342 .42226 .71828 .41576 Mtetra
.71828 .41576 .72342 .42226 .73462 .41873 .72951 .41223 Mtetra
.655 .753 .922 r
.72951 .41223 .73462 .41873 .74587 .4152 .74079 .40869 Mtetra
.654 .753 .922 r
.74079 .40869 .74587 .4152 .75716 .41166 .75212 .40514 Mtetra
.654 .754 .923 r
.75212 .40514 .75716 .41166 .7685 .40811 .76349 .40158 Mtetra
.654 .755 .924 r
.76349 .40158 .7685 .40811 .77989 .40454 .77491 .39801 Mtetra
.77491 .39801 .77989 .40454 .79132 .40096 .78637 .39443 Mtetra
.654 .756 .924 r
.78637 .39443 .79132 .40096 .80279 .39737 .79788 .39082 Mtetra
.655 .757 .925 r
.79788 .39082 .80279 .39737 .81431 .39375 .80943 .38717 Mtetra
.656 .757 .924 r
.80943 .38717 .81431 .39375 .82588 .3901 .82103 .38349 Mtetra
.657 .757 .924 r
.82103 .38349 .82588 .3901 .83749 .38643 .83267 .37976 Mtetra
.658 .757 .923 r
.83267 .37976 .83749 .38643 .84914 .38273 .84436 .376 Mtetra
.659 .756 .922 r
.84436 .376 .84914 .38273 .86084 .379 .85609 .3722 Mtetra
.659 .755 .92 r
.85609 .3722 .86084 .379 .87259 .37524 .86786 .36837 Mtetra
.648 .749 .923 r
.23902 .55988 .24535 .5654 .25479 .56251 .24847 .55705 Mtetra
.649 .753 .925 r
.24847 .55705 .25479 .56251 .26426 .55959 .25796 .55418 Mtetra
.65 .756 .927 r
.25796 .55418 .26426 .55959 .27377 .55664 .26748 .55128 Mtetra
.651 .758 .928 r
.26748 .55128 .27377 .55664 .28331 .55366 .27704 .54833 Mtetra
.653 .761 .929 r
.27704 .54833 .28331 .55366 .2929 .55064 .28664 .54532 Mtetra
.655 .763 .929 r
.28664 .54532 .2929 .55064 .30251 .54758 .29628 .54226 Mtetra
.657 .763 .928 r
.29628 .54226 .30251 .54758 .31217 .5445 .30596 .53915 Mtetra
.658 .763 .928 r
.30596 .53915 .31217 .5445 .32186 .54139 .31567 .53599 Mtetra
.659 .763 .927 r
.31567 .53599 .32186 .54139 .33159 .53828 .32543 .53281 Mtetra
.659 .761 .925 r
.32543 .53281 .33159 .53828 .34135 .53515 .33521 .52962 Mtetra
.659 .76 .924 r
.33521 .52962 .34135 .53515 .35114 .53201 .34503 .52642 Mtetra
.658 .758 .923 r
.34503 .52642 .35114 .53201 .36098 .52887 .35489 .52322 Mtetra
.658 .756 .923 r
.35489 .52322 .36098 .52887 .37085 .52573 .36479 .52002 Mtetra
.657 .755 .922 r
.36479 .52002 .37085 .52573 .38075 .52258 .37471 .51682 Mtetra
.657 .754 .921 r
.37471 .51682 .38075 .52258 .39069 .51942 .38468 .51362 Mtetra
.657 .753 .921 r
.38468 .51362 .39069 .51942 .40067 .51626 .39468 .51042 Mtetra
.656 .752 .921 r
.39468 .51042 .40067 .51626 .41068 .51308 .40472 .50721 Mtetra
.40472 .50721 .41068 .51308 .42074 .5099 .4148 .504 Mtetra
.656 .752 .92 r
.4148 .504 .42074 .5099 .43083 .5067 .42491 .50078 Mtetra
.42491 .50078 .43083 .5067 .44095 .50349 .43506 .49755 Mtetra
.656 .751 .92 r
.43506 .49755 .44095 .50349 .45112 .50028 .44525 .4943 Mtetra
.44525 .4943 .45112 .50028 .46132 .49705 .45548 .49105 Mtetra
.45548 .49105 .46132 .49705 .47157 .4938 .46575 .48778 Mtetra
.46575 .48778 .47157 .4938 .48185 .49055 .47605 .48451 Mtetra
.47605 .48451 .48185 .49055 .49217 .48728 .4864 .48122 Mtetra
.4864 .48122 .49217 .48728 .50253 .484 .49678 .47792 Mtetra
.49678 .47792 .50253 .484 .51292 .48071 .50721 .4746 Mtetra
.50721 .4746 .51292 .48071 .52336 .47741 .51767 .47127 Mtetra
.51767 .47127 .52336 .47741 .53384 .47409 .52817 .46793 Mtetra
.52817 .46793 .53384 .47409 .54436 .47076 .53872 .46458 Mtetra
.53872 .46458 .54436 .47076 .55491 .46742 .5493 .46122 Mtetra
.5493 .46122 .55491 .46742 .56551 .46407 .55993 .45784 Mtetra
.55993 .45784 .56551 .46407 .57615 .4607 .57059 .45445 Mtetra
.57059 .45445 .57615 .4607 .58683 .45732 .5813 .45104 Mtetra
.5813 .45104 .58683 .45732 .59755 .45393 .59205 .44762 Mtetra
.59205 .44762 .59755 .45393 .60832 .45052 .60284 .44419 Mtetra
.60284 .44419 .60832 .45052 .61912 .4471 .61367 .44075 Mtetra
.61367 .44075 .61912 .4471 .62997 .44367 .62455 .43729 Mtetra
.62455 .43729 .62997 .44367 .64085 .44022 .63546 .43383 Mtetra
.63546 .43383 .64085 .44022 .65178 .43676 .64642 .43034 Mtetra
.64642 .43034 .65178 .43676 .66276 .43329 .65743 .42685 Mtetra
.655 .752 .921 r
.65743 .42685 .66276 .43329 .67377 .42981 .66847 .42335 Mtetra
.66847 .42335 .67377 .42981 .68483 .42631 .67956 .41984 Mtetra
.67956 .41984 .68483 .42631 .69594 .42281 .6907 .41632 Mtetra
.655 .752 .922 r
.6907 .41632 .69594 .42281 .70708 .41929 .70187 .4128 Mtetra
.654 .753 .922 r
.70187 .4128 .70708 .41929 .71828 .41576 .7131 .40928 Mtetra
.653 .754 .923 r
.7131 .40928 .71828 .41576 .72951 .41223 .72437 .40575 Mtetra
.653 .755 .924 r
.72437 .40575 .72951 .41223 .74079 .40869 .73568 .40223 Mtetra
.652 .756 .926 r
.73568 .40223 .74079 .40869 .75212 .40514 .74704 .3987 Mtetra
.652 .757 .927 r
.74704 .3987 .75212 .40514 .76349 .40158 .75845 .39516 Mtetra
.652 .759 .928 r
.75845 .39516 .76349 .40158 .77491 .39801 .76991 .39161 Mtetra
.653 .761 .929 r
.76991 .39161 .77491 .39801 .78637 .39443 .7814 .38802 Mtetra
.654 .762 .929 r
.7814 .38802 .78637 .39443 .79788 .39082 .79295 .3844 Mtetra
.655 .763 .929 r
.79295 .3844 .79788 .39082 .80943 .38717 .80453 .38071 Mtetra
.657 .763 .928 r
.80453 .38071 .80943 .38717 .82103 .38349 .81616 .37697 Mtetra
.659 .763 .927 r
.81616 .37697 .82103 .38349 .83267 .37976 .82783 .37316 Mtetra
.66 .762 .925 r
.82783 .37316 .83267 .37976 .84436 .376 .83955 .3693 Mtetra
.662 .76 .923 r
.83955 .3693 .84436 .376 .85609 .3722 .8513 .36539 Mtetra
.662 .757 .92 r
.8513 .36539 .85609 .3722 .86786 .36837 .8631 .36144 Mtetra
.643 .748 .925 r
.23264 .55431 .23902 .55988 .24847 .55705 .2421 .55158 Mtetra
.643 .752 .928 r
.2421 .55158 .24847 .55705 .25796 .55418 .2516 .54881 Mtetra
.645 .757 .931 r
.2516 .54881 .25796 .55418 .26748 .55128 .26114 .54599 Mtetra
.647 .761 .933 r
.26114 .54599 .26748 .55128 .27704 .54833 .27071 .54312 Mtetra
.65 .766 .934 r
.27071 .54312 .27704 .54833 .28664 .54532 .28033 .54016 Mtetra
.652 .769 .935 r
.28033 .54016 .28664 .54532 .29628 .54226 .28999 .53712 Mtetra
.656 .771 .934 r
.28999 .53712 .29628 .54226 .30596 .53915 .29969 .534 Mtetra
.658 .772 .934 r
.29969 .534 .30596 .53915 .31567 .53599 .30943 .53081 Mtetra
.66 .772 .932 r
.30943 .53081 .31567 .53599 .32543 .53281 .31921 .52756 Mtetra
.661 .771 .931 r
.31921 .52756 .32543 .53281 .33521 .52962 .32902 .52429 Mtetra
.661 .769 .929 r
.32902 .52429 .33521 .52962 .34503 .52642 .33887 .521 Mtetra
.661 .766 .928 r
.33887 .521 .34503 .52642 .35489 .52322 .34876 .51771 Mtetra
.66 .764 .926 r
.34876 .51771 .35489 .52322 .36479 .52002 .35868 .51443 Mtetra
.659 .761 .925 r
.35868 .51443 .36479 .52002 .37471 .51682 .36863 .51115 Mtetra
.659 .759 .924 r
.36863 .51115 .37471 .51682 .38468 .51362 .37862 .50789 Mtetra
.658 .757 .923 r
.37862 .50789 .38468 .51362 .39468 .51042 .38865 .50463 Mtetra
.657 .756 .922 r
.38865 .50463 .39468 .51042 .40472 .50721 .39871 .50137 Mtetra
.657 .755 .922 r
.39871 .50137 .40472 .50721 .4148 .504 .40881 .49812 Mtetra
.657 .754 .922 r
.40881 .49812 .4148 .504 .42491 .50078 .41895 .49486 Mtetra
.656 .753 .921 r
.41895 .49486 .42491 .50078 .43506 .49755 .42913 .49159 Mtetra
.42913 .49159 .43506 .49755 .44525 .4943 .43934 .48832 Mtetra
.656 .752 .921 r
.43934 .48832 .44525 .4943 .45548 .49105 .4496 .48503 Mtetra
.4496 .48503 .45548 .49105 .46575 .48778 .45989 .48174 Mtetra
.45989 .48174 .46575 .48778 .47605 .48451 .47022 .47844 Mtetra
.47022 .47844 .47605 .48451 .4864 .48122 .48059 .47512 Mtetra
.48059 .47512 .4864 .48122 .49678 .47792 .491 .4718 Mtetra
.491 .4718 .49678 .47792 .50721 .4746 .50145 .46846 Mtetra
.656 .752 .92 r
.50145 .46846 .50721 .4746 .51767 .47127 .51194 .46511 Mtetra
.51194 .46511 .51767 .47127 .52817 .46793 .52247 .46174 Mtetra
.52247 .46174 .52817 .46793 .53872 .46458 .53304 .45837 Mtetra
.53304 .45837 .53872 .46458 .5493 .46122 .54365 .45498 Mtetra
.656 .752 .921 r
.54365 .45498 .5493 .46122 .55993 .45784 .5543 .45158 Mtetra
.5543 .45158 .55993 .45784 .57059 .45445 .565 .44816 Mtetra
.565 .44816 .57059 .45445 .5813 .45104 .57573 .44473 Mtetra
.57573 .44473 .5813 .45104 .59205 .44762 .58651 .44129 Mtetra
.58651 .44129 .59205 .44762 .60284 .44419 .59733 .43784 Mtetra
.59733 .43784 .60284 .44419 .61367 .44075 .60819 .43438 Mtetra
.655 .752 .921 r
.60819 .43438 .61367 .44075 .62455 .43729 .61909 .4309 Mtetra
.61909 .4309 .62455 .43729 .63546 .43383 .63004 .42742 Mtetra
.63004 .42742 .63546 .43383 .64642 .43034 .64102 .42392 Mtetra
.655 .753 .922 r
.64102 .42392 .64642 .43034 .65743 .42685 .65206 .42042 Mtetra
.654 .753 .922 r
.65206 .42042 .65743 .42685 .66847 .42335 .66313 .41692 Mtetra
.654 .754 .923 r
.66313 .41692 .66847 .42335 .67956 .41984 .67426 .41341 Mtetra
.653 .754 .924 r
.67426 .41341 .67956 .41984 .6907 .41632 .68542 .4099 Mtetra
.653 .755 .925 r
.68542 .4099 .6907 .41632 .70187 .4128 .69663 .4064 Mtetra
.652 .757 .926 r
.69663 .4064 .70187 .4128 .7131 .40928 .70789 .4029 Mtetra
.651 .758 .928 r
.70789 .4029 .7131 .40928 .72437 .40575 .7192 .39942 Mtetra
.65 .76 .93 r
.7192 .39942 .72437 .40575 .73568 .40223 .73055 .39594 Mtetra
.649 .762 .932 r
.73055 .39594 .73568 .40223 .74704 .3987 .74195 .39245 Mtetra
.649 .765 .934 r
.74195 .39245 .74704 .3987 .75845 .39516 .75339 .38895 Mtetra
.649 .767 .935 r
.75339 .38895 .75845 .39516 .76991 .39161 .76488 .38541 Mtetra
.651 .77 .936 r
.76488 .38541 .76991 .39161 .7814 .38802 .77642 .38182 Mtetra
.653 .771 .935 r
.77642 .38182 .7814 .38802 .79295 .3844 .788 .37815 Mtetra
.656 .772 .934 r
.788 .37815 .79295 .3844 .80453 .38071 .79961 .3744 Mtetra
.659 .771 .932 r
.79961 .3744 .80453 .38071 .81616 .37697 .81127 .37055 Mtetra
.662 .77 .93 r
.81127 .37055 .81616 .37697 .82783 .37316 .82297 .36662 Mtetra
.664 .767 .927 r
.82297 .36662 .82783 .37316 .83955 .3693 .8347 .36261 Mtetra
.666 .764 .923 r
.8347 .36261 .83955 .3693 .8513 .36539 .84648 .35856 Mtetra
.667 .76 .92 r
.84648 .35856 .8513 .36539 .8631 .36144 .85831 .35446 Mtetra
.636 .746 .928 r
.22623 .54871 .23264 .55431 .2421 .55158 .23569 .5461 Mtetra
.636 .752 .932 r
.23569 .5461 .2421 .55158 .2516 .54881 .2452 .54347 Mtetra
.637 .758 .935 r
.2452 .54347 .2516 .54881 .26114 .54599 .25474 .54079 Mtetra
.639 .764 .939 r
.25474 .54079 .26114 .54599 .27071 .54312 .26433 .53806 Mtetra
.641 .771 .942 r
.26433 .53806 .27071 .54312 .28033 .54016 .27396 .53523 Mtetra
.645 .777 .944 r
.27396 .53523 .28033 .54016 .28999 .53712 .28363 .53229 Mtetra
.65 .783 .945 r
.28363 .53229 .28999 .53712 .29969 .534 .29335 .52923 Mtetra
.654 .788 .945 r
.29335 .52923 .29969 .534 .30943 .53081 .30311 .52606 Mtetra
.659 .79 .945 r
.30311 .52606 .30943 .53081 .31921 .52756 .31291 .52278 Mtetra
.662 .79 .943 r
.31291 .52278 .31921 .52756 .32902 .52429 .32276 .51942 Mtetra
.664 .788 .941 r
.32276 .51942 .32902 .52429 .33887 .521 .33264 .51601 Mtetra
.665 .785 .938 r
.33264 .51601 .33887 .521 .34876 .51771 .34255 .51258 Mtetra
.664 .78 .935 r
.34255 .51258 .34876 .51771 .35868 .51443 .3525 .50916 Mtetra
.664 .775 .933 r
.3525 .50916 .35868 .51443 .36863 .51115 .36249 .50574 Mtetra
.662 .771 .93 r
.36249 .50574 .36863 .51115 .37862 .50789 .37251 .50235 Mtetra
.661 .767 .928 r
.37251 .50235 .37862 .50789 .38865 .50463 .38257 .49898 Mtetra
.66 .763 .926 r
.38257 .49898 .38865 .50463 .39871 .50137 .39266 .49563 Mtetra
.659 .76 .925 r
.39266 .49563 .39871 .50137 .40881 .49812 .40278 .49229 Mtetra
.658 .758 .924 r
.40278 .49229 .40881 .49812 .41895 .49486 .41295 .48897 Mtetra
.658 .756 .923 r
.41295 .48897 .41895 .49486 .42913 .49159 .42315 .48565 Mtetra
.657 .755 .922 r
.42315 .48565 .42913 .49159 .43934 .48832 .43339 .48233 Mtetra
.657 .754 .922 r
.43339 .48233 .43934 .48832 .4496 .48503 .44367 .479 Mtetra
.656 .753 .921 r
.44367 .479 .4496 .48503 .45989 .48174 .45399 .47567 Mtetra
.45399 .47567 .45989 .48174 .47022 .47844 .46434 .47234 Mtetra
.656 .752 .921 r
.46434 .47234 .47022 .47844 .48059 .47512 .47474 .46899 Mtetra
.47474 .46899 .48059 .47512 .491 .4718 .48517 .46564 Mtetra
.48517 .46564 .491 .4718 .50145 .46846 .49565 .46227 Mtetra
.656 .752 .92 r
.49565 .46227 .50145 .46846 .51194 .46511 .50617 .4589 Mtetra
.50617 .4589 .51194 .46511 .52247 .46174 .51672 .45551 Mtetra
.51672 .45551 .52247 .46174 .53304 .45837 .52732 .45211 Mtetra
.52732 .45211 .53304 .45837 .54365 .45498 .53796 .44869 Mtetra
.656 .752 .921 r
.53796 .44869 .54365 .45498 .5543 .45158 .54864 .44527 Mtetra
.54864 .44527 .5543 .45158 .565 .44816 .55936 .44183 Mtetra
.55936 .44183 .565 .44816 .57573 .44473 .57012 .43839 Mtetra
.655 .752 .921 r
.57012 .43839 .57573 .44473 .58651 .44129 .58092 .43493 Mtetra
.58092 .43493 .58651 .44129 .59733 .43784 .59177 .43146 Mtetra
.59177 .43146 .59733 .43784 .60819 .43438 .60266 .42799 Mtetra
.655 .753 .922 r
.60266 .42799 .60819 .43438 .61909 .4309 .61359 .4245 Mtetra
.654 .753 .922 r
.61359 .4245 .61909 .4309 .63004 .42742 .62457 .42102 Mtetra
.654 .754 .923 r
.62457 .42102 .63004 .42742 .64102 .42392 .63559 .41753 Mtetra
.653 .755 .924 r
.63559 .41753 .64102 .42392 .65206 .42042 .64665 .41405 Mtetra
.652 .756 .926 r
.64665 .41405 .65206 .42042 .66313 .41692 .65776 .41058 Mtetra
.651 .758 .928 r
.65776 .41058 .66313 .41692 .67426 .41341 .66892 .40712 Mtetra
.649 .76 .93 r
.66892 .40712 .67426 .41341 .68542 .4099 .68012 .40368 Mtetra
.648 .762 .933 r
.68012 .40368 .68542 .4099 .69663 .4064 .69137 .40026 Mtetra
.646 .765 .936 r
.69137 .40026 .69663 .4064 .70789 .4029 .70267 .39686 Mtetra
.644 .769 .939 r
.70267 .39686 .70789 .4029 .7192 .39942 .71401 .39347 Mtetra
.643 .773 .943 r
.71401 .39347 .7192 .39942 .73055 .39594 .72541 .39009 Mtetra
.642 .778 .946 r
.72541 .39009 .73055 .39594 .74195 .39245 .73685 .38668 Mtetra
.643 .782 .948 r
.73685 .38668 .74195 .39245 .75339 .38895 .74833 .38321 Mtetra
.646 .785 .949 r
.74833 .38321 .75339 .38895 .76488 .38541 .75986 .37967 Mtetra
.65 .788 .948 r
.75986 .37967 .76488 .38541 .77642 .38182 .77143 .37601 Mtetra
.655 .788 .946 r
.77143 .37601 .77642 .38182 .788 .37815 .78303 .37223 Mtetra
.66 .787 .942 r
.78303 .37223 .788 .37815 .79961 .3744 .79468 .36831 Mtetra
.664 .784 .938 r
.79468 .36831 .79961 .3744 .81127 .37055 .80636 .36429 Mtetra
.668 .779 .933 r
.80636 .36429 .81127 .37055 .82297 .36662 .81808 .36016 Mtetra
.67 .774 .928 r
.81808 .36016 .82297 .36662 .8347 .36261 .82983 .35595 Mtetra
.672 .769 .923 r
.82983 .35595 .8347 .36261 .84648 .35856 .84163 .35171 Mtetra
.672 .763 .919 r
.84163 .35171 .84648 .35856 .85831 .35446 .85348 .34743 Mtetra
.63 .745 .93 r
.21976 .54307 .22623 .54871 .23569 .5461 .22924 .54057 Mtetra
.629 .749 .934 r
.22924 .54057 .23569 .5461 .2452 .54347 .23875 .53807 Mtetra
.628 .755 .938 r
.23875 .53807 .2452 .54347 .25474 .54079 .2483 .53556 Mtetra
.629 .762 .942 r
.2483 .53556 .25474 .54079 .26433 .53806 .25789 .533 Mtetra
.63 .77 .947 r
.25789 .533 .26433 .53806 .27396 .53523 .26753 .53037 Mtetra
.634 .779 .951 r
.26753 .53037 .27396 .53523 .28363 .53229 .27721 .52763 Mtetra
.639 .789 .954 r
.27721 .52763 .28363 .53229 .29335 .52923 .28694 .52474 Mtetra
.645 .797 .956 r
.28694 .52474 .29335 .52923 .30311 .52606 .29672 .52168 Mtetra
.653 .804 .956 r
.29672 .52168 .30311 .52606 .31291 .52278 .30654 .51844 Mtetra
.659 .808 .955 r
.30654 .51844 .31291 .52278 .32276 .51942 .31641 .51506 Mtetra
.664 .809 .953 r
.31641 .51506 .32276 .51942 .33264 .51601 .32632 .51157 Mtetra
.667 .807 .95 r
.32632 .51157 .33264 .51601 .34255 .51258 .33627 .50801 Mtetra
.668 .803 .947 r
.33627 .50801 .34255 .51258 .3525 .50916 .34626 .50441 Mtetra
.668 .798 .944 r
.34626 .50441 .3525 .50916 .36249 .50574 .35628 .50082 Mtetra
.667 .792 .941 r
.35628 .50082 .36249 .50574 .37251 .50235 .36633 .49726 Mtetra
.666 .786 .938 r
.36633 .49726 .37251 .50235 .38257 .49898 .37642 .49372 Mtetra
.664 .78 .935 r
.37642 .49372 .38257 .49898 .39266 .49563 .38654 .49022 Mtetra
.663 .775 .933 r
.38654 .49022 .39266 .49563 .40278 .49229 .3967 .48676 Mtetra
.661 .77 .931 r
.3967 .48676 .40278 .49229 .41295 .48897 .40689 .48332 Mtetra
.66 .767 .929 r
.40689 .48332 .41295 .48897 .42315 .48565 .41712 .4799 Mtetra
.659 .764 .927 r
.41712 .4799 .42315 .48565 .43339 .48233 .42739 .4765 Mtetra
.658 .762 .926 r
.42739 .4765 .43339 .48233 .44367 .479 .4377 .47311 Mtetra
.658 .76 .925 r
.4377 .47311 .44367 .479 .45399 .47567 .44804 .46973 Mtetra
.657 .759 .925 r
.44804 .46973 .45399 .47567 .46434 .47234 .45842 .46634 Mtetra
.657 .758 .924 r
.45842 .46634 .46434 .47234 .47474 .46899 .46884 .46295 Mtetra
.656 .757 .924 r
.46884 .46295 .47474 .46899 .48517 .46564 .47931 .45956 Mtetra
.656 .756 .924 r
.47931 .45956 .48517 .46564 .49565 .46227 .48981 .45616 Mtetra
.656 .756 .923 r
.48981 .45616 .49565 .46227 .50617 .4589 .50035 .45275 Mtetra
.50035 .45275 .50617 .4589 .51672 .45551 .51093 .44933 Mtetra
.656 .755 .923 r
.51093 .44933 .51672 .45551 .52732 .45211 .52156 .44591 Mtetra
.655 .755 .923 r
.52156 .44591 .52732 .45211 .53796 .44869 .53222 .44248 Mtetra
.53222 .44248 .53796 .44869 .54864 .44527 .54293 .43903 Mtetra
.655 .755 .924 r
.54293 .43903 .54864 .44527 .55936 .44183 .55368 .43558 Mtetra
.655 .756 .924 r
.55368 .43558 .55936 .44183 .57012 .43839 .56447 .43213 Mtetra
.654 .756 .925 r
.56447 .43213 .57012 .43839 .58092 .43493 .5753 .42866 Mtetra
.654 .757 .925 r
.5753 .42866 .58092 .43493 .59177 .43146 .58618 .4252 Mtetra
.653 .757 .926 r
.58618 .4252 .59177 .43146 .60266 .42799 .5971 .42173 Mtetra
.653 .758 .927 r
.5971 .42173 .60266 .42799 .61359 .4245 .60806 .41827 Mtetra
.652 .76 .929 r
.60806 .41827 .61359 .4245 .62457 .42102 .61907 .41482 Mtetra
.65 .761 .93 r
.61907 .41482 .62457 .42102 .63559 .41753 .63012 .41138 Mtetra
.649 .763 .933 r
.63012 .41138 .63559 .41753 .64665 .41405 .64122 .40796 Mtetra
.647 .766 .936 r
.64122 .40796 .64665 .41405 .65776 .41058 .65237 .40457 Mtetra
.644 .769 .939 r
.65237 .40457 .65776 .41058 .66892 .40712 .66356 .40121 Mtetra
.641 .773 .943 r
.66356 .40121 .66892 .40712 .68012 .40368 .6748 .3979 Mtetra
.638 .777 .947 r
.6748 .3979 .68012 .40368 .69137 .40026 .68609 .39461 Mtetra
.635 .782 .952 r
.68609 .39461 .69137 .40026 .70267 .39686 .69743 .39134 Mtetra
.634 .787 .956 r
.69743 .39134 .70267 .39686 .71401 .39347 .70882 .38808 Mtetra
.633 .793 .959 r
.70882 .38808 .71401 .39347 .72541 .39009 .72026 .38479 Mtetra
.634 .798 .961 r
.72026 .38479 .72541 .39009 .73685 .38668 .73174 .38142 Mtetra
.639 .802 .961 r
.73174 .38142 .73685 .38668 .74833 .38321 .74326 .37793 Mtetra
.645 .805 .96 r
.74326 .37793 .74833 .38321 .75986 .37967 .75482 .37429 Mtetra
.653 .805 .956 r
.75482 .37429 .75986 .37967 .77143 .37601 .76642 .37047 Mtetra
.661 .802 .951 r
.76642 .37047 .77143 .37601 .78303 .37223 .77805 .36647 Mtetra
.668 .798 .944 r
.77805 .36647 .78303 .37223 .79468 .36831 .78971 .3623 Mtetra
.673 .791 .938 r
.78971 .3623 .79468 .36831 .80636 .36429 .80141 .35802 Mtetra
.675 .784 .931 r
.80141 .35802 .80636 .36429 .81808 .36016 .81315 .35365 Mtetra
.677 .777 .926 r
.81315 .35365 .81808 .36016 .82983 .35595 .82492 .34923 Mtetra
.677 .771 .921 r
.82492 .34923 .82983 .35595 .84163 .35171 .83674 .34479 Mtetra
.677 .765 .917 r
.83674 .34479 .84163 .35171 .85348 .34743 .84861 .34035 Mtetra
.629 .745 .931 r
.21326 .53739 .21976 .54307 .22924 .54057 .22275 .53489 Mtetra
.626 .744 .932 r
.22275 .53489 .22924 .54057 .23875 .53807 .23228 .53244 Mtetra
.624 .746 .935 r
.23228 .53244 .23875 .53807 .2483 .53556 .24184 .53002 Mtetra
.621 .749 .938 r
.24184 .53002 .2483 .53556 .25789 .533 .25143 .52762 Mtetra
.619 .755 .943 r
.25143 .52762 .25789 .533 .26753 .53037 .26107 .52524 Mtetra
.619 .766 .95 r
.26107 .52524 .26753 .53037 .27721 .52763 .27075 .5228 Mtetra
.621 .779 .957 r
.27075 .5228 .27721 .52763 .28694 .52474 .28047 .52025 Mtetra
.625 .794 .963 r
.28047 .52025 .28694 .52474 .29672 .52168 .29025 .51754 Mtetra
.633 .811 .968 r
.29025 .51754 .29672 .52168 .30654 .51844 .30008 .5146 Mtetra
.64 .825 .971 r
.30008 .5146 .30654 .51844 .31641 .51506 .30997 .51144 Mtetra
.649 .837 .972 r
.30997 .51144 .31641 .51506 .32632 .51157 .3199 .50805 Mtetra
.656 .844 .972 r
.3199 .50805 .32632 .51157 .33627 .50801 .32988 .50449 Mtetra
.663 .846 .97 r
.32988 .50449 .33627 .50801 .34626 .50441 .3399 .50079 Mtetra
.667 .843 .967 r
.3399 .50079 .34626 .50441 .35628 .50082 .34996 .49702 Mtetra
.669 .837 .964 r
.34996 .49702 .35628 .50082 .36633 .49726 .36005 .49323 Mtetra
.67 .829 .96 r
.36005 .49323 .36633 .49726 .37642 .49372 .37018 .48944 Mtetra
.669 .82 .956 r
.37018 .48944 .37642 .49372 .38654 .49022 .38034 .48569 Mtetra
.668 .811 .952 r
.38034 .48569 .38654 .49022 .3967 .48676 .39054 .48199 Mtetra
.667 .802 .947 r
.39054 .48199 .3967 .48676 .40689 .48332 .40077 .47833 Mtetra
.665 .794 .944 r
.40077 .47833 .40689 .48332 .41712 .4799 .41103 .47472 Mtetra
.663 .787 .94 r
.41103 .47472 .41712 .4799 .42739 .4765 .42133 .47115 Mtetra
.662 .782 .938 r
.42133 .47115 .42739 .4765 .4377 .47311 .43167 .46762 Mtetra
.66 .777 .935 r
.43167 .46762 .4377 .47311 .44804 .46973 .44204 .46411 Mtetra
.659 .773 .933 r
.44204 .46411 .44804 .46973 .45842 .46634 .45245 .46063 Mtetra
.658 .77 .932 r
.45245 .46063 .45842 .46634 .46884 .46295 .4629 .45716 Mtetra
.658 .768 .931 r
.4629 .45716 .46884 .46295 .47931 .45956 .47339 .4537 Mtetra
.657 .766 .93 r
.47339 .4537 .47931 .45956 .48981 .45616 .48392 .45024 Mtetra
.656 .764 .929 r
.48392 .45024 .48981 .45616 .50035 .45275 .49449 .44679 Mtetra
.49449 .44679 .50035 .45275 .51093 .44933 .5051 .44334 Mtetra
.655 .763 .929 r
.5051 .44334 .51093 .44933 .52156 .44591 .51576 .43989 Mtetra
.51576 .43989 .52156 .44591 .53222 .44248 .52645 .43644 Mtetra
.654 .763 .93 r
.52645 .43644 .53222 .44248 .54293 .43903 .53718 .433 Mtetra
.653 .763 .93 r
.53718 .433 .54293 .43903 .55368 .43558 .54796 .42955 Mtetra
.652 .764 .931 r
.54796 .42955 .55368 .43558 .56447 .43213 .55878 .42612 Mtetra
.651 .766 .933 r
.55878 .42612 .56447 .43213 .5753 .42866 .56965 .42269 Mtetra
.65 .767 .935 r
.56965 .42269 .5753 .42866 .58618 .4252 .58055 .41927 Mtetra
.648 .769 .937 r
.58055 .41927 .58618 .4252 .5971 .42173 .59151 .41588 Mtetra
.646 .772 .94 r
.59151 .41588 .5971 .42173 .60806 .41827 .6025 .41252 Mtetra
.643 .776 .944 r
.6025 .41252 .60806 .41827 .61907 .41482 .61355 .40918 Mtetra
.64 .78 .948 r
.61355 .40918 .61907 .41482 .63012 .41138 .62464 .40589 Mtetra
.636 .785 .953 r
.62464 .40589 .63012 .41138 .64122 .40796 .63578 .40265 Mtetra
.631 .791 .959 r
.63578 .40265 .64122 .40796 .65237 .40457 .64696 .39946 Mtetra
.626 .798 .965 r
.64696 .39946 .65237 .40457 .66356 .40121 .6582 .39631 Mtetra
.62 .806 .971 r
.6582 .39631 .66356 .40121 .6748 .3979 .66949 .39321 Mtetra
.615 .813 .976 r
.66949 .39321 .6748 .3979 .68609 .39461 .68083 .3901 Mtetra
.612 .821 .98 r
.68083 .3901 .68609 .39461 .69743 .39134 .69222 .38698 Mtetra
.612 .828 .983 r
.69222 .38698 .69743 .39134 .70882 .38808 .70365 .38378 Mtetra
.617 .833 .983 r
.70365 .38378 .70882 .38808 .72026 .38479 .71513 .38043 Mtetra
.626 .835 .981 r
.71513 .38043 .72026 .38479 .73174 .38142 .72664 .37691 Mtetra
.64 .835 .975 r
.72664 .37691 .73174 .38142 .74326 .37793 .73819 .37315 Mtetra
.654 .83 .968 r
.73819 .37315 .74326 .37793 .75482 .37429 .74977 .36916 Mtetra
.667 .821 .958 r
.74977 .36916 .75482 .37429 .76642 .37047 .76137 .36493 Mtetra
.676 .81 .947 r
.76137 .36493 .76642 .37047 .77805 .36647 .77301 .36052 Mtetra
.681 .797 .937 r
.77301 .36052 .77805 .36647 .78971 .3623 .78469 .35599 Mtetra
.683 .786 .928 r
.78469 .35599 .78971 .3623 .80141 .35802 .7964 .35139 Mtetra
.682 .776 .922 r
.7964 .35139 .80141 .35802 .81315 .35365 .80815 .34681 Mtetra
.681 .769 .917 r
.80815 .34681 .81315 .35365 .82492 .34923 .81996 .34224 Mtetra
.679 .764 .915 r
.81996 .34224 .82492 .34923 .83674 .34479 .8318 .3377 Mtetra
.677 .761 .914 r
.8318 .3377 .83674 .34479 .84861 .34035 .8437 .33321 Mtetra
.636 .746 .928 r
.20671 .53168 .21326 .53739 .22275 .53489 .21623 .52901 Mtetra
.632 .74 .926 r
.21623 .52901 .22275 .53489 .23228 .53244 .22579 .52643 Mtetra
.627 .735 .925 r
.22579 .52643 .23228 .53244 .24184 .53002 .23537 .52395 Mtetra
.621 .732 .926 r
.23537 .52395 .24184 .53002 .25143 .52762 .24498 .5216 Mtetra
.613 .732 .93 r
.24498 .5216 .25143 .52762 .26107 .52524 .25462 .51939 Mtetra
.608 .737 .937 r
.25462 .51939 .26107 .52524 .27075 .5228 .26429 .51725 Mtetra
.604 .747 .946 r
.26429 .51725 .27075 .5228 .28047 .52025 .27401 .51512 Mtetra
.604 .764 .956 r
.27401 .51512 .28047 .52025 .29025 .51754 .28377 .5129 Mtetra
.608 .786 .966 r
.28377 .5129 .29025 .51754 .30008 .5146 .29359 .51048 Mtetra
.615 .809 .975 r
.29359 .51048 .30008 .5146 .30997 .51144 .30347 .5078 Mtetra
.626 .832 .979 r
.30347 .5078 .30997 .51144 .3199 .50805 .3134 .50478 Mtetra
.636 .85 .982 r
.3134 .50478 .3199 .50805 .32988 .50449 .3234 .50147 Mtetra
.647 .863 .981 r
.3234 .50147 .32988 .50449 .3399 .50079 .33344 .49788 Mtetra
.655 .87 .98 r
.33344 .49788 .3399 .50079 .34996 .49702 .34354 .49409 Mtetra
.662 .872 .978 r
.34354 .49409 .34996 .49702 .36005 .49323 .35367 .49017 Mtetra
.667 .868 .975 r
.35367 .49017 .36005 .49323 .37018 .48944 .36384 .48618 Mtetra
.669 .862 .973 r
.36384 .48618 .37018 .48944 .38034 .48569 .37405 .48219 Mtetra
.67 .853 .97 r
.37405 .48219 .38034 .48569 .39054 .48199 .38428 .47822 Mtetra
.67 .844 .967 r
.38428 .47822 .39054 .48199 .40077 .47833 .39455 .47431 Mtetra
.668 .834 .963 r
.39455 .47431 .40077 .47833 .41103 .47472 .40486 .47046 Mtetra
.667 .825 .96 r
.40486 .47046 .41103 .47472 .42133 .47115 .4152 .46667 Mtetra
.665 .817 .956 r
.4152 .46667 .42133 .47115 .43167 .46762 .42557 .46294 Mtetra
.663 .81 .954 r
.42557 .46294 .43167 .46762 .44204 .46411 .43597 .45926 Mtetra
.661 .803 .951 r
.43597 .45926 .44204 .46411 .45245 .46063 .44642 .45563 Mtetra
.66 .798 .949 r
.44642 .45563 .45245 .46063 .4629 .45716 .4569 .45203 Mtetra
.658 .794 .947 r
.4569 .45203 .4629 .45716 .47339 .4537 .46742 .44847 Mtetra
.657 .791 .946 r
.46742 .44847 .47339 .4537 .48392 .45024 .47798 .44494 Mtetra
.655 .788 .945 r
.47798 .44494 .48392 .45024 .49449 .44679 .48858 .44143 Mtetra
.654 .787 .945 r
.48858 .44143 .49449 .44679 .5051 .44334 .49922 .43794 Mtetra
.653 .786 .945 r
.49922 .43794 .5051 .44334 .51576 .43989 .50991 .43446 Mtetra
.651 .785 .945 r
.50991 .43446 .51576 .43989 .52645 .43644 .52063 .43101 Mtetra
.65 .785 .946 r
.52063 .43101 .52645 .43644 .53718 .433 .5314 .42758 Mtetra
.648 .786 .948 r
.5314 .42758 .53718 .433 .54796 .42955 .54221 .42416 Mtetra
.646 .788 .95 r
.54221 .42416 .54796 .42955 .55878 .42612 .55306 .42078 Mtetra
.643 .79 .952 r
.55306 .42078 .55878 .42612 .56965 .42269 .56395 .41743 Mtetra
.64 .792 .955 r
.56395 .41743 .56965 .42269 .58055 .41927 .5749 .41411 Mtetra
.636 .796 .959 r
.5749 .41411 .58055 .41927 .59151 .41588 .58588 .41084 Mtetra
.631 .8 .964 r
.58588 .41084 .59151 .41588 .6025 .41252 .59692 .40763 Mtetra
.625 .805 .969 r
.59692 .40763 .6025 .41252 .61355 .40918 .608 .40448 Mtetra
.618 .811 .974 r
.608 .40448 .61355 .40918 .62464 .40589 .61914 .40139 Mtetra
.61 .817 .98 r
.61914 .40139 .62464 .40589 .63578 .40265 .63032 .39836 Mtetra
.602 .824 .985 r
.63032 .39836 .63578 .40265 .64696 .39946 .64155 .39539 Mtetra
.594 .831 .989 r
.64155 .39539 .64696 .39946 .6582 .39631 .65284 .39245 Mtetra
.587 .837 .992 r
.65284 .39245 .6582 .39631 .66949 .39321 .66418 .3895 Mtetra
.585 .844 .994 r
.66418 .3895 .66949 .39321 .68083 .3901 .67556 .38648 Mtetra
.589 .85 .994 r
.67556 .38648 .68083 .3901 .69222 .38698 .68699 .38333 Mtetra
.601 .854 .992 r
.68699 .38333 .69222 .38698 .70365 .38378 .69846 .37998 Mtetra
.621 .857 .988 r
.69846 .37998 .70365 .38378 .71513 .38043 .70996 .37633 Mtetra
.642 .853 .98 r
.70996 .37633 .71513 .38043 .72664 .37691 .7215 .37238 Mtetra
.665 .844 .969 r
.7215 .37238 .72664 .37691 .73819 .37315 .73305 .36808 Mtetra
.681 .829 .955 r
.73305 .36808 .73819 .37315 .74977 .36916 .74463 .3635 Mtetra
.691 .811 .939 r
.74463 .3635 .74977 .36916 .76137 .36493 .75624 .3587 Mtetra
.694 .793 .926 r
.75624 .3587 .76137 .36493 .77301 .36052 .76788 .3538 Mtetra
.693 .776 .915 r
.76788 .3538 .77301 .36052 .78469 .35599 .77956 .34891 Mtetra
.689 .764 .909 r
.77956 .34891 .78469 .35599 .7964 .35139 .79129 .34408 Mtetra
.684 .755 .906 r
.79129 .34408 .7964 .35139 .80815 .34681 .80308 .3394 Mtetra
.679 .751 .906 r
.80308 .3394 .80815 .34681 .81996 .34224 .81492 .33484 Mtetra
.675 .751 .908 r
.81492 .33484 .81996 .34224 .8318 .3377 .82681 .33038 Mtetra
.672 .753 .912 r
.82681 .33038 .8318 .3377 .8437 .33321 .83876 .32602 Mtetra
.655 .751 .921 r
.20012 .52592 .20671 .53168 .21623 .52901 .2097 .52281 Mtetra
.651 .736 .911 r
.2097 .52281 .21623 .52901 .22579 .52643 .21931 .51978 Mtetra
.645 .72 .903 r
.21931 .51978 .22579 .52643 .23537 .52395 .22894 .5169 Mtetra
.636 .706 .896 r
.22894 .5169 .23537 .52395 .24498 .5216 .2386 .51422 Mtetra
.625 .693 .893 r
.2386 .51422 .24498 .5216 .25462 .51939 .24826 .51182 Mtetra
.615 .684 .892 r
.24826 .51182 .25462 .51939 .26429 .51725 .25795 .50966 Mtetra
.603 .68 .896 r
.25795 .50966 .26429 .51725 .27401 .51512 .26766 .50776 Mtetra
.597 .685 .904 r
.26766 .50776 .27401 .51512 .28377 .5129 .27741 .50599 Mtetra
.592 .699 .917 r
.27741 .50599 .28377 .5129 .29359 .51048 .28719 .50425 Mtetra
.593 .723 .934 r
.28719 .50425 .29359 .51048 .30347 .5078 .29703 .50239 Mtetra
.598 .755 .953 r
.29703 .50239 .30347 .5078 .3134 .50478 .30693 .50027 Mtetra
.603 .793 .972 r
.30693 .50027 .3134 .50478 .3234 .50147 .3169 .49783 Mtetra
.611 .831 .984 r
.3169 .49783 .3234 .50147 .33344 .49788 .32693 .49498 Mtetra
.615 .862 .99 r
.32693 .49498 .33344 .49788 .34354 .49409 .33702 .49179 Mtetra
.618 .886 .989 r
.33702 .49179 .34354 .49409 .35367 .49017 .34717 .48826 Mtetra
.62 .901 .986 r
.34717 .48826 .35367 .49017 .36384 .48618 .35736 .48449 Mtetra
.622 .909 .983 r
.35736 .48449 .36384 .48618 .37405 .48219 .3676 .48055 Mtetra
.626 .912 .981 r
.3676 .48055 .37405 .48219 .38428 .47822 .37788 .47651 Mtetra
.629 .912 .982 r
.37788 .47651 .38428 .47822 .39455 .47431 .3882 .47243 Mtetra
.634 .908 .983 r
.3882 .47243 .39455 .47431 .40486 .47046 .39855 .46835 Mtetra
.637 .902 .984 r
.39855 .46835 .40486 .47046 .4152 .46667 .40893 .46431 Mtetra
.64 .895 .985 r
.40893 .46431 .4152 .46667 .42557 .46294 .41935 .46032 Mtetra
.642 .887 .985 r
.41935 .46032 .42557 .46294 .43597 .45926 .4298 .4564 Mtetra
.643 .879 .985 r
.4298 .4564 .43597 .45926 .44642 .45563 .44029 .45255 Mtetra
.643 .871 .984 r
.44029 .45255 .44642 .45563 .4569 .45203 .45081 .44876 Mtetra
.642 .864 .983 r
.45081 .44876 .4569 .45203 .46742 .44847 .46137 .44503 Mtetra
.64 .858 .982 r
.46137 .44503 .46742 .44847 .47798 .44494 .47197 .44137 Mtetra
.639 .853 .982 r
.47197 .44137 .47798 .44494 .48858 .44143 .48261 .43777 Mtetra
.636 .85 .982 r
.48261 .43777 .48858 .44143 .49922 .43794 .49328 .43422 Mtetra
.633 .848 .982 r
.49328 .43422 .49922 .43794 .50991 .43446 .504 .43072 Mtetra
.629 .846 .983 r
.504 .43072 .50991 .43446 .52063 .43101 .51476 .42728 Mtetra
.624 .846 .984 r
.51476 .42728 .52063 .43101 .5314 .42758 .52556 .42389 Mtetra
.618 .847 .986 r
.52556 .42389 .5314 .42758 .54221 .42416 .53641 .42057 Mtetra
.611 .849 .989 r
.53641 .42057 .54221 .42416 .55306 .42078 .5473 .4173 Mtetra
.603 .852 .991 r
.5473 .4173 .55306 .42078 .56395 .41743 .55824 .4141 Mtetra
.592 .855 .994 r
.55824 .4141 .56395 .41743 .5749 .41411 .56922 .41097 Mtetra
.58 .859 .996 r
.56922 .41097 .5749 .41411 .58588 .41084 .58025 .4079 Mtetra
.565 .862 .996 r
.58025 .4079 .58588 .41084 .59692 .40763 .59134 .40491 Mtetra
.55 .865 .996 r
.59134 .40491 .59692 .40763 .608 .40448 .60247 .40196 Mtetra
.535 .867 .993 r
.60247 .40196 .608 .40448 .61914 .40139 .61365 .39906 Mtetra
.522 .869 .99 r
.61365 .39906 .61914 .40139 .63032 .39836 .62488 .39616 Mtetra
.516 .871 .987 r
.62488 .39616 .63032 .39836 .64155 .39539 .63616 .39323 Mtetra
.52 .874 .986 r
.63616 .39323 .64155 .39539 .65284 .39245 .64749 .39019 Mtetra
.537 .879 .988 r
.64749 .39019 .65284 .39245 .66418 .3895 .65887 .38697 Mtetra
.567 .884 .991 r
.65887 .38697 .66418 .3895 .67556 .38648 .67028 .38351 Mtetra
.606 .883 .991 r
.67028 .38351 .67556 .38648 .68699 .38333 .68172 .3797 Mtetra
.645 .872 .983 r
.68172 .3797 .68699 .38333 .69846 .37998 .69319 .37553 Mtetra
.677 .851 .966 r
.69319 .37553 .69846 .37998 .70996 .37633 .70468 .37093 Mtetra
.696 .821 .942 r
.70468 .37093 .70996 .37633 .7215 .37238 .7162 .366 Mtetra
.705 .789 .917 r
.7162 .366 .7215 .37238 .73305 .36808 .72773 .3608 Mtetra
.705 .761 .895 r
.72773 .3608 .73305 .36808 .74463 .3635 .7393 .35546 Mtetra
.7 .738 .88 r
.7393 .35546 .74463 .3635 .75624 .3587 .7509 .35015 Mtetra
.694 .722 .871 r
.7509 .35015 .75624 .3587 .76788 .3538 .76255 .34495 Mtetra
.685 .711 .868 r
.76255 .34495 .76788 .3538 .77956 .34891 .77426 .34002 Mtetra
.678 .708 .871 r
.77426 .34002 .77956 .34891 .79129 .34408 .78604 .33534 Mtetra
.67 .709 .877 r
.78604 .33534 .79129 .34408 .80308 .3394 .79788 .33095 Mtetra
.664 .715 .887 r
.79788 .33095 .80308 .3394 .81492 .33484 .80978 .32676 Mtetra
.66 .725 .898 r
.80978 .32676 .81492 .33484 .82681 .33038 .82175 .32272 Mtetra
.657 .737 .909 r
.82175 .32272 .82681 .33038 .83876 .32602 .83378 .31877 Mtetra
.679 .757 .91 r
.19348 .52013 .20012 .52592 .2097 .52281 .20314 .5164 Mtetra
.675 .736 .896 r
.20314 .5164 .2097 .52281 .21931 .51978 .21283 .5127 Mtetra
.668 .715 .883 r
.21283 .5127 .21931 .51978 .22894 .5169 .22254 .50914 Mtetra
.658 .693 .872 r
.22254 .50914 .22894 .5169 .2386 .51422 .23226 .50581 Mtetra
.644 .672 .862 r
.23226 .50581 .2386 .51422 .24826 .51182 .24199 .50283 Mtetra
.629 .653 .855 r
.24199 .50283 .24826 .51182 .25795 .50966 .25172 .50024 Mtetra
.611 .636 .851 r
.25172 .50024 .25795 .50966 .26766 .50776 .26145 .49817 Mtetra
.596 .626 .852 r
.26145 .49817 .26766 .50776 .27741 .50599 .27119 .4965 Mtetra
.58 .623 .859 r
.27119 .4965 .27741 .50599 .28719 .50425 .28095 .49524 Mtetra
.571 .631 .872 r
.28095 .49524 .28719 .50425 .29703 .50239 .29075 .49415 Mtetra
.567 .651 .892 r
.29075 .49415 .29703 .50239 .30693 .50027 .30059 .49307 Mtetra
.568 .684 .918 r
.30059 .49307 .30693 .50027 .3169 .49783 .31049 .4918 Mtetra
.576 .728 .946 r
.31049 .4918 .3169 .49783 .32693 .49498 .32047 .49015 Mtetra
.584 .777 .971 r
.32047 .49015 .32693 .49498 .33702 .49179 .33053 .48805 Mtetra
.593 .825 .987 r
.33053 .48805 .33702 .49179 .34717 .48826 .34065 .48545 Mtetra
.597 .862 .993 r
.34065 .48545 .34717 .48826 .35736 .48449 .35084 .4824 Mtetra
.598 .89 .99 r
.35084 .4824 .35736 .48449 .3676 .48055 .3611 .47896 Mtetra
.597 .906 .983 r
.3611 .47896 .3676 .48055 .37788 .47651 .3714 .47523 Mtetra
.596 .915 .976 r
.3714 .47523 .37788 .47651 .3882 .47243 .38175 .47129 Mtetra
.596 .92 .972 r
.38175 .47129 .3882 .47243 .39855 .46835 .39214 .46724 Mtetra
.597 .921 .971 r
.39214 .46724 .39855 .46835 .40893 .46431 .40257 .46313 Mtetra
.598 .92 .972 r
.40257 .46313 .40893 .46431 .41935 .46032 .41303 .45902 Mtetra
.6 .918 .974 r
.41303 .45902 .41935 .46032 .4298 .4564 .42353 .45494 Mtetra
.601 .915 .977 r
.42353 .45494 .4298 .4564 .44029 .45255 .43406 .45093 Mtetra
.601 .911 .98 r
.43406 .45093 .44029 .45255 .45081 .44876 .44463 .44698 Mtetra
.6 .907 .983 r
.44463 .44698 .45081 .44876 .46137 .44503 .45523 .44312 Mtetra
.598 .902 .985 r
.45523 .44312 .46137 .44503 .47197 .44137 .46587 .43934 Mtetra
.594 .898 .987 r
.46587 .43934 .47197 .44137 .48261 .43777 .47655 .43565 Mtetra
.589 .894 .988 r
.47655 .43565 .48261 .43777 .49328 .43422 .48727 .43204 Mtetra
.583 .891 .989 r
.48727 .43204 .49328 .43422 .504 .43072 .49803 .42852 Mtetra
.576 .888 .99 r
.49803 .42852 .504 .43072 .51476 .42728 .50883 .42509 Mtetra
.566 .886 .99 r
.50883 .42509 .51476 .42728 .52556 .42389 .51967 .42175 Mtetra
.555 .884 .989 r
.51967 .42175 .52556 .42389 .53641 .42057 .53056 .4185 Mtetra
.542 .882 .987 r
.53056 .4185 .53641 .42057 .5473 .4173 .5415 .41533 Mtetra
.527 .879 .985 r
.5415 .41533 .5473 .4173 .55824 .4141 .55248 .41224 Mtetra
.511 .877 .981 r
.55248 .41224 .55824 .4141 .56922 .41097 .56351 .40924 Mtetra
.496 .874 .976 r
.56351 .40924 .56922 .41097 .58025 .4079 .57459 .40628 Mtetra
.482 .871 .971 r
.57459 .40628 .58025 .4079 .59134 .40491 .58572 .40337 Mtetra
.474 .87 .966 r
.58572 .40337 .59134 .40491 .60247 .40196 .5969 .40045 Mtetra
.474 .871 .965 r
.5969 .40045 .60247 .40196 .61365 .39906 .60813 .39749 Mtetra
.487 .876 .968 r
.60813 .39749 .61365 .39906 .62488 .39616 .6194 .3944 Mtetra
.515 .884 .975 r
.6194 .3944 .62488 .39616 .63616 .39323 .63072 .3911 Mtetra
.558 .892 .984 r
.63072 .3911 .63616 .39323 .64749 .39019 .64208 .38751 Mtetra
.609 .894 .988 r
.64208 .38751 .64749 .39019 .65887 .38697 .65347 .38351 Mtetra
.657 .881 .981 r
.65347 .38351 .65887 .38697 .67028 .38351 .66488 .37905 Mtetra
.695 .855 .959 r
.66488 .37905 .67028 .38351 .68172 .3797 .67631 .37406 Mtetra
.715 .817 .928 r
.67631 .37406 .68172 .3797 .69319 .37553 .68775 .36861 Mtetra
.723 .777 .895 r
.68775 .36861 .69319 .37553 .70468 .37093 .69921 .36276 Mtetra
.72 .74 .867 r
.69921 .36276 .70468 .37093 .7162 .366 .71069 .3567 Mtetra
.711 .709 .846 r
.71069 .3567 .7162 .366 .72773 .3608 .7222 .35063 Mtetra
.701 .686 .833 r
.7222 .35063 .72773 .3608 .7393 .35546 .73375 .34474 Mtetra
.688 .669 .827 r
.73375 .34474 .7393 .35546 .7509 .35015 .74537 .33925 Mtetra
.677 .662 .828 r
.74537 .33925 .7509 .35015 .76255 .34495 .75705 .33419 Mtetra
.664 .659 .835 r
.75705 .33419 .76255 .34495 .77426 .34002 .76882 .32965 Mtetra
.655 .664 .846 r
.76882 .32965 .77426 .34002 .78604 .33534 .78066 .32552 Mtetra
.647 .673 .861 r
.78066 .32552 .78604 .33534 .79788 .33095 .79258 .32175 Mtetra
.641 .686 .877 r
.79258 .32175 .79788 .33095 .80978 .32676 .80458 .31821 Mtetra
.637 .703 .894 r
.80458 .31821 .80978 .32676 .82175 .32272 .81664 .31482 Mtetra
.635 .722 .911 r
.81664 .31482 .82175 .32272 .83378 .31877 .82876 .31146 Mtetra
.697 .76 .901 r
.18679 .51429 .19348 .52013 .20314 .5164 .19653 .51003 Mtetra
.696 .744 .888 r
.19653 .51003 .20314 .5164 .21283 .5127 .20629 .5057 Mtetra
.692 .725 .875 r
.20629 .5057 .21283 .5127 .22254 .50914 .21609 .50139 Mtetra
.684 .703 .861 r
.21609 .50139 .22254 .50914 .23226 .50581 .2259 .49721 Mtetra
.674 .679 .847 r
.2259 .49721 .23226 .50581 .24199 .50283 .23573 .49321 Mtetra
.659 .651 .832 r
.23573 .49321 .24199 .50283 .25172 .50024 .24556 .48955 Mtetra
.64 .623 .817 r
.24556 .48955 .25172 .50024 .26145 .49817 .25539 .48638 Mtetra
.621 .596 .803 r
.25539 .48638 .26145 .49817 .27119 .4965 .2652 .48376 Mtetra
.601 .571 .793 r
.2652 .48376 .27119 .4965 .28095 .49524 .27501 .48181 Mtetra
.584 .553 .786 r
.27501 .48181 .28095 .49524 .29075 .49415 .28482 .48041 Mtetra
.57 .541 .784 r
.28482 .48041 .29075 .49415 .30059 .49307 .29465 .47952 Mtetra
.562 .54 .788 r
.29465 .47952 .30059 .49307 .31049 .4918 .3045 .47888 Mtetra
.559 .549 .8 r
.3045 .47888 .31049 .4918 .32047 .49015 .31441 .47832 Mtetra
.562 .569 .819 r
.31441 .47832 .32047 .49015 .33053 .48805 .32438 .47762 Mtetra
.571 .602 .845 r
.32438 .47762 .33053 .48805 .34065 .48545 .33443 .47658 Mtetra
.582 .645 .878 r
.33443 .47658 .34065 .48545 .35084 .4824 .34454 .47515 Mtetra
.596 .698 .914 r
.34454 .47515 .35084 .4824 .3611 .47896 .35474 .47324 Mtetra
.605 .754 .949 r
.35474 .47324 .3611 .47896 .3714 .47523 .365 .47089 Mtetra
.609 .81 .977 r
.365 .47089 .3714 .47523 .38175 .47129 .37532 .46813 Mtetra
.603 .855 .992 r
.37532 .46813 .38175 .47129 .39214 .46724 .38571 .46503 Mtetra
.587 .886 .991 r
.38571 .46503 .39214 .46724 .40257 .46313 .39615 .46168 Mtetra
.563 .901 .979 r
.39615 .46168 .40257 .46313 .41303 .45902 .40663 .45813 Mtetra
.537 .906 .96 r
.40663 .45813 .41303 .45902 .42353 .45494 .41716 .45447 Mtetra
.511 .903 .94 r
.41716 .45447 .42353 .45494 .43406 .45093 .42773 .45074 Mtetra
.487 .896 .921 r
.42773 .45074 .43406 .45093 .44463 .44698 .43833 .44698 Mtetra
.467 .888 .906 r
.43833 .44698 .44463 .44698 .45523 .44312 .44898 .44324 Mtetra
.449 .881 .894 r
.44898 .44324 .45523 .44312 .46587 .43934 .45967 .43952 Mtetra
.435 .873 .885 r
.45967 .43952 .46587 .43934 .47655 .43565 .4704 .43586 Mtetra
.422 .867 .879 r
.4704 .43586 .47655 .43565 .48727 .43204 .48116 .43225 Mtetra
.411 .861 .875 r
.48116 .43225 .48727 .43204 .49803 .42852 .49197 .42872 Mtetra
.402 .856 .872 r
.49197 .42872 .49803 .42852 .50883 .42509 .50282 .42525 Mtetra
.396 .853 .872 r
.50282 .42525 .50883 .42509 .51967 .42175 .51372 .42184 Mtetra
.394 .851 .875 r
.51372 .42184 .51967 .42175 .53056 .4185 .52466 .41848 Mtetra
.397 .853 .881 r
.52466 .41848 .53056 .4185 .5415 .41533 .53564 .41515 Mtetra
.408 .858 .892 r
.53564 .41515 .5415 .41533 .55248 .41224 .54667 .41184 Mtetra
.429 .867 .909 r
.54667 .41184 .55248 .41224 .56351 .40924 .55775 .4085 Mtetra
.461 .879 .932 r
.55775 .4085 .56351 .40924 .57459 .40628 .56887 .40509 Mtetra
.505 .892 .957 r
.56887 .40509 .57459 .40628 .58572 .40337 .58004 .40155 Mtetra
.558 .9 .979 r
.58004 .40155 .58572 .40337 .5969 .40045 .59125 .39783 Mtetra
.612 .894 .988 r
.59125 .39783 .5969 .40045 .60813 .39749 .6025 .39384 Mtetra
.658 .872 .979 r
.6025 .39384 .60813 .39749 .6194 .3944 .61378 .38951 Mtetra
.69 .834 .952 r
.61378 .38951 .6194 .3944 .63072 .3911 .62509 .38475 Mtetra
.707 .787 .914 r
.62509 .38475 .63072 .3911 .64208 .38751 .63642 .37954 Mtetra
.713 .74 .873 r
.63642 .37954 .64208 .38751 .65347 .38351 .64777 .37383 Mtetra
.71 .697 .836 r
.64777 .37383 .65347 .38351 .66488 .37905 .65914 .3677 Mtetra
.705 .663 .806 r
.65914 .3677 .66488 .37905 .67631 .37406 .67052 .36121 Mtetra
.696 .635 .784 r
.67052 .36121 .67631 .37406 .68775 .36861 .68192 .35458 Mtetra
.687 .615 .77 r
.68192 .35458 .68775 .36861 .69921 .36276 .69335 .348 Mtetra
.678 .601 .763 r
.69335 .348 .69921 .36276 .71069 .3567 .70483 .34168 Mtetra
.667 .593 .763 r
.70483 .34168 .71069 .3567 .7222 .35063 .71636 .33588 Mtetra
.659 .592 .769 r
.71636 .33588 .7222 .35063 .73375 .34474 .72797 .33063 Mtetra
.648 .595 .781 r
.72797 .33063 .73375 .34474 .74537 .33925 .73966 .32607 Mtetra
.64 .605 .798 r
.73966 .32607 .74537 .33925 .75705 .33419 .75143 .32209 Mtetra
.632 .619 .819 r
.75143 .32209 .75705 .33419 .76882 .32965 .7633 .3186 Mtetra
.626 .636 .841 r
.7633 .3186 .76882 .32965 .78066 .32552 .77524 .31548 Mtetra
.621 .657 .864 r
.77524 .31548 .78066 .32552 .79258 .32175 .78726 .31255 Mtetra
.617 .677 .884 r
.78726 .31255 .79258 .32175 .80458 .31821 .79935 .30974 Mtetra
.615 .696 .902 r
.79935 .30974 .80458 .31821 .81664 .31482 .8115 .30695 Mtetra
.615 .716 .917 r
.8115 .30695 .81664 .31482 .82876 .31146 .82371 .3041 Mtetra
.704 .761 .896 r
.18006 .50842 .18679 .51429 .19653 .51003 .18984 .5039 Mtetra
.708 .755 .889 r
.18984 .5039 .19653 .51003 .20629 .5057 .19967 .4992 Mtetra
.71 .745 .879 r
.19967 .4992 .20629 .5057 .21609 .50139 .20953 .49438 Mtetra
.709 .73 .867 r
.20953 .49438 .21609 .50139 .2259 .49721 .21943 .48944 Mtetra
.707 .71 .851 r
.21943 .48944 .2259 .49721 .23573 .49321 .22937 .48439 Mtetra
.697 .683 .833 r
.22937 .48439 .23573 .49321 .24556 .48955 .23933 .47943 Mtetra
.682 .652 .814 r
.23933 .47943 .24556 .48955 .25539 .48638 .24929 .47469 Mtetra
.662 .617 .793 r
.24929 .47469 .25539 .48638 .2652 .48376 .25924 .47041 Mtetra
.638 .582 .775 r
.25924 .47041 .2652 .48376 .27501 .48181 .26917 .46684 Mtetra
.614 .55 .759 r
.26917 .46684 .27501 .48181 .28482 .48041 .27908 .46408 Mtetra
.589 .522 .747 r
.27908 .46408 .28482 .48041 .29465 .47952 .28895 .46228 Mtetra
.569 .502 .74 r
.28895 .46228 .29465 .47952 .3045 .47888 .29882 .4613 Mtetra
.552 .489 .738 r
.29882 .4613 .3045 .47888 .31441 .47832 .30868 .46104 Mtetra
.542 .486 .743 r
.30868 .46104 .31441 .47832 .32438 .47762 .31858 .46118 Mtetra
.537 .492 .753 r
.31858 .46118 .32438 .47762 .33443 .47658 .32853 .46148 Mtetra
.538 .508 .771 r
.32853 .46148 .33443 .47658 .34454 .47515 .33855 .46167 Mtetra
.545 .535 .795 r
.33855 .46167 .34454 .47515 .35474 .47324 .34865 .46152 Mtetra
.555 .571 .825 r
.34865 .46152 .35474 .47324 .365 .47089 .35882 .46095 Mtetra
.569 .616 .859 r
.35882 .46095 .365 .47089 .37532 .46813 .36908 .45985 Mtetra
.583 .665 .895 r
.36908 .45985 .37532 .46813 .38571 .46503 .37942 .45827 Mtetra
.596 .718 .929 r
.37942 .45827 .38571 .46503 .39615 .46168 .38982 .45621 Mtetra
.603 .768 .958 r
.38982 .45621 .39615 .46168 .40663 .45813 .40029 .45376 Mtetra
.605 .812 .979 r
.40029 .45376 .40663 .45813 .41716 .45447 .41082 .45097 Mtetra
.6 .846 .991 r
.41082 .45097 .41716 .45447 .42773 .45074 .4214 .44794 Mtetra
.59 .87 .994 r
.4214 .44794 .42773 .45074 .43833 .44698 .43203 .44472 Mtetra
.578 .885 .991 r
.43203 .44472 .43833 .44698 .44898 .44324 .44271 .44136 Mtetra
.564 .893 .986 r
.44271 .44136 .44898 .44324 .45967 .43952 .45344 .43791 Mtetra
.552 .897 .979 r
.45344 .43791 .45967 .43952 .4704 .43586 .4642 .43441 Mtetra
.543 .898 .974 r
.4642 .43441 .4704 .43586 .48116 .43225 .47501 .43087 Mtetra
.538 .898 .971 r
.47501 .43087 .48116 .43225 .49197 .42872 .48587 .42732 Mtetra
.539 .899 .971 r
.48587 .42732 .49197 .42872 .50282 .42525 .49676 .42373 Mtetra
.546 .899 .974 r
.49676 .42373 .50282 .42525 .51372 .42184 .5077 .42012 Mtetra
.56 .9 .979 r
.5077 .42012 .51372 .42184 .52466 .41848 .51869 .41645 Mtetra
.581 .899 .985 r
.51869 .41645 .52466 .41848 .53564 .41515 .52972 .41268 Mtetra
.607 .895 .988 r
.52972 .41268 .53564 .41515 .54667 .41184 .54079 .40879 Mtetra
.636 .884 .986 r
.54079 .40879 .54667 .41184 .55775 .4085 .5519 .4047 Mtetra
.665 .865 .975 r
.5519 .4047 .55775 .4085 .56887 .40509 .56305 .40034 Mtetra
.689 .836 .954 r
.56305 .40034 .56887 .40509 .58004 .40155 .57424 .39566 Mtetra
.705 .799 .923 r
.57424 .39566 .58004 .40155 .59125 .39783 .58545 .39056 Mtetra
.714 .758 .887 r
.58545 .39056 .59125 .39783 .6025 .39384 .5967 .38498 Mtetra
.716 .717 .85 r
.5967 .38498 .6025 .39384 .61378 .38951 .60796 .37889 Mtetra
.714 .679 .814 r
.60796 .37889 .61378 .38951 .62509 .38475 .61923 .37225 Mtetra
.707 .644 .784 r
.61923 .37225 .62509 .38475 .63642 .37954 .63052 .36517 Mtetra
.7 .616 .76 r
.63052 .36517 .63642 .37954 .64777 .37383 .64182 .35773 Mtetra
.69 .592 .742 r
.64182 .35773 .64777 .37383 .65914 .3677 .65313 .35017 Mtetra
.679 .573 .729 r
.65313 .35017 .65914 .3677 .67052 .36121 .66447 .34275 Mtetra
.668 .559 .723 r
.66447 .34275 .67052 .36121 .68192 .35458 .67584 .33573 Mtetra
.655 .549 .723 r
.67584 .33573 .68192 .35458 .69335 .348 .68729 .32945 Mtetra
.644 .546 .728 r
.68729 .32945 .69335 .348 .70483 .34168 .6988 .32398 Mtetra
.631 .546 .74 r
.6988 .32398 .70483 .34168 .71636 .33588 .71041 .31952 Mtetra
.621 .553 .757 r
.71041 .31952 .71636 .33588 .72797 .33063 .72212 .31589 Mtetra
.611 .567 .781 r
.72212 .31589 .72797 .33063 .73966 .32607 .73393 .31299 Mtetra
.602 .587 .808 r
.73393 .31299 .73966 .32607 .75143 .32209 .74583 .31058 Mtetra
.598 .613 .838 r
.74583 .31058 .75143 .32209 .7633 .3186 .75781 .30839 Mtetra
.594 .64 .866 r
.75781 .30839 .7633 .3186 .77524 .31548 .76986 .3063 Mtetra
.596 .668 .89 r
.76986 .3063 .77524 .31548 .78726 .31255 .78197 .3041 Mtetra
.597 .69 .907 r
.78197 .3041 .78726 .31255 .79935 .30974 .79413 .30178 Mtetra
.6 .707 .919 r
.79413 .30178 .79935 .30974 .8115 .30695 .80635 .29932 Mtetra
.604 .72 .927 r
.80635 .29932 .8115 .30695 .82371 .3041 .81861 .29669 Mtetra
.69 .759 .904 r
.17328 .5025 .18006 .50842 .18984 .5039 .18304 .49838 Mtetra
.698 .774 .911 r
.18304 .49838 .18984 .5039 .19967 .4992 .19285 .49407 Mtetra
.707 .79 .916 r
.19285 .49407 .19967 .4992 .20953 .49438 .20272 .48953 Mtetra
.717 .802 .917 r
.20272 .48953 .20953 .49438 .21943 .48944 .21263 .48469 Mtetra
.73 .807 .913 r
.21263 .48469 .21943 .48944 .22937 .48439 .22261 .47947 Mtetra
.737 .803 .905 r
.22261 .47947 .22937 .48439 .23933 .47943 .23264 .47398 Mtetra
.741 .787 .89 r
.23264 .47398 .23933 .47943 .24929 .47469 .24272 .46825 Mtetra
.733 .756 .871 r
.24272 .46825 .24929 .47469 .25924 .47041 .25281 .46252 Mtetra
.717 .714 .846 r
.25281 .46252 .25924 .47041 .26917 .46684 .26291 .45698 Mtetra
.691 .663 .817 r
.26291 .45698 .26917 .46684 .27908 .46408 .273 .4519 Mtetra
.66 .611 .788 r
.273 .4519 .27908 .46408 .28895 .46228 .28307 .44755 Mtetra
.631 .563 .76 r
.28307 .44755 .28895 .46228 .29882 .4613 .2931 .44402 Mtetra
.602 .521 .736 r
.2931 .44402 .29882 .4613 .30868 .46104 .30311 .44145 Mtetra
.581 .49 .716 r
.30311 .44145 .30868 .46104 .31858 .46118 .31311 .43971 Mtetra
.565 .467 .703 r
.31311 .43971 .31858 .46118 .32853 .46148 .32311 .43872 Mtetra
.555 .454 .694 r
.32311 .43872 .32853 .46148 .33855 .46167 .33313 .43822 Mtetra
.55 .447 .69 r
.33313 .43822 .33855 .46167 .34865 .46152 .34319 .43802 Mtetra
.548 .446 .69 r
.34319 .43802 .34865 .46152 .35882 .46095 .35331 .43788 Mtetra
.55 .45 .694 r
.35331 .43788 .35882 .46095 .36908 .45985 .36349 .43762 Mtetra
.555 .458 .7 r
.36349 .43762 .36908 .45985 .37942 .45827 .37375 .43714 Mtetra
.561 .47 .708 r
.37375 .43714 .37942 .45827 .38982 .45621 .38407 .43633 Mtetra
.569 .484 .719 r
.38407 .43633 .38982 .45621 .40029 .45376 .39447 .43516 Mtetra
.578 .5 .73 r
.39447 .43516 .40029 .45376 .41082 .45097 .40494 .43362 Mtetra
.587 .516 .743 r
.40494 .43362 .41082 .45097 .4214 .44794 .41547 .43172 Mtetra
.596 .534 .755 r
.41547 .43172 .4214 .44794 .43203 .44472 .42607 .42948 Mtetra
.605 .55 .766 r
.42607 .42948 .43203 .44472 .44271 .44136 .43672 .42693 Mtetra
.614 .565 .776 r
.43672 .42693 .44271 .44136 .45344 .43791 .44743 .42409 Mtetra
.621 .577 .783 r
.44743 .42409 .45344 .43791 .4642 .43441 .45819 .42098 Mtetra
.628 .587 .788 r
.45819 .42098 .4642 .43441 .47501 .43087 .469 .41763 Mtetra
.634 .593 .79 r
.469 .41763 .47501 .43087 .48587 .42732 .47986 .41404 Mtetra
.639 .595 .789 r
.47986 .41404 .48587 .42732 .49676 .42373 .49077 .41021 Mtetra
.644 .594 .784 r
.49077 .41021 .49676 .42373 .5077 .42012 .50172 .40613 Mtetra
.647 .59 .777 r
.50172 .40613 .5077 .42012 .51869 .41645 .51271 .40178 Mtetra
.649 .583 .767 r
.51271 .40178 .51869 .41645 .52972 .41268 .52374 .39714 Mtetra
.651 .575 .756 r
.52374 .39714 .52972 .41268 .54079 .40879 .5348 .39218 Mtetra
.652 .565 .744 r
.5348 .39218 .54079 .40879 .5519 .4047 .5459 .38687 Mtetra
.652 .554 .731 r
.5459 .38687 .5519 .4047 .56305 .40034 .55703 .3812 Mtetra
.652 .543 .719 r
.55703 .3812 .56305 .40034 .57424 .39566 .56819 .37513 Mtetra
.651 .533 .707 r
.56819 .37513 .57424 .39566 .58545 .39056 .57937 .36869 Mtetra
.65 .525 .697 r
.57937 .36869 .58545 .39056 .5967 .38498 .59057 .36191 Mtetra
.648 .517 .69 r
.59057 .36191 .5967 .38498 .60796 .37889 .60178 .35488 Mtetra
.646 .511 .684 r
.60178 .35488 .60796 .37889 .61923 .37225 .61302 .34772 Mtetra
.643 .507 .681 r
.61302 .34772 .61923 .37225 .63052 .36517 .62428 .34062 Mtetra
.64 .505 .682 r
.62428 .34062 .63052 .36517 .64182 .35773 .63557 .3338 Mtetra
.636 .505 .686 r
.63557 .3338 .64182 .35773 .65313 .35017 .64691 .32747 Mtetra
.63 .508 .696 r
.64691 .32747 .65313 .35017 .66447 .34275 .65831 .32191 Mtetra
.624 .516 .711 r
.65831 .32191 .66447 .34275 .67584 .33573 .66978 .31719 Mtetra
.616 .529 .733 r
.66978 .31719 .67584 .33573 .68729 .32945 .68134 .31346 Mtetra
.607 .549 .764 r
.68134 .31346 .68729 .32945 .6988 .32398 .693 .31058 Mtetra
.595 .577 .804 r
.693 .31058 .6988 .32398 .71041 .31952 .70476 .30845 Mtetra
.581 .613 .849 r
.70476 .30845 .71041 .31952 .72212 .31589 .71661 .3068 Mtetra
.568 .655 .895 r
.71661 .3068 .72212 .31589 .73393 .31299 .72854 .30535 Mtetra
.556 .694 .931 r
.72854 .30535 .73393 .31299 .74583 .31058 .74054 .30391 Mtetra
.555 .728 .955 r
.74054 .30391 .74583 .31058 .75781 .30839 .75259 .30223 Mtetra
.561 .75 .966 r
.75259 .30223 .75781 .30839 .76986 .3063 .76469 .30026 Mtetra
.577 .763 .967 r
.76469 .30026 .76986 .3063 .78197 .3041 .77683 .2979 Mtetra
.593 .766 .962 r
.77683 .2979 .78197 .3041 .79413 .30178 .789 .29524 Mtetra
.607 .76 .952 r
.789 .29524 .79413 .30178 .80635 .29932 .80122 .29232 Mtetra
.618 .75 .94 r
.80122 .29232 .80635 .29932 .81861 .29669 .81347 .28921 Mtetra
.655 .751 .92 r
.16646 .49655 .17328 .5025 .18304 .49838 .17615 .49331 Mtetra
.659 .784 .941 r
.17615 .49331 .18304 .49838 .19285 .49407 .18588 .48994 Mtetra
.665 .821 .958 r
.18588 .48994 .19285 .49407 .20272 .48953 .19568 .48632 Mtetra
.675 .859 .97 r
.19568 .48632 .20272 .48953 .21263 .48469 .20555 .48232 Mtetra
.69 .893 .971 r
.20555 .48232 .21263 .48469 .22261 .47947 .2155 .4778 Mtetra
.708 .92 .965 r
.2155 .4778 .22261 .47947 .23264 .47398 .22553 .4727 Mtetra
.735 .935 .953 r
.22553 .4727 .23264 .47398 .24272 .46825 .23565 .46689 Mtetra
.762 .934 .941 r
.23565 .46689 .24272 .46825 .25281 .46252 .24584 .46049 Mtetra
.788 .91 .925 r
.24584 .46049 .25281 .46252 .26291 .45698 .2561 .4535 Mtetra
.791 .859 .9 r
.2561 .4535 .26291 .45698 .273 .4519 .26639 .44625 Mtetra
.775 .788 .864 r
.26639 .44625 .273 .4519 .28307 .44755 .2767 .43898 Mtetra
.739 .707 .821 r
.2767 .43898 .28307 .44755 .2931 .44402 .287 .43209 Mtetra
.698 .632 .78 r
.287 .43209 .2931 .44402 .30311 .44145 .29726 .42593 Mtetra
.659 .57 .744 r
.29726 .42593 .30311 .44145 .31311 .43971 .30748 .42071 Mtetra
.624 .521 .716 r
.30748 .42071 .31311 .43971 .32311 .43872 .31765 .41663 Mtetra
.598 .485 .696 r
.31765 .41663 .32311 .43872 .33313 .43822 .3278 .41361 Mtetra
.578 .459 .681 r
.3278 .41361 .33313 .43822 .34319 .43802 .33793 .41159 Mtetra
.565 .442 .672 r
.33793 .41159 .34319 .43802 .35331 .43788 .34806 .41029 Mtetra
.556 .432 .666 r
.34806 .41029 .35331 .43788 .36349 .43762 .35822 .40952 Mtetra
.552 .427 .664 r
.35822 .40952 .36349 .43762 .37375 .43714 .36842 .40903 Mtetra
.551 .427 .664 r
.36842 .40903 .37375 .43714 .38407 .43633 .37868 .40859 Mtetra
.552 .43 .667 r
.37868 .40859 .38407 .43633 .39447 .43516 .38901 .40806 Mtetra
.556 .435 .67 r
.38901 .40806 .39447 .43516 .40494 .43362 .3994 .40729 Mtetra
.561 .442 .675 r
.3994 .40729 .40494 .43362 .41547 .43172 .40986 .4062 Mtetra
.568 .45 .679 r
.40986 .4062 .41547 .43172 .42607 .42948 .42039 .40474 Mtetra
.575 .459 .684 r
.42039 .40474 .42607 .42948 .43672 .42693 .43099 .40286 Mtetra
.582 .467 .688 r
.43099 .40286 .43672 .42693 .44743 .42409 .44165 .40055 Mtetra
.59 .475 .691 r
.44165 .40055 .44743 .42409 .45819 .42098 .45238 .39781 Mtetra
.597 .482 .693 r
.45238 .39781 .45819 .42098 .469 .41763 .46316 .39462 Mtetra
.604 .488 .694 r
.46316 .39462 .469 .41763 .47986 .41404 .47399 .39099 Mtetra
.61 .491 .693 r
.47399 .39099 .47986 .41404 .49077 .41021 .48487 .38691 Mtetra
.615 .494 .691 r
.48487 .38691 .49077 .41021 .50172 .40613 .4958 .38239 Mtetra
.62 .495 .688 r
.4958 .38239 .50172 .40613 .51271 .40178 .50676 .37742 Mtetra
.624 .494 .684 r
.50676 .37742 .51271 .40178 .52374 .39714 .51776 .37202 Mtetra
.627 .492 .679 r
.51776 .37202 .52374 .39714 .5348 .39218 .5288 .36619 Mtetra
.629 .49 .674 r
.5288 .36619 .5348 .39218 .5459 .38687 .53986 .35997 Mtetra
.63 .487 .669 r
.53986 .35997 .5459 .38687 .55703 .3812 .55095 .35342 Mtetra
.63 .484 .665 r
.55095 .35342 .55703 .3812 .56819 .37513 .56205 .34662 Mtetra
.629 .481 .662 r
.56205 .34662 .56819 .37513 .57937 .36869 .57319 .33972 Mtetra
.627 .478 .66 r
.57319 .33972 .57937 .36869 .59057 .36191 .58434 .33286 Mtetra
.624 .475 .66 r
.58434 .33286 .59057 .36191 .60178 .35488 .59552 .32627 Mtetra
.619 .474 .663 r
.59552 .32627 .60178 .35488 .61302 .34772 .60675 .3202 Mtetra
.613 .474 .669 r
.60675 .3202 .61302 .34772 .62428 .34062 .61802 .31487 Mtetra
.605 .477 .679 r
.61802 .31487 .62428 .34062 .63557 .3338 .62937 .31056 Mtetra
.596 .484 .696 r
.62937 .31056 .63557 .3338 .64691 .32747 .6408 .30731 Mtetra
.582 .496 .722 r
.6408 .30731 .64691 .32747 .65831 .32191 .65233 .30526 Mtetra
.567 .519 .761 r
.65233 .30526 .65831 .32191 .66978 .31719 .66396 .30417 Mtetra
.544 .555 .817 r
.66396 .30417 .66978 .31719 .68134 .31346 .6757 .30384 Mtetra
.51 .61 .888 r
.6757 .30384 .68134 .31346 .693 .31058 .68754 .30391 Mtetra
.461 .679 .959 r
.68754 .30391 .693 .31058 .70476 .30845 .69945 .30397 Mtetra
.395 .733 .991 r
.69945 .30397 .70476 .30845 .71661 .3068 .71143 .30378 Mtetra
.356 .768 .98 r
.71143 .30378 .71661 .3068 .72854 .30535 .72345 .30298 Mtetra
.361 .794 .967 r
.72345 .30298 .72854 .30535 .74054 .30391 .7355 .30158 Mtetra
.42 .829 .975 r
.7355 .30158 .74054 .30391 .75259 .30223 .74758 .29944 Mtetra
.495 .853 .991 r
.74758 .29944 .75259 .30223 .76469 .30026 .75967 .2967 Mtetra
.566 .859 .997 r
.75967 .2967 .76469 .30026 .77683 .2979 .77178 .29341 Mtetra
.614 .844 .987 r
.77178 .29341 .77683 .2979 .789 .29524 .78392 .28973 Mtetra
.642 .816 .967 r
.78392 .28973 .789 .29524 .80122 .29232 .79609 .28577 Mtetra
.654 .783 .943 r
.79609 .28577 .80122 .29232 .81347 .28921 .8083 .28168 Mtetra
.61 .739 .937 r
.15958 .49055 .16646 .49655 .17615 .49331 .16919 .48827 Mtetra
.602 .773 .962 r
.16919 .48827 .17615 .49331 .18588 .48994 .17884 .48595 Mtetra
.595 .812 .983 r
.17884 .48595 .18588 .48994 .19568 .48632 .18854 .48348 Mtetra
.583 .853 .995 r
.18854 .48348 .19568 .48632 .20555 .48232 .19832 .48075 Mtetra
.563 .89 .987 r
.19832 .48075 .20555 .48232 .2155 .4778 .20817 .47763 Mtetra
.528 .909 .945 r
.20817 .47763 .2155 .4778 .22553 .4727 .2181 .47398 Mtetra
.483 .9 .863 r
.2181 .47398 .22553 .4727 .23565 .46689 .22814 .46965 Mtetra
.426 .86 .751 r
.22814 .46965 .23565 .46689 .24584 .46049 .23827 .46457 Mtetra
.388 .816 .647 r
.23827 .46457 .24584 .46049 .2561 .4535 .24849 .45864 Mtetra
0 0 0 r
.24849 .45864 .2561 .4535 .26639 .44625 .2588 .45198 Mtetra
.2588 .45198 .26639 .44625 .2767 .43898 .26918 .44465 Mtetra
.26918 .44465 .2767 .43898 .287 .43209 .27961 .43695 Mtetra
.493 .863 .637 r
.27961 .43695 .287 .43209 .29726 .42593 .29005 .42914 Mtetra
.616 .948 .774 r
.29005 .42914 .29726 .42593 .30748 .42071 .30049 .42153 Mtetra
.726 .984 .902 r
.30049 .42153 .30748 .42071 .31765 .41663 .31091 .41443 Mtetra
.764 .915 .94 r
.31091 .41443 .31765 .41663 .3278 .41361 .3213 .40798 Mtetra
.733 .792 .899 r
.3213 .40798 .3278 .41361 .33793 .41159 .33167 .40234 Mtetra
.689 .681 .838 r
.33167 .40234 .33793 .41159 .34806 .41029 .34201 .39745 Mtetra
.65 .601 .786 r
.34201 .39745 .34806 .41029 .35822 .40952 .35235 .3933 Mtetra
.623 .546 .747 r
.35235 .3933 .35822 .40952 .36842 .40903 .3627 .38974 Mtetra
.605 .509 .719 r
.3627 .38974 .36842 .40903 .37868 .40859 .37306 .38663 Mtetra
.593 .484 .699 r
.37306 .38663 .37868 .40859 .38901 .40806 .38345 .38383 Mtetra
.586 .468 .685 r
.38345 .38383 .38901 .40806 .3994 .40729 .39388 .38119 Mtetra
.582 .457 .674 r
.39388 .38119 .3994 .40729 .40986 .4062 .40436 .37862 Mtetra
.581 .45 .667 r
.40436 .37862 .40986 .4062 .42039 .40474 .41488 .376 Mtetra
.58 .445 .662 r
.41488 .376 .42039 .40474 .43099 .40286 .42546 .37326 Mtetra
.582 .443 .658 r
.42546 .37326 .43099 .40286 .44165 .40055 .43609 .37034 Mtetra
.583 .443 .656 r
.43609 .37034 .44165 .40055 .45238 .39781 .44677 .36719 Mtetra
.586 .443 .654 r
.44677 .36719 .45238 .39781 .46316 .39462 .4575 .36378 Mtetra
.588 .445 .653 r
.4575 .36378 .46316 .39462 .47399 .39099 .46828 .3601 Mtetra
.591 .447 .653 r
.46828 .3601 .47399 .39099 .48487 .38691 .4791 .35615 Mtetra
.594 .449 .654 r
.4791 .35615 .48487 .38691 .4958 .38239 .48997 .35194 Mtetra
.597 .452 .655 r
.48997 .35194 .4958 .38239 .50676 .37742 .50088 .3475 Mtetra
.601 .456 .657 r
.50088 .3475 .50676 .37742 .51776 .37202 .51183 .34287 Mtetra
.603 .461 .66 r
.51183 .34287 .51776 .37202 .5288 .36619 .52282 .33812 Mtetra
.606 .467 .665 r
.52282 .33812 .5288 .36619 .53986 .35997 .53385 .33332 Mtetra
.609 .474 .672 r
.53385 .33332 .53986 .35997 .55095 .35342 .54491 .32857 Mtetra
.611 .483 .682 r
.54491 .32857 .55095 .35342 .56205 .34662 .55601 .32399 Mtetra
.612 .496 .697 r
.55601 .32399 .56205 .34662 .57319 .33972 .56716 .31971 Mtetra
.612 .514 .718 r
.56716 .31971 .57319 .33972 .58434 .33286 .57836 .31591 Mtetra
.611 .539 .749 r
.57836 .31591 .58434 .33286 .59552 .32627 .58961 .31269 Mtetra
.603 .576 .797 r
.58961 .31269 .59552 .32627 .60675 .3202 .60093 .31022 Mtetra
.581 .635 .869 r
.60093 .31022 .60675 .3202 .61802 .31487 .61234 .30853 Mtetra
.508 .713 .964 r
.61234 .30853 .61802 .31487 .62937 .31056 .62383 .30767 Mtetra
.292 .733 .964 r
.62383 .30767 .62937 .31056 .6408 .30731 .63541 .30749 Mtetra
.053 0 0 r
.63541 .30749 .6408 .30731 .65233 .30526 .64709 .30784 Mtetra
.253 0 0 r
.64709 .30784 .65233 .30526 .66396 .30417 .65886 .30842 Mtetra
.323 0 0 r
.65886 .30842 .66396 .30417 .6757 .30384 .67071 .30889 Mtetra
.33 0 0 r
.67071 .30889 .6757 .30384 .68754 .30391 .68262 .309 Mtetra
.291 0 0 r
.68262 .309 .68754 .30391 .69945 .30397 .69458 .30842 Mtetra
.216 0 0 r
.69458 .30842 .69945 .30397 .71143 .30378 .70656 .30709 Mtetra
.083 0 0 r
.70656 .30709 .71143 .30378 .72345 .30298 .71857 .30488 Mtetra
0 0 0 r
.71857 .30488 .72345 .30298 .7355 .30158 .73059 .3019 Mtetra
.327 .812 .81 r
.73059 .3019 .7355 .30158 .74758 .29944 .74262 .2982 Mtetra
.509 .902 .939 r
.74262 .2982 .74758 .29944 .75967 .2967 .75466 .29395 Mtetra
.617 .91 .982 r
.75466 .29395 .75967 .2967 .77178 .29341 .76672 .2893 Mtetra
.668 .88 .977 r
.76672 .2893 .77178 .29341 .78392 .28973 .7788 .28435 Mtetra
.688 .84 .956 r
.7788 .28435 .78392 .28973 .79609 .28577 .79092 .27924 Mtetra
.692 .8 .932 r
.79092 .27924 .79609 .28577 .8083 .28168 .80308 .27409 Mtetra
.567 .725 .948 r
.15266 .48451 .15958 .49055 .16919 .48827 .1622 .48298 Mtetra
.551 .748 .969 r
.1622 .48298 .16919 .48827 .17884 .48595 .17178 .4815 Mtetra
.529 .775 .987 r
.17178 .4815 .17884 .48595 .18854 .48348 .1814 .48004 Mtetra
.497 .803 .999 r
.1814 .48004 .18854 .48348 .19832 .48075 .19108 .47854 Mtetra
.436 .821 .988 r
.19108 .47854 .19832 .48075 .20817 .47763 .20081 .47696 Mtetra
.338 .808 .917 r
.20081 .47696 .20817 .47763 .2181 .47398 .2106 .47517 Mtetra
.191 .72 .744 r
.2106 .47517 .2181 .47398 .22814 .46965 .22047 .47307 Mtetra
0 0 0 r
.22047 .47307 .22814 .46965 .23827 .46457 .23043 .47047 Mtetra
.08 0 0 r
.23043 .47047 .23827 .46457 .24849 .45864 .24049 .46719 Mtetra
.151 0 0 r
.24049 .46719 .24849 .45864 .2588 .45198 .25066 .46307 Mtetra
.18 0 0 r
.25066 .46307 .2588 .45198 .26918 .44465 .26095 .45792 Mtetra
.191 0 .054 r
.26095 .45792 .26918 .44465 .27961 .43695 .27135 .45172 Mtetra
.177 0 .078 r
.27135 .45172 .27961 .43695 .29005 .42914 .28185 .44442 Mtetra
.151 0 .074 r
.28185 .44442 .29005 .42914 .30049 .42153 .29242 .43627 Mtetra
.1 0 .039 r
.29242 .43627 .30049 .42153 .31091 .41443 .30305 .42744 Mtetra
.017 0 0 r
.30305 .42744 .31091 .41443 .3213 .40798 .31371 .41833 Mtetra
0 0 0 r
.31371 .41833 .3213 .40798 .33167 .40234 .32437 .40925 Mtetra
.32437 .40925 .33167 .40234 .34201 .39745 .33501 .40048 Mtetra
.654 .963 .781 r
.33501 .40048 .34201 .39745 .35235 .3933 .34563 .39225 Mtetra
.79 .955 .923 r
.34563 .39225 .35235 .3933 .3627 .38974 .35623 .38465 Mtetra
.77 .82 .892 r
.35623 .38465 .3627 .38974 .37306 .38663 .36681 .37774 Mtetra
.723 .705 .833 r
.36681 .37774 .37306 .38663 .38345 .38383 .37738 .37147 Mtetra
.684 .626 .785 r
.37738 .37147 .38345 .38383 .39388 .38119 .38794 .36581 Mtetra
.656 .574 .751 r
.38794 .36581 .39388 .38119 .40436 .37862 .39851 .36065 Mtetra
.636 .539 .728 r
.39851 .36065 .40436 .37862 .41488 .376 .4091 .35592 Mtetra
.623 .516 .711 r
.4091 .35592 .41488 .376 .42546 .37326 .41971 .35151 Mtetra
.614 .499 .699 r
.41971 .35151 .42546 .37326 .43609 .37034 .43035 .34736 Mtetra
.608 .489 .692 r
.43035 .34736 .43609 .37034 .44677 .36719 .44102 .34338 Mtetra
.603 .482 .687 r
.44102 .34338 .44677 .36719 .4575 .36378 .45173 .33955 Mtetra
.601 .478 .685 r
.45173 .33955 .4575 .36378 .46828 .3601 .46248 .33583 Mtetra
.599 .477 .685 r
.46248 .33583 .46828 .3601 .4791 .35615 .47327 .33222 Mtetra
.597 .478 .688 r
.47327 .33222 .4791 .35615 .48997 .35194 .4841 .32876 Mtetra
.596 .481 .693 r
.4841 .32876 .48997 .35194 .50088 .3475 .49497 .32548 Mtetra
.595 .488 .702 r
.49497 .32548 .50088 .3475 .51183 .34287 .50589 .32245 Mtetra
.592 .497 .715 r
.50589 .32245 .51183 .34287 .52282 .33812 .51686 .31976 Mtetra
.589 .511 .735 r
.51686 .31976 .52282 .33812 .53385 .33332 .52788 .31749 Mtetra
.582 .534 .766 r
.52788 .31749 .53385 .33332 .54491 .32857 .53895 .31574 Mtetra
.567 .568 .814 r
.53895 .31574 .54491 .32857 .55601 .32399 .55009 .31461 Mtetra
.53 .624 .889 r
.55009 .31461 .55601 .32399 .56716 .31971 .56131 .31413 Mtetra
.411 .693 .978 r
.56131 .31413 .56716 .31971 .57836 .31591 .5726 .31438 Mtetra
.05 .603 .824 r
.5726 .31438 .57836 .31591 .58961 .31269 .58398 .31527 Mtetra
.321 0 0 r
.58398 .31527 .58961 .31269 .60093 .31022 .59546 .31674 Mtetra
.448 0 0 r
.59546 .31674 .60093 .31022 .61234 .30853 .60703 .31853 Mtetra
.484 .046 .129 r
.60703 .31853 .61234 .30853 .62383 .30767 .61869 .32038 Mtetra
.491 .083 .194 r
.61869 .32038 .62383 .30767 .63541 .30749 .63043 .32195 Mtetra
.481 .09 .221 r
.63043 .32195 .63541 .30749 .64709 .30784 .64224 .32285 Mtetra
.463 .078 .222 r
.64224 .32285 .64709 .30784 .65886 .30842 .6541 .32288 Mtetra
.432 .044 .201 r
.6541 .32288 .65886 .30842 .67071 .30889 .66599 .32178 Mtetra
.387 0 .154 r
.66599 .32178 .67071 .30889 .68262 .309 .67789 .31961 Mtetra
.314 0 .068 r
.67789 .31961 .68262 .309 .69458 .30842 .68981 .31638 Mtetra
.2 0 0 r
.68981 .31638 .69458 .30842 .70656 .30709 .70173 .31227 Mtetra
.012 0 0 r
.70173 .31227 .70656 .30709 .71857 .30488 .71366 .30746 Mtetra
0 0 0 r
.71366 .30746 .71857 .30488 .73059 .3019 .7256 .30211 Mtetra
.505 .911 .851 r
.7256 .30211 .73059 .3019 .74262 .2982 .73756 .29643 Mtetra
.649 .948 .953 r
.73756 .29643 .74262 .2982 .75466 .29395 .74954 .29052 Mtetra
.703 .916 .967 r
.74954 .29052 .75466 .29395 .76672 .2893 .76156 .28453 Mtetra
.72 .873 .953 r
.76156 .28453 .76672 .2893 .7788 .28435 .77361 .27848 Mtetra
.722 .835 .934 r
.77361 .27848 .7788 .28435 .79092 .27924 .78569 .27243 Mtetra
.718 .802 .917 r
.78569 .27243 .79092 .27924 .80308 .27409 .79782 .26643 Mtetra
.559 .723 .95 r
.14569 .47843 .15266 .48451 .1622 .48298 .15524 .477 Mtetra
.549 .724 .955 r
.15524 .477 .1622 .48298 .17178 .4815 .16481 .47569 Mtetra
.538 .727 .961 r
.16481 .47569 .17178 .4815 .1814 .48004 .17442 .4745 Mtetra
.524 .732 .969 r
.17442 .4745 .1814 .48004 .19108 .47854 .18407 .47342 Mtetra
.502 .741 .98 r
.18407 .47342 .19108 .47854 .20081 .47696 .19375 .47249 Mtetra
.476 .757 .992 r
.19375 .47249 .20081 .47696 .2106 .47517 .20348 .4716 Mtetra
.434 .775 .997 r
.20348 .4716 .2106 .47517 .22047 .47307 .21326 .47072 Mtetra
.375 .79 .979 r
.21326 .47072 .22047 .47307 .23043 .47047 .22311 .46967 Mtetra
.279 .772 .898 r
.22311 .46967 .23043 .47047 .24049 .46719 .23303 .46834 Mtetra
.149 .69 .723 r
.23303 .46834 .24049 .46719 .25066 .46307 .24305 .46651 Mtetra
0 0 0 r
.24305 .46651 .25066 .46307 .26095 .45792 .25317 .464 Mtetra
.089 0 0 r
.25317 .464 .26095 .45792 .27135 .45172 .26341 .46068 Mtetra
.156 0 0 r
.26341 .46068 .27135 .45172 .28185 .44442 .27375 .45638 Mtetra
.206 0 .029 r
.27375 .45638 .28185 .44442 .29242 .43627 .2842 .45117 Mtetra
.237 0 .109 r
.2842 .45117 .29242 .43627 .30305 .42744 .29474 .44504 Mtetra
.263 0 .166 r
.29474 .44504 .30305 .42744 .31371 .41833 .30535 .43823 Mtetra
.283 0 .204 r
.30535 .43823 .31371 .41833 .32437 .40925 .31602 .4309 Mtetra
.3 0 .23 r
.31602 .4309 .32437 .40925 .33501 .40048 .32671 .4233 Mtetra
.313 0 .248 r
.32671 .4233 .33501 .40048 .34563 .39225 .33742 .41566 Mtetra
.324 .004 .258 r
.33742 .41566 .34563 .39225 .35623 .38465 .34815 .40814 Mtetra
.333 .013 .263 r
.34815 .40814 .35623 .38465 .36681 .37774 .35887 .40088 Mtetra
.339 .017 .264 r
.35887 .40088 .36681 .37774 .37738 .37147 .36959 .39396 Mtetra
.344 .019 .261 r
.36959 .39396 .37738 .37147 .38794 .36581 .38032 .38744 Mtetra
.348 .018 .255 r
.38032 .38744 .38794 .36581 .39851 .36065 .39105 .38132 Mtetra
.351 .015 .248 r
.39105 .38132 .39851 .36065 .4091 .35592 .40179 .37563 Mtetra
.354 .012 .24 r
.40179 .37563 .4091 .35592 .41971 .35151 .41255 .37034 Mtetra
.357 .01 .232 r
.41255 .37034 .41971 .35151 .43035 .34736 .42332 .36547 Mtetra
.362 .009 .226 r
.42332 .36547 .43035 .34736 .44102 .34338 .43412 .36098 Mtetra
.368 .012 .222 r
.43412 .36098 .44102 .34338 .45173 .33955 .44494 .35687 Mtetra
.377 .018 .223 r
.44494 .35687 .45173 .33955 .46248 .33583 .4558 .35315 Mtetra
.388 .028 .228 r
.4558 .35315 .46248 .33583 .47327 .33222 .46669 .3498 Mtetra
.401 .042 .236 r
.46669 .3498 .47327 .33222 .4841 .32876 .47763 .34683 Mtetra
.416 .059 .248 r
.47763 .34683 .4841 .32876 .49497 .32548 .48861 .34426 Mtetra
.43 .076 .262 r
.48861 .34426 .49497 .32548 .50589 .32245 .49963 .34211 Mtetra
.444 .094 .276 r
.49963 .34211 .50589 .32245 .51686 .31976 .51072 .34037 Mtetra
.457 .111 .29 r
.51072 .34037 .51686 .31976 .52788 .31749 .52186 .33906 Mtetra
.469 .127 .302 r
.52186 .33906 .52788 .31749 .53895 .31574 .53306 .33818 Mtetra
.479 .139 .312 r
.53306 .33818 .53895 .31574 .55009 .31461 .54434 .33771 Mtetra
.486 .148 .319 r
.54434 .33771 .55009 .31461 .56131 .31413 .55569 .33759 Mtetra
.491 .154 .323 r
.55569 .33759 .56131 .31413 .5726 .31438 .56711 .33775 Mtetra
.493 .155 .322 r
.56711 .33775 .5726 .31438 .58398 .31527 .57862 .33804 Mtetra
.491 .151 .317 r
.57862 .33804 .58398 .31527 .59546 .31674 .5902 .3383 Mtetra
.484 .138 .304 r
.5902 .3383 .59546 .31674 .60703 .31853 .60186 .3383 Mtetra
.469 .115 .282 r
.60186 .3383 .60703 .31853 .61869 .32038 .61357 .33779 Mtetra
.445 .078 .246 r
.61357 .33779 .61869 .32038 .63043 .32195 .62534 .33658 Mtetra
.402 .016 .189 r
.62534 .33658 .63043 .32195 .64224 .32285 .63715 .33443 Mtetra
.333 0 .097 r
.63715 .33443 .64224 .32285 .6541 .32288 .64899 .33135 Mtetra
.211 0 0 r
.64899 .33135 .6541 .32288 .66599 .32178 .66083 .32726 Mtetra
.01 0 0 r
.66083 .32726 .66599 .32178 .67789 .31961 .67269 .32232 Mtetra
0 0 0 r
.67269 .32232 .67789 .31961 .68981 .31638 .68456 .31667 Mtetra
.548 .93 .857 r
.68456 .31667 .68981 .31638 .70173 .31227 .69643 .3105 Mtetra
.686 .957 .948 r
.69643 .3105 .70173 .31227 .71366 .30746 .70832 .30402 Mtetra
.734 .921 .955 r
.70832 .30402 .71366 .30746 .7256 .30211 .72024 .29736 Mtetra
.744 .877 .941 r
.72024 .29736 .7256 .30211 .73756 .29643 .73218 .29068 Mtetra
.742 .843 .926 r
.73218 .29068 .73756 .29643 .74954 .29052 .74416 .28405 Mtetra
.735 .817 .915 r
.74416 .28405 .74954 .29052 .76156 .28453 .75619 .27755 Mtetra
.729 .8 .908 r
.75619 .27755 .76156 .28453 .77361 .27848 .76826 .27117 Mtetra
.724 .789 .903 r
.76826 .27117 .77361 .27848 .78569 .27243 .78037 .26489 Mtetra
.72 .781 .901 r
.78037 .26489 .78569 .27243 .79782 .26643 .79252 .25872 Mtetra
.586 .732 .944 r
.13868 .4723 .14569 .47843 .15524 .477 .14829 .4704 Mtetra
.583 .715 .934 r
.14829 .4704 .15524 .477 .16481 .47569 .15793 .46862 Mtetra
.577 .698 .924 r
.15793 .46862 .16481 .47569 .17442 .4745 .16759 .467 Mtetra
.569 .682 .916 r
.16759 .467 .17442 .4745 .18407 .47342 .17729 .46558 Mtetra
.558 .668 .911 r
.17729 .46558 .18407 .47342 .19375 .47249 .187 .46441 Mtetra
.548 .658 .908 r
.187 .46441 .19375 .47249 .20348 .4716 .19675 .46347 Mtetra
.536 .652 .909 r
.19675 .46347 .20348 .4716 .21326 .47072 .20652 .46275 Mtetra
.525 .653 .916 r
.20652 .46275 .21326 .47072 .22311 .46967 .21633 .46219 Mtetra
.51 .663 .93 r
.21633 .46219 .22311 .46967 .23303 .46834 .22619 .46177 Mtetra
.489 .686 .954 r
.22619 .46177 .23303 .46834 .24305 .46651 .23609 .46141 Mtetra
.444 .723 .985 r
.23609 .46141 .24305 .46651 .25317 .464 .24605 .46107 Mtetra
.333 .751 .977 r
.24605 .46107 .25317 .464 .26341 .46068 .25608 .46065 Mtetra
.086 .645 .761 r
.25608 .46065 .26341 .46068 .27375 .45638 .26618 .46007 Mtetra
.184 0 0 r
.26618 .46007 .27375 .45638 .2842 .45117 .27635 .45917 Mtetra
.32 0 0 r
.27635 .45917 .2842 .45117 .29474 .44504 .28662 .45782 Mtetra
.378 0 .142 r
.28662 .45782 .29474 .44504 .30535 .43823 .29698 .45588 Mtetra
.402 .04 .231 r
.29698 .45588 .30535 .43823 .31602 .4309 .30745 .45322 Mtetra
.415 .079 .284 r
.30745 .45322 .31602 .4309 .32671 .4233 .318 .44987 Mtetra
.421 .102 .316 r
.318 .44987 .32671 .4233 .33742 .41566 .32863 .44583 Mtetra
.426 .118 .338 r
.32863 .44583 .33742 .41566 .34815 .40814 .33934 .44123 Mtetra
.429 .128 .352 r
.33934 .44123 .34815 .40814 .35887 .40088 .3501 .43617 Mtetra
.432 .136 .361 r
.3501 .43617 .35887 .40088 .36959 .39396 .36091 .43081 Mtetra
.434 .142 .367 r
.36091 .43081 .36959 .39396 .38032 .38744 .37177 .42529 Mtetra
.437 .146 .372 r
.37177 .42529 .38032 .38744 .39105 .38132 .38265 .41975 Mtetra
.44 .15 .375 r
.38265 .41975 .39105 .38132 .40179 .37563 .39356 .41431 Mtetra
.443 .154 .377 r
.39356 .41431 .40179 .37563 .41255 .37034 .40449 .40907 Mtetra
.448 .157 .378 r
.40449 .40907 .41255 .37034 .42332 .36547 .41545 .40414 Mtetra
.452 .161 .38 r
.41545 .40414 .42332 .36547 .43412 .36098 .42643 .39957 Mtetra
.457 .166 .381 r
.42643 .39957 .43412 .36098 .44494 .35687 .43744 .39542 Mtetra
.463 .17 .382 r
.43744 .39542 .44494 .35687 .4558 .35315 .44847 .3917 Mtetra
.468 .175 .384 r
.44847 .3917 .4558 .35315 .46669 .3498 .45955 .38842 Mtetra
.473 .179 .386 r
.45955 .38842 .46669 .3498 .47763 .34683 .47066 .38556 Mtetra
.477 .183 .387 r
.47066 .38556 .47763 .34683 .48861 .34426 .48183 .38307 Mtetra
.481 .186 .388 r
.48183 .38307 .48861 .34426 .49963 .34211 .49304 .38089 Mtetra
.483 .188 .388 r
.49304 .38089 .49963 .34211 .51072 .34037 .50431 .37892 Mtetra
.484 .188 .388 r
.50431 .37892 .51072 .34037 .52186 .33906 .51564 .37706 Mtetra
.483 .187 .386 r
.51564 .37706 .52186 .33906 .53306 .33818 .52703 .37518 Mtetra
.48 .182 .382 r
.52703 .37518 .53306 .33818 .54434 .33771 .53848 .37315 Mtetra
.475 .174 .375 r
.53848 .37315 .54434 .33771 .55569 .33759 .54999 .37081 Mtetra
.465 .16 .364 r
.54999 .37081 .55569 .33759 .56711 .33775 .56155 .36801 Mtetra
.451 .14 .346 r
.56155 .36801 .56711 .33775 .57862 .33804 .57316 .36465 Mtetra
.428 .108 .319 r
.57316 .36465 .57862 .33804 .5902 .3383 .58481 .36057 Mtetra
.393 .059 .276 r
.58481 .36057 .5902 .3383 .60186 .3383 .59649 .35578 Mtetra
.333 0 .203 r
.59649 .35578 .60186 .3383 .61357 .33779 .6082 .35026 Mtetra
.225 0 .068 r
.6082 .35026 .61357 .33779 .62534 .33658 .61992 .34412 Mtetra
.008 0 0 r
.61992 .34412 .62534 .33658 .63715 .33443 .63167 .3375 Mtetra
.377 .805 .627 r
.63167 .3375 .63715 .33443 .64899 .33135 .64343 .33054 Mtetra
.689 .973 .918 r
.64343 .33054 .64899 .33135 .66083 .32726 .65521 .32341 Mtetra
.762 .907 .94 r
.65521 .32341 .66083 .32726 .67269 .32232 .66701 .31617 Mtetra
.759 .828 .906 r
.66701 .31617 .67269 .32232 .68456 .31667 .67884 .30894 Mtetra
.747 .777 .878 r
.67884 .30894 .68456 .31667 .69643 .3105 .69071 .30177 Mtetra
.736 .747 .862 r
.69071 .30177 .69643 .3105 .70832 .30402 .7026 .29472 Mtetra
.727 .731 .854 r
.7026 .29472 .70832 .30402 .72024 .29736 .71454 .28783 Mtetra
.72 .724 .853 r
.71454 .28783 .72024 .29736 .73218 .29068 .72652 .28116 Mtetra
.715 .722 .856 r
.72652 .28116 .73218 .29068 .74416 .28405 .73855 .27471 Mtetra
.709 .726 .863 r
.73855 .27471 .74416 .28405 .75619 .27755 .75063 .26851 Mtetra
.706 .733 .872 r
.75063 .26851 .75619 .27755 .76826 .27117 .76276 .26251 Mtetra
.704 .743 .882 r
.76276 .26251 .76826 .27117 .78037 .26489 .77495 .25667 Mtetra
.703 .756 .893 r
.77495 .25667 .78037 .26489 .79252 .25872 .78718 .25095 Mtetra
.636 .746 .928 r
.13161 .46613 .13868 .4723 .14829 .4704 .14135 .46322 Mtetra
.633 .714 .906 r
.14135 .46322 .14829 .4704 .15793 .46862 .15112 .46041 Mtetra
.625 .682 .884 r
.15112 .46041 .15793 .46862 .16759 .467 .16091 .45778 Mtetra
.615 .653 .864 r
.16091 .45778 .16759 .467 .17729 .46558 .17071 .45537 Mtetra
.602 .626 .847 r
.17071 .45537 .17729 .46558 .187 .46441 .18053 .45328 Mtetra
.589 .602 .832 r
.18053 .45328 .187 .46441 .19675 .46347 .19036 .45153 Mtetra
.576 .58 .82 r
.19036 .45153 .19675 .46347 .20652 .46275 .20019 .45014 Mtetra
.564 .563 .811 r
.20019 .45014 .20652 .46275 .21633 .46219 .21005 .44911 Mtetra
.552 .55 .805 r
.21005 .44911 .21633 .46219 .22619 .46177 .21992 .44844 Mtetra
.542 .541 .803 r
.21992 .44844 .22619 .46177 .23609 .46141 .22982 .44808 Mtetra
.532 .537 .805 r
.22982 .44808 .23609 .46141 .24605 .46107 .23975 .44798 Mtetra
.525 .538 .811 r
.23975 .44798 .24605 .46107 .25608 .46065 .24973 .44807 Mtetra
.52 .544 .821 r
.24973 .44807 .25608 .46065 .26618 .46007 .25976 .44824 Mtetra
.518 .558 .836 r
.25976 .44824 .26618 .46007 .27635 .45917 .26986 .44836 Mtetra
.52 .582 .857 r
.26986 .44836 .27635 .45917 .28662 .45782 .28004 .44829 Mtetra
.526 .616 .885 r
.28004 .44829 .28662 .45782 .29698 .45588 .2903 .4479 Mtetra
.534 .665 .92 r
.2903 .4479 .29698 .45588 .30745 .45322 .30065 .44706 Mtetra
.537 .728 .962 r
.30065 .44706 .30745 .45322 .318 .44987 .31109 .44573 Mtetra
.524 .8 .996 r
.31109 .44573 .318 .44987 .32863 .44583 .32162 .44388 Mtetra
.463 .849 .982 r
.32162 .44388 .32863 .44583 .33934 .44123 .33224 .44155 Mtetra
.329 .813 .853 r
.33224 .44155 .33934 .44123 .3501 .43617 .34293 .43878 Mtetra
0 0 0 r
.34293 .43878 .3501 .43617 .36091 .43081 .35368 .43565 Mtetra
.014 0 0 r
.35368 .43565 .36091 .43081 .37177 .42529 .3645 .43224 Mtetra
.126 0 0 r
.3645 .43224 .37177 .42529 .38265 .41975 .37536 .42862 Mtetra
.201 0 0 r
.37536 .42862 .38265 .41975 .39356 .41431 .38628 .42486 Mtetra
.25 0 .012 r
.38628 .42486 .39356 .41431 .40449 .40907 .39725 .42101 Mtetra
.284 0 .068 r
.39725 .42101 .40449 .40907 .41545 .40414 .40826 .41715 Mtetra
.307 0 .104 r
.40826 .41715 .41545 .40414 .42643 .39957 .41931 .41331 Mtetra
.322 0 .127 r
.41931 .41331 .42643 .39957 .43744 .39542 .43041 .40951 Mtetra
.331 0 .138 r
.43041 .40951 .43744 .39542 .44847 .3917 .44154 .40579 Mtetra
.334 0 .14 r
.44154 .40579 .44847 .3917 .45955 .38842 .45273 .40213 Mtetra
.331 0 .131 r
.45273 .40213 .45955 .38842 .47066 .38556 .46395 .39852 Mtetra
.32 0 .111 r
.46395 .39852 .47066 .38556 .48183 .38307 .47523 .39493 Mtetra
.3 0 .076 r
.47523 .39493 .48183 .38307 .49304 .38089 .48655 .39132 Mtetra
.265 0 .02 r
.48655 .39132 .49304 .38089 .50431 .37892 .49792 .38764 Mtetra
.207 0 0 r
.49792 .38764 .50431 .37892 .51564 .37706 .50935 .3838 Mtetra
.11 0 0 r
.50935 .3838 .51564 .37706 .52703 .37518 .52081 .37976 Mtetra
0 0 0 r
.52081 .37976 .52703 .37518 .53848 .37315 .53233 .37542 Mtetra
.289 .771 .681 r
.53233 .37542 .53848 .37315 .54999 .37081 .54389 .37071 Mtetra
.538 .924 .903 r
.54389 .37071 .54999 .37081 .56155 .36801 .55548 .36556 Mtetra
.682 .928 .97 r
.55548 .36556 .56155 .36801 .57316 .36465 .56711 .35991 Mtetra
.733 .863 .942 r
.56711 .35991 .57316 .36465 .58481 .36057 .57877 .35371 Mtetra
.742 .795 .895 r
.57877 .35371 .58481 .36057 .59649 .35578 .59045 .34701 Mtetra
.738 .741 .854 r
.59045 .34701 .59649 .35578 .6082 .35026 .60214 .33983 Mtetra
.731 .703 .823 r
.60214 .33983 .6082 .35026 .61992 .34412 .61386 .33231 Mtetra
.723 .674 .802 r
.61386 .33231 .61992 .34412 .63167 .3375 .62559 .32458 Mtetra
.715 .653 .787 r
.62559 .32458 .63167 .3375 .64343 .33054 .63734 .31678 Mtetra
.707 .638 .777 r
.63734 .31678 .64343 .33054 .65521 .32341 .64911 .30906 Mtetra
.7 .627 .771 r
.64911 .30906 .65521 .32341 .66701 .31617 .66092 .3015 Mtetra
.693 .619 .769 r
.66092 .3015 .66701 .31617 .67884 .30894 .67276 .29421 Mtetra
.687 .616 .771 r
.67276 .29421 .67884 .30894 .69071 .30177 .68464 .28723 Mtetra
.682 .616 .776 r
.68464 .28723 .69071 .30177 .7026 .29472 .69658 .2806 Mtetra
.678 .62 .784 r
.69658 .2806 .7026 .29472 .71454 .28783 .70857 .27433 Mtetra
.674 .628 .795 r
.70857 .27433 .71454 .28783 .72652 .28116 .72061 .26844 Mtetra
.672 .64 .81 r
.72061 .26844 .72652 .28116 .73855 .27471 .73272 .26289 Mtetra
.67 .656 .827 r
.73272 .26289 .73855 .27471 .75063 .26851 .7449 .25765 Mtetra
.669 .675 .847 r
.7449 .25765 .75063 .26851 .76276 .26251 .75714 .25266 Mtetra
.669 .699 .869 r
.75714 .25266 .76276 .26251 .77495 .25667 .76944 .24784 Mtetra
.67 .727 .892 r
.76944 .24784 .77495 .25667 .78718 .25095 .7818 .24311 Mtetra
.685 .758 .907 r
.12449 .45992 .13161 .46613 .14135 .46322 .1344 .45577 Mtetra
.678 .72 .881 r
.1344 .45577 .14135 .46322 .15112 .46041 .14433 .45167 Mtetra
.667 .684 .856 r
.14433 .45167 .15112 .46041 .16091 .45778 .15428 .44772 Mtetra
.654 .65 .834 r
.15428 .44772 .16091 .45778 .17071 .45537 .16424 .44399 Mtetra
.639 .619 .814 r
.16424 .44399 .17071 .45537 .18053 .45328 .1742 .44056 Mtetra
.624 .591 .796 r
.1742 .44056 .18053 .45328 .19036 .45153 .18416 .4375 Mtetra
.608 .564 .78 r
.18416 .4375 .19036 .45153 .20019 .45014 .19411 .43487 Mtetra
.594 .542 .765 r
.19411 .43487 .20019 .45014 .21005 .44911 .20407 .43265 Mtetra
.581 .521 .753 r
.20407 .43265 .21005 .44911 .21992 .44844 .21403 .43084 Mtetra
.572 .505 .741 r
.21403 .43084 .21992 .44844 .22982 .44808 .22402 .42936 Mtetra
.565 .491 .73 r
.22402 .42936 .22982 .44808 .23975 .44798 .23403 .42812 Mtetra
.561 .479 .72 r
.23403 .42812 .23975 .44798 .24973 .44807 .24408 .42701 Mtetra
.559 .47 .71 r
.24408 .42701 .24973 .44807 .25976 .44824 .25419 .42592 Mtetra
.558 .461 .701 r
.25419 .42592 .25976 .44824 .26986 .44836 .26435 .42481 Mtetra
.558 .454 .692 r
.26435 .42481 .26986 .44836 .28004 .44829 .27457 .42365 Mtetra
.558 .448 .685 r
.27457 .42365 .28004 .44829 .2903 .4479 .28485 .42245 Mtetra
.557 .444 .681 r
.28485 .42245 .2903 .4479 .30065 .44706 .29519 .42125 Mtetra
.557 .442 .679 r
.29519 .42125 .30065 .44706 .31109 .44573 .30558 .42007 Mtetra
.556 .443 .68 r
.30558 .42007 .31109 .44573 .32162 .44388 .31603 .4189 Mtetra
.557 .447 .685 r
.31603 .4189 .32162 .44388 .33224 .44155 .32653 .41772 Mtetra
.559 .455 .693 r
.32653 .41772 .33224 .44155 .34293 .43878 .3371 .41651 Mtetra
.561 .467 .704 r
.3371 .41651 .34293 .43878 .35368 .43565 .34773 .41522 Mtetra
.566 .483 .72 r
.34773 .41522 .35368 .43565 .3645 .43224 .35842 .41379 Mtetra
.572 .503 .739 r
.35842 .41379 .3645 .43224 .37536 .42862 .36918 .41217 Mtetra
.581 .529 .762 r
.36918 .41217 .37536 .42862 .38628 .42486 .38001 .4103 Mtetra
.591 .559 .787 r
.38001 .4103 .38628 .42486 .39725 .42101 .39091 .40811 Mtetra
.604 .591 .811 r
.39091 .40811 .39725 .42101 .40826 .41715 .40187 .40557 Mtetra
.618 .622 .832 r
.40187 .40557 .40826 .41715 .41931 .41331 .41291 .40265 Mtetra
.632 .647 .847 r
.41291 .40265 .41931 .41331 .43041 .40951 .424 .39931 Mtetra
.645 .663 .853 r
.424 .39931 .43041 .40951 .44154 .40579 .43516 .39555 Mtetra
.657 .668 .849 r
.43516 .39555 .44154 .40579 .45273 .40213 .44637 .39137 Mtetra
.665 .661 .836 r
.44637 .39137 .45273 .40213 .46395 .39852 .45763 .38678 Mtetra
.669 .645 .817 r
.45763 .38678 .46395 .39852 .47523 .39493 .46894 .38179 Mtetra
.668 .622 .794 r
.46894 .38179 .47523 .39493 .48655 .39132 .4803 .37644 Mtetra
.664 .597 .77 r
.4803 .37644 .48655 .39132 .49792 .38764 .49169 .37078 Mtetra
.658 .572 .747 r
.49169 .37078 .49792 .38764 .50935 .3838 .50313 .36485 Mtetra
.651 .549 .726 r
.50313 .36485 .50935 .3838 .52081 .37976 .51459 .35871 Mtetra
.644 .53 .709 r
.51459 .35871 .52081 .37976 .53233 .37542 .52609 .35243 Mtetra
.637 .514 .696 r
.52609 .35243 .53233 .37542 .54389 .37071 .53761 .34605 Mtetra
.632 .502 .686 r
.53761 .34605 .54389 .37071 .55548 .36556 .54917 .33963 Mtetra
.628 .493 .679 r
.54917 .33963 .55548 .36556 .56711 .35991 .56076 .3332 Mtetra
.625 .488 .675 r
.56076 .3332 .56711 .35991 .57877 .35371 .57237 .32677 Mtetra
.624 .486 .674 r
.57237 .32677 .57877 .35371 .59045 .34701 .58402 .32034 Mtetra
.625 .488 .675 r
.58402 .32034 .59045 .34701 .60214 .33983 .5957 .3139 Mtetra
.628 .493 .679 r
.5957 .3139 .60214 .33983 .61386 .33231 .60742 .30742 Mtetra
.632 .501 .685 r
.60742 .30742 .61386 .33231 .62559 .32458 .61916 .30086 Mtetra
.636 .51 .692 r
.61916 .30086 .62559 .32458 .63734 .31678 .63093 .29428 Mtetra
.641 .52 .701 r
.63093 .29428 .63734 .31678 .64911 .30906 .64273 .2877 Mtetra
.643 .529 .709 r
.64273 .2877 .64911 .30906 .66092 .3015 .65457 .28125 Mtetra
.644 .538 .719 r
.65457 .28125 .66092 .3015 .67276 .29421 .66645 .27505 Mtetra
.644 .547 .73 r
.66645 .27505 .67276 .29421 .68464 .28723 .67839 .26916 Mtetra
.642 .556 .742 r
.67839 .26916 .68464 .28723 .69658 .2806 .69039 .2637 Mtetra
.64 .566 .756 r
.69039 .2637 .69658 .2806 .70857 .27433 .70245 .25866 Mtetra
.637 .579 .773 r
.70245 .25866 .70857 .27433 .72061 .26844 .71458 .25406 Mtetra
.634 .596 .793 r
.71458 .25406 .72061 .26844 .73272 .26289 .7268 .24982 Mtetra
.632 .615 .816 r
.7268 .24982 .73272 .26289 .7449 .25765 .73908 .24591 Mtetra
.63 .64 .841 r
.73908 .24591 .7449 .25765 .75714 .25266 .75144 .24223 Mtetra
.629 .668 .869 r
.75144 .24223 .75714 .25266 .76944 .24784 .76387 .23869 Mtetra
.628 .701 .898 r
.76387 .23869 .76944 .24784 .7818 .24311 .77637 .23521 Mtetra
.72 .764 .887 r
.11732 .45366 .12449 .45992 .1344 .45577 .12739 .44839 Mtetra
.712 .731 .866 r
.12739 .44839 .1344 .45577 .14433 .45167 .13748 .44311 Mtetra
.702 .7 .845 r
.13748 .44311 .14433 .45167 .15428 .44772 .14758 .4379 Mtetra
.69 .669 .825 r
.14758 .4379 .15428 .44772 .16424 .44399 .1577 .4328 Mtetra
.676 .639 .805 r
.1577 .4328 .16424 .44399 .1742 .44056 .16783 .42789 Mtetra
.662 .61 .786 r
.16783 .42789 .1742 .44056 .18416 .4375 .17796 .42323 Mtetra
.646 .581 .767 r
.17796 .42323 .18416 .4375 .19411 .43487 .18809 .41889 Mtetra
.631 .554 .749 r
.18809 .41889 .19411 .43487 .20407 .43265 .19822 .41488 Mtetra
.617 .529 .733 r
.19822 .41488 .20407 .43265 .21403 .43084 .20834 .41126 Mtetra
.604 .507 .717 r
.20834 .41126 .21403 .43084 .22402 .42936 .21847 .40798 Mtetra
.593 .488 .704 r
.21847 .40798 .22402 .42936 .23403 .42812 .22861 .40505 Mtetra
.584 .472 .692 r
.22861 .40505 .23403 .42812 .24408 .42701 .23876 .40241 Mtetra
.577 .46 .683 r
.23876 .40241 .24408 .42701 .25419 .42592 .24894 .40001 Mtetra
.572 .45 .675 r
.24894 .40001 .25419 .42592 .26435 .42481 .25915 .39783 Mtetra
.567 .442 .67 r
.25915 .39783 .26435 .42481 .27457 .42365 .26939 .39584 Mtetra
.563 .437 .666 r
.26939 .39584 .27457 .42365 .28485 .42245 .27967 .39402 Mtetra
.56 .433 .663 r
.27967 .39402 .28485 .42245 .29519 .42125 .28999 .39235 Mtetra
.558 .429 .661 r
.28999 .39235 .29519 .42125 .30558 .42007 .30035 .3908 Mtetra
.557 .427 .66 r
.30035 .3908 .30558 .42007 .31603 .4189 .31077 .38932 Mtetra
.556 .426 .659 r
.31077 .38932 .31603 .4189 .32653 .41772 .32123 .38786 Mtetra
.556 .425 .658 r
.32123 .38786 .32653 .41772 .3371 .41651 .33176 .38638 Mtetra
.557 .425 .657 r
.33176 .38638 .3371 .41651 .34773 .41522 .34235 .38482 Mtetra
.559 .426 .656 r
.34235 .38482 .34773 .41522 .35842 .41379 .353 .38312 Mtetra
.561 .426 .655 r
.353 .38312 .35842 .41379 .36918 .41217 .36371 .38125 Mtetra
.564 .428 .654 r
.36371 .38125 .36918 .41217 .38001 .4103 .37449 .37914 Mtetra
.567 .429 .653 r
.37449 .37914 .38001 .4103 .39091 .40811 .38534 .37675 Mtetra
.571 .431 .653 r
.38534 .37675 .39091 .40811 .40187 .40557 .39626 .37404 Mtetra
.575 .434 .652 r
.39626 .37404 .40187 .40557 .41291 .40265 .40724 .37098 Mtetra
.579 .437 .652 r
.40724 .37098 .41291 .40265 .424 .39931 .41828 .36755 Mtetra
.583 .439 .651 r
.41828 .36755 .424 .39931 .43516 .39555 .42938 .36375 Mtetra
.587 .442 .651 r
.42938 .36375 .43516 .39555 .44637 .39137 .44053 .35956 Mtetra
.592 .445 .651 r
.44053 .35956 .44637 .39137 .45763 .38678 .45174 .35499 Mtetra
.596 .448 .651 r
.45174 .35499 .45763 .38678 .46894 .38179 .463 .35008 Mtetra
.599 .451 .651 r
.463 .35008 .46894 .38179 .4803 .37644 .4743 .34483 Mtetra
.602 .453 .652 r
.4743 .34483 .4803 .37644 .49169 .37078 .48564 .3393 Mtetra
.605 .456 .652 r
.48564 .3393 .49169 .37078 .50313 .36485 .49701 .33353 Mtetra
.608 .458 .653 r
.49701 .33353 .50313 .36485 .51459 .35871 .50842 .32757 Mtetra
.609 .46 .654 r
.50842 .32757 .51459 .35871 .52609 .35243 .51987 .32146 Mtetra
.611 .461 .654 r
.51987 .32146 .52609 .35243 .53761 .34605 .53135 .31527 Mtetra
.611 .462 .655 r
.53135 .31527 .53761 .34605 .54917 .33963 .54285 .30904 Mtetra
.612 .463 .656 r
.54285 .30904 .54917 .33963 .56076 .3332 .5544 .30282 Mtetra
.611 .464 .657 r
.5544 .30282 .56076 .3332 .57237 .32677 .56597 .29667 Mtetra
.611 .465 .659 r
.56597 .29667 .57237 .32677 .58402 .32034 .57758 .29063 Mtetra
.61 .465 .66 r
.57758 .29063 .58402 .32034 .5957 .3139 .58922 .28473 Mtetra
.609 .467 .663 r
.58922 .28473 .5957 .3139 .60742 .30742 .60091 .279 Mtetra
.609 .47 .667 r
.60091 .279 .60742 .30742 .61916 .30086 .61264 .27346 Mtetra
.608 .474 .673 r
.61264 .27346 .61916 .30086 .63093 .29428 .62441 .26813 Mtetra
.608 .48 .68 r
.62441 .26813 .63093 .29428 .64273 .2877 .63623 .26305 Mtetra
.608 .488 .69 r
.63623 .26305 .64273 .2877 .65457 .28125 .64811 .25827 Mtetra
.608 .497 .702 r
.64811 .25827 .65457 .28125 .66645 .27505 .66005 .25383 Mtetra
.607 .509 .717 r
.66005 .25383 .66645 .27505 .67839 .26916 .67206 .24975 Mtetra
.606 .523 .734 r
.67206 .24975 .67839 .26916 .69039 .2637 .68414 .24606 Mtetra
.604 .539 .754 r
.68414 .24606 .69039 .2637 .70245 .25866 .6963 .24272 Mtetra
.602 .557 .777 r
.6963 .24272 .70245 .25866 .71458 .25406 .70854 .23971 Mtetra
.599 .578 .801 r
.70854 .23971 .71458 .25406 .7268 .24982 .72086 .23696 Mtetra
.596 .602 .827 r
.72086 .23696 .7268 .24982 .73908 .24591 .73325 .2344 Mtetra
.593 .627 .854 r
.73325 .2344 .73908 .24591 .75144 .24223 .74573 .23198 Mtetra
.59 .655 .882 r
.74573 .23198 .75144 .24223 .76387 .23869 .75828 .22961 Mtetra
.587 .685 .909 r
.75828 .22961 .76387 .23869 .77637 .23521 .7709 .22725 Mtetra
.74 .766 .874 r
.1101 .44736 .11732 .45366 .12739 .44839 .12028 .44132 Mtetra
.735 .745 .86 r
.12028 .44132 .12739 .44839 .13748 .44311 .13049 .43521 Mtetra
.729 .723 .845 r
.13049 .43521 .13748 .44311 .14758 .4379 .14073 .42907 Mtetra
.721 .701 .83 r
.14073 .42907 .14758 .4379 .1577 .4328 .15099 .42292 Mtetra
.712 .677 .814 r
.15099 .42292 .1577 .4328 .16783 .42789 .16127 .41678 Mtetra
.701 .651 .797 r
.16127 .41678 .16783 .42789 .17796 .42323 .17156 .41072 Mtetra
.688 .625 .78 r
.17156 .41072 .17796 .42323 .18809 .41889 .18186 .40477 Mtetra
.674 .598 .762 r
.18186 .40477 .18809 .41889 .19822 .41488 .19217 .39904 Mtetra
.659 .571 .745 r
.19217 .39904 .19822 .41488 .20834 .41126 .20247 .39358 Mtetra
.643 .545 .729 r
.20247 .39358 .20834 .41126 .21847 .40798 .21276 .38848 Mtetra
.628 .522 .715 r
.21276 .38848 .21847 .40798 .22861 .40505 .22304 .38381 Mtetra
.614 .502 .702 r
.22304 .38381 .22861 .40505 .23876 .40241 .23331 .37961 Mtetra
.601 .485 .693 r
.23331 .37961 .23876 .40241 .24894 .40001 .24357 .37593 Mtetra
.591 .471 .685 r
.24357 .37593 .24894 .40001 .25915 .39783 .25383 .3727 Mtetra
.582 .46 .679 r
.25383 .3727 .25915 .39783 .26939 .39584 .2641 .36988 Mtetra
.576 .453 .675 r
.2641 .36988 .26939 .39584 .27967 .39402 .2744 .36731 Mtetra
.573 .448 .671 r
.2744 .36731 .27967 .39402 .28999 .39235 .28473 .36487 Mtetra
.572 .444 .667 r
.28473 .36487 .28999 .39235 .30035 .3908 .29511 .36246 Mtetra
.571 .44 .663 r
.29511 .36246 .30035 .3908 .31077 .38932 .30554 .35995 Mtetra
.572 .437 .658 r
.30554 .35995 .31077 .38932 .32123 .38786 .31603 .35731 Mtetra
.572 .433 .653 r
.31603 .35731 .32123 .38786 .33176 .38638 .32658 .3545 Mtetra
.573 .429 .648 r
.32658 .3545 .33176 .38638 .34235 .38482 .33719 .35151 Mtetra
.573 .425 .643 r
.33719 .35151 .34235 .38482 .353 .38312 .34785 .34836 Mtetra
.572 .421 .638 r
.34785 .34836 .353 .38312 .36371 .38125 .35857 .34507 Mtetra
.572 .417 .633 r
.35857 .34507 .36371 .38125 .37449 .37914 .36934 .34166 Mtetra
.571 .414 .629 r
.36934 .34166 .37449 .37914 .38534 .37675 .38016 .33814 Mtetra
.571 .411 .626 r
.38016 .33814 .38534 .37675 .39626 .37404 .39104 .33452 Mtetra
.571 .409 .624 r
.39104 .33452 .39626 .37404 .40724 .37098 .40195 .33082 Mtetra
.571 .408 .622 r
.40195 .33082 .40724 .37098 .41828 .36755 .41292 .32704 Mtetra
.571 .408 .621 r
.41292 .32704 .41828 .36755 .42938 .36375 .42393 .32318 Mtetra
.572 .408 .621 r
.42393 .32318 .42938 .36375 .44053 .35956 .435 .31923 Mtetra
.573 .41 .622 r
.435 .31923 .44053 .35956 .45174 .35499 .4461 .3152 Mtetra
.574 .412 .624 r
.4461 .3152 .45174 .35499 .463 .35008 .45726 .31108 Mtetra
.576 .415 .626 r
.45726 .31108 .463 .35008 .4743 .34483 .46846 .30686 Mtetra
.578 .419 .629 r
.46846 .30686 .4743 .34483 .48564 .3393 .4797 .30254 Mtetra
.581 .424 .633 r
.4797 .30254 .48564 .3393 .49701 .33353 .49099 .29809 Mtetra
.584 .429 .637 r
.49099 .29809 .49701 .33353 .50842 .32757 .50233 .2935 Mtetra
.588 .436 .642 r
.50233 .2935 .50842 .32757 .51987 .32146 .51371 .28873 Mtetra
.592 .443 .647 r
.51371 .28873 .51987 .32146 .53135 .31527 .52513 .28379 Mtetra
.597 .45 .652 r
.52513 .28379 .53135 .31527 .54285 .30904 .53658 .27866 Mtetra
.601 .456 .657 r
.53658 .27866 .54285 .30904 .5544 .30282 .54808 .2734 Mtetra
.604 .462 .661 r
.54808 .2734 .5544 .30282 .56597 .29667 .55962 .26804 Mtetra
.605 .466 .665 r
.55962 .26804 .56597 .29667 .57758 .29063 .5712 .26268 Mtetra
.605 .469 .669 r
.5712 .26268 .57758 .29063 .58922 .28473 .58281 .25746 Mtetra
.604 .471 .673 r
.58281 .25746 .58922 .28473 .60091 .279 .59448 .2525 Mtetra
.6 .472 .678 r
.59448 .2525 .60091 .279 .61264 .27346 .6062 .24795 Mtetra
.596 .475 .685 r
.6062 .24795 .61264 .27346 .62441 .26813 .61797 .24386 Mtetra
.591 .478 .694 r
.61797 .24386 .62441 .26813 .63623 .26305 .62982 .24029 Mtetra
.587 .485 .706 r
.62982 .24029 .63623 .26305 .64811 .25827 .64174 .23721 Mtetra
.582 .495 .721 r
.64174 .23721 .64811 .25827 .66005 .25383 .65375 .23458 Mtetra
.579 .508 .739 r
.65375 .23458 .66005 .25383 .67206 .24975 .66583 .23232 Mtetra
.575 .525 .761 r
.66583 .23232 .67206 .24975 .68414 .24606 .67799 .23035 Mtetra
.572 .544 .785 r
.67799 .23035 .68414 .24606 .6963 .24272 .69024 .2286 Mtetra
.569 .566 .81 r
.69024 .2286 .6963 .24272 .70854 .23971 .70257 .22698 Mtetra
.566 .588 .835 r
.70257 .22698 .70854 .23971 .72086 .23696 .71498 .22545 Mtetra
.564 .612 .859 r
.71498 .22545 .72086 .23696 .73325 .2344 .72747 .22393 Mtetra
.561 .635 .882 r
.72747 .22393 .73325 .2344 .74573 .23198 .74003 .2224 Mtetra
.557 .657 .903 r
.74003 .2224 .74573 .23198 .75828 .22961 .75267 .22084 Mtetra
.554 .68 .922 r
.75267 .22084 .75828 .22961 .7709 .22725 .76539 .21923 Mtetra
.74 .766 .874 r
.10283 .44102 .1101 .44736 .12028 .44132 .11304 .43492 Mtetra
.742 .766 .872 r
.11304 .43492 .12028 .44132 .13049 .43521 .12329 .42873 Mtetra
.743 .764 .87 r
.12329 .42873 .13049 .43521 .14073 .42907 .13357 .42245 Mtetra
.744 .761 .867 r
.13357 .42245 .14073 .42907 .15099 .42292 .14388 .41608 Mtetra
.744 .756 .862 r
.14388 .41608 .15099 .42292 .16127 .41678 .15422 .40962 Mtetra
.743 .748 .857 r
.15422 .40962 .16127 .41678 .17156 .41072 .16458 .40313 Mtetra
.739 .737 .85 r
.16458 .40313 .17156 .41072 .18186 .40477 .17496 .39663 Mtetra
.732 .723 .842 r
.17496 .39663 .18186 .40477 .19217 .39904 .18536 .3902 Mtetra
.724 .705 .833 r
.18536 .3902 .19217 .39904 .20247 .39358 .19577 .3839 Mtetra
.712 .685 .822 r
.19577 .3839 .20247 .39358 .21276 .38848 .20617 .37781 Mtetra
.699 .662 .81 r
.20617 .37781 .21276 .38848 .22304 .38381 .21657 .37199 Mtetra
.684 .636 .796 r
.21657 .37199 .22304 .38381 .23331 .37961 .22697 .36648 Mtetra
.668 .61 .781 r
.22697 .36648 .23331 .37961 .24357 .37593 .23737 .3613 Mtetra
.653 .584 .764 r
.23737 .3613 .24357 .37593 .25383 .3727 .24777 .35642 Mtetra
.64 .558 .747 r
.24777 .35642 .25383 .3727 .2641 .36988 .25818 .35179 Mtetra
.629 .535 .73 r
.25818 .35179 .2641 .36988 .2744 .36731 .26861 .34734 Mtetra
.619 .515 .714 r
.26861 .34734 .2744 .36731 .28473 .36487 .27907 .343 Mtetra
.612 .498 .699 r
.27907 .343 .28473 .36487 .29511 .36246 .28956 .33872 Mtetra
.606 .484 .687 r
.28956 .33872 .29511 .36246 .30554 .35995 .30009 .33445 Mtetra
.601 .472 .677 r
.30009 .33445 .30554 .35995 .31603 .35731 .31065 .33019 Mtetra
.597 .462 .668 r
.31065 .33019 .31603 .35731 .32658 .3545 .32125 .32593 Mtetra
.594 .454 .661 r
.32125 .32593 .32658 .3545 .33719 .35151 .33189 .32167 Mtetra
.591 .448 .656 r
.33189 .32167 .33719 .35151 .34785 .34836 .34256 .31743 Mtetra
.588 .443 .651 r
.34256 .31743 .34785 .34836 .35857 .34507 .35327 .31323 Mtetra
.586 .438 .647 r
.35327 .31323 .35857 .34507 .36934 .34166 .36402 .30907 Mtetra
.584 .435 .645 r
.36402 .30907 .36934 .34166 .38016 .33814 .37481 .30496 Mtetra
.582 .432 .643 r
.37481 .30496 .38016 .33814 .39104 .33452 .38564 .3009 Mtetra
.581 .43 .641 r
.38564 .3009 .39104 .33452 .40195 .33082 .39651 .29689 Mtetra
.58 .428 .64 r
.39651 .29689 .40195 .33082 .41292 .32704 .40741 .29293 Mtetra
.579 .427 .64 r
.40741 .29293 .41292 .32704 .42393 .32318 .41836 .28901 Mtetra
.578 .427 .64 r
.41836 .28901 .42393 .32318 .435 .31923 .42936 .28514 Mtetra
.577 .427 .64 r
.42936 .28514 .435 .31923 .4461 .3152 .44039 .28132 Mtetra
.577 .427 .641 r
.44039 .28132 .4461 .3152 .45726 .31108 .45147 .27755 Mtetra
.577 .428 .643 r
.45147 .27755 .45726 .31108 .46846 .30686 .4626 .27383 Mtetra
.577 .43 .645 r
.4626 .27383 .46846 .30686 .4797 .30254 .47377 .27016 Mtetra
.577 .432 .648 r
.47377 .27016 .4797 .30254 .49099 .29809 .48499 .26654 Mtetra
.578 .436 .651 r
.48499 .26654 .49099 .29809 .50233 .2935 .49626 .26295 Mtetra
.579 .44 .656 r
.49626 .26295 .50233 .2935 .51371 .28873 .50758 .25937 Mtetra
.581 .446 .662 r
.50758 .25937 .51371 .28873 .52513 .28379 .51895 .25581 Mtetra
.584 .453 .669 r
.51895 .25581 .52513 .28379 .53658 .27866 .53037 .25224 Mtetra
.586 .462 .678 r
.53037 .25224 .53658 .27866 .54808 .2734 .54184 .24868 Mtetra
.59 .473 .689 r
.54184 .24868 .54808 .2734 .55962 .26804 .55336 .24513 Mtetra
.593 .486 .702 r
.55336 .24513 .55962 .26804 .5712 .26268 .56494 .24164 Mtetra
.595 .501 .717 r
.56494 .24164 .5712 .26268 .58281 .25746 .57657 .23827 Mtetra
.597 .517 .735 r
.57657 .23827 .58281 .25746 .59448 .2525 .58826 .23507 Mtetra
.596 .534 .755 r
.58826 .23507 .59448 .2525 .6062 .24795 .60002 .23214 Mtetra
.593 .551 .777 r
.60002 .23214 .6062 .24795 .61797 .24386 .61184 .22951 Mtetra
.587 .569 .8 r
.61184 .22951 .61797 .24386 .62982 .24029 .62374 .22724 Mtetra
.58 .586 .824 r
.62374 .22724 .62982 .24029 .64174 .23721 .63571 .22527 Mtetra
.57 .603 .847 r
.63571 .22527 .64174 .23721 .65375 .23458 .64777 .2236 Mtetra
.561 .62 .868 r
.64777 .2236 .65375 .23458 .66583 .23232 .6599 .22214 Mtetra
.552 .635 .887 r
.6599 .22214 .66583 .23232 .67799 .23035 .67212 .22082 Mtetra
.545 .65 .903 r
.67212 .22082 .67799 .23035 .69024 .2286 .68443 .21959 Mtetra
.54 .663 .916 r
.68443 .21959 .69024 .2286 .70257 .22698 .6968 .21835 Mtetra
.538 .674 .926 r
.6968 .21835 .70257 .22698 .71498 .22545 .70926 .21709 Mtetra
.539 .684 .932 r
.70926 .21709 .71498 .22545 .72747 .22393 .72179 .21573 Mtetra
.54 .69 .937 r
.72179 .21573 .72747 .22393 .74003 .2224 .7344 .21429 Mtetra
.542 .695 .939 r
.7344 .21429 .74003 .2224 .75267 .22084 .74708 .21276 Mtetra
.545 .699 .94 r
.74708 .21276 .75267 .22084 .76539 .21923 .75983 .21113 Mtetra
.726 .765 .884 r
.09551 .43462 .10283 .44102 .11304 .43492 .10567 .42907 Mtetra
.732 .783 .893 r
.10567 .42907 .11304 .43492 .12329 .42873 .11588 .42341 Mtetra
.738 .801 .902 r
.11588 .42341 .12329 .42873 .13357 .42245 .12613 .41763 Mtetra
.744 .819 .91 r
.12613 .41763 .13357 .42245 .14388 .41608 .13641 .41173 Mtetra
.75 .835 .917 r
.13641 .41173 .14388 .41608 .15422 .40962 .14673 .40568 Mtetra
.755 .85 .922 r
.14673 .40568 .15422 .40962 .16458 .40313 .15709 .39951 Mtetra
.758 .863 .926 r
.15709 .39951 .16458 .40313 .17496 .39663 .16749 .39325 Mtetra
.76 .872 .929 r
.16749 .39325 .17496 .39663 .18536 .3902 .17791 .38693 Mtetra
.76 .877 .931 r
.17791 .38693 .18536 .3902 .19577 .3839 .18836 .38058 Mtetra
.76 .876 .931 r
.18836 .38058 .19577 .3839 .20617 .37781 .19883 .37424 Mtetra
.759 .869 .929 r
.19883 .37424 .20617 .37781 .21657 .37199 .20931 .36791 Mtetra
.757 .852 .921 r
.20931 .36791 .21657 .37199 .22697 .36648 .21983 .36158 Mtetra
.754 .826 .908 r
.21983 .36158 .22697 .36648 .23737 .3613 .23036 .35525 Mtetra
.746 .789 .887 r
.23036 .35525 .23737 .3613 .24777 .35642 .24092 .34892 Mtetra
.735 .747 .861 r
.24092 .34892 .24777 .35642 .25818 .35179 .2515 .34259 Mtetra
.719 .702 .833 r
.2515 .34259 .25818 .35179 .26861 .34734 .2621 .33631 Mtetra
.703 .661 .806 r
.2621 .33631 .26861 .34734 .27907 .343 .27271 .33013 Mtetra
.686 .625 .782 r
.27271 .33013 .27907 .343 .28956 .33872 .28334 .32411 Mtetra
.67 .595 .762 r
.28334 .32411 .28956 .33872 .30009 .33445 .29398 .31829 Mtetra
.657 .571 .746 r
.29398 .31829 .30009 .33445 .31065 .33019 .30463 .31269 Mtetra
.646 .552 .734 r
.30463 .31269 .31065 .33019 .32125 .32593 .31529 .30734 Mtetra
.637 .537 .725 r
.31529 .30734 .32125 .32593 .33189 .32167 .32597 .30222 Mtetra
.629 .526 .719 r
.32597 .30222 .33189 .32167 .34256 .31743 .33667 .29733 Mtetra
.623 .518 .714 r
.33667 .29733 .34256 .31743 .35327 .31323 .34739 .29265 Mtetra
.618 .512 .711 r
.34739 .29265 .35327 .31323 .36402 .30907 .35814 .28815 Mtetra
.614 .507 .709 r
.35814 .28815 .36402 .30907 .37481 .30496 .36892 .2838 Mtetra
.611 .504 .708 r
.36892 .2838 .37481 .30496 .38564 .3009 .37973 .27958 Mtetra
.609 .502 .707 r
.37973 .27958 .38564 .3009 .39651 .29689 .39058 .27547 Mtetra
.607 .5 .707 r
.39058 .27547 .39651 .29689 .40741 .29293 .40147 .27144 Mtetra
.605 .499 .706 r
.40147 .27144 .40741 .29293 .41836 .28901 .4124 .26748 Mtetra
.604 .498 .707 r
.4124 .26748 .41836 .28901 .42936 .28514 .42337 .2636 Mtetra
.602 .497 .707 r
.42337 .2636 .42936 .28514 .44039 .28132 .43438 .2598 Mtetra
.6 .497 .708 r
.43438 .2598 .44039 .28132 .45147 .27755 .44543 .25611 Mtetra
.598 .496 .709 r
.44543 .25611 .45147 .27755 .4626 .27383 .45653 .25255 Mtetra
.596 .496 .711 r
.45653 .25255 .4626 .27383 .47377 .27016 .46768 .24914 Mtetra
.593 .497 .714 r
.46768 .24914 .47377 .27016 .48499 .26654 .47887 .24592 Mtetra
.59 .498 .718 r
.47887 .24592 .48499 .26654 .49626 .26295 .49012 .24291 Mtetra
.587 .501 .725 r
.49012 .24291 .49626 .26295 .50758 .25937 .50141 .24013 Mtetra
.584 .506 .733 r
.50141 .24013 .50758 .25937 .51895 .25581 .51276 .23759 Mtetra
.581 .514 .745 r
.51276 .23759 .51895 .25581 .53037 .25224 .52417 .2353 Mtetra
.578 .527 .762 r
.52417 .2353 .53037 .25224 .54184 .24868 .53564 .23325 Mtetra
.575 .544 .783 r
.53564 .23325 .54184 .24868 .55336 .24513 .54718 .23141 Mtetra
.571 .568 .811 r
.54718 .23141 .55336 .24513 .56494 .24164 .55879 .22973 Mtetra
.568 .599 .845 r
.55879 .22973 .56494 .24164 .57657 .23827 .57046 .22815 Mtetra
.561 .637 .884 r
.57046 .22815 .57657 .23827 .58826 .23507 .5822 .22664 Mtetra
.551 .68 .924 r
.5822 .22664 .58826 .23507 .60002 .23214 .59402 .22513 Mtetra
.534 .72 .959 r
.59402 .22513 .60002 .23214 .61184 .22951 .60591 .22363 Mtetra
.511 .751 .982 r
.60591 .22363 .61184 .22951 .62374 .22724 .61787 .22213 Mtetra
.488 .77 .994 r
.61787 .22213 .62374 .22724 .63571 .22527 .6299 .22064 Mtetra
.468 .78 .998 r
.6299 .22064 .63571 .22527 .64777 .2236 .64201 .21917 Mtetra
.458 .783 .998 r
.64201 .21917 .64777 .2236 .6599 .22214 .65419 .2177 Mtetra
.458 .784 .999 r
.65419 .2177 .6599 .22214 .67212 .22082 .66645 .21622 Mtetra
.467 .783 .998 r
.66645 .21622 .67212 .22082 .68443 .21959 .67878 .21469 Mtetra
.483 .78 .997 r
.67878 .21469 .68443 .21959 .6968 .21835 .69118 .21305 Mtetra
.502 .775 .993 r
.69118 .21305 .6968 .21835 .70926 .21709 .70366 .21131 Mtetra
.522 .768 .987 r
.70366 .21131 .70926 .21709 .72179 .21573 .7162 .20941 Mtetra
.54 .757 .977 r
.7162 .20941 .72179 .21573 .7344 .21429 .7288 .20738 Mtetra
.554 .744 .965 r
.7288 .20738 .7344 .21429 .74708 .21276 .74148 .20523 Mtetra
.566 .729 .951 r
.74148 .20523 .74708 .21276 .75983 .21113 .75422 .20298 Mtetra
.692 .759 .903 r
.08813 .42819 .09551 .43462 .10567 .42907 .09818 .42371 Mtetra
.698 .796 .925 r
.09818 .42371 .10567 .42907 .11588 .42341 .10827 .41913 Mtetra
.703 .834 .946 r
.10827 .41913 .11588 .42341 .12613 .41763 .11841 .41443 Mtetra
.704 .873 .961 r
.11841 .41443 .12613 .41763 .13641 .41173 .12861 .40956 Mtetra
.701 .908 .968 r
.12861 .40956 .13641 .41173 .14673 .40568 .13885 .40449 Mtetra
.691 .935 .965 r
.13885 .40449 .14673 .40568 .15709 .39951 .14915 .39922 Mtetra
.674 .953 .951 r
.14915 .39922 .15709 .39951 .16749 .39325 .1595 .39375 Mtetra
.65 .96 .928 r
.1595 .39375 .16749 .39325 .17791 .38693 .16989 .38811 Mtetra
.623 .958 .899 r
.16989 .38811 .17791 .38693 .18836 .38058 .18033 .38231 Mtetra
.597 .951 .87 r
.18033 .38231 .18836 .38058 .19883 .37424 .19081 .37637 Mtetra
.574 .941 .843 r
.19081 .37637 .19883 .37424 .20931 .36791 .20133 .37034 Mtetra
.555 .931 .821 r
.20133 .37034 .20931 .36791 .21983 .36158 .21187 .36423 Mtetra
.538 .922 .803 r
.21187 .36423 .21983 .36158 .23036 .35525 .22245 .35807 Mtetra
.52 .911 .786 r
.22245 .35807 .23036 .35525 .24092 .34892 .23305 .35191 Mtetra
.497 .897 .767 r
.23305 .35191 .24092 .34892 .2515 .34259 .24367 .34579 Mtetra
.464 .877 .74 r
.24367 .34579 .2515 .34259 .2621 .33631 .2543 .33977 Mtetra
.421 .848 .706 r
.2543 .33977 .2621 .33631 .27271 .33013 .26495 .3339 Mtetra
.371 .812 .664 r
.26495 .3339 .27271 .33013 .28334 .32411 .27562 .32819 Mtetra
0 0 0 r
.27562 .32819 .28334 .32411 .29398 .31829 .2863 .32267 Mtetra
.2863 .32267 .29398 .31829 .30463 .31269 .297 .31734 Mtetra
.297 .31734 .30463 .31269 .31529 .30734 .30771 .31218 Mtetra
.30771 .31218 .31529 .30734 .32597 .30222 .31845 .3072 Mtetra
.31845 .3072 .32597 .30222 .33667 .29733 .32921 .30237 Mtetra
.32921 .30237 .33667 .29733 .34739 .29265 .34 .29769 Mtetra
.34 .29769 .34739 .29265 .35814 .28815 .35082 .29315 Mtetra
.35082 .29315 .35814 .28815 .36892 .2838 .36167 .28873 Mtetra
.36167 .28873 .36892 .2838 .37973 .27958 .37255 .28443 Mtetra
.37255 .28443 .37973 .27958 .39058 .27547 .38347 .28024 Mtetra
.38347 .28024 .39058 .27547 .40147 .27144 .39443 .27616 Mtetra
.39443 .27616 .40147 .27144 .4124 .26748 .40543 .27219 Mtetra
.40543 .27219 .4124 .26748 .42337 .2636 .41647 .26831 Mtetra
.41647 .26831 .42337 .2636 .43438 .2598 .42755 .26455 Mtetra
.42755 .26455 .43438 .2598 .44543 .25611 .43868 .2609 Mtetra
.005 0 0 r
.43868 .2609 .44543 .25611 .45653 .25255 .44985 .25736 Mtetra
.022 0 0 r
.44985 .25736 .45653 .25255 .46768 .24914 .46106 .25396 Mtetra
.036 0 0 r
.46106 .25396 .46768 .24914 .47887 .24592 .47233 .25069 Mtetra
.049 0 0 r
.47233 .25069 .47887 .24592 .49012 .24291 .48365 .24757 Mtetra
.058 0 0 r
.48365 .24757 .49012 .24291 .50141 .24013 .49501 .24462 Mtetra
.064 0 0 r
.49501 .24462 .50141 .24013 .51276 .23759 .50644 .24184 Mtetra
.066 0 0 r
.50644 .24184 .51276 .23759 .52417 .2353 .51792 .23924 Mtetra
.064 0 0 r
.51792 .23924 .52417 .2353 .53564 .23325 .52946 .23684 Mtetra
.06 0 0 r
.52946 .23684 .53564 .23325 .54718 .23141 .54107 .23463 Mtetra
.052 0 0 r
.54107 .23463 .54718 .23141 .55879 .22973 .55274 .2326 Mtetra
.042 0 0 r
.55274 .2326 .55879 .22973 .57046 .22815 .56448 .23072 Mtetra
.031 0 0 r
.56448 .23072 .57046 .22815 .5822 .22664 .57629 .22894 Mtetra
.017 0 0 r
.57629 .22894 .5822 .22664 .59402 .22513 .58817 .22721 Mtetra
.002 0 0 r
.58817 .22721 .59402 .22513 .60591 .22363 .60012 .22549 Mtetra
0 0 0 r
.60012 .22549 .60591 .22363 .61787 .22213 .61214 .22372 Mtetra
.61214 .22372 .61787 .22213 .6299 .22064 .62423 .22188 Mtetra
.62423 .22188 .6299 .22064 .64201 .21917 .63638 .21994 Mtetra
.134 .679 .717 r
.63638 .21994 .64201 .21917 .65419 .2177 .64861 .21787 Mtetra
.201 .73 .786 r
.64861 .21787 .65419 .2177 .66645 .21622 .6609 .21564 Mtetra
.282 .782 .859 r
.6609 .21564 .66645 .21622 .67878 .21469 .67325 .21322 Mtetra
.37 .826 .927 r
.67325 .21322 .67878 .21469 .69118 .21305 .68566 .2106 Mtetra
.451 .85 .974 r
.68566 .2106 .69118 .21305 .70366 .21131 .69813 .20778 Mtetra
.519 .852 .996 r
.69813 .20778 .70366 .21131 .7162 .20941 .71065 .20475 Mtetra
.566 .834 .996 r
.71065 .20475 .7162 .20941 .7288 .20738 .72324 .20154 Mtetra
.596 .804 .98 r
.72324 .20154 .7288 .20738 .74148 .20523 .73587 .1982 Mtetra
.613 .77 .956 r
.73587 .1982 .74148 .20523 .75422 .20298 .74857 .19475 Mtetra
.639 .747 .927 r
.0807 .4217 .08813 .42819 .09818 .42371 .09059 .41856 Mtetra
.637 .793 .957 r
.09059 .41856 .09818 .42371 .10827 .41913 .10053 .41534 Mtetra
.629 .84 .981 r
.10053 .41534 .10827 .41913 .11841 .41443 .11053 .41199 Mtetra
.61 .882 .991 r
.11053 .41199 .11841 .41443 .12861 .40956 .12059 .40846 Mtetra
.576 .91 .975 r
.12059 .40846 .12861 .40956 .13885 .40449 .13071 .4047 Mtetra
.523 .912 .928 r
.13071 .4047 .13885 .40449 .14915 .39922 .1409 .4007 Mtetra
.456 .886 .851 r
.1409 .4007 .14915 .39922 .1595 .39375 .15116 .39642 Mtetra
.38 .836 .755 r
.15116 .39642 .1595 .39375 .16989 .38811 .16149 .39188 Mtetra
.306 .775 .654 r
.16149 .39188 .16989 .38811 .18033 .38231 .17187 .38709 Mtetra
0 0 0 r
.17187 .38709 .18033 .38231 .19081 .37637 .18231 .38211 Mtetra
.18231 .38211 .19081 .37637 .20133 .37034 .1928 .37698 Mtetra
.1928 .37698 .20133 .37034 .21187 .36423 .20332 .3718 Mtetra
.20332 .3718 .21187 .36423 .22245 .35807 .21387 .36663 Mtetra
.035 0 0 r
.21387 .36663 .22245 .35807 .23305 .35191 .22444 .36155 Mtetra
.101 0 0 r
.22444 .36155 .23305 .35191 .24367 .34579 .23503 .35663 Mtetra
.16 0 0 r
.23503 .35663 .24367 .34579 .2543 .33977 .24565 .35187 Mtetra
.209 0 .004 r
.24565 .35187 .2543 .33977 .26495 .3339 .25628 .34727 Mtetra
.247 0 .055 r
.25628 .34727 .26495 .3339 .27562 .32819 .26694 .34277 Mtetra
.275 0 .095 r
.26694 .34277 .27562 .32819 .2863 .32267 .27763 .33834 Mtetra
.295 0 .125 r
.27763 .33834 .2863 .32267 .297 .31734 .28836 .33394 Mtetra
.309 0 .147 r
.28836 .33394 .297 .31734 .30771 .31218 .29913 .32952 Mtetra
.319 0 .163 r
.29913 .32952 .30771 .31218 .31845 .3072 .30993 .3251 Mtetra
.326 0 .174 r
.30993 .3251 .31845 .3072 .32921 .30237 .32078 .32066 Mtetra
.331 0 .181 r
.32078 .32066 .32921 .30237 .34 .29769 .33167 .31621 Mtetra
.335 0 .186 r
.33167 .31621 .34 .29769 .35082 .29315 .34259 .31178 Mtetra
.338 0 .19 r
.34259 .31178 .35082 .29315 .36167 .28873 .35356 .3074 Mtetra
.341 0 .192 r
.35356 .3074 .36167 .28873 .37255 .28443 .36456 .30309 Mtetra
.345 0 .193 r
.36456 .30309 .37255 .28443 .38347 .28024 .3756 .29888 Mtetra
.348 0 .195 r
.3756 .29888 .38347 .28024 .39443 .27616 .38667 .29477 Mtetra
.352 0 .196 r
.38667 .29477 .39443 .27616 .40543 .27219 .39779 .29078 Mtetra
.356 0 .198 r
.39779 .29078 .40543 .27219 .41647 .26831 .40895 .28692 Mtetra
.36 0 .2 r
.40895 .28692 .41647 .26831 .42755 .26455 .42015 .28316 Mtetra
.363 0 .202 r
.42015 .28316 .42755 .26455 .43868 .2609 .4314 .2795 Mtetra
.366 0 .203 r
.4314 .2795 .43868 .2609 .44985 .25736 .44269 .27591 Mtetra
.367 0 .202 r
.44269 .27591 .44985 .25736 .46106 .25396 .45403 .27236 Mtetra
.367 0 .201 r
.45403 .27236 .46106 .25396 .47233 .25069 .46543 .26884 Mtetra
.365 0 .197 r
.46543 .26884 .47233 .25069 .48365 .24757 .47687 .26532 Mtetra
.361 0 .19 r
.47687 .26532 .48365 .24757 .49501 .24462 .48837 .26177 Mtetra
.356 0 .179 r
.48837 .26177 .49501 .24462 .50644 .24184 .49992 .25822 Mtetra
.348 0 .165 r
.49992 .25822 .50644 .24184 .51792 .23924 .51152 .25465 Mtetra
.339 0 .145 r
.51152 .25465 .51792 .23924 .52946 .23684 .52318 .25111 Mtetra
.327 0 .12 r
.52318 .25111 .52946 .23684 .54107 .23463 .5349 .24765 Mtetra
.313 0 .088 r
.5349 .24765 .54107 .23463 .55274 .2326 .54666 .24428 Mtetra
.297 0 .049 r
.54666 .24428 .55274 .2326 .56448 .23072 .55849 .24109 Mtetra
.278 0 .004 r
.55849 .24109 .56448 .23072 .57629 .22894 .57038 .23805 Mtetra
.256 0 0 r
.57038 .23805 .57629 .22894 .58817 .22721 .58234 .23518 Mtetra
.229 0 0 r
.58234 .23518 .58817 .22721 .60012 .22549 .59435 .23241 Mtetra
.194 0 0 r
.59435 .23241 .60012 .22549 .61214 .22372 .60644 .22965 Mtetra
.15 0 0 r
.60644 .22965 .61214 .22372 .62423 .22188 .61858 .22683 Mtetra
.092 0 0 r
.61858 .22683 .62423 .22188 .63638 .21994 .63079 .22386 Mtetra
.017 0 0 r
.63079 .22386 .63638 .21994 .64861 .21787 .64305 .2207 Mtetra
0 0 0 r
.64305 .2207 .64861 .21787 .6609 .21564 .65537 .21727 Mtetra
.203 .719 .679 r
.65537 .21727 .6609 .21564 .67325 .21322 .66774 .21358 Mtetra
.339 .819 .813 r
.66774 .21358 .67325 .21322 .68566 .2106 .68015 .2096 Mtetra
.466 .885 .918 r
.68015 .2096 .68566 .2106 .69813 .20778 .69261 .20536 Mtetra
.564 .906 .975 r
.69261 .20536 .69813 .20778 .71065 .20475 .7051 .20087 Mtetra
.625 .888 .988 r
.7051 .20087 .71065 .20475 .72324 .20154 .71765 .19619 Mtetra
.657 .849 .974 r
.71765 .19619 .72324 .20154 .73587 .1982 .73024 .19137 Mtetra
.669 .803 .946 r
.73024 .19137 .73587 .1982 .74857 .19475 .74288 .18646 Mtetra
.571 .727 .947 r
.07322 .41517 .0807 .4217 .09059 .41856 .08295 .41333 Mtetra
.557 .769 .977 r
.08295 .41333 .09059 .41856 .10053 .41534 .09273 .41143 Mtetra
.532 .809 .997 r
.09273 .41143 .10053 .41534 .11053 .41199 .10258 .40944 Mtetra
.491 .84 .996 r
.10258 .40944 .11053 .41199 .12059 .40846 .11249 .4073 Mtetra
.429 .849 .958 r
.11249 .4073 .12059 .40846 .13071 .4047 .12247 .40497 Mtetra
.343 .82 .873 r
.12247 .40497 .13071 .4047 .1409 .4007 .13253 .40243 Mtetra
.242 .754 .747 r
.13253 .40243 .1409 .4007 .15116 .39642 .14266 .39964 Mtetra
0 0 0 r
.14266 .39964 .15116 .39642 .16149 .39188 .15286 .39662 Mtetra
.15286 .39662 .16149 .39188 .17187 .38709 .16313 .39336 Mtetra
.042 0 0 r
.16313 .39336 .17187 .38709 .18231 .38211 .17346 .38991 Mtetra
.11 0 0 r
.17346 .38991 .18231 .38211 .1928 .37698 .18386 .3863 Mtetra
.165 0 0 r
.18386 .3863 .1928 .37698 .20332 .3718 .1943 .38257 Mtetra
.21 0 0 r
.1943 .38257 .20332 .3718 .21387 .36663 .2048 .37878 Mtetra
.244 0 .019 r
.2048 .37878 .21387 .36663 .22444 .36155 .21534 .37495 Mtetra
.272 0 .063 r
.21534 .37495 .22444 .36155 .23503 .35663 .22592 .37111 Mtetra
.29 0 .095 r
.22592 .37111 .23503 .35663 .24565 .35187 .23654 .36724 Mtetra
.303 0 .118 r
.23654 .36724 .24565 .35187 .25628 .34727 .24721 .36333 Mtetra
.311 0 .133 r
.24721 .36333 .25628 .34727 .26694 .34277 .25793 .35934 Mtetra
.315 0 .143 r
.25793 .35934 .26694 .34277 .27763 .33834 .2687 .35526 Mtetra
.317 0 .15 r
.2687 .35526 .27763 .33834 .28836 .33394 .27951 .35109 Mtetra
.318 0 .154 r
.27951 .35109 .28836 .33394 .29913 .32952 .29037 .34683 Mtetra
.318 0 .156 r
.29037 .34683 .29913 .32952 .30993 .3251 .30128 .3425 Mtetra
.318 0 .158 r
.30128 .3425 .30993 .3251 .32078 .32066 .31223 .33812 Mtetra
.319 0 .159 r
.31223 .33812 .32078 .32066 .33167 .31621 .32323 .33371 Mtetra
.32 0 .161 r
.32323 .33371 .33167 .31621 .34259 .31178 .33426 .32931 Mtetra
.322 0 .162 r
.33426 .32931 .34259 .31178 .35356 .3074 .34534 .32495 Mtetra
.326 0 .164 r
.34534 .32495 .35356 .3074 .36456 .30309 .35645 .32066 Mtetra
.329 0 .167 r
.35645 .32066 .36456 .30309 .3756 .29888 .3676 .31645 Mtetra
.333 0 .169 r
.3676 .31645 .3756 .29888 .38667 .29477 .37879 .31234 Mtetra
.338 0 .171 r
.37879 .31234 .38667 .29477 .39779 .29078 .39003 .30835 Mtetra
.341 0 .173 r
.39003 .30835 .39779 .29078 .40895 .28692 .4013 .30446 Mtetra
.345 0 .174 r
.4013 .30446 .40895 .28692 .42015 .28316 .41262 .30067 Mtetra
.348 0 .175 r
.41262 .30067 .42015 .28316 .4314 .2795 .42399 .29697 Mtetra
.35 0 .176 r
.42399 .29697 .4314 .2795 .44269 .27591 .4354 .29334 Mtetra
.351 0 .176 r
.4354 .29334 .44269 .27591 .45403 .27236 .44686 .28975 Mtetra
.352 0 .175 r
.44686 .28975 .45403 .27236 .46543 .26884 .45838 .28616 Mtetra
.351 0 .174 r
.45838 .28616 .46543 .26884 .47687 .26532 .46995 .28256 Mtetra
.349 0 .172 r
.46995 .28256 .47687 .26532 .48837 .26177 .48157 .2789 Mtetra
.346 0 .169 r
.48157 .2789 .48837 .26177 .49992 .25822 .49324 .27516 Mtetra
.342 0 .165 r
.49324 .27516 .49992 .25822 .51152 .25465 .50497 .27134 Mtetra
.337 0 .159 r
.50497 .27134 .51152 .25465 .52318 .25111 .51676 .26742 Mtetra
.331 0 .151 r
.51676 .26742 .52318 .25111 .5349 .24765 .52859 .26341 Mtetra
.322 0 .139 r
.52859 .26341 .5349 .24765 .54666 .24428 .54048 .25932 Mtetra
.312 0 .122 r
.54048 .25932 .54666 .24428 .55849 .24109 .55242 .25519 Mtetra
.298 0 .099 r
.55242 .25519 .55849 .24109 .57038 .23805 .56441 .25102 Mtetra
.279 0 .067 r
.56441 .25102 .57038 .23805 .58234 .23518 .57646 .24683 Mtetra
.252 0 .023 r
.57646 .24683 .58234 .23518 .59435 .23241 .58856 .24261 Mtetra
.215 0 0 r
.58856 .24261 .59435 .23241 .60644 .22965 .60071 .23831 Mtetra
.162 0 0 r
.60071 .23831 .60644 .22965 .61858 .22683 .61291 .2339 Mtetra
.088 0 0 r
.61291 .2339 .61858 .22683 .63079 .22386 .62516 .22931 Mtetra
0 0 0 r
.62516 .22931 .63079 .22386 .64305 .2207 .63745 .22452 Mtetra
.63745 .22452 .64305 .2207 .65537 .21727 .64978 .21948 Mtetra
.294 .771 .668 r
.64978 .21948 .65537 .21727 .66774 .21358 .66216 .21419 Mtetra
.448 .88 .819 r
.66216 .21419 .66774 .21358 .68015 .2096 .67457 .20863 Mtetra
.573 .936 .92 r
.67457 .20863 .68015 .2096 .69261 .20536 .68701 .20285 Mtetra
.655 .939 .965 r
.68701 .20285 .69261 .20536 .7051 .20087 .69949 .19686 Mtetra
.697 .909 .969 r
.69949 .19686 .7051 .20087 .71765 .19619 .712 .1907 Mtetra
.715 .865 .953 r
.712 .1907 .71765 .19619 .73024 .19137 .72455 .18444 Mtetra
.718 .819 .928 r
.72455 .18444 .73024 .19137 .74288 .18646 .73713 .1781 Mtetra
.5 .701 .959 r
.06568 .40859 .07322 .41517 .08295 .41333 .07527 .4078 Mtetra
.477 .731 .982 r
.07527 .4078 .08295 .41333 .09273 .41143 .08493 .40699 Mtetra
.445 .758 .995 r
.08493 .40699 .09273 .41143 .10258 .40944 .09464 .40613 Mtetra
.4 .778 .992 r
.09464 .40613 .10258 .40944 .11249 .4073 .10443 .40517 Mtetra
.34 .782 .962 r
.10443 .40517 .11249 .4073 .12247 .40497 .11428 .40408 Mtetra
.26 .759 .893 r
.11428 .40408 .12247 .40497 .13253 .40243 .12421 .40285 Mtetra
.167 .705 .783 r
.12421 .40285 .13253 .40243 .14266 .39964 .13421 .40145 Mtetra
0 0 0 r
.13421 .40145 .14266 .39964 .15286 .39662 .14428 .39987 Mtetra
.025 0 0 r
.14428 .39987 .15286 .39662 .16313 .39336 .15443 .39811 Mtetra
.104 0 0 r
.15443 .39811 .16313 .39336 .17346 .38991 .16466 .39618 Mtetra
.166 0 0 r
.16466 .39618 .17346 .38991 .18386 .3863 .17495 .39408 Mtetra
.213 0 0 r
.17495 .39408 .18386 .3863 .1943 .38257 .18531 .3918 Mtetra
.246 0 0 r
.18531 .3918 .1943 .38257 .2048 .37878 .19574 .38934 Mtetra
.268 0 0 r
.19574 .38934 .2048 .37878 .21534 .37495 .20624 .38667 Mtetra
.28 0 .025 r
.20624 .38667 .21534 .37495 .22592 .37111 .21681 .38376 Mtetra
.286 0 .05 r
.21681 .38376 .22592 .37111 .23654 .36724 .22746 .3806 Mtetra
.287 0 .066 r
.22746 .3806 .23654 .36724 .24721 .36333 .23817 .37716 Mtetra
.286 0 .075 r
.23817 .37716 .24721 .36333 .25793 .35934 .24896 .3735 Mtetra
.283 0 .08 r
.24896 .3735 .25793 .35934 .2687 .35526 .2598 .36963 Mtetra
.281 0 .083 r
.2598 .36963 .2687 .35526 .27951 .35109 .2707 .3656 Mtetra
.279 0 .084 r
.2707 .3656 .27951 .35109 .29037 .34683 .28165 .36145 Mtetra
.279 0 .087 r
.28165 .36145 .29037 .34683 .30128 .3425 .29265 .35724 Mtetra
.28 0 .09 r
.29265 .35724 .30128 .3425 .31223 .33812 .30369 .35298 Mtetra
.283 0 .094 r
.30369 .35298 .31223 .33812 .32323 .33371 .31478 .34871 Mtetra
.286 0 .099 r
.31478 .34871 .32323 .33371 .33426 .32931 .32591 .34446 Mtetra
.291 0 .104 r
.32591 .34446 .33426 .32931 .34534 .32495 .33708 .34025 Mtetra
.296 0 .109 r
.33708 .34025 .34534 .32495 .35645 .32066 .34829 .33607 Mtetra
.3 0 .114 r
.34829 .33607 .35645 .32066 .3676 .31645 .35955 .33195 Mtetra
.305 0 .118 r
.35955 .33195 .3676 .31645 .37879 .31234 .37085 .32788 Mtetra
.308 0 .12 r
.37085 .32788 .37879 .31234 .39003 .30835 .38219 .32387 Mtetra
.311 0 .121 r
.38219 .32387 .39003 .30835 .4013 .30446 .39357 .31992 Mtetra
.313 0 .121 r
.39357 .31992 .4013 .30446 .41262 .30067 .40501 .31602 Mtetra
.314 0 .12 r
.40501 .31602 .41262 .30067 .42399 .29697 .41649 .31218 Mtetra
.314 0 .118 r
.41649 .31218 .42399 .29697 .4354 .29334 .42802 .30838 Mtetra
.314 0 .115 r
.42802 .30838 .4354 .29334 .44686 .28975 .4396 .30461 Mtetra
.313 0 .111 r
.4396 .30461 .44686 .28975 .45838 .28616 .45123 .30086 Mtetra
.311 0 .108 r
.45123 .30086 .45838 .28616 .46995 .28256 .46291 .2971 Mtetra
.308 0 .104 r
.46291 .2971 .46995 .28256 .48157 .2789 .47465 .2933 Mtetra
.304 0 .099 r
.47465 .2933 .48157 .2789 .49324 .27516 .48644 .28942 Mtetra
.298 0 .094 r
.48644 .28942 .49324 .27516 .50497 .27134 .49829 .28543 Mtetra
.29 0 .088 r
.49829 .28543 .50497 .27134 .51676 .26742 .51019 .28127 Mtetra
.279 0 .078 r
.51019 .28127 .51676 .26742 .52859 .26341 .52214 .27691 Mtetra
.265 0 .065 r
.52214 .27691 .52859 .26341 .54048 .25932 .53414 .2723 Mtetra
.245 0 .045 r
.53414 .2723 .54048 .25932 .55242 .25519 .54619 .26741 Mtetra
.218 0 .016 r
.54619 .26741 .55242 .25519 .56441 .25102 .55829 .26225 Mtetra
.183 0 0 r
.55829 .26225 .56441 .25102 .57646 .24683 .57043 .25685 Mtetra
.136 0 0 r
.57043 .25685 .57646 .24683 .58856 .24261 .58261 .25122 Mtetra
.073 0 0 r
.58261 .25122 .58856 .24261 .60071 .23831 .59482 .24539 Mtetra
0 0 0 r
.59482 .24539 .60071 .23831 .61291 .2339 .60708 .23937 Mtetra
.60708 .23937 .61291 .2339 .62516 .22931 .61937 .23317 Mtetra
.61937 .23317 .62516 .22931 .63745 .22452 .6317 .22679 Mtetra
.4 .836 .699 r
.6317 .22679 .63745 .22452 .64978 .21948 .64405 .2202 Mtetra
.534 .922 .826 r
.64405 .2202 .64978 .21948 .66216 .21419 .65644 .21342 Mtetra
.637 .962 .908 r
.65644 .21342 .66216 .21419 .67457 .20863 .66886 .20645 Mtetra
.702 .96 .946 r
.66886 .20645 .67457 .20863 .68701 .20285 .6813 .19931 Mtetra
.736 .934 .953 r
.6813 .19931 .68701 .20285 .69949 .19686 .69377 .19203 Mtetra
.751 .898 .944 r
.69377 .19203 .69949 .19686 .712 .1907 .70626 .18464 Mtetra
.754 .859 .927 r
.70626 .18464 .712 .1907 .72455 .18444 .71879 .17718 Mtetra
.75 .821 .907 r
.71879 .17718 .72455 .18444 .73713 .1781 .73134 .16968 Mtetra
.458 .684 .963 r
.05808 .40196 .06568 .40859 .07527 .4078 .06762 .4017 Mtetra
.444 .697 .973 r
.06762 .4017 .07527 .4078 .08493 .40699 .07721 .40143 Mtetra
.429 .711 .983 r
.07721 .40143 .08493 .40699 .09464 .40613 .08686 .40113 Mtetra
.412 .726 .989 r
.08686 .40113 .09464 .40613 .10443 .40517 .09658 .40077 Mtetra
.395 .74 .992 r
.09658 .40077 .10443 .40517 .11428 .40408 .10637 .40032 Mtetra
.375 .753 .99 r
.10637 .40032 .11428 .40408 .12421 .40285 .11624 .39975 Mtetra
.353 .764 .981 r
.11624 .39975 .12421 .40285 .13421 .40145 .12618 .39902 Mtetra
.328 .77 .964 r
.12618 .39902 .13421 .40145 .14428 .39987 .1362 .39813 Mtetra
.301 .771 .937 r
.1362 .39813 .14428 .39987 .15443 .39811 .1463 .39704 Mtetra
.272 .765 .903 r
.1463 .39704 .15443 .39811 .16466 .39618 .15648 .39576 Mtetra
.244 .755 .863 r
.15648 .39576 .16466 .39618 .17495 .39408 .16674 .39427 Mtetra
.218 .741 .82 r
.16674 .39427 .17495 .39408 .18531 .3918 .17708 .39257 Mtetra
.194 .725 .776 r
.17708 .39257 .18531 .3918 .19574 .38934 .1875 .39065 Mtetra
.174 .708 .733 r
.1875 .39065 .19574 .38934 .20624 .38667 .19799 .38852 Mtetra
0 0 0 r
.19799 .38852 .20624 .38667 .21681 .38376 .20856 .38616 Mtetra
.20856 .38616 .21681 .38376 .22746 .3806 .2192 .38361 Mtetra
.2192 .38361 .22746 .3806 .23817 .37716 .22991 .38089 Mtetra
.22991 .38089 .23817 .37716 .24896 .3735 .24067 .37802 Mtetra
.24067 .37802 .24896 .3735 .2598 .36963 .2515 .37504 Mtetra
.04 0 0 r
.2515 .37504 .2598 .36963 .2707 .3656 .26239 .37195 Mtetra
.086 0 0 r
.26239 .37195 .2707 .3656 .28165 .36145 .27334 .36878 Mtetra
.127 0 0 r
.27334 .36878 .28165 .36145 .29265 .35724 .28434 .36552 Mtetra
.162 0 0 r
.28434 .36552 .29265 .35724 .30369 .35298 .2954 .36219 Mtetra
.19 0 0 r
.2954 .36219 .30369 .35298 .31478 .34871 .30651 .35876 Mtetra
.212 0 0 r
.30651 .35876 .31478 .34871 .32591 .34446 .31768 .35525 Mtetra
.228 0 0 r
.31768 .35525 .32591 .34446 .33708 .34025 .3289 .35165 Mtetra
.239 0 0 r
.3289 .35165 .33708 .34025 .34829 .33607 .34018 .34794 Mtetra
.245 0 .006 r
.34018 .34794 .34829 .33607 .35955 .33195 .35151 .34414 Mtetra
.248 0 .015 r
.35151 .34414 .35955 .33195 .37085 .32788 .3629 .34022 Mtetra
.247 0 .019 r
.3629 .34022 .37085 .32788 .38219 .32387 .37434 .3362 Mtetra
.243 0 .017 r
.37434 .3362 .38219 .32387 .39357 .31992 .38583 .33206 Mtetra
.235 0 .008 r
.38583 .33206 .39357 .31992 .40501 .31602 .39738 .32782 Mtetra
.223 0 0 r
.39738 .32782 .40501 .31602 .41649 .31218 .40898 .32347 Mtetra
.207 0 0 r
.40898 .32347 .41649 .31218 .42802 .30838 .42063 .31902 Mtetra
.185 0 0 r
.42063 .31902 .42802 .30838 .4396 .30461 .43233 .31448 Mtetra
.157 0 0 r
.43233 .31448 .4396 .30461 .45123 .30086 .44408 .30984 Mtetra
.122 0 0 r
.44408 .30984 .45123 .30086 .46291 .2971 .45587 .30511 Mtetra
.079 0 0 r
.45587 .30511 .46291 .2971 .47465 .2933 .46772 .3003 Mtetra
.025 0 0 r
.46772 .3003 .47465 .2933 .48644 .28942 .47962 .2954 Mtetra
0 0 0 r
.47962 .2954 .48644 .28942 .49829 .28543 .49156 .2904 Mtetra
.49156 .2904 .49829 .28543 .51019 .28127 .50354 .2853 Mtetra
.50354 .2853 .51019 .28127 .52214 .27691 .51558 .28007 Mtetra
.51558 .28007 .52214 .27691 .53414 .2723 .52766 .27469 Mtetra
.344 .806 .699 r
.52766 .27469 .53414 .2723 .54619 .26741 .53978 .26913 Mtetra
.414 .856 .762 r
.53978 .26913 .54619 .26741 .55829 .26225 .55195 .26335 Mtetra
.478 .895 .814 r
.55195 .26335 .55829 .26225 .57043 .25685 .56415 .25735 Mtetra
.536 .925 .856 r
.56415 .25735 .57043 .25685 .58261 .25122 .57639 .25111 Mtetra
.588 .946 .89 r
.57639 .25111 .58261 .25122 .59482 .24539 .58867 .24464 Mtetra
.634 .959 .917 r
.58867 .24464 .59482 .24539 .60708 .23937 .60098 .23794 Mtetra
.675 .963 .936 r
.60098 .23794 .60708 .23937 .61937 .23317 .61332 .23101 Mtetra
.708 .958 .947 r
.61332 .23101 .61937 .23317 .6317 .22679 .62569 .22387 Mtetra
.733 .947 .95 r
.62569 .22387 .6317 .22679 .64405 .2202 .63808 .21652 Mtetra
.75 .929 .948 r
.63808 .21652 .64405 .2202 .65644 .21342 .6505 .20898 Mtetra
.761 .909 .941 r
.6505 .20898 .65644 .21342 .66886 .20645 .66294 .20126 Mtetra
.767 .887 .931 r
.66294 .20126 .66886 .20645 .6813 .19931 .6754 .1934 Mtetra
.769 .866 .92 r
.6754 .1934 .6813 .19931 .69377 .19203 .68789 .18544 Mtetra
.768 .845 .91 r
.68789 .18544 .69377 .19203 .70626 .18464 .7004 .17739 Mtetra
.766 .826 .899 r
.7004 .17739 .70626 .18464 .71879 .17718 .71294 .16929 Mtetra
.762 .807 .889 r
.71294 .16929 .71879 .17718 .73134 .16968 .7255 .16118 Mtetra
.457 .683 .963 r
.05043 .39529 .05808 .40196 .06762 .4017 .05998 .39501 Mtetra
.456 .683 .963 r
.05998 .39501 .06762 .4017 .07721 .40143 .06957 .39475 Mtetra
.456 .684 .964 r
.06957 .39475 .07721 .40143 .08686 .40113 .07924 .39448 Mtetra
.458 .687 .964 r
.07924 .39448 .08686 .40113 .09658 .40077 .08896 .39416 Mtetra
.462 .691 .965 r
.08896 .39416 .09658 .40077 .10637 .40032 .09875 .39377 Mtetra
.468 .696 .967 r
.09875 .39377 .10637 .40032 .11624 .39975 .10862 .39328 Mtetra
.476 .703 .968 r
.10862 .39328 .11624 .39975 .12618 .39902 .11856 .39265 Mtetra
.486 .712 .97 r
.11856 .39265 .12618 .39902 .1362 .39813 .12859 .39185 Mtetra
.498 .721 .971 r
.12859 .39185 .1362 .39813 .1463 .39704 .1387 .39085 Mtetra
.511 .729 .972 r
.1387 .39085 .1463 .39704 .15648 .39576 .14888 .38964 Mtetra
.524 .738 .972 r
.14888 .38964 .15648 .39576 .16674 .39427 .15916 .3882 Mtetra
.536 .745 .972 r
.15916 .3882 .16674 .39427 .17708 .39257 .16951 .38656 Mtetra
.547 .752 .972 r
.16951 .38656 .17708 .39257 .1875 .39065 .17994 .38471 Mtetra
.555 .758 .972 r
.17994 .38471 .1875 .39065 .19799 .38852 .19044 .38272 Mtetra
.559 .765 .975 r
.19044 .38272 .19799 .38852 .20856 .38616 .201 .38061 Mtetra
.557 .774 .979 r
.201 .38061 .20856 .38616 .2192 .38361 .21163 .37845 Mtetra
.549 .786 .986 r
.21163 .37845 .2192 .38361 .22991 .38089 .22231 .37628 Mtetra
.536 .801 .994 r
.22231 .37628 .22991 .38089 .24067 .37802 .23305 .3741 Mtetra
.513 .817 1 r
.23305 .3741 .24067 .37802 .2515 .37504 .24384 .37194 Mtetra
.482 .831 .997 r
.24384 .37194 .2515 .37504 .26239 .37195 .25468 .36974 Mtetra
.441 .838 .979 r
.25468 .36974 .26239 .37195 .27334 .36878 .26559 .36749 Mtetra
.391 .832 .943 r
.26559 .36749 .27334 .36878 .28434 .36552 .27657 .36514 Mtetra
.336 .814 .89 r
.27657 .36514 .28434 .36552 .2954 .36219 .28761 .36266 Mtetra
.283 .785 .826 r
.28761 .36266 .2954 .36219 .30651 .35876 .29872 .36001 Mtetra
.238 .753 .762 r
.29872 .36001 .30651 .35876 .31768 .35525 .3099 .35716 Mtetra
.203 .724 .704 r
.3099 .35716 .31768 .35525 .3289 .35165 .32114 .3541 Mtetra
0 0 0 r
.32114 .3541 .3289 .35165 .34018 .34794 .33246 .35081 Mtetra
.33246 .35081 .34018 .34794 .35151 .34414 .34384 .34727 Mtetra
.34384 .34727 .35151 .34414 .3629 .34022 .35528 .34348 Mtetra
.35528 .34348 .3629 .34022 .37434 .3362 .36679 .33943 Mtetra
.36679 .33943 .37434 .3362 .38583 .33206 .37836 .33513 Mtetra
.37836 .33513 .38583 .33206 .39738 .32782 .38999 .33057 Mtetra
.294 .774 .683 r
.38999 .33057 .39738 .32782 .40898 .32347 .40168 .32576 Mtetra
.351 .817 .732 r
.40168 .32576 .40898 .32347 .42063 .31902 .41342 .32072 Mtetra
.417 .861 .788 r
.41342 .32072 .42063 .31902 .43233 .31448 .4252 .31545 Mtetra
.486 .901 .846 r
.4252 .31545 .43233 .31448 .44408 .30984 .43704 .30998 Mtetra
.553 .931 .898 r
.43704 .30998 .44408 .30984 .45587 .30511 .44892 .30434 Mtetra
.611 .945 .937 r
.44892 .30434 .45587 .30511 .46772 .3003 .46085 .29855 Mtetra
.655 .943 .961 r
.46085 .29855 .46772 .3003 .47962 .2954 .47282 .29266 Mtetra
.685 .928 .97 r
.47282 .29266 .47962 .2954 .49156 .2904 .48483 .28671 Mtetra
.702 .904 .968 r
.48483 .28671 .49156 .2904 .50354 .2853 .49687 .28071 Mtetra
.709 .879 .96 r
.49687 .28071 .50354 .2853 .51558 .28007 .50896 .27471 Mtetra
.713 .855 .95 r
.50896 .27471 .51558 .28007 .52766 .27469 .52109 .26871 Mtetra
.713 .836 .94 r
.52109 .26871 .52766 .27469 .53978 .26913 .53326 .26268 Mtetra
.715 .823 .932 r
.53326 .26268 .53978 .26913 .55195 .26335 .54546 .2566 Mtetra
.718 .815 .925 r
.54546 .2566 .55195 .26335 .56415 .25735 .55771 .25038 Mtetra
.722 .811 .92 r
.55771 .25038 .56415 .25735 .57639 .25111 .57 .244 Mtetra
.727 .809 .915 r
.57 .244 .57639 .25111 .58867 .24464 .58232 .23741 Mtetra
.733 .808 .911 r
.58232 .23741 .58867 .24464 .60098 .23794 .59467 .23059 Mtetra
.739 .807 .906 r
.59467 .23059 .60098 .23794 .61332 .23101 .60705 .22353 Mtetra
.744 .806 .901 r
.60705 .22353 .61332 .23101 .62569 .22387 .61946 .21623 Mtetra
.749 .804 .897 r
.61946 .21623 .62569 .22387 .63808 .21652 .63189 .20872 Mtetra
.752 .802 .892 r
.63189 .20872 .63808 .21652 .6505 .20898 .64435 .20102 Mtetra
.755 .799 .888 r
.64435 .20102 .6505 .20898 .66294 .20126 .65683 .19315 Mtetra
.757 .796 .885 r
.65683 .19315 .66294 .20126 .6754 .1934 .66934 .18516 Mtetra
.758 .794 .882 r
.66934 .18516 .6754 .1934 .68789 .18544 .68187 .17708 Mtetra
.759 .792 .881 r
.68187 .17708 .68789 .18544 .7004 .17739 .69442 .16895 Mtetra
.759 .791 .88 r
.69442 .16895 .7004 .17739 .71294 .16929 .70701 .16078 Mtetra
.758 .79 .879 r
.70701 .16078 .71294 .16929 .7255 .16118 .71961 .15261 Mtetra
.506 .703 .959 r
.04273 .38856 .05043 .39529 .05998 .39501 .05238 .38762 Mtetra
.515 .685 .944 r
.05238 .38762 .05998 .39501 .06957 .39475 .06208 .3867 Mtetra
.523 .668 .928 r
.06208 .3867 .06957 .39475 .07924 .39448 .07184 .38577 Mtetra
.529 .652 .913 r
.07184 .38577 .07924 .39448 .08896 .39416 .08165 .38482 Mtetra
.535 .637 .898 r
.08165 .38482 .08896 .39416 .09875 .39377 .09153 .38383 Mtetra
.541 .625 .884 r
.09153 .38383 .09875 .39377 .10862 .39328 .10147 .38278 Mtetra
.547 .614 .872 r
.10147 .38278 .10862 .39328 .11856 .39265 .11148 .38165 Mtetra
.553 .606 .861 r
.11148 .38165 .11856 .39265 .12859 .39185 .12156 .3804 Mtetra
.558 .6 .851 r
.12156 .3804 .12859 .39185 .1387 .39085 .13171 .37903 Mtetra
.563 .595 .843 r
.13171 .37903 .1387 .39085 .14888 .38964 .14194 .37753 Mtetra
.568 .592 .838 r
.14194 .37753 .14888 .38964 .15916 .3882 .15223 .37588 Mtetra
.572 .591 .833 r
.15223 .37588 .15916 .3882 .16951 .38656 .1626 .37411 Mtetra
.576 .591 .831 r
.1626 .37411 .16951 .38656 .17994 .38471 .17303 .37222 Mtetra
.579 .592 .83 r
.17303 .37222 .17994 .38471 .19044 .38272 .18353 .37022 Mtetra
.582 .594 .83 r
.18353 .37022 .19044 .38272 .201 .38061 .19409 .36815 Mtetra
.584 .597 .831 r
.19409 .36815 .201 .38061 .21163 .37845 .20472 .36601 Mtetra
.585 .598 .832 r
.20472 .36601 .21163 .37845 .22231 .37628 .2154 .36381 Mtetra
.587 .6 .832 r
.2154 .36381 .22231 .37628 .23305 .3741 .22615 .36153 Mtetra
.589 .599 .83 r
.22615 .36153 .23305 .3741 .24384 .37194 .23696 .35918 Mtetra
.592 .598 .827 r
.23696 .35918 .24384 .37194 .25468 .36974 .24783 .35672 Mtetra
.595 .595 .822 r
.24783 .35672 .25468 .36974 .26559 .36749 .25877 .35413 Mtetra
.598 .592 .816 r
.25877 .35413 .26559 .36749 .27657 .36514 .26978 .35141 Mtetra
.601 .588 .81 r
.26978 .35141 .27657 .36514 .28761 .36266 .28085 .34854 Mtetra
.604 .584 .804 r
.28085 .34854 .28761 .36266 .29872 .36001 .29199 .3455 Mtetra
.607 .58 .797 r
.29199 .3455 .29872 .36001 .3099 .35716 .30319 .34228 Mtetra
.61 .577 .792 r
.30319 .34228 .3099 .35716 .32114 .3541 .31446 .3389 Mtetra
.613 .574 .787 r
.31446 .3389 .32114 .3541 .33246 .35081 .32578 .33533 Mtetra
.616 .573 .783 r
.32578 .33533 .33246 .35081 .34384 .34727 .33718 .33159 Mtetra
.619 .572 .78 r
.33718 .33159 .34384 .34727 .35528 .34348 .34863 .32768 Mtetra
.622 .573 .778 r
.34863 .32768 .35528 .34348 .36679 .33943 .36014 .32359 Mtetra
.626 .575 .777 r
.36014 .32359 .36679 .33943 .37836 .33513 .37171 .31933 Mtetra
.63 .578 .778 r
.37171 .31933 .37836 .33513 .38999 .33057 .38333 .3149 Mtetra
.634 .582 .779 r
.38333 .3149 .38999 .33057 .40168 .32576 .39501 .31028 Mtetra
.638 .588 .781 r
.39501 .31028 .40168 .32576 .41342 .32072 .40674 .30549 Mtetra
.643 .594 .784 r
.40674 .30549 .41342 .32072 .4252 .31545 .41853 .30051 Mtetra
.648 .601 .788 r
.41853 .30051 .4252 .31545 .43704 .30998 .43036 .29536 Mtetra
.653 .608 .791 r
.43036 .29536 .43704 .30998 .44892 .30434 .44225 .29004 Mtetra
.658 .616 .796 r
.44225 .29004 .44892 .30434 .46085 .29855 .45418 .28456 Mtetra
.663 .623 .799 r
.45418 .28456 .46085 .29855 .47282 .29266 .46615 .27892 Mtetra
.667 .63 .803 r
.46615 .27892 .47282 .29266 .48483 .28671 .47817 .27316 Mtetra
.671 .635 .806 r
.47817 .27316 .48483 .28671 .49687 .28071 .49023 .26728 Mtetra
.673 .639 .807 r
.49023 .26728 .49687 .28071 .50896 .27471 .50234 .26132 Mtetra
.675 .641 .808 r
.50234 .26132 .50896 .27471 .52109 .26871 .51448 .25527 Mtetra
.676 .641 .807 r
.51448 .25527 .52109 .26871 .53326 .26268 .52667 .24915 Mtetra
.677 .641 .806 r
.52667 .24915 .53326 .26268 .54546 .2566 .53889 .24295 Mtetra
.678 .64 .805 r
.53889 .24295 .54546 .2566 .55771 .25038 .55116 .23666 Mtetra
.68 .64 .803 r
.55116 .23666 .55771 .25038 .57 .244 .56346 .23026 Mtetra
.682 .641 .803 r
.56346 .23026 .57 .244 .58232 .23741 .5758 .22372 Mtetra
.685 .644 .803 r
.5758 .22372 .58232 .23741 .59467 .23059 .58817 .21705 Mtetra
.689 .649 .805 r
.58817 .21705 .59467 .23059 .60705 .22353 .60058 .21021 Mtetra
.694 .656 .808 r
.60058 .21021 .60705 .22353 .61946 .21623 .61302 .20323 Mtetra
.699 .664 .812 r
.61302 .20323 .61946 .21623 .63189 .20872 .6255 .1961 Mtetra
.704 .674 .817 r
.6255 .1961 .63189 .20872 .64435 .20102 .638 .18885 Mtetra
.71 .685 .824 r
.638 .18885 .64435 .20102 .65683 .19315 .65053 .18149 Mtetra
.715 .698 .832 r
.65053 .18149 .65683 .19315 .66934 .18516 .6631 .17406 Mtetra
.721 .713 .842 r
.6631 .17406 .66934 .18516 .68187 .17708 .67569 .16657 Mtetra
.726 .729 .852 r
.67569 .16657 .68187 .17708 .69442 .16895 .68832 .15905 Mtetra
.732 .746 .863 r
.68832 .15905 .69442 .16895 .70701 .16078 .70098 .15151 Mtetra
.736 .764 .876 r
.70098 .15151 .70701 .16078 .71961 .15261 .71368 .14397 Mtetra
.576 .728 .946 r
.03496 .38178 .04273 .38856 .05238 .38762 .04479 .37975 Mtetra
.581 .696 .921 r
.04479 .37975 .05238 .38762 .06208 .3867 .05466 .37772 Mtetra
.583 .667 .896 r
.05466 .37772 .06208 .3867 .07184 .38577 .06458 .3757 Mtetra
.584 .64 .872 r
.06458 .3757 .07184 .38577 .08165 .38482 .07455 .37368 Mtetra
.584 .616 .85 r
.07455 .37368 .08165 .38482 .09153 .38383 .08457 .37166 Mtetra
.583 .595 .831 r
.08457 .37166 .09153 .38383 .10147 .38278 .09464 .36961 Mtetra
.582 .578 .813 r
.09464 .36961 .10147 .38278 .11148 .38165 .10476 .36753 Mtetra
.581 .563 .798 r
.10476 .36753 .11148 .38165 .12156 .3804 .11495 .36542 Mtetra
.58 .55 .786 r
.11495 .36542 .12156 .3804 .13171 .37903 .12518 .36327 Mtetra
.579 .54 .775 r
.12518 .36327 .13171 .37903 .14194 .37753 .13548 .36108 Mtetra
.579 .531 .766 r
.13548 .36108 .14194 .37753 .15223 .37588 .14583 .35886 Mtetra
.578 .525 .759 r
.14583 .35886 .15223 .37588 .1626 .37411 .15623 .3566 Mtetra
.578 .52 .754 r
.15623 .3566 .1626 .37411 .17303 .37222 .1667 .35431 Mtetra
.578 .516 .75 r
.1667 .35431 .17303 .37222 .18353 .37022 .17722 .35196 Mtetra
.578 .513 .746 r
.17722 .35196 .18353 .37022 .19409 .36815 .1878 .34956 Mtetra
.58 .511 .743 r
.1878 .34956 .19409 .36815 .20472 .36601 .19844 .34704 Mtetra
.582 .51 .739 r
.19844 .34704 .20472 .36601 .2154 .36381 .20915 .34439 Mtetra
.584 .507 .734 r
.20915 .34439 .2154 .36381 .22615 .36153 .21993 .34158 Mtetra
.586 .504 .729 r
.21993 .34158 .22615 .36153 .23696 .35918 .23078 .33857 Mtetra
.588 .5 .723 r
.23078 .33857 .23696 .35918 .24783 .35672 .24169 .33538 Mtetra
.589 .496 .716 r
.24169 .33538 .24783 .35672 .25877 .35413 .25267 .33202 Mtetra
.59 .491 .71 r
.25267 .33202 .25877 .35413 .26978 .35141 .26372 .3285 Mtetra
.59 .486 .704 r
.26372 .3285 .26978 .35141 .28085 .34854 .27482 .32484 Mtetra
.59 .481 .698 r
.27482 .32484 .28085 .34854 .29199 .3455 .28598 .32106 Mtetra
.589 .476 .693 r
.28598 .32106 .29199 .3455 .30319 .34228 .2972 .31718 Mtetra
.589 .472 .688 r
.2972 .31718 .30319 .34228 .31446 .3389 .30847 .31323 Mtetra
.588 .469 .685 r
.30847 .31323 .31446 .3389 .32578 .33533 .31979 .30921 Mtetra
.588 .467 .682 r
.31979 .30921 .32578 .33533 .33718 .33159 .33116 .30514 Mtetra
.587 .465 .68 r
.33116 .30514 .33718 .33159 .34863 .32768 .34258 .30104 Mtetra
.587 .464 .68 r
.34258 .30104 .34863 .32768 .36014 .32359 .35406 .2969 Mtetra
.587 .464 .679 r
.35406 .2969 .36014 .32359 .37171 .31933 .36558 .29273 Mtetra
.588 .465 .68 r
.36558 .29273 .37171 .31933 .38333 .3149 .37716 .28853 Mtetra
.589 .468 .682 r
.37716 .28853 .38333 .3149 .39501 .31028 .38878 .28427 Mtetra
.591 .471 .685 r
.38878 .28427 .39501 .31028 .40674 .30549 .40046 .27996 Mtetra
.593 .475 .688 r
.40046 .27996 .40674 .30549 .41853 .30051 .41219 .27556 Mtetra
.596 .481 .692 r
.41219 .27556 .41853 .30051 .43036 .29536 .42397 .27106 Mtetra
.6 .487 .697 r
.42397 .27106 .43036 .29536 .44225 .29004 .43581 .26644 Mtetra
.604 .494 .702 r
.43581 .26644 .44225 .29004 .45418 .28456 .44769 .26167 Mtetra
.609 .502 .707 r
.44769 .26167 .45418 .28456 .46615 .27892 .45963 .25674 Mtetra
.614 .511 .713 r
.45963 .25674 .46615 .27892 .47817 .27316 .47162 .25163 Mtetra
.619 .519 .718 r
.47162 .25163 .47817 .27316 .49023 .26728 .48366 .24633 Mtetra
.625 .527 .723 r
.48366 .24633 .49023 .26728 .50234 .26132 .49575 .24083 Mtetra
.63 .534 .727 r
.49575 .24083 .50234 .26132 .51448 .25527 .50788 .23515 Mtetra
.634 .54 .731 r
.50788 .23515 .51448 .25527 .52667 .24915 .52006 .22933 Mtetra
.637 .544 .733 r
.52006 .22933 .52667 .24915 .53889 .24295 .53227 .22339 Mtetra
.639 .548 .736 r
.53227 .22339 .53889 .24295 .55116 .23666 .54453 .21737 Mtetra
.641 .552 .739 r
.54453 .21737 .55116 .23666 .56346 .23026 .55683 .2113 Mtetra
.643 .557 .742 r
.55683 .2113 .56346 .23026 .5758 .22372 .56918 .20518 Mtetra
.646 .563 .747 r
.56918 .20518 .5758 .22372 .58817 .21705 .58156 .19901 Mtetra
.649 .57 .753 r
.58156 .19901 .58817 .21705 .60058 .21021 .59399 .19281 Mtetra
.653 .58 .76 r
.59399 .19281 .60058 .21021 .61302 .20323 .60646 .18655 Mtetra
.658 .591 .769 r
.60646 .18655 .61302 .20323 .6255 .1961 .61896 .18024 Mtetra
.664 .605 .779 r
.61896 .18024 .6255 .1961 .638 .18885 .63151 .17389 Mtetra
.67 .621 .791 r
.63151 .17389 .638 .18885 .65053 .18149 .6441 .1675 Mtetra
.676 .64 .806 r
.6441 .1675 .65053 .18149 .6631 .17406 .65673 .16107 Mtetra
.683 .661 .822 r
.65673 .16107 .6631 .17406 .67569 .16657 .66941 .15463 Mtetra
.691 .685 .839 r
.66941 .15463 .67569 .16657 .68832 .15905 .68212 .14817 Mtetra
.698 .711 .859 r
.68212 .14817 .68832 .15905 .70098 .15151 .69489 .14171 Mtetra
.704 .741 .88 r
.69489 .14171 .70098 .15151 .71368 .14397 .70769 .13525 Mtetra
.642 .748 .926 r
.02714 .37496 .03496 .38178 .04479 .37975 .03719 .37156 Mtetra
.64 .708 .896 r
.03719 .37156 .04479 .37975 .05466 .37772 .04727 .36817 Mtetra
.635 .672 .868 r
.04727 .36817 .05466 .37772 .06458 .3757 .05739 .3648 Mtetra
.63 .641 .843 r
.05739 .3648 .06458 .3757 .07455 .37368 .06756 .36144 Mtetra
.623 .613 .819 r
.06756 .36144 .07455 .37368 .08457 .37166 .07776 .35809 Mtetra
.617 .589 .799 r
.07776 .35809 .08457 .37166 .09464 .36961 .088 .35476 Mtetra
.612 .568 .781 r
.088 .35476 .09464 .36961 .10476 .36753 .09829 .35144 Mtetra
.606 .55 .765 r
.09829 .35144 .10476 .36753 .11495 .36542 .10861 .34814 Mtetra
.601 .534 .751 r
.10861 .34814 .11495 .36542 .12518 .36327 .11898 .34486 Mtetra
.597 .521 .739 r
.11898 .34486 .12518 .36327 .13548 .36108 .12939 .34161 Mtetra
.593 .509 .729 r
.12939 .34161 .13548 .36108 .14583 .35886 .13983 .3384 Mtetra
.589 .499 .72 r
.13983 .3384 .14583 .35886 .15623 .3566 .15032 .33521 Mtetra
.586 .49 .712 r
.15032 .33521 .15623 .3566 .1667 .35431 .16086 .33205 Mtetra
.583 .482 .705 r
.16086 .33205 .1667 .35431 .17722 .35196 .17144 .32888 Mtetra
.582 .476 .699 r
.17144 .32888 .17722 .35196 .1878 .34956 .18207 .32567 Mtetra
.581 .471 .693 r
.18207 .32567 .1878 .34956 .19844 .34704 .19277 .32237 Mtetra
.582 .467 .688 r
.19277 .32237 .19844 .34704 .20915 .34439 .20352 .31892 Mtetra
.582 .464 .683 r
.20352 .31892 .20915 .34439 .21993 .34158 .21434 .3153 Mtetra
.583 .46 .678 r
.21434 .3153 .21993 .34158 .23078 .33857 .22522 .3115 Mtetra
.584 .457 .673 r
.22522 .3115 .23078 .33857 .24169 .33538 .23616 .30753 Mtetra
.584 .454 .669 r
.23616 .30753 .24169 .33538 .25267 .33202 .24716 .30342 Mtetra
.584 .45 .665 r
.24716 .30342 .25267 .33202 .26372 .3285 .25822 .29919 Mtetra
.583 .447 .661 r
.25822 .29919 .26372 .3285 .27482 .32484 .26932 .29487 Mtetra
.583 .444 .658 r
.26932 .29487 .27482 .32484 .28598 .32106 .28048 .29051 Mtetra
.581 .441 .656 r
.28048 .29051 .28598 .32106 .2972 .31718 .29168 .28612 Mtetra
.58 .439 .653 r
.29168 .28612 .2972 .31718 .30847 .31323 .30292 .28174 Mtetra
.579 .436 .652 r
.30292 .28174 .30847 .31323 .31979 .30921 .31421 .27738 Mtetra
.577 .434 .65 r
.31421 .27738 .31979 .30921 .33116 .30514 .32554 .27307 Mtetra
.576 .433 .65 r
.32554 .27307 .33116 .30514 .34258 .30104 .33691 .26882 Mtetra
.575 .432 .649 r
.33691 .26882 .34258 .30104 .35406 .2969 .34833 .26463 Mtetra
.574 .431 .649 r
.34833 .26463 .35406 .2969 .36558 .29273 .35979 .26051 Mtetra
.573 .431 .65 r
.35979 .26051 .36558 .29273 .37716 .28853 .37129 .25644 Mtetra
.572 .431 .651 r
.37129 .25644 .37716 .28853 .38878 .28427 .38285 .25242 Mtetra
.572 .432 .652 r
.38285 .25242 .38878 .28427 .40046 .27996 .39445 .24842 Mtetra
.573 .434 .654 r
.39445 .24842 .40046 .27996 .41219 .27556 .40611 .24444 Mtetra
.574 .436 .656 r
.40611 .24444 .41219 .27556 .42397 .27106 .41782 .24043 Mtetra
.575 .439 .659 r
.41782 .24043 .42397 .27106 .43581 .26644 .42958 .23636 Mtetra
.577 .443 .662 r
.42958 .23636 .43581 .26644 .44769 .26167 .4414 .23221 Mtetra
.58 .448 .665 r
.4414 .23221 .44769 .26167 .45963 .25674 .45328 .22795 Mtetra
.584 .453 .669 r
.45328 .22795 .45963 .25674 .47162 .25163 .46521 .22353 Mtetra
.587 .459 .673 r
.46521 .22353 .47162 .25163 .48366 .24633 .47719 .21894 Mtetra
.592 .466 .677 r
.47719 .21894 .48366 .24633 .49575 .24083 .48923 .21416 Mtetra
.596 .472 .682 r
.48923 .21416 .49575 .24083 .50788 .23515 .50132 .2092 Mtetra
.6 .479 .686 r
.50132 .2092 .50788 .23515 .52006 .22933 .51346 .20409 Mtetra
.604 .485 .691 r
.51346 .20409 .52006 .22933 .53227 .22339 .52565 .19887 Mtetra
.606 .492 .697 r
.52565 .19887 .53227 .22339 .54453 .21737 .53789 .19362 Mtetra
.609 .498 .702 r
.53789 .19362 .54453 .21737 .55683 .2113 .55017 .18835 Mtetra
.611 .506 .709 r
.55017 .18835 .55683 .2113 .56918 .20518 .56251 .18309 Mtetra
.614 .514 .717 r
.56251 .18309 .56918 .20518 .58156 .19901 .57489 .17786 Mtetra
.617 .523 .725 r
.57489 .17786 .58156 .19901 .59399 .19281 .58732 .17267 Mtetra
.62 .534 .735 r
.58732 .17267 .59399 .19281 .60646 .18655 .59981 .16749 Mtetra
.624 .547 .747 r
.59981 .16749 .60646 .18655 .61896 .18024 .61235 .16233 Mtetra
.629 .562 .76 r
.61235 .16233 .61896 .18024 .63151 .17389 .62494 .15719 Mtetra
.634 .58 .776 r
.62494 .15719 .63151 .17389 .6441 .1675 .63759 .15205 Mtetra
.64 .6 .793 r
.63759 .15205 .6441 .1675 .65673 .16107 .65029 .14692 Mtetra
.646 .623 .813 r
.65029 .14692 .65673 .16107 .66941 .15463 .66305 .1418 Mtetra
.652 .65 .836 r
.66305 .1418 .66941 .15463 .68212 .14817 .67586 .13668 Mtetra
.658 .681 .861 r
.67586 .13668 .68212 .14817 .69489 .14171 .68873 .13157 Mtetra
.663 .717 .888 r
.68873 .13157 .69489 .14171 .70769 .13525 .70165 .12647 Mtetra
.697 .76 .901 r
.01926 .36808 .02714 .37496 .03719 .37156 .02955 .36321 Mtetra
.688 .719 .873 r
.02955 .36321 .03719 .37156 .04727 .36817 .03987 .35836 Mtetra
.678 .682 .847 r
.03987 .35836 .04727 .36817 .05739 .3648 .05022 .35354 Mtetra
.668 .65 .823 r
.05022 .35354 .05739 .3648 .06756 .36144 .0606 .34873 Mtetra
.658 .621 .801 r
.0606 .34873 .06756 .36144 .07776 .35809 .07101 .34395 Mtetra
.649 .596 .782 r
.07101 .34395 .07776 .35809 .088 .35476 .08145 .33919 Mtetra
.641 .574 .764 r
.08145 .33919 .088 .35476 .09829 .35144 .09192 .33446 Mtetra
.633 .555 .748 r
.09192 .33446 .09829 .35144 .10861 .34814 .10242 .32974 Mtetra
.626 .537 .734 r
.10242 .32974 .10861 .34814 .11898 .34486 .11295 .32505 Mtetra
.619 .521 .721 r
.11295 .32505 .11898 .34486 .12939 .34161 .12352 .32038 Mtetra
.613 .507 .709 r
.12352 .32038 .12939 .34161 .13983 .3384 .13412 .31573 Mtetra
.608 .494 .698 r
.13412 .31573 .13983 .3384 .15032 .33521 .14476 .3111 Mtetra
.602 .482 .688 r
.14476 .3111 .15032 .33521 .16086 .33205 .15542 .3065 Mtetra
.597 .471 .679 r
.15542 .3065 .16086 .33205 .17144 .32888 .16613 .30191 Mtetra
.593 .462 .671 r
.16613 .30191 .17144 .32888 .18207 .32567 .17687 .29735 Mtetra
.589 .453 .664 r
.17687 .29735 .18207 .32567 .19277 .32237 .18765 .29281 Mtetra
.586 .446 .658 r
.18765 .29281 .19277 .32237 .20352 .31892 .19846 .28829 Mtetra
.583 .44 .653 r
.19846 .28829 .20352 .31892 .21434 .3153 .20931 .2838 Mtetra
.58 .435 .649 r
.20931 .2838 .21434 .3153 .22522 .3115 .2202 .27932 Mtetra
.578 .432 .646 r
.2202 .27932 .22522 .3115 .23616 .30753 .23113 .27487 Mtetra
.577 .429 .644 r
.23113 .27487 .23616 .30753 .24716 .30342 .2421 .27043 Mtetra
.576 .428 .643 r
.2421 .27043 .24716 .30342 .25822 .29919 .25311 .26602 Mtetra
.575 .427 .642 r
.25311 .26602 .25822 .29919 .26932 .29487 .26416 .26163 Mtetra
.575 .426 .642 r
.26416 .26163 .26932 .29487 .28048 .29051 .27525 .25726 Mtetra
.574 .426 .642 r
.27525 .25726 .28048 .29051 .29168 .28612 .28638 .25292 Mtetra
.574 .426 .643 r
.28638 .25292 .29168 .28612 .30292 .28174 .29756 .24859 Mtetra
.29756 .24859 .30292 .28174 .31421 .27738 .30878 .24429 Mtetra
.573 .426 .644 r
.30878 .24429 .31421 .27738 .32554 .27307 .32004 .24 Mtetra
.32004 .24 .32554 .27307 .33691 .26882 .33135 .23574 Mtetra
.33135 .23574 .33691 .26882 .34833 .26463 .34271 .2315 Mtetra
.572 .426 .644 r
.34271 .2315 .34833 .26463 .35979 .26051 .35411 .22728 Mtetra
.572 .425 .644 r
.35411 .22728 .35979 .26051 .37129 .25644 .36556 .22308 Mtetra
.571 .425 .644 r
.36556 .22308 .37129 .25644 .38285 .25242 .37706 .2189 Mtetra
.57 .424 .643 r
.37706 .2189 .38285 .25242 .39445 .24842 .3886 .21474 Mtetra
.57 .423 .643 r
.3886 .21474 .39445 .24842 .40611 .24444 .4002 .21061 Mtetra
.569 .422 .642 r
.4002 .21061 .40611 .24444 .41782 .24043 .41184 .20649 Mtetra
.568 .422 .642 r
.41184 .20649 .41782 .24043 .42958 .23636 .42354 .2024 Mtetra
.42354 .2024 .42958 .23636 .4414 .23221 .43529 .19833 Mtetra
.568 .422 .643 r
.43529 .19833 .4414 .23221 .45328 .22795 .44709 .19427 Mtetra
.568 .423 .644 r
.44709 .19427 .45328 .22795 .46521 .22353 .45894 .19024 Mtetra
.568 .424 .646 r
.45894 .19024 .46521 .22353 .47719 .21894 .47085 .18623 Mtetra
.568 .427 .649 r
.47085 .18623 .47719 .21894 .48923 .21416 .48282 .18224 Mtetra
.57 .431 .653 r
.48282 .18224 .48923 .21416 .50132 .2092 .49484 .17827 Mtetra
.571 .436 .658 r
.49484 .17827 .50132 .2092 .51346 .20409 .50692 .17432 Mtetra
.573 .442 .665 r
.50692 .17432 .51346 .20409 .52565 .19887 .51905 .1704 Mtetra
.575 .45 .672 r
.51905 .1704 .52565 .19887 .53789 .19362 .53125 .16649 Mtetra
.577 .458 .681 r
.53125 .16649 .53789 .19362 .55017 .18835 .5435 .16261 Mtetra
.58 .468 .69 r
.5435 .16261 .55017 .18835 .56251 .18309 .55581 .15874 Mtetra
.583 .479 .701 r
.55581 .15874 .56251 .18309 .57489 .17786 .56819 .1549 Mtetra
.586 .491 .713 r
.56819 .1549 .57489 .17786 .58732 .17267 .58063 .15107 Mtetra
.59 .504 .725 r
.58063 .15107 .58732 .17267 .59981 .16749 .59313 .14727 Mtetra
.593 .518 .739 r
.59313 .14727 .59981 .16749 .61235 .16233 .6057 .14349 Mtetra
.597 .534 .755 r
.6057 .14349 .61235 .16233 .62494 .15719 .61833 .13973 Mtetra
.6 .552 .773 r
.61833 .13973 .62494 .15719 .63759 .15205 .63103 .13599 Mtetra
.604 .573 .792 r
.63103 .13599 .63759 .15205 .65029 .14692 .6438 .13227 Mtetra
.608 .597 .814 r
.6438 .13227 .65029 .14692 .66305 .1418 .65663 .12857 Mtetra
.611 .624 .839 r
.65663 .12857 .66305 .1418 .67586 .13668 .66954 .1249 Mtetra
.614 .656 .867 r
.66954 .1249 .67586 .13668 .68873 .13157 .68252 .12124 Mtetra
.614 .691 .898 r
.68252 .12124 .68873 .13157 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Rooooo`;oWK3U00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`1Aooooo`00H?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B47ooooo`03o`000?oooooooooo01gooooo0ol00002ooooo`03o`000?oooooooooo05cooooo0_nM
Ymd4oif`i@03o`000?nM/>Gooooo01Gooooo00?o0000ooooooooool0D?ooool0063ooooo00Go410@
oooooooooooooooooa0@400;ooooo`Go00007?ooool2o`00063ooooo0_nLWmH5oifWg@?oWK3U00?o
0000ojVghoooool05?ooool00ol0003oooooo`00001Aooooo`00H?ooool01Ol0003ooooooooooooo
oooo000000_ooooo00CoA4A4omgMgOoooooo00006_ooool3o`0005gooooo0_nKV=06oibOePGoWJOM
00?oWK3UojVghol000000_nY]n<Fooooo`03o`000?oooooooooo04oooooo001Pooooo`05o`000?oo
ooooooooooooool000002oooool01?oMgMgoEEEEooooool0000Hooooo`;o0000G?ooool2oiZBbPGo
ViS@1OnLWmH4oifWg@04ojR^g?nY]n?oZKOSo`0000?oZKOS5_ooool00ol0003oooooooooo`1>oooo
o`00H?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000005Oooool3o`00
00;ooooo00?o0000ooooooooool0E_ooool00onISLGoVY;:oiZBbP03oiZBbPGoViS@1OnLWmH00onM
YmgoZ:kLojR^g002ojR^g005ojVghol0003oZKOSojVghond_N405_ooool00ol0003oooooooooo`1>
ooooo`00H?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000004oooool2
o`0005cooooo1?nISLD4oiZBbPKoViS@0_nLWmH2ojJVePKoZ:kL00?o0000okBmhOnd_N400_nd_N4F
ooooo`03o`000?oooooooooo04gooooo001Pooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`0?ooooo`?o0000Foooool2oiR8`@GoVHg51?nJT/X5oi^Hd003ojFOd?nVY]Ko
YZKF00?oYZKF1?nX[]`00onb]]_o0000okBmh@04okBmhAKooooo00?o0000ooooooooool0C?ooool0
08;ooooo0_l0001Jooooo`;oUhBm1OnHR<44oiV=a@GoVY;:00?oViS@ojFOd?nUWm000onUWm05ojJV
eP05ojR^g?nb]]_o/[KKok:ffol000001?nd_N400onl`n3oooooooooo`0Dooooo`03o`000?oooooo
oooo04cooooo001oooooo`?o00000_ooool00ol0003oooooooooo`1Cooooo`;oUh6i1OnGQ;d4oiR8
`@GoVHg50onJT/X00onSVL_oYIo@ojFOd004ojFOd0CoYZKF00?o/:oFok:ffonb]]/00_nb]]/00ol0
003o/[KKokBmh@04okc3h1Cooooo0ol0001=ooooo`00O?ooool3o`0005Oooooo0_nFOKH5oiN1^@Co
UhBm1?nHR<45oiV=a@03oiZBb_nSVL_oXiW;00;oXiW;1_nUWm000onVY]Ko/:oFok2_eP02ok2_eP?o
/[KK00?o0000ok^ng?nl`n001?nl`n0Gooooo`03o`000?oooooooooo04[ooooo001jooooo`;o0000
Eoooool00onEN[?oUWffoiIm]P03oiIm]PCoUh6i1?nGQ;d5oiR8`@;oVHg50_nRU<H6oj>Ib`CoYIo@
00?o[ZWBok2_e_n`[mH00on`[mH3ok:ff`03ok^ng?l0003o^kkL00?o_<?P0_o2b^4Fooooo`03o`00
0?oooooooooo04[ooooo001gooooo`?o0000F?ooool3oiEj/`CoUWff1?nGPKT5oiN4_@?oV8S100?o
XHo2oj:Da_nRU<H00onRU<H6oj>Ib`03ojFOd?n^ZM;o[ZWB00;o[ZWB1On`[mH01_nb]]_o^kkLok^n
g?l0003o^kkLokc3h0Go`/[Q5_ooool00ol0003oooooooooo`19ooooo`00MOooool2o`0000;ooooo
00?o0000ooooooooool0Doooool2oiAg/0CoUGZc1OnFOKH4oiN1^@CoUhBm00?oV8S1oj6?`_nQSl80
0_nQSl85oj:DaPCoXiW;00?o[J?>ojjYd_n^ZM800on^ZM84ok2_eP05okVjf_nk_]co^kkLok^ng?l0
00001_o2b^400oo3c^?oooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo001booooo`?o0000
1Oooool00ol0003oooooooooo`1>ooooo`;oTgF^1?nDMk04oiEj/`GoUWff1?nGPKT2oiN4_@;oWhbo
1_nQSl85oj:DaP03oj>Ibon]Xlko[J?>00;o[J?>1On^ZM800on`[mKo^K[JokVjfP02okVjfP;o^kkL
00?o0000ol;:hOo2b^400oo2b^43ol?>haKooooo00?o0000ooooooooool0B?ooool0073ooooo0_l0
001Eooooo`;oTg>/1?nCMJh5oiAg/0CoUGZc1?nFOKH3oiN1^@03oij8_?nOS;ooWhbo00?oWhbo1OnQ
Sl84oj:DaP03oj^Nb_n]Xlko[J?>00?o[J?>1?n^ZM800onh]]Oo^K[JokVjfP03okVjfP03ok^ng?o2
b^7o000000Co`/[Q1Oo3c^<Fooooo`03o`000?oooooooooo04Oooooo000hooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000Pooooo`?o0000E?ooool00onBLJ[oTg>/oi=c
[002oi=c[0GoTgF^1?nDMk04oiEj/`GoUWff00CoUh6ioij8_?nNR;coWXRl1OnOS;l5oj6?`P03oj:D
a_n[W/[oZik:00;oZik:1On]Xlh00on^ZM;o^;KGokRfe`02okRfe`?o^K[J0oo2b^400ol0003o`/[Q
ol;:h@02olCCiPCo`lkS00?o_m;Xooooooooool04oooool3o`0004Sooooo000hooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Nooooo`;o
00000oooool00ol0003oooooooooo`1?ooooo`?oTW6Z1OnCLj`4oi=e[PCoU7N`1?nEN[<4oiIm]P03
oif5^OnNR;coWXRl00;oWXRl1OnOS;l4oj6?`P03ojVJaon[W/[oZik:00?oZik:1?n]Xlh00ong/]Co
^;KGokRfe`04okRfe`03okVjf_o2b^7o`/[Q00;o`/[Q00?o0000ol;:hOo4dnH00oo4dnH00oo3c^?o
_m;XokoBj002okoBj1Kooooo00?o0000ooooooooool01_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:Oooool003Sooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^01cooooo0ol0001Dooooo`;oTVnX1OnBLJX4oi=c
[0CoTgF^1OnDMk04oiEj/`03oiIm]_nMQKWoWHFi00;oWHFi1?nNR;`5oin<_`03oj6?`_nYV/OoZI[7
00;oZI[71?n[W/X3ojfScP?o]k;D1?nh]]L00oo2bn7o`/[Qol;:h@03ol;:h@03o`000?o4dnKoa=?V
00;oa=?V00?o`M_]okoBj?nod^P01?nod^PFooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Zooooo`00>?ooool01Ol0
003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h06?ooool3o`0005?ooooo0_nAKZL4
oi9_Z0GoTW6Z1?nCLj`4oi=e[PGoU7N`0_nEN[<2oif3]`GoWHFi1?nNR;`4oin<_`03ojRGa?nYV/Oo
ZI[700?oZI[71On[W/X00on]Xlko]k;DokNbe002okNbe0?o^;KG0oo2bn43ol;:h@03olCHj?l0003o
a=?V00;oa=?V0oo1fnd4okoBj0;o]m7]5_ooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooo
ooooooooool@41002oooool5o`0002_ooooo000hooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`0Eooooo`?o0000D_ooool00onAKJKoTFjWoi5^Y`02oi5^Y`GoTVnX1?nB
LJX4oi=c[0GoTgF^0onDMk000onLPKGoWH>goif3]`03oif3]`CoWHFi1OnNR;`00onOS;ooZ9O4ojRG
a002ojRGa0CoZI[71?n[W/X00one[m;o]k;DokNbe004okNbe003okRfeoo2bn7o`/_Q00;o`/_Q00Oo
`/[QolCHj?o4f>Soa=SXo`000?o4f>Soa=?V00Go`M_]00?o_m;XokOAkOngdNd00ongdNdEooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgooooo
o`0002cooooo000hooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0A
ooooo`?o00000oooool00ol0003oooooooooo`1<ooooo`04oi5/YOnAKJKoTFfVoi5]YPGoTFjW1?nB
KjP4oi9aZPCoTg>/1OnCMJh01?nDMk3oW86eoib1]OnLPKD5oif3]`GoWHFi0onNR;`00onWU<;oZ9O4
ojRGa003ojRGa0GoZI[700?oZik:okF_d_ne[m800_ne[m84okNbe003ol7;h_o2bn7o`/_Q00;o`/_Q
0_o4gN/3olCHj003o`000?o0iO7o`>Ga00Co`M_]0_nggO<4okOAk@03oj_=l_oooooooooo01Cooooo
00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoo
oooo0000;?ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41004Oooool2o`0005?ooooo0onAK:D4oi5]YPCoTFjW1?nBKjP4oi9aZPGoTg>/0onCMJh0
0onKOk?oW86eoib1]@03oib1]@CoWH>g1OnMQKT00onNR;coYiC2ojND`P02ojND`PCoZ9O41?nYV/L0
0ond[=7o]JoBokF_dP03okF_dP?o]k;D0oo1bn82ol;;h@Coa=g[00?oa=SXol3UlOl000000oo0iO40
0oo1fngo]mgcokOMl`03okOMl`03okOAkOn[cO;oZlgb00;oZlgb5_ooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000/ooooo`00>?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00>ooooo`?o0000
D_ooool2oi5/Y0CoTFbU1?nAKJH4oi5^Y`CoTVnX1OnBLJX4oi=c[004oi=e[_nKOk?oVgncoi]o/`Go
W86e1OnMPkL3oif5^@03ojJA`?nWU<;oYiC200?oYiC21OnXUl@00onYV/Oo]:cAokB/d@02okB/d@Go
]JoB00?o]k;Dol7;h_o1bn800_o1bn800oo2bn7oa=g[olCMj`02olCMj`;o_>oc00Co`>Gao`000?o0
iO7o`>Ga0_nbj?P4okOMl`;oZ=Wi1On[cO8Dooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?ok^k^odA4A?l00000;?ooool005Wooooo0ol0001@ooooo`KoTFbT1OnAK:D3oi5]
YPCoTFjW1?nBKjP5oi9aZP;oTg>/0_nKOK85oi]o/`CoW86e1OnMPkL00onMQKWoYY70ojJA`002ojJA
`0CoYiC21?nXUl@00onbZLoo]:cAokB/d@03okB/d@Co]JoB00?o`LcSol7;h_o1bn800_o1bn82olCS
kP?oa=g[1?nlko<00ol0003o/^Shok;Xn003ok;Xn003okOMlonXfOWoZ=Wi00?oZ=Wi0_n[cO82oic5
m1?ooooo00Co0000oooooooooooo00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?o
MgMgo`000?ooool0:oooool005Kooooo0ol00003ooooo`03o`000?oooooooooo04[ooooo2_nAK:@4
oi5/Y@?oTFfV1?nAKZL5oi9_Z0?oTW6Z00?oVWb`oi]m/_nKOK800_nKOK85oi]o/`GoW86e0onMPkL0
0onUT;ooYY70ojJA`003ojJA`0GoYiC20_nXUl@3ok:Yc`Go]:cA00?o]JoBol7<hoo1c><00_o1c><0
0oo1bn;oa>?^olCSkP03olCSkP03olCMjonlko?o_>oc00;o_>oc00?oYo3go`000?nWl?L00_nbj?P4
oioSo0;oZ=Wi0_nHcOX5oic5m1Kooooo00?o0000ooooooooool0@?ooool005Cooooo0_l0001@oooo
o`goTFbT1?nAK:D3oi5]YPGoTFjW1?nBKjP01?nBLJ[oVWb`oiYl/?nJO;05oi]m/PCoVgnc1OnLPKD0
0onMPkOoYI2oojF@_`02ojF@_`CoYY701OnWU<800onXUlCo/ZW?ok:Yc`02ok:Yc`Co]:cA00?o`<gT
ol7<hoo1c><00oo1c><00oo2j?3oa>?^olCSkP02olCSkP?o/oGb00Go_>ocojO`monWl?OoYo3go`00
0003oi3Wn@;oWn?l0_n@eOh5oiS=nPCoW<Gd5_ooool00ol0003oooooooooo`10ooooo`00DOooool3
o`00053ooooo3onAK:@4oi5/Y@CoTFfV1?nAKZL3oi9_Z003oiUj[onJO;3oVWb`00?oVWb`1?nKOK85
oi]o/`?oW86e00?oY8jmojF@_onUT;l00onUT;l5ojJA`0?oYiC200?o/JO>ok:YconbZLl01?nbZLl0
0ond[=7o`<gTol3=i002ol3=i0?o`LcS0oo2j?001?o4hnko/oGbok?el_ncmO83oi;_j`?oMn;[00Co
0000oi3WnOn4f_koQ=[n1On@eOh2oiS=nP;oSKkg1On@^_<Fooooo`03o`000?oooooooooo03oooooo
001>ooooo`Go0000C_oooolBoi5/Y0CoTFbU1?nAKJH4oi5^Y`04oi9_Z?nINZooVGZ_oiUj[`GoVWb`
1?nKOK85oi]o/`03oib1]OnTS[goY8jm00;oY8jm1?nUT;l5ojJA`003ojND`_naYlko/JO>00;o/JO>
1?nbZLl00onocNGo`<gTol3=i004ol3=i004ol7<hoo2j?3o`^S`ol;Xl0;oXoKX0ombhM401?nBkn_o
Mn;[ogORjomgh^/2og?In@03o`000?n4f_koQ=[n00;oQ=[n0_n@eOh3oh[1nPCoSKkg1On@^_<Foooo
o`03o`000?oooooooooo03kooooo001<ooooo`;o00001Oooool00ol0003oooooooooo`17oooooaKo
TFbT1OnAK:D3oi5]YP;oTFjW0_nHN:h5oiUj[`CoVWb`1OnKOK83oi]o/`03ojB=_OnTS[goY8jm00?o
Y8jm1OnUT;l3ojJA`003ok2Vc_naYlko/JO>00?o/JO>0onbZLl3oko=i@Co`<gT0_nokO800oo2j?3o
XoKXoj?fj003og;Qd@;oE]7@0omNdnd2og?In@03oh36o_l0003oP<Kn00CoQLCl1On:`OX4ohfnm`;o
T;[c0_n;/_0Fooooo`03o`000?oooooooooo03kooooo0019ooooo`?o0000C_oooolJoi5/Y0CoTFbU
0_nAKJH00onGMjgoV7R^oiQh[P02oiQh[PGoVGZ_1?nJO;05oi]m/P03oi]o/onTSKgoY8fm00;oY8fm
1?nTS[d5ojF@_`03ojJA`?n`Y/ko/:K>00;o/:K>1OnaYlh00onbZLoo_lgUoko=i@03oko=i@04ol3=
i?nokO;o_ngboko]lP;oR>cC00?oBlF[oc>h[Olc^:d00_m8b=/2ogO8o`CoNlOo0on0a_h00ol0003o
P<KnohG4o003ohG4o0;oR/7j0_n:/>l5ohZal0CoRk;`5?ooool3o`0003oooooo000Rooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08?ooool2o`00053ooooo6onAK:@4oi5/Y@03oi5]Y_nGMjgoUgN]00Go
V7R^1?nINZl5oiYl/0?oVgfb00?oXhblojB=_OnTSKd00onTSKd5ojB>_@?oYI2o00?o[jC=ok2Vc_n`
Y/h00on`Y/h4ok6WcP;o_/kV1?nocND3ok_bl`03oko]l_n8k=?oMLSo00GoMLSo1?mgb?l4og_7o`;o
P<Kn00?o0000ohV/kOn9[nh01?n9[nh4ohZ`k`GoR[7`1?n;/_0Eooooo`03o`000?oooooooooo03go
oooo000Rooooo`05ogMgMonHV9SooooooiRHV?mgMgL07Oooool3o`0000;ooooo00?o0000oooooooo
ool0B_ooool2oi9/Y1coTFbT0_nAK:D2oiIe[0CoUgN]1?nHN:h4oiUj[`GoVWb`00?oVgfboj><_?nS
S;`00_nSS;`4ojB=_@GoY8jm00?oYI2oojnTcOn_Y<d00_n_Y<d5ok2VcP03ok6Wc_nnc^Ko_/kV00?o
_/kV00?o_lgUok_blonkl_<00_nkl_<2ogO7o`KoMLSo00?oSJ;Soh^Vion;Y^L00_n;Y^L5ohZYjP04
ohV/kOl0003oRJc]ohV/k@GoRJo^1?n:/>l2ohZal0;oSZSW1On=[^`Eooooo`03o`000?oooooooooo
03cooooo000Rooooo`05oa0@4?ooooooooooooooool@41006oooool2o`0004oooooo1OnBK:@Koi5/
Y003oiEcZonFMJcoUWF/00;oUWF/1?nGMjd4oiQh[PGoVGZ_0onJO;000onSRk_oXhbloj><_003oj><
_0GoY8fm0onTS[d00on^Y<go[jC=ojnTc@03ojnTc@Co/:K>00?o_LkWokk>i_nnc^H00onnc^H3okGe
lP03ok_blomgaoooMlOo00;oTI[H1?n?W]h4ohfRh`CoRjKW1On:ZNX01?l0003oRJc]ohV/kOn9[>d2
ohV_kP;oT9cK1?n?X^45ohjXi`GoSJk/5Oooool00ol0003oooooooooo`0kooooo`008_ooool01Ol0
003ooooooooooooooooo000001Sooooo0ol0001>ooooo`03oi9]Y?nBK:CoTVbT00KoTVbT6?nAK:@3
oiEcZ`GoUWF/0onGMjd4oiQh[PGoVGZ_00?oVWb`oj>;^onSRk/00_nSRk/4oj><_0GoY8fm00?oY8jm
ojjTcOn^Y<d00_n^Y<d5ojnTc@03ok2Vc_nmc^Oo_LkW00;o_LkW0onnc^H3okGelP;oU9KB1OnAV]P4
ohnNgPCoSJ;S1?n;Y^L2ohZYjP;oTI3?00Co0000oi2FeOn@U]GoT9KE1On@W=/4ohnRh@GoSZSW0_n=
[^`2oiJ_j1Gooooo00?o0000ooooooooool0>oooool002;ooooo00Go0000ooooooooooooooooo`00
000Fooooo`?o0000C_ooool3oi9]Y0SoTVbT5OnAK:@2oiAbZPGoUG>[1?nFMJ`3oiMg[@GoV7R^0onI
NZl00onRR[_oXh^koj>;^`03oj>;^`GoXhbl0onTSKd00on^Xlgo[ZC=ojjTc@03ojjTc@Co[jC=00?o
^lkYokg>ionmc^L01?nmc^L01?nnc^Ko]OGbokGel_nFTL`4oiBFdPCoTI[H1?n?W]h2ohfRh`;oThK2
1?nBRlP4oi6@c`03o`000?n@U]GoT9KE00;oT9KE1?n@W=/5ohnRh@;oSZSW0_nGYn45oiJ_j1Gooooo
00?o0000ooooooooool0>_ooool002;ooooo00Go410@oooooooooooooooooa0@400Cooooo`?o0000
0_ooool00ol0003oooooooooo`19ooooo`KoTVfT2?nBK:@Aoi5/Y0;oTg6Y1?nDLZX5oiEcZ`CoUWF/
0onGMjd5oiQh[P03oiUj[onRR[_oXXZk00;oXXZk1?nSRk/5oj><_003ojB=_On^Xlgo[Z?=00;o[Z?=
1?n^Y<d3ojnTc@?o^lkY1?nmc^L2ojcfk`?oUY7<1?nDU]85oi6Jf0;oSikN00?oU8:moi>6`_nCQ/80
0onCQ/84oi:;b0?oTI3?00?o0000oi2FeOn@U]D00on@U]D4oi2Lf`;oSj;Q0_nGX=X5oiNWh@CoUZoX
5_ooool00ol0003oooooooooo`0iooooo`008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg013ooooo
0ol0001>ooooo`WoTVfT2?nBK:@>oi5/Y003oi=`Z?nCLJWoTg6Y00;oTg6Y1OnDLZX4oiEcZ`CoUWF/
1?nGMjd3oiQh[P03oj68^_nRR[_oXXZk00?oXXZk1OnSRk/3oj><_003ojfSc_n^Xlgo[Z?=00?o[Z?=
1On^Y<d00on_Y<go^lkYok_>j@03ok_>j@04okg>ion/m^oo[?K_oiN=aPGoUY7<1?nDU]82oi6Jf0;o
U7jh1?nDP[d4oi>6`PCoTX_80onAT<l01?l0003oTI3?oi2FeOn@U]D2oiVCc@CoV9[C1OnGX=X5oiNW
h@;oUZoX0_nP/nDDooooo`;o0000>oooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>oooo
o`;o0000C_ooool<oi9]Y0SoTVbT3OnAK:@2oi=`Z0GoTg6Y1?nDLZX4oiEcZ`GoUWF/0onGMjd00onH
N:koXHRjoj68^P02oj68^PCoXXZk1OnSRk/00onSS;co[J?>ojfScP02ojfScPCo[Z?=1?n^Y<d2ok[?
jPCo^lkY0_nRmNX3oiN=aPCoUY7<00?oUgZaoiIl]?nFO;@00_nFO;@5oiAn^0?oU8:m1?nCQ/85oi:;
b0;oTI3?00?o0000oiZ>a_nITld01?nITld4oiRJd`GoUj3J0_nGYn42oj6[gPGoX;?U5Oooool00ol0
003oooooooooo`0hooooo`00<_ooool5o`0004cooooo3onBKJ@8oi9/Y0WoTFbT0_nBKjL4oi=`Z0Co
Tg6Y1?nDLZX4oiEcZ`GoUWF/0_nGMjd00onOQ[WoXHRjoj68^P03oj68^PGoXXZk0onSRk/00on]Y<ko
[J?>ojfScP03ojfScPGo[Z?=00?o[ZC=ok[?j_njcnX00onjcnX00onkc^WoX_GZoj;ejP02oiR8`@Co
Uhg600CoUY7<oiMj/OnGN[7oUgZa1OnFO;@4oiAn^0?oU8:m1OnCQ/82oi:;b0;oVXW100?oVXk6o`00
0?l000000_nJS/H4oiVCc@GoV9[C0_nGX=X2oj6Se`GoXJ_N0onP/nD00on[^^Coooooooooo`0Doooo
o`03o`000?oooooooooo03Oooooo000`ooooo`;o0000CooooolAoi9]Y0SoTVbT1OnAK:@6oi9_Y`Co
Tg2X1?nCLJT4oiAbZPGoUG>[0onFMJ`00onNQ;OoWhJioin6^@02oin6^@CoXHRj1OnRR[/00onSRk_o
[JC>ojfTcP02ojfTcPCo[J?>1?n^Xld2okS?j`Co^/oZ0_nFl^<5oiR8`@;oUhg600?oV7V_oiMj/OnG
N[400onGN[44oiIl]0CoU7jh1?nDP[d2oi>6`P;oVhFk0_nJRL43o`000004oiZ>a_l0003oVXk6oiZ>
aPCoVI?=1?nHV]<00onQWM3oXJ?Goj6Se`03oj6Se`CoXJ_N00?oX;?Uoj^ji?n[^^@00_n[^^@Eoooo
o`03o`000?oooooooooo03Oooooo000]ooooo`?o0000C_oooolDoi9]Y0SoTVbT0_nAK:@00onBKZKo
TVnWoi9_Y`07oi9_Y`?oTg2X1?nCLJT4oiAbZPGoUG>[00CoUWF/oij4]onNQ;OoWXBg1?nOQ[T5oj68
^P?oXXZk1_n]Y<h5ojfScP03ojjScOnhcn_o^<o[00?o^<o[00?o^/oZoiKbhonFl^<00onHQ;`2oiR8
`@;oVGR]0onHNJl5oiMj/@CoUWbd1OnDO[P2oiB2_@04oi^2]onKQK_oVhFkoi^5^`?o00000onJRL42
oiZ>aP03o`000?nJS/KoVI?=00CoVI?=00CoV9[Coj6Md?nQWM3oXIg@1OnQXmL2oj6[gP;oZk;N1_n[
^^@Eooooo`03o`000?oooooooooo03Kooooo000/ooooo`;o0000C_oooolFoi9]Y0OoTVbT1?nBKZH9
oi9_Y`?oTg2X1?nCLJT5oiAbZP?oUG>[00?oWH:foij4]onNQ;L00onNQ;L4oin6^@CoXHRj00?oXXZk
ojfTc_n]Y<h01_n]Y<h4ojfScP;o]m3/1?nhcn/2ohW/f`05oiR0]onHQ;coV8BloiR4_?nJN:`01?nI
N:d4oiQi[`CoUgZa1OnFO;@4oiAn^003oiB2_OnKP[OoVh:g00?o00000_nKQK/4oiZ9`@?oVXk600Co
0000oiZ>a_nITlgoVI?=0_nRV</5oj6Md0?oXJ?G00?oZjcHoj^bg_n[/]h00on[/]h4oj^ji0;o/l7T
5Oooool00ol0003oooooooooo`0eooooo`00;?ooool3o`0004_ooooo6?nBKJ@5oi9/Y0OoTVjV2?nB
KjL3oi=`Z0GoTg6Y1?nDLZX01?nELj_oWH:foif2]_nMP[H5oij4]`CoWhJi0onQR;X00on/Y<ko[JC>
ojfTcP08ojfTcP03ojfSc_ngd>co]m3/00?o]m3/00?o^<o[ohW/fon9k=/00onHP;L01?nHQ;coVWR/
oiYh[?nJN:`5oiUh[@?oV7V_1?nGN[45oiIl]0;oU7jh0_nKOk<3o`000003oi^2]onKQK_oVhFk00;o
VhFk1OnJRL42oiZ>aP03oj>DaOl0003oXYS;00CoXYS;1?nQWM000onQXmOoZjcHoj^/f002oj^/f0Go
Zk;N00?oZk[Tok?1i?nc`N@00onc`N@Dooooo`03o`000?oooooooooo03Gooooo000/ooooo`04o`00
0?oooooo0000o`0004Kooooo0_nCKJ@Joi9]Y0;oTVbT2_nBKZH8oi9_Y`CoTg2X1?nCLJT2oiAbZP;o
Vh2d1OnMP[H4oij4]`GoWhJi00CoXHRjojbTc_n/Y<ko[:C>2?n]Y<h2okOBkPCo]m3/00?oN^G@oiMl
/onGO;<00onHP;L00onJN:_oVWR/oiYh[003oiYh[0CoVGR]0onHNJl5oiMj/@?oUWbd00?oVgb`oi]o
/ol000000_l00004oi^2]`GoVhFk0onJRL401_nST<7oXiC5oj>DaOnSU<Go0000oj>Da@CoXYS;0onQ
WM000on[Ym?oZjcHoj^/f003oj^/f0CoZk;N0_nd_^44ok?1i003okS7i_oooooooooo017ooooo00?o
0000ooooool000002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^
k_lb<S;o0000oa0@4?o<c<`06Oooool002cooooo0_l00002ooooo`03o`000?oooooooooo043ooooo
1OnCKJ@Ioi9]Y0goTVjV2?nBKjL4oi=`Z0?oTg6Y00?oVWjcoi^0]?nKP;@00_nKP;@5oif2]PGoWXBg
0onOQ[T00on/Xlko[:C>ojbTcP03ojbTcPGo[JC>1Ongd^h00ongd>coUgV`oiMi/003oiMl/`04oiR0
]onJN:_oVWR[oiYhZ`GoVWR/1?nIN:d4oiQi[`CoUgZa00?oUWbdoi]l/?l000000_l00004oi]o/`?o
Vh:g1OnKQK/00onJRL7oXi31oj>@`@02oj>@`@?oXiC500?o0000oj:HbonRV</00onRV</01?nQWM3o
ZjOCoj^Wdon[Ym<5oj^/f003oj^bg_nd_^7o];kQ00?o];kQ00?o/l7TokS7i_nhanH00_nhanHEoooo
o`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q01Wooooo000[ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0?_ooool6oi=]Y1KoTVfT00?oTfjVoi9^Y_nBKZH03OnBKZH9oi9_Y`?oTg2X00CoTg6Y
oiYn/onJO[?oVWjc1OnKP;@4oif2]PGoWXBg00?oWhJiojbSc_n/Xlh00_n/Xlh4ojbTcP?o[JC>0_nf
e_04okOBkPCoUgV`0_nGO;<00onJMj[oVWR[oiYhZ`03oiYhZ`CoVWR/1?nIN:d4oiQi[`;oUgZa0_nK
NZh2o`0000?oVgb`1?nKOk<4oi^2]`?oVhFk00?oY8jmoj>@`OnST<400onST<44oj>Da@03o`000?nR
V<_oXYS;00;o[:??1On[Ym<2oj^/f0?o];_O1?nd_^400onibNOo^<OVokS7iP03okS7iQGooooo00?o
0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooo
ooooo`00000Iooooo`00:oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03[ooooo
2OnCKJ@Doi9]Y0?oTfjV3onBKZH9oi9_Y`;oTg2X00?oVGbboiYn/onJO[<00onJO[<4oi^0]0GoWH:f
0onNQ;L00on[X/ko[:?>ojbScP03ojbScPGo[:C>00?o[JC>okKFl?nfe_000_nfe_000ongd^koUWJ]
oiIf[@03oiMi/004oiYfZOnJMj[oVWNZoiYgZPGoVWR[1?nJN:`5oiUh[@;oV7V_00?oVgV/oi]j[_l0
00000_l00005oi]l/0CoVgnc1?nKP[L00onKQK_oY8jmojB>_@02ojB>_@CoXi311?nSU<D00ol0003o
[:??ojbSc`03ojbSc`?oZjOC00?o]KWLokBkgond^ml01?nd^ml00ond_^7o^LWWokW9i`02okW9i`?o
^<OV0_ngcNXEooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?nHV9SooooooiRHV?lQ8B406Oooool002_ooooo0ol00005ooooo`03o`000?oooooooooo
03Kooooo3?nCKJ@Aoi9]Y0OoTfjV3onBKZH7oi9_Y`03oiQk/OnIO;;oVGbb00;oVGbb1?nJO[<4oi^0
]0GoWH:f00?oWXBgoj^Rc_n[X/h00_n[X/h5ojbScP;o[:C>1?nff_<2okKFl005oeS>/_nFMZgoUWJ]
oiIf[OnGNK000onJMZT4oiYgZPCoVWR[1?nJN:`5oiUh[@04oiQi[ol0003o0000o`0000CoVgZ^1?nK
O;05oi]o/`;oVh:g00?oY8bjojB>_OnTS[d00onTS[d5oj>@`@05oj>DaOn/X<_o[:3;ojbPbol00000
1?n/Xll00on[Ym?o]KWLokFig002okFig0Co];_O00?o^/cXokW9ionibNL00onibNL00onhanKo]lgZ
okO=jP03okO=jQGooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000oeEEEOl0003o410@olc<c00Iooooo`00:oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo03;ooooo00?oTfjUoi=]Y?nCKJ@03OnCKJ@=oi9]Y003oi=_Y_nCKZKoTfjV00Oo
TfjV3onBKZH5oi9_Y`?oV7^a1?nIO;84oiYn/`GoVh2d0onMP[H00onZXLgoZj;>oj^RcP03oj^RcPCo
[:?>0_nehOD4okKJl`03o`000?nELj_oUG>[00?oUWJ]00?oVGBXoiYfZOnJMZT00onJMZT3oiYgZPCo
VWR[1OnJN:`2oiUh[@?o00000onKNJ`4oi]j[PGoVgb`1?nKOk<01?nKP[OoY8bjojB<^_nTS;X4ojB>
_@CoXi3100?o[Ik8ojbPbon/X</00on/X</01?l0003o[:??ojbScong^=/6okFig003okBkgonjc>So
^/cX00;o^/cX0onibNL2okSEk`Co]lgZ00?o/Lc^ooooooooool04oooool00ol0003oooooooooo`03
ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Kooooo`00:oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02oooooo0onCKZD?oi=]Y0[oTVfT00CoU6nV
oi=_Y_nCKjKoTfnV2OnCKZH?oi9^YP;oTVnW0_nGNK05oiQk/@CoVGbb0onJO[<5oi^0]003oif2]_nZ
XLgoZZ7=00;oZZ7=1On[X/h00on/Xlko]N7eokGQm@03okGQm@03okKJlonDLZWoU7:Y00?oUG>[00Co
UWJ]oiUdZ?nIM:SoVGBX1OnJMZT3oiYgZPCoVWR[1?nJN:`3o`0000;oVgRZ1?nKNJ`4oi]j[PGoVgb`
0_nKOk<2ojB9^0CoY8bj1OnTS[d00onST<7o[Ik8ojfNb002ojfNb0Go[:3;00Co0000okNhfong^=_o
]kSK1?ne^M`00onldN[o^/cXok[<j004ok[<j003okW9ionheNoo^=G_00;o^=G_00?o]lgZok7<k_na
c>h00_nac>hCooooo`?o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@
4?nHV9P06oooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`00
0003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0/oooo
o`03oiA_Y_nCKZGoTfjU00;oTfjU3onCKJ@8oi9]Y0?oU6nV1?nCKjH8oi=^YPkoTVjV00?oUgR_oiMi
/?nGNK000_nGNK05oiQk/@CoVGbb1?nJO[<3oi^0]003ojVOc?nZXLgoZZ7=00?oZZ7=1?n[X/h2ok?W
m`Co]N7e1?nDLZT2oiEcZ`03oiQcY_nIM:SoVGBX00?oVGBX1?nJMZT3oiYgZPGoVWR[0ol000000onK
MjWoVgRZoi]hZP03oi]hZP?oVgV/1?nKNZh4oi]l/003ojB7]OnTRKSoY8Vh00?oY8Vh0onTS;X4ojB>
_@03ojjMa_n]W/So[Ik800?o[Ik81?n/X</00onh^M[o0000okNhf`03okNhf`03okFig?nldN[o_=7Z
00;o_=7Z1?njc>P2okSOl`;o^=G_0on`eo@5ok7<kQGooooo00Wo0000ooooooooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410Iooooo`004?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo0ol0000:ooooo`03
o`000?oooooooooo02Sooooo00CoUG2WoiA_Y_nDKjKoU6nV1?nCKZD?oi=]Y0KoTVfT00?oU72WoiA_
Y_nDKjH00onDKjH3oi=_YPSoTfjV2onBKZH01?nFMjkoUgR_oiMh[onGN:l5oiMi/0CoV7^a1?nIO;84
oiYn/`03oi^0]?nYWlcoZIo<00;oZIo<1OnZXLd00on[X/ko/nOgok?Wm`03ok?Wm`03okGQmOnDL:Oo
U72W00?oU7:Y00CoUg6UoiQcY_nHLjKoV7>V1OnIM:P4oiYfZ@CoVWNZ00GoVWR[o`000?l0003o0000
oiYh[003oi]gZ@GoVgRZ0onKNJ`5oi]j[P;oVgb`0_nTQkD5ojB9^0CoY8bj00?oY8jmojjMa_n^WLH0
0_n^WLH4ojfNb0?o[:3;0onh^MX00ol0003o]kSKokNhf`02okgGk@Go_=7Z00Co^/cXokSOlonhgo?o
^=oc0_n[hOX5ok3Gm0;o/Lc^0_nWb?4Eooooo`03o`000?oooooooooo02oooooo0008ooooo`Ko0000
0_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00005ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool09Oooool3oiE`Y`CoU6nV0onCKZD?oi=]Y0;oTVfT1OnDL:L5oiA_YP?o
TfnV2OnCKZH8oi9^YP?oUWN^1?nGN:l4oiMi/0CoV7^a1OnIO;82oiYn/`03ojRMbonYWlcoZIo<00?o
ZIo<1?nZXLd3ojo]n0;o/nOg0_nCKjH3oiA`Y`04oiAbZOnGLJGoUg6UoiMaY@CoV7>V1?nIM:P4oiYf
Z@?oVWNZ0_l000000onJN:_oW7NXoiagZ005oi]gZ@CoVgRZ0onKNJ`5oi]j[P03oi]l/?nTQkGoY8Ne
00;oY8Ne1?nTRKP4ojB<^PGo[Yg61On]W/P00on/X<_o^;WJokRifP02okRifP03okNhfol0003o_MO]
00?o_MO]0_nldNX3ok?Zm`03okSOlon[hO[oZn7j00?oZn7j0_n`eo@2ojC@m`GoYlSa5Oooool00ol0
003oooooooooo`0^ooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgM
gOoooooo00001_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02;ooooo00?oUW:X
oiE`YonEL:L00_nEL:L4oiA_YPCoTfjU3OnCKJ@00onELJSoU72WoiA`Y`06oiA`Y`CoU6nV0onCKjH9
oi=^YPGoTVjV1onFMjh3oiMh[`CoUgV`1OnHNk43oiUl/P03ojNKb_nXWL_oZ9g;00;oZ9g;1OnYWl`0
0onZXLgo[nghojo]n002ojo]n003oi=^YOnCKjKoTfnV00;oTfnV0_nDL:L00onFKjCoUg6UoiMaY@03
oiMaY@?oV7>V1?nIM:P4oiYfZ@?o00001OnLMjP5oi]gZ@CoVgRZ1?nKNJ`3oi]j[P03ojB5/onTQkGo
Y8Ne00?oY8Ne1OnTRKP2ojB<^P;o[ig51?n^WLH4ojfNb003okZkf_nh^M[o^;WJ00?o^;WJ00?o_^3`
o`000?nmend00_nmend2ojKbl`?o/n[g0onMj?/2oj_QnP;oWMSl1OnTd?L2ojO8l@?oW[o`5Oooool0
0ol0003oooooooooo`0]ooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgM
oeEEEOoooooo00001_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01kooooo00Co
UW>YoiIbZ?nFLZSoUW:X1?nEL:L4oiA_YPCoTfjU3?nCKJ@2oiEaZ0SoU72W1?nDKjH3oi=_YPWoTfjV
0_nBKZH00onFMZgoUWN^oiIg[P07oiIg[P?oUgR_1?nGNK05oiQk/@03oiUl/_nWVl[oYi_:00;oYi_:
0onXWL/4ojVOc0?oYo7f00Co[nghoi=^YOnCKZGoTfjU0onCKjH01?nEKJ?oUVnToiI_Y?nFKj@5oiMa
Y@?oV7>V1?nIM:P01_nJMZWo0000o`000?l0003oVWJYoiYgZPOoW7NX1?nKMjT4oi]hZPCoVgV/00?o
VgZ^ojB5/onTQK<00_nTQK<4ojB7]@GoY8Vh00CoY8bjojnMaOn_WLGo[ig51On^WLH00on]W/So^[_J
okZkfP02okZkfP?o^;WJ0onnh?000ol0003oY_;cojKbl`03ojKbl`03ok?ZmonMj?_oWNSk00?oT=_o
1?nMf?`2ojC@m`?oVl;c1OnN_o0Dooooo`03o`000?oooooooooo02gooooo000@ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`;o00003oooool2o`0001cooooo
0onFLjT4oiIbZ0?oUG2W1?nDKjH4oi=^Y@WoTffT0_nELZT4oiEaZ0OoU72W1?nDKjH4oi=_YPOoTfjV
00CoUWJ^oiIf[OnFMZgoUWJ]2OnFMjh3oiMh[`GoUgV`0onHNk400onUVLWoYi_:ojNKbP03ojNKbPCo
Z9g;00?oZIo<ojOam_nWlOH00_nWlOH5oi=^Y@04oi=_Y_nEKJ?oUFfSoiE]X`CoUVnT1?nGLJD3oiQc
YP;oVGBX0ol00003oiYfZ@03oiafZ?nLMjSoW7NX00KoW7NX1?nKMjT5oi]hZP;oVgV/00?oXX:aojB5
/onTQK<00onTQK<5ojB7]@?oY8Vh00?o/Ik4ojnMaOn_WLD00_n_WLD4ojjMaP03okbog?nj^m[o^[_J
00Co^[_J00Co^;WJokkPl?nnh?3o_^3`0_n1jMT01?l0003oY_;cojKblon2i_03ogkJo@GoT=_o0_nM
f?`2oiO4mPGoVl;c0_nN_o02oiZhkAGooooo00?o0000ooooooooool0;?ooool0013ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Gooooo`03oiMfZonFLjWoUW>Y00;oUW>Y1?nFLZP4oiE`Y`?oU6nV1?nC
KZD6oi=]Y003oiEcZ_nELZWoUG:Y00;oUG:Y1?nELJP7oiA`Y`GoU6nV0onCKjH5oi=^YP?oUWJ^1?nF
MZd8oiIg[PCoUgR_1?nGNK000onHNk7oYIW9ojFIb@02ojFIb@CoYi_:0onXWL/4oicak`03ojOam_nC
KZGoTfjU00;oTfjU0_nDK:84oiE]X`CoUVnT1?nGLJD2oiQcYP?o00000onIM:P01?nJMZWoW7JXoiaf
Z?nLMZP8oiagZ0CoVgNY1OnKN:X00onKNJcoXX:aoj:2/@05ojB5/`GoY8Ne00?oY8Vhok6Na?naW/@0
0_naW/@4ojnMa@03ojjMa_nl_mco_;oL00;o_;oL1?nj^mX2ok_[m004okkPl?n1jMWoPNWIoh7Yf@;o
Dlo?00?o0000of_DnOm[e?T01?mnf_d2oi3Ko`;oTl?g1OnGa?H2oi_2l`;oVKC[1OnJ^>dCooooo`;o
0000;_ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Go
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Cooooo`04oiQh[OnGMZ_oUgJ[oiMf
Z`CoUW>Y1?nFLZP4oiE`Y`CoU6nV0onCKZD5oi=]Y0;oUG>Z1?nELZT4oiEaZ0OoU72W1OnDKjH3oi=_
YP;oTfjV0_nFMjh4oiIf[PCoUWJ]2?nFMjh4oiMh[`;oUgV`0_nTV<P5ojFIb@GoYi_:00CoZ9g;oica
konLlNooW?7_0_nCKJ@2oi=^Y@03oi=[XOnDK:;oU6bR00;oU6bR1?nEKJ<4oiI_Y0?oUg6U0ol00002
oiQcYP?oVGBX00?oW7JWoiafZ?nLMZP00onLMZP7oiagZ0GoVgNY0onKN:X00onQP:ooXX:aoj:2/@02
oj:2/@GoY8Fc0onTQkD00oncX<Go/Ik4ok6Na003ok6Na0?o[ig500?o_lKPokbog?nl_m`01?nl_m`0
1_nj^m[o^n_dok_[m?nkjoCo0000oe_4nPCoG<_g00?oJmCio`000?n>^_@00_n>^_@4ohnom`CoTl?g
0_nGa?H2oiR`j0GoVKC[1?nJ^>dEooooo`03o`000?oooooooooo02_ooooo000Yooooo`;o00005?oo
ool00ol0003oooooooooo`0?ooooo`04oiYk/?nHN:goV7R]oiQh[@CoUgJ[0onFLjT4oiIbZ0CoUG2W
1?nDKjH3oi=^Y@;oTffT0_nEM:/4oiEcZP?oUG:Y1?nELJP8oiA`Y`CoU6nV0_nCKjH5oiIg[PCoUWJ^
1?nFMZd9oiIg[P;oUgR_00?oXiK7ojBHb?nTV<P00onTV<P4ojFIb@CoYi_:0_n=k^D5oi=]Y003oi=^
YOnCJj7oTf^Q00CoU6bR1?nEKJ<4oiI_Y0?o00000_nGLJD3oiQcYP04oiUdZ?nLMZOoW7JWoiafY`Go
W7JX1onLMjP5oi]gZ@04oi]hZ_nQP:ooXH2_oj60[`CoXX:a1OnTQK<00onTQkGo/j35ok>Pa@02ok>P
a@Go/Ik400Co[ig5oko6h?noa^3o_lKP1?nl_m`3ojodlP04ok_[m?mKa?[oFlCjoi6Wi@GoS[7^00?o
S[[do`000?n>^_@00_n>^_@2ohnom`03oiRSgOnHZn?oV:_S00?oV:_S1?nH/>P5oiVdj`;oV[S]0_nM
]nXEooooo`03o`000?oooooooooo02[ooooo000Yooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool03?ooool3oiYk/0CoV7R]0onGMZ/4oiIcZ@?oUW:X1?nEL:L4oiA_YP;oTfjU00?oUGB/
oiEdZonEM:/00_nEM:/4oiEcZPCoUG:Y0onELJP8oiA`Y`?oU6nV00?oUWR_oiIg[_nFMjh01_nFMjh4
oiIf[P?oUWJ]2OnFMjh01?nGN:ooXiK7oj>FaonSU/L4ojBHb0GoYIW900?oYi_:ohg^iOn=k^D01OnC
KJ@2oi=ZX0?oTf^Q1OnDK:84oiE]X`03oiI_Y?l0003o000000GoUg6U0_nHLjH6oiafY`CoW7JX2?nL
MjP3oi]gZ@03oj1n[OnQP:ooXH2_00?oXH2_0onRP[44ojB5/`03okBSa_ncX<Go/j3500?o/j351?na
W/@00oo2dnOo_lKPoko6h003oko6h004okbog?n_m?;o[oCbojodlP?oU9cI1?nAYnD5ohjakP04ohjj
m?l0003oVIcFoiVLePCoV:?M1OnHZn<4oiR`j0;oVKC[0_nM/^H5oifgjQCooooo00?o0000oooooooo
ool0:_ooool002Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`09ooooo`03oi]n
/_nJNk3oVW^`00;oVW^`1?nHN:d3oiMfZ`CoUW>Y1?nFLZP3oiE`Y`;oU6nV0_nEMJd3oiEd[0CoUGB[
1?nELjX4oiEbZ@CoUG6X1onDL:L01?nDKjKoUWR_oiIh[onFN:l8oiIg[PCoUWJ^0onFMZd7oiIg[P;o
XYC71?nSU/L5ojBHb0;oYIW90_mli]P3oi=]X`;oTffT00?oTVVOoi=ZX?nCJZ000_nCJZ04oi=[X@Co
U6bR0_nEKJ<3o`0000?oUVnT1?nGLJD00onHLjKoW7JWoiafY`05oiafY`CoW7JX2?nLMjP01?nKMjWo
X7j]oj1n[OnPOZd5oj60[`CoXX:a0_nTQK<3okBSaPCo/j350onaW/@3ol;Ci`?o_lKP0_n<k]/3oiRC
c@CoU9cI1?nAYnD2ohjakP;oVYK>0_nIW=H00ol0003oVIcFoiVLeP04oiRSg@;oV:_S0_nNZ=d4oif]
hPGoWK;V0_nM]nX3oj:hjACooooo00?o0000ooooooooool0:Oooool002Wooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`05ooooo`04oib1]OnKO[;oVgjboi]n/PCoVW^`1?nHN:d3oiMf
Z`CoUW>Y1?nFLZP2oiE`Y`03oiAf[_nEMJgoUGF]00;oUGF]1?nEM:`3oiEdZ`CoUG>Z1?nELZT4oiEa
Z0KoU72W00?oUWR`oiIh[onFN:l00onFN:l7oiIg[PCoUWJ^1?nFMZd3oiIg[P03oj6CaonRU<OoXYC7
00?oXYC70onSU/L4ojBHb0;oJ]c91OnCKJ<01?nBJ9ooTVVOoi9YWonBJIl4oi=ZX0CoTf^Q0onDK:83
o`0000;oUFfS1?nFKj@3oiMaY@WoW7JW1?nLMZP7oiagZ003oiml[?nPOZgoX7j]00?oX7j]1?nQP:l4
oj:2/@03ojB5/ondXlKo]:?600;o]:?61OncX<D00onaW/Co`]?Wol;Ci`02ol;Ci`04oko6h?n<k]_o
S>kKoi^<``CoV9?=0onDW=T00onNSL7oW977oibAa`02oibAa`GoVYK>00CoVIcFo`000?nIW=KoVIcF
0_nHXmd2oj2Re`GoWZSM1?nM[N82oifbiP;oXk?T1_nR^>TDooooo`03o`000?oooooooooo02Sooooo
000Yooooo`?o00005oooool00ol0003oooooooooo`02ooooo`?oW86e1?nKO[84oiYk/0?oV7R]0onG
MZ/4oiIcZ@?oUW:X00CoU7N`oiAf[_nDMZkoU7J^1?nEMJd4oiEd[0CoUGB[0onELjX4oiEbZ@CoUG6X
0_nDL:L2oiIi/@?oUWR`1OnFN:l7oiIg[PCoUWJ^1?nFMZd00onFMjkoXI?7oj6Ca`02oj6Ca`CoXYC7
1?nSU/L01?nTV<SoJ]c9oiA]XonDKJ<4oi=]X`?oTVRO0onBJIl5oi=ZX0?oTf^Q0ol000000onDK:;o
UFfSoiE]X`02oiE]X`CoUVnT00?oUg6UoiafYonLMZL02OnLMZL5oiafZ0CoW7NX0onOO:`5oj1n[@Go
XH2_0_nRP[400ongYlWo]:?6okBSaP03okBSaPCo/j350_o3j?03ol;Ci`03o`000?nKS<?oVhc300;o
Vhc31OnHTld01?nDW=WoWXg1oij=`OnNSL44oibAa`GoVYK>00?oVIcFo`000?nQW]401OnPX]L5oijX
g@;oWJgR00?oY:oPoj>ci?nS/n@00onS/n@4oj:hj@03ojRlj?oooooooooo017ooooo0_l0000Zoooo
o`00:Oooool00ol0003oooooooooo`0Hooooo`03o`000?ooooooWXFh00GoW86e0onKO[84oiYk/0?o
V7R]1?nGMZ/3oiIcZ@04oiIbZ?nDMk3oU7N`oiAg/0CoU7J^0onEMJd4oiEd[0CoUGB[1?nELjX3oiEb
Z@;oUG6X0_nGNk84oiIi/@CoUWR`1?nFN:l8oiIg[P?oUWJ^0_nFMZd2oj2CaPGoXI?71?nRU<L3oj>F
a`03oeWA^onDKJ?oU6fS00;oU6fS0_nCKJ<00onBJ9koTVROoi9XW`02oi9XW`CoTVVO1?nCJZ03o`00
00CoU6bR1?nEKJ<3oiI_Y003oi]eYonLMZOoW7JW00[oW7JW1OnLMZP2oiagZ0KoWgb/1?nPOZd5oj60
[`04oj:2/OngYlWo]jO9okNWb@Go]:?600?o/j35ol?Xl?o3j?000oo3j?000oo2dnOoWHNkoif7^`05
oi^<``;oV9?=0_nQRkd4oij=`@CoW9771?nJU/h01OnSV/coXIkAoj6NdOl0003oXIkA00CoX:;G1?nN
Z=d00onU[=coY:oPojB_h002ojB_h0GoXk?T00?oX[SYojRlj?nX_>P00_nX_>PDooooo`03o`000?oo
oooooooo02Oooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0
0005ooooo`03o`000?oooooooooo01Sooooo00CoX8Vkoij5^?nNQKSoWXFh1OnLPKD3oi]n/PCoVW^`
1?nHN:d3oiMfZ`;oUW>Y00?oU7RaoiAg/?nDMk000onDMk03oiAf[PCoUGF]0onEM:`4oiEdZ`CoUG>Z
0_nELZT00onGO;CoUg^boiMk/P02oiMk/PCoUWVa1?nFN;04oiIh[`SoUWN^0_nFMZh00onOT/OoX9?6
oj2CaP03oj2CaPCoXI?71OnRU<L00onSU/OoU6fSoiA]X`02oiA]X`GoTVRN1OnBJ9l3oi9YW`04oi=Z
X?l0003o0000o`0000?oTf^Q1OnDK:83oiE]X`04oiI_Y?nKMJOoVgFWoi]eY`goW7JW1?nLMZP00onL
MjSoWgb/oiml[005oiml[0CoX7j]1?nQP:l00oni[<go]jO9okNWb@02okNWb@Co]:?60on`nN/2ol?X
l0;oWhBf0onMQk/4oi^<``03ojB;^_nQRkgoXH^m00;oXH^m1?nNSL45oibAa`04oiZFc_nSV/coXi[<
oj>Jc0;oXIkA00?o0000oj6NdOnPX]L01?nPX]L00onNZ=goYJcLojF/g002ojF/g0CoY:oP0_nS/n@2
ojRii@GoZ;cX5Oooool00ol0003oooooooooo`0Vooooo`003_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003ooooooooo
o`0Gooooo`;oX8Vk1?nNQKP4oib1]@?oVgjb1?nJNk04oiQh[@;oUgJ[00CoU7VboiAh/OnDN;7oU7Ra
1OnDMk03oiAf[PCoUGF]0onEM:`4oiEdZ`?oUG>Z00CoUgfeoiMl]?nGO;CoUgbd1OnGNk83oiIi/@Co
UWR`1?nFN:l6oiIg[P;oWY;71?nOT/L4oj2CaPGoXI?70_nRU<L2oiA^Y0;oU6fS00?oTVROoi9XW_nB
J9h01OnBJ9h5oi9XW`04oi9YWol0003o0000o`0000?oTfZP0onCJj45oiA/XP;oUFfS1_nKMJL<oiaf
Y`?oW7JX2OnOO:`5oj1n[@;oXH2_0oni[<d4okNWb@04okBSa_n`nN_o/?W[ok3ij`;oXH:b1?nOQ;H4
oif7^`03oi^<`onTRk[oY8^j00;oY8^j1?nQRkd4oij=`@;oW9770_nUV<L5oj>Jc0;oXIkA00Co0000
oj6NdOnPX]OoX:;G0_nWZMP5ojF/g0;oY:oP0onY]n<4ojRii@;oZ;cX0on/`>TDooooo`03o`000?oo
oooooooo02Kooooo0006ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h01_ooool2o`0001Gooooo0_nRS[l4oj29^`?oWXFh1?nLPKD4oi]n/P?oVW^`0_nH
N:d2oiEk]0?oU7Vb1?nDN;44oiAg/0?oU7J^1?nEMJd4oiEd[0?oUGB[00CoUG>ZoiMm]OnGOKGoUgfe
1?nGO;@4oiMk/PCoUWVa0onFN;05oiIh[`;oUWN^00?oWI;8oijBaonNT/L00onNT/L4oinBa`?oX9?6
1?nQTlL00ol0003oU6jToiA^Y005oi9XW`SoTVRN0onBJ9l2o`0000;oTVVO1?nCJZ04oi=[X@CoU6bR
00?oUFfSoi]eYonKMJL01OnKMJL<oiafY`03oiafZ?nOO:coWgb/00WoWgb/1OnPOZd00onQP:oo^Jc=
okV/c@02okV/c@?o]jO900?oH<jPoj:1[onQP[801?nQP[85oin4]P;oWHNk00?oYhbiojB;^_nTRkX0
0onTRkX4oj6;_@?oWXg100?oZ9O4ojFHaonUV<L00onUV<L4oj>Jc0;oXIkA00?oZJSEo`000?nWZMP0
1?nWZMP3ojF/g003oj^eh?nY]n?oZKOS00CoZKOS0_nX^ND2ojc0j0Go[<3Y5?ooool00ol0003ooooo
ooooo`0Uooooo`003_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1Oooool00ol0003oooooooooo`0Aooooo`03ojBB`onRS[ooXXjo00?oXXjo0onPRK/3oij5^0GoW86e
0onKO[82oiYk/003oiIm]_nENkCoUG^d00;oUG^d1?nDNK83oiAh/@CoU7N`0onDMZh4oiEe[@CoUGB/
0_nEM:/00onFO[OoUgfeoiMm]@03oiMm]@?oUgbd1?nGNk84oiIi/@CoUWR`1?nFN:l01?nFMjkoWI;8
oifBb?nMT/P4oijBa`CoWi;71?nPTlH01?nQTlOo0000oiA^Y?nBJJ07oi9XW`SoTVRN0ol000001?nB
J9ooTVVOoi9YWonBJIl4oi=ZX0CoTf^Q0onDK:800onJM:KoVgFWoi]eY`06oi]eY`_oW7JW00?oX7j]
oiml[?nOO:`02onOO:`3oj1n[@03ok^cd_ni[<go^Jc=00Co^Jc=00?o]jO9oj:1[onRPJl00_nRPJl4
oj62/PGoWhBf00CoWHNkojN<^OnWS;WoYhbi1?nTRkX4oj6;_@03oij=`OnXUlCoZ9O400;oZ9O41?nU
V<L3oj>Jc003ojfYdonYZ=GoZJSE00;oZJSE00?o0000ojNYf?nWZMP00onWZMP01?nU[=coZkGPoj^e
h?n[]N04ojVgh`03ojg0ion/`>So[<3X00?o[<3X0_n/`>T2ojg2jAGooooo00?o0000ooooooooool0
9?ooool000kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool04?ooool3ojBB``CoXXjo0onPRK/4oij5^0CoW86e0_nKO[801?nFOkSoUWff
oiIm]_nFOKH4oiEk]0CoU7Vb0onDN;44oiAg/0CoU7J^0onEMJd2oiEd[0;oUWni0onFO[L5oiMm]@?o
Ugbd1?nGNk84oiIi/@CoUWR`0_nFN:l2oibBb@CoWI;81?nNT/L5oinBa`;oX9?60_nEKjD00onDKZCo
TVVPoi9YX008oi9XW`CoTVRN0ol00004oi9XW`?oTVVO1OnCJZ03oi=[X@04oiA/X_nJM:KoVWBVoiYd
YPSoVgFW2OnLMZL3oj1n[@goWgb/00?oX7j]ok^cd_nk/m800_nk/m84okV/c@;oXh6^1?nRPJl5oj62
/P?oWhBf00?oZhniojN<^OnWS;T00_nWS;T5ojB;^P;oXH^m00?oZYO3ojRGa?nXUl@00onXUl@5ojFH
a`04oj>Jc?n]ZM?o[JWCojfYd`?oZJSE00Co0000ojVXeOnWZMSoYjWH0_n]]Mh5oj^eh003ojVghon]
`>Oo[L3W00;o[L3W0on/`>P00on]`n[o[L;Yojg2j@03ojg2jA?ooooo0_l00008ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c009ooooo`00
3_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00oooool2o`0000oo
oooo00?oYYS8ojBB`onTT/<00_nTT/<4oj:>_`CoX8Vk0onNQKP2oib1]@;oUh:j1?nFOkP3oiIm]PCo
UG^d0onDNK84oiAh/@CoU7N`0onDMZh2oiEe[@03oiJ1^_nFOkWoUWni00?oUWni0onFO[L4oiMm]@?o
Ugbd1OnGNk83oiIi/@;oUWR`0_nLTlX5oibBb@?oWI;81OnNT/L2oinBa`;oUW2U0_nEKjD2oi9YX@?o
TVVP2?nBJ9l01?nBJ9ko0000o`000?l00003oi9XWPCoTVRO1?nBJIl4oi=ZX0;oTf^Q00?oVW>VoiYd
Y_nJM:H00onJM:H7oi]eY`OoW7JW00?oXH2_oj1n[OnPOZd00onPOZd;oiml[003okbmf_nk/m;o^k?B
00Co^k?B00?o^Jc=oj>1[_nSPJh00onSPJh3oj:1[`GoXH:b00?oWhBfoj^?^On[SkT00_n[SkT3ojN<
^@GoY8^j00CoXH^mojZG`onZUl?oZYO31?nXUl@4ojFHa`03ok2[don]ZM?o[JWC00;o[JWC1?nYZ=D0
0ol0003o[KGNojfegP03ojfegP;oZkGP0on_`NL4ojg0i`03ojc0j?n]`n[o[L?Z00;o[L?Z0on]`^T2
ojg3jQCooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B402Oooool000kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool2o`0000gooooo00?oZ9k=ojJHb?nV
V<P00_nVV<P3ojBB``GoXXjo0onPRK/2oij5^003oiR5_OnGP[[oUh:j00?oUh:j0onFOkP3oiIm]PCo
UG^d1?nDNK83oiAh/@CoU7N`0_nDMZh00onEPK_oUX6joiJ1^P02oiJ1^PCoUWni0onFO[L4oiMm]@Co
Ugbd1?nGNk82oiIi/@03oi^Dc?nLTl[oW9?:00?oW9?:1?nLT/T4oifBb0;oWY;70onFLJH2oiI`Y@03
oi9ZX_nBJJ7oTVVQ00;oTVVQ1?nBJJ05oi9XW`?o00001_nBJ9h4oi9XW`CoTVVO1?nCJZ000onCJj7o
VW>VoiYcYP05oiYdYPSoVgFW1OnLMZL2oj60[`GoX7j]2_nOO:`3okbmfPCo^k?B00?oW7V[ojB1[_nS
PJh01?nSPJh4oj:1[`?oXH:b00?o[I:joj^?^On[SkT00on[SkT4ojN<^@?oY8^j00?o[IW3ojZG`onZ
Ul<00_nZUl<5ojRGa003ojFHaon`Zm?o/:_C00;o/:_C1?n]ZM<01OnYZ=Go[kKNojnfg_n_]]ko0000
00?o[KGN00?o/<?Xojo1ion_`NL01?n_`NL2ojg0i`;o[/CZ1On]`nX00on]`^Wo[L?Zojg3jP02ojg3
jQCooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`000009ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c004ooooo`03o`000?oooooooooo00[ooooo1?nXW/d3ojJHb0CoY9;3
1?nRS[l2oj29^`03oiV8`?nHQKgoV8Fm00;oV8Fm1?nGP[X3oiIo^0?oUWff1?nENk@4oiAi/P;oU7Ra
00?oU8:noiB2_OnDP[d00_nDP[d4oiF1^`?oUX6j1?nFOkT3oiIn]`GoUgfe0onGO;@2oiMk/P;oVYG=
1?nKU<`4oibCbPCoW9;90onMT/P00ol0003oUg:WoiMbY`02oiIaYP04oi9[XonBJZ;oTVZRoi9ZXPCo
TVVQ1?nBJJ02oi9XW`?o00000_nBJ9l7oi9XWPGoTVRO0onBJIl2oi=ZX0;oVG>V1?nJLjH4oiYdYPSo
VgFW0onLMZL00onSPk;oXH2_oj60[`02oj60[`CoX7j]2?nOO:`00onmbnGo_;gJokbmfP03okbmfP03
ok^cd_nNNJWoW7V[00?oY86^1?nSPJh4oj:1[`03oj62/_n]T[[o[I:j00;o[I:j1?n[SkT4ojN<^@03
ojB;^_n]VL?o[IW300;o[IW31?nZUl<2ojRGa0;o/joE1On`Zm<2ojfYd`?o/KSN1?n_]]h00ol0003o
/<?Xok33j002ok33j0Co[l7W00?o[/K/ojk4j_n^a>X00on^a>X2ojg3jP;o[LG[1?n]`nX00on/`n_o
ooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;oooo
o`05oc8b<_nHV9SooooooiRHV?lb<S802Oooool002Oooooo00?o0000ooooooooool02?ooool00on[
Y];oZ9k=ojRNc@03ojRNc@?oYYS81?nTT/<2oj:>_`;oVhc31?nIR<03oiR5_@CoUh:j1?nFOkP3oiIm
]P?oUG^d0_nDNK82oi>3_PCoU8:n1?nDP[d3oiF1^`?oUX6j1OnFOkT3oiIn]`CoUgfe0_nGO;@00onI
U/ooVYG=oiZEc@03oiZEc@CoViC<0onLTlX5oibBb@03oifBb?nGLZOoUg:W00;oTVbT0onBJj<3oi9Z
XPCoTVVQ0onBJJ03o`0000GoTVRO2?nBJ9h4oi9XW`;oTVVO00?oV7:VoiUcY_nILjH00_nILjH4oiYc
YPCoVWBV2?nKMJL01?nLMZOoXh>boj>3/_nSPk84oj60[`CoX7j]1_nOO:`4okg;i@?o_;gJ0_nNNJT0
0onUPZooY86^ojB1[P02ojB1[PCoXh6^1?nRPJl5ojfB^PGoZhni0_nWS;T00on_WLGo[IW3ojfI``03
ojfI``?oZYO300?o][GHok>_eOnc[mD00onc[mD3ok2[d`03ok>lhOna^=ko/KSN00Co/KSN0_n_]]h0
0onaa^[o0000ok33j004ok33j003ojo1ion^a^co[/K/00;o[/K/0_n^a>X2ojg6k@Go[LG[00?o[L?Z
ojc3jon/`n/00_n/`n/Dooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05olc<c?l0003o0000o`000?o<c<`02Oooool002Oooooo0_l00006ooooo`03ojf^f?n[
Y];oZjKB00;oZjKB1?nXW/d4ojJHb0;oY9;300?oW977oi^<`onKS<<00onKS<<3oiV8`0?oV8Fm1OnG
P[X3oiIo^0?oUWff0_nENk@00onCQ;ooTh>noi>3_P03oi>3_P?oU8:n1?nDP[d3oiF1^`CoUX6j1?nF
OkT3oiIn]`;oUgfe0_nIUm04oiVFc`CoVYG=1?nKU<`4oibCbP;oW9;90_nHM:T00onBKJGoTVbToi9/
Y002oi9/Y0?oTV^S1?nBJZ83oi9YX@04oi9YX?l0003o0000oi9YX0OoTVRO2?nBJ9h4oi9XW`03oi9Y
WonHLZKoV7:V00GoVG>V0onJLjH4oiYdYPOoVgFW00?oY8Neoj>3/_nSPk800onSPk83oj60[`GoX7j]
0onOO:`00onkg?7o_L_Uokg;i@03okg;i@03okbmf_nONJSoWWVY00?oYH:_1?nTPJh5oj>1[P;oXX6_
0_n`Ukd4ojfB^PGoZhni00CoYhbiojnMaOn_WLGo[ig51On]VL<01?nZUl?o][GHokJef?nf]MP5ok>_
e@04ok2[donc_>7o/kcQok>lh@Co/KSN00?o/L_]ok76j_naa^X00_naa^X00ol0003o/<?Xok33j002
ojk9k@Co[/K/00?o[<S^ojg6kOn]a^d00on]a^d2ojg5j`?o[<C/1?n/`n/Eooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
2Oooool002Oooooo00?o0000ooooooooool01?ooool3ojf^f0CoZjKB1?nXW/d2ojJHb003oifFc?nL
TLOoW97700;oW9771?nKS<<3oiV8`0CoV8Fm1?nGP[X2oiIo^004oi>6`_nCQL7oThG1oi>5`@CoThBo
1?nCPkh3oiB2_PCoU8:m1?nEPK/3oiJ1^P;oUWni0_nGVM<3oiRHdPGoVIO@0onIU/l5oiZEc@CoViC<
0_nLTlX00onHMZ_oTVjWoi9^Y`03oi9]Y@CoTVbT1?nBJj<3oi9ZXP04oi9YXOl0003o0000o`0000?o
TVVP1onBJ9l8oi9XWP;oTVRO0_nGLJH4oiQbYPCoVG>V0onJLjH5oiYdYPCoVgFW0onTQkD5oj>3/P?o
XH2_1OnPOZd00onOO:co^mcaok_Ll@02ok_Ll@?o_L_U0_nONJP00onUQ;3oYH:_ojF2[`03ojF2[`?o
Y86^1OnSPJh01?nRPJoo/9Nmok2G_On`Ukd5ojfB^P?oZhni00?o/Z;8ojnMaOn_WLD00_n_WLD4ojfI
``03okRmgOnf]MSo][GH00;o][GH1?nc[mD00ond`^Go/kcQok>lh@03ok>lh@03ok6hg_nabngo/L_]
00;o/L_]0onaa^X00on^c>oo0000ojk9k@03ojk9k@03ojk6k?n/b>ko[<S^00;o[<S^0on]a^d2oj_6
k@Go[<C/0_n/`n/2oj[2ja;ooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[Zjoooooonj^[[o000000Wooooo000Wooooo`03o`000?oooooooooo00;ooooo00?o/;SO
ojf^f?n][]P00_n][]P5oj^VdP;oZ9k=00?oWicAoifFc?nMU/`00_nMU/`3oibAa`CoVhc31?nIR<03
oiR5_@;oUh:j0_nDQl@4oi>6`P?oThG10onCQ;l4oi>3_PCoU8:n1?nDP[d3oiF1^`;oUX6j00?oUYWD
oiNIdonGVM<00onGVM<3oiRHdPCoVIO@1?nIU/l2oiZEc@?oB<SC00CoTW2Yoi9_Z?nBKjSoTVnX1?nB
KZL4oi9]Y@?oTVbT1?nBJj<01?nBJZ;o0000o`000?l00003oi9YX@?oTVVP2?nBJ9l6oi9XWP03oiIa
Y_nGLJKoUg6V00;oUg6V1?nHLZH4oiUcYP?oVW>V1OnJM:H2oi]eY`03ojJ<^OnTQkGoY8Ne00?oY8Ne
1?nSPk84oj60[`?oX7j]0_n^kOP5ok_Ll@03okg;iOnPNZSoWgVX00;oYHB`1OnUPZl4ojB1[P?oXh6^
00?o/ig2ok2G_On`Ukd00_n`Ukd5ojfB^P04oj^?^OnbX/So/Z;8ok:Rb0Go[ig500?o[IW3okRmgOnh
_Md00_nh_Md4okJef003ok>_eOnd`^Go]<;U00;o]<;U0onc_>42ok3?l0Co/L_]00Ko/LKZojk<kon^
c>oo[/c_o`000?n^c>l2ojk9k@;o[<[`1On/b>h00on]a^goZlK]oj_6k@02oj_6k@;o[<C/0_nZ`n`5
oj[2jaCooooo00Wo0000ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo
410@o`000?l@413oZJVY00Wooooo000Vooooo`?o000000?o//;Vok2hgon`^=l00_n`^=l4ojf^f0;o
ZjKB0_nQY=L4oinLd@?oWIK<0onLTLL5oi^<``;oVHS000CoU8c9oiB:a_nDR/KoU8[61OnDQl@3oi>6
`P?oThG10onCQ;l5oi>3_P?oU8:n1?nDP[d2oiF1^`GoUYWD1?nGVM<3oiRHdPGoVIO@0_nIU/l2oeK@
h`03oiao/_nBLJ[oTW2Y00;oTW2Y0onBKjP4oi9^Y`CoTVfU0onBK:@2oi9[X`?o00000_nBJZ84oi9Y
X@?oTVVP2?nBJ9l4oi9XWP?oUW6V1?nGLJH4oiQbYPCoVG>V1?nJLjH4oiYdYP03oi]eYonVS;WoYXbi
00GoY8Ne1?nSPk84oj60[`03oj1n[On^kOSo[^gh00?o[^gh0_nkg?43oj1jZ003ojJ6/_nUQ;3oYHB`
00;oYHB`1?nUPZl4ojB1[P03oj>1[_ncWL;o/ig200;o/ig21?n`Ukd3ojfB^P03okBYc_nbX/So/Z;8
00?o/Z;80on_WLD00onia^Go^;gMokRmg@03okRmg@;o][GH0ondbNX4okC2i@03ok>lhOn`co3o/<o`
00?o/<o`0_nabnd2ojg?lPCo[/c_00?o0000ojc:l?n/b_000on/b_02ojc8kP;oZlO^1?n[a^d2ojW4
k@CoZ/?/0_nZ`^/2ojW1jaGooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ok;2i_nb
`^H00_nb`^H4ok2hg`;o[JkH0_nR[=h4oj6Te`?oWicA0onMU/`4oibAa`;oVhc30_nDT<`4oiB<b@?o
U8[61?nDQl@3oi>6`P?oThG11?nCQ;l4oi>3_P;oU8:n00?oUISDoiFIe?nEVM@00_nEVM@8oiJIe0?o
UiWC1?nHV=82oiVGd0?oI=Ca0_nBLZ/3oi9aZPCoTW2Y0onBKjP3oi9^Y`CoTVfU0_nBK:@3o`0000;o
TV^S0onBJZ84oi9YX@CoTVVP1onBJ9l2oi9XWP03oiE`Y_nFLJKoUW6V00?oUW6V0onGLJH4oiQbYPCo
VG>V1?nJLjH3oiYdYP03ojRB_onVS;WoYXbi00;oYXbi1?nTQkD5oj>3/P;oXH2_0on9k>L2ojk]n0Co
XG^Y00CoX7ZXojJ6/_nVQ[;oYXJb1?nUQ;05ojF2[`;oY86^00?o]:C8ok>M`_ncWL800oncWL84ok2G
_@03ojfB^_ndZLko]:W>00;o]:W>1?nbX/P00on_WLGo^LKUokW6i@02okW6i@?o^;gM0_nbd_45okC9
jP;o]<;U0on^e?@2ok3?l0;oZ];e1On]co801On^c>ooZlcaoj_<lOn[c?7o000000;o[<[`0onYb?04
oj_7kP03oj_6kOnYa>goZLC]00?oZLC]0_nZ`n`2ojW2k0CoZL7[5?ooool00ol0003oooooooooo`0N
ooooo`006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooonb`^H00onb`^H2
ok2hg`;oXkGU1?nR[=h3oj6Te`CoWicA0onMU/`2oibAa`03oiBCd?nDT<coU93<00?oU93<0onDS<T3
oiB:aPCoU8O41?nCQ/83oi>5`@?oThBo0_nCPkh2oiBHe0CoUISD1?nEVM@8oiJIe0?oUiWC0_nHV=82
og3FnP03oj68^_nCLjcoTW:[00?oTW:[1?nBLJX3oi9`Z@?oTVnX0onBKZL3oi9]Y@?o00000_nBK:@3
oi9[X`?oTVZR1?nBJJ44oi9YX0GoTVRO0_nDKjH3oiE`YPGoUW6V0onGLJH4oiQbYPGoVG>V0onJLjH0
0onJM:KoZ9:oojRB_`02ojRB_`?oYXbi1OnTQkD4oj>3/P04oj60[on9k>OoRNcWohW/i`?oXG^Z0onQ
NjT00onVR;CoYXJbojJ6/P02ojJ6/PCoYHB`1OnUPZl01?nTPJko]:C8okBTb?ndY<P4ok>M`P?o/9Nm
00?o]K;FokBYc_ndZLh00ondZLh3ok:Rb0;o]m7]1Onia^D00onh_Mgo/];aok;Bl@02ok;Bl@;o]<WZ
0_nZf?P4ojkDm0;oYmCg1?nZd_D2ojg?lPCoZLgc0_n[c?400onXbO7o0000ojW8l004ojW8l0;oZlO^
0_nYaNh4ojW4k@03ojS3k?nY`^coZL;/00?oZL;/0_nY`N/2ojS1jaCooooo00?o0000ooooooooool0
7Oooool001_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00;o//;V
00?oY;o]oj>eiOnS]ND00onS]ND4oj:/gP?oXJCG0_nOW=401?nEWMWoUISDoiFHe?nEV=@4oiBCd0Co
U93<0onDS<T3oiB:aPGoU8O40onCQ/82oi>5`@04oi>Ge?nDUmCoU9ODoiBGe0GoU9SD0onEV=@4oiFI
e0KoUYWD1?n3dOl2og_Do`;oU7F]0onCLj`4oi9bZ`CoTW6Z0onBL:T3oi9_Z0?oTVjW0ol000000onB
KJGoTVbToi9/Y002oi9/Y0CoTV^S0onBJZ83oi9YX@CoTVVP0_nBJ9l00onCKjKoU6nVoiA_YP02oiA_
YPCoUG2V1?nFLJH4oiMaYPCoV7:V1?nILjH2oiYcYP03ojVHaOnXT[ooZ9:o00?oZ9:o0onVS;T5ojB7
]@;oXh>b0_m9aJh3oj5lZ`CoXG^Z00CoXG^YojJ8]?nVR;CoYXRd1OnVQ[84ojF4/0?oYH:_00?o]Zg@
okBTb?ndY<P00_ndY<P5ok>M`P04ok2G_One/]Ko]K;FokFbePGo]:W>00?o/Z;8okOAkOngdNd00_ng
dNd2okW6i@;o[MWg1?nbd_42ojCJnPCoZ]Sh00?o[]CdojODmonWe?L00onWe?L2oj[Bm@;oYlkd1?nY
cO<01_nWbO;oZ<WaojS9lOnXbO7o0000ojS9l@;oZLS`0_nXaNh5ojW5kP03ojW4kOnX`ncoZ<?/00;o
Z<?/0onY`^`00onX`NcoZ<7[ojS1j`03ojS1ja?ooooo0_l0000Nooooo`006oooool01Ol@413ooooo
oooooooooooo410@00Kooooo0_l00002ooooo`?oY;o]1OnS]ND2oj:/gP04oiFZiOnEXmooUJ?OoiFS
g`CoUIgI0onEV=@4oiBCd0?oU93<1?nDS<T3oiB:aP;oU8O40_nAUmH3oi:Ge@CoTiOD0onDUm@4oiBH
e0CoUISD1?nEVM@2oiJIe0CoRLgn0_n3dOl2oiMh[`?oU7F]1?nCLj`3oi9bZ`CoTW6Z0onBL:T3oi9_
Z0?o000000?oTVjWoi9]YOnBKJD00_nBKJD3oi9/Y0CoTV^S0onBJZ83oi9YX@;oTVVP0_nBKZL3oi=_
YPGoU6nV0onEL:H4oiIaYPCoUg6V1?nHLZH4oiUcYP04oiYcY_nYV<GoZIS5ojVHa@CoZ9:o1?nVS;T3
ojB7]@04oj1m[OnQOJcoXGf/oj5m[0GoXGb[0_nQNjX00onVRkSoYXRdojJ8]003ojJ8]0CoYXJb1?nU
Q;001?nUPZoo]Zg@okJ]d?nf[M04okBTb0Co/ig200?o][gOokFbe_ne/]H00_ne/]H4okBYcP03ok7J
mOngdNgo]m7]00;o]m7]0_nUgo/4ojgIm`03ok;BlOnTf_[oY=[j00?oY=[j0_nZf?P3oj?En@;oYmCg
0_nUc_D5ojO>m003ojW=lonWbO;oYlWb00;oYlWb0_nXbO400onWaNoo0000ojS5kP04ojS5kP;oZLG^
0_nX`nd5ojS3k003ojW2k?nX`NcoZ<7/00;oZ<7/0_nX`N/2ojS0ja;ooooo00?o0000ooooool00000
7_ooool001_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo
0onT_nd2oj>ei@;oU;;[1?nEZ^D3oiFSg`?oUIgI0onEV=@5oiBCd0?oU93<0_nDS<T01?n>VMWoT9SG
oi2Heon@V=L5oi6GeP?oTYOE0onCUm@4oiBGe0CoU9SD0_nEV=@3ohk6nPCoS<Wl0_n9cOh00on[W<Oo
VGbaoiUl/@03oiMh[`CoU7F]0onCLj`4oi9bZ`?oTW6Z0onBL:T00onBKjSo0000o`000004oi9^Y`Co
TVfU0onBK:@4oi9[X`?oTVZR0_nBJJ400onAKJOoTVjWoi9^Y`02oi9^Y`CoTfnV1?nDKjH3oiE`YPCo
UW6V1?nGLJH4oiQbYP;oVG>V0_n[Wl/4ojVHa@GoZ9:o0onVS;T01?nTQkGoX7f]oj1m[OnPOJd3oj5m
[0GoXGb[00?oXG^ZojJ;^?nVRkP01OnVR;@4ojJ6/P?oYHB`00?o]kOIokJ]d?nf[M000onf[M04okBT
b003ok>M`_nf_Moo][gO00;o][gO1?ne/]H00ondZLko/M[eok7Jm@02ok7Jm@03okOAkOnUgo_oYMok
00?oYMok0_n]fOL3oikKo0;oY=[j0onPeO/2oj?En@?oXlgf1?nUc_D2ojO>m0?oY/Wb0_nWbO86ojO5
k`03o`000?nXaNkoZ<G^00OoZ<?]0_nX`n`6ojS1k003ojS1jonX`>_oZ<3[00?oZ<3[5?ooool00ol0
003oooooooooo`0Kooooo`006oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool00oooool4oi>jlP?oU;;[0onEZ^D4oiFSg`?oUIgI0onEV=@2oiBCd0;oS9gO0on=Vm`4ohjI
f@?oT9SG1?nAUmH3oi:Ge@CoTiOD1?nDUm@2oiBHe0;oSl?i1On>a_X2ohc9o003ojnRbonMP;?oVGba
00?oVGba0onGN:l4oiAe[@?oTg>/1?nBLZ/3oi9aZP04oi9`ZOl0003o0000o`0000?oTVnX0onBKZL4
oi9]Y@?oTVbT0_nBJj<2ohm]Y`?oT6fW0onAKJL5oi9^Y`?oTfnV1?nDKjH3oiE`YPGoUW6V0onGLJH3
oiQbYP03oj^UdOn[Wl_oZio;00?oZio;0onYV<D5ojRB_`;oYXbi00?oWgj_oj1m[OnPOJd00_nPOJd4
oj5m[0?oXGb[00?oYXfkojJ;^?nVRkP00_nVRkP4ojJ8]0CoYXJb00?oYHB`okNgfOng]mT00_ng]mT4
okJ]d0;o]:C80ondbNT4okJmg`;o]K;F1?nXhO/2ok7Jm@?oVn;m0_nUgo/3oiWJo@;oW]_l1?nMeO/2
oj3En`;oX/cf1OnScOH2ojG>m@;oYLSb0onVbO82ojK5k`OoYlG_00?o0000ojO3kOnX`nd01_nX`nd8
ojS1k0?oZ<7[1?nX`>/Eooooo`03o`000?oooooooooo01[ooooo000Kooooo`05oa0@4?oooooooooo
ooooool@41001Oooool00ol0003oooooooooo`05ooooo`CoTk[b0onD/^/3oiFZi@;oUJ?O00?oQjKY
ohRSiOn8XnD00_n8XnD3ohZOhPCoS9gO0on=Vm`3ohjIf@?oT9SG1OnAUmH3oi:Ge@;oTiOD0on<`?P3
ohk2n0CoSl?i0_n>a_X2ok:Yc`04oj25]onMP;?oWH2coif0/`CoVGba1?nGN:l3oiAe[@?oTg>/1?nB
LZ/01?nBLJ[o0000o`000?l00003oi9`Z@?oTVnX0onBKZL2oi9]Y@;oSVbX1on?KJL3oi1]Y`CoTFfW
1?nBKZL3oi=_YPCoU6nV0onEL:H5oiIaYP?oUg6V00?oV7:Voj^UdOn[YM400_n[YM44oj^Ob`CoZIS5
0_nXT[l2oiin/0?oWgj_1?nPOJd4oj5m[003oj5lZonVSK_oYXfk00;oYXfk0onVRkP5ojJ8]0;oYXJb
00?o]/;SokNgfOng]mT00ong]mT3okJ]d0;o/=Gc1OndbNT2okJmg`?oVnCl0_nXhO/4oi7Ro@;oVn;m
0onFfOh2oiWJo@?oW=?k0_nMeO/2oj;;m@GoX/cf0_nScOH2ojC8lPGoYLSb00?oY/WbojK5konVaNl0
0_nVaNl2ojO5k`GoYl?]00Co0000ojO3kOnX`ngoZ<?]0_nW`N`9ojS1k0GoZ<7[1?nX`>/Dooooo`03
o`000?oooooooooo01[ooooo000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000Oo
oooo0_nC^_800on1/oGoPjoaoh>_l@02oh>_l@?oQJ_]0on7Y^T4ohRSi@?oRYoR0on<WMl3ohfKg0Co
SYWI0on@V=L2oi6GeP?oQ[ch0on9__P5ohc0n0?oS/;h0_n?`oT2okJ_dP04ojB;^_nPQKOoX8Fgoj25
]`CoWH2c1?nIO;43oiMh[`?oU7F]1?nCLj`01?nBLZ_o0000o`000?l00003oi9aZP?oTW2Y0_nBKjP0
0on>KJSoSVbXohi/Z005ohi/Z0OoSffW1?n@KJL3oi5]Y`CoTVjW0onCKjH4oiA_YPCoUG2V1?nFLJH2
oiMaYP03ojZYe_n[YM7oZjGA00?oZjGA1On[Wl/2ojVHa@GoWWj`0onOOZl5oj1m[@;oXGf/00?oYY2n
ojJ=^onVSK/00onVSK/3ojJ;^0GoYXRd00CoYXJbokK2honf`^?o]/;S1Ong]mT00onf[M3o/=Gcok3E
l`02ok3El`;o]<WY1?n>i?/2oi_To0?oRN7l0_nAh_d3oiGHoP;oU]Wn0onLd_X2oicCn`?oX/Wd1?nR
boD2oj;<mP?oY<Ob1?nTb?82ojG8lP?oY/C_0_nVaNl3ojO2k@KoYl?]00?oYl7/o`000?nW`N`01?nW
`N`2ojS1k0;oYl7/1OnX`N`2ojS1j`;oYl3[1OnX`>/Dooooo`03o`000?oooooooooo01Wooooo000K
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`07ooooo`?oPK?e1?n3
[o43ohF[k@?oQjKY1?n8XnD3ohZOhP?oS9gO0on=Vm`2ohjIf@?oOkSh0on2^_P4ohJln0?oRKkh0_n<
`?P3oc6iaP?o^KCE00Co]ZoBojB;^_nTRk[oY8^j1?nPQKL3oif0/`CoVGba0onGN:l4oiAe[@04oi=c
[?l0003o0000o`0000;oTW:[0_nBLJX2ohi]Z@KoSVfX2?n>K:P6ohm]Y`CoT6fW0onAKJL4oi9^Y`?o
TfnV1OnDKjH3oiE`YP?oUW6V00?oZ:_IojZYe_nZZMH00_nZZMH4oj^Ud@CoZio;1?nMO[04oiin/0Co
Wgj_1?nPOJd01?nQOJcoYY2nojJ@__nVT;h4ojJ=^`CoYX^h0onVR;@2okC<k0Co]/;S0_ng]mT4ojSO
nP;o/=Gc0on3h_T2ohkTn`?oQMol0_n9hO`4oiKFo@;oUMSn0onMd?T2oicBnP;oX/Sc1OnRbO@2oj;;
m@;oY<Ga1OnTao82ojC8lP;oY/?_0onVa>l00onV`^goYl;]ojO2k@04ojO2k@;oYl?]1OnW`N`00ol0
003oYl7/ojO1k007ojO1k0;oZ<7/1onW`>/2ojS0j`;oYl3[5?ooool00ol0003oooooooooo`0Ioooo
o`009Oooool00ol0003oooooooooo`08ooooo`?oPK?e0_n3[o42ogB^mP?oM:of1?me[oH3ogJ`m`?o
Mk;g0omi/oL3ogbfn0GoOkSh0on2^_P2ohJln0;o?/7L0_o2g>d01?o2gngo^kWGok^ieonk^ML3okVd
e@03ojRB__nTRk[oY8^j00?oY8^j0onPQKL3oif0/`CoVGba0onGN:l2oiAe[@?o000000?oTg>/oi1_
Z_n?KZT00_n?KZT4ohi]Z@OoSVfX1on>K:P6ohm]Y`CoT6fW0onAKJL4oi9^Y`CoTfnV1?nDKjH3oiE`
YP03oiIaY_nXZmWoZ:_I00;oZ:_I0onZZMH5oj^Ud@04oj^ObonLOK7oW7faoiam/@?oWGj`1?nNO[04
oimn[`;oX7f]0_nVTl44ojJ@_PGoYXfk0onVRkP00onVR;Co]<c/okC<k003okC<k0;o]/;S0onLi?`2
ojSOnP?oO>3g0_n3h_T4ohCNo0;oQMol0onHe?d2oiKFo@?oW/kh0_nMd?T3oj?6lPCoX/Sc0_nRbO@2
ojC4l0GoY<Ga0_nTao82ojK3kPGoY/?_00CoY/C_ojK2kOnV`^goY/;]1?nW`^d8ojO1k003o`000?nW
`NcoYl7/00KoYl7/3onW`>/Booooo`03o`000?oooooo000001[ooooo000Uooooo`03o`000?oooooo
oooo00[ooooo1_md[_H3ogB_mPCoMJof0omf/?L3ogNbm`?oNK?g0oml]_P2ognhn0CoCLG_0_m5`nL4
ol;Lk@03okflfOnk^MOo^kWG00?o^kWG00Co^KCEojRB__nXT[koZ9:n1?nTRkX3oj25]`CoWH2c0onI
O;42oiMh[`?o00000_nALJ/3oi1_ZP?oSfjY1?n>KJT7ohi]Z0OoSVbX1on?KJL3oi1]Y`?oTFfW1OnB
KZL3oi=_YPCoU6nV0_nEL:H00onUZM[oZ:_IojR[f@03ojR[f@CoZZWF0_n[YM42oiYl/@CoW7fa0onM
O[05oiin/0;oWgj_00?oYYG4ojJC`OnVTl400onVTl43ojJ@_PGoYXfk0_nVRkP2ok3Fm0Co]<c/0on>
i_X2oicTo0?oNMkg0_mlh?L3ohGNo@;oQ=kl0onJd_`2oiSDo@?oX<cg0onNc_P2ojC5l@GoXlKb0_nR
b?<2ojG3k`CoY<C`0_nTaO43ojK2kPCoY/?^0_nV`nl2ojK1k@GoY/;]00?oYl;]ojO1k?nW`N`01?nW
`N`2ojO0k0?oYl7/00Co0000ojO1k?nW`NcoYl7/5?nW`>/Dooooo`03o`000?oooooooooo01Oooooo
000Uooooo`;o00003?ooool6ogB^mP?oM:of0_me[oH2ofVio@GoIKgm0omO`?d3oe[3n`;oDlGf0_n5
jNd2ok3_m`?o`MW/00?o`]c]okflfOnm_=T00_nm_=T3ok^ie`03ojbI`onXT[koZ9:n00;oZ9:n1?nT
RkX4oj25]`?oWH2c0_nIO;401?nCMJko0000o`000?nBLj`4oi5aZ`CoT6nZ0on?KZT3ohi]Z@OoSVfX
1on>K:P7ohm]Y`?oT6fW1?nAKJL4oi9^Y`?oTfnV0_nDKjH2oj6Uf0CoYJWJ1OnXZmT2ojZYeP;oV7^a
0onJO;44oiam/@CoWGj`1?nNO[001?nOOZooYYG4ojJEa?nVUL@4ojJC`@CoYY2n0onVSK/2oj[Mn@Co
/=Kd00Co]<c/ohkVn_n>i_[oS^Kj1Omig_L4ohSMoP;oQMkm0onLdOX2oi[Bo0;oXL[e1OnPc?L00onN
c_SoY<GaojC5l@02ojC5l@;oXlKb0_nU`nh5ojG3k`;oY<C`0_nV`^d5ojK2kP;oY/?^1_nV`Nd2ojK2
k@KoYl7/1_nW`>`2ojO1k003ojO0jol0003oYl3[01KoYl3[4oooool00ol0003oooooooooo`0Goooo
o`009?ooool00ol0003oooooooooo`0=ooooo`?oMJof1?ma/_T3offfn`?oJKWm0_mU_Od4oeO8mP;o
@/;T0_mGdMl2ohGYk@?o/>og0oo1fN`2okjof`Go_KcI00Co^kWGojbI`on/VL?o[9W30onXT[h5ojB;
^P?oX8Fg0_nMP;<01?nEN;7o0000o`000?l00004oi9c[0?oTG6[1?n@KjX3ohm^Z@?oSVfY1on>KJP7
ohi/Z0OoSffW1?n@KJL3oi5]Y`CoTVjW0_nCKjH00onNWmCoXJGHoj6Uf003oj6Uf0CoYJWJ0_nXZmT3
oiMi/0?oV7^a1?nJO;44oiam/@?oWGj`0_nNO[02ojFGaPCoYYG41?nVTl44ojJ@_P03ojJ=^onZgOWo
Z]gi00?oZ]gi0_n`e_@00on1i?CoNmkhog_Nn002og_Nn0;oNMkg0on<gOh2ohSMoP?oW/oi0_nLdOX3
oj;8l`CoXL[e0_nPc?L3ojC4l0;oY<Ga0onV`^h4ojG3kP;oYL?_0_nV`Nd5ojK2k@;oY/;^0_nW`N`7
ojK1k@SoYl7/1_nW`>`5ojO0j`03o`000?nW`>_oYl3[01CoYl3[5?ooool00ol0003oooooooooo`0F
ooooo`009?ooool00ol0003oooooooooo`0>ooooo`?oMJof0_ma/_T3ogZkn`CoLL;n0_mVaod4oggG
oP;oKMWe0_nCj?T3ok?Xm`?o_mGZ00?o`MW/okjofonn_m/00_nn_m/3okflf@03ok2Oaon/VL?o[9W3
00;o[9W31?nXT[h4ojB;^P;oX8Fg00CoUgbdo`000?l0003o00001?nCMJh3oi9c[0?oTG6[1?n@KjX3
ohm^Z@CoSVfY1_n>KJP8ohi/Z0KoSffW1?n@KJL3oi5]Y`;oTVjW0_nJUll4oijOe0GoXJGH0_nUZMX2
oiAg/0CoUgV`0onHNk44oiYl/@CoW7fa0_nMO[000onTV<SoYIO6ojFGaP03ojFGaP?oYYG41OnVTl42
ojJ@_P?oX^;l0_nZgOT2ogKQkP?oO]oi0_mkg_P4oi3LoP;oS=gn0onOc_P2oik?n@;oXlOb1OnRb?<2
oj7:m@;oYLC_0onTa?02ojK2k@GoY/;^0_nU`nh2ojO1k0CoY/7]0_nV`^d7ojO1k0;oY/7]0_nW`>`7
ojO1k0SoYl3/1_nW`>/00ol0003oYl3[ojO0j`0EojO0jaCooooo00?o0000ooooooooool05Oooool0
02Cooooo0ol0000?ooooo`GoOk?e0omj^o/2og72oP?oR<oo0_mmeoh3oicQo@Co]=of00Co/nSgokoE
j_noeN[o_mGZ0_nn`M`5okjof`04okflfOn`WlOo/9o7ok2Oa`?o[9W31?nXT[h2ojB;^P;oVX6g0ol0
0004oiEh/@?oTgF^0onBLj`4oi5aZ`?oT6nZ0on?KZT4ohi]Z@OoSVfX1on>K:P6ohm]Y`;oT6fW0_nD
Ql<3oiN?b@GoVYO?1?nNWm@2oj6Uf0?oTgF_0onDMk04oiMi/0?oV7^a1?nJO;43oiam/@03oj>HbOnT
V<SoY9S800;oY9S81?nUUlH4ojJEa0;oYY?11?nKiO`2oj;Ro003ofgMj?n2h?_oP^3k00;oP^3k0_mn
goT3oiCKoP;oT=cn0onQc?H2oio>n0?oY<Ka1?nSao82oj;8l`;oY/?^1OnUa>l00onTa?3oY/;]ojK2
k@02ojK2k@;oY/;^1onW`N`2ojK1k@;oYl3/1onW`N`6ojO0k0;oYl7/0onW`>/6ojO0k0[oYl3[00?o
0000ojO0jonW`>/05OnW`>/Booooo`;o00002Oooool4o`000003oa0@4?oooooooooo00Oooooo000T
ooooo`03o`000?oooooooooo013ooooo0_mo/oD3oi:jlPCoS/Cj0_n8col4oj7Gn`03oicQoOndgoKo
]=of00;o]=of0onndNP00onoeN[o_/7Lokk1g002okk1g0;o_[oK0_ncY/`4ok2Oa`Co[9W30_nXT[h0
0onMQk_oVX6go`000002o`0000?oUgbd1?nEN;43oi=e[P?oTW>/1?nALJ/3oi1_ZP?oSfjY1?n>KJT7
ohi]Z0OoSVbX1On?KJL00onBP;goU8O3oiB7``03oiB7``?oUho91?nJUll3oijOe0;oTG>]1?nCMJl3
oiAg/0CoUgV`1?nHNk43oiYl/@03oiam/OnSV<WoXiS900;oXiS90onTV<P5ojFGaP;oYYG40onDi_`2
oi_Uo0;oJ=_T0on6hO`2oh;Pn`CoUm[n0_nDfoh3oj;;m@;oXLcf0_nUaO05ojC6l@;oXlOb0_nV`^h4
ojK3kP;oYLC_0onV`Nd3ojK2k@SoYl7/1onW`>`2ojO1k0;oYl3[1onW`>`7ojO0j`;oYl3/3_nW`>/0
0ol0003oYl3[ojO0j`0EojO0ja?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09
ooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool0
0ol0003oooooooooo`0Booooo`CoT[[b0_n>a?X4oj?;m0;oXMOk0onceO800ondgoKo_]7XokkAj002
okkAj0;o_/;M0onn`M`00onf[M3o/jK<ok>Vc003ok>Vc0Co/9o70_n/VL<00onQSKooWHNko`000002
o`0000?oVX6g1?nGO;@3oiEh/@?oTgF^0onBLj`4oi5aZ`CoT6nZ0on?KZT3ohi]Z@OoSVfX0_n>K:P0
0on?M;7oSgNdohmg]002ohmg]0?oT7^h1?nBP;d4oiB7``?oUho91OnJUll00onNWmCoTG>]oi5c[@02
oi5c[@?oTgF_0onDMk05oiMi/0?oV7^a0_nJO;400onRUl[oXiS9oj>Hb@03oj>Hb@?oY9S81?nUUlH3
ohoVnP;oU>Kl0_mUf^43oh[Qo0;oQ^7l0onJf_d2oiOJoP?oXl[d0_nRboD3ojG4k`CoYLG`0_nTa_42
ojK2k@GoY/;^0_nV`nh2ojO1k0GoY/7]00?oY/;]ojO1k?nW`N`01?nW`N`2ojO0j`KoYl3/1onW`>/2
ojO0k1_oYl3[00?o0000ojO0jonW`>/05OnW`>/Dooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02Oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool04oooool2oi:jlP;oXko]1?nS
bo@2ok;;k0?o/mGb1?nlcNH00onndNSo_/;Mokk2g@02okk2g@04okk1g?nf[M3o]Zg@okJ]d0Co/jK<
0on`WlL00onUU<CoXHfoo`000002o`0000?oWHNk1?nJPKL3oiMl]0?oUGRa1?nCMJh3oi9c[0?oTG6[
1?n@KjX3ohm^Z@?oSVfY0_n>KJP00on>LJkoSW:_ohib[`02ohib[`?oSgBa1?n?Mk@4oi1k^0?oTX2m
1?nDQl<4oiN?b@;oVYO?0on?LJ`4oi5c[@?oTgF_1?nDMk04oiMi/0;oV7^a00?oX9K9oj:Gb_nRUlX0
0_nRUlX4oj>Hb@CoY9S800CoYIO6ohoVn_n?i_[oSnKj0_mTfMl3ohkRo@;oR^7l1?nLfOd2oi[Jo@?o
Y<[c0_nSb_@2ojK4k`GoYLC_0_nUaO02ojO2k@CoY/;]0_nV`^h7ojO1k0;oY/7]0_nW`>`4ojO1k0Ko
Yl3[0_nW`>`XojO0j`03o`000?nW`>_oYl3[01GoYl3[4oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Wooooo0009ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP06ooooo`03o`000?oooooooooo01Gooooo1?nS_nd00onSboCo//_/ok;;k003ok;;k003
ok?El_nlcNKo_<gV00;o_<gV0_nn`mh3okk2g@03okRce?nf[M3o]Zg@00;o]Zg@1OncY/`01?n`WlOo
YIC4o`000?l00003oj6=_`?oWHNk1?nJPKL3oiMl]0CoUGRa0onCMJh3oi9c[0?oTG6[0_n@KjX2ohib
[`?oSW6^0on>LJd3ohia[PCoSW:_1?n?M;43ohmg]0CoT7^h0onBP;d5oiB7``;oUho90on>Kj/3ohma
[0CoTG>]1?nCMJl3oiAg/0;oUgV`0_nNTlP4oj2Fb@?oXYO:1OnSV<T2ojBHb0;oRnKi0_mUf]l3oi3R
o@;oS^;m0onNf?`2oicIo@?oYLWc0_nTb_<3ojK4kPCoY/C_0_nUa>l2ojO1k@GoYl;]0_nV`^d2ojO0
k0OoYl7/1_nW`>`00onW`NcoYl3[ojO0j`0aojO0j`03o`000?nW`>_oYl3[01GoYl3[4oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05o`000?oooooooooooooo
ool000003Oooool00onHV9So8B4Qonk^kP05ooooo`?o00005_ooool2oj>ok@Co/L;W0_nbbn`3ok_8
i003okc=i_nn`mko_/?N00?o_/?N00Co_/;MokRce?nh/mCo^;?D1?nf[M02ok>Vc004ojVLbOl0003o
0000o`0000;oYIC40onQSKl4oif7^`?oVX6g0onGO;@4oiEh/@;oTgF^00CoSgReohif/on>M[?oSWJc
0on>M;44ohib[`?oSW6^0on>LJd4ohia[PCoSW:_0on?M;44ohmg]0?oT7^h1?nBP;d2oiB7``CoSFjZ
0on>Kj/4ohma[0?oTG>]1?nCMJl2oiAg/003oif@a_nNTlSoWY?800;oWY?81?nPU/T4oj:GbP;oXiS9
0_n9i_P2ofKKg`CoTn?m0_n@h_d3oioHn`;oW]Sl0_nUbO83ojG9l`;oY/?^1OnVa>h2ojK4k`;oYl7/
1?nW`Nd2ojO2k@OoYl3/0_nW`N`2ojO0j`OoYl3/=_nW`>/00ol0003oYl3[ojO0j`0EojO0ja7ooooo
0ol00007ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05o`000?ooooooooooooooool00000
3_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo01Sooooo0ona`^L2okW3hP?o^lST
0onma=l3okk3gP03okZif?nh/mCo^;?D00;o^;?D0onf[M001?n]Xlko0000o`000?l00002ojVLb@?o
YIC41?nQSKl3oif7^`;oVX6g00CoTX6moi1m^_n@OK[oT7fj1?n?N[P3ohmh]@?oSWJc0on>M;44ohib
[`CoSW6^0on>LJd3ohia[PCoSW:_0on?M;44ohmg]0CoT7^h0_nBP;d3ohe]Z@CoSFjZ1?n>Kj/3ohma
[0;oTG>]00?oV8S1oiZ<a?nJS<@00_nJS<@4oif@aPCoWY?81?nPU/T2oj:GbP;oRNGh0_mYg=l3oiGT
o@;oTn?m0onQf?/2oioHn`?oY/Sb1?nUbO800onUbO?oY/?^ojK3kP02ojK3kP;oY/C^1onW`N`2ojO1
k@;oYl3[1onW`>`6ojO0j`;oYl3/>_nW`>/00ol0003oYl3[ojO0j`0EojO0j`kooooo1?l000000ooo
oooo0000ooooo`06ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05oa0@4?oooooooooooooo
ool@41003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo00?o/L;WokW3
h_ni`n800_ni`n800onkb>Co_LCOokg4g`03okg4g`04okk3g_nj^MSo^[WHokZif0Co^;?D0ol00000
0on]XlkoZIc9ojVLb@02ojVLb@CoYIC40onQSKl2oif7^`03oiB5`?nBPKgoTX6m00;oTX6m0on@OKX3
ohmj^0CoSgRe0on>M[<3ohid/@?oSW:_1?n>LJh3ohia[@?oSW6^1?n>LZl4ohmd/@?oSgNd0_n@NkP2
ohi^ZPKoSFfY0on=KZX4ohi_Z`;oSg6/00?oUXBnoiR8`OnHR<400_nHR<44oiZ<a0?oWI361?nNTlP2
oj2Fb@?oRnGi00?oK=gQoiKTo?nFi?`00_nFi?`2oiGTo@?oX]Wk0_nQf?/2ojK8l@GoY/Sb0_nUbO83
ojO3kP;oY/?^2?nW`N`7ojO0j`;oYl3/AonW`>/00ol0003oYl3[ojO0j`0EojO0j`[ooooo0ol00005
ooooo`03o`000?oooooooooo00?ooooo00?oEEEEofIVI_l000002oooool000Wooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool2o`0001_ooooo0oni
`n86okg4g`03okbng?nj^MSo^[WH00?o^[WH0ol00005ojfScPCoZIc90_nUU<@01?nKT<OoV8[3oiR:
`onHR/<4oiB5`0?oTX6m0on@OKX3ohmj^0CoSgRe0on>M[<3ohid/@CoSW:_0on>LJh3ohia[@?oSW6^
1On>LZl3ohmd/@;oSgNd00?o0000ohi^Z_n>KZX00_n>KZX6ohe]Z@;oSFjZ00?oTG^hoi=o^_nCOkX0
0_nCOkX4oiJ4_P?oV8S11?nJS<@4oif@aP;oWY?80on=iOX01?n;iOWoV>GloiSUo?nHiO`2oiKTo0Ko
X]Wk0_nWbO44ojK8l@;oY/Sb1_nW`nh8ojO1k5CoYl3[00?o0000ojO0jonW`>/05?nW`>/6ooooo`Co
00002?ooool00ol0003oooooooooo`0Aooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo01_ooooo00?o^L?Rokg4
gonma=l00onma=l4okbng004okZif?l0003o0000o`0000Co/:_C1On]Xlh2ojVLb@03oinGbonKT<Oo
Vi3700;oVi370onHR/<3oiB5`0?oTX6m0on@OKX4ohmj^0?oSgRe0on>M[<3ohid/@CoSW:_0on>LJh3
ohia[@CoSW6^1?n>LZl2ohmd/@;oE=3J0_n<L[04ohac/@?oSWFc0on?N;D4oi5k^0CoTgnj0onFQ;h3
oiR8`@GoVXc40_nMT<H3oi3To0;oSNGj00CoKmoRoiSUo?nHiOcoV>Gl0onSf_/2oj;In`OoYlWa0_nV
b?42ojO3k@GoYl?^1onW`NaGojO0j`03o`000?nW`>_oYl3[01GoYl3[0_ooool3o`0000cooooo00?o
0000ooooooooool04Oooool002;ooooo00?o0000ooooooooool07Oooool6okg4g`05okbng?l0003o
0000o`000?nj^MP00onc/mP4ok2[d`;o[J?>0_nSW]04oinGb`?oVi370onHR/<3oiB5`0CoTX6m0on@
OKX3ohmj^0CoSgRe0on>M[<3ohid/@?oSW:_1?n>LJh3ohia[@?oSW6^0_n>LZl3ogKIn`GoS7:`1?n<
Lk43ohie/`CoSgRe0onANkP4oi=o^P?oUXBn1?nHR<42oiZ<a0CoTn;m0_n@i?`2og;Qi0;oVNKl0onS
fo/2oj?Jn`SoYlWa1onW`nd2ojO3kPKoYl7/FonW`>/00ol0003oYl3[ojO0j`0EojO0j`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool07_ooool4
okg4g`;o00000_nl_]`00onf^mgo/k?Hok>cf003ok>cf0;o/:_C00?oYjKEoj>Nd?nSW]000onSW]03
oinGb`?oVi370onHR/<4oiB5`0?oTX6m0on@OKX3ohmj^0CoSgRe0on>M[<3ohid/@?oSW:_1?n>LJh3
ohia[@;oSW6^0on6c?h00omffO_oSWBaohid/@06ohab/0?oS7>a1?n>MK<3ohmh]@?oTG^h1?nCOkX4
oiJ4_P;oV8S10onGg_h2oi?Ro@;oMn?W0onIj?/00onTgO_oXm_koj?Kn`02oj?Kn`;oZ<[b1_nWbO49
ojO3k@OoYl7/G_nW`>/00ol0003oYl3[ojO0j`0EojO0ja3ooooo00?o0000ooooooooool04?ooool0
02;ooooo0_l0000Pooooo`?o000000?o_LCOokS3honf^md00onf^md3ok>cf003ojZ_fonWY]GoYjKE
00;oYjKE1?nSW]04oinGb`?oVi370onHR/<3oiB5`0;oTX6m00CoRX[=ohR9c_n8RLkoR8W>0on6RLl4
ohF;dP?oQ8kF0on5U=/3ohJMhPGoR:[[1?n9^_H2ohK<oPCoSWBa1_n<L[04ohac/@?oSWFc0on?N;D4
oi5k^0CoTgnj0_nFQ;h3oiWHo@;oUmkn0_mliN/3oiWYnP03oiWXnonTgO_oY=gk00;oY=gk00?oXm_k
ojS:l_nXb_800onXb_82ojO9l@SoYl?]2OnW`NaQojO0j`03o`000?nW`>_oYl3[01CoYl3[4?ooool0
0ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0Looooo`?o000000?ooooookg4
gonh`n<00onh`n<4okJkg@04ok>cf?nZ[m_oZZoKojZ_f`?oYjKE1OnSW]02oinGb`04oiJJe?nCU=7o
TiCAoi>Dd@?oT93?0on=S<h4ohZ:c@?oR8W>0on6RLl4ohF;dP?oQ8kF0on5U=/3ohJMhPGoR:[[0_n9
^_H01?nDOKOoT7Ncoi1g/on@Mk<3ohid/@KoS7:`1?n<Lk43ohie/`CoSgRe0onANkP2oi=o^PCoV/oj
0_nIf?d2oh;Wl0?oVN[j0_nIjOX3ojCNn`;oY=gk0onXbo82ojS:lP?oZ<C^1_nW`nd8ojO1k6GoYl3[
00?o0000ojO0jonW`>/05OnW`>/?ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oo
oooooooo01Wooooo0ol00006ooooo`Co^<?S0_nf^md2ojfhh@CoZZoK0onWY]D2oj>Nd0;oVZ3H1?nF
V]@3oi>Dd@?oT93?0on=S<h3ohZ:c@?oR8W>0on6RLl4ohF;dP?oQ8kF1?n5U=/3ohJMhP;oR:[[00?o
VXFloiAm]onDOKL00_nDOKL3oi1g/`?oSWBa1on<L[03ohac/@CoSWFc0on?N;D2oi5k^0;oV/Ce1?nJ
coX3ohWWm@04oh;Wl?nIj_[oVN[joiWZnP?oY>7l0_nTg_/3ojS<lP;oZ<_b1onXa>h2ojO3k@SoYl7/
JOnW`>/00ol0003oYl3[ojO0j`0DojO0j`oooooo00?o0000ooooooooool04?ooool002;ooooo00?o
0000ooooooooool05_ooool3o`0000[ooooo0_nh`n<2ojo2j0Co[KSQ0_nZ[m/01?nO[^;oWJOMoifW
gOnMYmd5oiZPf0?oUY[D0onCU=43oi2@c`?oSHc>0on:R/d3ohR9cPCoQXW?1?n5Rm83ohB>eP;oQICK
00?oZ9c9oj6@`_nQT<800_nQT<83oiZ5_0?oU7fg0on@Mk<4ohid/@KoS7:`0on<Lk44ohie/`;oSgRe
0_nH]nd4oi[4m@04oi[?n_n9ioGoRNOeohWWm@;oVN_i1?nTho`2ojCQo0?oZLgc0_nXc?82ojS5kPKo
Z<C^2OnW`Na]ojO0j`03o`000?nW`>_oYl3[01CoYl3[3_ooool00ol0003oooooooooo`0@ooooo`00
8_ooool2o`0001Cooooo0ol0000>ooooo`Co[l;X0_n]^>400onR]^OoWjkRoin^hP02oin^hP?oWJOM
1?nJX=P4oiJJe0?oTiCA0on@T<l3ohf<cP?oRX[=0on8RLh2ohJ9c`?oEL3j0_ng]]P4ok2Yd@?oZ9c9
0onQT<83oiZ5_0?oU7fg0on@Mk<4ohid/@GoS7:`00CoSY;Coi6MfonAWM_oTIgK1OnEZ^D4oiRgk@;o
V/Ce0_n@i_X2oiW[n0?oXnGl0_nTho`3ojW?m0;oZLgc1onXaNh2ojS4kPSoYl7/L_nW`>/00ol0003o
Yl3[ojO0j`0DojO0j`gooooo00?o0000ooooooooool04?ooool0027ooooo0_l0000Booooo`?o0000
4_ooool2ojo2j0;oX[k]0onR]^L4oin^hP?oWJOM1?nJX=P2oiJJe004ohbXj?n9Y^SoRJKXohVVj0Co
QZOZ0on2ZNh4ogf_m0;oLKWl0_nk`Mh5okNff0;o/:WA00CoWHc2oiJ5_onFQKooUXFo0onAP;d3ohem
_0?oRWbn0on9OL04ohV2a@?oRhS;1?n>T]<3oi6Mf`GoUJ[U0_nH]nd2oiKRo@?oV>_h00CoVN_hoj?U
o?nSiOcoXnGl0_nZdO@3ojW?m0;oZ<K_1onXaNh2ojS2k0KoYl7/MOnW`>/00ol0003oYl3[ojO0j`0E
ojO0j`cooooo00?o0000ooooooooool04?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool03oooool2
o`0001Kooooo1?nR_^d3oj:fi`;oWjkR0_nC/^`4oi6^jP?oSZ_Y0on<Z>P3ohVVj0CoQZOZ0on2ZNh2
ogf_m003okc_loo3ko3o^l7N00?o^l7N0_ng]]P2oj>DaPCoWHc20onFQKl3oi60_@?oSGfl0on:O;h3
ohUm`0CoRH;50on;R</3ohjBd`CoTIgK0_nEZ^D3oi[Jo@GoV>_h0_nSi_/2oj[Cm@CoZ]7d00?oZLod
ojS6konXa^l00_nXa^l2ojS5kPOoZ<;/0_nW`NaiojO0j`03o`000?nW`>_oYl3[01CoYl3[3Oooool0
0ol0003oooooooooo`0?ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool3o`0001Wooooo0_nR_^d0
0onF^o7oUKO_oiFgk`03oiFgk`?oTk;/1?nA[^X3ohj[j@?oS:SX0on9Y^P2ohJWjP;oGl[j00CoNnKL
okc_lonlko?o_>oc0_nmbN<3ok_1gP03ojVMbonSU<KoXiC600;oXiC61?nMS<83oiJ5_`?oTH2m0on=
OK`3ohYl_P?oRGg01?n9P/D4oh^8b`?oSY;C0_nAWM/3oi_?nP04oi[JoOnHjoSoV>_hoiS[n0?oX^Sk
0_n[eOH4oj[Cm@;oZ]7d0onYb?02ojS6k`WoZ<;/OOnW`>/00ol0003oYl3[ojO0j`0DojO0j`cooooo
00?o0000ooooooooool03oooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000
1Oooool2o`0000[ooooo0ol0000Mooooo`?oU[_a1OnE]nl3oi>bk0;oTJkZ0_n6^oP3oh2mnPCoNL7m
0_m_a_l00ol`^;koNnKLokG[m`02okG[m`03okc_lonmbN?o_LWS00;o_LWS00Co^l7NojVMbonYWL_o
ZIg;1?nSU<H3oif<`P?oUXFo0onAP;d3ohem_0?oRWbn1?n9OL04ohV2a@;oRhS;0_nH/^T4oi[1lP;o
Vloj0_nHj_T3oj7Yn`03oj;Xnon[eOKoZmGf00?oZmGf0_nZdoD3ojW9l0;oZLS`0_nX`nd6ojS2k87o
Yl3[00?o0000ojO0jonW`>/05OnW`>/;ooooo`03o`000?oooooooooo00oooooo0007ooooo`05o`00
0?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00006ooooo`03o`000?oooooooooo
00Kooooo0ol0000Qooooo`?oU[_a0_nE]nl3ohbim0?oRK[f1?n6^oP3oh2mnP;oNL7m0_mFc^X2ohOX
l@?o]N_g0onlcNL2okg9h`03ojjVd?nYWL_oZIg;00;oZIg;1?nSU<H4oif<`P?oUXFo0onAP;d3ohem
_0?oRWbn0_n9OL000onBV]SoU:GPoiBUh003oiBUh0CoV;;Y0_nJ`O82oiSWn`?oX>Wk0_nQjO/3oj_H
m`;oZmGf1?nZbo42ojW9l0KoZ<?]0_nX`^b5ojO0j`03o`000?nW`>_oYl3[01GoYl3[2_ooool00ol0
003oooooooooo`0?ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEE
EOoooooo00001_ooool00ol0003oooooooooo`03ooooo`?o00009_ooool4ohnil`?oS;Wd0on9^_H2
ohJkn0?oOlgo0_m_d_`2oi3So0?o/>Ch0_njc^T3okc=i`03ok:^eOn^Y]3o[ZK@00;o[ZK@0onYWL/4
oj>DaPCoWHc20_nFQKl01?nAR/SoSh[9ohn:bOn?R/T3ohn<c0?oSi7A1?nBV]P5oiBUh0;oV;;Y0onI
hod01?nHio_oX>Wkoj3YnonPjO/3oj_Jn0;oZmSg0_nZcO84oj[;l@03ojS4kOnX`ngoZ<?]00GoZ<?]
0_nX`Nb7ojO0j`03o`000?nW`>_oYl3[01CoYl3[2_ooool00ol0003oooooooooo`0?ooooo`001ooo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001Oooool01?l0003ooooo
ooooooooool3o`0002[ooooo0_n?^O<2oi6ilPCoSKoh0on7a_`2ogo=o`;oUM[n1?n/foP00on`i?So
^/kYok[>j@02ok[>j@04okc=ionb[]Go/ZkEok:^e@?o[ZK@1?nYWL/2oj>DaP03oiVBbonESLWoUHg9
00;oUHg91?nAR/P3ohn:b@?oShc<0on?TM44oi:Jf0;oU:GP1?nHg?h2oiWSo@;oWnSk0on[g?T2oj_J
n0;oZloc1?nZcO800onZbo7oZ<C]ojS4k@02ojS4k@;oZ<?]1onX`Nb7ojO0j`03o`000?nW`>_oYl3[
01CoYl3[2Oooool00ol0003oooooooooo`0?ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l000001Oooool4o`0002kooooo1?nA^O82ohfon0;oV/Gf1?nHco/00onE
f_ko[=_hojcKn002ojcKn0;o]lgZ0onjc^T00ond]MWo/ZkEok:^e@02ok:^e@Co[ZK@0_nYWL/00onN
V<goVI;;oiVBb`02oiVBb`?oUHg91?nAR/P3ohn:b@?oShc<1?n?TM42oi:Jf0?oUm?l0_nHg?h3oikV
o0;oZ]ki0on[g?T2oj_Am0CoZloc0_nZcO83ojW5kP;oZ<C]2OnX`Nb8ojO0j`03o`000?nW`>_oYl3[
01CoYl3[2Oooool00ol0003oooooooooo`0?ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00gooooo00?oMgMgo`000?ooool01?ooool2o`00037ooooo0_nA^O82oibmk`CoV/Gf0_nHco/4oj[B
m@03ojcKn?ngcN[o]lgZ00;o]lgZ00Co^/kYokBefOnd]MWo];GI1?nb[]D2ojjVd003oj>OdOnNV<go
WYS=00;oWYS=0onIT//4oiF=b@?oTH[81?n?R/T3ohn<c0;oSi7A0onEa_P2oiOCo0?oW^;m00?oW^Kl
oj[NnOnZg_T00onZg_T00on[g?WoZm7doj_Am002oj_Am0;oZloc0onYa^h2ojW5kP;oZ<;/1_nX`Nb=
ojO0j`03o`000?nW`>_oYl3[01CoYl3[2?ooool00ol0003oooooooooo`0?ooooo`008_ooool00ol0
003oooooooooo`0_ooooo`CoW;g_0_nJaOH3ojS8l0;oZ];e1?ndb^X2okO=jP;o]K[M1?nd]MT2ok:^
e@03ojRVe?nSWm7oXioA00;oXioA0onNV<d4oiVBb`?oUHg91?nAR/P2ohn:b@;oTJo[1?nC^_82oiG6
n0?oWMcm0_nNh_d3ojWOnP;oZ]ki1?n[e?D2oj_Am0?oZLO_0_nYa^h6ojS2k0;oZ<7/TOnW`>/00ol0
003oYl3[ojO0j`0CojO0j`Wooooo00?o0000ooooooooool03_ooool002?ooooo00?o0000oooooooo
ool0;oooool2oibmk`?oYl3[0_nXb?03ok;6j@?o]<[Z0_ne_^44okFjg@;o];GI00?o[:gHojRVe?nX
Y]@00_nXY]@4oj>Od@?oWYS=0_nIT//01?nDWm_oTZ7Ooi:QgonBXMl5oi6Vi0CoTJo[0_nC^_83oicD
n`;oWMcm0onWg_X2ojWOnP?oZmKf0_n[e?D3oj[9l0?oZLO_0_nX`nd6ojS2k0;oZ<7/T_nW`>/00ol0
003oYl3[ojO0j`0DojO0j`Sooooo00?o0000ooooooooool03_ooool002Cooooo00?o0000oooooooo
ool0;oooool3ojO0j`;o/<;W1Onba^T00ondb^[o]KkQokFnh@02okFnh@;o]K[M00?o[k?Lojb]f?n/
[MP00_n/[MP4ojRVe0;oXioA00CoW:;IoiRPf_nHX=[oV:3J1?nDWm/3oi:Qg`GoTJKT0_nA[n/3oi[;
n0;oW=Ck0onUg?/2ojONnP?oZ]Og0_n[e_H2oj[:l0GoZ/W`00?oZLO_ojS3kOnX`nd00_nX`nd2ojS2
k0KoZ<7/T_nW`>/00ol0003oYl3[ojO0j`0DojO0j`Oooooo00?o0000ooooooooool03_ooool002Go
oooo0_l0000`ooooo`03ojO0jon``^Oo/<;W00;o/<;W0_nba^T3okG1h`?o]KkQ00?o/KWOojncg?n_
/m`00_n_/m`4ojb]f0;oZ:KD00?oXJOJoibRfOnLX]T00_nLX]T3oiRPfPCoU9oK0onBXMl2oi6Vi0Co
VL7c0_nJboP3oj;In`;oYMck0onYf?P2oj[Gm`;oZlca1?nZb_02oj[9l0CoZLC]0_nX`nd8ojS1k9Co
Yl3[00?o0000ojO0jonW`>/05?nW`>/6ooooo`03o`000?oooooooooo00kooooo000Wooooo`03o`00
0?oooooooooo02kooooo0on``^L3okC2i@Co]L7S00Co]KkQok6igona^Moo/KWO1?n_/m`2ojb]f003
ojB/g?nQYm[oXJOJ00;oXJOJ1?nLX]T3oiRPfP;oU9oK0_nG/^X4oiNik`;oVL7c1?nPe?X2oj;In`?o
YmSh0_nYf?P2oj_=lPCoZlca0_nZb_03ojW5kP;oZLC]2OnX`NbHojO0j`03o`000?nW`>_oYl3[01?o
Yl3[1_ooool00ol0003oooooooooo`0>ooooo`00:?ooool00ol0003oooooooooo`0^ooooo`03ok32
iond`^Go]<;U00?o]<;U0_ne`N<2ok:nh`Co/KWO0_n_/m`2ojRag`?oY:cL1?nQYmX2oibRf@03oiZ^
iOnH[nOoV:oW00;oV:oW1?nG/^X2oiNik`CoWLoi0_nPe?X2ojKFn0?oYmSh0_nZc_<4oj_=lP;oZlca
0onYa^h2ojW5kP;oZ<;/1_nX`NbLojO0j`03o`000?nW`>_oYl3[01CoYl3[1Oooool00ol0003ooooo
ooooo`0>ooooo`00:Oooool00ol0003oooooooooo`0_ooooo`;o]<;U0onb`^H4ok:nh`;o/KWO0_n[
]n84ojRag`?oY:cL0_nQYmX2oif_i0?oVZkU1?nH[nL2oiNbjP?oVlWg0_nMcoT3oj?Cn0CoY]Kh00?o
YmShoj[>lonZc_<00_nZc_<2oj_=lP?oZLO_0_nYa^h6ojS2k0;oZ<7/0_nX`>^NojO0j`03o`000?nW
`>_oYl3[01CoYl3[1?ooool00ol0003oooooooooo`0>ooooo`00:_ooool2o`00037ooooo1?nb`^H2
ok:nh`;o[;cU1?n[]n82ojRag`03oj:diOnO/NCoWk7T00;oWk7T1?nM[n@3oiZ^i@;oV:oW0onJ`o@2
oi_9m`;oX/og1OnSdoP2ojKFn0?oZLoc0_nZc_<3oj[8l0;oZLO_0_nX`nd6ojS2k0;oZ<7[1?nX`>^N
ojO0j`03o`000?nW`>_oYl3[01CoYl3[0oooool00ol0003oooooooooo`0>ooooo`00;?ooool00ol0
003oooooooooo`0_ooooo`;o//;V0_n]`NP4ojbli@;oZkOR0_nU^>L3oj:di@CoWk7T0_nM[n@2oi^l
k`CoV[ob0_nJ`o@2oio;mPCoX/og0_nSdoP4ojS>m0;oZLoc0_nYbO03oj[8l0;oZLC]1?nX`nd2ojS2
k0;oZ<7/1?nX`N/2ojS0jj3oYl3[00?o0000ojO0jonW`>/05?nW`>/3ooooo`03o`000?oooooooooo
00gooooo000]ooooo`03o`000?oooooooooo02oooooo1?n]`NP2ojbli@;oY[cY1?nU^>L3oj:di@;o
Wk7T0_nL^nh4oi^lk`;oV[ob0_nNao@4oio;mP;oX/og0onWcO@2ojS>m0?oZL[a1?nYbO000onZb?3o
ZLC]ojW4k@02ojW4k@;oZ<?]1_nX`N`2ojS1jj?oYl3[00?o0000ojO0jonW`>/05?nW`>/3ooooo`03
o`000?oooooooooo00gooooo000^ooooo`03o`000?oooooooooo02oooooo0_n]`NP2ojO0j`CoY[cY
0_nU^>L2oj2lk0?oW[_]1?nL^nh2oi^lk`;oW/Cc1?nNao@2oio;mP?oYLcd0_nWcO@2ojS:l@GoZL[a
0_nYbO05ojW4k@;oZ<;/1_nX`NbWojO0j`03o`000?nW`>_oYl3[01CoYl3[0_ooool00ol0003ooooo
ooooo`0=ooooo`00;oooool00ol0003oooooooooo`0_ooooo`CoYl3[0_nV_>T2oj6mk@CoX;c/0onN
^nd2oibkkP?oW/7a0onNa?<2oik7m0?oXlWd0_nUc?@2ojO9l@CoZ<[a0_nYb_44ojW5kP;oZLC]1_nX
`^`2ojS1k0;oZ<3[ZOnW`>/00ol0003oYl3[ojO0j`0CojO0j`;ooooo00?o0000ooooooooool03Ooo
ool0033ooooo0_l0000`ooooo`;oYl3[0_nR_^d4oj6mk@;oX;c/0_nO_^l4oijol0;oW/7a0_nQaO84
oj;7l`;oXlWd0_nVb?44ojO9l@;oZ<[a0onXaNh2ojW5kPWoZ<;/0_nX`N`4ojS0jjSoYl3[00?o0000
ojO0jonW`>/05?nW`>/00ooooooo0000ooooo`0>ooooo`00<_ooool00ol0003oooooooooo`0^oooo
o`CoX[k]0_nQ_Nd2oj2nkPCoWkk_0_nN_o02oj73l@CoXLGb0_nRao<2ojG6l@CoY/Sa0_nWbO43ojS5
k`;oZ<G^0_nX`nd7ojS2k0KoZ<7/0_nX`>^ZojO0j`03o`000?nW`>_oYl3[01?oYl3[00?oooooo`00
0?ooool03_ooool003?ooooo00?o0000ooooooooool0;_ooool2oj:nk@;oXKk^1?nP_^h2oinnk`;o
X<7`1?nQ`o42oj75lP;oY<Ga1?nUa_42ojK8l@?oYlG_0_nXaNl6ojS3k@;oZ<;/2OnX`Nb^ojO0j`03
o`000?nW`>_oYl3[01?oYl3[00?o0000ooooooooool03Oooool003Cooooo00?o0000ooooooooool0
;_ooool4oj6nkP;oX;k^0_nQ_nl4oj31l0;oXL?a0_nS`o04ojC5l@;oYLKa0onVa>l2ojO5k`SoZ<?]
2?nX`NbcojO0j`03o`000?nW`>_oYl3[017oYl3[00?oooooo`000?ooool03_ooool003Gooooo0_l0
000_ooooo`GoXKk^0onQ_nl2oj31l0?oXl;_0onS`o02ojC5l@GoY/C_0_nW`nd6ojS3k@SoZ<7/]_nW
`>/00ol0003oYl3[ojO0j`0=ojO0j`Kooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000
ooooooooool0;_ooool2oj6nkP;oX[k]1?nR`>h2oj?2k`;oYL7^1?nU`^h2ojK4k`;oYl;]1?nW`nd2
ojS3k@SoZ<7/0_nX`>^hojO0j`03o`000?nW`>_oYl3[00WoYl3[2Oooool00ol0003oooooooooo`0<
ooooo`00>?ooool00ol0003oooooooooo`0^ooooo`CoX[k]0_nR`>h2ojC0k@CoYL7^0_nU`^h2ojK2
k@CoYl;]0_nW`nd2ojO1k0SoZ<7/1?nX`>^hojO0j`03o`000?nW`>_oYl3[00GoYl3[3?ooool00ol0
003oooooooooo`0<ooooo`00>Oooool00ol0003oooooooooo`0^ooooo`;oX[k]0_nT_n`4ojC0k@;o
YL7^0_nV`Nd4ojK2k@;oYl;]1_nW`N`2ojS1k0?oYl7/0onX`N`2ojS0jk[oYl3[00?o0000ojO0jonW
`>/04?ooool00ol0003oooooooooo`0<ooooo`00>_ooool2o`0002oooooo1?nT_n`2ojC0k@;oY/3/
1?nV`Nd2ojK2k@goYl7/`?nW`>/00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo
000looooo`03o`000?oooooooooo02gooooo0_nT_n`2ojFok0CoY/3/0_nV`Nd=ojO1k;ooYl3[1Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo000mooooo`03o`000?oooooo
oooo02gooooo1?nU_n`5ojK0k0[oYl7/_onW`>/9ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03?ooool003kooooo00?o0000ooooooooool0;Oooool2ojFok0?oY[o/0_nV`>`6ojO0
k0;oYl7/^onW`>/@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool003oo
oooo0_l0000_ooooo`;oY[o/0_nW`>/6ojO0k;_oYl3[5?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00_ooooo0011ooooo`03o`000?oooooooooo02gooooo1?nW`>/2ojO0k;_oYl3[
6?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0012ooooo`03o`000?oo
oooooooo02gooooo_?nW`>/Mooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool004?ooooo00?o0000ooooooooool0;OoooonhojO0jb3ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`00A?ooool00ol0003oooooooooo`0]oooookCoYl3[9?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0015ooooo`;o0000;ooooon^ojO0jbWo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`00Aoooool00ol0003ooooo
ooooo`0]oooooj[oYl3[;?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
0018ooooo`03o`000?oooooooooo02goooooY_nW`>/`ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02oooool004Wooooo00?o0000ooooooooool0;OoooonRojO0jcCooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00B_ooool2o`0002koooooWOnW`>/ioooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool004cooooo00?o0000oooooooo
ool0;?oooonIojO0jccooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00
COooool00ol0003oooooooooo`0/oooooi;oYl3[@oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00[ooooo001>ooooo`03o`000?oooooooooo02goooooSOnW`>]7ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02_ooool004oooooo0_l0000^ooooohSoYl3[C?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo001Aooooo`03o`000?oooooooooo
02coooooQ?nW`>]?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool005;o
oooo00?o0000ooooooooool0:ooooon1ojO0je?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0:ooooo`00Doooool00ol0003oooooooooo`0[oooooggoYl3[Eoooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Wooooo001Dooooo`;o0000;OoooomhojO0je[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`00E_ooool00ol0003oooooooooo`0[
ooooogCoYl3[G_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo001Goooo
o`03o`000?oooooooooo02_oooooK?nW`>]Vooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02Oooool005Sooooo00?o0000ooooooooool0;?oooomWojO0jf[ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`00FOooool00ol0003oooooooooo`0/ooooof?oYl3[KOooool01Ol0003o
oooooooooooooooo000000_ooooo001Jooooo`;o0000;OoooomOojO0jg7ooooo00Co0000oooooooo
oooo00002oooool005cooooo00?o0000ooooooooool0:ooooomKojO0jgGooooo00?o0000ooooool0
00002oooool005gooooo00?o0000ooooooooool0:ooooomGojO0jgSooooo00Co0000oooooooooooo
00002_ooool005kooooo00?o0000ooooooooool0:ooooomCojO0jgcooooo00?o0000ooooool00000
2_ooool005oooooo0_l0000/ooooodcoYl3[Poooool2o`0000[ooooo001Qooooo`03o`000?oooooo
oooo02[oooooB?nW`>^5ooooo`?o00002_ooool006;ooooo00?o0000ooooooooool0:ooooom3ojO0
jhCooooo1?l0000=ooooo`00Hoooool00ol0003oooooooooo`0[ooooocooYl3[Poooool4o`00017o
oooo001Tooooo`;o0000;?oooolkojO0jh?ooooo0ol0000Eooooo`00I_ooool00ol0003ooooooooo
o`0[oooooc?oYl3[QOooool4o`0001Sooooo001Wooooo`03o`000?oooooooooo02[ooooo<?nW`>^4
ooooo`Co00007?ooool006Sooooo00?o0000ooooooooool0:_ooool/ojO0jh?ooooo1?l0000Poooo
o`00JOooool2o`0002cooooo9onW`>^2ooooo`Co00009?ooool006_ooooo00?o0000ooooooooool0
:_oooolSojO0jh;ooooo0ol0000Xooooo`00K?ooool00ol0003oooooooooo`0ZoooooagoYl3[Pooo
ool4o`0002_ooooo001]ooooo`03o`000?oooooooooo02_ooooo6?nW`>^2ooooo`Co0000;oooool0
06kooooo00?o0000ooooooooool0:_oooolEojO0jh7ooooo1?l0000cooooo`00Koooool2o`0002_o
oooo4OnW`>^0ooooo`Co0000=oooool0077ooooo00?o0000ooooooooool0:_ooool9ojO0jh;ooooo
1?l0000kooooo`00L_ooool00ol0003oooooooooo`0Zooooo`GoYl3[P_ooool3o`0003oooooo001c
ooooo`03o`000?oooooooooo02[ooooo00?oYl3[ooooooooool0Ooooool4o`0004;ooooo001doooo
o`;o0000:_ooool00ol0003oooooooooo`1kooooo`Co0000A_ooool007Kooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`1hooooo`Co0000B_ooool007Oooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1dooooo`Co0000C_ooool007Sooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1aooooo`?o0000D_ooool007Wooooo0_l0000Tooooo`03o`000?oooooo
oooo06gooooo1?l0001Eooooo`00Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
06Wooooo1?l0001Iooooo`00O?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06Go
oooo1?l0001Mooooo`00OOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo067ooooo
1?l0001Qooooo`00O_ooool2o`0001oooooo00?o0000ooooooooool0GOooool4o`0006Gooooo0020
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0F_ooool3o`0006Wooooo0021oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0E_ooool4o`0006cooooo0022ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0D_ooool4o`00073ooooo0023ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0C_ooool4o`0007Cooooo0024ooooo`;o00006Ooo
ool00ol0003oooooooooo`1:ooooo`Co0000N?ooool008Kooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`16ooooo`Co0000O?ooool008Oooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`13ooooo`?o0000P?ooool008Sooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0oooooo`Co0000Poooool008Wooooo0_l0000Dooooo`03o`000?oooooooooo03_ooooo
1?l00027ooooo`00Roooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Oooooo1?l0
002;ooooo`00S?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03?ooooo1?l0002?
ooooo`00SOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo033ooooo0ol0002Coooo
o`00S_ooool2o`0000oooooo00?o0000ooooooooool0;?ooool4o`0009Kooooo002@ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0:?ooool4o`0009[ooooo002Aooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool09?ooool4o`0009kooooo002Booooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool08Oooool4o`000:;ooooo002Cooooo`;o00002Oooool00ol0
003oooooooooo`0Mooooo`Co0000Y_ooool009Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Jooooo`?o0000Z_ooool009Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Fooooo`Co0000[Oooool009Oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Booooo`Co0000/Oooool009Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>
ooooo`Co0000]Oooool009Wooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo1?l0002ioooo
o`00Voooool01?l0003oooooooooool00009ooooo`?o0000_Oooool009cooooo00?o0000ooooool0
00001Oooool4o`000<3ooooo002Mooooo`;o000000?oooooo`000?l000000_l00034ooooo`00W_oo
ool2o`000<Sooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo002booooo`05oiRHV?l0003o0000odA4
A?nj^[X02Oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Gooooo0_lQ8B6Looooo`00/_ooool01_l@
413o^[Zjonk^k_mgMgOo410@ooooo`Ko00000_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Gooooo
0_lQ8B6Looooo`00/_ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool00000
Xoooool00;;ooooo00?o0000ooooooooool00oooool6o`0000;ooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P2Sooooo`00/_ooool00ol0003oooooooooo`0;ooooo`05olc<c?l0003o0000o`000?o<c<`0
Xoooool00;3ooooo00?o410@o`000?l000000ol0000:ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
Xoooool00;;ooooo00?o0000ooooooooool02oooool01Ol0003o^[Zjoooooonj^[[o00000:?ooooo
002booooo`03o`000?oooooooooo00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2Sooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -17 0 ]
[.5 .82364 17 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8.8) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69467 Mtetra
.4053 .69467 .41061 .69934 .41957 .69681 .41427 .69213 Mtetra
.41427 .69213 .41957 .69681 .42855 .69428 .42327 .68958 Mtetra
.42327 .68958 .42855 .69428 .43756 .69174 .43231 .68703 Mtetra
.43231 .68703 .43756 .69174 .4466 .68919 .44137 .68446 Mtetra
.44137 .68446 .4466 .68919 .45567 .68663 .45046 .68189 Mtetra
.45046 .68189 .45567 .68663 .46478 .68407 .45958 .67931 Mtetra
.45958 .67931 .46478 .68407 .47391 .68149 .46873 .67671 Mtetra
.46873 .67671 .47391 .68149 .48307 .67891 .47792 .67412 Mtetra
.47792 .67412 .48307 .67891 .49227 .67632 .48713 .67151 Mtetra
.48713 .67151 .49227 .67632 .50149 .67371 .49638 .66889 Mtetra
.49638 .66889 .50149 .67371 .51075 .6711 .50565 .66626 Mtetra
.50565 .66626 .51075 .6711 .52004 .66849 .51496 .66363 Mtetra
.51496 .66363 .52004 .66849 .52936 .66586 .5243 .66098 Mtetra
.5243 .66098 .52936 .66586 .53871 .66322 .53367 .65833 Mtetra
.53367 .65833 .53871 .66322 .54809 .66058 .54308 .65567 Mtetra
.54308 .65567 .54809 .66058 .55751 .65792 .55251 .653 Mtetra
.55251 .653 .55751 .65792 .56695 .65526 .56198 .65032 Mtetra
.56198 .65032 .56695 .65526 .57643 .65259 .57148 .64763 Mtetra
.57148 .64763 .57643 .65259 .58595 .6499 .58102 .64493 Mtetra
.58102 .64493 .58595 .6499 .59549 .64721 .59058 .64222 Mtetra
.59058 .64222 .59549 .64721 .60507 .64451 .60018 .6395 Mtetra
.60018 .6395 .60507 .64451 .61468 .6418 .60982 .63678 Mtetra
.60982 .63678 .61468 .6418 .62432 .63908 .61948 .63404 Mtetra
.61948 .63404 .62432 .63908 .634 .63636 .62918 .63129 Mtetra
.62918 .63129 .634 .63636 .64371 .63362 .63892 .62854 Mtetra
.63892 .62854 .64371 .63362 .65345 .63087 .64868 .62577 Mtetra
.64868 .62577 .65345 .63087 .66323 .62811 .65848 .623 Mtetra
.65848 .623 .66323 .62811 .67304 .62535 .66832 .62021 Mtetra
.66832 .62021 .67304 .62535 .68289 .62257 .67819 .61742 Mtetra
.67819 .61742 .68289 .62257 .69277 .61979 .68809 .61462 Mtetra
.68809 .61462 .69277 .61979 .70269 .61699 .69803 .6118 Mtetra
.69803 .6118 .70269 .61699 .71264 .61418 .70801 .60898 Mtetra
.70801 .60898 .71264 .61418 .72262 .61137 .71802 .60615 Mtetra
.71802 .60615 .72262 .61137 .73264 .60854 .72806 .6033 Mtetra
.72806 .6033 .73264 .60854 .7427 .60571 .73814 .60045 Mtetra
.73814 .60045 .7427 .60571 .75279 .60286 .74826 .59759 Mtetra
.74826 .59759 .75279 .60286 .76291 .60001 .75841 .59471 Mtetra
.75841 .59471 .76291 .60001 .77308 .59714 .7686 .59183 Mtetra
.7686 .59183 .77308 .59714 .78328 .59427 .77882 .58893 Mtetra
.77882 .58893 .78328 .59427 .79351 .59138 .78908 .58603 Mtetra
.78908 .58603 .79351 .59138 .80378 .58849 .79938 .58311 Mtetra
.79938 .58311 .80378 .58849 .81409 .58558 .80971 .58019 Mtetra
.80971 .58019 .81409 .58558 .82443 .58267 .82008 .57725 Mtetra
.82008 .57725 .82443 .58267 .83482 .57974 .83049 .57431 Mtetra
.83049 .57431 .83482 .57974 .84523 .5768 .84094 .57135 Mtetra
.84094 .57135 .84523 .5768 .85569 .57385 .85142 .56838 Mtetra
.85142 .56838 .85569 .57385 .86618 .57089 .86194 .5654 Mtetra
.86194 .5654 .86618 .57089 .87672 .56792 .8725 .56241 Mtetra
.8725 .56241 .87672 .56792 .88729 .56494 .8831 .55941 Mtetra
.8831 .55941 .88729 .56494 .89789 .56195 .89374 .5564 Mtetra
.89374 .5564 .89789 .56195 .90854 .55895 .90441 .55338 Mtetra
.90441 .55338 .90854 .55895 .91923 .55594 .91512 .55035 Mtetra
.91512 .55035 .91923 .55594 .92995 .55292 .92588 .5473 Mtetra
.92588 .5473 .92995 .55292 .94071 .54988 .93667 .54425 Mtetra
.93667 .54425 .94071 .54988 .95152 .54684 .9475 .54118 Mtetra
.9475 .54118 .95152 .54684 .96236 .54378 .95837 .53811 Mtetra
.95837 .53811 .96236 .54378 .97324 .54071 .96928 .53502 Mtetra
.96928 .53502 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.391 .69252 .39636 .6972 .4053 .69467 .39996 .68998 Mtetra
.39996 .68998 .4053 .69467 .41427 .69213 .40895 .68742 Mtetra
.40895 .68742 .41427 .69213 .42327 .68958 .41797 .68486 Mtetra
.41797 .68486 .42327 .68958 .43231 .68703 .42702 .68228 Mtetra
.42702 .68228 .43231 .68703 .44137 .68446 .4361 .6797 Mtetra
.4361 .6797 .44137 .68446 .45046 .68189 .44521 .67711 Mtetra
.44521 .67711 .45046 .68189 .45958 .67931 .45435 .67452 Mtetra
.45435 .67452 .45958 .67931 .46873 .67671 .46352 .67191 Mtetra
.46352 .67191 .46873 .67671 .47792 .67412 .47273 .66929 Mtetra
.47273 .66929 .47792 .67412 .48713 .67151 .48196 .66667 Mtetra
.48196 .66667 .48713 .67151 .49638 .66889 .49123 .66403 Mtetra
.49123 .66403 .49638 .66889 .50565 .66626 .50053 .66139 Mtetra
.50053 .66139 .50565 .66626 .51496 .66363 .50985 .65874 Mtetra
.50985 .65874 .51496 .66363 .5243 .66098 .51922 .65608 Mtetra
.51922 .65608 .5243 .66098 .53367 .65833 .52861 .65341 Mtetra
.52861 .65341 .53367 .65833 .54308 .65567 .53803 .65073 Mtetra
.53803 .65073 .54308 .65567 .55251 .653 .54749 .64804 Mtetra
.54749 .64804 .55251 .653 .56198 .65032 .55698 .64534 Mtetra
.55698 .64534 .56198 .65032 .57148 .64763 .5665 .64264 Mtetra
.5665 .64264 .57148 .64763 .58102 .64493 .57606 .63992 Mtetra
.57606 .63992 .58102 .64493 .59058 .64222 .58565 .6372 Mtetra
.58565 .6372 .59058 .64222 .60018 .6395 .59527 .63446 Mtetra
.59527 .63446 .60018 .6395 .60982 .63678 .60493 .63172 Mtetra
.60493 .63172 .60982 .63678 .61948 .63404 .61461 .62896 Mtetra
.61461 .62896 .61948 .63404 .62918 .63129 .62434 .6262 Mtetra
.62434 .6262 .62918 .63129 .63892 .62854 .63409 .62343 Mtetra
.63409 .62343 .63892 .62854 .64868 .62577 .64388 .62064 Mtetra
.64388 .62064 .64868 .62577 .65848 .623 .65371 .61785 Mtetra
.65371 .61785 .65848 .623 .66832 .62021 .66357 .61505 Mtetra
.66357 .61505 .66832 .62021 .67819 .61742 .67346 .61224 Mtetra
.67346 .61224 .67819 .61742 .68809 .61462 .68339 .60942 Mtetra
.68339 .60942 .68809 .61462 .69803 .6118 .69335 .60658 Mtetra
.69335 .60658 .69803 .6118 .70801 .60898 .70335 .60374 Mtetra
.70335 .60374 .70801 .60898 .71802 .60615 .71338 .60089 Mtetra
.71338 .60089 .71802 .60615 .72806 .6033 .72345 .59803 Mtetra
.72345 .59803 .72806 .6033 .73814 .60045 .73356 .59516 Mtetra
.73356 .59516 .73814 .60045 .74826 .59759 .7437 .59227 Mtetra
.7437 .59227 .74826 .59759 .75841 .59471 .75387 .58938 Mtetra
.75387 .58938 .75841 .59471 .7686 .59183 .76409 .58648 Mtetra
.76409 .58648 .7686 .59183 .77882 .58893 .77434 .58356 Mtetra
.77434 .58356 .77882 .58893 .78908 .58603 .78462 .58064 Mtetra
.78462 .58064 .78908 .58603 .79938 .58311 .79495 .57771 Mtetra
.79495 .57771 .79938 .58311 .80971 .58019 .80531 .57476 Mtetra
.80531 .57476 .80971 .58019 .82008 .57725 .81571 .57181 Mtetra
.81571 .57181 .82008 .57725 .83049 .57431 .82614 .56884 Mtetra
.82614 .56884 .83049 .57431 .84094 .57135 .83661 .56586 Mtetra
.83661 .56586 .84094 .57135 .85142 .56838 .84712 .56288 Mtetra
.84712 .56288 .85142 .56838 .86194 .5654 .85767 .55988 Mtetra
.85767 .55988 .86194 .5654 .8725 .56241 .86826 .55687 Mtetra
.86826 .55687 .8725 .56241 .8831 .55941 .87889 .55385 Mtetra
.87889 .55385 .8831 .55941 .89374 .5564 .88955 .55082 Mtetra
.88955 .55082 .89374 .5564 .90441 .55338 .90025 .54777 Mtetra
.90025 .54777 .90441 .55338 .91512 .55035 .911 .54472 Mtetra
.911 .54472 .91512 .55035 .92588 .5473 .92178 .54166 Mtetra
.92178 .54166 .92588 .5473 .93667 .54425 .9326 .53858 Mtetra
.9326 .53858 .93667 .54425 .9475 .54118 .94346 .53549 Mtetra
.94346 .53549 .9475 .54118 .95837 .53811 .95436 .53239 Mtetra
.95436 .53239 .95837 .53811 .96928 .53502 .9653 .52928 Mtetra
.9653 .52928 .96928 .53502 .98024 .53192 .97628 .52616 Mtetra
.38561 .68781 .391 .69252 .39996 .68998 .39459 .68525 Mtetra
.39459 .68525 .39996 .68998 .40895 .68742 .40359 .68268 Mtetra
.40359 .68268 .40895 .68742 .41797 .68486 .41263 .6801 Mtetra
.41263 .6801 .41797 .68486 .42702 .68228 .4217 .67751 Mtetra
.4217 .67751 .42702 .68228 .4361 .6797 .4308 .67492 Mtetra
.4308 .67492 .4361 .6797 .44521 .67711 .43993 .67231 Mtetra
.43993 .67231 .44521 .67711 .45435 .67452 .44909 .6697 Mtetra
.44909 .6697 .45435 .67452 .46352 .67191 .45828 .66707 Mtetra
.45828 .66707 .46352 .67191 .47273 .66929 .46751 .66444 Mtetra
.46751 .66444 .47273 .66929 .48196 .66667 .47676 .6618 Mtetra
.47676 .6618 .48196 .66667 .49123 .66403 .48605 .65915 Mtetra
.48605 .65915 .49123 .66403 .50053 .66139 .49537 .65649 Mtetra
.49537 .65649 .50053 .66139 .50985 .65874 .50472 .65382 Mtetra
.50472 .65382 .50985 .65874 .51922 .65608 .5141 .65114 Mtetra
.5141 .65114 .51922 .65608 .52861 .65341 .52351 .64846 Mtetra
.52351 .64846 .52861 .65341 .53803 .65073 .53296 .64576 Mtetra
.53296 .64576 .53803 .65073 .54749 .64804 .54244 .64305 Mtetra
.54244 .64305 .54749 .64804 .55698 .64534 .55195 .64034 Mtetra
.55195 .64034 .55698 .64534 .5665 .64264 .56149 .63762 Mtetra
.56149 .63762 .5665 .64264 .57606 .63992 .57107 .63488 Mtetra
.57107 .63488 .57606 .63992 .58565 .6372 .58068 .63214 Mtetra
.58068 .63214 .58565 .6372 .59527 .63446 .59032 .62939 Mtetra
.59032 .62939 .59527 .63446 .60493 .63172 .6 .62663 Mtetra
.6 .62663 .60493 .63172 .61461 .62896 .60971 .62385 Mtetra
.60971 .62385 .61461 .62896 .62434 .6262 .61946 .62107 Mtetra
.61946 .62107 .62434 .6262 .63409 .62343 .62924 .61828 Mtetra
.62924 .61828 .63409 .62343 .64388 .62064 .63905 .61548 Mtetra
.63905 .61548 .64388 .62064 .65371 .61785 .6489 .61267 Mtetra
.6489 .61267 .65371 .61785 .66357 .61505 .65878 .60985 Mtetra
.65878 .60985 .66357 .61505 .67346 .61224 .6687 .60702 Mtetra
.6687 .60702 .67346 .61224 .68339 .60942 .67865 .60418 Mtetra
.67865 .60418 .68339 .60942 .69335 .60658 .68864 .60133 Mtetra
.68864 .60133 .69335 .60658 .70335 .60374 .69866 .59847 Mtetra
.69866 .59847 .70335 .60374 .71338 .60089 .70872 .5956 Mtetra
.70872 .5956 .71338 .60089 .72345 .59803 .71881 .59272 Mtetra
.71881 .59272 .72345 .59803 .73356 .59516 .72894 .58983 Mtetra
.72894 .58983 .73356 .59516 .7437 .59227 .73911 .58692 Mtetra
.73911 .58692 .7437 .59227 .75387 .58938 .74931 .58401 Mtetra
.74931 .58401 .75387 .58938 .76409 .58648 .75955 .58109 Mtetra
.75955 .58109 .76409 .58648 .77434 .58356 .76982 .57816 Mtetra
.76982 .57816 .77434 .58356 .78462 .58064 .78014 .57521 Mtetra
.78014 .57521 .78462 .58064 .79495 .57771 .79049 .57226 Mtetra
.79049 .57226 .79495 .57771 .80531 .57476 .80087 .5693 Mtetra
.80087 .5693 .80531 .57476 .81571 .57181 .8113 .56632 Mtetra
.8113 .56632 .81571 .57181 .82614 .56884 .82176 .56334 Mtetra
.82176 .56334 .82614 .56884 .83661 .56586 .83226 .56034 Mtetra
.83226 .56034 .83661 .56586 .84712 .56288 .8428 .55733 Mtetra
.8428 .55733 .84712 .56288 .85767 .55988 .85337 .55431 Mtetra
.85337 .55431 .85767 .55988 .86826 .55687 .86399 .55128 Mtetra
.86399 .55128 .86826 .55687 .87889 .55385 .87464 .54824 Mtetra
.87464 .54824 .87889 .55385 .88955 .55082 .88533 .54519 Mtetra
.88533 .54519 .88955 .55082 .90025 .54777 .89607 .54213 Mtetra
.89607 .54213 .90025 .54777 .911 .54472 .90684 .53905 Mtetra
.90684 .53905 .911 .54472 .92178 .54166 .91765 .53597 Mtetra
.91765 .53597 .92178 .54166 .9326 .53858 .9285 .53287 Mtetra
.9285 .53287 .9326 .53858 .94346 .53549 .93939 .52976 Mtetra
.93939 .52976 .94346 .53549 .95436 .53239 .95032 .52664 Mtetra
.95032 .52664 .95436 .53239 .9653 .52928 .96129 .52351 Mtetra
.96129 .52351 .9653 .52928 .97628 .52616 .9723 .52037 Mtetra
.38018 .68308 .38561 .68781 .39459 .68525 .38918 .6805 Mtetra
.38918 .6805 .39459 .68525 .40359 .68268 .3982 .67791 Mtetra
.3982 .67791 .40359 .68268 .41263 .6801 .40726 .67532 Mtetra
.40726 .67532 .41263 .6801 .4217 .67751 .41635 .67271 Mtetra
.41635 .67271 .4217 .67751 .4308 .67492 .42547 .6701 Mtetra
.42547 .6701 .4308 .67492 .43993 .67231 .43462 .66748 Mtetra
.43462 .66748 .43993 .67231 .44909 .6697 .4438 .66485 Mtetra
.4438 .66485 .44909 .6697 .45828 .66707 .45301 .66221 Mtetra
.45301 .66221 .45828 .66707 .46751 .66444 .46225 .65956 Mtetra
.46225 .65956 .46751 .66444 .47676 .6618 .47153 .6569 Mtetra
.47153 .6569 .47676 .6618 .48605 .65915 .48083 .65423 Mtetra
.48083 .65423 .48605 .65915 .49537 .65649 .49017 .65156 Mtetra
.49017 .65156 .49537 .65649 .50472 .65382 .49954 .64887 Mtetra
.49954 .64887 .50472 .65382 .5141 .65114 .50895 .64618 Mtetra
.50895 .64618 .5141 .65114 .52351 .64846 .51838 .64347 Mtetra
.51838 .64347 .52351 .64846 .53296 .64576 .52785 .64076 Mtetra
.52785 .64076 .53296 .64576 .54244 .64305 .53735 .63804 Mtetra
.53735 .63804 .54244 .64305 .55195 .64034 .54688 .6353 Mtetra
.54688 .6353 .55195 .64034 .56149 .63762 .55645 .63256 Mtetra
.55645 .63256 .56149 .63762 .57107 .63488 .56605 .62981 Mtetra
.56605 .62981 .57107 .63488 .58068 .63214 .57568 .62705 Mtetra
.57568 .62705 .58068 .63214 .59032 .62939 .58535 .62428 Mtetra
.58535 .62428 .59032 .62939 .6 .62663 .59505 .6215 Mtetra
.59505 .6215 .6 .62663 .60971 .62385 .60478 .61871 Mtetra
.60478 .61871 .60971 .62385 .61946 .62107 .61455 .61591 Mtetra
.61455 .61591 .61946 .62107 .62924 .61828 .62435 .6131 Mtetra
.62435 .6131 .62924 .61828 .63905 .61548 .63419 .61028 Mtetra
.63419 .61028 .63905 .61548 .6489 .61267 .64406 .60746 Mtetra
.64406 .60746 .6489 .61267 .65878 .60985 .65396 .60462 Mtetra
.65396 .60462 .65878 .60985 .6687 .60702 .66391 .60177 Mtetra
.66391 .60177 .6687 .60702 .67865 .60418 .67388 .59891 Mtetra
.67388 .59891 .67865 .60418 .68864 .60133 .68389 .59604 Mtetra
.68389 .59604 .68864 .60133 .69866 .59847 .69394 .59316 Mtetra
.69394 .59316 .69866 .59847 .70872 .5956 .70402 .59027 Mtetra
.70402 .59027 .70872 .5956 .71881 .59272 .71414 .58737 Mtetra
.71414 .58737 .71881 .59272 .72894 .58983 .7243 .58446 Mtetra
.7243 .58446 .72894 .58983 .73911 .58692 .73449 .58154 Mtetra
.73449 .58154 .73911 .58692 .74931 .58401 .74472 .57861 Mtetra
.74472 .57861 .74931 .58401 .75955 .58109 .75498 .57567 Mtetra
.75498 .57567 .75955 .58109 .76982 .57816 .76528 .57272 Mtetra
.76528 .57272 .76982 .57816 .78014 .57521 .77562 .56975 Mtetra
.77562 .56975 .78014 .57521 .79049 .57226 .786 .56678 Mtetra
.786 .56678 .79049 .57226 .80087 .5693 .79641 .5638 Mtetra
.79641 .5638 .80087 .5693 .8113 .56632 .80686 .5608 Mtetra
.80686 .5608 .8113 .56632 .82176 .56334 .81735 .55779 Mtetra
.81735 .55779 .82176 .56334 .83226 .56034 .82788 .55478 Mtetra
.82788 .55478 .83226 .56034 .8428 .55733 .83844 .55175 Mtetra
.83844 .55175 .8428 .55733 .85337 .55431 .84905 .54871 Mtetra
.84905 .54871 .85337 .55431 .86399 .55128 .85969 .54566 Mtetra
.85969 .54566 .86399 .55128 .87464 .54824 .87037 .5426 Mtetra
.87037 .5426 .87464 .54824 .88533 .54519 .88109 .53953 Mtetra
.88109 .53953 .88533 .54519 .89607 .54213 .89185 .53644 Mtetra
.89185 .53644 .89607 .54213 .90684 .53905 .90265 .53335 Mtetra
.90265 .53335 .90684 .53905 .91765 .53597 .91349 .53024 Mtetra
.91349 .53024 .91765 .53597 .9285 .53287 .92437 .52712 Mtetra
.92437 .52712 .9285 .53287 .93939 .52976 .93529 .524 Mtetra
.93529 .524 .93939 .52976 .95032 .52664 .94625 .52085 Mtetra
.94625 .52085 .95032 .52664 .96129 .52351 .95725 .5177 Mtetra
.95725 .5177 .96129 .52351 .9723 .52037 .96829 .51454 Mtetra
.37472 .67831 .38018 .68308 .38918 .6805 .38373 .67572 Mtetra
.38373 .67572 .38918 .6805 .3982 .67791 .39278 .67311 Mtetra
.39278 .67311 .3982 .67791 .40726 .67532 .40186 .6705 Mtetra
.40186 .6705 .40726 .67532 .41635 .67271 .41096 .66788 Mtetra
.41096 .66788 .41635 .67271 .42547 .6701 .4201 .66525 Mtetra
.4201 .66525 .42547 .6701 .43462 .66748 .42927 .66261 Mtetra
.42927 .66261 .43462 .66748 .4438 .66485 .43847 .65996 Mtetra
.43847 .65996 .4438 .66485 .45301 .66221 .4477 .65731 Mtetra
.4477 .65731 .45301 .66221 .46225 .65956 .45697 .65464 Mtetra
.45697 .65464 .46225 .65956 .47153 .6569 .46626 .65197 Mtetra
.46626 .65197 .47153 .6569 .48083 .65423 .47559 .64928 Mtetra
.47559 .64928 .48083 .65423 .49017 .65156 .48495 .64659 Mtetra
.48495 .64659 .49017 .65156 .49954 .64887 .49434 .64389 Mtetra
.49434 .64389 .49954 .64887 .50895 .64618 .50376 .64118 Mtetra
.50376 .64118 .50895 .64618 .51838 .64347 .51322 .63846 Mtetra
.51322 .63846 .51838 .64347 .52785 .64076 .52271 .63572 Mtetra
.52271 .63572 .52785 .64076 .53735 .63804 .53223 .63298 Mtetra
.53223 .63298 .53735 .63804 .54688 .6353 .54178 .63024 Mtetra
.54178 .63024 .54688 .6353 .55645 .63256 .55137 .62748 Mtetra
.55137 .62748 .55645 .63256 .56605 .62981 .56099 .62471 Mtetra
.56099 .62471 .56605 .62981 .57568 .62705 .57065 .62193 Mtetra
.57065 .62193 .57568 .62705 .58535 .62428 .58034 .61914 Mtetra
.58034 .61914 .58535 .62428 .59505 .6215 .59006 .61634 Mtetra
.59006 .61634 .59505 .6215 .60478 .61871 .59982 .61354 Mtetra
.59982 .61354 .60478 .61871 .61455 .61591 .60961 .61072 Mtetra
.60961 .61072 .61455 .61591 .62435 .6131 .61943 .60789 Mtetra
.61943 .60789 .62435 .6131 .63419 .61028 .62929 .60505 Mtetra
.62929 .60505 .63419 .61028 .64406 .60746 .63919 .60221 Mtetra
.63919 .60221 .64406 .60746 .65396 .60462 .64912 .59935 Mtetra
.64912 .59935 .65396 .60462 .66391 .60177 .65908 .59648 Mtetra
.65908 .59648 .66391 .60177 .67388 .59891 .66908 .5936 Mtetra
.66908 .5936 .67388 .59891 .68389 .59604 .67912 .59072 Mtetra
.67912 .59072 .68389 .59604 .69394 .59316 .68919 .58782 Mtetra
.68919 .58782 .69394 .59316 .70402 .59027 .6993 .58491 Mtetra
.6993 .58491 .70402 .59027 .71414 .58737 .70944 .58199 Mtetra
.70944 .58199 .71414 .58737 .7243 .58446 .71962 .57906 Mtetra
.71962 .57906 .7243 .58446 .73449 .58154 .72984 .57612 Mtetra
.72984 .57612 .73449 .58154 .74472 .57861 .74009 .57317 Mtetra
.74009 .57317 .74472 .57861 .75498 .57567 .75038 .57021 Mtetra
.75038 .57021 .75498 .57567 .76528 .57272 .76071 .56724 Mtetra
.76071 .56724 .76528 .57272 .77562 .56975 .77107 .56426 Mtetra
.77107 .56426 .77562 .56975 .786 .56678 .78148 .56126 Mtetra
.78148 .56126 .786 .56678 .79641 .5638 .79192 .55826 Mtetra
.79192 .55826 .79641 .5638 .80686 .5608 .80239 .55524 Mtetra
.80239 .55524 .80686 .5608 .81735 .55779 .81291 .55222 Mtetra
.81291 .55222 .81735 .55779 .82788 .55478 .82346 .54918 Mtetra
.82346 .54918 .82788 .55478 .83844 .55175 .83406 .54613 Mtetra
.83406 .54613 .83844 .55175 .84905 .54871 .84469 .54307 Mtetra
.84469 .54307 .84905 .54871 .85969 .54566 .85536 .54 Mtetra
.85536 .54 .85969 .54566 .87037 .5426 .86607 .53692 Mtetra
.86607 .53692 .87037 .5426 .88109 .53953 .87682 .53383 Mtetra
.87682 .53383 .88109 .53953 .89185 .53644 .88761 .53072 Mtetra
.88761 .53072 .89185 .53644 .90265 .53335 .89844 .52761 Mtetra
.89844 .52761 .90265 .53335 .91349 .53024 .90931 .52448 Mtetra
.90931 .52448 .91349 .53024 .92437 .52712 .92022 .52134 Mtetra
.92022 .52134 .92437 .52712 .93529 .524 .93116 .51819 Mtetra
.93116 .51819 .93529 .524 .94625 .52085 .94216 .51503 Mtetra
.94216 .51503 .94625 .52085 .95725 .5177 .95319 .51185 Mtetra
.95319 .51185 .95725 .5177 .96829 .51454 .96426 .50866 Mtetra
.36922 .67351 .37472 .67831 .38373 .67572 .37826 .6709 Mtetra
.37826 .6709 .38373 .67572 .39278 .67311 .38732 .66828 Mtetra
.38732 .66828 .39278 .67311 .40186 .6705 .39642 .66566 Mtetra
.39642 .66566 .40186 .6705 .41096 .66788 .40554 .66302 Mtetra
.40554 .66302 .41096 .66788 .4201 .66525 .4147 .66037 Mtetra
.4147 .66037 .4201 .66525 .42927 .66261 .42389 .65772 Mtetra
.42389 .65772 .42927 .66261 .43847 .65996 .43311 .65505 Mtetra
.43311 .65505 .43847 .65996 .4477 .65731 .44236 .65238 Mtetra
.44236 .65238 .4477 .65731 .45697 .65464 .45165 .6497 Mtetra
.45165 .6497 .45697 .65464 .46626 .65197 .46096 .64701 Mtetra
.46096 .64701 .46626 .65197 .47559 .64928 .47031 .6443 Mtetra
.47031 .6443 .47559 .64928 .48495 .64659 .47969 .64159 Mtetra
.47969 .64159 .48495 .64659 .49434 .64389 .4891 .63887 Mtetra
.4891 .63887 .49434 .64389 .50376 .64118 .49855 .63615 Mtetra
.49855 .63615 .50376 .64118 .51322 .63846 .50802 .63341 Mtetra
.50802 .63341 .51322 .63846 .52271 .63572 .51753 .63066 Mtetra
.51753 .63066 .52271 .63572 .53223 .63298 .52708 .6279 Mtetra
.52708 .6279 .53223 .63298 .54178 .63024 .53665 .62513 Mtetra
.53665 .62513 .54178 .63024 .55137 .62748 .54626 .62236 Mtetra
.54626 .62236 .55137 .62748 .56099 .62471 .55591 .61957 Mtetra
.55591 .61957 .56099 .62471 .57065 .62193 .56558 .61677 Mtetra
.56558 .61677 .57065 .62193 .58034 .61914 .57529 .61397 Mtetra
.57529 .61397 .58034 .61914 .59006 .61634 .58504 .61115 Mtetra
.58504 .61115 .59006 .61634 .59982 .61354 .59482 .60833 Mtetra
.59482 .60833 .59982 .61354 .60961 .61072 .60463 .60549 Mtetra
.60463 .60549 .60961 .61072 .61943 .60789 .61448 .60265 Mtetra
.61448 .60265 .61943 .60789 .62929 .60505 .62437 .59979 Mtetra
.62437 .59979 .62929 .60505 .63919 .60221 .63428 .59692 Mtetra
.63428 .59692 .63919 .60221 .64912 .59935 .64424 .59405 Mtetra
.64424 .59405 .64912 .59935 .65908 .59648 .65423 .59116 Mtetra
.65423 .59116 .65908 .59648 .66908 .5936 .66425 .58826 Mtetra
.66425 .58826 .66908 .5936 .67912 .59072 .67431 .58536 Mtetra
.67431 .58536 .67912 .59072 .68919 .58782 .68441 .58244 Mtetra
.68441 .58244 .68919 .58782 .6993 .58491 .69454 .57951 Mtetra
.69454 .57951 .6993 .58491 .70944 .58199 .70471 .57657 Mtetra
.70471 .57657 .70944 .58199 .71962 .57906 .71491 .57363 Mtetra
.71491 .57363 .71962 .57906 .72984 .57612 .72516 .57067 Mtetra
.72516 .57067 .72984 .57612 .74009 .57317 .73544 .5677 Mtetra
.73544 .5677 .74009 .57317 .75038 .57021 .74575 .56471 Mtetra
.74575 .56471 .75038 .57021 .76071 .56724 .75611 .56172 Mtetra
.75611 .56172 .76071 .56724 .77107 .56426 .7665 .55872 Mtetra
.7665 .55872 .77107 .56426 .78148 .56126 .77693 .55571 Mtetra
.77693 .55571 .78148 .56126 .79192 .55826 .78739 .55268 Mtetra
.78739 .55268 .79192 .55826 .80239 .55524 .7979 .54965 Mtetra
.7979 .54965 .80239 .55524 .81291 .55222 .80844 .5466 Mtetra
.80844 .5466 .81291 .55222 .82346 .54918 .81902 .54354 Mtetra
.81902 .54354 .82346 .54918 .83406 .54613 .82964 .54047 Mtetra
.82964 .54047 .83406 .54613 .84469 .54307 .8403 .53739 Mtetra
.8403 .53739 .84469 .54307 .85536 .54 .851 .5343 Mtetra
.851 .5343 .85536 .54 .86607 .53692 .86174 .5312 Mtetra
.86174 .5312 .86607 .53692 .87682 .53383 .87252 .52809 Mtetra
.87252 .52809 .87682 .53383 .88761 .53072 .88334 .52496 Mtetra
.88334 .52496 .88761 .53072 .89844 .52761 .89419 .52182 Mtetra
.89419 .52182 .89844 .52761 .90931 .52448 .90509 .51867 Mtetra
.90509 .51867 .90931 .52448 .92022 .52134 .91603 .51551 Mtetra
.91603 .51551 .92022 .52134 .93116 .51819 .92701 .51234 Mtetra
.92701 .51234 .93116 .51819 .94216 .51503 .93803 .50916 Mtetra
.93803 .50916 .94216 .51503 .95319 .51185 .94909 .50596 Mtetra
.94909 .50596 .95319 .51185 .96426 .50866 .9602 .50275 Mtetra
.36369 .66869 .36922 .67351 .37826 .6709 .37275 .66606 Mtetra
.37275 .66606 .37826 .6709 .38732 .66828 .38183 .66342 Mtetra
.38183 .66342 .38732 .66828 .39642 .66566 .39094 .66078 Mtetra
.39094 .66078 .39642 .66566 .40554 .66302 .40009 .65813 Mtetra
.40009 .65813 .40554 .66302 .4147 .66037 .40927 .65546 Mtetra
.40927 .65546 .4147 .66037 .42389 .65772 .41848 .65279 Mtetra
.41848 .65279 .42389 .65772 .43311 .65505 .42772 .65011 Mtetra
.42772 .65011 .43311 .65505 .44236 .65238 .43699 .64742 Mtetra
.43699 .64742 .44236 .65238 .45165 .6497 .44629 .64472 Mtetra
.44629 .64472 .45165 .6497 .46096 .64701 .45563 .64201 Mtetra
.45563 .64201 .46096 .64701 .47031 .6443 .465 .63929 Mtetra
.465 .63929 .47031 .6443 .47969 .64159 .4744 .63657 Mtetra
.4744 .63657 .47969 .64159 .4891 .63887 .48383 .63383 Mtetra
.48383 .63383 .4891 .63887 .49855 .63615 .4933 .63108 Mtetra
.4933 .63108 .49855 .63615 .50802 .63341 .50279 .62833 Mtetra
.50279 .62833 .50802 .63341 .51753 .63066 .51233 .62556 Mtetra
.51233 .62556 .51753 .63066 .52708 .6279 .52189 .62279 Mtetra
.52189 .62279 .52708 .6279 .53665 .62513 .53149 .62 Mtetra
.53149 .62 .53665 .62513 .54626 .62236 .54112 .61721 Mtetra
.54112 .61721 .54626 .62236 .55591 .61957 .55079 .6144 Mtetra
.55079 .6144 .55591 .61957 .56558 .61677 .56049 .61159 Mtetra
.56049 .61159 .56558 .61677 .57529 .61397 .57022 .60876 Mtetra
.57022 .60876 .57529 .61397 .58504 .61115 .57999 .60593 Mtetra
.57999 .60593 .58504 .61115 .59482 .60833 .58979 .60308 Mtetra
.58979 .60308 .59482 .60833 .60463 .60549 .59963 .60023 Mtetra
.59963 .60023 .60463 .60549 .61448 .60265 .6095 .59737 Mtetra
.6095 .59737 .61448 .60265 .62437 .59979 .61941 .59449 Mtetra
.61941 .59449 .62437 .59979 .63428 .59692 .62935 .59161 Mtetra
.62935 .59161 .63428 .59692 .64424 .59405 .63933 .58871 Mtetra
.63933 .58871 .64424 .59405 .65423 .59116 .64934 .58581 Mtetra
.64934 .58581 .65423 .59116 .66425 .58826 .65939 .58289 Mtetra
.65939 .58289 .66425 .58826 .67431 .58536 .66947 .57996 Mtetra
.66947 .57996 .67431 .58536 .68441 .58244 .67959 .57703 Mtetra
.67959 .57703 .68441 .58244 .69454 .57951 .68975 .57408 Mtetra
.68975 .57408 .69454 .57951 .70471 .57657 .69995 .57112 Mtetra
.69995 .57112 .70471 .57657 .71491 .57363 .71018 .56815 Mtetra
.71018 .56815 .71491 .57363 .72516 .57067 .72044 .56517 Mtetra
.72044 .56517 .72516 .57067 .73544 .5677 .73075 .56218 Mtetra
.73075 .56218 .73544 .5677 .74575 .56471 .74109 .55918 Mtetra
.74109 .55918 .74575 .56471 .75611 .56172 .75147 .55617 Mtetra
.75147 .55617 .75611 .56172 .7665 .55872 .76189 .55315 Mtetra
.76189 .55315 .7665 .55872 .77693 .55571 .77234 .55012 Mtetra
.77234 .55012 .77693 .55571 .78739 .55268 .78284 .54707 Mtetra
.78284 .54707 .78739 .55268 .7979 .54965 .79337 .54401 Mtetra
.79337 .54401 .7979 .54965 .80844 .5466 .80394 .54095 Mtetra
.80394 .54095 .80844 .5466 .81902 .54354 .81455 .53787 Mtetra
.81455 .53787 .81902 .54354 .82964 .54047 .8252 .53478 Mtetra
.8252 .53478 .82964 .54047 .8403 .53739 .83589 .53168 Mtetra
.83589 .53168 .8403 .53739 .851 .5343 .84661 .52857 Mtetra
.84661 .52857 .851 .5343 .86174 .5312 .85738 .52544 Mtetra
.85738 .52544 .86174 .5312 .87252 .52809 .86819 .52231 Mtetra
.86819 .52231 .87252 .52809 .88334 .52496 .87903 .51916 Mtetra
.87903 .51916 .88334 .52496 .89419 .52182 .88992 .516 Mtetra
.88992 .516 .89419 .52182 .90509 .51867 .90085 .51283 Mtetra
.90085 .51283 .90509 .51867 .91603 .51551 .91182 .50965 Mtetra
.91182 .50965 .91603 .51551 .92701 .51234 .92283 .50645 Mtetra
.92283 .50645 .92701 .51234 .93803 .50916 .93388 .50324 Mtetra
.93388 .50324 .93803 .50916 .94909 .50596 .94497 .50003 Mtetra
.94497 .50003 .94909 .50596 .9602 .50275 .9561 .4968 Mtetra
.35813 .66383 .36369 .66869 .37275 .66606 .3672 .66119 Mtetra
.3672 .66119 .37275 .66606 .38183 .66342 .3763 .65854 Mtetra
.3763 .65854 .38183 .66342 .39094 .66078 .38544 .65587 Mtetra
.38544 .65587 .39094 .66078 .40009 .65813 .3946 .6532 Mtetra
.3946 .6532 .40009 .65813 .40927 .65546 .4038 .65052 Mtetra
.4038 .65052 .40927 .65546 .41848 .65279 .41303 .64783 Mtetra
.41303 .64783 .41848 .65279 .42772 .65011 .42229 .64514 Mtetra
.42229 .64514 .42772 .65011 .43699 .64742 .43158 .64243 Mtetra
.43158 .64243 .43699 .64742 .44629 .64472 .4409 .63971 Mtetra
.4409 .63971 .44629 .64472 .45563 .64201 .45026 .63699 Mtetra
.45026 .63699 .45563 .64201 .465 .63929 .45965 .63425 Mtetra
.45965 .63425 .465 .63929 .4744 .63657 .46907 .63151 Mtetra
.46907 .63151 .4744 .63657 .48383 .63383 .47853 .62875 Mtetra
.47853 .62875 .48383 .63383 .4933 .63108 .48801 .62599 Mtetra
.48801 .62599 .4933 .63108 .50279 .62833 .49753 .62321 Mtetra
.49753 .62321 .50279 .62833 .51233 .62556 .50709 .62043 Mtetra
.50709 .62043 .51233 .62556 .52189 .62279 .51667 .61764 Mtetra
.51667 .61764 .52189 .62279 .53149 .62 .52629 .61483 Mtetra
.52629 .61483 .53149 .62 .54112 .61721 .53595 .61202 Mtetra
.53595 .61202 .54112 .61721 .55079 .6144 .54563 .6092 Mtetra
.54563 .6092 .55079 .6144 .56049 .61159 .55536 .60636 Mtetra
.55536 .60636 .56049 .61159 .57022 .60876 .56511 .60352 Mtetra
.56511 .60352 .57022 .60876 .57999 .60593 .5749 .60067 Mtetra
.5749 .60067 .57999 .60593 .58979 .60308 .58473 .59781 Mtetra
.58473 .59781 .58979 .60308 .59963 .60023 .59459 .59493 Mtetra
.59459 .59493 .59963 .60023 .6095 .59737 .60448 .59205 Mtetra
.60448 .59205 .6095 .59737 .61941 .59449 .61441 .58916 Mtetra
.61441 .58916 .61941 .59449 .62935 .59161 .62438 .58625 Mtetra
.62438 .58625 .62935 .59161 .63933 .58871 .63438 .58334 Mtetra
.63438 .58334 .63933 .58871 .64934 .58581 .64442 .58041 Mtetra
.64442 .58041 .64934 .58581 .65939 .58289 .65449 .57748 Mtetra
.65449 .57748 .65939 .58289 .66947 .57996 .6646 .57453 Mtetra
.6646 .57453 .66947 .57996 .67959 .57703 .67475 .57158 Mtetra
.67475 .57158 .67959 .57703 .68975 .57408 .68493 .56861 Mtetra
.68493 .56861 .68975 .57408 .69995 .57112 .69515 .56563 Mtetra
.69515 .56563 .69995 .57112 .71018 .56815 .70541 .56264 Mtetra
.70541 .56264 .71018 .56815 .72044 .56517 .7157 .55965 Mtetra
.7157 .55965 .72044 .56517 .73075 .56218 .72603 .55664 Mtetra
.72603 .55664 .73075 .56218 .74109 .55918 .7364 .55361 Mtetra
.7364 .55361 .74109 .55918 .75147 .55617 .7468 .55058 Mtetra
.7468 .55058 .75147 .55617 .76189 .55315 .75725 .54754 Mtetra
.75725 .54754 .76189 .55315 .77234 .55012 .76773 .54449 Mtetra
.76773 .54449 .77234 .55012 .78284 .54707 .77825 .54142 Mtetra
.77825 .54142 .78284 .54707 .79337 .54401 .78881 .53834 Mtetra
.78881 .53834 .79337 .54401 .80394 .54095 .79941 .53526 Mtetra
.79941 .53526 .80394 .54095 .81455 .53787 .81005 .53216 Mtetra
.81005 .53216 .81455 .53787 .8252 .53478 .82072 .52905 Mtetra
.82072 .52905 .8252 .53478 .83589 .53168 .83144 .52592 Mtetra
.83144 .52592 .83589 .53168 .84661 .52857 .84219 .52279 Mtetra
.84219 .52279 .84661 .52857 .85738 .52544 .85299 .51964 Mtetra
.85299 .51964 .85738 .52544 .86819 .52231 .86383 .51649 Mtetra
.86383 .51649 .86819 .52231 .87903 .51916 .8747 .51332 Mtetra
.8747 .51332 .87903 .51916 .88992 .516 .88562 .51014 Mtetra
.88562 .51014 .88992 .516 .90085 .51283 .89658 .50694 Mtetra
.89658 .50694 .90085 .51283 .91182 .50965 .90758 .50374 Mtetra
.90758 .50374 .91182 .50965 .92283 .50645 .91862 .50052 Mtetra
.91862 .50052 .92283 .50645 .93388 .50324 .9297 .49729 Mtetra
.9297 .49729 .93388 .50324 .94497 .50003 .94082 .49405 Mtetra
.94082 .49405 .94497 .50003 .9561 .4968 .95198 .4908 Mtetra
.35253 .65894 .35813 .66383 .3672 .66119 .36162 .65628 Mtetra
.36162 .65628 .3672 .66119 .3763 .65854 .37074 .65361 Mtetra
.37074 .65361 .3763 .65854 .38544 .65587 .3799 .65094 Mtetra
.3799 .65094 .38544 .65587 .3946 .6532 .38908 .64825 Mtetra
.38908 .64825 .3946 .6532 .4038 .65052 .3983 .64555 Mtetra
.3983 .64555 .4038 .65052 .41303 .64783 .40755 .64285 Mtetra
.40755 .64285 .41303 .64783 .42229 .64514 .41683 .64013 Mtetra
.41683 .64013 .42229 .64514 .43158 .64243 .42614 .63741 Mtetra
.42614 .63741 .43158 .64243 .4409 .63971 .43548 .63467 Mtetra
.43548 .63467 .4409 .63971 .45026 .63699 .44486 .63193 Mtetra
.44486 .63193 .45026 .63699 .45965 .63425 .45427 .62918 Mtetra
.45427 .62918 .45965 .63425 .46907 .63151 .46371 .62641 Mtetra
.46371 .62641 .46907 .63151 .47853 .62875 .47319 .62364 Mtetra
.47319 .62364 .47853 .62875 .48801 .62599 .48269 .62086 Mtetra
.48269 .62086 .48801 .62599 .49753 .62321 .49224 .61807 Mtetra
.49224 .61807 .49753 .62321 .50709 .62043 .50181 .61527 Mtetra
.50181 .61527 .50709 .62043 .51667 .61764 .51142 .61245 Mtetra
.51142 .61245 .51667 .61764 .52629 .61483 .52106 .60963 Mtetra
.52106 .60963 .52629 .61483 .53595 .61202 .53074 .6068 Mtetra
.53074 .6068 .53595 .61202 .54563 .6092 .54045 .60396 Mtetra
.54045 .60396 .54563 .6092 .55536 .60636 .55019 .60111 Mtetra
.55019 .60111 .55536 .60636 .56511 .60352 .55997 .59825 Mtetra
.55997 .59825 .56511 .60352 .5749 .60067 .56978 .59538 Mtetra
.56978 .59538 .5749 .60067 .58473 .59781 .57963 .59249 Mtetra
.57963 .59249 .58473 .59781 .59459 .59493 .58952 .5896 Mtetra
.58952 .5896 .59459 .59493 .60448 .59205 .59944 .5867 Mtetra
.59944 .5867 .60448 .59205 .61441 .58916 .60939 .58379 Mtetra
.60939 .58379 .61441 .58916 .62438 .58625 .61938 .58087 Mtetra
.61938 .58087 .62438 .58625 .63438 .58334 .62941 .57793 Mtetra
.62941 .57793 .63438 .58334 .64442 .58041 .63947 .57499 Mtetra
.63947 .57499 .64442 .58041 .65449 .57748 .64957 .57203 Mtetra
.64957 .57203 .65449 .57748 .6646 .57453 .6597 .56907 Mtetra
.6597 .56907 .6646 .57453 .67475 .57158 .66987 .56609 Mtetra
.66987 .56609 .67475 .57158 .68493 .56861 .68008 .56311 Mtetra
.68008 .56311 .68493 .56861 .69515 .56563 .69032 .56011 Mtetra
.69032 .56011 .69515 .56563 .70541 .56264 .7006 .5571 Mtetra
.7006 .5571 .70541 .56264 .7157 .55965 .71092 .55408 Mtetra
.71092 .55408 .7157 .55965 .72603 .55664 .72128 .55105 Mtetra
.72128 .55105 .72603 .55664 .7364 .55361 .73168 .54801 Mtetra
.73168 .54801 .7364 .55361 .7468 .55058 .74211 .54496 Mtetra
.74211 .54496 .7468 .55058 .75725 .54754 .75258 .54189 Mtetra
.75258 .54189 .75725 .54754 .76773 .54449 .76309 .53882 Mtetra
.76309 .53882 .76773 .54449 .77825 .54142 .77364 .53573 Mtetra
.77364 .53573 .77825 .54142 .78881 .53834 .78422 .53263 Mtetra
.78422 .53263 .78881 .53834 .79941 .53526 .79485 .52952 Mtetra
.79485 .52952 .79941 .53526 .81005 .53216 .80551 .5264 Mtetra
.80551 .5264 .81005 .53216 .82072 .52905 .81622 .52327 Mtetra
.81622 .52327 .82072 .52905 .83144 .52592 .82696 .52013 Mtetra
.82696 .52013 .83144 .52592 .84219 .52279 .83775 .51697 Mtetra
.83775 .51697 .84219 .52279 .85299 .51964 .84857 .51381 Mtetra
.84857 .51381 .85299 .51964 .86383 .51649 .85944 .51063 Mtetra
.85944 .51063 .86383 .51649 .8747 .51332 .87034 .50744 Mtetra
.87034 .50744 .8747 .51332 .88562 .51014 .88129 .50423 Mtetra
.88129 .50423 .88562 .51014 .89658 .50694 .89227 .50102 Mtetra
.89227 .50102 .89658 .50694 .90758 .50374 .9033 .49779 Mtetra
.9033 .49779 .90758 .50374 .91862 .50052 .91437 .49455 Mtetra
.91437 .49455 .91862 .50052 .9297 .49729 .92549 .4913 Mtetra
.92549 .4913 .9297 .49729 .94082 .49405 .93664 .48804 Mtetra
.93664 .48804 .94082 .49405 .95198 .4908 .94784 .48476 Mtetra
.34689 .65403 .35253 .65894 .36162 .65628 .356 .65135 Mtetra
.356 .65135 .36162 .65628 .37074 .65361 .36515 .64866 Mtetra
.36515 .64866 .37074 .65361 .3799 .65094 .37432 .64597 Mtetra
.37432 .64597 .3799 .65094 .38908 .64825 .38352 .64326 Mtetra
.38352 .64326 .38908 .64825 .3983 .64555 .39276 .64055 Mtetra
.39276 .64055 .3983 .64555 .40755 .64285 .40203 .63783 Mtetra
.40203 .63783 .40755 .64285 .41683 .64013 .41133 .63509 Mtetra
.41133 .63509 .41683 .64013 .42614 .63741 .42066 .63235 Mtetra
.42066 .63235 .42614 .63741 .43548 .63467 .43003 .6296 Mtetra
.43003 .6296 .43548 .63467 .44486 .63193 .43942 .62684 Mtetra
.43942 .62684 .44486 .63193 .45427 .62918 .44885 .62407 Mtetra
.44885 .62407 .45427 .62918 .46371 .62641 .45832 .62129 Mtetra
.45832 .62129 .46371 .62641 .47319 .62364 .46781 .6185 Mtetra
.46781 .6185 .47319 .62364 .48269 .62086 .47734 .6157 Mtetra
.47734 .6157 .48269 .62086 .49224 .61807 .4869 .61289 Mtetra
.4869 .61289 .49224 .61807 .50181 .61527 .4965 .61007 Mtetra
.4965 .61007 .50181 .61527 .51142 .61245 .50613 .60724 Mtetra
.50613 .60724 .51142 .61245 .52106 .60963 .5158 .6044 Mtetra
.5158 .6044 .52106 .60963 .53074 .6068 .52549 .60155 Mtetra
.52549 .60155 .53074 .6068 .54045 .60396 .53523 .59869 Mtetra
.53523 .59869 .54045 .60396 .55019 .60111 .54499 .59582 Mtetra
.54499 .59582 .55019 .60111 .55997 .59825 .5548 .59294 Mtetra
.5548 .59294 .55997 .59825 .56978 .59538 .56463 .59005 Mtetra
.56463 .59005 .56978 .59538 .57963 .59249 .5745 .58715 Mtetra
.5745 .58715 .57963 .59249 .58952 .5896 .58441 .58424 Mtetra
.58441 .58424 .58952 .5896 .59944 .5867 .59435 .58132 Mtetra
.59435 .58132 .59944 .5867 .60939 .58379 .60433 .57838 Mtetra
.60433 .57838 .60939 .58379 .61938 .58087 .61435 .57544 Mtetra
.61435 .57544 .61938 .58087 .62941 .57793 .6244 .57249 Mtetra
.6244 .57249 .62941 .57793 .63947 .57499 .63448 .56952 Mtetra
.63448 .56952 .63947 .57499 .64957 .57203 .6446 .56655 Mtetra
.6446 .56655 .64957 .57203 .6597 .56907 .65476 .56357 Mtetra
.65476 .56357 .6597 .56907 .66987 .56609 .66496 .56057 Mtetra
.66496 .56057 .66987 .56609 .68008 .56311 .67519 .55756 Mtetra
.67519 .55756 .68008 .56311 .69032 .56011 .68546 .55455 Mtetra
.68546 .55455 .69032 .56011 .7006 .5571 .69577 .55152 Mtetra
.69577 .55152 .7006 .5571 .71092 .55408 .70612 .54848 Mtetra
.70612 .54848 .71092 .55408 .72128 .55105 .7165 .54543 Mtetra
.7165 .54543 .72128 .55105 .73168 .54801 .72692 .54236 Mtetra
.72692 .54236 .73168 .54801 .74211 .54496 .73738 .53929 Mtetra
.73738 .53929 .74211 .54496 .75258 .54189 .74788 .53621 Mtetra
.74788 .53621 .75258 .54189 .76309 .53882 .75841 .53311 Mtetra
.75841 .53311 .76309 .53882 .77364 .53573 .76899 .53 Mtetra
.76899 .53 .77364 .53573 .78422 .53263 .7796 .52688 Mtetra
.7796 .52688 .78422 .53263 .79485 .52952 .79026 .52375 Mtetra
.79026 .52375 .79485 .52952 .80551 .5264 .80095 .52061 Mtetra
.80095 .52061 .80551 .5264 .81622 .52327 .81168 .51746 Mtetra
.81168 .51746 .81622 .52327 .82696 .52013 .82245 .51429 Mtetra
.82245 .51429 .82696 .52013 .83775 .51697 .83327 .51112 Mtetra
.83327 .51112 .83775 .51697 .84857 .51381 .84412 .50793 Mtetra
.84412 .50793 .84857 .51381 .85944 .51063 .85501 .50473 Mtetra
.85501 .50473 .85944 .51063 .87034 .50744 .86595 .50151 Mtetra
.86595 .50151 .87034 .50744 .88129 .50423 .87693 .49829 Mtetra
.87693 .49829 .88129 .50423 .89227 .50102 .88794 .49505 Mtetra
.88794 .49505 .89227 .50102 .9033 .49779 .899 .4918 Mtetra
.899 .4918 .9033 .49779 .91437 .49455 .9101 .48854 Mtetra
.9101 .48854 .91437 .49455 .92549 .4913 .92125 .48527 Mtetra
.92125 .48527 .92549 .4913 .93664 .48804 .93243 .48198 Mtetra
.93243 .48198 .93664 .48804 .94784 .48476 .94366 .47868 Mtetra
.34122 .64908 .34689 .65403 .356 .65135 .35035 .64638 Mtetra
.35035 .64638 .356 .65135 .36515 .64866 .35951 .64368 Mtetra
.35951 .64368 .36515 .64866 .37432 .64597 .36871 .64097 Mtetra
.36871 .64097 .37432 .64597 .38352 .64326 .37793 .63825 Mtetra
.37793 .63825 .38352 .64326 .39276 .64055 .38719 .63551 Mtetra
.38719 .63551 .39276 .64055 .40203 .63783 .39647 .63277 Mtetra
.39647 .63277 .40203 .63783 .41133 .63509 .40579 .63002 Mtetra
.40579 .63002 .41133 .63509 .42066 .63235 .41515 .62726 Mtetra
.41515 .62726 .42066 .63235 .43003 .6296 .42453 .62449 Mtetra
.42453 .62449 .43003 .6296 .43942 .62684 .43395 .62172 Mtetra
.43395 .62172 .43942 .62684 .44885 .62407 .4434 .61893 Mtetra
.4434 .61893 .44885 .62407 .45832 .62129 .45289 .61613 Mtetra
.45289 .61613 .45832 .62129 .46781 .6185 .4624 .61332 Mtetra
.4624 .61332 .46781 .6185 .47734 .6157 .47195 .6105 Mtetra
.47195 .6105 .47734 .6157 .4869 .61289 .48154 .60767 Mtetra
.48154 .60767 .4869 .61289 .4965 .61007 .49116 .60484 Mtetra
.49116 .60484 .4965 .61007 .50613 .60724 .50081 .60199 Mtetra
.50081 .60199 .50613 .60724 .5158 .6044 .5105 .59913 Mtetra
.5105 .59913 .5158 .6044 .52549 .60155 .52022 .59626 Mtetra
.52022 .59626 .52549 .60155 .53523 .59869 .52997 .59338 Mtetra
.52997 .59338 .53523 .59869 .54499 .59582 .53976 .59049 Mtetra
.53976 .59049 .54499 .59582 .5548 .59294 .54959 .58759 Mtetra
.54959 .58759 .5548 .59294 .56463 .59005 .55945 .58469 Mtetra
.55945 .58469 .56463 .59005 .5745 .58715 .56934 .58177 Mtetra
.56934 .58177 .5745 .58715 .58441 .58424 .57927 .57884 Mtetra
.57927 .57884 .58441 .58424 .59435 .58132 .58924 .57589 Mtetra
.58924 .57589 .59435 .58132 .60433 .57838 .59924 .57294 Mtetra
.59924 .57294 .60433 .57838 .61435 .57544 .60928 .56998 Mtetra
.60928 .56998 .61435 .57544 .6244 .57249 .61935 .56701 Mtetra
.61935 .56701 .6244 .57249 .63448 .56952 .62946 .56403 Mtetra
.62946 .56403 .63448 .56952 .6446 .56655 .63961 .56103 Mtetra
.63961 .56103 .6446 .56655 .65476 .56357 .64979 .55803 Mtetra
.64979 .55803 .65476 .56357 .66496 .56057 .66002 .55501 Mtetra
.66002 .55501 .66496 .56057 .67519 .55756 .67027 .55198 Mtetra
.67027 .55198 .67519 .55756 .68546 .55455 .68057 .54895 Mtetra
.68057 .54895 .68546 .55455 .69577 .55152 .6909 .5459 Mtetra
.6909 .5459 .69577 .55152 .70612 .54848 .70127 .54284 Mtetra
.70127 .54284 .70612 .54848 .7165 .54543 .71168 .53976 Mtetra
.71168 .53976 .7165 .54543 .72692 .54236 .72213 .53668 Mtetra
.72213 .53668 .72692 .54236 .73738 .53929 .73262 .53359 Mtetra
.73262 .53359 .73738 .53929 .74788 .53621 .74314 .53048 Mtetra
.74314 .53048 .74788 .53621 .75841 .53311 .75371 .52737 Mtetra
.75371 .52737 .75841 .53311 .76899 .53 .76431 .52424 Mtetra
.76431 .52424 .76899 .53 .7796 .52688 .77495 .5211 Mtetra
.77495 .5211 .7796 .52688 .79026 .52375 .78563 .51794 Mtetra
.78563 .51794 .79026 .52375 .80095 .52061 .79635 .51478 Mtetra
.79635 .51478 .80095 .52061 .81168 .51746 .80711 .51161 Mtetra
.80711 .51161 .81168 .51746 .82245 .51429 .81792 .50842 Mtetra
.81792 .50842 .82245 .51429 .83327 .51112 .82876 .50522 Mtetra
.82876 .50522 .83327 .51112 .84412 .50793 .83964 .50201 Mtetra
.83964 .50201 .84412 .50793 .85501 .50473 .85056 .49879 Mtetra
.85056 .49879 .85501 .50473 .86595 .50151 .86153 .49555 Mtetra
.86153 .49555 .86595 .50151 .87693 .49829 .87253 .4923 Mtetra
.87253 .4923 .87693 .49829 .88794 .49505 .88358 .48904 Mtetra
.88358 .48904 .88794 .49505 .899 .4918 .89467 .48577 Mtetra
.89467 .48577 .899 .4918 .9101 .48854 .9058 .48249 Mtetra
.9058 .48249 .9101 .48854 .92125 .48527 .91698 .47919 Mtetra
.91698 .47919 .92125 .48527 .93243 .48198 .92819 .47588 Mtetra
.92819 .47588 .93243 .48198 .94366 .47868 .93945 .47256 Mtetra
.33552 .6441 .34122 .64908 .35035 .64638 .34467 .64139 Mtetra
.34467 .64139 .35035 .64638 .35951 .64368 .35385 .63866 Mtetra
.35385 .63866 .35951 .64368 .36871 .64097 .36306 .63594 Mtetra
.36306 .63594 .36871 .64097 .37793 .63825 .3723 .6332 Mtetra
.3723 .6332 .37793 .63825 .38719 .63551 .38158 .63045 Mtetra
.38158 .63045 .38719 .63551 .39647 .63277 .39089 .62769 Mtetra
.39089 .62769 .39647 .63277 .40579 .63002 .40023 .62492 Mtetra
.40023 .62492 .40579 .63002 .41515 .62726 .4096 .62214 Mtetra
.4096 .62214 .41515 .62726 .42453 .62449 .41901 .61936 Mtetra
.41901 .61936 .42453 .62449 .43395 .62172 .42844 .61656 Mtetra
.42844 .61656 .43395 .62172 .4434 .61893 .43792 .61375 Mtetra
.43792 .61375 .4434 .61893 .45289 .61613 .44742 .61094 Mtetra
.44742 .61094 .45289 .61613 .4624 .61332 .45696 .60811 Mtetra
.45696 .60811 .4624 .61332 .47195 .6105 .46653 .60527 Mtetra
.46653 .60527 .47195 .6105 .48154 .60767 .47614 .60243 Mtetra
.47614 .60243 .48154 .60767 .49116 .60484 .48578 .59957 Mtetra
.48578 .59957 .49116 .60484 .50081 .60199 .49545 .5967 Mtetra
.49545 .5967 .50081 .60199 .5105 .59913 .50516 .59383 Mtetra
.50516 .59383 .5105 .59913 .52022 .59626 .5149 .59094 Mtetra
.5149 .59094 .52022 .59626 .52997 .59338 .52468 .58804 Mtetra
.52468 .58804 .52997 .59338 .53976 .59049 .5345 .58513 Mtetra
.5345 .58513 .53976 .59049 .54959 .58759 .54434 .58222 Mtetra
.54434 .58222 .54959 .58759 .55945 .58469 .55423 .57929 Mtetra
.55423 .57929 .55945 .58469 .56934 .58177 .56414 .57635 Mtetra
.56414 .57635 .56934 .58177 .57927 .57884 .5741 .5734 Mtetra
.5741 .5734 .57927 .57884 .58924 .57589 .58409 .57044 Mtetra
.58409 .57044 .58924 .57589 .59924 .57294 .59412 .56747 Mtetra
.59412 .56747 .59924 .57294 .60928 .56998 .60418 .56449 Mtetra
.60418 .56449 .60928 .56998 .61935 .56701 .61428 .56149 Mtetra
.61428 .56149 .61935 .56701 .62946 .56403 .62441 .55849 Mtetra
.62441 .55849 .62946 .56403 .63961 .56103 .63458 .55547 Mtetra
.63458 .55547 .63961 .56103 .64979 .55803 .64479 .55245 Mtetra
.64479 .55245 .64979 .55803 .66002 .55501 .65504 .54941 Mtetra
.65504 .54941 .66002 .55501 .67027 .55198 .66532 .54637 Mtetra
.66532 .54637 .67027 .55198 .68057 .54895 .67564 .54331 Mtetra
.67564 .54331 .68057 .54895 .6909 .5459 .686 .54024 Mtetra
.686 .54024 .6909 .5459 .70127 .54284 .6964 .53716 Mtetra
.6964 .53716 .70127 .54284 .71168 .53976 .70684 .53406 Mtetra
.70684 .53406 .71168 .53976 .72213 .53668 .71731 .53096 Mtetra
.71731 .53096 .72213 .53668 .73262 .53359 .72782 .52785 Mtetra
.72782 .52785 .73262 .53359 .74314 .53048 .73838 .52472 Mtetra
.73838 .52472 .74314 .53048 .75371 .52737 .74897 .52158 Mtetra
.74897 .52158 .75371 .52737 .76431 .52424 .7596 .51843 Mtetra
.7596 .51843 .76431 .52424 .77495 .5211 .77027 .51527 Mtetra
.77027 .51527 .77495 .5211 .78563 .51794 .78098 .5121 Mtetra
.78098 .5121 .78563 .51794 .79635 .51478 .79173 .50891 Mtetra
.79173 .50891 .79635 .51478 .80711 .51161 .80251 .50571 Mtetra
.80251 .50571 .80711 .51161 .81792 .50842 .81335 .5025 Mtetra
.81335 .5025 .81792 .50842 .82876 .50522 .82422 .49928 Mtetra
.82422 .49928 .82876 .50522 .83964 .50201 .83513 .49605 Mtetra
.83513 .49605 .83964 .50201 .85056 .49879 .84608 .4928 Mtetra
.84608 .4928 .85056 .49879 .86153 .49555 .85707 .48955 Mtetra
.85707 .48955 .86153 .49555 .87253 .4923 .86811 .48627 Mtetra
.86811 .48627 .87253 .4923 .88358 .48904 .87919 .48299 Mtetra
.87919 .48299 .88358 .48904 .89467 .48577 .89031 .4797 Mtetra
.89031 .4797 .89467 .48577 .9058 .48249 .90147 .47639 Mtetra
.90147 .47639 .9058 .48249 .91698 .47919 .91268 .47307 Mtetra
.91268 .47307 .91698 .47919 .92819 .47588 .92392 .46974 Mtetra
.92392 .46974 .92819 .47588 .93945 .47256 .93521 .46639 Mtetra
.32977 .63908 .33552 .6441 .34467 .64139 .33894 .63636 Mtetra
.33894 .63636 .34467 .64139 .35385 .63866 .34814 .63362 Mtetra
.34814 .63362 .35385 .63866 .36306 .63594 .35737 .63087 Mtetra
.35737 .63087 .36306 .63594 .3723 .6332 .36664 .62811 Mtetra
.36664 .62811 .3723 .6332 .38158 .63045 .37593 .62535 Mtetra
.37593 .62535 .38158 .63045 .39089 .62769 .38526 .62257 Mtetra
.38526 .62257 .39089 .62769 .40023 .62492 .39462 .61979 Mtetra
.39462 .61979 .40023 .62492 .4096 .62214 .40402 .61699 Mtetra
.40402 .61699 .4096 .62214 .41901 .61936 .41344 .61418 Mtetra
.41344 .61418 .41901 .61936 .42844 .61656 .4229 .61137 Mtetra
.4229 .61137 .42844 .61656 .43792 .61375 .43239 .60854 Mtetra
.43239 .60854 .43792 .61375 .44742 .61094 .44192 .60571 Mtetra
.44192 .60571 .44742 .61094 .45696 .60811 .45148 .60286 Mtetra
.45148 .60286 .45696 .60811 .46653 .60527 .46108 .60001 Mtetra
.46108 .60001 .46653 .60527 .47614 .60243 .4707 .59714 Mtetra
.4707 .59714 .47614 .60243 .48578 .59957 .48037 .59427 Mtetra
.48037 .59427 .48578 .59957 .49545 .5967 .49006 .59138 Mtetra
.49006 .59138 .49545 .5967 .50516 .59383 .49979 .58849 Mtetra
.49979 .58849 .50516 .59383 .5149 .59094 .50956 .58558 Mtetra
.50956 .58558 .5149 .59094 .52468 .58804 .51936 .58267 Mtetra
.51936 .58267 .52468 .58804 .5345 .58513 .52919 .57974 Mtetra
.52919 .57974 .5345 .58513 .54434 .58222 .53907 .5768 Mtetra
.53907 .5768 .54434 .58222 .55423 .57929 .54897 .57385 Mtetra
.54897 .57385 .55423 .57929 .56414 .57635 .55891 .57089 Mtetra
.55891 .57089 .56414 .57635 .5741 .5734 .56889 .56792 Mtetra
.56889 .56792 .5741 .5734 .58409 .57044 .57891 .56494 Mtetra
.57891 .56494 .58409 .57044 .59412 .56747 .58896 .56195 Mtetra
.58896 .56195 .59412 .56747 .60418 .56449 .59904 .55895 Mtetra
.59904 .55895 .60418 .56449 .61428 .56149 .60917 .55594 Mtetra
.60917 .55594 .61428 .56149 .62441 .55849 .61933 .55292 Mtetra
.61933 .55292 .62441 .55849 .63458 .55547 .62952 .54988 Mtetra
.62952 .54988 .63458 .55547 .64479 .55245 .63976 .54684 Mtetra
.63976 .54684 .64479 .55245 .65504 .54941 .65003 .54378 Mtetra
.65003 .54378 .65504 .54941 .66532 .54637 .66034 .54071 Mtetra
.66034 .54071 .66532 .54637 .67564 .54331 .67069 .53763 Mtetra
.67069 .53763 .67564 .54331 .686 .54024 .68107 .53454 Mtetra
.68107 .53454 .686 .54024 .6964 .53716 .69149 .53144 Mtetra
.69149 .53144 .6964 .53716 .70684 .53406 .70196 .52833 Mtetra
.70196 .52833 .70684 .53406 .71731 .53096 .71246 .5252 Mtetra
.71246 .5252 .71731 .53096 .72782 .52785 .723 .52206 Mtetra
.723 .52206 .72782 .52785 .73838 .52472 .73358 .51892 Mtetra
.73358 .51892 .73838 .52472 .74897 .52158 .74419 .51576 Mtetra
.74419 .51576 .74897 .52158 .7596 .51843 .75485 .51258 Mtetra
.75485 .51258 .7596 .51843 .77027 .51527 .76555 .5094 Mtetra
.76555 .5094 .77027 .51527 .78098 .5121 .77629 .50621 Mtetra
.77629 .50621 .78098 .5121 .79173 .50891 .78707 .503 Mtetra
.78707 .503 .79173 .50891 .80251 .50571 .79788 .49978 Mtetra
.79788 .49978 .80251 .50571 .81335 .5025 .80874 .49655 Mtetra
.80874 .49655 .81335 .5025 .82422 .49928 .81964 .4933 Mtetra
.81964 .4933 .82422 .49928 .83513 .49605 .83058 .49005 Mtetra
.83058 .49005 .83513 .49605 .84608 .4928 .84157 .48678 Mtetra
.84157 .48678 .84608 .4928 .85707 .48955 .85259 .4835 Mtetra
.85259 .4835 .85707 .48955 .86811 .48627 .86366 .4802 Mtetra
.86366 .4802 .86811 .48627 .87919 .48299 .87477 .4769 Mtetra
.87477 .4769 .87919 .48299 .89031 .4797 .88592 .47358 Mtetra
.88592 .47358 .89031 .4797 .90147 .47639 .89711 .47025 Mtetra
.89711 .47025 .90147 .47639 .91268 .47307 .90834 .46691 Mtetra
.90834 .46691 .91268 .47307 .92392 .46974 .91962 .46355 Mtetra
.91962 .46355 .92392 .46974 .93521 .46639 .93095 .46018 Mtetra
.32399 .63404 .32977 .63908 .33894 .63636 .33318 .63129 Mtetra
.33318 .63129 .33894 .63636 .34814 .63362 .3424 .62854 Mtetra
.3424 .62854 .34814 .63362 .35737 .63087 .35165 .62577 Mtetra
.35165 .62577 .35737 .63087 .36664 .62811 .36094 .623 Mtetra
.36094 .623 .36664 .62811 .37593 .62535 .37025 .62022 Mtetra
.37025 .62022 .37593 .62535 .38526 .62257 .3796 .61742 Mtetra
.3796 .61742 .38526 .62257 .39462 .61979 .38898 .61462 Mtetra
.38898 .61462 .39462 .61979 .40402 .61699 .3984 .6118 Mtetra
.3984 .6118 .40402 .61699 .41344 .61418 .40784 .60898 Mtetra
.40784 .60898 .41344 .61418 .4229 .61137 .41732 .60615 Mtetra
.41732 .60615 .4229 .61137 .43239 .60854 .42684 .6033 Mtetra
.42684 .6033 .43239 .60854 .44192 .60571 .43639 .60045 Mtetra
.43639 .60045 .44192 .60571 .45148 .60286 .44597 .59759 Mtetra
.44597 .59759 .45148 .60286 .46108 .60001 .45558 .59471 Mtetra
.45558 .59471 .46108 .60001 .4707 .59714 .46523 .59183 Mtetra
.46523 .59183 .4707 .59714 .48037 .59427 .47492 .58893 Mtetra
.47492 .58893 .48037 .59427 .49006 .59138 .48463 .58603 Mtetra
.48463 .58603 .49006 .59138 .49979 .58849 .49439 .58311 Mtetra
.49439 .58311 .49979 .58849 .50956 .58558 .50418 .58019 Mtetra
.50418 .58019 .50956 .58558 .51936 .58267 .514 .57725 Mtetra
.514 .57725 .51936 .58267 .52919 .57974 .52386 .57431 Mtetra
.52386 .57431 .52919 .57974 .53907 .5768 .53375 .57135 Mtetra
.53375 .57135 .53907 .5768 .54897 .57385 .54368 .56838 Mtetra
.54368 .56838 .54897 .57385 .55891 .57089 .55365 .5654 Mtetra
.55365 .5654 .55891 .57089 .56889 .56792 .56365 .56241 Mtetra
.56365 .56241 .56889 .56792 .57891 .56494 .57369 .55941 Mtetra
.57369 .55941 .57891 .56494 .58896 .56195 .58376 .5564 Mtetra
.58376 .5564 .58896 .56195 .59904 .55895 .59387 .55338 Mtetra
.59387 .55338 .59904 .55895 .60917 .55594 .60402 .55035 Mtetra
.60402 .55035 .60917 .55594 .61933 .55292 .61421 .5473 Mtetra
.61421 .5473 .61933 .55292 .62952 .54988 .62443 .54425 Mtetra
.62443 .54425 .62952 .54988 .63976 .54684 .63469 .54118 Mtetra
.63469 .54118 .63976 .54684 .65003 .54378 .64498 .53811 Mtetra
.64498 .53811 .65003 .54378 .66034 .54071 .65532 .53502 Mtetra
.65532 .53502 .66034 .54071 .67069 .53763 .66569 .53192 Mtetra
.66569 .53192 .67069 .53763 .68107 .53454 .6761 .52881 Mtetra
.6761 .52881 .68107 .53454 .69149 .53144 .68655 .52568 Mtetra
.68655 .52568 .69149 .53144 .70196 .52833 .69704 .52255 Mtetra
.69704 .52255 .70196 .52833 .71246 .5252 .70757 .5194 Mtetra
.70757 .5194 .71246 .5252 .723 .52206 .71814 .51624 Mtetra
.71814 .51624 .723 .52206 .73358 .51892 .72874 .51307 Mtetra
.72874 .51307 .73358 .51892 .74419 .51576 .73939 .50989 Mtetra
.73939 .50989 .74419 .51576 .75485 .51258 .75008 .5067 Mtetra
.75008 .5067 .75485 .51258 .76555 .5094 .7608 .50349 Mtetra
.7608 .50349 .76555 .5094 .77629 .50621 .77157 .50027 Mtetra
.77157 .50027 .77629 .50621 .78707 .503 .78237 .49704 Mtetra
.78237 .49704 .78707 .503 .79788 .49978 .79322 .4938 Mtetra
.79322 .4938 .79788 .49978 .80874 .49655 .80411 .49055 Mtetra
.80411 .49055 .80874 .49655 .81964 .4933 .81504 .48728 Mtetra
.81504 .48728 .81964 .4933 .83058 .49005 .82601 .484 Mtetra
.82601 .484 .83058 .49005 .84157 .48678 .83702 .48071 Mtetra
.83702 .48071 .84157 .48678 .85259 .4835 .84808 .47741 Mtetra
.84808 .47741 .85259 .4835 .86366 .4802 .85917 .47409 Mtetra
.85917 .47409 .86366 .4802 .87477 .4769 .87031 .47076 Mtetra
.87031 .47076 .87477 .4769 .88592 .47358 .88149 .46742 Mtetra
.88149 .46742 .88592 .47358 .89711 .47025 .89272 .46407 Mtetra
.89272 .46407 .89711 .47025 .90834 .46691 .90398 .4607 Mtetra
.90398 .4607 .90834 .46691 .91962 .46355 .91529 .45732 Mtetra
.91529 .45732 .91962 .46355 .93095 .46018 .92665 .45393 Mtetra
.31818 .62896 .32399 .63404 .33318 .63129 .32738 .6262 Mtetra
.32738 .6262 .33318 .63129 .3424 .62854 .33662 .62343 Mtetra
.33662 .62343 .3424 .62854 .35165 .62577 .34589 .62064 Mtetra
.34589 .62064 .35165 .62577 .36094 .623 .3552 .61785 Mtetra
.3552 .61785 .36094 .623 .37025 .62022 .36453 .61505 Mtetra
.36453 .61505 .37025 .62022 .3796 .61742 .3739 .61224 Mtetra
.3739 .61224 .3796 .61742 .38898 .61462 .3833 .60942 Mtetra
.3833 .60942 .38898 .61462 .3984 .6118 .39274 .60658 Mtetra
.39274 .60658 .3984 .6118 .40784 .60898 .40221 .60374 Mtetra
.40221 .60374 .40784 .60898 .41732 .60615 .41171 .60089 Mtetra
.41171 .60089 .41732 .60615 .42684 .6033 .42124 .59803 Mtetra
.42124 .59803 .42684 .6033 .43639 .60045 .43081 .59516 Mtetra
.43081 .59516 .43639 .60045 .44597 .59759 .44042 .59227 Mtetra
.44042 .59227 .44597 .59759 .45558 .59471 .45005 .58938 Mtetra
.45005 .58938 .45558 .59471 .46523 .59183 .45972 .58648 Mtetra
.45972 .58648 .46523 .59183 .47492 .58893 .46943 .58356 Mtetra
.46943 .58356 .47492 .58893 .48463 .58603 .47917 .58064 Mtetra
.47917 .58064 .48463 .58603 .49439 .58311 .48895 .57771 Mtetra
.48895 .57771 .49439 .58311 .50418 .58019 .49876 .57476 Mtetra
.49876 .57476 .50418 .58019 .514 .57725 .5086 .57181 Mtetra
.5086 .57181 .514 .57725 .52386 .57431 .51849 .56884 Mtetra
.51849 .56884 .52386 .57431 .53375 .57135 .5284 .56586 Mtetra
.5284 .56586 .53375 .57135 .54368 .56838 .53836 .56288 Mtetra
.53836 .56288 .54368 .56838 .55365 .5654 .54835 .55988 Mtetra
.54835 .55988 .55365 .5654 .56365 .56241 .55837 .55687 Mtetra
.55837 .55687 .56365 .56241 .57369 .55941 .56843 .55385 Mtetra
.56843 .55385 .57369 .55941 .58376 .5564 .57853 .55082 Mtetra
.57853 .55082 .58376 .5564 .59387 .55338 .58867 .54777 Mtetra
.58867 .54777 .59387 .55338 .60402 .55035 .59884 .54472 Mtetra
.59884 .54472 .60402 .55035 .61421 .5473 .60905 .54166 Mtetra
.60905 .54166 .61421 .5473 .62443 .54425 .6193 .53858 Mtetra
.6193 .53858 .62443 .54425 .63469 .54118 .62958 .53549 Mtetra
.62958 .53549 .63469 .54118 .64498 .53811 .63991 .53239 Mtetra
.63991 .53239 .64498 .53811 .65532 .53502 .65027 .52928 Mtetra
.65027 .52928 .65532 .53502 .66569 .53192 .66067 .52616 Mtetra
.66067 .52616 .66569 .53192 .6761 .52881 .6711 .52303 Mtetra
.6711 .52303 .6761 .52881 .68655 .52568 .68158 .51989 Mtetra
.68158 .51989 .68655 .52568 .69704 .52255 .6921 .51673 Mtetra
.6921 .51673 .69704 .52255 .70757 .5194 .70265 .51356 Mtetra
.70265 .51356 .70757 .5194 .71814 .51624 .71324 .51038 Mtetra
.71324 .51038 .71814 .51624 .72874 .51307 .72388 .50719 Mtetra
.72388 .50719 .72874 .51307 .73939 .50989 .73455 .50399 Mtetra
.73455 .50399 .73939 .50989 .75008 .5067 .74527 .50077 Mtetra
.74527 .50077 .75008 .5067 .7608 .50349 .75602 .49754 Mtetra
.75602 .49754 .7608 .50349 .77157 .50027 .76681 .4943 Mtetra
.76681 .4943 .77157 .50027 .78237 .49704 .77765 .49105 Mtetra
.77765 .49105 .78237 .49704 .79322 .4938 .78852 .48779 Mtetra
.78852 .48779 .79322 .4938 .80411 .49055 .79944 .48451 Mtetra
.79944 .48451 .80411 .49055 .81504 .48728 .8104 .48122 Mtetra
.8104 .48122 .81504 .48728 .82601 .484 .8214 .47792 Mtetra
.8214 .47792 .82601 .484 .83702 .48071 .83244 .4746 Mtetra
.83244 .4746 .83702 .48071 .84808 .47741 .84353 .47128 Mtetra
.84353 .47128 .84808 .47741 .85917 .47409 .85465 .46794 Mtetra
.85465 .46794 .85917 .47409 .87031 .47076 .86582 .46458 Mtetra
.86582 .46458 .87031 .47076 .88149 .46742 .87704 .46122 Mtetra
.87704 .46122 .88149 .46742 .89272 .46407 .88829 .45784 Mtetra
.88829 .45784 .89272 .46407 .90398 .4607 .89959 .45445 Mtetra
.89959 .45445 .90398 .4607 .91529 .45732 .91093 .45104 Mtetra
.91093 .45104 .91529 .45732 .92665 .45393 .92232 .44763 Mtetra
.31232 .62385 .31818 .62896 .32738 .6262 .32155 .62107 Mtetra
.32155 .62107 .32738 .6262 .33662 .62343 .33081 .61828 Mtetra
.33081 .61828 .33662 .62343 .34589 .62064 .3401 .61548 Mtetra
.3401 .61548 .34589 .62064 .3552 .61785 .34942 .61267 Mtetra
.34942 .61267 .3552 .61785 .36453 .61505 .35878 .60985 Mtetra
.35878 .60985 .36453 .61505 .3739 .61224 .36817 .60702 Mtetra
.36817 .60702 .3739 .61224 .3833 .60942 .37759 .60418 Mtetra
.37759 .60418 .3833 .60942 .39274 .60658 .38704 .60133 Mtetra
.38704 .60133 .39274 .60658 .40221 .60374 .39653 .59847 Mtetra
.39653 .59847 .40221 .60374 .41171 .60089 .40606 .5956 Mtetra
.40606 .5956 .41171 .60089 .42124 .59803 .41561 .59272 Mtetra
.41561 .59272 .42124 .59803 .43081 .59516 .4252 .58983 Mtetra
.4252 .58983 .43081 .59516 .44042 .59227 .43483 .58692 Mtetra
.43483 .58692 .44042 .59227 .45005 .58938 .44449 .58401 Mtetra
.44449 .58401 .45005 .58938 .45972 .58648 .45418 .58109 Mtetra
.45418 .58109 .45972 .58648 .46943 .58356 .46391 .57816 Mtetra
.46391 .57816 .46943 .58356 .47917 .58064 .47367 .57521 Mtetra
.47367 .57521 .47917 .58064 .48895 .57771 .48347 .57226 Mtetra
.48347 .57226 .48895 .57771 .49876 .57476 .4933 .5693 Mtetra
.4933 .5693 .49876 .57476 .5086 .57181 .50317 .56632 Mtetra
.50317 .56632 .5086 .57181 .51849 .56884 .51308 .56334 Mtetra
.51308 .56334 .51849 .56884 .5284 .56586 .52302 .56034 Mtetra
.52302 .56034 .5284 .56586 .53836 .56288 .533 .55733 Mtetra
.533 .55733 .53836 .56288 .54835 .55988 .54301 .55431 Mtetra
.54301 .55431 .54835 .55988 .55837 .55687 .55306 .55128 Mtetra
.55306 .55128 .55837 .55687 .56843 .55385 .56314 .54824 Mtetra
.56314 .54824 .56843 .55385 .57853 .55082 .57327 .54519 Mtetra
.57327 .54519 .57853 .55082 .58867 .54777 .58343 .54213 Mtetra
.58343 .54213 .58867 .54777 .59884 .54472 .59363 .53905 Mtetra
.59363 .53905 .59884 .54472 .60905 .54166 .60386 .53597 Mtetra
.60386 .53597 .60905 .54166 .6193 .53858 .61413 .53287 Mtetra
.61413 .53287 .6193 .53858 .62958 .53549 .62444 .52976 Mtetra
.62444 .52976 .62958 .53549 .63991 .53239 .63479 .52664 Mtetra
.63479 .52664 .63991 .53239 .65027 .52928 .64518 .52351 Mtetra
.64518 .52351 .65027 .52928 .66067 .52616 .6556 .52037 Mtetra
.6556 .52037 .66067 .52616 .6711 .52303 .66607 .51722 Mtetra
.66607 .51722 .6711 .52303 .68158 .51989 .67657 .51405 Mtetra
.67657 .51405 .68158 .51989 .6921 .51673 .68711 .51087 Mtetra
.68711 .51087 .6921 .51673 .70265 .51356 .6977 .50768 Mtetra
.6977 .50768 .70265 .51356 .71324 .51038 .70832 .50448 Mtetra
.70832 .50448 .71324 .51038 .72388 .50719 .71898 .50127 Mtetra
.71898 .50127 .72388 .50719 .73455 .50399 .72968 .49804 Mtetra
.72968 .49804 .73455 .50399 .74527 .50077 .74042 .4948 Mtetra
.74042 .4948 .74527 .50077 .75602 .49754 .7512 .49155 Mtetra
.7512 .49155 .75602 .49754 .76681 .4943 .76203 .48829 Mtetra
.76203 .48829 .76681 .4943 .77765 .49105 .77289 .48501 Mtetra
.77289 .48501 .77765 .49105 .78852 .48779 .7838 .48173 Mtetra
.7838 .48173 .78852 .48779 .79944 .48451 .79474 .47843 Mtetra
.79474 .47843 .79944 .48451 .8104 .48122 .80573 .47511 Mtetra
.80573 .47511 .8104 .48122 .8214 .47792 .81676 .47179 Mtetra
.81676 .47179 .8214 .47792 .83244 .4746 .82783 .46845 Mtetra
.82783 .46845 .83244 .4746 .84353 .47128 .83895 .4651 Mtetra
.83895 .4651 .84353 .47128 .85465 .46794 .85011 .46174 Mtetra
.85011 .46174 .85465 .46794 .86582 .46458 .86131 .45836 Mtetra
.86131 .45836 .86582 .46458 .87704 .46122 .87255 .45497 Mtetra
.87255 .45497 .87704 .46122 .88829 .45784 .88384 .45157 Mtetra
.88384 .45157 .88829 .45784 .89959 .45445 .89517 .44815 Mtetra
.89517 .44815 .89959 .45445 .91093 .45104 .90654 .44472 Mtetra
.90654 .44472 .91093 .45104 .92232 .44763 .91796 .44128 Mtetra
.30643 .61871 .31232 .62385 .32155 .62107 .31568 .61591 Mtetra
.31568 .61591 .32155 .62107 .33081 .61828 .32495 .6131 Mtetra
.32495 .6131 .33081 .61828 .3401 .61548 .33427 .61028 Mtetra
.33427 .61028 .3401 .61548 .34942 .61267 .34361 .60746 Mtetra
.34361 .60746 .34942 .61267 .35878 .60985 .35299 .60462 Mtetra
.35299 .60462 .35878 .60985 .36817 .60702 .36239 .60177 Mtetra
.36239 .60177 .36817 .60702 .37759 .60418 .37184 .59891 Mtetra
.37184 .59891 .37759 .60418 .38704 .60133 .38131 .59604 Mtetra
.38131 .59604 .38704 .60133 .39653 .59847 .39082 .59316 Mtetra
.39082 .59316 .39653 .59847 .40606 .5956 .40037 .59027 Mtetra
.40037 .59027 .40606 .5956 .41561 .59272 .40995 .58737 Mtetra
.40995 .58737 .41561 .59272 .4252 .58983 .41956 .58446 Mtetra
.41956 .58446 .4252 .58983 .43483 .58692 .4292 .58154 Mtetra
.4292 .58154 .43483 .58692 .44449 .58401 .43888 .57861 Mtetra
.43888 .57861 .44449 .58401 .45418 .58109 .4486 .57567 Mtetra
.4486 .57567 .45418 .58109 .46391 .57816 .45835 .57272 Mtetra
.45835 .57272 .46391 .57816 .47367 .57521 .46814 .56975 Mtetra
.46814 .56975 .47367 .57521 .48347 .57226 .47796 .56678 Mtetra
.47796 .56678 .48347 .57226 .4933 .5693 .48781 .5638 Mtetra
.48781 .5638 .4933 .5693 .50317 .56632 .49771 .5608 Mtetra
.49771 .5608 .50317 .56632 .51308 .56334 .50763 .55779 Mtetra
.50763 .55779 .51308 .56334 .52302 .56034 .5176 .55478 Mtetra
.5176 .55478 .52302 .56034 .533 .55733 .5276 .55175 Mtetra
.5276 .55175 .533 .55733 .54301 .55431 .53764 .54871 Mtetra
.53764 .54871 .54301 .55431 .55306 .55128 .54771 .54566 Mtetra
.54771 .54566 .55306 .55128 .56314 .54824 .55782 .5426 Mtetra
.55782 .5426 .56314 .54824 .57327 .54519 .56797 .53953 Mtetra
.56797 .53953 .57327 .54519 .58343 .54213 .57815 .53644 Mtetra
.57815 .53644 .58343 .54213 .59363 .53905 .58837 .53335 Mtetra
.58837 .53335 .59363 .53905 .60386 .53597 .59864 .53024 Mtetra
.59864 .53024 .60386 .53597 .61413 .53287 .60893 .52712 Mtetra
.60893 .52712 .61413 .53287 .62444 .52976 .61927 .524 Mtetra
.61927 .524 .62444 .52976 .63479 .52664 .62964 .52085 Mtetra
.62964 .52085 .63479 .52664 .64518 .52351 .64006 .5177 Mtetra
.64006 .5177 .64518 .52351 .6556 .52037 .65051 .51454 Mtetra
.65051 .51454 .6556 .52037 .66607 .51722 .661 .51136 Mtetra
.661 .51136 .66607 .51722 .67657 .51405 .67153 .50817 Mtetra
.67153 .50817 .67657 .51405 .68711 .51087 .6821 .50497 Mtetra
.6821 .50497 .68711 .51087 .6977 .50768 .69271 .50176 Mtetra
.69271 .50176 .6977 .50768 .70832 .50448 .70336 .49854 Mtetra
.70336 .49854 .70832 .50448 .71898 .50127 .71405 .4953 Mtetra
.71405 .4953 .71898 .50127 .72968 .49804 .72477 .49205 Mtetra
.72477 .49205 .72968 .49804 .74042 .4948 .73554 .48879 Mtetra
.73554 .48879 .74042 .4948 .7512 .49155 .74636 .48552 Mtetra
.74636 .48552 .7512 .49155 .76203 .48829 .75721 .48223 Mtetra
.75721 .48223 .76203 .48829 .77289 .48501 .7681 .47893 Mtetra
.7681 .47893 .77289 .48501 .7838 .48173 .77903 .47562 Mtetra
.77903 .47562 .7838 .48173 .79474 .47843 .79001 .4723 Mtetra
.79001 .4723 .79474 .47843 .80573 .47511 .80103 .46897 Mtetra
.80103 .46897 .80573 .47511 .81676 .47179 .81209 .46562 Mtetra
.81209 .46562 .81676 .47179 .82783 .46845 .82319 .46226 Mtetra
.82319 .46226 .82783 .46845 .83895 .4651 .83434 .45888 Mtetra
.83434 .45888 .83895 .4651 .85011 .46174 .84553 .45549 Mtetra
.84553 .45549 .85011 .46174 .86131 .45836 .85676 .45209 Mtetra
.85676 .45209 .86131 .45836 .87255 .45497 .86803 .44868 Mtetra
.86803 .44868 .87255 .45497 .88384 .45157 .87935 .44525 Mtetra
.87935 .44525 .88384 .45157 .89517 .44815 .89071 .44181 Mtetra
.89071 .44181 .89517 .44815 .90654 .44472 .90212 .43836 Mtetra
.90212 .43836 .90654 .44472 .91796 .44128 .91357 .43489 Mtetra
.3005 .61354 .30643 .61871 .31568 .61591 .30977 .61072 Mtetra
.30977 .61072 .31568 .61591 .32495 .6131 .31906 .60789 Mtetra
.31906 .60789 .32495 .6131 .33427 .61028 .32839 .60506 Mtetra
.32839 .60506 .33427 .61028 .34361 .60746 .33776 .60221 Mtetra
.33776 .60221 .34361 .60746 .35299 .60462 .34715 .59935 Mtetra
.34715 .59935 .35299 .60462 .36239 .60177 .35658 .59648 Mtetra
.35658 .59648 .36239 .60177 .37184 .59891 .36605 .5936 Mtetra
.36605 .5936 .37184 .59891 .38131 .59604 .37555 .59072 Mtetra
.37555 .59072 .38131 .59604 .39082 .59316 .38508 .58782 Mtetra
.38508 .58782 .39082 .59316 .40037 .59027 .39464 .58491 Mtetra
.39464 .58491 .40037 .59027 .40995 .58737 .40424 .58199 Mtetra
.40424 .58199 .40995 .58737 .41956 .58446 .41387 .57906 Mtetra
.41387 .57906 .41956 .58446 .4292 .58154 .42354 .57612 Mtetra
.42354 .57612 .4292 .58154 .43888 .57861 .43324 .57317 Mtetra
.43324 .57317 .43888 .57861 .4486 .57567 .44298 .57021 Mtetra
.44298 .57021 .4486 .57567 .45835 .57272 .45276 .56724 Mtetra
.45276 .56724 .45835 .57272 .46814 .56975 .46256 .56426 Mtetra
.46256 .56426 .46814 .56975 .47796 .56678 .47241 .56126 Mtetra
.47241 .56126 .47796 .56678 .48781 .5638 .48229 .55826 Mtetra
.48229 .55826 .48781 .5638 .49771 .5608 .4922 .55524 Mtetra
.4922 .55524 .49771 .5608 .50763 .55779 .50215 .55222 Mtetra
.50215 .55222 .50763 .55779 .5176 .55478 .51214 .54918 Mtetra
.51214 .54918 .5176 .55478 .5276 .55175 .52217 .54613 Mtetra
.52217 .54613 .5276 .55175 .53764 .54871 .53223 .54307 Mtetra
.53223 .54307 .53764 .54871 .54771 .54566 .54232 .54 Mtetra
.54232 .54 .54771 .54566 .55782 .5426 .55246 .53692 Mtetra
.55246 .53692 .55782 .5426 .56797 .53953 .56263 .53383 Mtetra
.56263 .53383 .56797 .53953 .57815 .53644 .57284 .53072 Mtetra
.57284 .53072 .57815 .53644 .58837 .53335 .58309 .52761 Mtetra
.58309 .52761 .58837 .53335 .59864 .53024 .59337 .52448 Mtetra
.59337 .52448 .59864 .53024 .60893 .52712 .6037 .52134 Mtetra
.6037 .52134 .60893 .52712 .61927 .524 .61406 .51819 Mtetra
.61406 .51819 .61927 .524 .62964 .52085 .62446 .51503 Mtetra
.62446 .51503 .62964 .52085 .64006 .5177 .6349 .51185 Mtetra
.6349 .51185 .64006 .5177 .65051 .51454 .64538 .50866 Mtetra
.64538 .50866 .65051 .51454 .661 .51136 .65589 .50547 Mtetra
.65589 .50547 .661 .51136 .67153 .50817 .66645 .50226 Mtetra
.66645 .50226 .67153 .50817 .6821 .50497 .67705 .49903 Mtetra
.67705 .49903 .6821 .50497 .69271 .50176 .68768 .4958 Mtetra
.68768 .4958 .69271 .50176 .70336 .49854 .69836 .49255 Mtetra
.69836 .49255 .70336 .49854 .71405 .4953 .70908 .48929 Mtetra
.70908 .48929 .71405 .4953 .72477 .49205 .71984 .48602 Mtetra
.71984 .48602 .72477 .49205 .73554 .48879 .73063 .48274 Mtetra
.73063 .48274 .73554 .48879 .74636 .48552 .74147 .47944 Mtetra
.74147 .47944 .74636 .48552 .75721 .48223 .75235 .47613 Mtetra
.75235 .47613 .75721 .48223 .7681 .47893 .76328 .47281 Mtetra
.76328 .47281 .7681 .47893 .77903 .47562 .77424 .46948 Mtetra
.77424 .46948 .77903 .47562 .79001 .4723 .78524 .46613 Mtetra
.78524 .46613 .79001 .4723 .80103 .46897 .79629 .46277 Mtetra
.79629 .46277 .80103 .46897 .81209 .46562 .80738 .4594 Mtetra
.80738 .4594 .81209 .46562 .82319 .46226 .81852 .45602 Mtetra
.81852 .45602 .82319 .46226 .83434 .45888 .82969 .45262 Mtetra
.82969 .45262 .83434 .45888 .84553 .45549 .84091 .44921 Mtetra
.84091 .44921 .84553 .45549 .85676 .45209 .85217 .44578 Mtetra
.85217 .44578 .85676 .45209 .86803 .44868 .86348 .44234 Mtetra
.86348 .44234 .86803 .44868 .87935 .44525 .87483 .43889 Mtetra
.87483 .43889 .87935 .44525 .89071 .44181 .88623 .43543 Mtetra
.88623 .43543 .89071 .44181 .90212 .43836 .89766 .43195 Mtetra
.89766 .43195 .90212 .43836 .91357 .43489 .90915 .42846 Mtetra
.29453 .60833 .3005 .61354 .30977 .61072 .30382 .60549 Mtetra
.30382 .60549 .30977 .61072 .31906 .60789 .31313 .60265 Mtetra
.31313 .60265 .31906 .60789 .32839 .60506 .32249 .59979 Mtetra
.32249 .59979 .32839 .60506 .33776 .60221 .33187 .59693 Mtetra
.33187 .59693 .33776 .60221 .34715 .59935 .34129 .59405 Mtetra
.34129 .59405 .34715 .59935 .35658 .59648 .35074 .59116 Mtetra
.35074 .59116 .35658 .59648 .36605 .5936 .36022 .58827 Mtetra
.36022 .58827 .36605 .5936 .37555 .59072 .36974 .58536 Mtetra
.36974 .58536 .37555 .59072 .38508 .58782 .37929 .58244 Mtetra
.37929 .58244 .38508 .58782 .39464 .58491 .38888 .57951 Mtetra
.38888 .57951 .39464 .58491 .40424 .58199 .3985 .57657 Mtetra
.3985 .57657 .40424 .58199 .41387 .57906 .40815 .57363 Mtetra
.40815 .57363 .41387 .57906 .42354 .57612 .41784 .57067 Mtetra
.41784 .57067 .42354 .57612 .43324 .57317 .42757 .5677 Mtetra
.42757 .5677 .43324 .57317 .44298 .57021 .43733 .56471 Mtetra
.43733 .56471 .44298 .57021 .45276 .56724 .44712 .56172 Mtetra
.44712 .56172 .45276 .56724 .46256 .56426 .45695 .55872 Mtetra
.45695 .55872 .46256 .56426 .47241 .56126 .46682 .55571 Mtetra
.46682 .55571 .47241 .56126 .48229 .55826 .47672 .55268 Mtetra
.47672 .55268 .48229 .55826 .4922 .55524 .48666 .54965 Mtetra
.48666 .54965 .4922 .55524 .50215 .55222 .49664 .5466 Mtetra
.49664 .5466 .50215 .55222 .51214 .54918 .50665 .54354 Mtetra
.50665 .54354 .51214 .54918 .52217 .54613 .5167 .54047 Mtetra
.5167 .54047 .52217 .54613 .53223 .54307 .52678 .53739 Mtetra
.52678 .53739 .53223 .54307 .54232 .54 .5369 .5343 Mtetra
.5369 .5343 .54232 .54 .55246 .53692 .54706 .5312 Mtetra
.54706 .5312 .55246 .53692 .56263 .53383 .55726 .52809 Mtetra
.55726 .52809 .56263 .53383 .57284 .53072 .56749 .52496 Mtetra
.56749 .52496 .57284 .53072 .58309 .52761 .57777 .52182 Mtetra
.57777 .52182 .58309 .52761 .59337 .52448 .58808 .51867 Mtetra
.58808 .51867 .59337 .52448 .6037 .52134 .59843 .51551 Mtetra
.59843 .51551 .6037 .52134 .61406 .51819 .60881 .51234 Mtetra
.60881 .51234 .61406 .51819 .62446 .51503 .61924 .50916 Mtetra
.61924 .50916 .62446 .51503 .6349 .51185 .62971 .50596 Mtetra
.62971 .50596 .6349 .51185 .64538 .50866 .64021 .50275 Mtetra
.64021 .50275 .64538 .50866 .65589 .50547 .65075 .49953 Mtetra
.65075 .49953 .65589 .50547 .66645 .50226 .66134 .4963 Mtetra
.66134 .4963 .66645 .50226 .67705 .49903 .67196 .49305 Mtetra
.67196 .49305 .67705 .49903 .68768 .4958 .68263 .4898 Mtetra
.68263 .4898 .68768 .4958 .69836 .49255 .69333 .48653 Mtetra
.69333 .48653 .69836 .49255 .70908 .48929 .70408 .48325 Mtetra
.70408 .48325 .70908 .48929 .71984 .48602 .71486 .47995 Mtetra
.71486 .47995 .71984 .48602 .73063 .48274 .72569 .47664 Mtetra
.72569 .47664 .73063 .48274 .74147 .47944 .73656 .47333 Mtetra
.73656 .47333 .74147 .47944 .75235 .47613 .74746 .46999 Mtetra
.74746 .46999 .75235 .47613 .76328 .47281 .75842 .46665 Mtetra
.75842 .46665 .76328 .47281 .77424 .46948 .76941 .46329 Mtetra
.76941 .46329 .77424 .46948 .78524 .46613 .78044 .45992 Mtetra
.78044 .45992 .78524 .46613 .79629 .46277 .79152 .45654 Mtetra
.79152 .45654 .79629 .46277 .80738 .4594 .80264 .45314 Mtetra
.80264 .45314 .80738 .4594 .81852 .45602 .81381 .44973 Mtetra
.81381 .44973 .81852 .45602 .82969 .45262 .82501 .44631 Mtetra
.82501 .44631 .82969 .45262 .84091 .44921 .83626 .44287 Mtetra
.83626 .44287 .84091 .44921 .85217 .44578 .84756 .43943 Mtetra
.84756 .43943 .85217 .44578 .86348 .44234 .8589 .43596 Mtetra
.8589 .43596 .86348 .44234 .87483 .43889 .87028 .43249 Mtetra
.87028 .43249 .87483 .43889 .88623 .43543 .88171 .429 Mtetra
.88171 .429 .88623 .43543 .89766 .43195 .89318 .42549 Mtetra
.89318 .42549 .89766 .43195 .90915 .42846 .90469 .42197 Mtetra
.28853 .60308 .29453 .60833 .30382 .60549 .29783 .60023 Mtetra
.29783 .60023 .30382 .60549 .31313 .60265 .30717 .59737 Mtetra
.656 .752 .92 r
.30717 .59737 .31313 .60265 .32249 .59979 .31654 .5945 Mtetra
.31654 .5945 .32249 .59979 .33187 .59693 .32594 .59161 Mtetra
.32594 .59161 .33187 .59693 .34129 .59405 .33538 .58872 Mtetra
.33538 .58872 .34129 .59405 .35074 .59116 .34485 .58581 Mtetra
.34485 .58581 .35074 .59116 .36022 .58827 .35435 .58289 Mtetra
.35435 .58289 .36022 .58827 .36974 .58536 .36389 .57997 Mtetra
.656 .751 .92 r
.36389 .57997 .36974 .58536 .37929 .58244 .37347 .57703 Mtetra
.37347 .57703 .37929 .58244 .38888 .57951 .38307 .57408 Mtetra
.38307 .57408 .38888 .57951 .3985 .57657 .39272 .57112 Mtetra
.39272 .57112 .3985 .57657 .40815 .57363 .40239 .56815 Mtetra
.40239 .56815 .40815 .57363 .41784 .57067 .41211 .56517 Mtetra
.41211 .56517 .41784 .57067 .42757 .5677 .42185 .56218 Mtetra
.42185 .56218 .42757 .5677 .43733 .56471 .43163 .55918 Mtetra
.43163 .55918 .43733 .56471 .44712 .56172 .44145 .55617 Mtetra
.44145 .55617 .44712 .56172 .45695 .55872 .45131 .55315 Mtetra
.45131 .55315 .45695 .55872 .46682 .55571 .4612 .55012 Mtetra
.4612 .55012 .46682 .55571 .47672 .55268 .47112 .54707 Mtetra
.47112 .54707 .47672 .55268 .48666 .54965 .48108 .54401 Mtetra
.48108 .54401 .48666 .54965 .49664 .5466 .49108 .54095 Mtetra
.49108 .54095 .49664 .5466 .50665 .54354 .50112 .53787 Mtetra
.50112 .53787 .50665 .54354 .5167 .54047 .51119 .53478 Mtetra
.51119 .53478 .5167 .54047 .52678 .53739 .5213 .53168 Mtetra
.5213 .53168 .52678 .53739 .5369 .5343 .53144 .52857 Mtetra
.53144 .52857 .5369 .5343 .54706 .5312 .54163 .52544 Mtetra
.54163 .52544 .54706 .5312 .55726 .52809 .55185 .52231 Mtetra
.55185 .52231 .55726 .52809 .56749 .52496 .56211 .51916 Mtetra
.56211 .51916 .56749 .52496 .57777 .52182 .57241 .516 Mtetra
.57241 .516 .57777 .52182 .58808 .51867 .58274 .51283 Mtetra
.58274 .51283 .58808 .51867 .59843 .51551 .59312 .50965 Mtetra
.59312 .50965 .59843 .51551 .60881 .51234 .60353 .50645 Mtetra
.60353 .50645 .60881 .51234 .61924 .50916 .61398 .50324 Mtetra
.61398 .50324 .61924 .50916 .62971 .50596 .62448 .50003 Mtetra
.62448 .50003 .62971 .50596 .64021 .50275 .63501 .4968 Mtetra
.63501 .4968 .64021 .50275 .65075 .49953 .64558 .49355 Mtetra
.64558 .49355 .65075 .49953 .66134 .4963 .65619 .4903 Mtetra
.65619 .4903 .66134 .4963 .67196 .49305 .66684 .48703 Mtetra
.66684 .48703 .67196 .49305 .68263 .4898 .67753 .48375 Mtetra
.67753 .48375 .68263 .4898 .69333 .48653 .68826 .48046 Mtetra
.68826 .48046 .69333 .48653 .70408 .48325 .69904 .47715 Mtetra
.69904 .47715 .70408 .48325 .71486 .47995 .70985 .47384 Mtetra
.70985 .47384 .71486 .47995 .72569 .47664 .72071 .47051 Mtetra
.72071 .47051 .72569 .47664 .73656 .47333 .7316 .46716 Mtetra
.7316 .46716 .73656 .47333 .74746 .46999 .74254 .46381 Mtetra
.74254 .46381 .74746 .46999 .75842 .46665 .75352 .46044 Mtetra
.75352 .46044 .75842 .46665 .76941 .46329 .76455 .45706 Mtetra
.76455 .45706 .76941 .46329 .78044 .45992 .77561 .45366 Mtetra
.77561 .45366 .78044 .45992 .79152 .45654 .78672 .45026 Mtetra
.78672 .45026 .79152 .45654 .80264 .45314 .79787 .44684 Mtetra
.79787 .44684 .80264 .45314 .81381 .44973 .80906 .44341 Mtetra
.80906 .44341 .81381 .44973 .82501 .44631 .8203 .43996 Mtetra
.8203 .43996 .82501 .44631 .83626 .44287 .83158 .4365 Mtetra
.656 .752 .92 r
.83158 .4365 .83626 .44287 .84756 .43943 .84291 .43303 Mtetra
.84291 .43303 .84756 .43943 .8589 .43596 .85428 .42954 Mtetra
.85428 .42954 .8589 .43596 .87028 .43249 .86569 .42604 Mtetra
.86569 .42604 .87028 .43249 .88171 .429 .87715 .42252 Mtetra
.87715 .42252 .88171 .429 .89318 .42549 .88866 .41899 Mtetra
.88866 .41899 .89318 .42549 .90469 .42197 .90021 .41544 Mtetra
.655 .751 .92 r
.28248 .59781 .28853 .60308 .29783 .60023 .2918 .59494 Mtetra
.656 .751 .92 r
.2918 .59494 .29783 .60023 .30717 .59737 .30116 .59206 Mtetra
.656 .752 .921 r
.30116 .59206 .30717 .59737 .31654 .5945 .31055 .58917 Mtetra
.31055 .58917 .31654 .5945 .32594 .59161 .31997 .58627 Mtetra
.31997 .58627 .32594 .59161 .33538 .58872 .32943 .58336 Mtetra
.32943 .58336 .33538 .58872 .34485 .58581 .33892 .58043 Mtetra
.656 .752 .92 r
.33892 .58043 .34485 .58581 .35435 .58289 .34845 .57749 Mtetra
.34845 .57749 .35435 .58289 .36389 .57997 .35801 .57454 Mtetra
.35801 .57454 .36389 .57997 .37347 .57703 .3676 .57158 Mtetra
.3676 .57158 .37347 .57703 .38307 .57408 .37723 .56862 Mtetra
.37723 .56862 .38307 .57408 .39272 .57112 .3869 .56564 Mtetra
.656 .751 .92 r
.3869 .56564 .39272 .57112 .40239 .56815 .3966 .56265 Mtetra
.3966 .56265 .40239 .56815 .41211 .56517 .40633 .55965 Mtetra
.40633 .55965 .41211 .56517 .42185 .56218 .4161 .55664 Mtetra
.4161 .55664 .42185 .56218 .43163 .55918 .4259 .55361 Mtetra
.4259 .55361 .43163 .55918 .44145 .55617 .43574 .55058 Mtetra
.43574 .55058 .44145 .55617 .45131 .55315 .44562 .54754 Mtetra
.44562 .54754 .45131 .55315 .4612 .55012 .45553 .54449 Mtetra
.45553 .54449 .4612 .55012 .47112 .54707 .46548 .54142 Mtetra
.46548 .54142 .47112 .54707 .48108 .54401 .47547 .53834 Mtetra
.47547 .53834 .48108 .54401 .49108 .54095 .48549 .53526 Mtetra
.48549 .53526 .49108 .54095 .50112 .53787 .49555 .53216 Mtetra
.49555 .53216 .50112 .53787 .51119 .53478 .50564 .52905 Mtetra
.50564 .52905 .51119 .53478 .5213 .53168 .51578 .52592 Mtetra
.51578 .52592 .5213 .53168 .53144 .52857 .52595 .52279 Mtetra
.52595 .52279 .53144 .52857 .54163 .52544 .53616 .51964 Mtetra
.53616 .51964 .54163 .52544 .55185 .52231 .5464 .51649 Mtetra
.5464 .51649 .55185 .52231 .56211 .51916 .55669 .51332 Mtetra
.55669 .51332 .56211 .51916 .57241 .516 .56701 .51014 Mtetra
.56701 .51014 .57241 .516 .58274 .51283 .57737 .50694 Mtetra
.57737 .50694 .58274 .51283 .59312 .50965 .58777 .50374 Mtetra
.58777 .50374 .59312 .50965 .60353 .50645 .59821 .50052 Mtetra
.59821 .50052 .60353 .50645 .61398 .50324 .60869 .49729 Mtetra
.60869 .49729 .61398 .50324 .62448 .50003 .61921 .49405 Mtetra
.61921 .49405 .62448 .50003 .63501 .4968 .62977 .4908 Mtetra
.62977 .4908 .63501 .4968 .64558 .49355 .64037 .48753 Mtetra
.64037 .48753 .64558 .49355 .65619 .4903 .65101 .48426 Mtetra
.65101 .48426 .65619 .4903 .66684 .48703 .66168 .48097 Mtetra
.66168 .48097 .66684 .48703 .67753 .48375 .6724 .47766 Mtetra
.6724 .47766 .67753 .48375 .68826 .48046 .68316 .47435 Mtetra
.68316 .47435 .68826 .48046 .69904 .47715 .69396 .47102 Mtetra
.69396 .47102 .69904 .47715 .70985 .47384 .70481 .46768 Mtetra
.70481 .46768 .70985 .47384 .72071 .47051 .71569 .46433 Mtetra
.71569 .46433 .72071 .47051 .7316 .46716 .72662 .46096 Mtetra
.72662 .46096 .7316 .46716 .74254 .46381 .73758 .45758 Mtetra
.73758 .45758 .74254 .46381 .75352 .46044 .74859 .45419 Mtetra
.74859 .45419 .75352 .46044 .76455 .45706 .75965 .45078 Mtetra
.75965 .45078 .76455 .45706 .77561 .45366 .77074 .44737 Mtetra
.77074 .44737 .77561 .45366 .78672 .45026 .78188 .44394 Mtetra
.78188 .44394 .78672 .45026 .79787 .44684 .79306 .44049 Mtetra
.656 .752 .92 r
.79306 .44049 .79787 .44684 .80906 .44341 .80429 .43704 Mtetra
.80429 .43704 .80906 .44341 .8203 .43996 .81556 .43357 Mtetra
.656 .752 .921 r
.81556 .43357 .8203 .43996 .83158 .4365 .82687 .43009 Mtetra
.82687 .43009 .83158 .4365 .84291 .43303 .83823 .42659 Mtetra
.83823 .42659 .84291 .43303 .85428 .42954 .84963 .42308 Mtetra
.84963 .42308 .85428 .42954 .86569 .42604 .86108 .41955 Mtetra
.656 .752 .92 r
.86108 .41955 .86569 .42604 .87715 .42252 .87257 .416 Mtetra
.87257 .416 .87715 .42252 .88866 .41899 .88411 .41244 Mtetra
.88411 .41244 .88866 .41899 .90021 .41544 .89569 .40886 Mtetra
.655 .751 .921 r
.27639 .59249 .28248 .59781 .2918 .59494 .28574 .58962 Mtetra
.655 .752 .921 r
.28574 .58962 .2918 .59494 .30116 .59206 .29511 .58673 Mtetra
.29511 .58673 .30116 .59206 .31055 .58917 .30452 .58383 Mtetra
.656 .752 .921 r
.30452 .58383 .31055 .58917 .31997 .58627 .31397 .58091 Mtetra
.31397 .58091 .31997 .58627 .32943 .58336 .32344 .57797 Mtetra
.32344 .57797 .32943 .58336 .33892 .58043 .33296 .57502 Mtetra
.33296 .57502 .33892 .58043 .34845 .57749 .3425 .57206 Mtetra
.3425 .57206 .34845 .57749 .35801 .57454 .35209 .56909 Mtetra
.35209 .56909 .35801 .57454 .3676 .57158 .3617 .56611 Mtetra
.656 .752 .92 r
.3617 .56611 .3676 .57158 .37723 .56862 .37135 .56312 Mtetra
.37135 .56312 .37723 .56862 .3869 .56564 .38104 .56011 Mtetra
.38104 .56011 .3869 .56564 .3966 .56265 .39076 .5571 Mtetra
.39076 .5571 .3966 .56265 .40633 .55965 .40052 .55408 Mtetra
.656 .751 .92 r
.40052 .55408 .40633 .55965 .4161 .55664 .41031 .55105 Mtetra
.41031 .55105 .4161 .55664 .4259 .55361 .42013 .54801 Mtetra
.42013 .54801 .4259 .55361 .43574 .55058 .43 .54496 Mtetra
.43 .54496 .43574 .55058 .44562 .54754 .4399 .54189 Mtetra
.4399 .54189 .44562 .54754 .45553 .54449 .44983 .53882 Mtetra
.44983 .53882 .45553 .54449 .46548 .54142 .4598 .53573 Mtetra
.4598 .53573 .46548 .54142 .47547 .53834 .46981 .53263 Mtetra
.46981 .53263 .47547 .53834 .48549 .53526 .47986 .52952 Mtetra
.47986 .52952 .48549 .53526 .49555 .53216 .48994 .5264 Mtetra
.48994 .5264 .49555 .53216 .50564 .52905 .50006 .52327 Mtetra
.50006 .52327 .50564 .52905 .51578 .52592 .51022 .52013 Mtetra
.51022 .52013 .51578 .52592 .52595 .52279 .52041 .51697 Mtetra
.52041 .51697 .52595 .52279 .53616 .51964 .53065 .51381 Mtetra
.53065 .51381 .53616 .51964 .5464 .51649 .54092 .51063 Mtetra
.54092 .51063 .5464 .51649 .55669 .51332 .55123 .50744 Mtetra
.55123 .50744 .55669 .51332 .56701 .51014 .56158 .50423 Mtetra
.56158 .50423 .56701 .51014 .57737 .50694 .57197 .50102 Mtetra
.57197 .50102 .57737 .50694 .58777 .50374 .58239 .49779 Mtetra
.58239 .49779 .58777 .50374 .59821 .50052 .59286 .49455 Mtetra
.59286 .49455 .59821 .50052 .60869 .49729 .60336 .4913 Mtetra
.60336 .4913 .60869 .49729 .61921 .49405 .61391 .48804 Mtetra
.61391 .48804 .61921 .49405 .62977 .4908 .62449 .48476 Mtetra
.62449 .48476 .62977 .4908 .64037 .48753 .63512 .48147 Mtetra
.63512 .48147 .64037 .48753 .65101 .48426 .64578 .47817 Mtetra
.64578 .47817 .65101 .48426 .66168 .48097 .65649 .47486 Mtetra
.65649 .47486 .66168 .48097 .6724 .47766 .66724 .47153 Mtetra
.66724 .47153 .6724 .47766 .68316 .47435 .67803 .46819 Mtetra
.67803 .46819 .68316 .47435 .69396 .47102 .68886 .46484 Mtetra
.68886 .46484 .69396 .47102 .70481 .46768 .69973 .46148 Mtetra
.69973 .46148 .70481 .46768 .71569 .46433 .71064 .4581 Mtetra
.71064 .4581 .71569 .46433 .72662 .46096 .72159 .45471 Mtetra
.72159 .45471 .72662 .46096 .73758 .45758 .73259 .45131 Mtetra
.73259 .45131 .73758 .45758 .74859 .45419 .74363 .44789 Mtetra
.74363 .44789 .74859 .45419 .75965 .45078 .75471 .44446 Mtetra
.75471 .44446 .75965 .45078 .77074 .44737 .76584 .44102 Mtetra
.76584 .44102 .77074 .44737 .78188 .44394 .77701 .43757 Mtetra
.656 .752 .921 r
.77701 .43757 .78188 .44394 .79306 .44049 .78822 .43411 Mtetra
.78822 .43411 .79306 .44049 .80429 .43704 .79948 .43063 Mtetra
.655 .752 .921 r
.79948 .43063 .80429 .43704 .81556 .43357 .81078 .42714 Mtetra
.81078 .42714 .81556 .43357 .82687 .43009 .82213 .42364 Mtetra
.656 .752 .921 r
.82213 .42364 .82687 .43009 .83823 .42659 .83351 .42012 Mtetra
.83351 .42012 .83823 .42659 .84963 .42308 .84495 .41658 Mtetra
.84495 .41658 .84963 .42308 .86108 .41955 .85643 .41302 Mtetra
.85643 .41302 .86108 .41955 .87257 .416 .86795 .40945 Mtetra
.86795 .40945 .87257 .416 .88411 .41244 .87952 .40585 Mtetra
.656 .752 .92 r
.87952 .40585 .88411 .41244 .89569 .40886 .89113 .40224 Mtetra
.654 .751 .921 r
.27027 .58715 .27639 .59249 .28574 .58962 .27963 .58427 Mtetra
.655 .752 .921 r
.27963 .58427 .28574 .58962 .29511 .58673 .28902 .58138 Mtetra
.28902 .58138 .29511 .58673 .30452 .58383 .29845 .57846 Mtetra
.655 .753 .922 r
.29845 .57846 .30452 .58383 .31397 .58091 .30792 .57553 Mtetra
.656 .753 .922 r
.30792 .57553 .31397 .58091 .32344 .57797 .31742 .57258 Mtetra
.656 .753 .921 r
.31742 .57258 .32344 .57797 .33296 .57502 .32695 .56961 Mtetra
.32695 .56961 .33296 .57502 .3425 .57206 .33652 .56662 Mtetra
.33652 .56662 .3425 .57206 .35209 .56909 .34612 .56362 Mtetra
.34612 .56362 .35209 .56909 .3617 .56611 .35576 .56061 Mtetra
.656 .752 .921 r
.35576 .56061 .3617 .56611 .37135 .56312 .36543 .55759 Mtetra
.36543 .55759 .37135 .56312 .38104 .56011 .37514 .55457 Mtetra
.37514 .55457 .38104 .56011 .39076 .5571 .38488 .55153 Mtetra
.656 .752 .92 r
.38488 .55153 .39076 .5571 .40052 .55408 .39466 .54849 Mtetra
.39466 .54849 .40052 .55408 .41031 .55105 .40448 .54543 Mtetra
.40448 .54543 .41031 .55105 .42013 .54801 .41432 .54237 Mtetra
.656 .751 .92 r
.41432 .54237 .42013 .54801 .43 .54496 .42421 .53929 Mtetra
.42421 .53929 .43 .54496 .4399 .54189 .43413 .53621 Mtetra
.43413 .53621 .4399 .54189 .44983 .53882 .44409 .53311 Mtetra
.44409 .53311 .44983 .53882 .4598 .53573 .45409 .53 Mtetra
.45409 .53 .4598 .53573 .46981 .53263 .46412 .52688 Mtetra
.46412 .52688 .46981 .53263 .47986 .52952 .47419 .52375 Mtetra
.47419 .52375 .47986 .52952 .48994 .5264 .4843 .52061 Mtetra
.4843 .52061 .48994 .5264 .50006 .52327 .49444 .51746 Mtetra
.49444 .51746 .50006 .52327 .51022 .52013 .50462 .51429 Mtetra
.50462 .51429 .51022 .52013 .52041 .51697 .51484 .51112 Mtetra
.51484 .51112 .52041 .51697 .53065 .51381 .5251 .50793 Mtetra
.5251 .50793 .53065 .51381 .54092 .51063 .5354 .50473 Mtetra
.5354 .50473 .54092 .51063 .55123 .50744 .54573 .50151 Mtetra
.54573 .50151 .55123 .50744 .56158 .50423 .55611 .49829 Mtetra
.55611 .49829 .56158 .50423 .57197 .50102 .56652 .49505 Mtetra
.56652 .49505 .57197 .50102 .58239 .49779 .57697 .4918 Mtetra
.57697 .4918 .58239 .49779 .59286 .49455 .58747 .48854 Mtetra
.58747 .48854 .59286 .49455 .60336 .4913 .598 .48527 Mtetra
.598 .48527 .60336 .4913 .61391 .48804 .60857 .48198 Mtetra
.60857 .48198 .61391 .48804 .62449 .48476 .61918 .47868 Mtetra
.61918 .47868 .62449 .48476 .63512 .48147 .62983 .47537 Mtetra
.62983 .47537 .63512 .48147 .64578 .47817 .64053 .47205 Mtetra
.64053 .47205 .64578 .47817 .65649 .47486 .65126 .46871 Mtetra
.65126 .46871 .65649 .47486 .66724 .47153 .66204 .46536 Mtetra
.66204 .46536 .66724 .47153 .67803 .46819 .67285 .462 Mtetra
.67285 .462 .67803 .46819 .68886 .46484 .68371 .45862 Mtetra
.68371 .45862 .68886 .46484 .69973 .46148 .69461 .45523 Mtetra
.69461 .45523 .69973 .46148 .71064 .4581 .70555 .45183 Mtetra
.70555 .45183 .71064 .4581 .72159 .45471 .71654 .44842 Mtetra
.71654 .44842 .72159 .45471 .73259 .45131 .72756 .44499 Mtetra
.72756 .44499 .73259 .45131 .74363 .44789 .73863 .44156 Mtetra
.656 .752 .92 r
.73863 .44156 .74363 .44789 .75471 .44446 .74975 .43811 Mtetra
.655 .752 .921 r
.74975 .43811 .75471 .44446 .76584 .44102 .7609 .43465 Mtetra
.7609 .43465 .76584 .44102 .77701 .43757 .7721 .43117 Mtetra
.7721 .43117 .77701 .43757 .78822 .43411 .78335 .42769 Mtetra
.78335 .42769 .78822 .43411 .79948 .43063 .79464 .4242 Mtetra
.79464 .4242 .79948 .43063 .81078 .42714 .80597 .42069 Mtetra
.655 .753 .922 r
.80597 .42069 .81078 .42714 .82213 .42364 .81735 .41717 Mtetra
.81735 .41717 .82213 .42364 .83351 .42012 .82877 .41362 Mtetra
.656 .753 .922 r
.82877 .41362 .83351 .42012 .84495 .41658 .84024 .41006 Mtetra
.656 .753 .921 r
.84024 .41006 .84495 .41658 .85643 .41302 .85175 .40647 Mtetra
.85175 .40647 .85643 .41302 .86795 .40945 .8633 .40286 Mtetra
.657 .753 .921 r
.8633 .40286 .86795 .40945 .87952 .40585 .8749 .39922 Mtetra
.657 .753 .92 r
.8749 .39922 .87952 .40585 .89113 .40224 .88655 .39556 Mtetra
.653 .751 .921 r
.2641 .58177 .27027 .58715 .27963 .58427 .27348 .5789 Mtetra
.653 .752 .922 r
.27348 .5789 .27963 .58427 .28902 .58138 .28289 .57601 Mtetra
.654 .753 .923 r
.28289 .57601 .28902 .58138 .29845 .57846 .29234 .5731 Mtetra
.655 .754 .923 r
.29234 .5731 .29845 .57846 .30792 .57553 .30182 .57017 Mtetra
.655 .755 .923 r
.30182 .57017 .30792 .57553 .31742 .57258 .31134 .5672 Mtetra
.656 .755 .923 r
.31134 .5672 .31742 .57258 .32695 .56961 .3209 .56421 Mtetra
.3209 .56421 .32695 .56961 .33652 .56662 .33049 .56119 Mtetra
.657 .755 .922 r
.33049 .56119 .33652 .56662 .34612 .56362 .34012 .55816 Mtetra
.657 .754 .922 r
.34012 .55816 .34612 .56362 .35576 .56061 .34978 .55511 Mtetra
.657 .754 .921 r
.34978 .55511 .35576 .56061 .36543 .55759 .35947 .55206 Mtetra
.657 .753 .921 r
.35947 .55206 .36543 .55759 .37514 .55457 .3692 .549 Mtetra
.656 .753 .921 r
.3692 .549 .37514 .55457 .38488 .55153 .37897 .54593 Mtetra
.656 .752 .921 r
.37897 .54593 .38488 .55153 .39466 .54849 .38877 .54286 Mtetra
.38877 .54286 .39466 .54849 .40448 .54543 .3986 .53978 Mtetra
.656 .752 .92 r
.3986 .53978 .40448 .54543 .41432 .54237 .40848 .53669 Mtetra
.40848 .53669 .41432 .54237 .42421 .53929 .41839 .53359 Mtetra
.41839 .53359 .42421 .53929 .43413 .53621 .42833 .53048 Mtetra
.656 .751 .92 r
.42833 .53048 .43413 .53621 .44409 .53311 .43831 .52737 Mtetra
.43831 .52737 .44409 .53311 .45409 .53 .44833 .52424 Mtetra
.44833 .52424 .45409 .53 .46412 .52688 .45839 .5211 Mtetra
.45839 .5211 .46412 .52688 .47419 .52375 .46848 .51794 Mtetra
.46848 .51794 .47419 .52375 .4843 .52061 .47861 .51478 Mtetra
.47861 .51478 .4843 .52061 .49444 .51746 .48878 .51161 Mtetra
.48878 .51161 .49444 .51746 .50462 .51429 .49899 .50842 Mtetra
.49899 .50842 .50462 .51429 .51484 .51112 .50923 .50522 Mtetra
.50923 .50522 .51484 .51112 .5251 .50793 .51952 .50201 Mtetra
.51952 .50201 .5251 .50793 .5354 .50473 .52984 .49879 Mtetra
.52984 .49879 .5354 .50473 .54573 .50151 .5402 .49555 Mtetra
.5402 .49555 .54573 .50151 .55611 .49829 .5506 .4923 Mtetra
.5506 .4923 .55611 .49829 .56652 .49505 .56104 .48904 Mtetra
.56104 .48904 .56652 .49505 .57697 .4918 .57152 .48577 Mtetra
.57152 .48577 .57697 .4918 .58747 .48854 .58203 .48249 Mtetra
.58203 .48249 .58747 .48854 .598 .48527 .59259 .47919 Mtetra
.59259 .47919 .598 .48527 .60857 .48198 .60319 .47588 Mtetra
.60319 .47588 .60857 .48198 .61918 .47868 .61383 .47256 Mtetra
.61383 .47256 .61918 .47868 .62983 .47537 .62451 .46922 Mtetra
.62451 .46922 .62983 .47537 .64053 .47205 .63523 .46587 Mtetra
.63523 .46587 .64053 .47205 .65126 .46871 .64599 .46251 Mtetra
.64599 .46251 .65126 .46871 .66204 .46536 .6568 .45914 Mtetra
.6568 .45914 .66204 .46536 .67285 .462 .66764 .45575 Mtetra
.66764 .45575 .67285 .462 .68371 .45862 .67853 .45236 Mtetra
.67853 .45236 .68371 .45862 .69461 .45523 .68946 .44894 Mtetra
.68946 .44894 .69461 .45523 .70555 .45183 .70043 .44552 Mtetra
.70043 .44552 .70555 .45183 .71654 .44842 .71144 .44209 Mtetra
.71144 .44209 .71654 .44842 .72756 .44499 .7225 .43864 Mtetra
.655 .752 .921 r
.7225 .43864 .72756 .44499 .73863 .44156 .7336 .43518 Mtetra
.7336 .43518 .73863 .44156 .74975 .43811 .74474 .43172 Mtetra
.74474 .43172 .74975 .43811 .7609 .43465 .75593 .42824 Mtetra
.75593 .42824 .7609 .43465 .7721 .43117 .76716 .42476 Mtetra
.655 .753 .922 r
.76716 .42476 .7721 .43117 .78335 .42769 .77844 .42127 Mtetra
.77844 .42127 .78335 .42769 .79464 .4242 .78976 .41776 Mtetra
.655 .754 .923 r
.78976 .41776 .79464 .4242 .80597 .42069 .80113 .41424 Mtetra
.80113 .41424 .80597 .42069 .81735 .41717 .81254 .4107 Mtetra
.655 .755 .923 r
.81254 .4107 .81735 .41717 .82877 .41362 .82399 .40714 Mtetra
.656 .755 .923 r
.82399 .40714 .82877 .41362 .84024 .41006 .83549 .40354 Mtetra
.657 .755 .923 r
.83549 .40354 .84024 .41006 .85175 .40647 .84703 .39991 Mtetra
.657 .755 .922 r
.84703 .39991 .85175 .40647 .8633 .40286 .85862 .39625 Mtetra
.658 .754 .921 r
.85862 .39625 .8633 .40286 .8749 .39922 .87025 .39256 Mtetra
.658 .754 .92 r
.87025 .39256 .8749 .39922 .88655 .39556 .88193 .38884 Mtetra
.651 .75 .922 r
.25789 .57635 .2641 .58177 .27348 .5789 .26729 .57351 Mtetra
.651 .752 .923 r
.26729 .57351 .27348 .5789 .28289 .57601 .27672 .57065 Mtetra
.652 .754 .924 r
.27672 .57065 .28289 .57601 .29234 .5731 .28618 .56776 Mtetra
.653 .756 .925 r
.28618 .56776 .29234 .5731 .30182 .57017 .29569 .56484 Mtetra
.654 .757 .925 r
.29569 .56484 .30182 .57017 .31134 .5672 .30523 .56187 Mtetra
.656 .758 .925 r
.30523 .56187 .31134 .5672 .3209 .56421 .3148 .55886 Mtetra
.657 .758 .925 r
.3148 .55886 .3209 .56421 .33049 .56119 .32442 .55581 Mtetra
.657 .758 .924 r
.32442 .55581 .33049 .56119 .34012 .55816 .33406 .55274 Mtetra
.658 .758 .924 r
.33406 .55274 .34012 .55816 .34978 .55511 .34375 .54965 Mtetra
.658 .757 .923 r
.34375 .54965 .34978 .55511 .35947 .55206 .35347 .54655 Mtetra
.658 .756 .922 r
.35347 .54655 .35947 .55206 .3692 .549 .36322 .54345 Mtetra
.657 .755 .922 r
.36322 .54345 .3692 .549 .37897 .54593 .37301 .54034 Mtetra
.657 .754 .921 r
.37301 .54034 .37897 .54593 .38877 .54286 .38283 .53722 Mtetra
.657 .753 .921 r
.38283 .53722 .38877 .54286 .3986 .53978 .39269 .53411 Mtetra
.656 .753 .921 r
.39269 .53411 .3986 .53978 .40848 .53669 .40259 .53099 Mtetra
.656 .752 .921 r
.40259 .53099 .40848 .53669 .41839 .53359 .41252 .52786 Mtetra
.41252 .52786 .41839 .53359 .42833 .53048 .42249 .52473 Mtetra
.656 .752 .92 r
.42249 .52473 .42833 .53048 .43831 .52737 .43249 .52159 Mtetra
.43249 .52159 .43831 .52737 .44833 .52424 .44254 .51844 Mtetra
.44254 .51844 .44833 .52424 .45839 .5211 .45262 .51527 Mtetra
.45262 .51527 .45839 .5211 .46848 .51794 .46273 .5121 Mtetra
.656 .751 .92 r
.46273 .5121 .46848 .51794 .47861 .51478 .47289 .50891 Mtetra
.47289 .50891 .47861 .51478 .48878 .51161 .48308 .50571 Mtetra
.48308 .50571 .48878 .51161 .49899 .50842 .49331 .5025 Mtetra
.49331 .5025 .49899 .50842 .50923 .50522 .50358 .49928 Mtetra
.50358 .49928 .50923 .50522 .51952 .50201 .51389 .49605 Mtetra
.51389 .49605 .51952 .50201 .52984 .49879 .52424 .4928 Mtetra
.52424 .4928 .52984 .49879 .5402 .49555 .53463 .48955 Mtetra
.53463 .48955 .5402 .49555 .5506 .4923 .54505 .48628 Mtetra
.54505 .48628 .5506 .4923 .56104 .48904 .55552 .48299 Mtetra
.55552 .48299 .56104 .48904 .57152 .48577 .56602 .4797 Mtetra
.56602 .4797 .57152 .48577 .58203 .48249 .57657 .47639 Mtetra
.57657 .47639 .58203 .48249 .59259 .47919 .58715 .47307 Mtetra
.58715 .47307 .59259 .47919 .60319 .47588 .59778 .46974 Mtetra
.59778 .46974 .60319 .47588 .61383 .47256 .60844 .46639 Mtetra
.60844 .46639 .61383 .47256 .62451 .46922 .61915 .46303 Mtetra
.61915 .46303 .62451 .46922 .63523 .46587 .6299 .45966 Mtetra
.6299 .45966 .63523 .46587 .64599 .46251 .64069 .45628 Mtetra
.64069 .45628 .64599 .46251 .6568 .45914 .65152 .45288 Mtetra
.65152 .45288 .6568 .45914 .66764 .45575 .66239 .44947 Mtetra
.656 .752 .92 r
.66239 .44947 .66764 .45575 .67853 .45236 .67331 .44605 Mtetra
.67331 .44605 .67853 .45236 .68946 .44894 .68427 .44262 Mtetra
.655 .752 .921 r
.68427 .44262 .68946 .44894 .70043 .44552 .69527 .43918 Mtetra
.69527 .43918 .70043 .44552 .71144 .44209 .70631 .43572 Mtetra
.70631 .43572 .71144 .44209 .7225 .43864 .7174 .43226 Mtetra
.7174 .43226 .7225 .43864 .7336 .43518 .72853 .42879 Mtetra
.655 .753 .922 r
.72853 .42879 .7336 .43518 .74474 .43172 .73971 .42532 Mtetra
.654 .753 .922 r
.73971 .42532 .74474 .43172 .75593 .42824 .75093 .42184 Mtetra
.654 .754 .923 r
.75093 .42184 .75593 .42824 .76716 .42476 .76219 .41836 Mtetra
.653 .754 .924 r
.76219 .41836 .76716 .42476 .77844 .42127 .7735 .41487 Mtetra
.653 .755 .925 r
.7735 .41487 .77844 .42127 .78976 .41776 .78486 .41137 Mtetra
.654 .756 .925 r
.78486 .41137 .78976 .41776 .80113 .41424 .79626 .40784 Mtetra
.654 .757 .925 r
.79626 .40784 .80113 .41424 .81254 .4107 .8077 .40429 Mtetra
.655 .758 .925 r
.8077 .40429 .81254 .4107 .82399 .40714 .81919 .40069 Mtetra
.656 .758 .925 r
.81919 .40069 .82399 .40714 .83549 .40354 .83072 .39705 Mtetra
.658 .758 .924 r
.83072 .39705 .83549 .40354 .84703 .39991 .84229 .39336 Mtetra
.659 .758 .923 r
.84229 .39336 .84703 .39991 .85862 .39625 .85391 .38963 Mtetra
.659 .756 .922 r
.85391 .38963 .85862 .39625 .87025 .39256 .86557 .38586 Mtetra
.66 .755 .92 r
.86557 .38586 .87025 .39256 .88193 .38884 .87727 .38207 Mtetra
.647 .749 .924 r
.25164 .57089 .25789 .57635 .26729 .57351 .26105 .56812 Mtetra
.648 .752 .926 r
.26105 .56812 .26729 .57351 .27672 .57065 .2705 .56531 Mtetra
.649 .755 .927 r
.2705 .56531 .27672 .57065 .28618 .56776 .27998 .56248 Mtetra
.65 .758 .928 r
.27998 .56248 .28618 .56776 .29569 .56484 .2895 .55959 Mtetra
.652 .761 .929 r
.2895 .55959 .29569 .56484 .30523 .56187 .29906 .55664 Mtetra
.654 .763 .93 r
.29906 .55664 .30523 .56187 .3148 .55886 .30865 .55364 Mtetra
.656 .764 .929 r
.30865 .55364 .3148 .55886 .32442 .55581 .31829 .55057 Mtetra
.658 .765 .929 r
.31829 .55057 .32442 .55581 .33406 .55274 .32796 .54746 Mtetra
.659 .764 .928 r
.32796 .54746 .33406 .55274 .34375 .54965 .33767 .54431 Mtetra
.659 .763 .926 r
.33767 .54431 .34375 .54965 .35347 .54655 .34741 .54114 Mtetra
.659 .761 .925 r
.34741 .54114 .35347 .54655 .36322 .54345 .35719 .53797 Mtetra
.659 .759 .924 r
.35719 .53797 .36322 .54345 .37301 .54034 .36701 .53479 Mtetra
.658 .758 .923 r
.36701 .53479 .37301 .54034 .38283 .53722 .37685 .53162 Mtetra
.658 .756 .922 r
.37685 .53162 .38283 .53722 .39269 .53411 .38674 .52845 Mtetra
.657 .755 .922 r
.38674 .52845 .39269 .53411 .40259 .53099 .39666 .52528 Mtetra
.657 .754 .921 r
.39666 .52528 .40259 .53099 .41252 .52786 .40661 .52212 Mtetra
.657 .753 .921 r
.40661 .52212 .41252 .52786 .42249 .52473 .41661 .51895 Mtetra
.656 .752 .921 r
.41661 .51895 .42249 .52473 .43249 .52159 .42663 .51578 Mtetra
.656 .752 .92 r
.42663 .51578 .43249 .52159 .44254 .51844 .4367 .5126 Mtetra
.4367 .5126 .44254 .51844 .45262 .51527 .4468 .50941 Mtetra
.4468 .50941 .45262 .51527 .46273 .5121 .45695 .50621 Mtetra
.656 .751 .92 r
.45695 .50621 .46273 .5121 .47289 .50891 .46713 .503 Mtetra
.46713 .503 .47289 .50891 .48308 .50571 .47734 .49978 Mtetra
.47734 .49978 .48308 .50571 .49331 .5025 .4876 .49655 Mtetra
.4876 .49655 .49331 .5025 .50358 .49928 .49789 .4933 Mtetra
.49789 .4933 .50358 .49928 .51389 .49605 .50823 .49005 Mtetra
.50823 .49005 .51389 .49605 .52424 .4928 .5186 .48678 Mtetra
.5186 .48678 .52424 .4928 .53463 .48955 .52901 .4835 Mtetra
.52901 .4835 .53463 .48955 .54505 .48628 .53946 .4802 Mtetra
.53946 .4802 .54505 .48628 .55552 .48299 .54996 .4769 Mtetra
.54996 .4769 .55552 .48299 .56602 .4797 .56049 .47358 Mtetra
.56049 .47358 .56602 .4797 .57657 .47639 .57106 .47025 Mtetra
.57106 .47025 .57657 .47639 .58715 .47307 .58167 .46691 Mtetra
.58167 .46691 .58715 .47307 .59778 .46974 .59232 .46355 Mtetra
.59232 .46355 .59778 .46974 .60844 .46639 .60302 .46018 Mtetra
.60302 .46018 .60844 .46639 .61915 .46303 .61375 .4568 Mtetra
.61375 .4568 .61915 .46303 .6299 .45966 .62453 .4534 Mtetra
.62453 .4534 .6299 .45966 .64069 .45628 .63535 .45 Mtetra
.63535 .45 .64069 .45628 .65152 .45288 .64621 .44658 Mtetra
.64621 .44658 .65152 .45288 .66239 .44947 .65711 .44315 Mtetra
.655 .752 .921 r
.65711 .44315 .66239 .44947 .67331 .44605 .66805 .43971 Mtetra
.66805 .43971 .67331 .44605 .68427 .44262 .67904 .43626 Mtetra
.67904 .43626 .68427 .44262 .69527 .43918 .69007 .4328 Mtetra
.655 .752 .922 r
.69007 .4328 .69527 .43918 .70631 .43572 .70115 .42935 Mtetra
.654 .753 .922 r
.70115 .42935 .70631 .43572 .7174 .43226 .71227 .42588 Mtetra
.653 .753 .923 r
.71227 .42588 .7174 .43226 .72853 .42879 .72343 .42243 Mtetra
.653 .754 .924 r
.72343 .42243 .72853 .42879 .73971 .42532 .73464 .41897 Mtetra
.652 .755 .925 r
.73464 .41897 .73971 .42532 .75093 .42184 .74589 .41552 Mtetra
.651 .757 .927 r
.74589 .41552 .75093 .42184 .76219 .41836 .75719 .41206 Mtetra
.651 .759 .928 r
.75719 .41206 .76219 .41836 .7735 .41487 .76854 .40859 Mtetra
.651 .761 .929 r
.76854 .40859 .7735 .41487 .78486 .41137 .77993 .4051 Mtetra
.652 .762 .93 r
.77993 .4051 .78486 .41137 .79626 .40784 .79137 .40157 Mtetra
.654 .764 .93 r
.79137 .40157 .79626 .40784 .8077 .40429 .80285 .39799 Mtetra
.656 .764 .93 r
.80285 .39799 .8077 .40429 .81919 .40069 .81436 .39434 Mtetra
.658 .764 .928 r
.81436 .39434 .81919 .40069 .83072 .39705 .82593 .39063 Mtetra
.66 .764 .927 r
.82593 .39063 .83072 .39705 .84229 .39336 .83753 .38685 Mtetra
.661 .762 .925 r
.83753 .38685 .84229 .39336 .85391 .38963 .84917 .38302 Mtetra
.662 .76 .922 r
.84917 .38302 .85391 .38963 .86557 .38586 .86086 .37915 Mtetra
.663 .757 .92 r
.86086 .37915 .86557 .38586 .87727 .38207 .87259 .37524 Mtetra
.643 .748 .926 r
.24535 .5654 .25164 .57089 .26105 .56812 .25477 .56271 Mtetra
.643 .752 .928 r
.25477 .56271 .26105 .56812 .2705 .56531 .26423 .55999 Mtetra
.644 .756 .93 r
.26423 .55999 .2705 .56531 .27998 .56248 .27372 .55723 Mtetra
.646 .76 .932 r
.27372 .55723 .27998 .56248 .2895 .55959 .28326 .55442 Mtetra
.648 .764 .934 r
.28326 .55442 .2895 .55959 .29906 .55664 .29283 .55154 Mtetra
.651 .768 .935 r
.29283 .55154 .29906 .55664 .30865 .55364 .30245 .54857 Mtetra
.654 .771 .935 r
.30245 .54857 .30865 .55364 .31829 .55057 .31211 .54551 Mtetra
.657 .773 .934 r
.31211 .54551 .31829 .55057 .32796 .54746 .3218 .54237 Mtetra
.66 .773 .933 r
.3218 .54237 .32796 .54746 .33767 .54431 .33153 .53917 Mtetra
.661 .772 .932 r
.33153 .53917 .33767 .54431 .34741 .54114 .3413 .53592 Mtetra
.662 .77 .93 r
.3413 .53592 .34741 .54114 .35719 .53797 .35111 .53266 Mtetra
.662 .768 .928 r
.35111 .53266 .35719 .53797 .36701 .53479 .36095 .52938 Mtetra
.661 .765 .927 r
.36095 .52938 .36701 .53479 .37685 .53162 .37083 .52612 Mtetra
.66 .762 .925 r
.37083 .52612 .37685 .53162 .38674 .52845 .38074 .52287 Mtetra
.659 .76 .924 r
.38074 .52287 .38674 .52845 .39666 .52528 .39068 .51963 Mtetra
.658 .757 .923 r
.39068 .51963 .39666 .52528 .40661 .52212 .40066 .51641 Mtetra
.658 .756 .922 r
.40066 .51641 .40661 .52212 .41661 .51895 .41068 .51319 Mtetra
.657 .755 .922 r
.41068 .51319 .41661 .51895 .42663 .51578 .42073 .50997 Mtetra
.657 .754 .921 r
.42073 .50997 .42663 .51578 .4367 .5126 .43082 .50675 Mtetra
.656 .753 .921 r
.43082 .50675 .4367 .5126 .4468 .50941 .44095 .50353 Mtetra
.44095 .50353 .4468 .50941 .45695 .50621 .45112 .5003 Mtetra
.656 .752 .921 r
.45112 .5003 .45695 .50621 .46713 .503 .46132 .49706 Mtetra
.46132 .49706 .46713 .503 .47734 .49978 .47157 .49382 Mtetra
.47157 .49382 .47734 .49978 .4876 .49655 .48185 .49056 Mtetra
.48185 .49056 .4876 .49655 .49789 .4933 .49217 .48729 Mtetra
.656 .752 .92 r
.49217 .48729 .49789 .4933 .50823 .49005 .50253 .48401 Mtetra
.50253 .48401 .50823 .49005 .5186 .48678 .51292 .48072 Mtetra
.51292 .48072 .5186 .48678 .52901 .4835 .52336 .47741 Mtetra
.52336 .47741 .52901 .4835 .53946 .4802 .53384 .4741 Mtetra
.53384 .4741 .53946 .4802 .54996 .4769 .54436 .47077 Mtetra
.54436 .47077 .54996 .4769 .56049 .47358 .55491 .46743 Mtetra
.55491 .46743 .56049 .47358 .57106 .47025 .56551 .46407 Mtetra
.56551 .46407 .57106 .47025 .58167 .46691 .57615 .46071 Mtetra
.57615 .46071 .58167 .46691 .59232 .46355 .58683 .45733 Mtetra
.656 .752 .921 r
.58683 .45733 .59232 .46355 .60302 .46018 .59755 .45394 Mtetra
.59755 .45394 .60302 .46018 .61375 .4568 .60832 .45053 Mtetra
.60832 .45053 .61375 .4568 .62453 .4534 .61912 .44712 Mtetra
.655 .752 .921 r
.61912 .44712 .62453 .4534 .63535 .45 .62997 .44369 Mtetra
.62997 .44369 .63535 .45 .64621 .44658 .64086 .44026 Mtetra
.64086 .44026 .64621 .44658 .65711 .44315 .65179 .43682 Mtetra
.655 .753 .922 r
.65179 .43682 .65711 .44315 .66805 .43971 .66276 .43337 Mtetra
.654 .753 .922 r
.66276 .43337 .66805 .43971 .67904 .43626 .67378 .42992 Mtetra
.654 .754 .923 r
.67378 .42992 .67904 .43626 .69007 .4328 .68484 .42647 Mtetra
.653 .754 .924 r
.68484 .42647 .69007 .4328 .70115 .42935 .69595 .42302 Mtetra
.652 .755 .925 r
.69595 .42302 .70115 .42935 .71227 .42588 .7071 .41959 Mtetra
.651 .757 .927 r
.7071 .41959 .71227 .42588 .72343 .42243 .7183 .41617 Mtetra
.65 .759 .929 r
.7183 .41617 .72343 .42243 .73464 .41897 .72954 .41276 Mtetra
.648 .761 .931 r
.72954 .41276 .73464 .41897 .74589 .41552 .74084 .40935 Mtetra
.648 .763 .933 r
.74084 .40935 .74589 .41552 .75719 .41206 .75218 .40594 Mtetra
.648 .766 .935 r
.75218 .40594 .75719 .41206 .76854 .40859 .76356 .40251 Mtetra
.649 .769 .936 r
.76356 .40251 .76854 .40859 .77993 .4051 .77499 .39903 Mtetra
.651 .771 .936 r
.77499 .39903 .77993 .4051 .79137 .40157 .78646 .39548 Mtetra
.654 .772 .936 r
.78646 .39548 .79137 .40157 .80285 .39799 .79797 .39185 Mtetra
.657 .772 .934 r
.79797 .39185 .80285 .39799 .81436 .39434 .80952 .38811 Mtetra
.66 .771 .932 r
.80952 .38811 .81436 .39434 .82593 .39063 .8211 .38429 Mtetra
.663 .769 .929 r
.8211 .38429 .82593 .39063 .83753 .38685 .83273 .38038 Mtetra
.665 .767 .926 r
.83273 .38038 .83753 .38685 .84917 .38302 .8444 .37642 Mtetra
.666 .763 .923 r
.8444 .37642 .84917 .38302 .86086 .37915 .85611 .37241 Mtetra
.667 .76 .92 r
.85611 .37241 .86086 .37915 .87259 .37524 .86786 .36837 Mtetra
.638 .747 .927 r
.23902 .55988 .24535 .5654 .25477 .56271 .24845 .55727 Mtetra
.637 .751 .93 r
.24845 .55727 .25477 .56271 .26423 .55999 .25792 .55465 Mtetra
.637 .755 .933 r
.25792 .55465 .26423 .55999 .27372 .55723 .26742 .55201 Mtetra
.639 .76 .936 r
.26742 .55201 .27372 .55723 .28326 .55442 .27697 .54932 Mtetra
.641 .766 .939 r
.27697 .54932 .28326 .55442 .29283 .55154 .28656 .54656 Mtetra
.644 .773 .942 r
.28656 .54656 .29283 .55154 .30245 .54857 .29618 .54371 Mtetra
.648 .779 .943 r
.29618 .54371 .30245 .54857 .31211 .54551 .30586 .54073 Mtetra
.653 .784 .944 r
.30586 .54073 .31211 .54551 .3218 .54237 .31557 .53764 Mtetra
.658 .788 .944 r
.31557 .53764 .3218 .54237 .33153 .53917 .32533 .53442 Mtetra
.661 .789 .942 r
.32533 .53442 .33153 .53917 .3413 .53592 .33513 .53111 Mtetra
.664 .788 .94 r
.33513 .53111 .3413 .53592 .35111 .53266 .34496 .52774 Mtetra
.665 .785 .938 r
.34496 .52774 .35111 .53266 .36095 .52938 .35484 .52433 Mtetra
.665 .781 .935 r
.35484 .52433 .36095 .52938 .37083 .52612 .36474 .52093 Mtetra
.664 .776 .932 r
.36474 .52093 .37083 .52612 .38074 .52287 .37468 .51753 Mtetra
.663 .771 .93 r
.37468 .51753 .38074 .52287 .39068 .51963 .38466 .51417 Mtetra
.662 .767 .928 r
.38466 .51417 .39068 .51963 .40066 .51641 .39467 .51083 Mtetra
.66 .763 .926 r
.39467 .51083 .40066 .51641 .41068 .51319 .40471 .50751 Mtetra
.659 .76 .924 r
.40471 .50751 .41068 .51319 .42073 .50997 .41479 .50422 Mtetra
.658 .758 .923 r
.41479 .50422 .42073 .50997 .43082 .50675 .42491 .50094 Mtetra
.658 .756 .922 r
.42491 .50094 .43082 .50675 .44095 .50353 .43506 .49766 Mtetra
.657 .755 .922 r
.43506 .49766 .44095 .50353 .45112 .5003 .44525 .49439 Mtetra
.657 .754 .921 r
.44525 .49439 .45112 .5003 .46132 .49706 .45548 .49111 Mtetra
.656 .753 .921 r
.45548 .49111 .46132 .49706 .47157 .49382 .46575 .48783 Mtetra
.46575 .48783 .47157 .49382 .48185 .49056 .47605 .48454 Mtetra
.656 .752 .921 r
.47605 .48454 .48185 .49056 .49217 .48729 .4864 .48124 Mtetra
.4864 .48124 .49217 .48729 .50253 .48401 .49678 .47794 Mtetra
.49678 .47794 .50253 .48401 .51292 .48072 .50721 .47462 Mtetra
.656 .752 .92 r
.50721 .47462 .51292 .48072 .52336 .47741 .51767 .47129 Mtetra
.51767 .47129 .52336 .47741 .53384 .4741 .52817 .46795 Mtetra
.52817 .46795 .53384 .4741 .54436 .47077 .53872 .4646 Mtetra
.53872 .4646 .54436 .47077 .55491 .46743 .5493 .46123 Mtetra
.656 .752 .921 r
.5493 .46123 .55491 .46743 .56551 .46407 .55993 .45786 Mtetra
.55993 .45786 .56551 .46407 .57615 .46071 .57059 .45447 Mtetra
.57059 .45447 .57615 .46071 .58683 .45733 .5813 .45107 Mtetra
.655 .752 .921 r
.5813 .45107 .58683 .45733 .59755 .45394 .59205 .44766 Mtetra
.59205 .44766 .59755 .45394 .60832 .45053 .60284 .44424 Mtetra
.60284 .44424 .60832 .45053 .61912 .44712 .61367 .44081 Mtetra
.655 .752 .922 r
.61367 .44081 .61912 .44712 .62997 .44369 .62455 .43738 Mtetra
.654 .753 .922 r
.62455 .43738 .62997 .44369 .64086 .44026 .63547 .43394 Mtetra
.654 .753 .923 r
.63547 .43394 .64086 .44026 .65179 .43682 .64643 .43051 Mtetra
.653 .754 .924 r
.64643 .43051 .65179 .43682 .66276 .43337 .65744 .42708 Mtetra
.652 .755 .926 r
.65744 .42708 .66276 .43337 .67378 .42992 .66849 .42366 Mtetra
.65 .757 .927 r
.66849 .42366 .67378 .42992 .68484 .42647 .67958 .42026 Mtetra
.649 .759 .93 r
.67958 .42026 .68484 .42647 .69595 .42302 .69072 .41688 Mtetra
.647 .762 .933 r
.69072 .41688 .69595 .42302 .7071 .41959 .70191 .41353 Mtetra
.645 .765 .936 r
.70191 .41353 .7071 .41959 .7183 .41617 .71315 .41021 Mtetra
.643 .769 .94 r
.71315 .41021 .7183 .41617 .72954 .41276 .72444 .4069 Mtetra
.642 .773 .943 r
.72444 .4069 .72954 .41276 .74084 .40935 .73577 .40359 Mtetra
.642 .778 .946 r
.73577 .40359 .74084 .40935 .75218 .40594 .74715 .40024 Mtetra
.644 .782 .947 r
.74715 .40024 .75218 .40594 .76356 .40251 .75857 .39683 Mtetra
.647 .785 .947 r
.75857 .39683 .76356 .40251 .77499 .39903 .77004 .39332 Mtetra
.652 .786 .946 r
.77004 .39332 .77499 .39903 .78646 .39548 .78154 .38967 Mtetra
.657 .786 .943 r
.78154 .38967 .78646 .39548 .79797 .39185 .79307 .3859 Mtetra
.662 .783 .939 r
.79307 .3859 .79797 .39185 .80952 .38811 .80465 .382 Mtetra
.666 .78 .934 r
.80465 .382 .80952 .38811 .8211 .38429 .81626 .378 Mtetra
.668 .775 .93 r
.81626 .378 .8211 .38429 .83273 .38038 .8279 .37392 Mtetra
.67 .771 .925 r
.8279 .37392 .83273 .38038 .8444 .37642 .83959 .36979 Mtetra
.671 .766 .922 r
.83959 .36979 .8444 .37642 .85611 .37241 .85133 .36562 Mtetra
.671 .761 .919 r
.85133 .36562 .85611 .37241 .86786 .36837 .8631 .36144 Mtetra
.635 .746 .929 r
.23264 .55431 .23902 .55988 .24845 .55727 .24209 .55176 Mtetra
.633 .748 .931 r
.24209 .55176 .24845 .55727 .25792 .55465 .25157 .54922 Mtetra
.631 .752 .934 r
.25157 .54922 .25792 .55465 .26742 .55201 .26108 .54669 Mtetra
.631 .756 .938 r
.26108 .54669 .26742 .55201 .27697 .54932 .27064 .54414 Mtetra
.631 .762 .942 r
.27064 .54414 .27697 .54932 .28656 .54656 .28023 .54156 Mtetra
.634 .771 .946 r
.28023 .54156 .28656 .54656 .29618 .54371 .28987 .5389 Mtetra
.638 .78 .949 r
.28987 .5389 .29618 .54371 .30586 .54073 .29955 .5361 Mtetra
.644 .789 .952 r
.29955 .5361 .30586 .54073 .31557 .53764 .30928 .53315 Mtetra
.651 .797 .953 r
.30928 .53315 .31557 .53764 .32533 .53442 .31906 .53001 Mtetra
.658 .803 .952 r
.31906 .53001 .32533 .53442 .33513 .53111 .32888 .52671 Mtetra
.664 .805 .951 r
.32888 .52671 .33513 .53111 .34496 .52774 .33874 .52328 Mtetra
.667 .804 .948 r
.33874 .52328 .34496 .52774 .35484 .52433 .34865 .51975 Mtetra
.669 .801 .945 r
.34865 .51975 .35484 .52433 .36474 .52093 .35859 .51619 Mtetra
.67 .796 .942 r
.35859 .51619 .36474 .52093 .37468 .51753 .36856 .51262 Mtetra
.668 .789 .939 r
.36856 .51262 .37468 .51753 .38466 .51417 .37857 .50908 Mtetra
.667 .783 .936 r
.37857 .50908 .38466 .51417 .39467 .51083 .38861 .50557 Mtetra
.665 .777 .933 r
.38861 .50557 .39467 .51083 .40471 .50751 .39868 .50211 Mtetra
.663 .772 .931 r
.39868 .50211 .40471 .50751 .41479 .50422 .40879 .49869 Mtetra
.661 .768 .929 r
.40879 .49869 .41479 .50422 .42491 .50094 .41894 .4953 Mtetra
.66 .764 .927 r
.41894 .4953 .42491 .50094 .43506 .49766 .42912 .49193 Mtetra
.659 .762 .926 r
.42912 .49193 .43506 .49766 .44525 .49439 .43934 .48858 Mtetra
.658 .76 .925 r
.43934 .48858 .44525 .49439 .45548 .49111 .44959 .48525 Mtetra
.657 .758 .924 r
.44959 .48525 .45548 .49111 .46575 .48783 .45988 .48191 Mtetra
.657 .757 .923 r
.45988 .48191 .46575 .48783 .47605 .48454 .47022 .47858 Mtetra
.657 .756 .923 r
.47022 .47858 .47605 .48454 .4864 .48124 .48059 .47524 Mtetra
.656 .755 .923 r
.48059 .47524 .4864 .48124 .49678 .47794 .491 .4719 Mtetra
.656 .755 .922 r
.491 .4719 .49678 .47794 .50721 .47462 .50145 .46855 Mtetra
.656 .754 .922 r
.50145 .46855 .50721 .47462 .51767 .47129 .51194 .46519 Mtetra
.51194 .46519 .51767 .47129 .52817 .46795 .52247 .46182 Mtetra
.52247 .46182 .52817 .46795 .53872 .4646 .53304 .45845 Mtetra
.53304 .45845 .53872 .4646 .5493 .46123 .54365 .45506 Mtetra
.655 .754 .922 r
.54365 .45506 .5493 .46123 .55993 .45786 .5543 .45167 Mtetra
.655 .754 .923 r
.5543 .45167 .55993 .45786 .57059 .45447 .565 .44826 Mtetra
.565 .44826 .57059 .45447 .5813 .45107 .57573 .44485 Mtetra
.655 .755 .923 r
.57573 .44485 .5813 .45107 .59205 .44766 .58651 .44143 Mtetra
.654 .755 .924 r
.58651 .44143 .59205 .44766 .60284 .44424 .59733 .43801 Mtetra
.654 .756 .925 r
.59733 .43801 .60284 .44424 .61367 .44081 .60819 .43459 Mtetra
.653 .756 .926 r
.60819 .43459 .61367 .44081 .62455 .43738 .6191 .43117 Mtetra
.652 .758 .927 r
.6191 .43117 .62455 .43738 .63547 .43394 .63005 .42777 Mtetra
.651 .759 .929 r
.63005 .42777 .63547 .43394 .64643 .43051 .64104 .42437 Mtetra
.649 .761 .931 r
.64104 .42437 .64643 .43051 .65744 .42708 .65208 .42101 Mtetra
.647 .763 .934 r
.65208 .42101 .65744 .42708 .66849 .42366 .66317 .41767 Mtetra
.644 .766 .937 r
.66317 .41767 .66849 .42366 .67958 .42026 .6743 .41437 Mtetra
.641 .77 .941 r
.6743 .41437 .67958 .42026 .69072 .41688 .68548 .41112 Mtetra
.638 .774 .946 r
.68548 .41112 .69072 .41688 .70191 .41353 .69671 .40791 Mtetra
.635 .779 .95 r
.69671 .40791 .70191 .41353 .71315 .41021 .70799 .40472 Mtetra
.633 .785 .954 r
.70799 .40472 .71315 .41021 .72444 .4069 .71932 .40153 Mtetra
.633 .79 .957 r
.71932 .40153 .72444 .4069 .73577 .40359 .7307 .39829 Mtetra
.636 .795 .959 r
.7307 .39829 .73577 .40359 .74715 .40024 .74212 .39496 Mtetra
.641 .799 .958 r
.74212 .39496 .74715 .40024 .75857 .39683 .75357 .39149 Mtetra
.648 .8 .956 r
.75357 .39149 .75857 .39683 .77004 .39332 .76507 .38785 Mtetra
.657 .799 .951 r
.76507 .38785 .77004 .39332 .78154 .38967 .77659 .38401 Mtetra
.664 .796 .945 r
.77659 .38401 .78154 .38967 .79307 .3859 .78815 .38001 Mtetra
.67 .79 .938 r
.78815 .38001 .79307 .3859 .80465 .382 .79974 .37586 Mtetra
.673 .783 .932 r
.79974 .37586 .80465 .382 .81626 .378 .81137 .37163 Mtetra
.674 .776 .927 r
.81137 .37163 .81626 .378 .8279 .37392 .82304 .36735 Mtetra
.675 .77 .922 r
.82304 .36735 .8279 .37392 .83959 .36979 .83475 .36305 Mtetra
.674 .765 .919 r
.83475 .36305 .83959 .36979 .85133 .36562 .8465 .35875 Mtetra
.673 .761 .917 r
.8465 .35875 .85133 .36562 .8631 .36144 .85831 .35446 Mtetra
.637 .747 .928 r
.22623 .54871 .23264 .55431 .24209 .55176 .23569 .54609 Mtetra
.634 .744 .928 r
.23569 .54609 .24209 .55176 .25157 .54922 .24519 .54353 Mtetra
.631 .743 .929 r
.24519 .54353 .25157 .54922 .26108 .54669 .25472 .54102 Mtetra
.628 .744 .931 r
.25472 .54102 .26108 .54669 .27064 .54414 .26429 .53855 Mtetra
.624 .746 .935 r
.26429 .53855 .27064 .54414 .28023 .54156 .27389 .53615 Mtetra
.623 .753 .94 r
.27389 .53615 .28023 .54156 .28987 .5389 .28353 .53373 Mtetra
.623 .764 .946 r
.28353 .53373 .28987 .5389 .29955 .5361 .29321 .53125 Mtetra
.627 .778 .953 r
.29321 .53125 .29955 .5361 .30928 .53315 .30294 .52864 Mtetra
.634 .794 .959 r
.30294 .52864 .30928 .53315 .31906 .53001 .31272 .52581 Mtetra
.641 .809 .964 r
.31272 .52581 .31906 .53001 .32888 .52671 .32255 .52277 Mtetra
.651 .822 .965 r
.32255 .52277 .32888 .52671 .33874 .52328 .33244 .51947 Mtetra
.659 .83 .966 r
.33244 .51947 .33874 .52328 .34865 .51975 .34237 .51599 Mtetra
.666 .834 .964 r
.34237 .51599 .34865 .51975 .35859 .51619 .35234 .51234 Mtetra
.67 .833 .962 r
.35234 .51234 .35859 .51619 .36856 .51262 .36235 .50861 Mtetra
.672 .827 .958 r
.36235 .50861 .36856 .51262 .37857 .50908 .3724 .50486 Mtetra
.672 .82 .954 r
.3724 .50486 .37857 .50908 .38861 .50557 .38247 .50111 Mtetra
.671 .811 .95 r
.38247 .50111 .38861 .50557 .39868 .50211 .39259 .4974 Mtetra
.669 .802 .946 r
.39259 .4974 .39868 .50211 .40879 .49869 .40273 .49375 Mtetra
.667 .793 .942 r
.40273 .49375 .40879 .49869 .41894 .4953 .41291 .49015 Mtetra
.665 .786 .938 r
.41291 .49015 .41894 .4953 .42912 .49193 .42312 .48661 Mtetra
.663 .779 .935 r
.42312 .48661 .42912 .49193 .43934 .48858 .43337 .48311 Mtetra
.661 .774 .933 r
.43337 .48311 .43934 .48858 .44959 .48525 .44365 .47965 Mtetra
.66 .77 .931 r
.44365 .47965 .44959 .48525 .45988 .48191 .45397 .47621 Mtetra
.659 .767 .929 r
.45397 .47621 .45988 .48191 .47022 .47858 .46433 .47279 Mtetra
.658 .764 .928 r
.46433 .47279 .47022 .47858 .48059 .47524 .47473 .46938 Mtetra
.657 .762 .927 r
.47473 .46938 .48059 .47524 .491 .4719 .48517 .46598 Mtetra
.657 .761 .926 r
.48517 .46598 .491 .4719 .50145 .46855 .49565 .46259 Mtetra
.656 .76 .926 r
.49565 .46259 .50145 .46855 .51194 .46519 .50616 .45919 Mtetra
.656 .759 .926 r
.50616 .45919 .51194 .46519 .52247 .46182 .51672 .45579 Mtetra
.655 .759 .926 r
.51672 .45579 .52247 .46182 .53304 .45845 .52732 .45239 Mtetra
.52732 .45239 .53304 .45845 .54365 .45506 .53796 .44899 Mtetra
.654 .759 .926 r
.53796 .44899 .54365 .45506 .5543 .45167 .54864 .44558 Mtetra
.654 .759 .927 r
.54864 .44558 .5543 .45167 .565 .44826 .55936 .44218 Mtetra
.653 .76 .928 r
.55936 .44218 .565 .44826 .57573 .44485 .57012 .43878 Mtetra
.652 .761 .929 r
.57012 .43878 .57573 .44485 .58651 .44143 .58093 .43539 Mtetra
.651 .762 .93 r
.58093 .43539 .58651 .44143 .59733 .43801 .59178 .432 Mtetra
.65 .764 .932 r
.59178 .432 .59733 .43801 .60819 .43459 .60268 .42864 Mtetra
.648 .766 .935 r
.60268 .42864 .60819 .43459 .6191 .43117 .61361 .4253 Mtetra
.645 .769 .938 r
.61361 .4253 .6191 .43117 .63005 .42777 .6246 .422 Mtetra
.642 .773 .943 r
.6246 .422 .63005 .42777 .64104 .42437 .63563 .41874 Mtetra
.638 .777 .947 r
.63563 .41874 .64104 .42437 .65208 .42101 .64671 .41553 Mtetra
.633 .783 .953 r
.64671 .41553 .65208 .42101 .66317 .41767 .65784 .41239 Mtetra
.628 .789 .959 r
.65784 .41239 .66317 .41767 .6743 .41437 .66901 .40929 Mtetra
.623 .796 .965 r
.66901 .40929 .6743 .41437 .68548 .41112 .68024 .40625 Mtetra
.618 .804 .971 r
.68024 .40625 .68548 .41112 .69671 .40791 .69152 .40321 Mtetra
.616 .811 .975 r
.69152 .40321 .69671 .40791 .70799 .40472 .70285 .40014 Mtetra
.618 .818 .977 r
.70285 .40014 .70799 .40472 .71932 .40153 .71422 .39698 Mtetra
.624 .823 .977 r
.71422 .39698 .71932 .40153 .7307 .39829 .72563 .39366 Mtetra
.635 .824 .973 r
.72563 .39366 .7307 .39829 .74212 .39496 .73707 .39014 Mtetra
.649 .822 .967 r
.73707 .39014 .74212 .39496 .75357 .39149 .74855 .38636 Mtetra
.661 .815 .957 r
.74855 .38636 .75357 .39149 .76507 .38785 .76006 .38235 Mtetra
.672 .806 .947 r
.76006 .38235 .76507 .38785 .77659 .38401 .77159 .37811 Mtetra
.678 .794 .936 r
.77159 .37811 .77659 .38401 .78815 .38001 .78316 .37373 Mtetra
.681 .782 .927 r
.78316 .37373 .78815 .38001 .79974 .37586 .79476 .36928 Mtetra
.681 .772 .92 r
.79476 .36928 .79974 .37586 .81137 .37163 .8064 .36481 Mtetra
.678 .764 .916 r
.8064 .36481 .81137 .37163 .82304 .36735 .8181 .36039 Mtetra
.676 .759 .914 r
.8181 .36039 .82304 .36735 .83475 .36305 .82984 .35602 Mtetra
.674 .757 .913 r
.82984 .35602 .83475 .36305 .8465 .35875 .84163 .3517 Mtetra
.672 .757 .914 r
.84163 .3517 .8465 .35875 .85831 .35446 .85348 .34743 Mtetra
.645 .749 .925 r
.21976 .54307 .22623 .54871 .23569 .54609 .22927 .54024 Mtetra
.642 .741 .921 r
.22927 .54024 .23569 .54609 .24519 .54353 .2388 .53749 Mtetra
.637 .734 .918 r
.2388 .53749 .24519 .54353 .25472 .54102 .24836 .53485 Mtetra
.631 .728 .918 r
.24836 .53485 .25472 .54102 .26429 .53855 .25795 .53234 Mtetra
.622 .725 .92 r
.25795 .53234 .26429 .53855 .27389 .53615 .26756 .53001 Mtetra
.616 .726 .925 r
.26756 .53001 .27389 .53615 .28353 .53373 .2772 .5278 Mtetra
.61 .732 .932 r
.2772 .5278 .28353 .53373 .29321 .53125 .28687 .52568 Mtetra
.608 .746 .942 r
.28687 .52568 .29321 .53125 .30294 .52864 .29659 .52351 Mtetra
.611 .765 .953 r
.29659 .52351 .30294 .52864 .31272 .52581 .30636 .5212 Mtetra
.618 .787 .963 r
.30636 .5212 .31272 .52581 .32255 .52277 .31619 .51865 Mtetra
.629 .811 .97 r
.31619 .51865 .32255 .52277 .33244 .51947 .32607 .51577 Mtetra
.64 .831 .974 r
.32607 .51577 .33244 .51947 .34237 .51599 .33601 .51257 Mtetra
.652 .847 .975 r
.33601 .51257 .34237 .51599 .35234 .51234 .34601 .50906 Mtetra
.661 .855 .974 r
.34601 .50906 .35234 .51234 .36235 .50861 .35605 .50532 Mtetra
.669 .857 .972 r
.35605 .50532 .36235 .50861 .3724 .50486 .36613 .50144 Mtetra
.673 .854 .969 r
.36613 .50144 .3724 .50486 .38247 .50111 .37625 .49749 Mtetra
.674 .847 .966 r
.37625 .49749 .38247 .50111 .39259 .4974 .3864 .49354 Mtetra
.674 .838 .962 r
.3864 .49354 .39259 .4974 .40273 .49375 .39659 .48963 Mtetra
.672 .828 .958 r
.39659 .48963 .40273 .49375 .41291 .49015 .40681 .48578 Mtetra
.67 .818 .954 r
.40681 .48578 .41291 .49015 .42312 .48661 .41705 .482 Mtetra
.668 .809 .951 r
.41705 .482 .42312 .48661 .43337 .48311 .42734 .47829 Mtetra
.666 .801 .947 r
.42734 .47829 .43337 .48311 .44365 .47965 .43766 .47464 Mtetra
.663 .794 .945 r
.43766 .47464 .44365 .47965 .45397 .47621 .44801 .47104 Mtetra
.662 .789 .942 r
.44801 .47104 .45397 .47621 .46433 .47279 .4584 .46749 Mtetra
.66 .784 .94 r
.4584 .46749 .46433 .47279 .47473 .46938 .46883 .46398 Mtetra
.659 .781 .939 r
.46883 .46398 .47473 .46938 .48517 .46598 .47929 .46049 Mtetra
.657 .778 .938 r
.47929 .46049 .48517 .46598 .49565 .46259 .4898 .45703 Mtetra
.656 .776 .937 r
.4898 .45703 .49565 .46259 .50616 .45919 .50034 .45358 Mtetra
.655 .774 .937 r
.50034 .45358 .50616 .45919 .51672 .45579 .51093 .45014 Mtetra
.654 .774 .937 r
.51093 .45014 .51672 .45579 .52732 .45239 .52156 .44672 Mtetra
.653 .773 .937 r
.52156 .44672 .52732 .45239 .53796 .44899 .53223 .4433 Mtetra
.652 .773 .938 r
.53223 .4433 .53796 .44899 .54864 .44558 .54294 .43991 Mtetra
.65 .774 .939 r
.54294 .43991 .54864 .44558 .55936 .44218 .55369 .43652 Mtetra
.649 .775 .941 r
.55369 .43652 .55936 .44218 .57012 .43878 .56448 .43316 Mtetra
.647 .777 .943 r
.56448 .43316 .57012 .43878 .58093 .43539 .57532 .42983 Mtetra
.644 .779 .946 r
.57532 .42983 .58093 .43539 .59178 .432 .5862 .42653 Mtetra
.641 .782 .949 r
.5862 .42653 .59178 .432 .60268 .42864 .59713 .42328 Mtetra
.637 .786 .954 r
.59713 .42328 .60268 .42864 .61361 .4253 .60811 .42008 Mtetra
.631 .791 .959 r
.60811 .42008 .61361 .4253 .6246 .422 .61913 .41695 Mtetra
.625 .796 .964 r
.61913 .41695 .6246 .422 .63563 .41874 .6302 .41388 Mtetra
.618 .802 .97 r
.6302 .41388 .63563 .41874 .64671 .41553 .64133 .41089 Mtetra
.61 .809 .977 r
.64133 .41089 .64671 .41553 .65784 .41239 .6525 .40797 Mtetra
.603 .817 .982 r
.6525 .40797 .65784 .41239 .66901 .40929 .66372 .40508 Mtetra
.597 .824 .986 r
.66372 .40508 .66901 .40929 .68024 .40625 .675 .40219 Mtetra
.595 .831 .989 r
.675 .40219 .68024 .40625 .69152 .40321 .68632 .39924 Mtetra
.601 .837 .989 r
.68632 .39924 .69152 .40321 .70285 .40014 .69769 .39612 Mtetra
.614 .841 .986 r
.69769 .39612 .70285 .40014 .71422 .39698 .70909 .39279 Mtetra
.634 .842 .98 r
.70909 .39279 .71422 .39698 .72563 .39366 .72052 .38912 Mtetra
.654 .836 .97 r
.72052 .38912 .72563 .39366 .73707 .39014 .73198 .38514 Mtetra
.674 .825 .956 r
.73198 .38514 .73707 .39014 .74855 .38636 .74346 .38079 Mtetra
.686 .808 .941 r
.74346 .38079 .74855 .38636 .76006 .38235 .75496 .3762 Mtetra
.692 .79 .926 r
.75496 .3762 .76006 .38235 .77159 .37811 .76649 .37144 Mtetra
.692 .773 .913 r
.76649 .37144 .77159 .37811 .78316 .37373 .77806 .36664 Mtetra
.688 .758 .905 r
.77806 .36664 .78316 .37373 .79476 .36928 .78968 .36192 Mtetra
.683 .749 .901 r
.78968 .36192 .79476 .36928 .8064 .36481 .80135 .35732 Mtetra
.676 .743 .901 r
.80135 .35732 .8064 .36481 .8181 .36039 .81308 .3529 Mtetra
.672 .742 .903 r
.81308 .3529 .8181 .36039 .82984 .35602 .82487 .34862 Mtetra
.668 .744 .907 r
.82487 .34862 .82984 .35602 .84163 .3517 .83671 .34444 Mtetra
.665 .749 .913 r
.83671 .34444 .84163 .3517 .85348 .34743 .84861 .34035 Mtetra
.662 .753 .918 r
.21326 .53739 .21976 .54307 .22927 .54024 .22282 .53416 Mtetra
.659 .739 .909 r
.22282 .53416 .22927 .54024 .2388 .53749 .2324 .53098 Mtetra
.653 .724 .901 r
.2324 .53098 .2388 .53749 .24836 .53485 .24201 .52793 Mtetra
.645 .71 .894 r
.24201 .52793 .24836 .53485 .25795 .53234 .25164 .52506 Mtetra
.634 .696 .89 r
.25164 .52506 .25795 .53234 .26756 .53001 .26129 .52247 Mtetra
.624 .685 .887 r
.26129 .52247 .26756 .53001 .2772 .5278 .27095 .52014 Mtetra
.611 .678 .889 r
.27095 .52014 .2772 .5278 .28687 .52568 .28063 .51812 Mtetra
.603 .679 .895 r
.28063 .51812 .28687 .52568 .29659 .52351 .29034 .51629 Mtetra
.596 .687 .905 r
.29034 .51629 .29659 .52351 .30636 .5212 .30009 .51456 Mtetra
.596 .706 .921 r
.30009 .51456 .30636 .5212 .31619 .51865 .30988 .51276 Mtetra
.601 .735 .939 r
.30988 .51276 .31619 .51865 .32607 .51577 .31973 .51073 Mtetra
.608 .771 .958 r
.31973 .51073 .32607 .51577 .33601 .51257 .32965 .50838 Mtetra
.62 .809 .972 r
.32965 .50838 .33601 .51257 .34601 .50906 .33963 .50561 Mtetra
.629 .842 .982 r
.33963 .50561 .34601 .50906 .35605 .50532 .34967 .50245 Mtetra
.638 .868 .985 r
.34967 .50245 .35605 .50532 .36613 .50144 .35977 .49893 Mtetra
.644 .884 .985 r
.35977 .49893 .36613 .50144 .37625 .49749 .36991 .49516 Mtetra
.649 .892 .983 r
.36991 .49516 .37625 .49749 .3864 .49354 .3801 .4912 Mtetra
.653 .894 .982 r
.3801 .4912 .3864 .49354 .39659 .48963 .39033 .48716 Mtetra
.656 .891 .982 r
.39033 .48716 .39659 .48963 .40681 .48578 .40059 .4831 Mtetra
.659 .884 .981 r
.40059 .4831 .40681 .48578 .41705 .482 .41088 .47905 Mtetra
.66 .875 .979 r
.41088 .47905 .41705 .482 .42734 .47829 .42121 .47507 Mtetra
.66 .865 .977 r
.42121 .47507 .42734 .47829 .43766 .47464 .43157 .47115 Mtetra
.659 .855 .975 r
.43157 .47115 .43766 .47464 .44801 .47104 .44196 .46731 Mtetra
.658 .846 .972 r
.44196 .46731 .44801 .47104 .4584 .46749 .45239 .46354 Mtetra
.657 .838 .97 r
.45239 .46354 .4584 .46749 .46883 .46398 .46285 .45984 Mtetra
.655 .831 .968 r
.46285 .45984 .46883 .46398 .47929 .46049 .47335 .4562 Mtetra
.653 .825 .966 r
.47335 .4562 .47929 .46049 .4898 .45703 .48389 .45261 Mtetra
.651 .82 .965 r
.48389 .45261 .4898 .45703 .50034 .45358 .49447 .44907 Mtetra
.649 .817 .964 r
.49447 .44907 .50034 .45358 .51093 .45014 .50509 .44558 Mtetra
.646 .815 .964 r
.50509 .44558 .51093 .45014 .52156 .44672 .51575 .44213 Mtetra
.643 .814 .965 r
.51575 .44213 .52156 .44672 .53223 .4433 .52645 .43873 Mtetra
.64 .814 .967 r
.52645 .43873 .53223 .4433 .54294 .43991 .53719 .43538 Mtetra
.636 .816 .969 r
.53719 .43538 .54294 .43991 .55369 .43652 .54798 .43207 Mtetra
.631 .818 .972 r
.54798 .43207 .55369 .43652 .56448 .43316 .55881 .42882 Mtetra
.625 .822 .976 r
.55881 .42882 .56448 .43316 .57532 .42983 .56969 .42563 Mtetra
.617 .826 .98 r
.56969 .42563 .57532 .42983 .5862 .42653 .58061 .42251 Mtetra
.608 .831 .985 r
.58061 .42251 .5862 .42653 .59713 .42328 .59158 .41946 Mtetra
.597 .837 .99 r
.59158 .41946 .59713 .42328 .60811 .42008 .6026 .41649 Mtetra
.585 .842 .993 r
.6026 .41649 .60811 .42008 .61913 .41695 .61367 .41359 Mtetra
.572 .848 .996 r
.61367 .41359 .61913 .41695 .6302 .41388 .62479 .41075 Mtetra
.56 .853 .997 r
.62479 .41075 .6302 .41388 .64133 .41089 .63596 .40793 Mtetra
.552 .857 .997 r
.63596 .40793 .64133 .41089 .6525 .40797 .64718 .40509 Mtetra
.553 .862 .996 r
.64718 .40509 .6525 .40797 .66372 .40508 .65844 .40217 Mtetra
.566 .866 .996 r
.65844 .40217 .66372 .40508 .675 .40219 .66975 .39906 Mtetra
.591 .868 .994 r
.66975 .39906 .675 .40219 .68632 .39924 .6811 .39569 Mtetra
.625 .865 .988 r
.6811 .39569 .68632 .39924 .69769 .39612 .69247 .39194 Mtetra
.657 .851 .974 r
.69247 .39194 .69769 .39612 .70909 .39279 .70387 .38779 Mtetra
.684 .828 .952 r
.70387 .38779 .70909 .39279 .72052 .38912 .71529 .3832 Mtetra
.699 .799 .927 r
.71529 .3832 .72052 .38912 .73198 .38514 .72673 .37828 Mtetra
.704 .769 .903 r
.72673 .37828 .73198 .38514 .74346 .38079 .73819 .37311 Mtetra
.702 .744 .884 r
.73819 .37311 .74346 .38079 .75496 .3762 .74968 .36786 Mtetra
.695 .724 .872 r
.74968 .36786 .75496 .3762 .76649 .37144 .76121 .36271 Mtetra
.688 .711 .866 r
.76121 .36271 .76649 .37144 .77806 .36664 .7728 .35774 Mtetra
.678 .704 .867 r
.7728 .35774 .77806 .36664 .78968 .36192 .78445 .35309 Mtetra
.671 .703 .871 r
.78445 .35309 .78968 .36192 .80135 .35732 .79617 .34871 Mtetra
.663 .706 .88 r
.79617 .34871 .80135 .35732 .81308 .3529 .80796 .34461 Mtetra
.657 .714 .89 r
.80796 .34461 .81308 .3529 .82487 .34862 .81981 .34071 Mtetra
.653 .724 .901 r
.81981 .34071 .82487 .34862 .83671 .34444 .83173 .33693 Mtetra
.651 .736 .912 r
.83173 .33693 .83671 .34444 .84861 .34035 .8437 .33321 Mtetra
.68 .757 .909 r
.20671 .53168 .21326 .53739 .22282 .53416 .21633 .52794 Mtetra
.679 .741 .898 r
.21633 .52794 .22282 .53416 .2324 .53098 .22599 .5242 Mtetra
.674 .723 .886 r
.22599 .5242 .2324 .53098 .24201 .52793 .23566 .52055 Mtetra
.665 .704 .876 r
.23566 .52055 .24201 .52793 .25164 .52506 .24536 .51707 Mtetra
.654 .684 .866 r
.24536 .51707 .25164 .52506 .26129 .52247 .25507 .51388 Mtetra
.639 .664 .858 r
.25507 .51388 .26129 .52247 .27095 .52014 .26478 .51105 Mtetra
.621 .646 .853 r
.26478 .51105 .27095 .52014 .28063 .51812 .27449 .50873 Mtetra
.605 .632 .852 r
.27449 .50873 .28063 .51812 .29034 .51629 .28421 .50687 Mtetra
.587 .625 .856 r
.28421 .50687 .29034 .51629 .30009 .51456 .29394 .50548 Mtetra
.576 .629 .867 r
.29394 .50548 .30009 .51456 .30988 .51276 .3037 .50433 Mtetra
.57 .644 .884 r
.3037 .50433 .30988 .51276 .31973 .51073 .3135 .50327 Mtetra
.571 .673 .909 r
.3135 .50327 .31973 .51073 .32965 .50838 .32336 .50205 Mtetra
.58 .715 .935 r
.32336 .50205 .32965 .50838 .33963 .50561 .3333 .50044 Mtetra
.591 .763 .961 r
.3333 .50044 .33963 .50561 .34967 .50245 .3433 .49837 Mtetra
.606 .812 .979 r
.3433 .49837 .34967 .50245 .35977 .49893 .35338 .49574 Mtetra
.616 .851 .988 r
.35338 .49574 .35977 .49893 .36991 .49516 .36353 .49263 Mtetra
.624 .88 .989 r
.36353 .49263 .36991 .49516 .3801 .4912 .37373 .4891 Mtetra
.629 .897 .986 r
.37373 .4891 .3801 .4912 .39033 .48716 .38398 .48527 Mtetra
.633 .907 .983 r
.38398 .48527 .39033 .48716 .40059 .4831 .39428 .48126 Mtetra
.636 .91 .982 r
.39428 .48126 .40059 .4831 .41088 .47905 .40461 .47714 Mtetra
.638 .909 .982 r
.40461 .47714 .41088 .47905 .42121 .47507 .41498 .47301 Mtetra
.64 .905 .983 r
.41498 .47301 .42121 .47507 .43157 .47115 .42539 .4689 Mtetra
.641 .899 .984 r
.42539 .4689 .43157 .47115 .44196 .46731 .43582 .46485 Mtetra
.641 .892 .985 r
.43582 .46485 .44196 .46731 .45239 .46354 .44629 .46088 Mtetra
.64 .885 .985 r
.44629 .46088 .45239 .46354 .46285 .45984 .4568 .45699 Mtetra
.638 .879 .986 r
.4568 .45699 .46285 .45984 .47335 .4562 .46734 .45319 Mtetra
.635 .873 .986 r
.46734 .45319 .47335 .4562 .48389 .45261 .47792 .44947 Mtetra
.632 .868 .986 r
.47792 .44947 .48389 .45261 .49447 .44907 .48853 .44584 Mtetra
.628 .864 .987 r
.48853 .44584 .49447 .44907 .50509 .44558 .49919 .44229 Mtetra
.623 .861 .988 r
.49919 .44229 .50509 .44558 .51575 .44213 .50989 .43882 Mtetra
.617 .859 .989 r
.50989 .43882 .51575 .44213 .52645 .43873 .52062 .43543 Mtetra
.61 .858 .99 r
.52062 .43543 .52645 .43873 .53719 .43538 .53141 .43213 Mtetra
.602 .858 .992 r
.53141 .43213 .53719 .43538 .54798 .43207 .54223 .4289 Mtetra
.592 .859 .994 r
.54223 .4289 .54798 .43207 .55881 .42882 .5531 .42577 Mtetra
.58 .86 .995 r
.5531 .42577 .55881 .42882 .56969 .42563 .56402 .42272 Mtetra
.567 .862 .996 r
.56402 .42272 .56969 .42563 .58061 .42251 .57498 .41977 Mtetra
.552 .863 .996 r
.57498 .41977 .58061 .42251 .59158 .41946 .586 .41689 Mtetra
.537 .864 .995 r
.586 .41689 .59158 .41946 .6026 .41649 .59706 .41407 Mtetra
.525 .865 .993 r
.59706 .41407 .6026 .41649 .61367 .41359 .60818 .41128 Mtetra
.518 .866 .99 r
.60818 .41128 .61367 .41359 .62479 .41075 .61934 .40847 Mtetra
.522 .87 .99 r
.61934 .40847 .62479 .41075 .63596 .40793 .63056 .40556 Mtetra
.54 .875 .991 r
.63056 .40556 .63596 .40793 .64718 .40509 .64181 .40246 Mtetra
.574 .88 .993 r
.64181 .40246 .64718 .40509 .65844 .40217 .6531 .39906 Mtetra
.618 .879 .99 r
.6531 .39906 .65844 .40217 .66975 .39906 .66443 .39522 Mtetra
.661 .866 .977 r
.66443 .39522 .66975 .39906 .6811 .39569 .67577 .39089 Mtetra
.697 .839 .951 r
.67577 .39089 .6811 .39569 .69247 .39194 .68713 .38597 Mtetra
.715 .802 .919 r
.68713 .38597 .69247 .39194 .70387 .38779 .69849 .38058 Mtetra
.721 .764 .886 r
.69849 .38058 .70387 .38779 .71529 .3832 .70987 .37477 Mtetra
.717 .729 .86 r
.70987 .37477 .71529 .3832 .72673 .37828 .72128 .36879 Mtetra
.707 .7 .841 r
.72128 .36879 .72673 .37828 .73819 .37311 .73271 .36288 Mtetra
.696 .68 .83 r
.73271 .36288 .73819 .37311 .74968 .36786 .7442 .35722 Mtetra
.682 .666 .828 r
.7442 .35722 .74968 .36786 .76121 .36271 .75576 .35205 Mtetra
.67 .661 .832 r
.75576 .35205 .76121 .36271 .7728 .35774 .76739 .34735 Mtetra
.659 .661 .841 r
.76739 .34735 .7728 .35774 .78445 .35309 .7791 .34316 Mtetra
.65 .668 .854 r
.7791 .34316 .78445 .35309 .79617 .34871 .79089 .33935 Mtetra
.643 .679 .869 r
.79089 .33935 .79617 .34871 .80796 .34461 .80276 .33584 Mtetra
.637 .692 .885 r
.80276 .33584 .80796 .34461 .81981 .34071 .8147 .33251 Mtetra
.634 .708 .9 r
.8147 .33251 .81981 .34071 .83173 .33693 .8267 .32927 Mtetra
.633 .725 .914 r
.8267 .32927 .83173 .33693 .8437 .33321 .83876 .32602 Mtetra
.691 .759 .904 r
.20012 .52592 .20671 .53168 .21633 .52794 .20979 .52186 Mtetra
.693 .749 .895 r
.20979 .52186 .21633 .52794 .22599 .5242 .2195 .5177 Mtetra
.692 .737 .885 r
.2195 .5177 .22599 .5242 .23566 .52055 .22924 .51351 Mtetra
.688 .721 .875 r
.22924 .51351 .23566 .52055 .24536 .51707 .23901 .50936 Mtetra
.681 .701 .862 r
.23901 .50936 .24536 .51707 .25507 .51388 .2488 .50531 Mtetra
.669 .676 .848 r
.2488 .50531 .25507 .51388 .26478 .51105 .25861 .50151 Mtetra
.652 .649 .834 r
.25861 .50151 .26478 .51105 .27449 .50873 .26841 .49813 Mtetra
.633 .62 .82 r
.26841 .49813 .27449 .50873 .28421 .50687 .2782 .49529 Mtetra
.61 .593 .808 r
.2782 .49529 .28421 .50687 .29394 .50548 .28799 .49314 Mtetra
.591 .571 .8 r
.28799 .49314 .29394 .50548 .3037 .50433 .29777 .49159 Mtetra
.574 .556 .797 r
.29777 .49159 .3037 .50433 .3135 .50327 .30756 .49063 Mtetra
.564 .553 .801 r
.30756 .49063 .3135 .50327 .32336 .50205 .31739 .48999 Mtetra
.559 .561 .812 r
.31739 .48999 .32336 .50205 .3333 .50044 .32726 .48945 Mtetra
.562 .583 .832 r
.32726 .48945 .3333 .50044 .3433 .49837 .33719 .48876 Mtetra
.572 .618 .86 r
.33719 .48876 .3433 .49837 .35338 .49574 .3472 .48769 Mtetra
.585 .666 .894 r
.3472 .48769 .35338 .49574 .36353 .49263 .35728 .48616 Mtetra
.602 .723 .93 r
.35728 .48616 .36353 .49263 .37373 .4891 .36744 .48408 Mtetra
.612 .78 .961 r
.36744 .48408 .37373 .4891 .38398 .48527 .37766 .48151 Mtetra
.617 .833 .983 r
.37766 .48151 .38398 .48527 .39428 .48126 .38795 .4785 Mtetra
.612 .871 .991 r
.38795 .4785 .39428 .48126 .40461 .47714 .39829 .47515 Mtetra
.601 .896 .988 r
.39829 .47515 .40461 .47714 .41498 .47301 .40868 .47155 Mtetra
.586 .908 .979 r
.40868 .47155 .41498 .47301 .42539 .4689 .41911 .4678 Mtetra
.57 .913 .969 r
.41911 .4678 .42539 .4689 .43582 .46485 .42958 .46396 Mtetra
.557 .914 .961 r
.42958 .46396 .43582 .46485 .44629 .46088 .44009 .46009 Mtetra
.546 .912 .956 r
.44009 .46009 .44629 .46088 .4568 .45699 .45064 .45624 Mtetra
.536 .909 .953 r
.45064 .45624 .4568 .45699 .46734 .45319 .46123 .45243 Mtetra
.528 .906 .951 r
.46123 .45243 .46734 .45319 .47792 .44947 .47185 .44869 Mtetra
.52 .902 .951 r
.47185 .44869 .47792 .44947 .48853 .44584 .48251 .44503 Mtetra
.511 .898 .95 r
.48251 .44503 .48853 .44584 .49919 .44229 .49321 .44145 Mtetra
.502 .894 .95 r
.49321 .44145 .49919 .44229 .50989 .43882 .50395 .43796 Mtetra
.492 .89 .948 r
.50395 .43796 .50989 .43882 .52062 .43543 .51474 .43456 Mtetra
.482 .885 .947 r
.51474 .43456 .52062 .43543 .53141 .43213 .52556 .43125 Mtetra
.472 .88 .945 r
.52556 .43125 .53141 .43213 .54223 .4289 .53644 .42801 Mtetra
.464 .876 .943 r
.53644 .42801 .54223 .4289 .5531 .42577 .54735 .42484 Mtetra
.459 .874 .943 r
.54735 .42484 .5531 .42577 .56402 .42272 .55832 .42172 Mtetra
.461 .874 .946 r
.55832 .42172 .56402 .42272 .57498 .41977 .56933 .41861 Mtetra
.473 .877 .953 r
.56933 .41861 .57498 .41977 .586 .41689 .58038 .41547 Mtetra
.497 .883 .965 r
.58038 .41547 .586 .41689 .59706 .41407 .59149 .41226 Mtetra
.535 .889 .979 r
.59149 .41226 .59706 .41407 .60818 .41128 .60263 .40888 Mtetra
.583 .89 .989 r
.60263 .40888 .60818 .41128 .61934 .40847 .61382 .40525 Mtetra
.633 .878 .987 r
.61382 .40525 .61934 .40847 .63056 .40556 .62504 .40127 Mtetra
.675 .85 .966 r
.62504 .40127 .63056 .40556 .64181 .40246 .63629 .39684 Mtetra
.701 .807 .931 r
.63629 .39684 .64181 .40246 .6531 .39906 .64756 .3919 Mtetra
.714 .761 .889 r
.64756 .3919 .6531 .39906 .66443 .39522 .65884 .38639 Mtetra
.714 .716 .85 r
.65884 .38639 .66443 .39522 .67577 .39089 .67014 .3804 Mtetra
.71 .678 .817 r
.67014 .3804 .67577 .39089 .68713 .38597 .68144 .374 Mtetra
.702 .649 .794 r
.68144 .374 .68713 .38597 .69849 .38058 .69277 .36744 Mtetra
.692 .627 .779 r
.69277 .36744 .69849 .38058 .70987 .37477 .70412 .36098 Mtetra
.682 .613 .773 r
.70412 .36098 .70987 .37477 .72128 .36879 .71553 .35483 Mtetra
.669 .605 .775 r
.71553 .35483 .72128 .36879 .73271 .36288 .727 .34928 Mtetra
.659 .605 .783 r
.727 .34928 .73271 .36288 .7442 .35722 .73855 .34435 Mtetra
.648 .611 .798 r
.73855 .34435 .7442 .35722 .75576 .35205 .75019 .34013 Mtetra
.639 .622 .817 r
.75019 .34013 .75576 .35205 .76739 .34735 .76192 .33646 Mtetra
.631 .639 .84 r
.76192 .33646 .76739 .34735 .7791 .34316 .77373 .33323 Mtetra
.625 .657 .862 r
.77373 .33323 .7791 .34316 .79089 .33935 .78562 .33027 Mtetra
.622 .678 .882 r
.78562 .33027 .79089 .33935 .80276 .33584 .79757 .3274 Mtetra
.619 .695 .899 r
.79757 .3274 .80276 .33584 .8147 .33251 .80959 .32458 Mtetra
.619 .711 .912 r
.80959 .32458 .8147 .33251 .8267 .32927 .82166 .32173 Mtetra
.621 .725 .921 r
.82166 .32173 .8267 .32927 .83876 .32602 .83378 .31877 Mtetra
.692 .759 .903 r
.19348 .52013 .20012 .52592 .20979 .52186 .20317 .51604 Mtetra
.697 .76 .9 r
.20317 .51604 .20979 .52186 .2195 .5177 .21292 .51177 Mtetra
.702 .758 .895 r
.21292 .51177 .2195 .5177 .22924 .51351 .2227 .50732 Mtetra
.706 .752 .887 r
.2227 .50732 .22924 .51351 .23901 .50936 .23253 .5027 Mtetra
.71 .739 .874 r
.23253 .5027 .23901 .50936 .2488 .50531 .24241 .49785 Mtetra
.705 .716 .858 r
.24241 .49785 .2488 .50531 .25861 .50151 .25232 .49297 Mtetra
.695 .687 .838 r
.25232 .49297 .25861 .50151 .26841 .49813 .26225 .48816 Mtetra
.677 .651 .817 r
.26225 .48816 .26841 .49813 .2782 .49529 .27217 .48373 Mtetra
.652 .613 .797 r
.27217 .48373 .2782 .49529 .28799 .49314 .28208 .47993 Mtetra
.626 .577 .779 r
.28208 .47993 .28799 .49314 .29777 .49159 .29196 .47695 Mtetra
.597 .543 .765 r
.29196 .47695 .29777 .49159 .30756 .49063 .30181 .475 Mtetra
.574 .52 .756 r
.30181 .475 .30756 .49063 .31739 .48999 .31165 .47394 Mtetra
.553 .504 .754 r
.31165 .47394 .31739 .48999 .32726 .48945 .32149 .47371 Mtetra
.541 .5 .76 r
.32149 .47371 .32726 .48945 .33719 .48876 .33136 .47392 Mtetra
.535 .508 .773 r
.33136 .47392 .33719 .48876 .3472 .48769 .34127 .47427 Mtetra
.537 .529 .794 r
.34127 .47427 .3472 .48769 .35728 .48616 .35126 .47446 Mtetra
.547 .564 .824 r
.35126 .47446 .35728 .48616 .36744 .48408 .36133 .47421 Mtetra
.56 .609 .859 r
.36133 .47421 .36744 .48408 .37766 .48151 .37148 .47343 Mtetra
.578 .665 .898 r
.37148 .47343 .37766 .48151 .38795 .4785 .38172 .47203 Mtetra
.592 .723 .935 r
.38172 .47203 .38795 .4785 .39829 .47515 .39202 .47007 Mtetra
.603 .779 .965 r
.39202 .47007 .39829 .47515 .40868 .47155 .4024 .46761 Mtetra
.606 .826 .984 r
.4024 .46761 .40868 .47155 .41911 .4678 .41283 .46475 Mtetra
.601 .861 .992 r
.41283 .46475 .41911 .4678 .42958 .46396 .42332 .46159 Mtetra
.591 .883 .992 r
.42332 .46159 .42958 .46396 .44009 .46009 .43386 .45822 Mtetra
.577 .895 .986 r
.43386 .45822 .44009 .46009 .45064 .45624 .44444 .45473 Mtetra
.562 .901 .979 r
.44444 .45473 .45064 .45624 .46123 .45243 .45506 .45116 Mtetra
.547 .902 .971 r
.45506 .45116 .46123 .45243 .47185 .44869 .46572 .44756 Mtetra
.534 .901 .965 r
.46572 .44756 .47185 .44869 .48251 .44503 .47643 .44398 Mtetra
.523 .899 .961 r
.47643 .44398 .48251 .44503 .49321 .44145 .48717 .44043 Mtetra
.515 .896 .958 r
.48717 .44043 .49321 .44145 .50395 .43796 .49796 .43692 Mtetra
.51 .894 .957 r
.49796 .43692 .50395 .43796 .51474 .43456 .50879 .43345 Mtetra
.509 .893 .959 r
.50879 .43345 .51474 .43456 .52556 .43125 .51966 .43001 Mtetra
.514 .893 .964 r
.51966 .43001 .52556 .43125 .53644 .42801 .53058 .42659 Mtetra
.526 .894 .97 r
.53058 .42659 .53644 .42801 .54735 .42484 .54154 .42314 Mtetra
.547 .895 .979 r
.54154 .42314 .54735 .42484 .55832 .42172 .55254 .41962 Mtetra
.577 .896 .986 r
.55254 .41962 .55832 .42172 .56933 .41861 .56359 .41596 Mtetra
.613 .89 .989 r
.56359 .41596 .56933 .41861 .58038 .41547 .57468 .41209 Mtetra
.65 .876 .982 r
.57468 .41209 .58038 .41547 .59149 .41226 .58581 .40792 Mtetra
.683 .848 .962 r
.58581 .40792 .59149 .41226 .60263 .40888 .59696 .40334 Mtetra
.707 .81 .929 r
.59696 .40334 .60263 .40888 .61382 .40525 .60815 .39824 Mtetra
.719 .765 .889 r
.60815 .39824 .61382 .40525 .62504 .40127 .61935 .39257 Mtetra
.723 .721 .848 r
.61935 .39257 .62504 .40127 .63629 .39684 .63056 .38624 Mtetra
.719 .679 .811 r
.63056 .38624 .63629 .39684 .64756 .3919 .64178 .37938 Mtetra
.712 .644 .78 r
.64178 .37938 .64756 .3919 .65884 .38639 .65301 .37204 Mtetra
.701 .615 .758 r
.65301 .37204 .65884 .38639 .67014 .3804 .66424 .36452 Mtetra
.689 .593 .743 r
.66424 .36452 .67014 .3804 .68144 .374 .67551 .35714 Mtetra
.676 .576 .736 r
.67551 .35714 .68144 .374 .69277 .36744 .68681 .35019 Mtetra
.661 .565 .736 r
.68681 .35019 .69277 .36744 .70412 .36098 .69819 .34409 Mtetra
.648 .561 .743 r
.69819 .34409 .70412 .36098 .71553 .35483 .70965 .3389 Mtetra
.633 .563 .758 r
.70965 .3389 .71553 .35483 .727 .34928 .72121 .33477 Mtetra
.621 .574 .779 r
.72121 .33477 .727 .34928 .73855 .34435 .73288 .33148 Mtetra
.61 .592 .808 r
.73288 .33148 .73855 .34435 .75019 .34013 .74464 .32885 Mtetra
.602 .617 .839 r
.74464 .32885 .75019 .34013 .76192 .33646 .7565 .32661 Mtetra
.599 .647 .87 r
.7565 .32661 .76192 .33646 .77373 .33323 .76842 .32445 Mtetra
.597 .675 .895 r
.76842 .32445 .77373 .33323 .78562 .33027 .7804 .32227 Mtetra
.603 .701 .913 r
.7804 .32227 .78562 .33027 .79757 .3274 .79242 .31985 Mtetra
.607 .718 .924 r
.79242 .31985 .79757 .3274 .80959 .32458 .80449 .31724 Mtetra
.613 .729 .929 r
.80449 .31724 .80959 .32458 .82166 .32173 .81661 .31445 Mtetra
.619 .735 .929 r
.81661 .31445 .82166 .32173 .83378 .31877 .82876 .31146 Mtetra
.672 .755 .913 r
.18679 .51429 .19348 .52013 .20317 .51604 .19646 .51071 Mtetra
.679 .775 .923 r
.19646 .51071 .20317 .51604 .21292 .51177 .20617 .50695 Mtetra
.688 .796 .931 r
.20617 .50695 .21292 .51177 .2227 .50732 .21595 .50295 Mtetra
.701 .815 .936 r
.21595 .50295 .2227 .50732 .23253 .5027 .22578 .49862 Mtetra
.717 .829 .934 r
.22578 .49862 .23253 .5027 .24241 .49785 .23568 .49385 Mtetra
.73 .833 .929 r
.23568 .49385 .24241 .49785 .25232 .49297 .24563 .4887 Mtetra
.742 .825 .916 r
.24563 .4887 .25232 .49297 .26225 .48816 .25565 .48316 Mtetra
.742 .8 .899 r
.25565 .48316 .26225 .48816 .27217 .48373 .2657 .4775 Mtetra
.732 .76 .875 r
.2657 .4775 .27217 .48373 .28208 .47993 .27576 .4719 Mtetra
.708 .706 .846 r
.27576 .4719 .28208 .47993 .29196 .47695 .28582 .4667 Mtetra
.675 .648 .815 r
.28582 .4667 .29196 .47695 .30181 .475 .29585 .46222 Mtetra
.641 .591 .783 r
.29585 .46222 .30181 .475 .31165 .47394 .30586 .45863 Mtetra
.607 .543 .756 r
.30586 .45863 .31165 .47394 .32149 .47371 .31583 .45614 Mtetra
.583 .506 .734 r
.31583 .45614 .32149 .47371 .33136 .47392 .32578 .45458 Mtetra
.563 .48 .72 r
.32578 .45458 .33136 .47392 .34127 .47427 .33574 .45388 Mtetra
.552 .466 .712 r
.33574 .45388 .34127 .47427 .35126 .47446 .34572 .45371 Mtetra
.546 .46 .71 r
.34572 .45371 .35126 .47446 .36133 .47421 .35574 .45381 Mtetra
.546 .463 .713 r
.35574 .45381 .36133 .47421 .37148 .47343 .36582 .45392 Mtetra
.551 .473 .721 r
.36582 .45392 .37148 .47343 .38172 .47203 .37598 .45379 Mtetra
.558 .488 .733 r
.37598 .45379 .38172 .47203 .39202 .47007 .3862 .45333 Mtetra
.568 .509 .749 r
.3862 .45333 .39202 .47007 .4024 .46761 .39651 .45243 Mtetra
.579 .533 .767 r
.39651 .45243 .4024 .46761 .41283 .46475 .40688 .4511 Mtetra
.592 .56 .787 r
.40688 .4511 .41283 .46475 .42332 .46159 .41733 .44933 Mtetra
.604 .588 .808 r
.41733 .44933 .42332 .46159 .43386 .45822 .42783 .44719 Mtetra
.615 .616 .828 r
.42783 .44719 .43386 .45822 .44444 .45473 .43839 .44471 Mtetra
.626 .642 .847 r
.43839 .44471 .44444 .45473 .45506 .45116 .44901 .44195 Mtetra
.634 .665 .862 r
.44901 .44195 .45506 .45116 .46572 .44756 .45968 .43895 Mtetra
.642 .683 .874 r
.45968 .43895 .46572 .44756 .47643 .44398 .4704 .43575 Mtetra
.648 .697 .882 r
.4704 .43575 .47643 .44398 .48717 .44043 .48116 .43238 Mtetra
.653 .704 .885 r
.48116 .43238 .48717 .44043 .49796 .43692 .49197 .42884 Mtetra
.658 .706 .883 r
.49197 .42884 .49796 .43692 .50879 .43345 .50283 .42514 Mtetra
.663 .702 .876 r
.50283 .42514 .50879 .43345 .51966 .43001 .51372 .42126 Mtetra
.667 .693 .865 r
.51372 .42126 .51966 .43001 .53058 .42659 .52466 .41718 Mtetra
.67 .68 .85 r
.52466 .41718 .53058 .42659 .54154 .42314 .53564 .41286 Mtetra
.673 .662 .831 r
.53564 .41286 .54154 .42314 .55254 .41962 .54665 .40825 Mtetra
.674 .643 .811 r
.54665 .40825 .55254 .41962 .56359 .41596 .5577 .4033 Mtetra
.674 .622 .789 r
.5577 .4033 .56359 .41596 .57468 .41209 .56877 .39796 Mtetra
.674 .602 .767 r
.56877 .39796 .57468 .41209 .58581 .40792 .57988 .39217 Mtetra
.672 .583 .748 r
.57988 .39217 .58581 .40792 .59696 .40334 .591 .38593 Mtetra
.67 .567 .73 r
.591 .38593 .59696 .40334 .60815 .39824 .60214 .37924 Mtetra
.667 .553 .716 r
.60214 .37924 .60815 .39824 .61935 .39257 .6133 .37219 Mtetra
.663 .541 .705 r
.6133 .37219 .61935 .39257 .63056 .38624 .62447 .36489 Mtetra
.659 .533 .699 r
.62447 .36489 .63056 .38624 .64178 .37938 .63566 .35758 Mtetra
.654 .527 .697 r
.63566 .35758 .64178 .37938 .65301 .37204 .64688 .35054 Mtetra
.648 .525 .7 r
.64688 .35054 .65301 .37204 .66424 .36452 .65814 .34403 Mtetra
.64 .527 .71 r
.65814 .34403 .66424 .36452 .67551 .35714 .66948 .33839 Mtetra
.632 .535 .727 r
.66948 .33839 .67551 .35714 .68681 .35019 .68089 .33371 Mtetra
.62 .55 .753 r
.68089 .33371 .68681 .35019 .69819 .34409 .6924 .33015 Mtetra
.608 .574 .79 r
.6924 .33015 .69819 .34409 .70965 .3389 .70402 .3275 Mtetra
.592 .609 .838 r
.70402 .3275 .70965 .3389 .72121 .33477 .71574 .32561 Mtetra
.573 .651 .889 r
.71574 .32561 .72121 .33477 .73288 .33148 .72755 .32414 Mtetra
.556 .699 .936 r
.72755 .32414 .73288 .33148 .74464 .32885 .73943 .32273 Mtetra
.543 .738 .966 r
.73943 .32273 .74464 .32885 .7565 .32661 .75137 .3212 Mtetra
.549 .77 .98 r
.75137 .3212 .7565 .32661 .76842 .32445 .76335 .31927 Mtetra
.564 .787 .983 r
.76335 .31927 .76842 .32445 .7804 .32227 .77536 .31696 Mtetra
.59 .795 .977 r
.77536 .31696 .7804 .32227 .79242 .31985 .7874 .31418 Mtetra
.612 .791 .967 r
.7874 .31418 .79242 .31985 .80449 .31724 .79946 .31105 Mtetra
.628 .779 .953 r
.79946 .31105 .80449 .31724 .81661 .31445 .81156 .30767 Mtetra
.638 .763 .938 r
.81156 .30767 .81661 .31445 .82876 .31146 .82371 .3041 Mtetra
.636 .746 .928 r
.18006 .50842 .18679 .51429 .19646 .51071 .18966 .50568 Mtetra
.635 .777 .949 r
.18966 .50568 .19646 .51071 .20617 .50695 .19931 .50285 Mtetra
.637 .814 .968 r
.19931 .50285 .20617 .50695 .21595 .50295 .20901 .49982 Mtetra
.642 .854 .981 r
.20901 .49982 .21595 .50295 .22578 .49862 .21879 .49642 Mtetra
.652 .892 .983 r
.21879 .49642 .22578 .49862 .23568 .49385 .22864 .49253 Mtetra
.666 .924 .974 r
.22864 .49253 .23568 .49385 .24563 .4887 .23858 .48802 Mtetra
.695 .947 .958 r
.23858 .48802 .24563 .4887 .25565 .48316 .24862 .48272 Mtetra
.728 .958 .945 r
.24862 .48272 .25565 .48316 .2657 .4775 .25874 .47669 Mtetra
.772 .95 .934 r
.25874 .47669 .2657 .4775 .27576 .4719 .26893 .4699 Mtetra
.795 .911 .92 r
.26893 .4699 .27576 .4719 .28582 .4667 .27918 .4627 Mtetra
.791 .84 .889 r
.27918 .4627 .28582 .4667 .29585 .46222 .28945 .45536 Mtetra
.757 .75 .846 r
.28945 .45536 .29585 .46222 .30586 .45863 .2997 .44838 Mtetra
.711 .663 .801 r
.2997 .44838 .30586 .45863 .31583 .45614 .30992 .44221 Mtetra
.665 .59 .761 r
.30992 .44221 .31583 .45614 .32578 .45458 .3201 .43713 Mtetra
.624 .532 .73 r
.3201 .43713 .32578 .45458 .33574 .45388 .33021 .43343 Mtetra
.594 .492 .708 r
.33021 .43343 .33574 .45388 .34572 .45371 .34029 .43095 Mtetra
.57 .463 .693 r
.34029 .43095 .34572 .45371 .35574 .45381 .35036 .42964 Mtetra
.556 .447 .685 r
.35036 .42964 .35574 .45381 .36582 .45392 .36043 .42912 Mtetra
.547 .438 .682 r
.36043 .42912 .36582 .45392 .37598 .45379 .37054 .4291 Mtetra
.544 .437 .683 r
.37054 .4291 .37598 .45379 .3862 .45333 .3807 .42927 Mtetra
.545 .442 .687 r
.3807 .42927 .3862 .45333 .39651 .45243 .39093 .42937 Mtetra
.55 .45 .694 r
.39093 .42937 .39651 .45243 .40688 .4511 .40123 .42923 Mtetra
.557 .462 .703 r
.40123 .42923 .40688 .4511 .41733 .44933 .4116 .42871 Mtetra
.565 .476 .713 r
.4116 .42871 .41733 .44933 .42783 .44719 .42204 .42776 Mtetra
.575 .491 .723 r
.42204 .42776 .42783 .44719 .43839 .44471 .43256 .42635 Mtetra
.585 .506 .732 r
.43256 .42635 .43839 .44471 .44901 .44195 .44314 .42449 Mtetra
.596 .521 .74 r
.44314 .42449 .44901 .44195 .45968 .43895 .45378 .42217 Mtetra
.606 .533 .747 r
.45378 .42217 .45968 .43895 .4704 .43575 .46448 .41942 Mtetra
.615 .544 .751 r
.46448 .41942 .4704 .43575 .48116 .43238 .47524 .41626 Mtetra
.624 .551 .752 r
.47524 .41626 .48116 .43238 .49197 .42884 .48604 .41269 Mtetra
.631 .555 .75 r
.48604 .41269 .49197 .42884 .50283 .42514 .49689 .40871 Mtetra
.638 .556 .746 r
.49689 .40871 .50283 .42514 .51372 .42126 .50779 .40431 Mtetra
.643 .554 .739 r
.50779 .40431 .51372 .42126 .52466 .41718 .51872 .39947 Mtetra
.647 .55 .731 r
.51872 .39947 .52466 .41718 .53564 .41286 .52969 .39417 Mtetra
.65 .544 .721 r
.52969 .39417 .53564 .41286 .54665 .40825 .54069 .38841 Mtetra
.652 .537 .711 r
.54069 .38841 .54665 .40825 .5577 .4033 .55171 .38217 Mtetra
.652 .529 .701 r
.55171 .38217 .5577 .4033 .56877 .39796 .56276 .37549 Mtetra
.652 .521 .692 r
.56276 .37549 .56877 .39796 .57988 .39217 .57382 .36841 Mtetra
.65 .514 .684 r
.57382 .36841 .57988 .39217 .591 .38593 .5849 .36108 Mtetra
.647 .507 .678 r
.5849 .36108 .591 .38593 .60214 .37924 .59599 .35366 Mtetra
.642 .501 .675 r
.59599 .35366 .60214 .37924 .6133 .37219 .60711 .34642 Mtetra
.636 .496 .675 r
.60711 .34642 .6133 .37219 .62447 .36489 .61827 .33968 Mtetra
.628 .493 .679 r
.61827 .33968 .62447 .36489 .63566 .35758 .62948 .33374 Mtetra
.617 .493 .689 r
.62948 .33374 .63566 .35758 .64688 .35054 .64076 .32898 Mtetra
.605 .499 .707 r
.64076 .32898 .64688 .35054 .65814 .34403 .65213 .32547 Mtetra
.587 .511 .736 r
.65213 .32547 .65814 .34403 .66948 .33839 .66361 .32339 Mtetra
.566 .536 .781 r
.66361 .32339 .66948 .33839 .68089 .33371 .67521 .32242 Mtetra
.534 .58 .848 r
.67521 .32242 .68089 .33371 .6924 .33015 .68692 .3223 Mtetra
.481 .644 .929 r
.68692 .3223 .6924 .33015 .70402 .3275 .69872 .32256 Mtetra
.4 .712 .986 r
.69872 .32256 .70402 .3275 .71574 .32561 .7106 .32268 Mtetra
.309 .741 .97 r
.7106 .32268 .71574 .32561 .72755 .32414 .72253 .3224 Mtetra
.282 .762 .927 r
.72253 .3224 .72755 .32414 .73943 .32273 .73449 .32134 Mtetra
.322 .795 .922 r
.73449 .32134 .73943 .32273 .75137 .3212 .74646 .31952 Mtetra
.42 .845 .954 r
.74646 .31952 .75137 .3212 .76335 .31927 .75844 .31688 Mtetra
.518 .876 .984 r
.75844 .31688 .76335 .31927 .77536 .31696 .77043 .3136 Mtetra
.596 .877 .993 r
.77043 .3136 .77536 .31696 .7874 .31418 .78244 .30979 Mtetra
.642 .855 .981 r
.78244 .30979 .7874 .31418 .79946 .31105 .79446 .30561 Mtetra
.664 .823 .96 r
.79446 .30561 .79946 .31105 .81156 .30767 .80652 .30119 Mtetra
.672 .789 .937 r
.80652 .30119 .81156 .30767 .82371 .3041 .81861 .29669 Mtetra
.599 .736 .94 r
.17328 .5025 .18006 .50842 .18966 .50568 .18283 .50048 Mtetra
.588 .76 .96 r
.18283 .50048 .18966 .50568 .19931 .50285 .19241 .49848 Mtetra
.579 .79 .979 r
.19241 .49848 .19931 .50285 .20901 .49982 .20205 .4964 Mtetra
.568 .825 .994 r
.20205 .4964 .20901 .49982 .21879 .49642 .21174 .49413 Mtetra
.549 .861 .996 r
.21174 .49413 .21879 .49642 .22864 .49253 .22151 .49158 Mtetra
.52 .891 .971 r
.22151 .49158 .22864 .49253 .23858 .48802 .23135 .48854 Mtetra
.478 .895 .901 r
.23135 .48854 .23858 .48802 .24862 .48272 .24129 .48483 Mtetra
.421 .863 .787 r
.24129 .48483 .24862 .48272 .25874 .47669 .25134 .48032 Mtetra
.38 .818 .669 r
.25134 .48032 .25874 .47669 .26893 .4699 .26149 .47481 Mtetra
0 0 0 r
.26149 .47481 .26893 .4699 .27918 .4627 .27173 .4684 Mtetra
.27173 .4684 .27918 .4627 .28945 .45536 .28206 .4611 Mtetra
.28206 .4611 .28945 .45536 .2997 .44838 .29244 .45331 Mtetra
.5 .865 .631 r
.29244 .45331 .2997 .44838 .30992 .44221 .30285 .44529 Mtetra
.639 .958 .783 r
.30285 .44529 .30992 .44221 .3201 .43713 .31325 .43751 Mtetra
.748 .981 .913 r
.31325 .43751 .3201 .43713 .33021 .43343 .32362 .43035 Mtetra
.765 .882 .93 r
.32362 .43035 .33021 .43343 .34029 .43095 .33396 .42402 Mtetra
.716 .745 .875 r
.33396 .42402 .34029 .43095 .35036 .42964 .34426 .41874 Mtetra
.666 .637 .811 r
.34426 .41874 .35036 .42964 .36043 .42912 .35454 .41441 Mtetra
.627 .563 .763 r
.35454 .41441 .36043 .42912 .37054 .4291 .36481 .41099 Mtetra
.603 .516 .729 r
.36481 .41099 .37054 .4291 .3807 .42927 .37509 .40825 Mtetra
.588 .486 .706 r
.37509 .40825 .3807 .42927 .39093 .42937 .38538 .406 Mtetra
.579 .467 .69 r
.38538 .406 .39093 .42937 .40123 .42923 .39572 .40405 Mtetra
.575 .456 .68 r
.39572 .40405 .40123 .42923 .4116 .42871 .4061 .4022 Mtetra
.574 .449 .673 r
.4061 .4022 .4116 .42871 .42204 .42776 .41653 .40033 Mtetra
.575 .446 .668 r
.41653 .40033 .42204 .42776 .43256 .42635 .42701 .39829 Mtetra
.577 .446 .665 r
.42701 .39829 .43256 .42635 .44314 .42449 .43756 .39603 Mtetra
.58 .447 .664 r
.43756 .39603 .44314 .42449 .45378 .42217 .44816 .39347 Mtetra
.584 .449 .663 r
.44816 .39347 .45378 .42217 .46448 .41942 .45882 .39058 Mtetra
.588 .451 .662 r
.45882 .39058 .46448 .41942 .47524 .41626 .46952 .38733 Mtetra
.593 .454 .661 r
.46952 .38733 .47524 .41626 .48604 .41269 .48028 .38371 Mtetra
.597 .457 .661 r
.48028 .38371 .48604 .41269 .49689 .40871 .49109 .37972 Mtetra
.601 .459 .661 r
.49109 .37972 .49689 .40871 .50779 .40431 .50194 .37538 Mtetra
.605 .462 .661 r
.50194 .37538 .50779 .40431 .51872 .39947 .51282 .3707 Mtetra
.608 .465 .662 r
.51282 .3707 .51872 .39947 .52969 .39417 .52375 .36571 Mtetra
.612 .469 .663 r
.52375 .36571 .52969 .39417 .54069 .38841 .5347 .36049 Mtetra
.615 .473 .665 r
.5347 .36049 .54069 .38841 .55171 .38217 .54569 .3551 Mtetra
.617 .478 .669 r
.54569 .3551 .55171 .38217 .56276 .37549 .55672 .34968 Mtetra
.619 .484 .676 r
.55672 .34968 .56276 .37549 .57382 .36841 .56777 .34436 Mtetra
.62 .493 .686 r
.56777 .34436 .57382 .36841 .5849 .36108 .57887 .33932 Mtetra
.62 .506 .702 r
.57887 .33932 .5849 .36108 .59599 .35366 .59001 .33479 Mtetra
.618 .525 .727 r
.59001 .33479 .59599 .35366 .60711 .34642 .6012 .33095 Mtetra
.61 .554 .766 r
.6012 .33095 .60711 .34642 .61827 .33968 .61247 .32803 Mtetra
.593 .602 .831 r
.61247 .32803 .61827 .33968 .62948 .33374 .62382 .32609 Mtetra
.535 .676 .929 r
.62382 .32609 .62948 .33374 .64076 .32898 .63527 .32522 Mtetra
.345 .729 .985 r
.63527 .32522 .64076 .32898 .65213 .32547 .64682 .32522 Mtetra
.043 0 0 r
.64682 .32522 .65213 .32547 .66361 .32339 .65848 .32586 Mtetra
.276 0 0 r
.65848 .32586 .66361 .32339 .67521 .32242 .67022 .32676 Mtetra
.345 0 0 r
.67022 .32676 .67521 .32242 .68692 .3223 .68204 .32745 Mtetra
.343 0 0 r
.68204 .32745 .68692 .3223 .69872 .32256 .69392 .32764 Mtetra
.288 0 0 r
.69392 .32764 .69872 .32256 .7106 .32268 .70582 .32691 Mtetra
.189 0 0 r
.70582 .32691 .7106 .32268 .72253 .3224 .71774 .32527 Mtetra
.014 0 0 r
.71774 .32527 .72253 .3224 .73449 .32134 .72966 .32259 Mtetra
.217 .732 .699 r
.72966 .32259 .73449 .32134 .74646 .31952 .74159 .31907 Mtetra
.449 .881 .89 r
.74159 .31907 .74646 .31952 .75844 .31688 .75351 .31486 Mtetra
.596 .921 .97 r
.75351 .31486 .75844 .31688 .77043 .3136 .76545 .31013 Mtetra
.664 .899 .979 r
.76545 .31013 .77043 .3136 .78244 .30979 .77741 .3051 Mtetra
.692 .863 .963 r
.77741 .3051 .78244 .30979 .79446 .30561 .78939 .29986 Mtetra
.701 .827 .943 r
.78939 .29986 .79446 .30561 .80652 .30119 .80141 .29453 Mtetra
.699 .795 .924 r
.80141 .29453 .80652 .30119 .81861 .29669 .81347 .28921 Mtetra
.576 .729 .946 r
.16646 .49655 .17328 .5025 .18283 .50048 .17598 .4949 Mtetra
.563 .739 .958 r
.17598 .4949 .18283 .50048 .19241 .49848 .18553 .49337 Mtetra
.548 .752 .972 r
.18553 .49337 .19241 .49848 .20205 .4964 .19512 .49193 Mtetra
.526 .77 .987 r
.19512 .49193 .20205 .4964 .21174 .49413 .20475 .49056 Mtetra
.485 .792 .999 r
.20475 .49056 .21174 .49413 .22151 .49158 .21442 .48928 Mtetra
.421 .811 .988 r
.21442 .48928 .22151 .49158 .23135 .48854 .22415 .48792 Mtetra
.299 .786 .9 r
.22415 .48792 .23135 .48854 .24129 .48483 .23393 .48639 Mtetra
0 0 0 r
.23393 .48639 .24129 .48483 .25134 .48032 .24381 .48441 Mtetra
.028 0 0 r
.24381 .48441 .25134 .48032 .26149 .47481 .25378 .48178 Mtetra
.127 0 0 r
.25378 .48178 .26149 .47481 .27173 .4684 .26386 .47821 Mtetra
.164 0 0 r
.26386 .47821 .27173 .4684 .28206 .4611 .27408 .4734 Mtetra
.174 0 .03 r
.27408 .4734 .28206 .4611 .29244 .45331 .28443 .46729 Mtetra
.15 0 .055 r
.28443 .46729 .29244 .45331 .30285 .44529 .29489 .45975 Mtetra
.109 0 .044 r
.29489 .45975 .30285 .44529 .31325 .43751 .30544 .45113 Mtetra
.029 0 0 r
.30544 .45113 .31325 .43751 .32362 .43035 .31605 .44167 Mtetra
0 0 0 r
.31605 .44167 .32362 .43035 .33396 .42402 .32668 .43192 Mtetra
.32668 .43192 .33396 .42402 .34426 .41874 .3373 .42234 Mtetra
.673 .963 .752 r
.3373 .42234 .34426 .41874 .35454 .41441 .34789 .41331 Mtetra
.812 .95 .91 r
.34789 .41331 .35454 .41441 .36481 .41099 .35845 .40515 Mtetra
.772 .792 .869 r
.35845 .40515 .36481 .41099 .37509 .40825 .36896 .39791 Mtetra
.711 .668 .806 r
.36896 .39791 .37509 .40825 .38538 .406 .37945 .39164 Mtetra
.668 .59 .759 r
.37945 .39164 .38538 .406 .39572 .40405 .38993 .3862 Mtetra
.638 .54 .727 r
.38993 .3862 .39572 .40405 .4061 .4022 .4004 .38147 Mtetra
.619 .508 .705 r
.4004 .38147 .4061 .4022 .41653 .40033 .41089 .37727 Mtetra
.607 .487 .69 r
.41089 .37727 .41653 .40033 .42701 .39829 .42141 .37345 Mtetra
.6 .474 .68 r
.42141 .37345 .42701 .39829 .43756 .39603 .43195 .36984 Mtetra
.596 .465 .673 r
.43195 .36984 .43756 .39603 .44816 .39347 .44254 .36633 Mtetra
.594 .46 .669 r
.44254 .36633 .44816 .39347 .45882 .39058 .45317 .36282 Mtetra
.593 .458 .666 r
.45317 .36282 .45882 .39058 .46952 .38733 .46384 .35925 Mtetra
.594 .457 .665 r
.46384 .35925 .46952 .38733 .48028 .38371 .47455 .35559 Mtetra
.595 .458 .664 r
.47455 .35559 .48028 .38371 .49109 .37972 .48531 .35184 Mtetra
.596 .459 .666 r
.48531 .35184 .49109 .37972 .50194 .37538 .49611 .34802 Mtetra
.597 .462 .668 r
.49611 .34802 .50194 .37538 .51282 .3707 .50695 .34421 Mtetra
.597 .466 .673 r
.50695 .34421 .51282 .3707 .52375 .36571 .51783 .34049 Mtetra
.596 .472 .68 r
.51783 .34049 .52375 .36571 .5347 .36049 .52876 .337 Mtetra
.594 .479 .692 r
.52876 .337 .5347 .36049 .54569 .3551 .53974 .33388 Mtetra
.59 .49 .709 r
.53974 .33388 .54569 .3551 .55672 .34968 .55076 .33129 Mtetra
.582 .507 .736 r
.55076 .33129 .55672 .34968 .56777 .34436 .56185 .32943 Mtetra
.566 .535 .78 r
.56185 .32943 .56777 .34436 .57887 .33932 .57301 .32842 Mtetra
.525 .582 .854 r
.57301 .32842 .57887 .33932 .59001 .33479 .58426 .32841 Mtetra
.397 .651 .96 r
.58426 .32841 .59001 .33479 .6012 .33095 .59559 .32934 Mtetra
0 .526 .777 r
.59559 .32934 .6012 .33095 .61247 .32803 .60703 .33118 Mtetra
.408 0 0 r
.60703 .33118 .61247 .32803 .62382 .32609 .61858 .3336 Mtetra
.494 .022 .062 r
.61858 .3336 .62382 .32609 .63527 .32522 .63023 .33621 Mtetra
.507 .083 .17 r
.63023 .33621 .63527 .32522 .64682 .32522 .64196 .33855 Mtetra
.495 .096 .213 r
.64196 .33855 .64682 .32522 .65848 .32586 .65374 .34004 Mtetra
.472 .082 .218 r
.65374 .34004 .65848 .32586 .67022 .32676 .66557 .34043 Mtetra
.431 .04 .194 r
.66557 .34043 .67022 .32676 .68204 .32745 .67741 .33936 Mtetra
.372 0 .134 r
.67741 .33936 .68204 .32745 .69392 .32764 .68925 .33696 Mtetra
.271 0 .017 r
.68925 .33696 .69392 .32764 .70582 .32691 .70109 .33328 Mtetra
.101 0 0 r
.70109 .33328 .70582 .32691 .71774 .32527 .71291 .32861 Mtetra
0 0 0 r
.71291 .32861 .71774 .32527 .72966 .32259 .72474 .32325 Mtetra
.484 .898 .817 r
.72474 .32325 .72966 .32259 .74159 .31907 .73657 .31743 Mtetra
.656 .952 .949 r
.73657 .31743 .74159 .31907 .75351 .31486 .74843 .31142 Mtetra
.713 .915 .964 r
.74843 .31142 .75351 .31486 .76545 .31013 .76032 .30531 Mtetra
.723 .868 .949 r
.76032 .30531 .76545 .31013 .77741 .3051 .77225 .29928 Mtetra
.722 .832 .933 r
.77225 .29928 .77741 .3051 .78939 .29986 .78422 .29332 Mtetra
.718 .806 .92 r
.78422 .29332 .78939 .29986 .80141 .29453 .79623 .28744 Mtetra
.712 .787 .911 r
.79623 .28744 .80141 .29453 .81347 .28921 .8083 .28168 Mtetra
.592 .734 .942 r
.15958 .49055 .16646 .49655 .17598 .4949 .16915 .48861 Mtetra
.586 .722 .937 r
.16915 .48861 .17598 .4949 .18553 .49337 .17875 .48682 Mtetra
.577 .711 .934 r
.17875 .48682 .18553 .49337 .19512 .49193 .18837 .48521 Mtetra
.565 .702 .933 r
.18837 .48521 .19512 .49193 .20475 .49056 .19801 .48384 Mtetra
.547 .695 .937 r
.19801 .48384 .20475 .49056 .21442 .48928 .20767 .48276 Mtetra
.529 .697 .946 r
.20767 .48276 .21442 .48928 .22415 .48792 .21736 .48192 Mtetra
.504 .706 .961 r
.21736 .48192 .22415 .48792 .23393 .48639 .22709 .4813 Mtetra
.476 .731 .982 r
.22709 .4813 .23393 .48639 .24381 .48441 .23686 .4807 Mtetra
.428 .765 .996 r
.23686 .4807 .24381 .48441 .25378 .48178 .2467 .47998 Mtetra
.347 .79 .96 r
.2467 .47998 .25378 .48178 .26386 .47821 .25662 .47883 Mtetra
.203 .731 .785 r
.25662 .47883 .26386 .47821 .27408 .4734 .26665 .47699 Mtetra
0 0 0 r
.26665 .47699 .27408 .4734 .28443 .46729 .2768 .4742 Mtetra
.087 0 0 r
.2768 .4742 .28443 .46729 .29489 .45975 .28708 .4702 Mtetra
.165 0 0 r
.28708 .4702 .29489 .45975 .30544 .45113 .29748 .465 Mtetra
.205 0 .08 r
.29748 .465 .30544 .45113 .31605 .44167 .30799 .45857 Mtetra
.237 0 .15 r
.30799 .45857 .31605 .44167 .32668 .43192 .31858 .45122 Mtetra
.257 0 .192 r
.31858 .45122 .32668 .43192 .3373 .42234 .32922 .44318 Mtetra
.273 0 .217 r
.32922 .44318 .3373 .42234 .34789 .41331 .33989 .43483 Mtetra
.284 0 .23 r
.33989 .43483 .34789 .41331 .35845 .40515 .35057 .42648 Mtetra
.29 0 .231 r
.35057 .42648 .35845 .40515 .36896 .39791 .36125 .41837 Mtetra
.294 0 .225 r
.36125 .41837 .36896 .39791 .37945 .39164 .37192 .4107 Mtetra
.291 0 .209 r
.37192 .4107 .37945 .39164 .38993 .3862 .38259 .40352 Mtetra
.285 0 .185 r
.38259 .40352 .38993 .3862 .4004 .38147 .39324 .39691 Mtetra
.273 0 .152 r
.39324 .39691 .4004 .38147 .41089 .37727 .4039 .39082 Mtetra
.256 0 .109 r
.4039 .39082 .41089 .37727 .42141 .37345 .41457 .38524 Mtetra
.235 0 .06 r
.41457 .38524 .42141 .37345 .43195 .36984 .42525 .38012 Mtetra
.214 0 .007 r
.42525 .38012 .43195 .36984 .44254 .36633 .43595 .37541 Mtetra
.195 0 0 r
.43595 .37541 .44254 .36633 .45317 .36282 .44667 .37106 Mtetra
.186 0 0 r
.44667 .37106 .45317 .36282 .46384 .35925 .45743 .36706 Mtetra
.191 0 0 r
.45743 .36706 .46384 .35925 .47455 .35559 .46822 .36339 Mtetra
.213 0 0 r
.46822 .36339 .47455 .35559 .48531 .35184 .47905 .36004 Mtetra
.25 0 0 r
.47905 .36004 .48531 .35184 .49611 .34802 .48992 .35703 Mtetra
.296 0 .012 r
.48992 .35703 .49611 .34802 .50695 .34421 .50083 .3544 Mtetra
.343 0 .074 r
.50083 .3544 .50695 .34421 .51783 .34049 .5118 .35218 Mtetra
.386 0 .135 r
.5118 .35218 .51783 .34049 .52876 .337 .52281 .35043 Mtetra
.422 .03 .188 r
.52281 .35043 .52876 .337 .53974 .33388 .53389 .3492 Mtetra
.451 .074 .231 r
.53389 .3492 .53974 .33388 .55076 .33129 .54504 .34851 Mtetra
.474 .109 .265 r
.54504 .34851 .55076 .33129 .56185 .32943 .55626 .3484 Mtetra
.49 .135 .29 r
.55626 .3484 .56185 .32943 .57301 .32842 .56755 .3488 Mtetra
.501 .153 .307 r
.56755 .3488 .57301 .32842 .58426 .32841 .57893 .34967 Mtetra
.507 .162 .316 r
.57893 .34967 .58426 .32841 .59559 .32934 .5904 .35079 Mtetra
.507 .162 .317 r
.5904 .35079 .59559 .32934 .60703 .33118 .60195 .35193 Mtetra
.501 .153 .308 r
.60195 .35193 .60703 .33118 .61858 .3336 .61357 .35277 Mtetra
.484 .129 .287 r
.61357 .35277 .61858 .3336 .63023 .33621 .62526 .35292 Mtetra
.456 .086 .248 r
.62526 .35292 .63023 .33621 .64196 .33855 .63699 .35214 Mtetra
.4 .008 .176 r
.63699 .35214 .64196 .33855 .65374 .34004 .64874 .35009 Mtetra
.301 0 .048 r
.64874 .35009 .65374 .34004 .66557 .34043 .6605 .34682 Mtetra
.1 0 0 r
.6605 .34682 .66557 .34043 .67741 .33936 .67226 .34229 Mtetra
0 0 0 r
.67226 .34229 .67741 .33936 .68925 .33696 .68402 .33677 Mtetra
.597 .949 .891 r
.68402 .33677 .68925 .33696 .70109 .33328 .69577 .33053 Mtetra
.73 .938 .954 r
.69577 .33053 .70109 .33328 .71291 .32861 .70753 .32383 Mtetra
.753 .872 .934 r
.70753 .32383 .71291 .32861 .72474 .32325 .71932 .317 Mtetra
.748 .821 .908 r
.71932 .317 .72474 .32325 .73657 .31743 .73113 .31017 Mtetra
.736 .786 .893 r
.73113 .31017 .73657 .31743 .74843 .31142 .74299 .30356 Mtetra
.726 .766 .884 r
.74299 .30356 .74843 .31142 .76032 .30531 .7549 .29718 Mtetra
.716 .755 .883 r
.7549 .29718 .76032 .30531 .77225 .29928 .76686 .2911 Mtetra
.709 .752 .886 r
.76686 .2911 .77225 .29928 .78422 .29332 .77888 .28526 Mtetra
.704 .755 .891 r
.77888 .28526 .78422 .29332 .79623 .28744 .79095 .2796 Mtetra
.7 .761 .899 r
.79095 .2796 .79623 .28744 .8083 .28168 .80308 .27409 Mtetra
.632 .745 .929 r
.15266 .48451 .15958 .49055 .16915 .48861 .16234 .48175 Mtetra
.628 .718 .911 r
.16234 .48175 .16915 .48861 .17875 .48682 .17203 .47912 Mtetra
.62 .691 .894 r
.17203 .47912 .17875 .48682 .18837 .48521 .18175 .47668 Mtetra
.609 .664 .878 r
.18175 .47668 .18837 .48521 .19801 .48384 .19148 .47452 Mtetra
.595 .639 .865 r
.19148 .47452 .19801 .48384 .20767 .48276 .20122 .47272 Mtetra
.58 .616 .853 r
.20122 .47272 .20767 .48276 .21736 .48192 .21097 .47131 Mtetra
.564 .597 .845 r
.21097 .47131 .21736 .48192 .22709 .4813 .22072 .47034 Mtetra
.548 .583 .841 r
.22072 .47034 .22709 .4813 .23686 .4807 .23049 .46977 Mtetra
.531 .576 .845 r
.23049 .46977 .23686 .4807 .2467 .47998 .24028 .46962 Mtetra
.513 .58 .86 r
.24028 .46962 .2467 .47998 .25662 .47883 .2501 .4698 Mtetra
.484 .602 .894 r
.2501 .4698 .25662 .47883 .26665 .47699 .25996 .47026 Mtetra
.431 .652 .952 r
.25996 .47026 .26665 .47699 .2768 .4742 .26987 .47079 Mtetra
.265 .696 .965 r
.26987 .47079 .2768 .4742 .28708 .4702 .27985 .47125 Mtetra
.107 0 0 r
.27985 .47125 .28708 .4702 .29748 .465 .28992 .47131 Mtetra
.327 0 0 r
.28992 .47131 .29748 .465 .30799 .45857 .3001 .47069 Mtetra
.391 0 .142 r
.3001 .47069 .30799 .45857 .31858 .45122 .3104 .46913 Mtetra
.407 .05 .243 r
.3104 .46913 .31858 .45122 .32922 .44318 .32082 .46638 Mtetra
.414 .085 .296 r
.32082 .46638 .32922 .44318 .33989 .43483 .33136 .46251 Mtetra
.414 .102 .325 r
.33136 .46251 .33989 .43483 .35057 .42648 .34199 .45752 Mtetra
.414 .113 .342 r
.34199 .45752 .35057 .42648 .36125 .41837 .35271 .45168 Mtetra
.413 .118 .352 r
.35271 .45168 .36125 .41837 .37192 .4107 .36348 .44522 Mtetra
.413 .121 .357 r
.36348 .44522 .37192 .4107 .38259 .40352 .37429 .43842 Mtetra
.413 .122 .359 r
.37429 .43842 .38259 .40352 .39324 .39691 .38512 .43152 Mtetra
.414 .123 .358 r
.38512 .43152 .39324 .39691 .4039 .39082 .39597 .42474 Mtetra
.417 .123 .357 r
.39597 .42474 .4039 .39082 .41457 .38524 .40683 .41825 Mtetra
.42 .124 .355 r
.40683 .41825 .41457 .38524 .42525 .38012 .4177 .41218 Mtetra
.425 .127 .353 r
.4177 .41218 .42525 .38012 .43595 .37541 .42858 .40664 Mtetra
.432 .13 .351 r
.42858 .40664 .43595 .37541 .44667 .37106 .43948 .40168 Mtetra
.44 .136 .351 r
.43948 .40168 .44667 .37106 .45743 .36706 .45039 .39735 Mtetra
.449 .143 .353 r
.45039 .39735 .45743 .36706 .46822 .36339 .46134 .39368 Mtetra
.459 .152 .356 r
.46134 .39368 .46822 .36339 .47905 .36004 .47231 .39067 Mtetra
.469 .162 .361 r
.47231 .39067 .47905 .36004 .48992 .35703 .48333 .38829 Mtetra
.479 .171 .366 r
.48333 .38829 .48992 .35703 .50083 .3544 .49439 .3865 Mtetra
.487 .181 .372 r
.49439 .3865 .50083 .3544 .5118 .35218 .50551 .38526 Mtetra
.494 .189 .378 r
.50551 .38526 .5118 .35218 .52281 .35043 .51669 .38444 Mtetra
.498 .195 .382 r
.51669 .38444 .52281 .35043 .53389 .3492 .52794 .38393 Mtetra
.5 .198 .385 r
.52794 .38393 .53389 .3492 .54504 .34851 .53926 .38354 Mtetra
.53926 .38354 .54504 .34851 .55626 .3484 .55064 .38308 Mtetra
.495 .193 .383 r
.55064 .38308 .55626 .3484 .56755 .3488 .5621 .38227 Mtetra
.487 .183 .376 r
.5621 .38227 .56755 .3488 .57893 .34967 .57361 .38084 Mtetra
.472 .164 .362 r
.57361 .38084 .57893 .34967 .5904 .35079 .58517 .37856 Mtetra
.448 .133 .338 r
.58517 .37856 .5904 .35079 .60195 .35193 .59677 .37513 Mtetra
.408 .081 .295 r
.59677 .37513 .60195 .35193 .61357 .35277 .60839 .37054 Mtetra
.336 0 .215 r
.60839 .37054 .61357 .35277 .62526 .35292 .62001 .36474 Mtetra
.188 0 .045 r
.62001 .36474 .62526 .35292 .63699 .35214 .63164 .35796 Mtetra
0 0 0 r
.63164 .35796 .63699 .35214 .64874 .35009 .64327 .35047 Mtetra
.676 .978 .861 r
.64327 .35047 .64874 .35009 .6605 .34682 .65491 .34255 Mtetra
.79 .892 .917 r
.65491 .34255 .6605 .34682 .67226 .34229 .66656 .33453 Mtetra
.765 .776 .862 r
.66656 .33453 .67226 .34229 .68402 .33677 .67823 .32658 Mtetra
.737 .709 .825 r
.67823 .32658 .68402 .33677 .69577 .33053 .68994 .3189 Mtetra
.718 .674 .806 r
.68994 .3189 .69577 .33053 .70753 .32383 .70169 .31155 Mtetra
.705 .657 .8 r
.70169 .31155 .70753 .32383 .71932 .317 .71349 .30461 Mtetra
.696 .652 .802 r
.71349 .30461 .71932 .317 .73113 .31017 .72534 .29809 Mtetra
.689 .654 .811 r
.72534 .29809 .73113 .31017 .74299 .30356 .73726 .29201 Mtetra
.683 .662 .823 r
.73726 .29201 .74299 .30356 .7549 .29718 .74924 .28632 Mtetra
.679 .674 .839 r
.74924 .28632 .7549 .29718 .76686 .2911 .76129 .28101 Mtetra
.676 .691 .856 r
.76129 .28101 .76686 .2911 .77888 .28526 .77341 .27598 Mtetra
.674 .711 .876 r
.77341 .27598 .77888 .28526 .79095 .2796 .78559 .27115 Mtetra
.673 .734 .896 r
.78559 .27115 .79095 .2796 .80308 .27409 .79782 .26643 Mtetra
.677 .756 .911 r
.14569 .47843 .15266 .48451 .16234 .48175 .15551 .47457 Mtetra
.671 .722 .887 r
.15551 .47457 .16234 .48175 .17203 .47912 .16535 .47079 Mtetra
.661 .688 .865 r
.16535 .47079 .17203 .47912 .18175 .47668 .1752 .46715 Mtetra
.648 .656 .844 r
.1752 .46715 .18175 .47668 .19148 .47452 .18507 .46376 Mtetra
.633 .625 .824 r
.18507 .46376 .19148 .47452 .20122 .47272 .19493 .4607 Mtetra
.617 .596 .806 r
.19493 .4607 .20122 .47272 .21097 .47131 .2048 .45806 Mtetra
.6 .568 .79 r
.2048 .45806 .21097 .47131 .22072 .47034 .21466 .45591 Mtetra
.583 .544 .776 r
.21466 .45591 .22072 .47034 .23049 .46977 .22452 .4543 Mtetra
.566 .522 .765 r
.22452 .4543 .23049 .46977 .24028 .46962 .23437 .45329 Mtetra
.55 .503 .756 r
.23437 .45329 .24028 .46962 .2501 .4698 .24422 .45285 Mtetra
.534 .488 .75 r
.24422 .45285 .2501 .4698 .25996 .47026 .25408 .453 Mtetra
.522 .478 .748 r
.25408 .453 .25996 .47026 .26987 .47079 .26397 .45361 Mtetra
.512 .473 .75 r
.26397 .45361 .26987 .47079 .27985 .47125 .27389 .45458 Mtetra
.508 .477 .757 r
.27389 .45458 .27985 .47125 .28992 .47131 .28387 .45564 Mtetra
.508 .49 .771 r
.28387 .45564 .28992 .47131 .3001 .47069 .29393 .45658 Mtetra
.516 .516 .795 r
.29393 .45658 .3001 .47069 .3104 .46913 .30408 .45711 Mtetra
.531 .56 .83 r
.30408 .45711 .3104 .46913 .32082 .46638 .31434 .45701 Mtetra
.548 .629 .883 r
.31434 .45701 .32082 .46638 .33136 .46251 .3247 .45618 Mtetra
.563 .729 .953 r
.3247 .45618 .33136 .46251 .34199 .45752 .33517 .45452 Mtetra
.529 .842 .999 r
.33517 .45452 .34199 .45752 .35271 .45168 .34574 .45213 Mtetra
.355 .829 .854 r
.34574 .45213 .35271 .45168 .36348 .44522 .35639 .44906 Mtetra
0 0 0 r
.35639 .44906 .36348 .44522 .37429 .43842 .36711 .44549 Mtetra
.114 0 0 r
.36711 .44549 .37429 .43842 .38512 .43152 .37788 .44155 Mtetra
.222 0 0 r
.37788 .44155 .38512 .43152 .39597 .42474 .38871 .43737 Mtetra
.285 0 .092 r
.38871 .43737 .39597 .42474 .40683 .41825 .39958 .43309 Mtetra
.325 0 .156 r
.39958 .43309 .40683 .41825 .4177 .41218 .41049 .4288 Mtetra
.352 0 .197 r
.41049 .4288 .4177 .41218 .42858 .40664 .42144 .42459 Mtetra
.371 .015 .224 r
.42144 .42459 .42858 .40664 .43948 .40168 .43242 .42052 Mtetra
.385 .033 .241 r
.43242 .42052 .43948 .40168 .45039 .39735 .44344 .41664 Mtetra
.394 .045 .249 r
.44344 .41664 .45039 .39735 .46134 .39368 .4545 .41297 Mtetra
.4 .05 .252 r
.4545 .41297 .46134 .39368 .47231 .39067 .4656 .4095 Mtetra
.402 .049 .247 r
.4656 .4095 .47231 .39067 .48333 .38829 .47674 .40621 Mtetra
.399 .04 .235 r
.47674 .40621 .48333 .38829 .49439 .3865 .48793 .40307 Mtetra
.39 .022 .214 r
.48793 .40307 .49439 .3865 .50551 .38526 .49917 .40002 Mtetra
.372 0 .178 r
.49917 .40002 .50551 .38526 .51669 .38444 .51046 .39696 Mtetra
.338 0 .118 r
.51046 .39696 .51669 .38444 .52794 .38393 .52181 .39379 Mtetra
.274 0 .016 r
.52181 .39379 .52794 .38393 .53926 .38354 .5332 .39039 Mtetra
.145 0 0 r
.5332 .39039 .53926 .38354 .55064 .38308 .54464 .38661 Mtetra
0 0 0 r
.54464 .38661 .55064 .38308 .5621 .38227 .55612 .38232 Mtetra
.517 .915 .893 r
.55612 .38232 .5621 .38227 .57361 .38084 .56764 .37733 Mtetra
.711 .898 .964 r
.56764 .37733 .57361 .38084 .58517 .37856 .57919 .3716 Mtetra
.74 .787 .891 r
.57919 .3716 .58517 .37856 .59677 .37513 .59075 .365 Mtetra
.731 .704 .825 r
.59075 .365 .59677 .37513 .60839 .37054 .60233 .35765 Mtetra
.72 .652 .781 r
.60233 .35765 .60839 .37054 .62001 .36474 .61391 .34962 Mtetra
.709 .618 .753 r
.61391 .34962 .62001 .36474 .63164 .35796 .62549 .34117 Mtetra
.7 .596 .737 r
.62549 .34117 .63164 .35796 .64327 .35047 .63709 .33258 Mtetra
.691 .581 .728 r
.63709 .33258 .64327 .35047 .65491 .34255 .6487 .32406 Mtetra
.683 .572 .724 r
.6487 .32406 .65491 .34255 .66656 .33453 .66034 .31589 Mtetra
.675 .567 .725 r
.66034 .31589 .66656 .33453 .67823 .32658 .67203 .30819 Mtetra
.668 .565 .729 r
.67203 .30819 .67823 .32658 .68994 .3189 .68376 .30107 Mtetra
.662 .567 .737 r
.68376 .30107 .68994 .3189 .70169 .31155 .69556 .29454 Mtetra
.656 .572 .748 r
.69556 .29454 .70169 .31155 .71349 .30461 .70742 .28862 Mtetra
.652 .58 .762 r
.70742 .28862 .71349 .30461 .72534 .29809 .71936 .28325 Mtetra
.647 .593 .779 r
.71936 .28325 .72534 .29809 .73726 .29201 .73137 .27839 Mtetra
.644 .609 .799 r
.73137 .27839 .73726 .29201 .74924 .28632 .74345 .27396 Mtetra
.641 .628 .822 r
.74345 .27396 .74924 .28632 .76129 .28101 .75561 .26986 Mtetra
.639 .651 .846 r
.75561 .26986 .76129 .28101 .77341 .27598 .76785 .26602 Mtetra
.637 .678 .872 r
.76785 .26602 .77341 .27598 .78559 .27115 .78016 .26234 Mtetra
.636 .709 .899 r
.78016 .26234 .78559 .27115 .79782 .26643 .79252 .25872 Mtetra
.712 .763 .892 r
.13868 .4723 .14569 .47843 .15551 .47457 .14863 .46737 Mtetra
.706 .731 .87 r
.14863 .46737 .15551 .47457 .16535 .47079 .15861 .46244 Mtetra
.696 .699 .849 r
.15861 .46244 .16535 .47079 .1752 .46715 .16862 .45758 Mtetra
.683 .669 .829 r
.16862 .45758 .1752 .46715 .18507 .46376 .17863 .45287 Mtetra
.669 .638 .81 r
.17863 .45287 .18507 .46376 .19493 .4607 .18865 .44839 Mtetra
.654 .609 .791 r
.18865 .44839 .19493 .4607 .2048 .45806 .19867 .44424 Mtetra
.637 .58 .774 r
.19867 .44424 .2048 .45806 .21466 .45591 .20868 .4405 Mtetra
.62 .552 .756 r
.20868 .4405 .21466 .45591 .22452 .4543 .21868 .43722 Mtetra
.604 .526 .74 r
.21868 .43722 .22452 .4543 .23437 .45329 .22867 .43444 Mtetra
.59 .503 .724 r
.22867 .43444 .23437 .45329 .24422 .45285 .23867 .43213 Mtetra
.578 .482 .709 r
.23867 .43213 .24422 .45285 .25408 .453 .24867 .43025 Mtetra
.568 .463 .695 r
.24867 .43025 .25408 .453 .26397 .45361 .25869 .42872 Mtetra
.561 .447 .681 r
.25869 .42872 .26397 .45361 .27389 .45458 .26874 .42748 Mtetra
.554 .433 .669 r
.26874 .42748 .27389 .45458 .28387 .45564 .27883 .42653 Mtetra
.549 .422 .659 r
.27883 .42653 .28387 .45564 .29393 .45658 .28895 .42584 Mtetra
.544 .413 .652 r
.28895 .42584 .29393 .45658 .30408 .45711 .2991 .42545 Mtetra
.539 .407 .649 r
.2991 .42545 .30408 .45711 .31434 .45701 .30929 .42537 Mtetra
.536 .405 .649 r
.30929 .42537 .31434 .45701 .3247 .45618 .31953 .42555 Mtetra
.533 .407 .654 r
.31953 .42555 .3247 .45618 .33517 .45452 .32983 .42591 Mtetra
.532 .414 .664 r
.32983 .42591 .33517 .45452 .34574 .45213 .34018 .42633 Mtetra
.533 .427 .68 r
.34018 .42633 .34574 .45213 .35639 .44906 .35061 .42667 Mtetra
.536 .449 .704 r
.35061 .42667 .35639 .44906 .36711 .44549 .36112 .42682 Mtetra
.542 .481 .738 r
.36112 .42682 .36711 .44549 .37788 .44155 .3717 .42666 Mtetra
.549 .528 .784 r
.3717 .42666 .37788 .44155 .38871 .43737 .38237 .42611 Mtetra
.559 .595 .846 r
.38237 .42611 .38871 .43737 .39958 .43309 .39312 .42511 Mtetra
.565 .682 .918 r
.39312 .42511 .39958 .43309 .41049 .4288 .40395 .42361 Mtetra
.558 .777 .98 r
.40395 .42361 .41049 .4288 .42144 .42459 .41486 .42157 Mtetra
.529 .848 .998 r
.41486 .42157 .42144 .42459 .43242 .42052 .42584 .41899 Mtetra
.497 .879 .971 r
.42584 .41899 .43242 .42052 .44344 .41664 .43688 .41585 Mtetra
.496 .894 .944 r
.43688 .41585 .44344 .41664 .4545 .41297 .44799 .41216 Mtetra
.545 .915 .948 r
.44799 .41216 .4545 .41297 .4656 .4095 .45915 .4079 Mtetra
.626 .928 .971 r
.45915 .4079 .4656 .4095 .47674 .40621 .47037 .40308 Mtetra
.698 .9 .969 r
.47037 .40308 .47674 .40621 .48793 .40307 .48163 .3977 Mtetra
.73 .828 .926 r
.48163 .3977 .48793 .40307 .49917 .40002 .49293 .39178 Mtetra
.728 .741 .862 r
.49293 .39178 .49917 .40002 .51046 .39696 .50427 .38535 Mtetra
.71 .664 .803 r
.50427 .38535 .51046 .39696 .52181 .39379 .51563 .37844 Mtetra
.69 .603 .754 r
.51563 .37844 .52181 .39379 .5332 .39039 .52702 .37113 Mtetra
.672 .558 .717 r
.52702 .37113 .5332 .39039 .54464 .38661 .53844 .3635 Mtetra
.656 .524 .691 r
.53844 .3635 .54464 .38661 .55612 .38232 .54987 .35566 Mtetra
.644 .499 .671 r
.54987 .35566 .55612 .38232 .56764 .37733 .56132 .34772 Mtetra
.634 .482 .658 r
.56132 .34772 .56764 .37733 .57919 .3716 .57278 .33982 Mtetra
.626 .469 .65 r
.57278 .33982 .57919 .3716 .59075 .365 .58427 .3321 Mtetra
.621 .463 .647 r
.58427 .3321 .59075 .365 .60233 .35765 .59579 .32462 Mtetra
.617 .46 .646 r
.59579 .32462 .60233 .35765 .61391 .34962 .60734 .31745 Mtetra
.616 .462 .65 r
.60734 .31745 .61391 .34962 .62549 .34117 .61892 .31058 Mtetra
.617 .468 .656 r
.61892 .31058 .62549 .34117 .63709 .33258 .63053 .30397 Mtetra
.619 .476 .665 r
.63053 .30397 .63709 .33258 .6487 .32406 .64219 .29763 Mtetra
.622 .487 .676 r
.64219 .29763 .6487 .32406 .66034 .31589 .65389 .29159 Mtetra
.623 .498 .689 r
.65389 .29159 .66034 .31589 .67203 .30819 .66564 .2859 Mtetra
.624 .51 .704 r
.66564 .2859 .67203 .30819 .68376 .30107 .67745 .28065 Mtetra
.623 .523 .72 r
.67745 .28065 .68376 .30107 .69556 .29454 .68933 .27586 Mtetra
.62 .536 .737 r
.68933 .27586 .69556 .29454 .70742 .28862 .70128 .27161 Mtetra
.617 .55 .757 r
.70128 .27161 .70742 .28862 .71936 .28325 .71332 .26782 Mtetra
.613 .567 .779 r
.71332 .26782 .71936 .28325 .73137 .27839 .72543 .26446 Mtetra
.61 .586 .802 r
.72543 .26446 .73137 .27839 .74345 .27396 .73763 .26144 Mtetra
.606 .609 .828 r
.73763 .26144 .74345 .27396 .75561 .26986 .74991 .25866 Mtetra
.603 .634 .854 r
.74991 .25866 .75561 .26986 .76785 .26602 .76226 .25604 Mtetra
.6 .661 .881 r
.76226 .25604 .76785 .26602 .78016 .26234 .77469 .2535 Mtetra
.597 .691 .908 r
.77469 .2535 .78016 .26234 .79252 .25872 .78718 .25095 Mtetra
.729 .765 .881 r
.13161 .46613 .13868 .4723 .14863 .46737 .14166 .46057 Mtetra
.727 .747 .869 r
.14166 .46057 .14863 .46737 .15861 .46244 .15174 .45494 Mtetra
.722 .728 .855 r
.15174 .45494 .15861 .46244 .16862 .45758 .16185 .44928 Mtetra
.715 .708 .842 r
.16185 .44928 .16862 .45758 .17863 .45287 .17198 .44362 Mtetra
.707 .685 .826 r
.17198 .44362 .17863 .45287 .18865 .44839 .18214 .438 Mtetra
.695 .659 .81 r
.18214 .438 .18865 .44839 .19867 .44424 .1923 .4325 Mtetra
.682 .631 .792 r
.1923 .4325 .19867 .44424 .20868 .4405 .20247 .42719 Mtetra
.666 .602 .773 r
.20247 .42719 .20868 .4405 .21868 .43722 .21264 .42215 Mtetra
.65 .573 .754 r
.21264 .42215 .21868 .43722 .22867 .43444 .22281 .41745 Mtetra
.634 .545 .736 r
.22281 .41745 .22867 .43444 .23867 .43213 .23297 .41311 Mtetra
.619 .519 .719 r
.23297 .41311 .23867 .43213 .24867 .43025 .24313 .40917 Mtetra
.605 .497 .704 r
.24313 .40917 .24867 .43025 .25869 .42872 .2533 .40565 Mtetra
.593 .478 .691 r
.2533 .40565 .25869 .42872 .26874 .42748 .26346 .40254 Mtetra
.583 .461 .68 r
.26346 .40254 .26874 .42748 .27883 .42653 .27364 .39989 Mtetra
.573 .447 .671 r
.27364 .39989 .27883 .42653 .28895 .42584 .28382 .3977 Mtetra
.564 .435 .664 r
.28382 .3977 .28895 .42584 .2991 .42545 .29402 .39598 Mtetra
.556 .425 .658 r
.29402 .39598 .2991 .42545 .30929 .42537 .30424 .3947 Mtetra
.55 .417 .653 r
.30424 .3947 .30929 .42537 .31953 .42555 .31449 .39378 Mtetra
.546 .411 .648 r
.31449 .39378 .31953 .42555 .32983 .42591 .32478 .39313 Mtetra
.544 .407 .645 r
.32478 .39313 .32983 .42591 .34018 .42633 .33513 .39261 Mtetra
.543 .404 .641 r
.33513 .39261 .34018 .42633 .35061 .42667 .34553 .39209 Mtetra
.544 .402 .639 r
.34553 .39209 .35061 .42667 .36112 .42682 .356 .39147 Mtetra
.547 .402 .636 r
.356 .39147 .36112 .42682 .3717 .42666 .36655 .39064 Mtetra
.549 .403 .635 r
.36655 .39064 .3717 .42666 .38237 .42611 .37716 .38953 Mtetra
.553 .404 .633 r
.37716 .38953 .38237 .42611 .39312 .42511 .38785 .38807 Mtetra
.557 .406 .632 r
.38785 .38807 .39312 .42511 .40395 .42361 .39862 .38621 Mtetra
.562 .409 .631 r
.39862 .38621 .40395 .42361 .41486 .42157 .40946 .38391 Mtetra
.566 .412 .631 r
.40946 .38391 .41486 .42157 .42584 .41899 .42036 .38114 Mtetra
.571 .415 .631 r
.42036 .38114 .42584 .41899 .43688 .41585 .43133 .37789 Mtetra
.576 .418 .63 r
.43133 .37789 .43688 .41585 .44799 .41216 .44236 .37413 Mtetra
.581 .421 .63 r
.44236 .37413 .44799 .41216 .45915 .4079 .45345 .36988 Mtetra
.585 .425 .63 r
.45345 .36988 .45915 .4079 .47037 .40308 .46459 .36513 Mtetra
.59 .428 .631 r
.46459 .36513 .47037 .40308 .48163 .3977 .47577 .35991 Mtetra
.594 .432 .631 r
.47577 .35991 .48163 .3977 .49293 .39178 .48699 .35424 Mtetra
.598 .435 .632 r
.48699 .35424 .49293 .39178 .50427 .38535 .49826 .34817 Mtetra
.602 .439 .632 r
.49826 .34817 .50427 .38535 .51563 .37844 .50955 .34172 Mtetra
.606 .442 .634 r
.50955 .34172 .51563 .37844 .52702 .37113 .52087 .33499 Mtetra
.609 .445 .635 r
.52087 .33499 .52702 .37113 .53844 .3635 .53222 .32803 Mtetra
.611 .449 .637 r
.53222 .32803 .53844 .3635 .54987 .35566 .54359 .32096 Mtetra
.612 .452 .64 r
.54359 .32096 .54987 .35566 .56132 .34772 .55499 .31388 Mtetra
.613 .454 .643 r
.55499 .31388 .56132 .34772 .57278 .33982 .56641 .30692 Mtetra
.612 .456 .646 r
.56641 .30692 .57278 .33982 .58427 .3321 .57786 .30022 Mtetra
.611 .459 .65 r
.57786 .30022 .58427 .3321 .59579 .32462 .58935 .29387 Mtetra
.609 .461 .655 r
.58935 .29387 .59579 .32462 .60734 .31745 .60088 .28797 Mtetra
.606 .464 .661 r
.60088 .28797 .60734 .31745 .61892 .31058 .61245 .28254 Mtetra
.604 .468 .669 r
.61245 .28254 .61892 .31058 .63053 .30397 .62408 .27758 Mtetra
.602 .474 .678 r
.62408 .27758 .63053 .30397 .64219 .29763 .63577 .27308 Mtetra
.6 .482 .69 r
.63577 .27308 .64219 .29763 .65389 .29159 .64752 .26901 Mtetra
.599 .493 .705 r
.64752 .26901 .65389 .29159 .66564 .2859 .65934 .26536 Mtetra
.597 .506 .722 r
.65934 .26536 .66564 .2859 .67745 .28065 .67124 .26213 Mtetra
.595 .522 .743 r
.67124 .26213 .67745 .28065 .68933 .27586 .68321 .25927 Mtetra
.592 .541 .766 r
.68321 .25927 .68933 .27586 .70128 .27161 .69526 .25677 Mtetra
.588 .561 .791 r
.69526 .25677 .70128 .27161 .71332 .26782 .70739 .25454 Mtetra
.584 .584 .818 r
.70739 .25454 .71332 .26782 .72543 .26446 .71961 .25251 Mtetra
.581 .607 .843 r
.71961 .25251 .72543 .26446 .73763 .26144 .7319 .25062 Mtetra
.578 .63 .867 r
.7319 .25062 .73763 .26144 .74991 .25866 .74427 .24877 Mtetra
.575 .652 .888 r
.74427 .24877 .74991 .25866 .76226 .25604 .75671 .24693 Mtetra
.572 .672 .907 r
.75671 .24693 .76226 .25604 .77469 .2535 .76922 .24506 Mtetra
.57 .692 .923 r
.76922 .24506 .77469 .2535 .78718 .25095 .7818 .24311 Mtetra
.731 .765 .88 r
.12449 .45992 .13161 .46613 .14166 .46057 .13458 .45427 Mtetra
.734 .764 .877 r
.13458 .45427 .14166 .46057 .15174 .45494 .1447 .44849 Mtetra
.736 .761 .873 r
.1447 .44849 .15174 .45494 .16185 .44928 .15486 .44258 Mtetra
.737 .755 .867 r
.15486 .44258 .16185 .44928 .17198 .44362 .16506 .43653 Mtetra
.738 .745 .857 r
.16506 .43653 .17198 .44362 .18214 .438 .1753 .4303 Mtetra
.735 .729 .846 r
.1753 .4303 .18214 .438 .1923 .4325 .18557 .42396 Mtetra
.729 .709 .831 r
.18557 .42396 .1923 .4325 .20247 .42719 .19587 .41755 Mtetra
.719 .683 .815 r
.19587 .41755 .20247 .42719 .21264 .42215 .20619 .41118 Mtetra
.706 .655 .797 r
.20619 .41118 .21264 .42215 .22281 .41745 .21651 .40493 Mtetra
.689 .624 .778 r
.21651 .40493 .22281 .41745 .23297 .41311 .22683 .39894 Mtetra
.671 .595 .761 r
.22683 .39894 .23297 .41311 .24313 .40917 .23714 .39335 Mtetra
.653 .567 .746 r
.23714 .39335 .24313 .40917 .2533 .40565 .24743 .38825 Mtetra
.635 .543 .733 r
.24743 .38825 .2533 .40565 .26346 .40254 .25771 .38372 Mtetra
.62 .522 .722 r
.25771 .38372 .26346 .40254 .27364 .39989 .26797 .3797 Mtetra
.607 .504 .712 r
.26797 .3797 .27364 .39989 .28382 .3977 .27823 .37617 Mtetra
.598 .49 .702 r
.27823 .37617 .28382 .3977 .29402 .39598 .28852 .37292 Mtetra
.592 .478 .692 r
.28852 .37292 .29402 .39598 .30424 .3947 .29883 .36981 Mtetra
.588 .466 .68 r
.29883 .36981 .30424 .3947 .31449 .39378 .30919 .36669 Mtetra
.586 .454 .668 r
.30919 .36669 .31449 .39378 .32478 .39313 .3196 .36345 Mtetra
.583 .443 .656 r
.3196 .36345 .32478 .39313 .33513 .39261 .33006 .36008 Mtetra
.58 .432 .645 r
.33006 .36008 .33513 .39261 .34553 .39209 .34057 .35655 Mtetra
.577 .422 .635 r
.34057 .35655 .34553 .39209 .356 .39147 .35114 .3529 Mtetra
.575 .414 .626 r
.35114 .3529 .356 .39147 .36655 .39064 .36174 .34916 Mtetra
.572 .406 .618 r
.36174 .34916 .36655 .39064 .37716 .38953 .37239 .34538 Mtetra
.569 .4 .612 r
.37239 .34538 .37716 .38953 .38785 .38807 .38309 .34158 Mtetra
.567 .395 .608 r
.38309 .34158 .38785 .38807 .39862 .38621 .39382 .33778 Mtetra
.565 .391 .604 r
.39382 .33778 .39862 .38621 .40946 .38391 .4046 .33399 Mtetra
.564 .388 .602 r
.4046 .33399 .40946 .38391 .42036 .38114 .41542 .33019 Mtetra
.563 .387 .6 r
.41542 .33019 .42036 .38114 .43133 .37789 .42628 .32638 Mtetra
.563 .386 .599 r
.42628 .32638 .43133 .37789 .44236 .37413 .43719 .32256 Mtetra
.43719 .32256 .44236 .37413 .45345 .36988 .44814 .31873 Mtetra
.563 .387 .6 r
.44814 .31873 .45345 .36988 .46459 .36513 .45914 .31489 Mtetra
.564 .388 .602 r
.45914 .31489 .46459 .36513 .47577 .35991 .47018 .31104 Mtetra
.565 .391 .604 r
.47018 .31104 .47577 .35991 .48699 .35424 .48126 .30721 Mtetra
.566 .394 .608 r
.48126 .30721 .48699 .35424 .49826 .34817 .4924 .30336 Mtetra
.568 .399 .612 r
.4924 .30336 .49826 .34817 .50955 .34172 .50357 .2995 Mtetra
.571 .406 .618 r
.50357 .2995 .50955 .34172 .52087 .33499 .51479 .2956 Mtetra
.575 .414 .626 r
.51479 .2956 .52087 .33499 .53222 .32803 .52606 .2916 Mtetra
.58 .424 .635 r
.52606 .2916 .53222 .32803 .54359 .32096 .53738 .28748 Mtetra
.586 .436 .645 r
.53738 .28748 .54359 .32096 .55499 .31388 .54874 .2832 Mtetra
.592 .449 .656 r
.54874 .2832 .55499 .31388 .56641 .30692 .56014 .27878 Mtetra
.598 .463 .668 r
.56014 .27878 .56641 .30692 .57786 .30022 .57158 .27424 Mtetra
.603 .475 .679 r
.57158 .27424 .57786 .30022 .58935 .29387 .58307 .26968 Mtetra
.606 .486 .69 r
.58307 .26968 .58935 .29387 .60088 .28797 .59461 .26527 Mtetra
.605 .495 .701 r
.59461 .26527 .60088 .28797 .61245 .28254 .60619 .26113 Mtetra
.601 .501 .712 r
.60619 .26113 .61245 .28254 .62408 .27758 .61785 .25749 Mtetra
.595 .508 .725 r
.61785 .25749 .62408 .27758 .63577 .27308 .62957 .25438 Mtetra
.587 .515 .741 r
.62957 .25438 .63577 .27308 .64752 .26901 .64137 .25186 Mtetra
.58 .526 .76 r
.64137 .25186 .64752 .26901 .65934 .26536 .65326 .24985 Mtetra
.572 .542 .783 r
.65326 .24985 .65934 .26536 .67124 .26213 .66523 .24824 Mtetra
.565 .562 .809 r
.66523 .24824 .67124 .26213 .68321 .25927 .67728 .24692 Mtetra
.559 .586 .837 r
.67728 .24692 .68321 .25927 .69526 .25677 .68942 .24573 Mtetra
.554 .612 .865 r
.68942 .24573 .69526 .25677 .70739 .25454 .70164 .24458 Mtetra
.552 .637 .889 r
.70164 .24458 .70739 .25454 .71961 .25251 .71393 .24336 Mtetra
.55 .659 .908 r
.71393 .24336 .71961 .25251 .7319 .25062 .72628 .24204 Mtetra
.553 .678 .922 r
.72628 .24204 .7319 .25062 .74427 .24877 .73871 .24055 Mtetra
.555 .691 .93 r
.73871 .24055 .74427 .24877 .75671 .24693 .7512 .2389 Mtetra
.559 .7 .935 r
.7512 .2389 .75671 .24693 .76922 .24506 .76375 .23712 Mtetra
.563 .706 .937 r
.76375 .23712 .76922 .24506 .7818 .24311 .77637 .23521 Mtetra
.713 .763 .892 r
.11732 .45366 .12449 .45992 .13458 .45427 .12735 .44864 Mtetra
.72 .784 .903 r
.12735 .44864 .13458 .45427 .1447 .44849 .13743 .44349 Mtetra
.728 .807 .913 r
.13743 .44349 .1447 .44849 .15486 .44258 .14755 .43816 Mtetra
.736 .828 .922 r
.14755 .43816 .15486 .44258 .16506 .43653 .15772 .43263 Mtetra
.746 .848 .927 r
.15772 .43263 .16506 .43653 .1753 .4303 .16795 .42683 Mtetra
.753 .864 .93 r
.16795 .42683 .1753 .4303 .18557 .42396 .17822 .4208 Mtetra
.761 .875 .93 r
.17822 .4208 .18557 .42396 .19587 .41755 .18854 .41453 Mtetra
.765 .882 .93 r
.18854 .41453 .19587 .41755 .20619 .41118 .1989 .40812 Mtetra
.768 .881 .928 r
.1989 .40812 .20619 .41118 .21651 .40493 .20929 .40162 Mtetra
.767 .874 .926 r
.20929 .40162 .21651 .40493 .22683 .39894 .21969 .39513 Mtetra
.762 .857 .921 r
.21969 .39513 .22683 .39894 .23714 .39335 .2301 .38876 Mtetra
.753 .831 .912 r
.2301 .38876 .23714 .39335 .24743 .38825 .24052 .38259 Mtetra
.739 .795 .897 r
.24052 .38259 .24743 .38825 .25771 .38372 .25094 .37667 Mtetra
.723 .752 .875 r
.25094 .37667 .25771 .38372 .26797 .3797 .26136 .37099 Mtetra
.705 .704 .847 r
.26136 .37099 .26797 .3797 .27823 .37617 .2718 .36554 Mtetra
.687 .658 .816 r
.2718 .36554 .27823 .37617 .28852 .37292 .28224 .36024 Mtetra
.672 .618 .786 r
.28224 .36024 .28852 .37292 .29883 .36981 .29271 .35503 Mtetra
.658 .584 .761 r
.29271 .35503 .29883 .36981 .30919 .36669 .30321 .34989 Mtetra
.647 .557 .739 r
.30321 .34989 .30919 .36669 .3196 .36345 .31374 .34478 Mtetra
.637 .535 .722 r
.31374 .34478 .3196 .36345 .33006 .36008 .32429 .33974 Mtetra
.629 .518 .709 r
.32429 .33974 .33006 .36008 .34057 .35655 .33487 .33476 Mtetra
.622 .505 .699 r
.33487 .33476 .34057 .35655 .35114 .3529 .34547 .32989 Mtetra
.616 .494 .691 r
.34547 .32989 .35114 .3529 .36174 .34916 .35611 .32513 Mtetra
.611 .486 .685 r
.35611 .32513 .36174 .34916 .37239 .34538 .36677 .3205 Mtetra
.607 .479 .68 r
.36677 .3205 .37239 .34538 .38309 .34158 .37746 .31602 Mtetra
.603 .473 .677 r
.37746 .31602 .38309 .34158 .39382 .33778 .38818 .31168 Mtetra
.599 .469 .674 r
.38818 .31168 .39382 .33778 .4046 .33399 .39894 .30747 Mtetra
.597 .465 .672 r
.39894 .30747 .4046 .33399 .41542 .33019 .40973 .30339 Mtetra
.594 .463 .671 r
.40973 .30339 .41542 .33019 .42628 .32638 .42056 .29942 Mtetra
.593 .461 .671 r
.42056 .29942 .42628 .32638 .43719 .32256 .43142 .29556 Mtetra
.591 .46 .671 r
.43142 .29556 .43719 .32256 .44814 .31873 .44233 .2918 Mtetra
.589 .459 .671 r
.44233 .2918 .44814 .31873 .45914 .31489 .45328 .28816 Mtetra
.588 .46 .673 r
.45328 .28816 .45914 .31489 .47018 .31104 .46427 .28463 Mtetra
.587 .46 .675 r
.46427 .28463 .47018 .31104 .48126 .30721 .47531 .28125 Mtetra
.585 .462 .678 r
.47531 .28125 .48126 .30721 .4924 .30336 .4864 .27801 Mtetra
.584 .464 .682 r
.4864 .27801 .4924 .30336 .50357 .2995 .49753 .27492 Mtetra
.583 .468 .687 r
.49753 .27492 .50357 .2995 .51479 .2956 .50872 .27196 Mtetra
.583 .473 .694 r
.50872 .27196 .51479 .2956 .52606 .2916 .51995 .26913 Mtetra
.584 .481 .703 r
.51995 .26913 .52606 .2916 .53738 .28748 .53125 .26639 Mtetra
.585 .492 .715 r
.53125 .26639 .53738 .28748 .54874 .2832 .54259 .26374 Mtetra
.587 .506 .73 r
.54259 .26374 .54874 .2832 .56014 .27878 .554 .26114 Mtetra
.59 .525 .75 r
.554 .26114 .56014 .27878 .57158 .27424 .56547 .25859 Mtetra
.593 .549 .775 r
.56547 .25859 .57158 .27424 .58307 .26968 .57699 .2561 Mtetra
.594 .58 .806 r
.57699 .2561 .58307 .26968 .59461 .26527 .58858 .25371 Mtetra
.592 .616 .844 r
.58858 .25371 .59461 .26527 .60619 .26113 .60023 .25148 Mtetra
.582 .655 .887 r
.60023 .25148 .60619 .26113 .61785 .25749 .61196 .24949 Mtetra
.563 .694 .929 r
.61196 .24949 .61785 .25749 .62957 .25438 .62375 .24774 Mtetra
.532 .727 .964 r
.62375 .24774 .62957 .25438 .64137 .25186 .63563 .24627 Mtetra
.496 .75 .986 r
.63563 .24627 .64137 .25186 .65326 .24985 .64758 .245 Mtetra
.462 .763 .995 r
.64758 .245 .65326 .24985 .66523 .24824 .65962 .24386 Mtetra
.439 .771 .997 r
.65962 .24386 .66523 .24824 .67728 .24692 .67173 .24275 Mtetra
.435 .777 .997 r
.67173 .24275 .67728 .24692 .68942 .24573 .68391 .24154 Mtetra
.445 .783 .998 r
.68391 .24154 .68942 .24573 .70164 .24458 .69616 .24019 Mtetra
.47 .789 .999 r
.69616 .24019 .70164 .24458 .71393 .24336 .70847 .2386 Mtetra
.498 .789 .997 r
.70847 .2386 .71393 .24336 .72628 .24204 .72085 .23678 Mtetra
.529 .786 .991 r
.72085 .23678 .72628 .24204 .73871 .24055 .73327 .23468 Mtetra
.553 .775 .981 r
.73327 .23468 .73871 .24055 .7512 .2389 .74576 .23237 Mtetra
.572 .76 .967 r
.74576 .23237 .7512 .2389 .76375 .23712 .7583 .22988 Mtetra
.586 .743 .951 r
.7583 .22988 .76375 .23712 .77637 .23521 .7709 .22725 Mtetra
.675 .756 .912 r
.1101 .44736 .11732 .45366 .12735 .44864 .12002 .44344 Mtetra
.68 .794 .935 r
.12002 .44344 .12735 .44864 .13743 .44349 .12999 .43941 Mtetra
.683 .835 .957 r
.12999 .43941 .13743 .44349 .14755 .43816 .14 .43522 Mtetra
.682 .877 .971 r
.14 .43522 .14755 .43816 .15772 .43263 .15008 .43082 Mtetra
.676 .914 .975 r
.15008 .43082 .15772 .43263 .16795 .42683 .16022 .42614 Mtetra
.659 .941 .963 r
.16022 .42614 .16795 .42683 .17822 .4208 .17042 .42119 Mtetra
.631 .953 .932 r
.17042 .42119 .17822 .4208 .18854 .41453 .18067 .41594 Mtetra
.591 .948 .885 r
.18067 .41594 .18854 .41453 .1989 .40812 .19099 .41041 Mtetra
.548 .929 .829 r
.19099 .41041 .1989 .40812 .20929 .40162 .20136 .40461 Mtetra
.512 .906 .777 r
.20136 .40461 .20929 .40162 .21969 .39513 .21178 .39854 Mtetra
.496 .893 .745 r
.21178 .39854 .21969 .39513 .2301 .38876 .22225 .39224 Mtetra
.509 .899 .744 r
.22225 .39224 .2301 .38876 .24052 .38259 .23276 .38571 Mtetra
.555 .925 .777 r
.23276 .38571 .24052 .38259 .25094 .37667 .2433 .37896 Mtetra
.625 .96 .836 r
.2433 .37896 .25094 .37667 .26136 .37099 .25388 .37208 Mtetra
.698 .98 .896 r
.25388 .37208 .26136 .37099 .2718 .36554 .26449 .36511 Mtetra
.747 .967 .933 r
.26449 .36511 .2718 .36554 .28224 .36024 .27511 .35821 Mtetra
.765 .926 .94 r
.27511 .35821 .28224 .36024 .29271 .35503 .28574 .35149 Mtetra
.76 .876 .931 r
.28574 .35149 .29271 .35503 .30321 .34989 .29636 .34507 Mtetra
.744 .832 .918 r
.29636 .34507 .30321 .34989 .31374 .34478 .30698 .33904 Mtetra
.728 .799 .908 r
.30698 .33904 .31374 .34478 .32429 .33974 .3176 .33339 Mtetra
.713 .778 .903 r
.3176 .33339 .32429 .33974 .33487 .33476 .32823 .32812 Mtetra
.701 .767 .903 r
.32823 .32812 .33487 .33476 .34547 .32989 .33886 .32319 Mtetra
.691 .764 .907 r
.33886 .32319 .34547 .32989 .35611 .32513 .34952 .31854 Mtetra
.683 .766 .914 r
.34952 .31854 .35611 .32513 .36677 .3205 .3602 .3141 Mtetra
.677 .771 .922 r
.3602 .3141 .36677 .3205 .37746 .31602 .37091 .30983 Mtetra
.672 .778 .93 r
.37091 .30983 .37746 .31602 .38818 .31168 .38165 .30569 Mtetra
.667 .785 .936 r
.38165 .30569 .38818 .31168 .39894 .30747 .39243 .30164 Mtetra
.664 .79 .942 r
.39243 .30164 .39894 .30747 .40973 .30339 .40325 .29765 Mtetra
.66 .793 .946 r
.40325 .29765 .40973 .30339 .42056 .29942 .41411 .29372 Mtetra
.658 .795 .948 r
.41411 .29372 .42056 .29942 .43142 .29556 .425 .28983 Mtetra
.655 .794 .949 r
.425 .28983 .43142 .29556 .44233 .2918 .43595 .28598 Mtetra
.652 .791 .948 r
.43595 .28598 .44233 .2918 .45328 .28816 .44693 .28218 Mtetra
.649 .786 .947 r
.44693 .28218 .45328 .28816 .46427 .28463 .45796 .27845 Mtetra
.645 .778 .944 r
.45796 .27845 .46427 .28463 .47531 .28125 .46904 .27481 Mtetra
.64 .768 .941 r
.46904 .27481 .47531 .28125 .4864 .27801 .48015 .2713 Mtetra
.633 .757 .937 r
.48015 .2713 .4864 .27801 .49753 .27492 .49132 .26796 Mtetra
.624 .746 .935 r
.49132 .26796 .49753 .27492 .50872 .27196 .50254 .26483 Mtetra
.611 .737 .935 r
.50254 .26483 .50872 .27196 .51995 .26913 .5138 .262 Mtetra
.595 .732 .939 r
.5138 .262 .51995 .26913 .53125 .26639 .52512 .2595 Mtetra
.573 .731 .95 r
.52512 .2595 .53125 .26639 .54259 .26374 .5365 .2574 Mtetra
.544 .74 .966 r
.5365 .2574 .54259 .26374 .554 .26114 .54795 .25569 Mtetra
.499 .754 .986 r
.54795 .25569 .554 .26114 .56547 .25859 .55947 .25438 Mtetra
.429 .769 .997 r
.55947 .25438 .56547 .25859 .57699 .2561 .57106 .25339 Mtetra
.321 .762 .965 r
.57106 .25339 .57699 .2561 .58858 .25371 .58272 .25259 Mtetra
.18 .707 .86 r
.58272 .25259 .58858 .25371 .60023 .25148 .59446 .25186 Mtetra
.049 .616 .707 r
.59446 .25186 .60023 .25148 .61196 .24949 .60628 .25106 Mtetra
.04 0 0 r
.60628 .25106 .61196 .24949 .62375 .24774 .61816 .25012 Mtetra
.083 0 0 r
.61816 .25012 .62375 .24774 .63563 .24627 .63012 .24898 Mtetra
.088 0 0 r
.63012 .24898 .63563 .24627 .64758 .245 .64214 .2476 Mtetra
.06 0 0 r
.64214 .2476 .64758 .245 .65962 .24386 .65423 .24598 Mtetra
.002 0 0 r
.65423 .24598 .65962 .24386 .67173 .24275 .66637 .2441 Mtetra
0 0 0 r
.66637 .2441 .67173 .24275 .68391 .24154 .67857 .24194 Mtetra
.2 .728 .767 r
.67857 .24194 .68391 .24154 .69616 .24019 .69083 .23949 Mtetra
.327 .809 .879 r
.69083 .23949 .69616 .24019 .70847 .2386 .70314 .23673 Mtetra
.44 .857 .956 r
.70314 .23673 .70847 .2386 .72085 .23678 .71549 .23368 Mtetra
.529 .867 .992 r
.71549 .23368 .72085 .23678 .73327 .23468 .72789 .23035 Mtetra
.585 .849 .994 r
.72789 .23035 .73327 .23468 .74576 .23237 .74034 .22679 Mtetra
.617 .817 .977 r
.74034 .22679 .74576 .23237 .7583 .22988 .75284 .22307 Mtetra
.633 .781 .952 r
.75284 .22307 .7583 .22988 .7709 .22725 .76539 .21923 Mtetra
.618 .742 .934 r
.10283 .44102 .1101 .44736 .12002 .44344 .11261 .43839 Mtetra
.612 .786 .965 r
.11261 .43839 .12002 .44344 .12999 .43941 .12243 .43569 Mtetra
.599 .832 .988 r
.12243 .43569 .12999 .43941 .14 .43522 .13231 .43286 Mtetra
.573 .873 .994 r
.13231 .43286 .14 .43522 .15008 .43082 .14226 .42984 Mtetra
.529 .895 .97 r
.14226 .42984 .15008 .43082 .16022 .42614 .15227 .42657 Mtetra
.461 .886 .904 r
.15227 .42657 .16022 .42614 .17042 .42119 .16236 .42302 Mtetra
.378 .841 .8 r
.16236 .42302 .17042 .42119 .18067 .41594 .17252 .41913 Mtetra
.288 .769 .675 r
.17252 .41913 .18067 .41594 .19099 .41041 .18275 .4149 Mtetra
0 0 0 r
.18275 .4149 .19099 .41041 .20136 .40461 .19306 .41031 Mtetra
.19306 .41031 .20136 .40461 .21178 .39854 .20343 .40537 Mtetra
.20343 .40537 .21178 .39854 .22225 .39224 .21386 .40008 Mtetra
.21386 .40008 .22225 .39224 .23276 .38571 .22436 .3945 Mtetra
.22436 .3945 .23276 .38571 .2433 .37896 .2349 .38865 Mtetra
.033 0 0 r
.2349 .38865 .2433 .37896 .25388 .37208 .24549 .38265 Mtetra
.073 0 0 r
.24549 .38265 .25388 .37208 .26449 .36511 .2561 .37659 Mtetra
.116 0 0 r
.2561 .37659 .26449 .36511 .27511 .35821 .26674 .37057 Mtetra
.159 0 0 r
.26674 .37057 .27511 .35821 .28574 .35149 .27738 .36472 Mtetra
.198 0 .037 r
.27738 .36472 .28574 .35149 .29636 .34507 .28805 .35907 Mtetra
.231 0 .072 r
.28805 .35907 .29636 .34507 .30698 .33904 .29872 .35366 Mtetra
.256 0 .098 r
.29872 .35366 .30698 .33904 .3176 .33339 .3094 .34847 Mtetra
.275 0 .116 r
.3094 .34847 .3176 .33339 .32823 .32812 .32011 .34349 Mtetra
.287 0 .128 r
.32011 .34349 .32823 .32812 .33886 .32319 .33084 .33866 Mtetra
.295 0 .134 r
.33084 .33866 .33886 .32319 .34952 .31854 .3416 .33396 Mtetra
.3 0 .136 r
.3416 .33396 .34952 .31854 .3602 .3141 .35239 .32938 Mtetra
.303 0 .136 r
.35239 .32938 .3602 .3141 .37091 .30983 .36321 .3249 Mtetra
.304 0 .133 r
.36321 .3249 .37091 .30983 .38165 .30569 .37407 .32052 Mtetra
.306 0 .13 r
.37407 .32052 .38165 .30569 .39243 .30164 .38495 .31625 Mtetra
.307 0 .127 r
.38495 .31625 .39243 .30164 .40325 .29765 .39588 .31209 Mtetra
.31 0 .126 r
.39588 .31209 .40325 .29765 .41411 .29372 .40684 .30805 Mtetra
.315 0 .126 r
.40684 .30805 .41411 .29372 .425 .28983 .41784 .30415 Mtetra
.32 0 .129 r
.41784 .30415 .425 .28983 .43595 .28598 .42889 .30038 Mtetra
.327 0 .133 r
.42889 .30038 .43595 .28598 .44693 .28218 .43997 .29673 Mtetra
.334 0 .14 r
.43997 .29673 .44693 .28218 .45796 .27845 .4511 .2932 Mtetra
.341 0 .147 r
.4511 .2932 .45796 .27845 .46904 .27481 .46228 .28977 Mtetra
.347 0 .153 r
.46228 .28977 .46904 .27481 .48015 .2713 .4735 .28645 Mtetra
.354 0 .16 r
.4735 .28645 .48015 .2713 .49132 .26796 .48477 .28323 Mtetra
.359 0 .164 r
.48477 .28323 .49132 .26796 .50254 .26483 .4961 .28013 Mtetra
.364 0 .167 r
.4961 .28013 .50254 .26483 .5138 .262 .50748 .27717 Mtetra
.368 0 .166 r
.50748 .27717 .5138 .262 .52512 .2595 .51891 .27437 Mtetra
.372 0 .162 r
.51891 .27437 .52512 .2595 .5365 .2574 .5304 .27177 Mtetra
.374 0 .154 r
.5304 .27177 .5365 .2574 .54795 .25569 .54195 .2694 Mtetra
.375 0 .142 r
.54195 .2694 .54795 .25569 .55947 .25438 .55357 .26729 Mtetra
.373 0 .124 r
.55357 .26729 .55947 .25438 .57106 .25339 .56525 .26538 Mtetra
.368 0 .101 r
.56525 .26538 .57106 .25339 .58272 .25259 .577 .26364 Mtetra
.357 0 .072 r
.577 .26364 .58272 .25259 .59446 .25186 .58882 .26197 Mtetra
.339 0 .036 r
.58882 .26197 .59446 .25186 .60628 .25106 .60071 .26023 Mtetra
.314 0 0 r
.60071 .26023 .60628 .25106 .61816 .25012 .61266 .25833 Mtetra
.279 0 0 r
.61266 .25833 .61816 .25012 .63012 .24898 .62467 .25618 Mtetra
.234 0 0 r
.62467 .25618 .63012 .24898 .64214 .2476 .63675 .25372 Mtetra
.171 0 0 r
.63675 .25372 .64214 .2476 .65423 .24598 .64887 .2509 Mtetra
.088 0 0 r
.64887 .2509 .65423 .24598 .66637 .2441 .66104 .24772 Mtetra
0 0 0 r
.66104 .24772 .66637 .2441 .67857 .24194 .67325 .24417 Mtetra
.67325 .24417 .67857 .24194 .69083 .23949 .68551 .24025 Mtetra
.33 .811 .78 r
.68551 .24025 .69083 .23949 .70314 .23673 .6978 .23599 Mtetra
.478 .894 .906 r
.6978 .23599 .70314 .23673 .71549 .23368 .71013 .23143 Mtetra
.586 .918 .97 r
.71013 .23143 .71549 .23368 .72789 .23035 .7225 .2266 Mtetra
.648 .897 .983 r
.7225 .2266 .72789 .23035 .74034 .22679 .7349 .22157 Mtetra
.677 .855 .968 r
.7349 .22157 .74034 .22679 .75284 .22307 .74734 .21639 Mtetra
.686 .808 .94 r
.74734 .21639 .75284 .22307 .76539 .21923 .75983 .21113 Mtetra
.55 .72 .952 r
.09551 .43462 .10283 .44102 .11261 .43839 .10514 .4332 Mtetra
.53 .757 .98 r
.10514 .4332 .11261 .43839 .12243 .43569 .11483 .43174 Mtetra
.501 .794 .998 r
.11483 .43174 .12243 .43569 .13231 .43286 .12458 .4302 Mtetra
.456 .821 .995 r
.12458 .4302 .13231 .43286 .14226 .42984 .13439 .42852 Mtetra
.392 .826 .955 r
.13439 .42852 .14226 .42984 .15227 .42657 .14428 .42664 Mtetra
.307 .798 .869 r
.14428 .42664 .15227 .42657 .16236 .42302 .15424 .42451 Mtetra
.214 .736 .743 r
.15424 .42451 .16236 .42302 .17252 .41913 .16429 .42207 Mtetra
0 0 0 r
.16429 .42207 .17252 .41913 .18275 .4149 .17441 .4193 Mtetra
.17441 .4193 .18275 .4149 .19306 .41031 .18462 .41616 Mtetra
.028 0 0 r
.18462 .41616 .19306 .41031 .20343 .40537 .1949 .41271 Mtetra
.088 0 0 r
.1949 .41271 .20343 .40537 .21386 .40008 .20525 .40895 Mtetra
.145 0 0 r
.20525 .40895 .21386 .40008 .22436 .3945 .21567 .40501 Mtetra
.198 0 0 r
.21567 .40501 .22436 .3945 .2349 .38865 .22613 .40094 Mtetra
.247 0 .035 r
.22613 .40094 .2349 .38865 .24549 .38265 .23663 .39685 Mtetra
.29 0 .1 r
.23663 .39685 .24549 .38265 .2561 .37659 .24716 .39282 Mtetra
.323 0 .153 r
.24716 .39282 .2561 .37659 .26674 .37057 .25773 .38883 Mtetra
.349 0 .194 r
.25773 .38883 .26674 .37057 .27738 .36472 .26833 .38489 Mtetra
.366 .011 .224 r
.26833 .38489 .27738 .36472 .28805 .35907 .27898 .38089 Mtetra
.376 .03 .245 r
.27898 .38089 .28805 .35907 .29872 .35366 .28968 .37679 Mtetra
.382 .042 .259 r
.28968 .37679 .29872 .35366 .3094 .34847 .30042 .37255 Mtetra
.384 .048 .267 r
.30042 .37255 .3094 .34847 .32011 .34349 .31122 .36813 Mtetra
.384 .051 .272 r
.31122 .36813 .32011 .34349 .33084 .33866 .32207 .36356 Mtetra
.384 .052 .274 r
.32207 .36356 .33084 .33866 .3416 .33396 .33296 .35887 Mtetra
.383 .051 .274 r
.33296 .35887 .3416 .33396 .35239 .32938 .34389 .35413 Mtetra
.383 .05 .272 r
.34389 .35413 .35239 .32938 .36321 .3249 .35486 .34938 Mtetra
.383 .05 .271 r
.35486 .34938 .36321 .3249 .37407 .32052 .36586 .34471 Mtetra
.385 .05 .269 r
.36586 .34471 .37407 .32052 .38495 .31625 .3769 .34017 Mtetra
.388 .051 .269 r
.3769 .34017 .38495 .31625 .39588 .31209 .38797 .3358 Mtetra
.392 .054 .269 r
.38797 .3358 .39588 .31209 .40684 .30805 .39907 .33166 Mtetra
.397 .058 .27 r
.39907 .33166 .40684 .30805 .41784 .30415 .4102 .32775 Mtetra
.402 .063 .272 r
.4102 .32775 .41784 .30415 .42889 .30038 .42138 .32408 Mtetra
.408 .069 .275 r
.42138 .32408 .42889 .30038 .43997 .29673 .43259 .32063 Mtetra
.413 .074 .279 r
.43259 .32063 .43997 .29673 .4511 .2932 .44385 .31736 Mtetra
.417 .079 .282 r
.44385 .31736 .4511 .2932 .46228 .28977 .45516 .31422 Mtetra
.42 .083 .285 r
.45516 .31422 .46228 .28977 .4735 .28645 .46653 .31116 Mtetra
.421 .085 .287 r
.46653 .31116 .4735 .28645 .48477 .28323 .47794 .3081 Mtetra
.421 .085 .288 r
.47794 .3081 .48477 .28323 .4961 .28013 .48941 .30499 Mtetra
.419 .083 .287 r
.48941 .30499 .4961 .28013 .50748 .27717 .50094 .30175 Mtetra
.415 .079 .284 r
.50094 .30175 .50748 .27717 .51891 .27437 .51252 .29836 Mtetra
.409 .071 .278 r
.51252 .29836 .51891 .27437 .5304 .27177 .52416 .2948 Mtetra
.402 .06 .267 r
.52416 .2948 .5304 .27177 .54195 .2694 .53585 .29109 Mtetra
.392 .044 .252 r
.53585 .29109 .54195 .2694 .55357 .26729 .54759 .28727 Mtetra
.38 .024 .23 r
.54759 .28727 .55357 .26729 .56525 .26538 .55938 .2834 Mtetra
.365 0 .201 r
.55938 .2834 .56525 .26538 .577 .26364 .57123 .27957 Mtetra
.346 0 .163 r
.57123 .27957 .577 .26364 .58882 .26197 .58313 .27579 Mtetra
.321 0 .115 r
.58313 .27579 .58882 .26197 .60071 .26023 .59508 .27206 Mtetra
.287 0 .056 r
.59508 .27206 .60071 .26023 .61266 .25833 .6071 .26831 Mtetra
.24 0 0 r
.6071 .26831 .61266 .25833 .62467 .25618 .61916 .26443 Mtetra
.178 0 0 r
.61916 .26443 .62467 .25618 .63675 .25372 .63127 .26035 Mtetra
.092 0 0 r
.63127 .26035 .63675 .25372 .64887 .2509 .64343 .25596 Mtetra
0 0 0 r
.64343 .25596 .64887 .2509 .66104 .24772 .65562 .25124 Mtetra
.65562 .25124 .66104 .24772 .67325 .24417 .66784 .24613 Mtetra
.328 .796 .692 r
.66784 .24613 .67325 .24417 .68551 .24025 .6801 .24067 Mtetra
.486 .901 .837 r
.6801 .24067 .68551 .24025 .6978 .23599 .69238 .23487 Mtetra
.607 .947 .927 r
.69238 .23487 .6978 .23599 .71013 .23143 .70469 .22881 Mtetra
.68 .942 .963 r
.70469 .22881 .71013 .23143 .7225 .2266 .71702 .22253 Mtetra
.716 .909 .962 r
.71702 .22253 .7225 .2266 .7349 .22157 .72939 .21609 Mtetra
.729 .865 .945 r
.72939 .21609 .7349 .22157 .74734 .21639 .74179 .20956 Mtetra
.729 .82 .921 r
.74179 .20956 .74734 .21639 .75983 .21113 .75422 .20298 Mtetra
.499 .7 .96 r
.08813 .42819 .09551 .43462 .10514 .4332 .09768 .42749 Mtetra
.48 .72 .976 r
.09768 .42749 .10514 .4332 .11483 .43174 .10729 .4268 Mtetra
.458 .741 .989 r
.10729 .4268 .11483 .43174 .12458 .4302 .11695 .42608 Mtetra
.43 .76 .996 r
.11695 .42608 .12458 .4302 .13439 .42852 .12667 .42531 Mtetra
.393 .775 .991 r
.12667 .42531 .13439 .42852 .14428 .42664 .13647 .42443 Mtetra
.343 .781 .965 r
.13647 .42443 .14428 .42664 .15424 .42451 .14633 .42341 Mtetra
.28 .768 .91 r
.14633 .42341 .15424 .42451 .16429 .42207 .15627 .42219 Mtetra
.199 .727 .816 r
.15627 .42219 .16429 .42207 .17441 .4193 .16628 .42075 Mtetra
0 0 0 r
.16628 .42075 .17441 .4193 .18462 .41616 .17638 .41905 Mtetra
.17638 .41905 .18462 .41616 .1949 .41271 .18656 .41711 Mtetra
.068 0 0 r
.18656 .41711 .1949 .41271 .20525 .40895 .19681 .41493 Mtetra
.14 0 0 r
.19681 .41493 .20525 .40895 .21567 .40501 .20712 .41255 Mtetra
.196 0 0 r
.20712 .41255 .21567 .40501 .22613 .40094 .21751 .41 Mtetra
.239 0 0 r
.21751 .41 .22613 .40094 .23663 .39685 .22795 .4073 Mtetra
.269 0 0 r
.22795 .4073 .23663 .39685 .24716 .39282 .23846 .40448 Mtetra
.288 0 .039 r
.23846 .40448 .24716 .39282 .25773 .38883 .24902 .40149 Mtetra
.299 0 .069 r
.24902 .40149 .25773 .38883 .26833 .38489 .25965 .39832 Mtetra
.303 0 .088 r
.25965 .39832 .26833 .38489 .27898 .38089 .27034 .39492 Mtetra
.303 0 .1 r
.27034 .39492 .27898 .38089 .28968 .37679 .28109 .39128 Mtetra
.302 0 .108 r
.28109 .39128 .28968 .37679 .30042 .37255 .29191 .38743 Mtetra
.301 0 .115 r
.29191 .38743 .30042 .37255 .31122 .36813 .30278 .38338 Mtetra
.302 0 .122 r
.30278 .38338 .31122 .36813 .32207 .36356 .3137 .37918 Mtetra
.304 0 .129 r
.3137 .37918 .32207 .36356 .33296 .35887 .32467 .37488 Mtetra
.308 0 .138 r
.32467 .37488 .33296 .35887 .34389 .35413 .33568 .37052 Mtetra
.314 0 .147 r
.33568 .37052 .34389 .35413 .35486 .34938 .34674 .36615 Mtetra
.321 0 .157 r
.34674 .36615 .35486 .34938 .36586 .34471 .35783 .36182 Mtetra
.328 0 .165 r
.35783 .36182 .36586 .34471 .3769 .34017 .36897 .35755 Mtetra
.336 0 .173 r
.36897 .35755 .3769 .34017 .38797 .3358 .38014 .35339 Mtetra
.342 0 .179 r
.38014 .35339 .38797 .3358 .39907 .33166 .39135 .34934 Mtetra
.348 0 .183 r
.39135 .34934 .39907 .33166 .4102 .32775 .4026 .34543 Mtetra
.352 0 .185 r
.4026 .34543 .4102 .32775 .42138 .32408 .4139 .34164 Mtetra
.355 0 .185 r
.4139 .34164 .42138 .32408 .43259 .32063 .42524 .33797 Mtetra
.357 0 .182 r
.42524 .33797 .43259 .32063 .44385 .31736 .43662 .3344 Mtetra
.356 0 .178 r
.43662 .3344 .44385 .31736 .45516 .31422 .44805 .3309 Mtetra
.354 0 .172 r
.44805 .3309 .45516 .31422 .46653 .31116 .45954 .32744 Mtetra
.35 0 .164 r
.45954 .32744 .46653 .31116 .47794 .3081 .47108 .32397 Mtetra
.344 0 .155 r
.47108 .32397 .47794 .3081 .48941 .30499 .48267 .32044 Mtetra
.337 0 .145 r
.48267 .32044 .48941 .30499 .50094 .30175 .49431 .31681 Mtetra
.327 0 .134 r
.49431 .31681 .50094 .30175 .51252 .29836 .50601 .31303 Mtetra
.316 0 .122 r
.50601 .31303 .51252 .29836 .52416 .2948 .51776 .30904 Mtetra
.302 0 .109 r
.51776 .30904 .52416 .2948 .53585 .29109 .52956 .30484 Mtetra
.286 0 .092 r
.52956 .30484 .53585 .29109 .54759 .28727 .54142 .30038 Mtetra
.267 0 .07 r
.54142 .30038 .54759 .28727 .55938 .2834 .55331 .2957 Mtetra
.243 0 .041 r
.55331 .2957 .55938 .2834 .57123 .27957 .56526 .29082 Mtetra
.211 0 0 r
.56526 .29082 .57123 .27957 .58313 .27579 .57724 .28576 Mtetra
.169 0 0 r
.57724 .28576 .58313 .27579 .59508 .27206 .58927 .28057 Mtetra
.107 0 0 r
.58927 .28057 .59508 .27206 .6071 .26831 .60134 .27522 Mtetra
.022 0 0 r
.60134 .27522 .6071 .26831 .61916 .26443 .61345 .26969 Mtetra
0 0 0 r
.61345 .26969 .61916 .26443 .63127 .26035 .6256 .26395 Mtetra
.6256 .26395 .63127 .26035 .64343 .25596 .63778 .25795 Mtetra
.402 .841 .717 r
.63778 .25795 .64343 .25596 .65562 .25124 .64998 .25169 Mtetra
.546 .929 .846 r
.64998 .25169 .65562 .25124 .66784 .24613 .66222 .24515 Mtetra
.647 .962 .92 r
.66222 .24515 .66784 .24613 .6801 .24067 .67448 .23836 Mtetra
.707 .956 .949 r
.67448 .23836 .6801 .24067 .69238 .23487 .68676 .23137 Mtetra
.738 .931 .953 r
.68676 .23137 .69238 .23487 .70469 .22881 .69907 .2242 Mtetra
.752 .899 .944 r
.69907 .2242 .70469 .22881 .71702 .22253 .7114 .21692 Mtetra
.755 .867 .93 r
.7114 .21692 .71702 .22253 .72939 .21609 .72376 .20956 Mtetra
.754 .838 .915 r
.72376 .20956 .72939 .21609 .74179 .20956 .73615 .20216 Mtetra
.749 .81 .901 r
.73615 .20216 .74179 .20956 .75422 .20298 .74857 .19475 Mtetra
.481 .693 .961 r
.0807 .4217 .08813 .42819 .09768 .42749 .09024 .42121 Mtetra
.472 .698 .967 r
.09024 .42121 .09768 .42749 .10729 .4268 .09982 .42076 Mtetra
.463 .704 .972 r
.09982 .42076 .10729 .4268 .11695 .42608 .10946 .42034 Mtetra
.452 .711 .978 r
.10946 .42034 .11695 .42608 .12667 .42531 .11915 .41994 Mtetra
.439 .719 .984 r
.11915 .41994 .12667 .42531 .13647 .42443 .1289 .41954 Mtetra
.422 .731 .99 r
.1289 .41954 .13647 .42443 .14633 .42341 .13871 .41912 Mtetra
.4 .743 .993 r
.13871 .41912 .14633 .42341 .15627 .42219 .14858 .41864 Mtetra
.369 .755 .988 r
.14858 .41864 .15627 .42219 .16628 .42075 .15853 .41808 Mtetra
.326 .76 .969 r
.15853 .41808 .16628 .42075 .17638 .41905 .16854 .4174 Mtetra
.266 .751 .923 r
.16854 .4174 .17638 .41905 .18656 .41711 .17863 .41656 Mtetra
.194 .72 .846 r
.17863 .41656 .18656 .41711 .19681 .41493 .18879 .41555 Mtetra
.118 .669 .743 r
.18879 .41555 .19681 .41493 .20712 .41255 .19904 .4143 Mtetra
0 0 0 r
.19904 .4143 .20712 .41255 .21751 .41 .20937 .41278 Mtetra
.20937 .41278 .21751 .41 .22795 .4073 .21978 .41094 Mtetra
.015 0 0 r
.21978 .41094 .22795 .4073 .23846 .40448 .23028 .40873 Mtetra
.019 0 0 r
.23028 .40873 .23846 .40448 .24902 .40149 .24087 .40614 Mtetra
.009 0 0 r
.24087 .40614 .24902 .40149 .25965 .39832 .25154 .40319 Mtetra
0 0 0 r
.25154 .40319 .25965 .39832 .27034 .39492 .26228 .39995 Mtetra
.26228 .39995 .27034 .39492 .28109 .39128 .27308 .39649 Mtetra
.27308 .39649 .28109 .39128 .29191 .38743 .28394 .3929 Mtetra
.002 0 0 r
.28394 .3929 .29191 .38743 .30278 .38338 .29485 .38924 Mtetra
.027 0 0 r
.29485 .38924 .30278 .38338 .3137 .37918 .3058 .38556 Mtetra
.06 0 0 r
.3058 .38556 .3137 .37918 .32467 .37488 .31681 .38187 Mtetra
.095 0 0 r
.31681 .38187 .32467 .37488 .33568 .37052 .32785 .37819 Mtetra
.128 0 0 r
.32785 .37819 .33568 .37052 .34674 .36615 .33895 .37451 Mtetra
.157 0 0 r
.33895 .37451 .34674 .36615 .35783 .36182 .35009 .3708 Mtetra
.179 0 0 r
.35009 .3708 .35783 .36182 .36897 .35755 .36128 .36706 Mtetra
.195 0 0 r
.36128 .36706 .36897 .35755 .38014 .35339 .37252 .36327 Mtetra
.204 0 0 r
.37252 .36327 .38014 .35339 .39135 .34934 .38381 .3594 Mtetra
.207 0 0 r
.38381 .3594 .39135 .34934 .4026 .34543 .39515 .35547 Mtetra
.204 0 0 r
.39515 .35547 .4026 .34543 .4139 .34164 .40654 .35147 Mtetra
.195 0 0 r
.40654 .35147 .4139 .34164 .42524 .33797 .41798 .3474 Mtetra
.18 0 0 r
.41798 .3474 .42524 .33797 .43662 .3344 .42947 .34327 Mtetra
.16 0 0 r
.42947 .34327 .43662 .3344 .44805 .3309 .44101 .33911 Mtetra
.135 0 0 r
.44101 .33911 .44805 .3309 .45954 .32744 .4526 .33492 Mtetra
.105 0 0 r
.4526 .33492 .45954 .32744 .47108 .32397 .46423 .33073 Mtetra
.072 0 0 r
.46423 .33073 .47108 .32397 .48267 .32044 .47592 .32653 Mtetra
.038 0 0 r
.47592 .32653 .48267 .32044 .49431 .31681 .48765 .32234 Mtetra
.005 0 0 r
.48765 .32234 .49431 .31681 .50601 .31303 .49943 .31812 Mtetra
0 0 0 r
.49943 .31812 .50601 .31303 .51776 .30904 .51127 .31383 Mtetra
.51127 .31383 .51776 .30904 .52956 .30484 .52315 .3094 Mtetra
.52315 .3094 .52956 .30484 .54142 .30038 .53508 .30475 Mtetra
.53508 .30475 .54142 .30038 .55331 .2957 .54706 .2998 Mtetra
.54706 .2998 .55331 .2957 .56526 .29082 .55908 .29446 Mtetra
.55908 .29446 .56526 .29082 .57724 .28576 .57114 .28873 Mtetra
.329 .785 .643 r
.57114 .28873 .57724 .28576 .58927 .28057 .58323 .28262 Mtetra
.434 .861 .735 r
.58323 .28262 .58927 .28057 .60134 .27522 .59535 .27616 Mtetra
.541 .925 .826 r
.59535 .27616 .60134 .27522 .61345 .26969 .6075 .26942 Mtetra
.633 .962 .896 r
.6075 .26942 .61345 .26969 .6256 .26395 .61968 .26242 Mtetra
.699 .967 .935 r
.61968 .26242 .6256 .26395 .63778 .25795 .63188 .25522 Mtetra
.737 .949 .948 r
.63188 .25522 .63778 .25795 .64998 .25169 .64411 .24785 Mtetra
.756 .921 .945 r
.64411 .24785 .64998 .25169 .66222 .24515 .65636 .24034 Mtetra
.764 .892 .935 r
.65636 .24034 .66222 .24515 .67448 .23836 .66864 .23273 Mtetra
.765 .866 .923 r
.66864 .23273 .67448 .23836 .68676 .23137 .68094 .22505 Mtetra
.764 .845 .913 r
.68094 .22505 .68676 .23137 .69907 .2242 .69327 .21732 Mtetra
.761 .828 .904 r
.69327 .21732 .69907 .2242 .7114 .21692 .70562 .20959 Mtetra
.758 .814 .897 r
.70562 .20959 .7114 .21692 .72376 .20956 .71801 .20186 Mtetra
.755 .804 .892 r
.71801 .20186 .72376 .20956 .73615 .20216 .73043 .19415 Mtetra
.752 .795 .887 r
.73043 .19415 .73615 .20216 .74857 .19475 .74288 .18646 Mtetra
.514 .706 .958 r
.07322 .41517 .0807 .4217 .09024 .42121 .08282 .41422 Mtetra
.517 .692 .948 r
.08282 .41422 .09024 .42121 .09982 .42076 .09248 .41332 Mtetra
.519 .679 .938 r
.09248 .41332 .09982 .42076 .10946 .42034 .10218 .41248 Mtetra
.52 .666 .928 r
.10218 .41248 .10946 .42034 .11915 .41994 .11193 .41169 Mtetra
.52 .655 .92 r
.11193 .41169 .11915 .41994 .1289 .41954 .12172 .41097 Mtetra
.521 .647 .913 r
.12172 .41097 .1289 .41954 .13871 .41912 .13157 .41028 Mtetra
.522 .64 .907 r
.13157 .41028 .13871 .41912 .14858 .41864 .14147 .4096 Mtetra
.526 .637 .903 r
.14147 .4096 .14858 .41864 .15853 .41808 .15144 .40888 Mtetra
.53 .635 .899 r
.15144 .40888 .15853 .41808 .16854 .4174 .16147 .40809 Mtetra
.536 .636 .896 r
.16147 .40809 .16854 .4174 .17863 .41656 .17157 .40719 Mtetra
.544 .638 .894 r
.17157 .40719 .17863 .41656 .18879 .41555 .18175 .40612 Mtetra
.554 .642 .892 r
.18175 .40612 .18879 .41555 .19904 .4143 .19201 .40485 Mtetra
.564 .646 .89 r
.19201 .40485 .19904 .4143 .20937 .41278 .20234 .40334 Mtetra
.575 .652 .888 r
.20234 .40334 .20937 .41278 .21978 .41094 .21276 .40157 Mtetra
.585 .659 .888 r
.21276 .40157 .21978 .41094 .23028 .40873 .22326 .39954 Mtetra
.594 .668 .891 r
.22326 .39954 .23028 .40873 .24087 .40614 .23383 .39729 Mtetra
.601 .68 .897 r
.23383 .39729 .24087 .40614 .25154 .40319 .24446 .39484 Mtetra
.604 .697 .909 r
.24446 .39484 .25154 .40319 .26228 .39995 .25517 .39229 Mtetra
.604 .718 .925 r
.25517 .39229 .26228 .39995 .27308 .39649 .26592 .38967 Mtetra
.601 .744 .945 r
.26592 .38967 .27308 .39649 .28394 .3929 .27673 .38701 Mtetra
.593 .774 .966 r
.27673 .38701 .28394 .3929 .29485 .38924 .2876 .38434 Mtetra
.58 .805 .985 r
.2876 .38434 .29485 .38924 .3058 .38556 .29852 .38163 Mtetra
.56 .834 .997 r
.29852 .38163 .3058 .38556 .31681 .38187 .30949 .37886 Mtetra
.536 .856 .997 r
.30949 .37886 .31681 .38187 .32785 .37819 .32053 .376 Mtetra
.508 .869 .986 r
.32053 .376 .32785 .37819 .33895 .37451 .33162 .37301 Mtetra
.481 .874 .966 r
.33162 .37301 .33895 .37451 .35009 .3708 .34277 .36987 Mtetra
.46 .875 .943 r
.34277 .36987 .35009 .3708 .36128 .36706 .35399 .36655 Mtetra
.448 .874 .923 r
.35399 .36655 .36128 .36706 .37252 .36327 .36527 .36302 Mtetra
.446 .877 .909 r
.36527 .36302 .37252 .36327 .38381 .3594 .37661 .35929 Mtetra
.455 .882 .904 r
.37661 .35929 .38381 .3594 .39515 .35547 .388 .35533 Mtetra
.475 .892 .908 r
.388 .35533 .39515 .35547 .40654 .35147 .39946 .35115 Mtetra
.503 .904 .92 r
.39946 .35115 .40654 .35147 .41798 .3474 .41096 .34676 Mtetra
.537 .916 .936 r
.41096 .34676 .41798 .3474 .42947 .34327 .42252 .34216 Mtetra
.575 .925 .954 r
.42252 .34216 .42947 .34327 .44101 .33911 .43413 .33737 Mtetra
.612 .926 .97 r
.43413 .33737 .44101 .33911 .4526 .33492 .44579 .33243 Mtetra
.645 .918 .978 r
.44579 .33243 .4526 .33492 .46423 .33073 .4575 .32736 Mtetra
.669 .899 .978 r
.4575 .32736 .46423 .33073 .47592 .32653 .46924 .32218 Mtetra
.685 .872 .969 r
.46924 .32218 .47592 .32653 .48765 .32234 .48104 .31695 Mtetra
.693 .839 .953 r
.48104 .31695 .48765 .32234 .49943 .31812 .49287 .31167 Mtetra
.695 .805 .934 r
.49287 .31167 .49943 .31812 .51127 .31383 .50475 .30636 Mtetra
.694 .774 .913 r
.50475 .30636 .51127 .31383 .52315 .3094 .51667 .30101 Mtetra
.692 .748 .895 r
.51667 .30101 .52315 .3094 .53508 .30475 .52863 .2956 Mtetra
.691 .729 .879 r
.52863 .2956 .53508 .30475 .54706 .2998 .54063 .29006 Mtetra
.693 .716 .866 r
.54063 .29006 .54706 .2998 .55908 .29446 .55268 .28432 Mtetra
.696 .708 .857 r
.55268 .28432 .55908 .29446 .57114 .28873 .56476 .27834 Mtetra
.701 .706 .851 r
.56476 .27834 .57114 .28873 .58323 .28262 .57688 .27208 Mtetra
.706 .705 .846 r
.57688 .27208 .58323 .28262 .59535 .27616 .58903 .26555 Mtetra
.712 .706 .843 r
.58903 .26555 .59535 .27616 .6075 .26942 .60121 .25876 Mtetra
.716 .708 .841 r
.60121 .25876 .6075 .26942 .61968 .26242 .61342 .25175 Mtetra
.72 .71 .84 r
.61342 .25175 .61968 .26242 .63188 .25522 .62566 .24455 Mtetra
.723 .712 .839 r
.62566 .24455 .63188 .25522 .64411 .24785 .63792 .23723 Mtetra
.725 .714 .84 r
.63792 .23723 .64411 .24785 .65636 .24034 .65021 .22981 Mtetra
.727 .718 .842 r
.65021 .22981 .65636 .24034 .66864 .23273 .66253 .22235 Mtetra
.728 .722 .845 r
.66253 .22235 .66864 .23273 .68094 .22505 .67488 .21488 Mtetra
.729 .729 .85 r
.67488 .21488 .68094 .22505 .69327 .21732 .68726 .20743 Mtetra
.73 .736 .856 r
.68726 .20743 .69327 .21732 .70562 .20959 .69967 .20003 Mtetra
.732 .746 .863 r
.69967 .20003 .70562 .20959 .71801 .20186 .71212 .19268 Mtetra
.733 .757 .871 r
.71212 .19268 .71801 .20186 .73043 .19415 .72461 .18537 Mtetra
.735 .769 .88 r
.72461 .18537 .73043 .19415 .74288 .18646 .73713 .1781 Mtetra
.574 .728 .947 r
.06568 .40859 .07322 .41517 .08282 .41422 .07543 .40668 Mtetra
.577 .698 .925 r
.07543 .40668 .08282 .41422 .09248 .41332 .08522 .40482 Mtetra
.578 .671 .903 r
.08522 .40482 .09248 .41332 .10218 .41248 .09506 .40303 Mtetra
.576 .646 .882 r
.09506 .40303 .10218 .41248 .11193 .41169 .10493 .40131 Mtetra
.573 .622 .863 r
.10493 .40131 .11193 .41169 .12172 .41097 .11484 .39968 Mtetra
.571 .602 .845 r
.11484 .39968 .12172 .41097 .13157 .41028 .1248 .39811 Mtetra
.57 .585 .829 r
.1248 .39811 .13157 .41028 .14147 .4096 .1348 .39659 Mtetra
.569 .57 .814 r
.1348 .39659 .14147 .4096 .15144 .40888 .14485 .39505 Mtetra
.57 .558 .801 r
.14485 .39505 .15144 .40888 .16147 .40809 .15497 .39346 Mtetra
.572 .547 .789 r
.15497 .39346 .16147 .40809 .17157 .40719 .16515 .39179 Mtetra
.574 .539 .777 r
.16515 .39179 .17157 .40719 .18175 .40612 .17539 .38998 Mtetra
.576 .531 .768 r
.17539 .38998 .18175 .40612 .19201 .40485 .1857 .38805 Mtetra
.578 .525 .759 r
.1857 .38805 .19201 .40485 .20234 .40334 .19608 .38597 Mtetra
.579 .52 .753 r
.19608 .38597 .20234 .40334 .21276 .40157 .20652 .38381 Mtetra
.579 .516 .748 r
.20652 .38381 .21276 .40157 .22326 .39954 .21702 .3816 Mtetra
.578 .514 .747 r
.21702 .3816 .22326 .39954 .23383 .39729 .22757 .37941 Mtetra
.576 .514 .749 r
.22757 .37941 .23383 .39729 .24446 .39484 .23816 .3773 Mtetra
.575 .517 .753 r
.23816 .3773 .24446 .39484 .25517 .39229 .2488 .37527 Mtetra
.573 .523 .761 r
.2488 .37527 .25517 .39229 .26592 .38967 .25949 .37334 Mtetra
.574 .531 .77 r
.25949 .37334 .26592 .38967 .27673 .38701 .27023 .37142 Mtetra
.575 .542 .781 r
.27023 .37142 .27673 .38701 .2876 .38434 .28104 .36948 Mtetra
.579 .555 .791 r
.28104 .36948 .2876 .38434 .29852 .38163 .2919 .36745 Mtetra
.584 .568 .802 r
.2919 .36745 .29852 .38163 .30949 .37886 .30284 .36525 Mtetra
.591 .581 .811 r
.30284 .36525 .30949 .37886 .32053 .376 .31384 .36285 Mtetra
.599 .593 .818 r
.31384 .36285 .32053 .376 .33162 .37301 .32492 .36021 Mtetra
.607 .604 .823 r
.32492 .36021 .33162 .37301 .34277 .36987 .33607 .35732 Mtetra
.615 .613 .826 r
.33607 .35732 .34277 .36987 .35399 .36655 .34728 .35415 Mtetra
.623 .62 .827 r
.34728 .35415 .35399 .36655 .36527 .36302 .35856 .35071 Mtetra
.63 .626 .827 r
.35856 .35071 .36527 .36302 .37661 .35929 .36991 .34699 Mtetra
.637 .63 .826 r
.36991 .34699 .37661 .35929 .388 .35533 .38132 .343 Mtetra
.644 .633 .824 r
.38132 .343 .388 .35533 .39946 .35115 .39279 .33873 Mtetra
.65 .635 .821 r
.39279 .33873 .39946 .35115 .41096 .34676 .40431 .33418 Mtetra
.656 .635 .818 r
.40431 .33418 .41096 .34676 .42252 .34216 .41589 .32935 Mtetra
.661 .634 .813 r
.41589 .32935 .42252 .34216 .43413 .33737 .42753 .32425 Mtetra
.665 .632 .806 r
.42753 .32425 .43413 .33737 .44579 .33243 .43921 .31888 Mtetra
.668 .627 .799 r
.43921 .31888 .44579 .33243 .4575 .32736 .45094 .31327 Mtetra
.669 .62 .791 r
.45094 .31327 .4575 .32736 .46924 .32218 .46271 .30744 Mtetra
.668 .61 .782 r
.46271 .30744 .46924 .32218 .48104 .31695 .47452 .30145 Mtetra
.665 .6 .772 r
.47452 .30145 .48104 .31695 .49287 .31167 .48637 .29535 Mtetra
.661 .588 .763 r
.48637 .29535 .49287 .31167 .50475 .30636 .49826 .28921 Mtetra
.656 .576 .754 r
.49826 .28921 .50475 .30636 .51667 .30101 .51018 .28308 Mtetra
.65 .566 .746 r
.51018 .28308 .51667 .30101 .52863 .2956 .52214 .27704 Mtetra
.646 .557 .741 r
.52214 .27704 .52863 .2956 .54063 .29006 .53414 .27108 Mtetra
.642 .552 .737 r
.53414 .27108 .54063 .29006 .55268 .28432 .54618 .26519 Mtetra
.641 .55 .736 r
.54618 .26519 .55268 .28432 .56476 .27834 .55826 .25932 Mtetra
.642 .552 .738 r
.55826 .25932 .56476 .27834 .57688 .27208 .57038 .25339 Mtetra
.645 .557 .741 r
.57038 .25339 .57688 .27208 .58903 .26555 .58253 .24736 Mtetra
.65 .565 .746 r
.58253 .24736 .58903 .26555 .60121 .25876 .59473 .24117 Mtetra
.656 .575 .752 r
.59473 .24117 .60121 .25876 .61342 .25175 .60696 .23484 Mtetra
.662 .586 .759 r
.60696 .23484 .61342 .25175 .62566 .24455 .61922 .22837 Mtetra
.668 .598 .768 r
.61922 .22837 .62566 .24455 .63792 .23723 .63152 .22179 Mtetra
.674 .611 .777 r
.63152 .22179 .63792 .23723 .65021 .22981 .64386 .21516 Mtetra
.679 .624 .787 r
.64386 .21516 .65021 .22981 .66253 .22235 .65623 .2085 Mtetra
.683 .639 .799 r
.65623 .2085 .66253 .22235 .67488 .21488 .66864 .20187 Mtetra
.688 .656 .813 r
.66864 .20187 .67488 .21488 .68726 .20743 .68109 .19529 Mtetra
.692 .674 .828 r
.68109 .19529 .68726 .20743 .69967 .20003 .69358 .1888 Mtetra
.697 .695 .844 r
.69358 .1888 .69967 .20003 .71212 .19268 .70612 .18237 Mtetra
.701 .719 .862 r
.70612 .18237 .71212 .19268 .72461 .18537 .71871 .176 Mtetra
.706 .745 .882 r
.71871 .176 .72461 .18537 .73713 .1781 .73134 .16968 Mtetra
.642 .748 .926 r
.05808 .40196 .06568 .40859 .07543 .40668 .06805 .39867 Mtetra
.639 .707 .896 r
.06805 .39867 .07543 .40668 .08522 .40482 .07804 .39543 Mtetra
.633 .669 .867 r
.07804 .39543 .08522 .40482 .09506 .40303 .08807 .39225 Mtetra
.625 .636 .841 r
.08807 .39225 .09506 .40303 .10493 .40131 .09812 .38916 Mtetra
.617 .607 .818 r
.09812 .38916 .10493 .40131 .11484 .39968 .10821 .38618 Mtetra
.609 .581 .797 r
.10821 .38618 .11484 .39968 .1248 .39811 .11832 .3833 Mtetra
.602 .559 .779 r
.11832 .3833 .1248 .39811 .1348 .39659 .12847 .3805 Mtetra
.596 .541 .763 r
.12847 .3805 .1348 .39659 .14485 .39505 .13866 .37777 Mtetra
.592 .526 .749 r
.13866 .37777 .14485 .39505 .15497 .39346 .14889 .37508 Mtetra
.588 .513 .738 r
.14889 .37508 .15497 .39346 .16515 .39179 .15916 .37241 Mtetra
.585 .503 .728 r
.15916 .37241 .16515 .39179 .17539 .38998 .16948 .36974 Mtetra
.583 .495 .72 r
.16948 .36974 .17539 .38998 .1857 .38805 .17984 .36708 Mtetra
.581 .488 .714 r
.17984 .36708 .1857 .38805 .19608 .38597 .19026 .36441 Mtetra
.579 .483 .71 r
.19026 .36441 .19608 .38597 .20652 .38381 .20072 .36177 Mtetra
.577 .479 .706 r
.20072 .36177 .20652 .38381 .21702 .3816 .21122 .35916 Mtetra
.575 .475 .703 r
.21122 .35916 .21702 .3816 .22757 .37941 .22177 .3566 Mtetra
.574 .472 .701 r
.22177 .3566 .22757 .37941 .23816 .3773 .23237 .35408 Mtetra
.573 .469 .698 r
.23237 .35408 .23816 .3773 .2488 .37527 .24303 .35155 Mtetra
.573 .466 .695 r
.24303 .35155 .2488 .37527 .25949 .37334 .25373 .34899 Mtetra
.573 .463 .691 r
.25373 .34899 .25949 .37334 .27023 .37142 .2645 .34633 Mtetra
.573 .46 .686 r
.2645 .34633 .27023 .37142 .28104 .36948 .27533 .34355 Mtetra
.574 .456 .681 r
.27533 .34355 .28104 .36948 .2919 .36745 .28622 .34062 Mtetra
.575 .452 .676 r
.28622 .34062 .2919 .36745 .30284 .36525 .29717 .33753 Mtetra
.576 .449 .671 r
.29717 .33753 .30284 .36525 .31384 .36285 .30819 .33427 Mtetra
.576 .446 .666 r
.30819 .33427 .31384 .36285 .32492 .36021 .31927 .33085 Mtetra
.577 .443 .662 r
.31927 .33085 .32492 .36021 .33607 .35732 .3304 .32728 Mtetra
.577 .441 .659 r
.3304 .32728 .33607 .35732 .34728 .35415 .3416 .32357 Mtetra
.578 .44 .657 r
.3416 .32357 .34728 .35415 .35856 .35071 .35285 .31974 Mtetra
.578 .439 .655 r
.35285 .31974 .35856 .35071 .36991 .34699 .36415 .3158 Mtetra
.579 .439 .654 r
.36415 .3158 .36991 .34699 .38132 .343 .3755 .31176 Mtetra
.58 .44 .654 r
.3755 .31176 .38132 .343 .39279 .33873 .38691 .30761 Mtetra
.582 .441 .655 r
.38691 .30761 .39279 .33873 .40431 .33418 .39837 .30334 Mtetra
.584 .444 .657 r
.39837 .30334 .40431 .33418 .41589 .32935 .40988 .29896 Mtetra
.586 .447 .659 r
.40988 .29896 .41589 .32935 .42753 .32425 .42144 .29443 Mtetra
.589 .452 .662 r
.42144 .29443 .42753 .32425 .43921 .31888 .43306 .28975 Mtetra
.593 .457 .665 r
.43306 .28975 .43921 .31888 .45094 .31327 .44472 .28491 Mtetra
.597 .463 .669 r
.44472 .28491 .45094 .31327 .46271 .30744 .45643 .27989 Mtetra
.601 .47 .674 r
.45643 .27989 .46271 .30744 .47452 .30145 .46819 .27471 Mtetra
.605 .476 .678 r
.46819 .27471 .47452 .30145 .48637 .29535 .47999 .26936 Mtetra
.609 .483 .683 r
.47999 .26936 .48637 .29535 .49826 .28921 .49184 .26389 Mtetra
.613 .489 .687 r
.49184 .26389 .49826 .28921 .51018 .28308 .50373 .25831 Mtetra
.615 .493 .691 r
.50373 .25831 .51018 .28308 .52214 .27704 .51566 .25269 Mtetra
.616 .497 .694 r
.51566 .25269 .52214 .27704 .53414 .27108 .52763 .24706 Mtetra
.617 .499 .697 r
.52763 .24706 .53414 .27108 .54618 .26519 .53965 .24147 Mtetra
.617 .501 .699 r
.53965 .24147 .54618 .26519 .55826 .25932 .55171 .23591 Mtetra
.617 .504 .702 r
.55171 .23591 .55826 .25932 .57038 .25339 .56381 .23038 Mtetra
.618 .507 .705 r
.56381 .23038 .57038 .25339 .58253 .24736 .57595 .22486 Mtetra
.62 .512 .709 r
.57595 .22486 .58253 .24736 .59473 .24117 .58814 .21935 Mtetra
.623 .519 .715 r
.58814 .21935 .59473 .24117 .60696 .23484 .60038 .21383 Mtetra
.626 .527 .722 r
.60038 .21383 .60696 .23484 .61922 .22837 .61266 .2083 Mtetra
.629 .537 .731 r
.61266 .2083 .61922 .22837 .63152 .22179 .62499 .20278 Mtetra
.633 .549 .742 r
.62499 .20278 .63152 .22179 .64386 .21516 .63736 .1973 Mtetra
.637 .563 .755 r
.63736 .1973 .64386 .21516 .65623 .2085 .64979 .19188 Mtetra
.641 .58 .77 r
.64979 .19188 .65623 .2085 .66864 .20187 .66227 .18655 Mtetra
.645 .6 .788 r
.66227 .18655 .66864 .20187 .68109 .19529 .6748 .1813 Mtetra
.65 .622 .809 r
.6748 .1813 .68109 .19529 .69358 .1888 .68739 .17617 Mtetra
.654 .649 .832 r
.68739 .17617 .69358 .1888 .70612 .18237 .70003 .17112 Mtetra
.659 .68 .859 r
.70003 .17112 .70612 .18237 .71871 .176 .71274 .16612 Mtetra
.663 .716 .887 r
.71274 .16612 .71871 .176 .73134 .16968 .7255 .16118 Mtetra
.697 .76 .9 r
.05043 .39529 .05808 .40196 .06805 .39867 .06063 .3905 Mtetra
.688 .718 .872 r
.06063 .3905 .06805 .39867 .07804 .39543 .07085 .38576 Mtetra
.677 .679 .845 r
.07085 .38576 .07804 .39543 .08807 .39225 .08109 .38109 Mtetra
.665 .645 .821 r
.08109 .38109 .08807 .39225 .09812 .38916 .09135 .37651 Mtetra
.653 .615 .799 r
.09135 .37651 .09812 .38916 .10821 .38618 .10163 .37204 Mtetra
.642 .589 .779 r
.10163 .37204 .10821 .38618 .11832 .3833 .11193 .36771 Mtetra
.632 .566 .762 r
.11193 .36771 .11832 .3833 .12847 .3805 .12225 .36351 Mtetra
.622 .546 .747 r
.12225 .36351 .12847 .3805 .13866 .37777 .13258 .35944 Mtetra
.614 .528 .734 r
.13258 .35944 .13866 .37777 .14889 .37508 .14294 .3555 Mtetra
.607 .514 .723 r
.14294 .3555 .14889 .37508 .15916 .37241 .15333 .35169 Mtetra
.601 .501 .713 r
.15333 .35169 .15916 .37241 .16948 .36974 .16374 .348 Mtetra
.595 .491 .705 r
.16374 .348 .16948 .36974 .17984 .36708 .17417 .34444 Mtetra
.591 .482 .699 r
.17417 .34444 .17984 .36708 .19026 .36441 .18464 .34099 Mtetra
.587 .475 .694 r
.18464 .34099 .19026 .36441 .20072 .36177 .19514 .33762 Mtetra
.584 .47 .689 r
.19514 .33762 .20072 .36177 .21122 .35916 .20568 .33431 Mtetra
.582 .465 .685 r
.20568 .33431 .21122 .35916 .22177 .3566 .21627 .331 Mtetra
.582 .461 .68 r
.21627 .331 .22177 .3566 .23237 .35408 .22691 .32762 Mtetra
.582 .457 .675 r
.22691 .32762 .23237 .35408 .24303 .35155 .23761 .3241 Mtetra
.582 .453 .669 r
.23761 .3241 .24303 .35155 .25373 .34899 .24837 .3204 Mtetra
.582 .448 .663 r
.24837 .3204 .25373 .34899 .2645 .34633 .25919 .31651 Mtetra
.582 .443 .657 r
.25919 .31651 .2645 .34633 .27533 .34355 .27007 .31244 Mtetra
.581 .438 .652 r
.27007 .31244 .27533 .34355 .28622 .34062 .281 .30823 Mtetra
.58 .433 .646 r
.281 .30823 .28622 .34062 .29717 .33753 .29199 .30391 Mtetra
.578 .428 .641 r
.29199 .30391 .29717 .33753 .30819 .33427 .30302 .29953 Mtetra
.577 .424 .637 r
.30302 .29953 .30819 .33427 .31927 .33085 .31409 .29513 Mtetra
.575 .42 .634 r
.31409 .29513 .31927 .33085 .3304 .32728 .32521 .29075 Mtetra
.573 .417 .631 r
.32521 .29075 .3304 .32728 .3416 .32357 .33636 .28641 Mtetra
.571 .414 .629 r
.33636 .28641 .3416 .32357 .35285 .31974 .34756 .28214 Mtetra
.569 .412 .628 r
.34756 .28214 .35285 .31974 .36415 .3158 .3588 .27795 Mtetra
.568 .41 .627 r
.3588 .27795 .36415 .3158 .3755 .31176 .37007 .27384 Mtetra
.567 .409 .627 r
.37007 .27384 .3755 .31176 .38691 .30761 .38139 .26983 Mtetra
.566 .409 .628 r
.38139 .26983 .38691 .30761 .39837 .30334 .39276 .2659 Mtetra
.565 .41 .629 r
.39276 .2659 .39837 .30334 .40988 .29896 .40417 .26204 Mtetra
.566 .412 .631 r
.40417 .26204 .40988 .29896 .42144 .29443 .41563 .25822 Mtetra
.566 .414 .634 r
.41563 .25822 .42144 .29443 .43306 .28975 .42714 .25442 Mtetra
.568 .418 .637 r
.42714 .25442 .43306 .28975 .44472 .28491 .43871 .2506 Mtetra
.57 .422 .642 r
.43871 .2506 .44472 .28491 .45643 .27989 .45032 .24671 Mtetra
.573 .428 .646 r
.45032 .24671 .45643 .27989 .46819 .27471 .462 .24272 Mtetra
.577 .435 .652 r
.462 .24272 .46819 .27471 .47999 .26936 .47372 .23859 Mtetra
.581 .443 .657 r
.47372 .23859 .47999 .26936 .49184 .26389 .4855 .23426 Mtetra
.586 .45 .663 r
.4855 .23426 .49184 .26389 .50373 .25831 .49733 .22975 Mtetra
.591 .458 .669 r
.49733 .22975 .50373 .25831 .51566 .25269 .50922 .22504 Mtetra
.595 .465 .674 r
.50922 .22504 .51566 .25269 .52763 .24706 .52115 .22019 Mtetra
.598 .471 .679 r
.52115 .22019 .52763 .24706 .53965 .24147 .53313 .21527 Mtetra
.599 .476 .683 r
.53313 .21527 .53965 .24147 .55171 .23591 .54516 .21034 Mtetra
.6 .48 .688 r
.54516 .21034 .55171 .23591 .56381 .23038 .55723 .20546 Mtetra
.601 .484 .692 r
.55723 .20546 .56381 .23038 .57595 .22486 .56936 .20067 Mtetra
.601 .489 .698 r
.56936 .20067 .57595 .22486 .58814 .21935 .58154 .19599 Mtetra
.601 .495 .705 r
.58154 .19599 .58814 .21935 .60038 .21383 .59377 .19142 Mtetra
.602 .502 .713 r
.59377 .19142 .60038 .21383 .61266 .2083 .60606 .18699 Mtetra
.603 .511 .723 r
.60606 .18699 .61266 .2083 .62499 .20278 .61841 .18268 Mtetra
.605 .523 .735 r
.61841 .18268 .62499 .20278 .63736 .1973 .63083 .1785 Mtetra
.606 .536 .75 r
.63083 .1785 .63736 .1973 .64979 .19188 .6433 .17446 Mtetra
.608 .553 .767 r
.6433 .17446 .64979 .19188 .66227 .18655 .65585 .17055 Mtetra
.61 .572 .787 r
.65585 .17055 .66227 .18655 .6748 .1813 .66846 .16677 Mtetra
.611 .595 .81 r
.66846 .16677 .6748 .1813 .68739 .17617 .68114 .16312 Mtetra
.613 .622 .836 r
.68114 .16312 .68739 .17617 .70003 .17112 .69389 .15956 Mtetra
.614 .653 .865 r
.69389 .15956 .70003 .17112 .71274 .16612 .70672 .15606 Mtetra
.614 .69 .897 r
.70672 .15606 .71274 .16612 .7255 .16118 .71961 .15261 Mtetra
.733 .766 .879 r
.04273 .38856 .05043 .39529 .06063 .3905 .05313 .3825 Mtetra
.723 .731 .857 r
.05313 .3825 .06063 .3905 .07085 .38576 .06355 .37648 Mtetra
.711 .699 .837 r
.06355 .37648 .07085 .38576 .08109 .38109 .07399 .37054 Mtetra
.699 .67 .819 r
.07399 .37054 .08109 .38109 .09135 .37651 .08443 .36468 Mtetra
.687 .644 .801 r
.08443 .36468 .09135 .37651 .10163 .37204 .09489 .35896 Mtetra
.675 .62 .785 r
.09489 .35896 .10163 .37204 .11193 .36771 .10536 .35336 Mtetra
.664 .598 .771 r
.10536 .35336 .11193 .36771 .12225 .36351 .11583 .34791 Mtetra
.654 .578 .757 r
.11583 .34791 .12225 .36351 .13258 .35944 .12632 .3426 Mtetra
.644 .56 .745 r
.12632 .3426 .13258 .35944 .14294 .3555 .13682 .33742 Mtetra
.636 .544 .733 r
.13682 .33742 .14294 .3555 .15333 .35169 .14734 .33236 Mtetra
.628 .529 .722 r
.14734 .33236 .15333 .35169 .16374 .348 .15788 .32742 Mtetra
.621 .515 .712 r
.15788 .32742 .16374 .348 .17417 .34444 .16844 .32258 Mtetra
.615 .502 .702 r
.16844 .32258 .17417 .34444 .18464 .34099 .17902 .31782 Mtetra
.609 .491 .693 r
.17902 .31782 .18464 .34099 .19514 .33762 .18964 .31311 Mtetra
.604 .48 .684 r
.18964 .31311 .19514 .33762 .20568 .33431 .20028 .30845 Mtetra
.6 .471 .676 r
.20028 .30845 .20568 .33431 .21627 .331 .21096 .30381 Mtetra
.596 .462 .669 r
.21096 .30381 .21627 .331 .22691 .32762 .22168 .29915 Mtetra
.593 .455 .662 r
.22168 .29915 .22691 .32762 .23761 .3241 .23244 .29447 Mtetra
.59 .448 .657 r
.23244 .29447 .23761 .3241 .24837 .3204 .24324 .28978 Mtetra
.588 .443 .652 r
.24324 .28978 .24837 .3204 .25919 .31651 .25407 .2851 Mtetra
.586 .439 .649 r
.25407 .2851 .25919 .31651 .27007 .31244 .26495 .28043 Mtetra
.584 .436 .646 r
.26495 .28043 .27007 .31244 .281 .30823 .27586 .27579 Mtetra
.582 .434 .645 r
.27586 .27579 .281 .30823 .29199 .30391 .2868 .2712 Mtetra
.581 .432 .644 r
.2868 .2712 .29199 .30391 .30302 .29953 .29778 .26667 Mtetra
.58 .431 .643 r
.29778 .26667 .30302 .29953 .31409 .29513 .3088 .2622 Mtetra
.579 .43 .643 r
.3088 .2622 .31409 .29513 .32521 .29075 .31985 .2578 Mtetra
.578 .429 .644 r
.31985 .2578 .32521 .29075 .33636 .28641 .33095 .25346 Mtetra
.577 .429 .644 r
.33095 .25346 .33636 .28641 .34756 .28214 .34208 .24919 Mtetra
.576 .428 .644 r
.34208 .24919 .34756 .28214 .3588 .27795 .35326 .24497 Mtetra
.575 .428 .644 r
.35326 .24497 .3588 .27795 .37007 .27384 .36447 .24082 Mtetra
.574 .427 .644 r
.36447 .24082 .37007 .27384 .38139 .26983 .37573 .23673 Mtetra
.573 .426 .644 r
.37573 .23673 .38139 .26983 .39276 .2659 .38704 .2327 Mtetra
.572 .426 .644 r
.38704 .2327 .39276 .2659 .40417 .26204 .39839 .22873 Mtetra
.571 .425 .644 r
.39839 .22873 .40417 .26204 .41563 .25822 .40979 .22483 Mtetra
.57 .424 .644 r
.40979 .22483 .41563 .25822 .42714 .25442 .42124 .22099 Mtetra
.569 .423 .644 r
.42124 .22099 .42714 .25442 .43871 .2506 .43273 .21722 Mtetra
.568 .423 .644 r
.43273 .21722 .43871 .2506 .45032 .24671 .44428 .2135 Mtetra
.568 .424 .645 r
.44428 .2135 .45032 .24671 .462 .24272 .45588 .20983 Mtetra
.568 .425 .647 r
.45588 .20983 .462 .24272 .47372 .23859 .46753 .2062 Mtetra
.568 .427 .649 r
.46753 .2062 .47372 .23859 .4855 .23426 .47924 .20259 Mtetra
.569 .431 .653 r
.47924 .20259 .4855 .23426 .49733 .22975 .491 .19898 Mtetra
.571 .435 .657 r
.491 .19898 .49733 .22975 .50922 .22504 .50282 .19535 Mtetra
.573 .441 .663 r
.50282 .19535 .50922 .22504 .52115 .22019 .5147 .19171 Mtetra
.575 .448 .67 r
.5147 .19171 .52115 .22019 .53313 .21527 .52663 .18806 Mtetra
.577 .456 .678 r
.52663 .18806 .53313 .21527 .54516 .21034 .53862 .18441 Mtetra
.579 .464 .687 r
.53862 .18441 .54516 .21034 .55723 .20546 .55068 .18081 Mtetra
.581 .473 .696 r
.55068 .18081 .55723 .20546 .56936 .20067 .56279 .17727 Mtetra
.582 .482 .706 r
.56279 .17727 .56936 .20067 .58154 .19599 .57496 .17382 Mtetra
.583 .492 .717 r
.57496 .17382 .58154 .19599 .59377 .19142 .5872 .17046 Mtetra
.584 .502 .729 r
.5872 .17046 .59377 .19142 .60606 .18699 .59951 .16723 Mtetra
.584 .514 .741 r
.59951 .16723 .60606 .18699 .61841 .18268 .61188 .16412 Mtetra
.584 .526 .756 r
.61188 .16412 .61841 .18268 .63083 .1785 .62433 .16115 Mtetra
.584 .54 .771 r
.62433 .16115 .63083 .1785 .6433 .17446 .63685 .15832 Mtetra
.583 .555 .789 r
.63685 .15832 .6433 .17446 .65585 .17055 .64945 .15564 Mtetra
.581 .573 .809 r
.64945 .15564 .65585 .17055 .66846 .16677 .66213 .1531 Mtetra
.579 .593 .831 r
.66213 .1531 .66846 .16677 .68114 .16312 .67489 .15069 Mtetra
.576 .616 .855 r
.67489 .15069 .68114 .16312 .69389 .15956 .68774 .14839 Mtetra
.572 .642 .882 r
.68774 .14839 .69389 .15956 .70672 .15606 .70066 .14615 Mtetra
.566 .672 .91 r
.70066 .14615 .70672 .15606 .71961 .15261 .71368 .14397 Mtetra
.755 .768 .863 r
.03496 .38178 .04273 .38856 .05313 .3825 .04553 .37476 Mtetra
.746 .743 .849 r
.04553 .37476 .05313 .3825 .06355 .37648 .05612 .36779 Mtetra
.736 .719 .836 r
.05612 .36779 .06355 .37648 .07399 .37054 .06671 .3609 Mtetra
.726 .697 .823 r
.06671 .3609 .07399 .37054 .08443 .36468 .0773 .3541 Mtetra
.715 .677 .811 r
.0773 .3541 .08443 .36468 .09489 .35896 .0879 .34744 Mtetra
.705 .657 .8 r
.0879 .34744 .09489 .35896 .10536 .35336 .09851 .3409 Mtetra
.695 .639 .789 r
.09851 .3409 .10536 .35336 .11583 .34791 .10912 .33449 Mtetra
.686 .621 .778 r
.10912 .33449 .11583 .34791 .12632 .3426 .11973 .32821 Mtetra
.677 .605 .767 r
.11973 .32821 .12632 .3426 .13682 .33742 .13036 .32204 Mtetra
.669 .589 .757 r
.13036 .32204 .13682 .33742 .14734 .33236 .141 .31595 Mtetra
.662 .574 .746 r
.141 .31595 .14734 .33236 .15788 .32742 .15166 .30993 Mtetra
.655 .56 .736 r
.15166 .30993 .15788 .32742 .16844 .32258 .16234 .30396 Mtetra
.648 .547 .726 r
.16234 .30396 .16844 .32258 .17902 .31782 .17304 .29802 Mtetra
.642 .534 .716 r
.17304 .29802 .17902 .31782 .18964 .31311 .18377 .2921 Mtetra
.636 .521 .706 r
.18377 .2921 .18964 .31311 .20028 .30845 .19453 .2862 Mtetra
.629 .509 .698 r
.19453 .2862 .20028 .30845 .21096 .30381 .20531 .28035 Mtetra
.623 .498 .69 r
.20531 .28035 .21096 .30381 .22168 .29915 .21611 .27458 Mtetra
.617 .488 .683 r
.21611 .27458 .22168 .29915 .23244 .29447 .22693 .26896 Mtetra
.611 .48 .678 r
.22693 .26896 .23244 .29447 .24324 .28978 .23776 .26354 Mtetra
.605 .473 .674 r
.23776 .26354 .24324 .28978 .25407 .2851 .2486 .25833 Mtetra
.6 .467 .671 r
.2486 .25833 .25407 .2851 .26495 .28043 .25946 .25336 Mtetra
.596 .463 .67 r
.25946 .25336 .26495 .28043 .27586 .27579 .27034 .24859 Mtetra
.593 .461 .669 r
.27034 .24859 .27586 .27579 .2868 .2712 .28124 .24401 Mtetra
.591 .459 .67 r
.28124 .24401 .2868 .2712 .29778 .26667 .29217 .23958 Mtetra
.589 .459 .671 r
.29217 .23958 .29778 .26667 .3088 .2622 .30314 .23525 Mtetra
.588 .459 .672 r
.30314 .23525 .3088 .2622 .31985 .2578 .31414 .23101 Mtetra
.588 .46 .673 r
.31414 .23101 .31985 .2578 .33095 .25346 .32518 .22681 Mtetra
.588 .461 .674 r
.32518 .22681 .33095 .25346 .34208 .24919 .33627 .22262 Mtetra
.588 .461 .675 r
.33627 .22262 .34208 .24919 .35326 .24497 .3474 .21843 Mtetra
.588 .462 .676 r
.3474 .21843 .35326 .24497 .36447 .24082 .35858 .21424 Mtetra
.35858 .21424 .36447 .24082 .37573 .23673 .36981 .21002 Mtetra
.588 .461 .675 r
.36981 .21002 .37573 .23673 .38704 .2327 .38108 .20581 Mtetra
.587 .46 .674 r
.38108 .20581 .38704 .2327 .39839 .22873 .3924 .20161 Mtetra
.586 .458 .673 r
.3924 .20161 .39839 .22873 .40979 .22483 .40377 .19746 Mtetra
.584 .456 .672 r
.40377 .19746 .40979 .22483 .42124 .22099 .41518 .19338 Mtetra
.581 .454 .671 r
.41518 .19338 .42124 .22099 .43273 .21722 .42663 .18941 Mtetra
.579 .451 .671 r
.42663 .18941 .43273 .21722 .44428 .2135 .43814 .1856 Mtetra
.575 .449 .671 r
.43814 .1856 .44428 .2135 .45588 .20983 .44969 .18197 Mtetra
.572 .447 .671 r
.44969 .18197 .45588 .20983 .46753 .2062 .46129 .17855 Mtetra
.569 .446 .673 r
.46129 .17855 .46753 .2062 .47924 .20259 .47294 .17537 Mtetra
.566 .447 .676 r
.47294 .17537 .47924 .20259 .491 .19898 .48466 .17241 Mtetra
.564 .449 .681 r
.48466 .17241 .491 .19898 .50282 .19535 .49643 .16966 Mtetra
.563 .454 .687 r
.49643 .16966 .50282 .19535 .5147 .19171 .50826 .16705 Mtetra
.563 .46 .695 r
.50826 .16705 .5147 .19171 .52663 .18806 .52016 .16453 Mtetra
.564 .469 .705 r
.52016 .16453 .52663 .18806 .53862 .18441 .53212 .16207 Mtetra
.566 .478 .715 r
.53212 .16207 .53862 .18441 .55068 .18081 .54416 .15963 Mtetra
.567 .489 .726 r
.54416 .15963 .55068 .18081 .56279 .17727 .55627 .15722 Mtetra
.569 .5 .738 r
.55627 .15722 .56279 .17727 .57496 .17382 .56844 .15483 Mtetra
.569 .511 .751 r
.56844 .15483 .57496 .17382 .5872 .17046 .58069 .1525 Mtetra
.569 .523 .764 r
.58069 .1525 .5872 .17046 .59951 .16723 .59301 .15024 Mtetra
.568 .535 .778 r
.59301 .15024 .59951 .16723 .61188 .16412 .60541 .14808 Mtetra
.566 .547 .792 r
.60541 .14808 .61188 .16412 .62433 .16115 .61789 .14603 Mtetra
.564 .559 .807 r
.61789 .14603 .62433 .16115 .63685 .15832 .63045 .14412 Mtetra
.56 .573 .824 r
.63045 .14412 .63685 .15832 .64945 .15564 .6431 .14234 Mtetra
.555 .587 .841 r
.6431 .14234 .64945 .15564 .66213 .1531 .65583 .1407 Mtetra
.548 .603 .86 r
.65583 .1407 .66213 .1531 .67489 .15069 .66866 .1392 Mtetra
.542 .62 .879 r
.66866 .1392 .67489 .15069 .68774 .14839 .68158 .13781 Mtetra
.534 .639 .9 r
.68158 .13781 .68774 .14839 .70066 .14615 .69459 .1365 Mtetra
.524 .66 .922 r
.69459 .1365 .70066 .14615 .71368 .14397 .70769 .13525 Mtetra
.765 .768 .856 r
.02714 .37496 .03496 .38178 .04553 .37476 .03782 .36742 Mtetra
.759 .756 .85 r
.03782 .36742 .04553 .37476 .05612 .36779 .0485 .35997 Mtetra
.753 .744 .844 r
.0485 .35997 .05612 .36779 .06671 .3609 .05918 .3526 Mtetra
.746 .732 .839 r
.05918 .3526 .06671 .3609 .0773 .3541 .06987 .34534 Mtetra
.74 .721 .834 r
.06987 .34534 .0773 .3541 .0879 .34744 .08056 .3382 Mtetra
.733 .71 .829 r
.08056 .3382 .0879 .34744 .09851 .3409 .09125 .33118 Mtetra
.727 .699 .824 r
.09125 .33118 .09851 .3409 .10912 .33449 .10194 .32428 Mtetra
.72 .688 .818 r
.10194 .32428 .10912 .33449 .11973 .32821 .11264 .31748 Mtetra
.714 .677 .812 r
.11264 .31748 .11973 .32821 .13036 .32204 .12335 .31078 Mtetra
.709 .666 .806 r
.12335 .31078 .13036 .32204 .141 .31595 .13407 .30415 Mtetra
.703 .655 .799 r
.13407 .30415 .141 .31595 .15166 .30993 .14481 .29756 Mtetra
.698 .644 .792 r
.14481 .29756 .15166 .30993 .16234 .30396 .15557 .29101 Mtetra
.693 .634 .785 r
.15557 .29101 .16234 .30396 .17304 .29802 .16635 .28447 Mtetra
.689 .624 .778 r
.16635 .28447 .17304 .29802 .18377 .2921 .17715 .27795 Mtetra
.684 .614 .771 r
.17715 .27795 .18377 .2921 .19453 .2862 .18798 .27147 Mtetra
.678 .604 .766 r
.18798 .27147 .19453 .2862 .20531 .28035 .19882 .26508 Mtetra
.672 .594 .761 r
.19882 .26508 .20531 .28035 .21611 .27458 .20967 .25883 Mtetra
.664 .585 .757 r
.20967 .25883 .21611 .27458 .22693 .26896 .22052 .2528 Mtetra
.656 .577 .754 r
.22052 .2528 .22693 .26896 .23776 .26354 .23138 .24706 Mtetra
.649 .57 .752 r
.23138 .24706 .23776 .26354 .2486 .25833 .24224 .24162 Mtetra
.641 .564 .752 r
.24224 .24162 .2486 .25833 .25946 .25336 .25311 .23649 Mtetra
.635 .559 .752 r
.25311 .23649 .25946 .25336 .27034 .24859 .26399 .23163 Mtetra
.63 .555 .752 r
.26399 .23163 .27034 .24859 .28124 .24401 .27489 .227 Mtetra
.625 .553 .753 r
.27489 .227 .28124 .24401 .29217 .23958 .28581 .22255 Mtetra
.623 .551 .754 r
.28581 .22255 .29217 .23958 .30314 .23525 .29677 .21822 Mtetra
.621 .551 .754 r
.29677 .21822 .30314 .23525 .31414 .23101 .30777 .21398 Mtetra
.62 .551 .755 r
.30777 .21398 .31414 .23101 .32518 .22681 .3188 .20977 Mtetra
.619 .551 .756 r
.3188 .20977 .32518 .22681 .33627 .22262 .32989 .20557 Mtetra
.32989 .20557 .33627 .22262 .3474 .21843 .34101 .20136 Mtetra
.34101 .20136 .3474 .21843 .35858 .21424 .35219 .19712 Mtetra
.62 .551 .756 r
.35219 .19712 .35858 .21424 .36981 .21002 .36341 .19286 Mtetra
.36341 .19286 .36981 .21002 .38108 .20581 .37468 .18858 Mtetra
.619 .551 .756 r
.37468 .18858 .38108 .20581 .3924 .20161 .386 .1843 Mtetra
.617 .549 .755 r
.386 .1843 .3924 .20161 .40377 .19746 .39736 .18007 Mtetra
.615 .548 .755 r
.39736 .18007 .40377 .19746 .41518 .19338 .40876 .17592 Mtetra
.612 .546 .756 r
.40876 .17592 .41518 .19338 .42663 .18941 .42022 .17189 Mtetra
.608 .543 .756 r
.42022 .17189 .42663 .18941 .43814 .1856 .43171 .16805 Mtetra
.602 .54 .757 r
.43171 .16805 .43814 .1856 .44969 .18197 .44326 .16444 Mtetra
.596 .537 .759 r
.44326 .16444 .44969 .18197 .46129 .17855 .45485 .16109 Mtetra
.589 .535 .762 r
.45485 .16109 .46129 .17855 .47294 .17537 .46649 .15807 Mtetra
.582 .533 .765 r
.46649 .15807 .47294 .17537 .48466 .17241 .47819 .15535 Mtetra
.575 .533 .77 r
.47819 .15535 .48466 .17241 .49643 .16966 .48995 .15293 Mtetra
.57 .534 .776 r
.48995 .15293 .49643 .16966 .50826 .16705 .50178 .15074 Mtetra
.567 .539 .783 r
.50178 .15074 .50826 .16705 .52016 .16453 .51367 .1487 Mtetra
.565 .544 .791 r
.51367 .1487 .52016 .16453 .53212 .16207 .52564 .14675 Mtetra
.564 .552 .8 r
.52564 .14675 .53212 .16207 .54416 .15963 .53768 .14484 Mtetra
.563 .561 .809 r
.53768 .14484 .54416 .15963 .55627 .15722 .54979 .14296 Mtetra
.563 .57 .819 r
.54979 .14296 .55627 .15722 .56844 .15483 .56198 .1411 Mtetra
.561 .579 .829 r
.56198 .1411 .56844 .15483 .58069 .1525 .57425 .13928 Mtetra
.559 .588 .839 r
.57425 .13928 .58069 .1525 .59301 .15024 .58659 .13751 Mtetra
.556 .596 .849 r
.58659 .13751 .59301 .15024 .60541 .14808 .59902 .13581 Mtetra
.551 .605 .86 r
.59902 .13581 .60541 .14808 .61789 .14603 .61153 .13422 Mtetra
.546 .612 .87 r
.61153 .13422 .61789 .14603 .63045 .14412 .62412 .13274 Mtetra
.539 .62 .881 r
.62412 .13274 .63045 .14412 .6431 .14234 .63681 .1314 Mtetra
.532 .627 .891 r
.63681 .1314 .6431 .14234 .65583 .1407 .64958 .13018 Mtetra
.523 .635 .902 r
.64958 .13018 .65583 .1407 .66866 .1392 .66245 .12909 Mtetra
.515 .642 .912 r
.66245 .12909 .66866 .1392 .68158 .13781 .67542 .12812 Mtetra
.506 .65 .923 r
.67542 .12812 .68158 .13781 .69459 .1365 .68849 .12725 Mtetra
.496 .659 .933 r
.68849 .12725 .69459 .1365 .70769 .13525 .70165 .12647 Mtetra
.763 .768 .857 r
.01926 .36808 .02714 .37496 .03782 .36742 .02995 .36063 Mtetra
.761 .771 .861 r
.02995 .36063 .03782 .36742 .0485 .35997 .04064 .3533 Mtetra
.76 .775 .866 r
.04064 .3533 .0485 .35997 .05918 .3526 .05133 .34608 Mtetra
.758 .78 .871 r
.05133 .34608 .05918 .3526 .06987 .34534 .06203 .33897 Mtetra
.757 .786 .876 r
.06203 .33897 .06987 .34534 .08056 .3382 .07272 .33198 Mtetra
.756 .791 .882 r
.07272 .33198 .08056 .3382 .09125 .33118 .08342 .3251 Mtetra
.754 .796 .887 r
.08342 .3251 .09125 .33118 .10194 .32428 .09413 .31833 Mtetra
.752 .8 .892 r
.09413 .31833 .10194 .32428 .11264 .31748 .10484 .31167 Mtetra
.75 .805 .897 r
.10484 .31167 .11264 .31748 .12335 .31078 .11556 .30513 Mtetra
.747 .811 .903 r
.11556 .30513 .12335 .31078 .13407 .30415 .12629 .29869 Mtetra
.745 .818 .909 r
.12629 .29869 .13407 .30415 .14481 .29756 .13703 .29236 Mtetra
.743 .827 .916 r
.13703 .29236 .14481 .29756 .15557 .29101 .14778 .28615 Mtetra
.74 .839 .925 r
.14778 .28615 .15557 .29101 .16635 .28447 .15855 .28004 Mtetra
.737 .854 .935 r
.15855 .28004 .16635 .28447 .17715 .27795 .16933 .27404 Mtetra
.732 .871 .946 r
.16933 .27404 .17715 .27795 .18798 .27147 .18013 .26816 Mtetra
.724 .891 .956 r
.18013 .26816 .18798 .27147 .19882 .26508 .19094 .26238 Mtetra
.712 .909 .964 r
.19094 .26238 .19882 .26508 .20967 .25883 .20177 .25671 Mtetra
.696 .925 .968 r
.20177 .25671 .20967 .25883 .22052 .2528 .21263 .25114 Mtetra
.678 .934 .968 r
.21263 .25114 .22052 .2528 .23138 .24706 .22351 .24569 Mtetra
.662 .938 .966 r
.22351 .24569 .23138 .24706 .24224 .24162 .23441 .24034 Mtetra
.649 .938 .965 r
.23441 .24034 .24224 .24162 .25311 .23649 .24533 .2351 Mtetra
.644 .935 .967 r
.24533 .2351 .25311 .23649 .26399 .23163 .25628 .22997 Mtetra
.643 .929 .972 r
.25628 .22997 .26399 .23163 .27489 .227 .26726 .22495 Mtetra
.646 .921 .977 r
.26726 .22495 .27489 .227 .28581 .22255 .27827 .22003 Mtetra
.65 .911 .98 r
.27827 .22003 .28581 .22255 .29677 .21822 .28931 .21522 Mtetra
.653 .898 .982 r
.28931 .21522 .29677 .21822 .30777 .21398 .30038 .21052 Mtetra
.654 .885 .982 r
.30038 .21052 .30777 .21398 .3188 .20977 .31148 .20593 Mtetra
.653 .873 .981 r
.31148 .20593 .3188 .20977 .32989 .20557 .32262 .20145 Mtetra
.65 .864 .98 r
.32262 .20145 .32989 .20557 .34101 .20136 .3338 .19707 Mtetra
.645 .858 .981 r
.3338 .19707 .34101 .20136 .35219 .19712 .34502 .1928 Mtetra
.638 .856 .983 r
.34502 .1928 .35219 .19712 .36341 .19286 .35627 .18864 Mtetra
.629 .858 .986 r
.35627 .18864 .36341 .19286 .37468 .18858 .36757 .18458 Mtetra
.617 .863 .989 r
.36757 .18458 .37468 .18858 .386 .1843 .37891 .18064 Mtetra
.601 .87 .993 r
.37891 .18064 .386 .1843 .39736 .18007 .3903 .1768 Mtetra
.581 .876 .994 r
.3903 .1768 .39736 .18007 .40876 .17592 .40174 .17308 Mtetra
.557 .88 .991 r
.40174 .17308 .40876 .17592 .42022 .17189 .41322 .16946 Mtetra
.529 .881 .984 r
.41322 .16946 .42022 .17189 .43171 .16805 .42476 .16595 Mtetra
.501 .877 .975 r
.42476 .16595 .43171 .16805 .44326 .16444 .43635 .16255 Mtetra
.478 .872 .967 r
.43635 .16255 .44326 .16444 .45485 .16109 .44799 .15927 Mtetra
.462 .866 .962 r
.44799 .15927 .45485 .16109 .46649 .15807 .45969 .15609 Mtetra
.459 .861 .966 r
.45969 .15609 .46649 .15807 .47819 .15535 .47145 .15303 Mtetra
.466 .857 .975 r
.47145 .15303 .47819 .15535 .48995 .15293 .48327 .15007 Mtetra
.481 .852 .987 r
.48327 .15007 .48995 .15293 .50178 .15074 .49515 .14723 Mtetra
.498 .842 .996 r
.49515 .14723 .50178 .15074 .51367 .1487 .50709 .1445 Mtetra
.513 .827 1 r
.50709 .1445 .51367 .1487 .52564 .14675 .51911 .14189 Mtetra
.524 .81 .998 r
.51911 .14189 .52564 .14675 .53768 .14484 .53119 .13939 Mtetra
.53 .793 .993 r
.53119 .13939 .53768 .14484 .54979 .14296 .54334 .137 Mtetra
.533 .777 .987 r
.54334 .137 .54979 .14296 .56198 .1411 .55557 .13473 Mtetra
.533 .763 .982 r
.55557 .13473 .56198 .1411 .57425 .13928 .56787 .13257 Mtetra
.531 .752 .977 r
.56787 .13257 .57425 .13928 .58659 .13751 .58025 .13054 Mtetra
.527 .742 .973 r
.58025 .13054 .58659 .13751 .59902 .13581 .5927 .12862 Mtetra
.523 .733 .97 r
.5927 .12862 .59902 .13581 .61153 .13422 .60525 .12681 Mtetra
.519 .725 .967 r
.60525 .12681 .61153 .13422 .62412 .13274 .61787 .12513 Mtetra
.515 .717 .964 r
.61787 .12513 .62412 .13274 .63681 .1314 .63059 .12357 Mtetra
.511 .709 .961 r
.63059 .12357 .63681 .1314 .64958 .13018 .64339 .12213 Mtetra
.506 .701 .957 r
.64339 .12213 .64958 .13018 .66245 .12909 .65629 .12081 Mtetra
.503 .692 .953 r
.65629 .12081 .66245 .12909 .67542 .12812 .66928 .11962 Mtetra
.499 .684 .95 r
.66928 .11962 .67542 .12812 .68849 .12725 .68237 .11855 Mtetra
.494 .677 .946 r
.68237 .11855 .68849 .12725 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Jooooo`;oP;7c1?mo[o<4ogj]lP03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0DOooool0063ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Mooooo`?o00000_ooool00ol0003ooooooooo
o`1;ooooo`;oPkOf1?n2]OH5oh6cm0GoP;7c1?mo[o<3ogj]lP03o`000?mn[O;ooooo01Gooooo00?o
0000ooooooooool0D?ooool0063ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00007?oo
ool2o`0004oooooo0on4^OL4oh>gmPCoP[Gf1On1/o@4oh2al`GoOjoc0_mn[O800ol0003oOZS^oooo
o`0Dooooo`03o`000?oooooo0000057ooooo001Pooooo`05o`000?ooooooooooooooool000002ooo
ool01?m4A4CogMgMooooool0000Jooooo`?o0000BOooool3ohJmn@CoQK_h1On4^OL4oh>gmPCoP[Gf
0_n1/o@2ohFRiPCoPjCY1On1Y^`2ogjXkP03o`000?mnZ>koOZS^01Kooooo00?o0000ooooooooool0
Coooool0063ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0001So
oooo0_l00014ooooo`?oR<?k1?n7`?X5ohJmn@CoQK_h0_n4^OL2oh^LgPCoRIkQ1?n8X>@5ohFRiPCo
PjCY1On1Y^`00omnZ>ko0000ogjXkP02ogjXkQKooooo00?o0000ooooooooool0C_ooool0063ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001Gooooo0ol00002ooooo`03
o`000?oooooooooo03kooooo0_n8a_`5ohS3n`CoQl3j0_n6_OT2ohjHf@CoSI[L1On;W=h4ohVNh@Co
R:3T1On5X^H4oh>Tj@GoPJK/00Co0000ogjXk_n6Z>coQZS/5_ooool00ol0003oooooooooo`1>oooo
o`00H?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000004oooool2o`00
03kooooo0on6col4ohO;oPCoR<Kl0_n8`o/2ohnDe0CoSiKF1On>V=T4ohfJg0CoRicN1On9W^44ohRP
i0;oQJ;V0_n<V]`4ohZNh@GoR:?V00?o0000ohJXk?n6Z>`00_n6Z>`Fooooo`03o`000?oooooooooo
04gooooo001Pooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0?oooo
o`?o0000??ooool3oh?Co`GoQ/oo1?n7boh2ohS6o003oi2AdOn?U=CoSiCD00?oSiCD1?n?U]H4ohjH
f@CoSI[L1On;W=h2ohVNh@;oSi;B1?n>U]L5ohbJg0CoRYkQ1?n8XnH00ol0003oQZS/ohJXk003ohJX
k1Kooooo00?o0000ooooooooool0C?ooool008;ooooo0_l0000kooooo`CoOmOn1?n3dol2ohK?o`;o
T8g<1?n@Sll4oi2Ad@CoSiCD1?n?U]H5ohjHf@CoSI[L0_n;W=h2oi2?cPGoSi;B1?n>U]L4ohbJg0Go
RYkQ0on8XnH01?l0003oQZS/ohJXk?n6Z>`2oi2/j1Kooooo00?o0000ooooooooool0C?ooool007oo
oooo0ol00002ooooo`03o`000?oooooooooo03Gooooo0omkf_`2ogoGoP;oTHW81?n@RlX5oi2=c0Co
T8o?1?n@TM43ohnDe0GoSiKF0_n>V=T2oi68a`CoT8c:1On@Slh4ohnBdPCoSYKG1On<V]`2ohZNh@;o
TigJ0onBY>400ol0003oT:cXoi2/j004oi2/j1Cooooo0ol0001=ooooo`00O?ooool3o`0003Wooooo
1?mgfoT2og_Jo003oi68a_nARLSoTHW800?oTHW81?n@RlX4oi2=c0CoT8o?1On@TM43ohnDe0;oSiKF
0_nAQL<5oi68a`CoT8c:1?n@Slh4ohnBdPGoSYKG0_n<V]`2oiBGe0GoTigJ0_nBY>400ol0003oTZCQ
oi2/j004oi2/j1Oooooo00?o0000ooooooooool0B_ooool007[ooooo0_l0000hooooo`CoMMcg0_mg
foT2oi>8a@CoTHS61?nARLP4oi2;bPCoT8g<1On@Sll2oi2Ad@;oTGnl0onAP/05oi65``CoTHS71?n@
S<X4oi2?cPGoSi;B0_n>U]L2oiBBc`GoU9OD1?nCWMX3oi:Th@04o`000?nBY>7oT:cXoi2/j0?oWK3U
5_ooool00ol0003oooooooooo`1:ooooo`00Moooool3o`0003Kooooo0omfgOH00onFR<?oU8S3oiB8
``02oiB8``GoThS50onAR<H4oi69b0CoT8_:1On@SL`2oi2?c`;oTGfi1OnAOk`3oi62`0CoTHG31?nA
R<L5oi2<bPCoT8o>0_n?T]82oiF>b@GoU9;?1?nDUm@5oi>MfP;oTZCQ00?o0000oifWgOnM/>D01OnM
/>DFooooo`03o`000?oooooooooo04Wooooo001eooooo`;o00000_ooool00ol0003oooooooooo`0a
ooooo`;oN]og0_nHRL84oiJ8``CoU8S31?nCR<D3oi68aPGoTHW81?n@RlX2oi2=c0;oT7Zg1?nAOKT5
oi5o_0?oTH;01?nAQL<5oi68a`;oT8c:0_nEQ/44oiF:a@GoUHk91?nDT/l5oiBGe0;oTigJ0_nLWmH2
oifWg@03o`000?nMYmgoWJOM00CoWK3U00?oZKOSooooooooool05Oooool00ol0003oooooooooo`18
ooooo`00L_ooool3o`0000Gooooo00?o0000ooooooooool0;?ooool3oh3Pn@03oiZ:`OnHRL;oV8W2
00?oV8W20onFR<<4oiB8``CoThS51?nAR<H2oi69b0;oT7Fa1?n@N;@4oi1j]`GoTGfi1?nAOk`3oi62
`0GoTHG30_nAR<L2oiF3_@GoUHK11?nER/D4oiF>b@GoU9;?0_nDUm@2oibHc`GoW9oF00?oWJOMo`00
0?nMYmd00_nMYmd00onM/>GoZKOSojVgh`02ojVghaKooooo00?o0000ooooooooool0B?ooool0073o
oooo0_l0000cooooo`CoQn7k00?oP>3ioiZ:`OnJR/400_nJR/44oiR9`P?oUXS31?nDR<<5oi>8a@;o
THS600?oT7B_oi1e/On@MK400_n@MK44oi1h]0GoT7Zg1?nAOKT5oi5o_0?oTH;00_nAQL<2oiF0^PGo
UH>m1?nEQ/44oiF:a@GoUHk90_nDT/l2oibBb@GoW9S?1?nLWmH01OnMYmgo0000oifWgOnMYmgoZ:kK
00KoZKOS5_ooool00ol0003oooooooooo`17ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00008?ooool3o`0003;ooooo1?n>hOd2ohOQn`03oi^;`OnJR/7oVX[1
00?oVX[11?nHRL84oiJ8``CoU8S30_nCR<D2oi1b[P?oT7B_1On@MK44oi1h]0CoT7Zg1?nAOKT5oi5o
_0;oTH;000?oUGfgoiF0^_nEP;X00_nEP;X5oiF3_@CoUHK11?nER/D4oiF>b@03oi^=a?nLT/WoW9;9
00?oW9;91?nLV<l5oibOeP03o`000?nX[]_oZ:kK00;oZ:kK1?nY]n<00ond_^7oooooooooo`0Coooo
o`?o0000B?ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A401kooooo0_l00003ooooo`03o`000?oooooooooo02_ooooo1?nDh?h2
ohkQo@;oW8_11?nKRl44oiZ:`@GoV8W20onFR<<2oiB8``;oT7:]1?n@LZh4oi1d[`CoT7Fa1?n@N;@4
oi1j]`GoTGfi0onAOk`00onDNkCoUGfgoiEm]`02oiEm]`CoUH2j1?nEPkd5oiF6`@CoUH[500?oUHk9
oi^=a?nKSL@00_nKSL@4oibBb@GoW9S?0_nLWmH2ojNVe003o`000?nX[]_oZ:kK00?oZ:kK00?oZKOS
okBnhOnd_^400_nd_^4Fooooo`03o`000?oooooooooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo02Wooooo000hooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Looooo`?o0000<?ooool3oiWNoP;oU>3n0_nM
S<45oib;`@?oVh_11OnJR/44oiR9`P;oUXS300?oTG:/oi1b[On@LZd00_n@LZd5oi1b[P?oT7B_1?n@
MK44oi1h]0GoT7Zg1?nAOKT01?nAOkcoU7^doiAk]?nDNk@4oiEm]`CoUH2j1OnEPkd4oiF6`@;oUH[5
0_nKRKl5oi^=a0CoW9;91?nLV<l00onVWlooYjKDojNVe002ojNVe003o`000?nX[]_oZ:kK00;oZ:kK
00?o/kSLokBnhOnd_^401?nd_^4Fooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Zooooo`00>?ooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h06?ooool3o`00037ooooo1?nIg_h6oif<`@Co
W8_10onKRl45oiZ:`@;oV8W20_nBLZ/3oi5b[0GoT7:]1?n@LZh3oi1d[`CoT7Fa1On@N;@4oi1j]`;o
TGfi0_nDNK85oiAk]0CoUGfg0onEP;X5oiF3_@;oUHK10_nJQK`5oi^9_`CoVhg41OnLT/T00onLV<oo
YYo?ojJOc`02ojJOc`?oYjKD00?o0000ojNVe?nX[]/01?nc^=`4okBnh@;o_<CQ5_ooool00ol0003o
ooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0002_ooooo000hooooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Eooooo`?o0000<Oooool4oigL
o@03oiWNo_nMS<7oWHc100GoWHc11?nLRl44oi^;`@;oVX[10_nCLZ/4oi9bZ`CoTG:/1?n@LZd4oi1b
[P?oT7B_1On@MK44oi1h]0;oT7Zg0_nDMZl4oiAi/PGoU7^d1?nEOKL4oiF0^P?oUH>m00?oVX:ioiZ5
_?nJQK`00onJQK`4oi^9_`GoVhg40_nLT/T2ojFIb@GoYYo?0onWY]@00ol0003o/[7Hok>hg005ok>h
g003okBnhOnla>7o_<CQ00?o_<CQ5Oooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool000002oooool01?m4A4CogMgMooooool0000/ooooo`00>?ooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool04Oooool3o`0000?ooooo00?o0000ooooooooool0:_oo
ool4oj7Ko0;oWMcm0_nNSL48oif<`@GoW8_10_nKRl400onDLj_oTg:[oi=bZ`02oi=bZ`GoTW:[0onA
LZ`4oi1b[@CoT7:^1?n@M:l4oi1e/@;oT7Rd0_nCM:d4oiAf[`GoU7Vb1?nDNk@4oiEm]`CoUH2j00Co
UH>moiZ2^OnJP[WoVX:i1OnJQK`4oi^9_`CoVhg400?oY9C5ojFIbOnUVLT00onUVLT5ojJOc`03ojNV
e?nb/MSo000000;o/[7H1?nc^=`00onk`Mko_<CQokc4h@03okc4h@03ol3;hooooooooooo01Cooooo
00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoo
oooo0000;?ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41004Oooool2o`00033ooooo1?nSfo/2oj7Ko0KoWXg12?nMS<43oib;`@04oiAdZonDLj_o
U7>[oiAcZ`GoTg:[1?nBLZ/3oi5b[0CoT7:]1On@LZh3oi1d[`;oT7Fa0_nCLZ/4oi=d[@GoU7J_1?nD
NK85oiAk]0CoUGfg0_nEP;X00onJP;KoVX:ioiZ2^@03oiZ2^@CoVXFl1OnKRKl00onKSLCoY9C5ojBD
a@02ojBDa@CoYIW91?nVWll01?na[=?o/[7Hok:af?l00003ok:af003ok>hg?nk`Mko^l7N00;o^l7N
0onla>43ol3;haKooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l00000;?ooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`03_ooool3o`0002oooooo0_nUfo/4oj?Kn`WoWXg12?nMS<401?nL
Rl7oU7B[oiAdZonDM:/4oiAcZ`CoTg:[1?nBLZ/3oi5b[0GoT7:]1?n@LZh2oi1d[`03oi9`ZOnCLZ_o
Tg:[00;oTg:[1OnCM:d4oiAf[`CoU7Vb1OnDNk@2oiEm]`;oVGjd1?nJP;H4oiZ2^@GoVXFl0onKRKl0
0onST<7oY9C5ojBDa@03ojBDa@GoYIW900?oYYo?ok6/dona[=<00_na[=<01Onb/MSo0000ok:af?nb
/MSo^kkL00Ko^l7N00?o_<CQol3;hoo0bn<00oo0bn<Dooooo`;o00001?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000;?ooool005Wooooo0ol0000_ooooo`GoYM_k00?o
Xm_koij=`OnNSL402OnNSL46oif<`@;oUGB/1?nDM:/4oiAcZ`CoTg:[1?nBLZ/3oi5b[0GoT7:]0_n@
LZh2oi9_Z0CoTW2Y1?nCLZ/4oi=d[@CoU7J_1OnDNK83oiAk]003oiUm/_nIO[CoVGjd00;oVGjd1?nJ
P;H4oiZ2^@GoVXFl00?oVhVooj>@`OnST<400_nST<44ojBDa@CoYIW900?o/:O@ok6/dona[=<00ona
[=<00onb/MSo0000ok:af003ok^ng0Co^l7N0_o1cN@4ol3;h`03oko?i_oooooooooo017ooooo00Co
0000oooooooooooo00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?oo
ool0:oooool005Kooooo0ol00003ooooo`03o`000?oooooooooo02[ooooo0onVgOX2ojGKn`ooWXg1
0_nMS<400onFMJcoUGB/oiEd[002oiEd[0CoU7B[1?nDLj/4oi=bZ`CoTW:[1?nALZ`3oi1b[@03oi5^
YonBKjSoTVnX00;oTVnX1?nBL:T4oi=bZ`CoTgB]1OnDMZl4oiAi/P04oiAk]?nIOK;oVGfboiUm/PGo
VGjd1?nJP;H4oiZ2^@?oVXFl00?oXXbmoj>@`OnST<400onST<45ojBDa@03ojFIbOn`Ym3o/:O@00;o
/:O@1Ona[=<00ol0003o^kkLok^ng003ok^ng003ok_1g_o1cNCo`LgT00?o`LgT00?o`<_Soko?i_no
cnH00_nocnHFooooo`03o`000?oooooooooo043ooooo001Dooooo`;o0000<?ooool3ojOOn`;oY]gj
4OnNSL44oiIe[0GoUGB/1?nDM:/3oiAcZ`CoTg:[1OnBLZ/3oi5b[004oi1b[OnAKZOoTFjWoi5^Y`Go
TVnX0onBL:T4oi=bZ`CoTgB]1OnDMZl2oiAi/P;oVG^a1OnIOK84oiUn]0CoVX2f1?nJP[T00onJQKco
XXbmoj:<_@02oj:<_@CoXi311?nTU<D00on^Xlco/:O@ok2Wd003ok2Wd0Co/JcC00?o^[cKo`000?nk
_]`00onk_]`00oo2d>Go`LgTol7=i003ol7=i003ol7Fj_nocnKo_loV00?o_loV5_ooool00ol0003o
ooooooooo`10ooooo`00DOooool3o`00033ooooo1?nWgo/Boij=`@OoUWF/1?nEM:`4oiAdZ`?oU7>[
1OnCLZ/4oi9bZ`;oTG:/00?oTFfVoi5^YonAKZL00onAKZL4oi9_Z0CoTW2Y0onCLZ/5oi=d[@?oU7J_
00?oVGZ`oiUk/OnINk400_nINk45oiUm/PCoVGjd1OnJP;H2oiZ2^@03oj69^onRS;goXXbm00?oXXbm
1OnST<400onTU<Go[Z?<ojjSc002ojjSc0Go/:O@00Go/JcCokZlfonj_=_o^[cKo`000003ok^ng0?o
`]3U0oo1cN@3ol7FjP?o_loV0_njdN/Fooooo`03o`000?oooooooooo03oooooo001>ooooo`Go0000
;oooool3ojORn`03ojOOnonNSL7oWXg1013oWXg100?oUWJ/oiIe[?nFMJ`01_nFMJ`4oiEd[0CoU7B[
1?nDLj/4oi=bZ`;oTW:[0_nAK:D3oi5]YPGoTFjW1?nBKjP4oi9`Z@?oTg:[1OnCM:d01?nDMZooVGZ`
oiUj/?nIN[05oiUk/@CoVGfb1OnIO[@3oiZ0]P03oj26^?nQRK_oXHVk00;oXHVk1?nRS;d4oj>@`@03
ojfObOn^Xlco[Z?<00?o[Z?<1?n`Ym000onj^]Wo^[cKokZlf`02okZlf`03o`000?nj_=_o^kkL00Go
`]3U00?o`LgTol7Fj_o1e^X00oo1e^X00onocnKo^]7[ok[Aj`02ok[AjaKooooo00?o0000oooooooo
ool0?_ooool004cooooo0_l00005ooooo`03o`000?oooooooooo02Wooooo0onWiO/2ojORna3oWXg1
0_nFMZd3oiIf[0SoUWF/1?nEM:`4oiAdZ`CoU7>[0_nCLZ/6oi5/Y@CoTFfV1?nAKZL4oi9_Z0CoTW2Y
1?nCLZ/3oi=d[@03oiUi[_nIN[3oVGZ`00?oVGZ`1?nINk44oiUm/PGoVGjd00CoVX2foj26^?nPQ[So
X8Jh1?nQRK/5oj:<_@;oXi310on]WlT5ojjSc003ok2Wd?nj^]Wo^[[I00;o^[[I0onj_=/00ol0003o
`]?Wol;Ci`04ol;@i@;o`Mg^1?o1e^X00onjgO7o^]7[ok[Aj`02ok[Aj`03ojo>l?oooooooooo01Co
oooo00?o0000ooooooooool0?_ooool004Wooooo0ol0000aooooo`?oYnGk4OnNSL45oiIf[@CoUWJ/
1onFMJ`5oiEd[0?oU7B[0_nDLj/2oi5/Y0SoTFbU1?nAKJH4oi5^Y`CoTVnX1OnBL:T3oi=bZ`04oi=d
[OnINJkoVGV^oiUi[PGoVGZ`1?nINk45oiUm/P?oVGjd00?oWhBgoj26^?nPQ[P00onPQ[P4oj69^`Co
XXbm00?oXi31ojfObOn]WlT00_n]WlT4ojjSc003okZhf?nj^]Wo^[[I00Co^[[I00Co^[cKol;Cioo2
dnOo00000_o2dnL00oo2d>Go`Mg^ol7MkP03ol7MkP03ol7Fj_njgO7o^]ga00;o^]ga00?o^]7[ojo>
l?n_c_000_n_c_0Dooooo`?o0000?oooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Poooo
o`;o0000<_ooool2ojKYnP03oin=`OnNSL7oWXg100ooWXg11onFMZd4oiIf[0OoUWF/1OnEM:`2oiAd
Z`GoTFbT2?nAK:D4oi5]YPCoTFjW1OnBKjP4oi9`Z@;oTg:[00?oVGR]oiUi[_nINJh00onINJh4oiUj
/0CoVG^a1OnIOK801?nIO[CoWhBgoin4]onOQ;L5oj26^0CoXHVk0onRS;d00on/W<Ko[Io9ojfOb@03
ojfOb@?o[Z?<0onj^=P4okZjf@;o`mSY0_o2dnL01?l0003o`]?Wol3VlOo0i_44ol7MkP03okOXm_nj
gO7o^]ga00;o^]ga0_n]f_L5ojo>l1Gooooo00?o0000ooooooooool0?Oooool002;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Mooooo`?o00000_ooool00ol0003oooooooooo`0/ooooo`?oYN_j00Co
Y^Wjoin=`OnOSL7oWhg13_nNSL400onFMZcoUWJ]oiIf[@06oiIf[@CoUWJ/2?nFMJ`3oiEd[0SoTFbT
2?nAK:D4oi5]YPGoTFjW1?nBKjP3oi9`Z@04oiQg[?nIN:goVGR]oiUh[@GoVGV^1?nIN[05oiUk/@?o
VGfb00?oWX>eoin4]onOQ;L00onOQ;L4oj26^0GoXHVk00CoXXbmojbLa_n/W<Ko[9c61On]WlT00on^
Xlco^[SHokZhf002okZhf0?o^[[I1?o3f>T00oo2dnOo0000ol3Vl@03ol3Vl@03ol7Mk_ngj?Ko]nSf
00;o]nSf00?o^]gaojgJmon]f_L00on]f_L2ojo>l0?oX/Oc5Oooool00ol0003oooooooooo`0loooo
o`008_ooool01Ol@413ooooooooooooooooo410@01_ooooo0_l0000booooo`?oYN_j0_nOSL04oin=
`@[oWXg11OnFMZ`9oiIf[@?oUWJ/2?nFMJ`00onEM:coTFbToi5/Y009oi5/Y0SoTFbU0onAKJH5oi5^
Y`CoTVnX00CoTW2YoiQg[?nHMjcoV7N/1?nIN:d4oiUi[PGoVGZ`1?nINk401?nIOK;oWX>eoij3]OnN
PkD5oin4]`GoX8Jh0onQRK/00on[VLCo[9c6ojbLaP02ojbLaPCo[Io900?o^[OGokZhf?nj^=P01?nj
^=P00onj^]Wo`mSYol?Hj@02ol?Hj@;o_>kc00Co0000ol3VlOo0i_7o`>Ka0_n^lOH2okOXmPCoYNGk
0_n]f_L3oigAnPGoX/Oc5Oooool00ol0003oooooooooo`0kooooo`008_ooool01Ol0003ooooooooo
oooooooo000001Sooooo0ol0000booooo`;oY>gh00?oXHk0oin=`?nOSL000onOSL03oin=`@OoWXg1
00?oUWF/oiIf[?nFMZ`01_nFMZ`8oiIf[@CoUWJ/1_nFMJ`00onBK:CoTFbToi5/Y00:oi5/Y0SoTFbU
1?nAKJH4oi5^Y`;oTVnX0_nGMJ/5oiQg[0?oVGR]1?nINJh5oiUj/0;oVG^a0_nNPK@5oij3]@CoWhBg
1OnPQ[P00onQRK_oZiW4oj^Ia002oj^Ia0Co[9c600?o[Io9okZgeonj]mL00_nj]mL4okZhf0;o`mg/
0oo3f>T3okc^l`03o`000?o0i_7o[_7f00;o[_7f0onFjoP2ojGUn`?oUMWn1OnMdOX2oj;7l`;oU[kc
5Oooool00ol0003oooooooooo`0kooooo`008_ooool01Ol0003ooooooooooooooooo000001Kooooo
0ol0000aooooo`?oY>og00CoY>ghoj6>`?nQS/3oXHk01?nOSL04oin=`@GoWXg10_nFMJ`8oiIf[0So
UWJ]1?nFMZ`2oiIe[0;oTVfT0onBK:@<oi5/Y0SoTFbU1?nAKJH3oi5^Y`03oiIcZOnGMJ_oUgF[00;o
UgF[1OnHMj`3oiUh[@GoVGV^0onIN[000onMPK?oWX6doij1]002oij1]0GoWX>e1OnOQ;L3oj26^003
ojVF`_n[VLCoZiW400?oZiW41?n/W<H6okZge`03okZhf?o3gNco`mg/00?o`mg/00?o`mSYokc^lonl
k_<00_nlk_<00ol0003oVo;]ojkamP03oiK[n0?oQmgm1OnEfOh2oigAnP;oT/;g1OnF__<Eooooo`03
o`000?oooooooooo03[ooooo000Rooooo`05oa0@4?ooooooooooooooool@41004oooool3o`0000;o
oooo00?o0000ooooooooool0;Oooool4ojC_m`03oj:?`?nQS/3oXHk000;oXHk01?nOSL04oin=`@;o
WXg11_nFMJ`7oiIf[0SoUWJ]0_nFMZ`6oi9]Y0CoTVbT2onAK:@8oi5/Y@CoTFfV00CoTFjWoiIcZOnF
LjWoUW>Y1OnGMJ/4oiQg[0?oVGR]1OnINJh01?nIN[3oWH6coif1/onMPK<5oij1]0CoWX>e1OnOQ;L0
0onPQ[SoZIK2ojVF`P02ojVF`PCoZiW40on/W<H2okVfe`Co^[OG0_o3i>l4ol?Mk0?o]?Cb00Go_>kc
oi_bkOnKl^go0000og[Ti`04og3Km0CoQmgm0_nEfOh2ohg6n`GoT/;g1?nF__<Fooooo`03o`000?oo
oooooooo03Wooooo000Rooooo`05ogMgMonHV9SooooooiRHV?mgMgL04?ooool3o`0003?ooooo0onV
l?L00onTT<3oXXo0oj:?`002oj:?`0?oXHk01OnOSL02oin=`@03oiIeZonFMJcoUWF/00KoUWF/1onF
MZ`7oiIf[@WoTVfT1?nBK:@;oi5/Y0SoTFbU0_nAKJH2oiAaZ0GoUW>Y1?nGMJ/4oiQg[0CoVGR]0onI
NJh00onMP;;oWH6coif1/`03oif1/`CoWX6d1OnNPkD3oin4]`03ojNC`?nYU/;oZIK200?oZIK21On[
VL@01?n/W<Ko^KKGokVfeoni]]L3okZge`Co`nC_00?o`mg/okCdl_ndm?800_ndm?801_mli]KoE<o7
oe??hOmCcn7o0000oe??h@;oL=_d0omobOl4ohO9o@CoSLKk0_nB`_L2ohnck`GoT;C_5?ooool2o`00
03_ooooo000Rooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool2o`0003Gooooo0_nVl?L4ojB@
`0?oXXo01?nQS/03oin=`004oiMeZonFMJ_oUWF[oiIeZ`SoUWF/2?nFMZ`5oiIf[@[oTVfT1?nBK:@<
oi5/Y0KoTFbU00?oTfnVoiAaZ?nDLJP00_nDLJP5oiIcZ@CoUgF[1?nHMj`4oiUh[@04oiUi[_nMP;;o
WH2boif0/PGoWH6c1?nNPK@5oij3]@03oin4]onWTl3oYi?000;oYi?01?nYU/84oj^Ia003okVfe_ni
]]Oo^KKG00?o^KKG00?o^[OGol?Tkoo3i>l00_o3i>l3ojGfj`03okCdl_lc^/Co<k[400?oLLSo00?o
N<Woo`000?mhbOl00_mhbOl4ogo9o`CoQlWm0_n=a_/00on>/>koSk?_ohnck`03ohnck`GoT;C_5Ooo
ool00ol0003oooooooooo`0hooooo`00<_ooool5o`0003;ooooo0onYl?L00onVTL3oY930ojB@`003
ojB@`0?oXXo01?nQS/001?nOSL3oUgF[oiMeZonGMJ/4oiIeZ`OoUWF/2?nFMZ`2oiIf[@;oTffT2onB
KJ@4oi9/Y0coTFbT0onAK:D01?nBKJGoTfnVoi=_Y_nCKjH5oiAaZ0CoUW>Y1?nGMJ/5oiQg[0;oVGR]
00?oWGnboif0/_nMP;800onMP;84oif1/`GoWX6d0onNPkD00onVT;koYi?0ojNC`003ojNC`0GoZIK2
00?oZiW4okVfe_ni]]H00_ni]]H3okVfe`?o`N_a00Go`nC_ojGfjonUm^_oYOK[oe?;/@04ofo6o`?o
LLSo0_l000000omhbOooSJ?SohfSh`04ohbXj0CoSJg/1?n>/>h5ohnck`;oT;C_0_nA/N`Fooooo`03
o`000?oooooooooo03Oooooo000`ooooo`;o0000=?ooool4ojg_m`04ojW`monVTL3oYY70ojJA`0Co
Y9301?nRSl02oj6>`003oiMfZonGMJ_oUgF[00?oUgF[0onFMJ/7oiIe[0OoUWJ/1OnCKJ@<oi9]Y0?o
TVbT3?nAK:@01?nAK:GoTVfUoi9]YOnBKJD4oi=_YPCoU76X1?nFLjT5oiMeZ`CoV7N/00?oVGR]oieo
/_nMOk801OnMP;84oif1/`GoWX6d00?oWX>eojJ@__nVT;h00_nVT;h4ojNC`0CoZIK200?o^;GGokVf
e_ni]]H01?ni]]H01?ni]]Oo`N_aol7[lOo1jo42oh_]f004o`000?m`aOooL<Goog35o`;oKlKo0_n?
U]H3o`000003ohfLgOl0003oSJ?S00?oSJ?S1?n<Z>P4ohf]k0CoS[3^0_n?/nl2oi:/j0GoTK7/5Ooo
ool00ol0003oooooooooo`0gooooo`00;Oooool3o`0003Gooooo0on]koL2ojNC`@CoYY701OnTT<02
oj:?`004oiQfZonGMZ_oUgJ[oiMfZ`GoUgF[0onFMJ/8oiIe[0?oUWJ/2OnCKJ@;oi9]Y0CoTVbT2onA
K:@5oi9]Y@?oTfnV1?nDLJP4oiIcZ@GoUgF[0_nHMj`2oieo/@CoWGnb1?nMP;85oif1/`?oWX6d00?o
YHjmojJ@__nVT;h00onVT;h5ojNC`003ojVF`_nh]MOo^;GG00;o^;GG1?ni]]H2okcblP03ol7[lOn;
kMSoRngH00;oTX[81?n@Sll01On?U]Ko0000o`000?l0003oSiKF00CoSIcM00Co0000ohfShon=Xn?o
SJ?S1?n<Z>P2ohf]k0;oTj7M1OnCY^<4oi:/j0GoTK7/5Oooool00ol0003oooooooooo`0fooooo`00
;?ooool2o`0003Gooooo0_nbk?L00onYUL7oYi?1ojNC`@03ojNC`@?oYY701OnTT<000onRSl3oV7J[
oiQfZ`04oiMfZ`CoUgF[0onFMJ/8oiIe[003oiIf[?nCKJCoTffT00WoTffT2onBKJ@4oi9/Y0KoTFbT
00?oTF^Soi5/Y?nAK:@00_nAK:@5oi9]Y@?oTfnV1?nDLJP5oiIcZ@?oUgF[00?oWGj`oieo/OnMOk40
0_nMOk44oieo/PCoWH2b1OnMPK<00onNPKCoYHjmojF>_@02ojF>_@CoYY2n1?nWTl000ong]MOo^;GG
okRee`04okRee`06okVfe_nll_;o_?;bokcbl_mVekOoU8K21OnBR/P01?n@Sloo0000o`000?l00004
ohnFePGoSIcM00?o0000ohfShonEUM401?nDVmL5oi>Qg@GoTjKS1?nB[>P2oi6ak0?oV;3X5Oooool0
0ol0003oooooooooo`0eooooo`00;?ooool3o`0003;ooooo0onbk?L3ojVE`@CoYi?11?nVTL02ojB@
`0;oVGN[1?nHMZ/3oiMfZ`CoUgF[1?nFMJ/6oiIe[0goTffT2onBKJ@4oi9/Y0;oTFbT0_n@JJ83oi5[
X`GoTFbT1?nBKJD3oi=_YPCoU76X1OnFLjT01?nGMJ_oWGj`oien/?nMO[05oieo/@?oWGnb1OnMP;83
oif1/`03ojB=_?nUS[goYHjm00?oYHjm1OnVT;h00onWTl3o]kGGokNee`02okNee`Co^;GG0onbmnl0
0onll_;oUX>moiB6`P02oiB6`P;oTX[80ol00003oi2?c`GoSiKF0_n=W=d2oiJ?bP04oiFEdOl0003o
UIGAoiFEd@CoU9_G1OnCXMd2oi>Vh`;oVZ;J1OnIZN45oiR`j1Cooooo00?o0000ooooooooool0=Ooo
ool002cooooo00Co0000ooooool0003o0000;oooool3okKXmP03ojbH`_nYUL7oZIG100;oZIG11?nW
Tl43ojJA`003oiYi[?nIMj_oVGN[00;oVGN[1?nHMZ/3oiMfZ`CoUgF[1?nFMJ/2oiIe[0;oU6jT3onC
KJ@;oi9]Y0;oTVbT0_n@JJ44oi1YXP?oTF^S1OnAK:@4oi9]Y@?oTfnV1OnDLJP3oiIcZ@03oiam[onM
O[3oWGj`00?oWGj`1?nMOk44oieo/PCoWH2b00?oWH6cojB=_?nTSK`00_nTSK`4ojF>_@CoYY2n00?o
][CGokNeeong]ML00ong]ML3okRee`?o/_O_0onFPkd2oiB6`P?o00000onBR/P4oi2?c`;oSiKF0_nG
R/@4oiJ?bP04oiFEdOl0003oUIGAoiFEd@GoU9_G0_nCXMd2oi^Kd`GoVZ;J1OnIZN42oiR`j0;oX[GV
4oooool00ol0003oooooo`000008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00Gok^k^oc8b<_l0003o410@olc<c00Iooooo`00;?ooool2o`0000;ooooo00?o0000oooooooo
ool0:oooool2okKXmPCo[9S20onYUL45ojNC`@03ojJA`?nJNJcoVWV/00CoVGN[1?nHMZ/3oiMfZ`Go
UgF[0_nFMJ/5oiA^Y0ooTffT2_nBKJ@00on@J:7oT6VQoi1YX@02oi1YX@CoT6VR1?nAJj<4oi5/Y0Co
TVfU1?nCKjH4oiAaZ004oiIcZOnLOJooW7f_oiam[`GoWGj`1?nMOk44oieo/P;oWH2b0_nTS;`5ojB=
_0GoYHjm0_nVT;h3okJde`Go]kGG00Co^;GGok;gkonbmnooV8:i0onFPkd3o`0000;oU8K20_nBR/P2
oiR1^0CoV8Fn1OnGR/@4oiJ?bP04oiFEdOl0003oUIGAoiFEd@;oU9_G0_nLU/d5oi^Kd`CoVZ;J1?nI
ZN400onS[MooX[GVoj:eiP03oj:eiQGooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B406Oooool002_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Wooooo`?o^NCd00?o[I[4ojbH`_n/V<80
0on/V<84ojVE`@?oYi?100?oW7Z]oiYi[?nJNJ`00_nJNJ`3oiUgZ`CoV7J[1?nGMZ/4oiMeZ`03oiIe
ZonDKZCoU6jT00CoU6jT4?nCKJ@8oi9]Y0;oT6RQ1?n@JJ45oi1YXP?oTF^S1?nAK:@5oi9]Y@?oTfnV
0onDLJP00onKNjkoW7f_oiam[`03oiam[`CoWGj`1OnMOk42oieo/P03ojB=_?nTS;coY8bl00?oY8bl
1?nTSK`5ojF>_@03ojJ@__nf]=Oo][CG00;o][CG1?ng]ML2oj;fi@?oV8:i00?oUX>mo`000?l00000
0_nFPkd2oiB6`P03oiUn]?nHPKSoV86h00?oV86h1?nHQKh4oiN:a0CoUXo:0_nEUM400ol0003oW977
oibFc@04oibFc@CoVi_C1OnJX]X00onIZN7oXjgOoj>]g`02oj>]g`CoX[GV5Oooool00ol0003ooooo
ooooo`05ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo0000
01Wooooo000[ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08oooool4ok_NlP04
okWTm?n]V/Co[I[4ojfJa0Co[9S21?nYUL401?nWTl7oW7Z]oiaj[OnLNZd4oiYi[0CoVGN[0onHMZ/4
oiMfZ`;oUgF[2OnDKZ@@oi=]Y0GoTVfT0_n@J:03oi1XX@GoT6VQ1?n@JJ83oi5[X`CoTFbT1OnBKJD3
oi=_YP04oiAaZ?nKNjkoVg^^oi]k[PGoW7f_1?nMO[05oieo/@04oieo/_nTSKcoY8flojB=_0CoY8bl
1OnTSK`3ojF>_@03okBdf?nf]=Oo][CG00Co][CG00Co]kGGoj;fiOnRm^GoVH2f0_nHP[T3o`0000Co
UX>m00?oU8K2oiUn]?nIO[@01OnHPKP4oiR5_PGoUh[40_nFSlX01?nMS<7oW977oibAaol00002oibA
a`CoW9K=1OnKVm<2oiZRfP;oXjKH1OnS[Ml2oj:eiP?o[;_U5Oooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q01Wooooo000[
ooooo`?o00001Oooool00ol0003oooooooooo`0Qooooo`Co^mkb00?o[ig5ojfJa?n]V/@00_n]V/@5
ojbH`P;oZIG100?oWGb^oiaj[OnLNZd00_nLNZd4oiYi[0CoVGN[1?nHMZ/2oiMfZ`03oiA_YOnDKZCo
U6jT00WoU6jT4?nCKJ@2oi9]Y003oi5XX?n@J:3oT6RP00;oT6RP1?n@J:44oi1YX@CoT6VR0onAJj<5
oi5/Y0CoTVfU0_nCKjH00onJNJgoVg^^oi]k[P03oi]k[PCoW7f_1OnMO[03oieo/@03ojF>_OnTSKco
Y8fl00;oY8fl1?nTS;`5ojB=_003ojF>_Ond]=So];CH00;o];CH1?nf]=L2oh[/d`;oVH2f0ol00003
oiR2^@;oUX>m0_nINk04oiUn]0CoV86h1?nHQKh4oiN:a003oij9_?nMS<7oWHc100;oWHc10_nLTLL0
0ol0003oW977oibFc@04oibFc@;oVi_C0_nTX=85oj>Vf0?oXjgO00?o[;KPojbkiOn/^nD01?n/^nDE
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mE
EEGo0000oa0@4?o<c<`06Oooool002_ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Nooooo`?o_=[_00?o^mkbojnMaOn_WLD00_n_WLD3ojfJa0Co[9S200CoWgn`oiel[_nMO:koWGb^
1?nLNZd4oiYi[0CoVGN[1?nHMZ/00onGMZ_oU6nUoiA_Y@0<oiA^Y0goTffT1OnAJ:04oi1XX0CoT6RQ
1?n@JJ44oi1YXP?oTF^S1OnAK:@3oi9]Y@03oiUh[?nJNJgoVWV]00;oVWV]1?nKNjh4oiam[`GoWGj`
00?oWGnaojF>_OnUS[d00_nUS[d4ojB=_0CoY8bl0onTSK`00onc]=Wo];CHokBdf004okBdf004okJd
eon:k=?oR^cCoiYn/`?o00000_nIP;H2oiR2^@;oVWV]1?nINk04oiUn]0GoV86h1?nHQKh00onGR/Co
WXVloij9_002oij9_0?oWHc10onLTLL00ol0003oW9K=oibFc@02oibFc@03ojBKc?nTX=;oY:3B00?o
Y:3B1OnSY]P01?nS[Moo[;KPojbfh?n/]^04ojbki@03ok?2i_oooooooooo01?ooooo00?o0000oooo
ooooool00oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool06oooool0
02_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`Co_=[_1On_WLD4ojfJ
a004ojbH`_nOOk3oWgn`oimo/0CoWGb^1?nLNZd3oiYi[0CoVGN[0_nHMZ/2oiE_Y@?oU6nU3?nDKZ@:
oi=]Y003oi5YX?nAJ:3oTFRP00GoTFRP1On@J:03oi1XX@CoT6VQ1?n@JJ84oi5[X`CoTFbT00CoTVfU
oiUh[?nIN:coVGR/1?nJNJd4oi]k[PGoW7f_0onMO[000onVT;koYHjmojF>_@03ojF>_@CoY8fl1?nT
S;`00onTSKco/kCIok>df@02ok>df@Co];CH00?oKmbloi]l/?l000000_l000001OnJO[?oVH2foiV0
]_nIP;KoVWN[00CoVWV]1OnINk03oiUn]0GoV86h0_nHQKh2oin5^0GoWXVl0onMS<44oibAa`03o`00
0?nLU/goY9_<00?oY9_<1OnTX=82oj>Vf0;o[K3K1On/]^000on/^nGo/l;Vok?2iP02ok?2iQ?ooooo
0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00Kooooo`00
4?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@oooooooo
ool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Wooooo0_nme^`3okcJk`;o
/9o71?n_WLD3ojfJa003oj62/_nOOk3oWgn`00?oWgn`0onMO:h4oiaj[@CoVWV/0_nIMj/00onFL:Ko
UFnUoiE_Y@02oiE_Y@CoU6nU2onDKZ@8oi=]Y0?oTFVP2?nAJ:04oi1XX0?oT6RQ1?n@JJ45oi1YXP?o
TF^S0onAK:@00onHMZ_oVGR/oiUh[003oiUh[0?oVWV]1?nKNjh5oiam[`03oien/?nVT;koYY2n00;o
YY2n1?nUS[d5ojB=_0;oY8bl00?o/[GKok>dfOnc]=T01?nc]=T00ond]=SoVgb`o`000002o`0000Co
VWjc00CoVH2foiYgZonJMj_oVWN[1OnJNJd4oiUk/0CoVGjd0onHPKP00onOP[CoWhFhoin5^003oin5
^0CoWXVl1?nMS<42oibAa`03ojFGaol0003oY9_<00CoY9_<1?nTX=800on][=Ko[K3Kojf`f`03ojf`
f`?o[;KP0_nd`N@5ok?2iQGooooo00Wo0000ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool01?o<c<coA4A4o`000?l@410Iooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo0ol0000:ooooo`03o`000?oooooooooo01Ko
oooo1Onme^`00onlf^oo/9o7ok2Oa`02ok2Oa`Co[ig500?o[I[4oj62/_nQP[801OnOOk03oiel[PCo
W7Z]1?nJNJ`00onIMj_oUW2VoiI`YP04oiE_Y@CoU6nU2onDKZ@6oi=]Y003oi9YXOnAJJ3oTFVP00;o
TFVP2?nAJ:04oi1XX0?oT6RQ1?n@JJ45oi1YXP?oTF^S00CoTFbToiQfZonHMZ_oV7J[1OnIN:`4oiYi
[@CoVg^^0onLOJl00onWTl7oYY2nojJ@_P03ojJ@_PGoYHjm0onTSK`00ona]mgo/[GKok:ef`02ok:e
f`Co/kCI0ol00004oi]l/0;oVWjc00?oVgJYoiYgZonJMj/00onJMj/4oiYi[@CoVG^`1?nIO[@01?nH
PKSoWh:doin2]?nOP[@5oin5^0GoWXVl0_nMS<400onVU<?oYIO7ojFGa`02ojFGa`03o`000?nTVlco
Y9_<00?oY9_<00CoY:3Bojf/e_n][=Ko[JcF1On]/=/00on/]^3o]<7TokC1i003okC1i0;o/l;V0_nf
bNTEooooo`03o`000?oooooooooo02oooooo0008ooooo`Ko00000_ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol00005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04ooo
ool3okkCjP?o_MK/00?o/J;8ok2Oaon`WlL00on`WlL3ojnMa@03oj:5]?nQP[;oXH:b00;oXH:b1?nO
Ok03oiel[PCoW7Z]0_nJNJ`2oiIaYPCoUW2V0onEKjD4oiA_Y@_oU6jT0onCKJ@01?nBJZ7oTVVQoi9Y
XOnBJJ45oi5YX0OoTFRP1?n@J:03oi1XX@GoT6VQ1?n@JJ82oi5[X`03oiMdZ_nHMZ_oV7J[00?oV7J[
1?nIN:`4oiYi[@CoVg^^00?oW7f_ojNC`OnWTl400_nWTl44ojJ@_PGoYHjm00?oY8flok6ggOna]md0
0_na]md4ok:ef`03ok>dfOl0003o000000?oVWV]1?nKO;001?nJO[?oVgJYoi]fZOnKMZT4oiYgZ`Co
VWV]1OnINk02oiUn]003oimo/?nOP[CoWh:d00?oWh:d1?nOQKP5oij9_004oif<`OnVU<?oYYC3ojJD
``CoYIO700Go0000ojBKc?nTVlcoY9_<ojjYdP05ojf/eP?o[K3K0_ne`>84okC1i003okO>jonfbNWo
]/WY00?o]/WY5Oooool00ol0003oooooooooo`0^ooooo`004?ooool01Ol0003ooooooooooooooooo
000000_ooooo00CoA4A4omgMgOoooooo00001_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo017ooooo1OnndnX01?nme^co/J;8ok6Rb?naX/P5ok2Oa`03ojnMaOnRQKCoXXFd00CoXH:b
1?nOOk04oiel[P;oW7Z]00?oUg:XoiIaY_nFLJH00_nFLJH4oiI`YP?oUFnU1?nDKjD;oiA^Y004oi=]
Y?nBJZ7oTVZQoi9ZX@?oTVVQ1OnAJJ07oi5XX0CoT6RP1?n@J:44oi1YX@?oT6VR00CoUW>YoiMdZ_nG
M:[oUgBZ1OnHMZ/4oiUh[0CoVWV]0onKNjh00onYU/?oYi?1ojNC`@03ojNC`@GoYY2n0onUS[d00on`
^^7o/KOMok6gg@03ok6gg@;o/[GK0ol000000onIMZ_oVWV]oiYi[@02oiYi[@;oVgb`0_nKMZL4oi]f
Z@CoVWN[1?nJNJd5oiUk/003oiUn]?nOOk3oWgn`00GoWh:d1OnOQKP3oij9_003ojNB_onVU<?oYYC3
00;oYYC31?nUUlL00ol0003oY9_<ojjYdP03ojjYdPCo[JcF00?o[K3KokG0h_ne`>800one`>800ond
`NCo]lk[okO>j`02okO>j`?o]/WY0_nbbn`Eooooo`03o`000?oooooooooo02gooooo000@ooooo`05
o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00006ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03_ooool2okkAj0Co_]?Z00?o/ZC:ok6Rb?naX/P00_naX/P4
ok2Oa`03ojB8]onRQKCoXXFd00;oXXFd0onQP[85oimo/0?oWGb^00?oW7Z]oiMbZ?nGLZP01?nFLJH4
oiI`YPCoUFnU0onDKjD:oiA^Y003oi=[X_nBJZ7oTVZQ00;oTVZQ1?nBJJ44oi5YX0OoTFRP1On@J:03
oi1XX@CoT6VQ00CoT6VRoiIcZOnFLjWoUW>Y1?nGM:X4oiQfZ`CoVGR/1OnJNJd01?nKNjkoZIK3ojVF
`onYU/<4ojNC`@GoYY2n00?oYHjmok2jhOn`^^400_n`^^43ok6gg@?o00001?nIMZ/4oiYi[@CoVgJW
1?nKMZT4oiYgZ`GoVWV]0onINk000onOO:goWgn`oimo/002oimo/0CoWh:d1OnOQKP00onNRKcoYi:o
ojNB_`02ojNB_`?oYYC31?nUUlL00on`Yloo0000ojjYdP03ojjYdP?o[JcF0_ng`N84okG0hP;o^=C^
1?ngc^/00onfbNWo//_/ok;;k003ok;;k1Cooooo00?o0000ooooooooool0;Oooool0013ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo0_l0000?ooooo`;o0000
3?ooool5okkAj003okkCj_nbY<[o/ZC:00;o/ZC:1?naX/P01?n`WlOoY8RgojB8]onTR;L4oj:5]0?o
XH:b1OnOOk02oiel[P03oiMdZOnGLZSoUg:X00;oUg:X0onFLJH4oiI`YPCoUFnU1?nDKjD5oiA^Y0;o
TfbS0onCJj85oi9ZX@?oTVVQ1?nAJJ07oi5XX0GoT6RP0on@J:42oi1YX@;oUW:X1OnFLjT3oiMdZPCo
V7J[1OnIN:`3oiYi[@03ojZIaOnYU/?oZIK300;oZIK31OnWTl43ojJ@_P03ok6oiOn`^^7o/;[Q00?o
/;[Q0ol00003oiMbY`GoVGJ[0_nJNJd00onLMJKoVgJWoi]fY`03oi]fY`CoVgJY0onJMj/5oiYi[@04
oiUk/?nOO:goWgb]oiml[@CoWgn`1OnOP[@3oin5^003ojVA_?nWT[ooYi:o00?oYi:o1?nVU<<00onU
UlOo/:O?ok2Wc`02ok2Wc`03o`000?n^ZM;o[ZWB00;o[ZWB00?o[JcFokO1h_ng`N800_ng`N800one
`>;o^=C^okSDkP03okSDkP;o]lk[0_ncdo44ok;;k003ojc9kooooooooooo01?ooooo00?o0000oooo
ooooool0;?ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co0000
00Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`?o_loW0onndNP00onc
Ylco/ZC:ok:TbP03ok:TbP?o/J;800?oYHbiojB8]onTR;L00_nTR;L4oj:5]0CoXH:b0onOOk001?nH
MZ_oUgBYoiMdZOnGM:T4oiMbZ0?oUW6V1?nFL:H4oiE_Y@CoU6nU0_nDKZ@00onCKJCoTfbSoi=/X`02
oi=/X`?oTf^R1OnBJZ43oi9YX@CoTFVP2?nAJ:04oi1XX0;oT6RQ00?oUG6XoiIbZ?nFLZP00_nFLZP5
oiIcZ@?oUgBZ1?nHMZ/5oiUh[003oiYi[OnZVLGoZYW500;oZYW50onYU/<5ojNC`@03ojJ@__na_nGo
/KoU00;o/KoU00Co/;[Qo`000?l0003o00000_nFKjD4oiMbY`GoVGJ[00CoVWV]oiaeY_nLMJKoW7FV
1?nKMZL4oi]fZ@CoVWN[0onJNJd00onNNJ[oWgb]oiml[@03oiml[@?oWgn`1OnOP[@00onOQKSoZI6l
ojVA_002ojVA_0CoYi:o0onVU<<00onbY/go/:O?ok2Wc`03ok2Wc`05ojjYd_l0003o[ZWBojjYd_ni
a>801?ng`N82okWNlPCo^=C^00?o/Mcfok?ClOncdo400oncdo400onbbnco[<W_ojc9k`02ojc9ka?o
oooo0_l0000^ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?oo
ool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo1OnocnL01?nndNSo
/jO<ok>Wc?ncYl`5ok:TbP04ok6Rb?nUS;WoYHbiojF<^@CoY8Rg1?nRQK@3oj62/P04oimo/?nHMZ_o
V7J[oiQfZ`CoUgBY0onGLZP4oiIaYPCoUW2V0onEKjD4oiA_Y@03oiA^Y?nCKJCoTffT00CoTfbS1?nC
Jj84oi9ZX@?oTVVQ1?nAJJ08oi5XX0?oT6RP00CoU72WoiEaZ?nELJSoUG6X1OnFLZP4oiIcZ@?oUgBZ
1OnHMZ/3oiUh[003oj^Lb?nZVLGoZYW500?oZYW51?nYU/<2ojNC`@?o/LKY0_na_nD3o`000003ok2j
hOnDK:;oUVnU00;oUVnU1OnGLZL3oiUfZ`03oiadYOnLMJKoW7FV00;oW7FV1?nKMZL4oi]fZ@CoVWN[
00CoVWV]oiiiZ_nNNJ[oWWVZ1OnOO:d4oimo/0?oWh:d00?oZi2jojVA_?nYTK`00onYTK`5ojNB_`04
ojJD`onbY/go/ZK=ok:Vc@Go/:O?00?o0000okW4h_nia>800_nia>800ong`N;o^MkbokWNlP03okWN
lP03okSDk_nag?Ko/Mcf00;o/Mcf0_ncdo43ojWBm@Co[<W_5Oooool00ol0003oooooooooo`0[oooo
o`00:Oooool2o`0001Cooooo00?o0000ooooooooool00_ooool2oko>i@Co_loW00?o]J[>ok>Wc?nc
Yl`00_ncYl`4ok:TbP03ojN?_?nUS;WoYHbi00;oYHbi1?nTR;L4oj:5]0;oXH:b00?oVGR]oiQfZonH
MZ/00_nHMZ/4oiMdZ@?oUg:X1?nFLJH4oiI`YP?oUFnU0_nDKjD2oiA^Y@?oTffT1OnCK:<3oi=[XPCo
TVZQ0onBJJ45oi5YX0OoTFRP00CoT6RPoiA`YonDL:OoU72W1?nELJP4oiIbZ0CoUW>Y0onGM:X5oiQf
Z`03oiUh[?n[W<SoZic800;oZic81?nZVLD3ojVF``03ok7>konaa^Wo/LKY00;o/LKY0ol000000ona
_nGoU6bRoiA/XP02oiA/XPCoUVnU1?nGLZL01?nIMZ_oW7BUoiadYOnLM:D4oiaeYPCoVgJW1OnKMZT2
oiYgZ`03oiegYonNNJ[oWWVZ00?oWWVZ1?nOO:d4oimo/003oin2]?n[T;[oZi2j00;oZi2j1?nYTK`4
ojNB_`03okBXc?nbY/go/ZK=00;o/ZK=1?n`Yll2okc9i003o`000?nia>;o^LCR00;o]^[f1?nig_80
0onYi_[o/Mcfok7LmP02ok7LmP;oY=[k1OnYd_D2ojc9k`;oXl?`5Oooool00ol0003oooooooooo`0Z
ooooo`00:Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Co_lkU00?o_loWokFZ
c_neZ/h00_neZ/h4ok>Wc003ok:Tb_nWSkcoYhnl00;oYhnl0onUS;T4ojB8]`?oXXFd00CoVWZ_oiUh
[OnIN:goVGR]1?nHMZ/4oiMdZ@?oUg:X1?nFLJH4oiI`YP;oUFnU00?oU72VoiA^YOnDKZD00_nDKZD4
oi=]Y0CoTfbS0onCJj84oi9ZX@?oTVVQ1OnAJJ05oi5XX0KoU72W1?nELJP4oiIbZ0CoUW>Y1?nGM:X3
oiQfZ`03oj^Nb_n[W<SoZic800?oZic81OnZVLD01OnYU/?o/Lk_ok7>konac^oo/LKY00;o000000Co
/LKYoi=YX?nCJJ3oTfVP1?nDK:84oiI_Y@?oUg:W00?oW7BToiadYOnLM:D00onLM:D3oiaeYPCoVgJW
1OnKMZT00onJMj_oWGNWoiegY`05oiiiZPGoWgb]0_nOOk000on/TKWoZi2joj^@^P03oj^@^PGoZI6l
00CoYi:ookBXc?ndZ<co]:S<1OnbY/d00on`Yloo_<WTokc9i003okc9i003o`000?nfj_Ko]^[f00;o
]^[f00?o^MkbojWVn_nYi_X00_nYi_X00onag?KoY=[kojCJn`03ojCJn`;oZM;e0_nPao<5oj?3l1Co
oooo00?o0000ooooooooool0:_ooool002Wooooo00?o0000ooooooooool05Oooool2ol3<i0?o_lkU
0_nf[Ll5okFZcP;o/jO<00?oZI:nojN?_?nWSk`00onWSk`4ojF<^@?oY8Rg00CoXXFdoiYj[onJNZoo
VWZ_1?nIN:d4oiQfZ`?oUgBY1?nGLZP3oiIaYP?oUW2V00CoU76XoiA`Y_nDL:KoU72V1OnDKZD3oi=]
Y0CoTfbS0onCJj84oi9ZX@CoTVVQ1?nAJJ02oi5XX0WoU72W1?nELJP4oiIbZ0GoUW>Y0onGM:X00onH
MZ_oZik:oj^NbP02oj^NbPCoZic81?nZVLD2ok7Fl`06ok7>kol0003o0000o`000?naa^WoTVNN1?nC
JJ05oiA/XP?oUVnU00CoUg:WoiadY?nLM:CoW7BT1OnLM:D3oiaeYPGoVgJW0onKMZT00onMMZKoWGNW
oiegY`02oiegY`CoWWVZ1OnOO:d01?nOOk3o[96iojbA^On/TKT4oj^@^PCoZI6l00?o]jc>okBXc?nd
Z<`00ondZ<`3ok:Vc@;o_m;X1?nlbN@2ojOclP03o`000?nfj_KoV>_h00?oV>_h0_nYi_X3oiSPoP;o
Y=[k0_nLb_L5oj37l`;oXl?`0onN_>dDooooo`03o`000?oooooooooo02Wooooo000Yooooo`03o`00
0?oooooooooo01?ooooo1Oo0c>@00onoc^Go]Zg?okJ]c`02okJ]c`?o]J[>00?oZiK1ojVB__nYT[h0
0_nYT[h4ojN?_0CoYHbi0_nTR;L00onKOK7oVWZ_oiYj[`02oiYj[`CoVGR]1?nHMZ/3oiMdZ@CoUg:X
0onFLJH01?nFL:KoU76XoiAaZ?nDLJP4oiA`YPCoU6jU0onCKJ@4oi=/X`?oTf^R1OnBJZ43oi9YX@?o
TFVP00?oTg2WoiA`YonDL:L02OnDL:L4oiEaZ0CoUW:X1OnFLjT2oiMdZP03oj^Pc?n[W/[oZik:00?o
Zik:1On[W<P00onZVLGo/MKcok7Fl`03o`0000;o/Lk_1?nBIih3oi=YX0GoU6bR0_nFKjD00onLLj?o
W7BToiadY003oiadY0CoW7BU1?nLMJH4oi]fY`04oi]fZOnMMZKoWGJVoiefYPCoWGNW1?nNNJX4oiml
[@03ojjB^On/TKWo[96i00;o[96i1On[T;X00onYTKco]jc>okN/cP02okN/cPCo]:S<00?o/ZK=okoB
j?nod^P00onod^P00onlbNCoYo?bojOclP02og;Qh`04o`000?mbhN?oV>_hoiS[n0?oQ>3k0_nHh?h3
oiO;nPCoW<[g0_nPao<3oibjk@GoW[c]5?ooool00ol0003oooooooooo`0Xooooo`00:Oooool3o`00
017ooooo0oo1bn<3ol3<i003okR`dOnf[Loo]Zg?00Co]Zg?00Co]J[>oj^F`On[U/7oZiK10onYT[h5
ojN?_0;oYHbi00CoWH2coi]m/OnKOK7oVgfa1?nJNZl4oiUh[@CoV7J[1?nGM:T3oiMbZ0;oUW6V00?o
U7:YoiAaZ?nDLJP00onDLJP3oiA`YPCoU6jU0onCKJ@4oi=/X`CoTf^R1?nBJZ43oi9YX@04oi5YX?nC
L:OoTg2Woi=`Y`coU72W0onELJP5oiIbZ0?oUW>Y00?oZZ7>oj^Pc?n[X<`00_n[X<`5oj^NbP;oZic8
0_n_goP3o`0000;o/MKc0onAIY`4oi9WWPCoTfVP1?nDK:800onFKjGoW7>SoiacX`05oiadY0CoW7BU
1?nLMJH3oi]fY`03oieeYOnMMZKoWGJV00?oWGJV0onMMjL5oiiiZP;oWgb]0on^T[T3ojbA^@CoZi2j
00?o_;GCokN/c_ng[<h00ong[<h3okBXc0;o`=o_1?nod^P01?mkiM7o=k^bocNk/_lg^k82og;Qh`03
of_Hm?l0003oJmSd00;oQ>3k1?n@bO/4oiO;nP;oW<[g0_nK]n`5oibjk@;oW[c]0_nN^N/Cooooo`;o
0000:_ooool002Wooooo00?o0000ooooooooool04?ooool5ol7;h`04ol3<i?nh/=7o^;3AokR`d@Co
]Zg?00?o[I[4oj^F`On[U/400_n[U/43ojVB_PGoYhnl00?oYHbioif0/onMP;<01?nKOK44oiYj[`?o
VGR]1?nHMZ/4oiMdZ@;oUg:X00CoU7>[oiAbZOnDLZWoU7:Y1OnDLJP3oiA`YPCoU6jU0onCKJ@5oi=/
X`?oTf^R1?nBJZ42oi9YX@03oi=`Z?nCL:OoTg2W00?oTg2W2onDL:L4oiEaZ0CoUW:X00?oUW>YojZQ
c_nZXLh00_nZXLh3oj^Pc0CoZik:0_n[i_X3o`0000;o[moh00?o/MKcoi1TVonAIY`00onAIY`4oi9W
WPCoTfVP0onDK:801?nLLZ?oW7>SoiacXonLLj<5oiadY0CoW7BU1?nLMJH01?nKMZOoWGFUoieeYOnM
MJD5oiefYP?oWGNW1OnNNJX00onOO:go[Y:iojjB^@02ojjB^@Co[96i0_n[T;X3okbed`Go]jc>00?o
]:S<ol3Okoo0gnl00_o0gnl00onod^SoNnGAog_Ud@02odS3k@;oD/_/0_n;_?L2ohc5nP03o`000?n<
aO[oS<Gj00;oT<Wk0_nH[>D4oiZcj@GoVkO/0_nL^^d2oijfj@GoW[W[5?ooool00ol0003ooooooooo
o`0Wooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001Ooo
ool00ol0003oooooooooo`0?ooooo`;o`L[Q1?o1bn<00onj/];o^;3AokR`d@03okR`d@03okJ]con]
V/Co[I[400;o[I[40on[U/44ojVB_P;oYhnl0_nNPkH4oif0/`?oVgfa1?nJNZl4oiUh[@?oV7J[0_nG
M:T2oiAd[0?oU7>[1?nDLZT4oiAaZ0?oU72V1?nDKZD4oi=]Y0CoTfbS0onCJj82oi9ZX@GoTg2X1OnC
L:L;oiA`Y`CoUG6X0onFLZP00onYX]3oZZ7>ojZQcP03ojZQcPCoZj3<00?oZik:oj_Vn_l000000_l0
00001?n[i_[o[mohojoOn?n@I9X3oi1TV`CoTFJL1?nBIih4oi=YX004oiA/X_nLLZ?oW7:SoiabX`Co
W7>S1?nLM:@5oiadY@?oW7FV1OnMMJD4oiefYP?oWGNW1?nNNJX00on`U;[o[Y:iojjB^@03ojjB^@Co
[96i00?oZi2jokbedonl]M<00_nl]M<4okN/cP03ok[`m?o0gnoo`=o_00;o`=o_0onBY^<3ohjbk`Go
Rkcg00CoS<Gjo`000?nIYMkoVJGN1OnH[>D4oiZcj@;oVkO/0_nN/NH5oijfj@CoW[W[5Oooool00ol0
003oooooooooo`0Vooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003oooooooooo`0>ooooo`Co`L[Q00?o`L_S
okZbd_nj/]800_nj/]83okR`d@03ojnNaon]V/Co[I[400?o[I[41?n[U/42ojVB_P03oj27^?nNPkKo
WX>f00;oWX>f1?nMP;<3oi]m/@CoVWZ_1?nIN:d2oiQfZ`03oiAf[_nDM:coU7B/00;oU7B/1?nDLj/3
oiAbZ@CoU76X0onDL:H5oiA^Y@?oTffT1?nCK:<2oi=[XP03oi=aZOnCL:SoTg2X00KoTg2X1?nCL:L;
oiA`Y`CoUG6X00?oUW:XojVRd?nYX]000_nYX]04ojZQcP?oZj3<0ol00002oj_VnP03oi1SV_n@I9[o
T6BJ00;oT6BJ0on@I9/4oi5VW0CoTVNN0onCJJ000onKLJ;oW7:SoiabX`02oiabX`CoW7>S1?nLM:@5
oiadY@;oW7FV00?oWWJUoieeYOnMMJD00onMMJD4oiefYPCoWGNW0_nNNJX3ok2D^PGo[Y:i0_n/TKT0
0oo3a]co_;GCokbed`04okbed`03okN/c_njl?Co^_3d00;o^_3d00?o`=o_oiNKe_nBY^<01?nBY^<3
ohjbk`;oRkcg0_nJWMH2oiVUgP03o`000?nIYMkoVJGN00CoV:cU0_nJ/nT2oin]h@GoW[7V1?nN]^T2
oijij`?oX[WY5?ooool00ol0003oooooooooo`0Vooooo`001_ooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0_l0000>ooooo`Go`L[Q1_nj/]80
1?nh/=7o[ik7ojnNaon_W/L4ojfJa0CoZiK100?oZI:noj27^?nPQkP01?nNPkH4oif0/`CoVgfa0onJ
NZl2oiUh[@;oU7N_0onDMZh4oiAd[0CoU7>[0onDLZT4oiAaZ0CoU72V1?nDKZD3oi=]Y0;oTfbS0_nC
LZX3oi=aZ@SoTg2X1?nCL:L;oiA`Y`;oUG6X0_nWX]45ojVRd0GoZZ7>0_l00002ojG[nP04oi1SVOn@
Hi[oT6>Joi1SVPCoT6BJ0on@I9/5oi5VW0?oTVNN0_nCJJ02oi]aXPGoW7:S0onLLj<5oiadY0CoW7BU
00?oW7FVoiifYOnNMZD01OnMMJD4oiefYPCoWGNW00?oWWVZok2D^_n`U;X00_n`U;X5ojjB^@04ojbA
^Oo3a]co`lKLol?6g0Co_;GC0onHl^@2ok[`m0CoUi_F0_nBY^<2oijBa`?oW9O>1OnJWMH2oiVUgP03
o`000?nIYMkoVJGN00;oV:cU00?oWjSLoin]hOnO[N400onO[N45oijaiP;oW[KY0_nR]NH5oj:ijACo
oooo00?o0000ooooooooool09Oooool000kooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool02oooool3ol79h0?o`L[Q0_nk]M@4okZbdP03
ok6SbOn_W/Oo[ik700;o[ik71On]V/@2oj^F`@03oj:;^onPQkSoX8Nh00;oX8Nh1?nNPkH4oif0/`?o
Vgfa0_nJNZl00onEN;3oU7N_oiAg[`02oiAg[`CoU7J^0onDM:`4oiAcZ`?oU7:Y1OnDLJP3oiA`YPCo
U6jU0_nCKJ@00onCLZ_oTg:Zoi=bZP02oi=bZPCoTg6Y1onCL:P4oi=`Y`[oU72W00?oYZ;BojNRdOnW
X]400onWX]45ojVRd004ojZQc_l0003o0000o`0000;oW>gh00?oYN_joi1SVOn@HiT00on@HiX4oi1T
VP?oT6BK1OnAIY`3oi9WWP04oi=YX?nKLJ;oVg6Roi]aXPGoW7:S0onLLj<5oiadY0?oW7BU00?oX7RV
oiifYOnNMZD00_nNMZD4oieeY@GoWGJV0_nMMjL00oncV;co/9Bjok2D^P03ok2D^PCo[Y:i00?ob^CZ
ol?6g?o3a]`00oo3a]`01?nl]M?oV?;ToiSbi?nHl^@4oi^BbP?oUi_F00?oXY32oijBaonNT/L00_nN
T/L4oibGcPGoVYgF0_nIYMh00ol0003oXJ?GoinXg003oinXg0GoWjgQ0_nN/NH2oj>ahPGoX[GV0_nR
^NT2ojJljAGooooo00?o0000ooooooooool09?ooool000kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool02_ooool5ol79h003ol7:hOnk
]MCo^kGD00;o^kGD00?o^[;Bok6SbOnaXlT00_naXlT3ojnNa`Co[I[400?oY8nnoj:;^onRRk/00_nR
Rk/3oj27^0CoWX>f1?nMP;<2oi]m/@04oiIi/OnEN;3oUGR`oiEh/0GoU7N_0onDMZh4oiAd[0?oU7>[
0onDLZT5oiAaZ0?oU72V0_nDKZD2oi=c[@?oTg:[1?nCLZX4oi=aZ@OoTg2X1OnCL:L8oiA`Y`?oYZ;B
1?nWX]43ojVRd0?o000000CoTncdoic]n?nLkOSoT6:I1?n@HiT3oi1SVPCoT6BJ1?n@I9/4oi5VW0;o
TVNN1_nKLJ84oiabX`?oW7>S1OnLM:@01?nLM:GoX7RVoj1hY_nPN:H4oiifY@CoWGFU1OnMMZH01?nM
MjOo/iRlok>H_?ncV;`5ok2D^P;o[Y:i0oo:i>X3ol?6g003o`000?nNS<3oWXc000;oWXc01?nKT/X0
0onGVmKoXY32oj:@`P02oj:@`PCoWY;71?nLUlh2oiZMeP;oXioA0_nQXmL00ol0003oXJ?Goj6Se`04
oinXg0;oWjgQ0_nT[Mh5oj>ahP;oX[GV0_nW^NH5ojJljA?ooooo0_l00008ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c009ooooo`003_oo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00oooool2o`0000Wooooo
0_o2amh4ol79h0;o_KSE0onk]M@00ondZ<co/J?9ok6Sb@03ok6Sb@Co[ik700?o[I[4ojB?__nTSkh0
0_nTSkh3oj:;^`?oX8Nh1?nNPkH3oif0/`04oiMk/_nFNK7oUWVaoiIi/@CoUGR`1?nDMjl3oiAf[PCo
U7B/0onDLj/4oiAbZ@CoU76X0_nDL:H00onBM:koTg>]oi=c[@02oi=c[@CoTg:[0onCLZX4oi=aZ@Oo
Tg2X1OnCL:L5oiA`Y`;oY:;B1OnVX]83ojNRd@?o00000_nCk?@5oi1RV@CoT6>I0on@HiX4oi1TVPCo
T6BK1?nAIY`00onBIikoVg6Roi]aXP05oi]aXPCoW7:S1?nLLj<3oiadY003oj9kZ?nPN:KoX7RV00?o
X7RV0onNMZD5oieeY@?oWGJV00?o]Ik0ok>H_?ncV;`00_ncV;`5ok2D^P03ojjB^Oo:i>[ob^CZ00;o
b^CZ00Co`lKLoj68^_nQR;[oXHRj1OnNS<02oi^BbP03ojF?__nRT<;oXY3200?oXY321?nNT/L2oibG
cP;oYIc<1OnSWm42oj6Se`04o`000?nQXmOoWjSLoinXg0;oYZ_J1OnT[Mh3oj>ahP03ojRfhonW^NKo
YkWV00?oYkWV0onV_>T2ojZojACooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B402Oooool000kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool2o`0000Wo
oooo1?o2amh00oo1bN3o_KSEokfhe@03okfhe@04ok^ee?ndZ<co]:S<okBXc0Co/J?90on_W/L00onW
Tl7oY8nnojB?_P03ojB?_P?oXX^k1?nPQkP3oij3]P04oif0/onGNk;oUg^boiMk/PCoUWVa0onEN;04
oiAg[`?oU7J^1?nDM:`4oiAcZ`?oU7:Y0_nDLJP2oi9e[`?oTWB^1?nCLjd4oi=bZ`?oTg:Z1?nCLJT8
oi=`Z0CoTg2W0_nDL:L00onSXM?oY:;BojBRdP03ojBRdPCoYZ;B0ol00002ohWZk`03oi1SVOn@HYWo
T6:I00GoT6:I1?n@HiT3oi1SVPGoT6BJ0on@I9/3oi5VW003oiY`XOnKLJ;oVg6R00KoVg6R1?nLLZ<4
oiacX`;oW7BT0_nRNjP5oj1hYP?oWWJU1OnMMJD2oiefYP?o]Ik00oncV;`4ok2D^P?o[O[L0_o:i>X0
0onSQ[GoXHRjoj68^P02oj68^PCoWXc000?oZI2lojF?__nUSkh00_nUSkh4oj:@`P?oWY;700?oZ9[8
ojFLc?nUW<`00onUW<`5oj>Od@;oXJ?G00?o0000ojJ[f_nVZmX00onVZmX4ojB]gP03oj>ah_nX]^?o
Z;KS00;oZ;KS1OnW^NH00onV_>WoZ[oYojZoj@02ojZojACooooo00?o0000ooooooooool01?ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000009ooooo`003_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`03
o`000?oooooooooo00Kooooo0_o2a]d3ol;7gP;o_[_F1Onm^=D5okBXc0Co/J?900Co[ik7ojNC`OnW
Tl7oYi?11?nTSkh4oj:;^`?oX8Nh0_nNPkH00onHOKCoUg^boiMk/P03oiMk/P?oUWVa0onEN;04oiAg
[`?oU7J^1?nDM:`4oiAcZ`;oU7:Y00?oTWJ`oi9e[onBMJl00_nBMJl4oi9d[P?oTg>]1?nCLZ/4oi=b
ZP?oTg6Y2?nCL:P3oi=`Y`03oj6PdonSXM?oXj7C00;oXj7C1?nTX]801?nVX];o0000o`000?l00002
oh3Wj`04oi1SV_n@HiWoT6>Ioi1SV@OoT6:I1?n@HiT4oi1SVPCoT6BJ0on@I9/01?nAIYcoVW2QoiY`
XOnJL:48oi]aXPGoW7:S0onLLj<00onLM:CoXW^Xoj9kZ002oj9kZ0CoX7RV0onNMZD5oieeY@03oief
Y_neW/3o]Ik000;o]Ik01?ncV;`01On`U;[o[O[Lojgjg?n]n]coYHJc00CoXhJe1OnQR;X00onNS<3o
ZI2lojV@_002ojV@_0?oYHnn1OnRT<801?nNT/OoZ9[8ojRJb?nXV/P4ojFLc0CoXioA00GoZjWDojRY
eonXZMOoZ:WGo`000005ojJ[fP;oY:gN0_nY]>45ojRfh`;oYkWV0_n[_^P4ojZoj@03ojc1jOoooooo
oooo01;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go
<S8boiRHV?ooooooV9RHoc8b<P09ooooo`009oooool00ol0003oooooooooo`04ooooo`Go`/KM00?o
`/ONokjke_nn^mH00_nn^mH3okfhe@;o]jg?1OndZ<`2ok6Sb@03ojVIaOnWTl7oYi?100;oYi?11OnT
Skh3oj:;^`;oX8Nh00CoVH2foiQm]?nHOKCoV7fd1OnGNk83oiIi/@?oUGR`1OnDMjl3oiAf[P?oU7B/
0_nDLj/2oi9g/@?oTWJ`1?nBMJl4oi9d[PCoTg>]0onCLZ/4oi=bZPCoTg6Y1onCL:P00onCL:OoXJ3C
oj6Pd`02oj6Pd`?oXj7C0_nTX]83o`000003ojJRd_n0in_oP>O[00?oT6>J0on@HiT7oi1RV@CoT6>I
1?n@HiX4oi1TVP;oT6BK00?oVFnQoiY`XOnJL:400_nJL:48oi]aXPGoW7:S0_nLLj<00onTOj_oXW^X
oj9kZ003oj9kZ0CoX7RV1?nNMZD3oieeY@03okRVaoneW/3o]Ik000?o]Ik01?ncV;`00onMO[3oYHJc
ojF6/`03ojF6/`CoXhJe0onQR;X00on]TkcoZI2lojV@_003ojV@_0?oYHnn1?nRT<800on[V/KoZ9[8
ojRJb002ojRJb0GoYIc<00CoXioAoj^Ye?n[ZMCoZjWD0onXZML01?l0003oZ:WGojJ[f_nVZmX2oj^c
gPGoZKCQ0_nX]^<2ojbmi`GoZkkX00?oZ[oYojc1jOn/`NT00_n/`NTDooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`02Ooo
ool002Oooooo0_l00004ooooo`;o`/GL0oo2a]d00oo0_]So_[_FokjkeP04okjkeP04okfheOng[Loo
]jg?okN]c`Co]:S<00?o[9k8ojVIaOnYVLD00_nYVLD3ojNC`@GoY8nn0_nRRk/01?nKPkWoVH2foiV0
]_nIP;H4oiQm]0CoUg^b0onFNK44oiEh/0CoU7N_0onDMZh2oiAd[003oi9h/_nBMk7oTWNa00;oTWNa
1?nBM[03oi9e[`CoTWB^1?nCLjd3oi=bZ`CoTg:Z1?nCLJT5oi=`Z0;oWikC1OnQX=<3oj>Qd`;o0000
00GoY:;BogWTj?mii>SoNNCXoi1TVP04oi1SVP?oT6>I1on@HYT5oi1SV@?oT6>J1?n@I9X00on@I9_o
VFnQoiU_X@05oiY`X@OoVg6R1OnLLZ<00onLLj?oY7n[ojAoZ`05oj9kZ0CoX7RV1?nNMZD2oieeY@?o
^:K71OneW/02ok>H_003oien/?nWQ[;oYHJc00CoYHJc1?nSQ[D2oj68^P?o[I>l1?nYT;`4ojF?_P03
oj:@`_n[V/KoZi[600;oZi[60onXV/P4ojFLc003ojjZdon[ZMCoZjWD00?oZjWD0onXZML00ol0003o
Zk?Noj^cgP03oj^cgP?oZKCQ00?o[KkVojbmion/_NL00on/_NL2oj^nj0Oo[<7Y5Oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o
410@00Wooooo000Wooooo`03o`000?oooooooooo00;ooooo1?o2aM`01?o2a]go`;kHol2nf?o0_]P4
okjkeP03okVbd_ng[Loo]jg?00?o]jg?00?o]:S<ojbNb?n/W/P00_n/W/P3ojVIa@CoYi?10_nTSkh2
oif7^`CoVh>i0onIP;H3oiQm]0CoUg^b1?nFNK43oiEh/0;oU7N_0_nCNK<3oi9h/`?oTWRb1OnBMk43
oi9f/0CoTWF_0onBM:h4oi=c[@CoTg:[0onCLZX4oi=aZ@;oTg2X00?oWIcCoinNdonOW]<00onOW]<4
oj6Pd`?o00000_mdhNL2oi5UV`?oT6BJ1?n@HiX3oi1SV@OoT6:I1On@HiT3oi1SVP;oT6BJ0_nHKZ43
oiU_X@GoVW2Q2?nKLJ83oiabX`03ojN6/?nTOj_oY7n[00;oY7n[1?nRNjP5oj1hYP?oWWJU00?oWGFU
okRVaonhY/L00_nhY/L5okFN`003ok>H_?nMO[3oYhJb00;oYhJb1?nUQ[<4oj>6]@03oj68^_n]Tkco
[I>l00;o[I>l1OnYT;`2ojF?_P03ojjLaOn[V/KoZi[600?oZi[61?nXV/P00onUW<co[Z[CojjZd`02
ojjZd`CoZjWD00GoZ:WGojfdgOn]]=go[KCMo`000004oj^cgP03ojVdhOn]_^Ko[KkV00;o[KkV0on/
_NL2ojg2j@Oo[<7Y0_n/`^XBooooo`?o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_oooooo^[Zjo`000009ooooo`009oooool01?l0003oooooooooooooool4ol;5g003
ol;1fOo0_]So`;kH00?o`;kH00?o_[_FokVbd_ni/]800_ni/]83okN]c`03ojnTcOn/W/So[9k800?o
[9k80onYVLD3ojNC`@03oin;_onMQk_oWHNk00;oWHNk1?nKPkT3oiV0]P?oV7fd1OnGNk83oiIi/@;o
UGR`00?oTgZdoi=i/onCNK<00_nCNK<3oi9h/`CoTWRb1?nBMk43oi9f/0CoTWF_0onBM:h4oi=c[@Co
Tg:[0onCLZX2oi=aZ@;oVi[B1?nMW=<5oinNd`?o000000?oL^3Xoi5VW?nAIY`01?nAII/4oi1TVP?o
T6>J0on@HiT8oi1RV@CoT6>I0_n@HiX00onGKJ7oV6jQoiQ^X@02oiQ^X@CoVFnQ1?nJL:48oi]aXP;o
W7:S0_nWQ[04ojAoZ`CoXW^X1OnPN:H2oiifY@03ok^ddonhY/Oo^:K700?o^:K71?neW/000onPOZgo
Z8RbojN6/P03ojN6/PGoYHJc0_nSQ[D00on`Ukko[I>lojfC_003ojfC_0GoZI2l00CoYHnnojjLaOn^
W<Go[Yc51On[V/H2ojRJb003ok:^e?n^Z]?o[Z[C00Co[Z[C0_n[ZM@00on`]]go[KCMojfdg@02ojfd
g@04o`000?n]]=goZk?Noj^cgP;o[[oV1On]_^H00on/_NOo[L;Yojg2j@02ojg2j@;o[<7Y0_n/`n/5
ojc2jQCooooo00Wo0000ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo
410@o`000?l@413oZJVY00Wooooo000Vooooo`?o00000_o3a=/3ol;5g0?o`/7I0oo0_]P2okbhePGo
^K;B00Co]jg?ojnTcOn_Y<go[jC=1?n/W/P4ojVIa@04ojNC`OnORkooWh^ooin;_`?oWHNk1?nKPkT3
oiV0]PCoV7fd1?nGNk82oiIi/@04oiAk]OnCN[CoTgZdoi=j]0CoTgVc1?nBN;<3oi9h/PCoTWNa0onB
M[04oi9e[`CoTWB^0onCLjd2oi=bZ`;oUiC?0onIUm45oi^JdPCoWIcC00GoWikCo`000?l0003o0000
og;Ok002oi9WWP?oTFJL1?nAII/4oi1TVP?oT6>J0on@HiT8oi1RV@CoT6>I00?oT6>JoiM]XOnGKJ40
1?nHKZ44oiU_X@CoVW2Q2?nKLJ800onLLZ?oYhJ`ojN6/002ojN6/0?oY7n[1OnRNjP4oj1hYP04oiif
YOnk]=?o^kCCok^dd`Go^:K700?o]Ik0oj1n[OnXR;800_nXR;84ojN6/PGoYHJc00CoXhJeok2G__n`
Ukko/9Nn1On]Tk`3ojV@_003ok6Paon^W<Go[Yc500;o[Yc51?n[V/H00ond/mOo/ZkDok:^e002ok:^
e0Co[Z[C00?o/KWOok2fgOn`]]d00_n`]]d4ojfdg@03o`000?n^_nKo[[oV00?o[[oV0_n]_^H2ojg3
jPCo[L;Y00?o[<G/ojc3jon/`n/00on/`n/2ojc2jP;oZl;[5Oooool00ol0003oooooooooo`0Noooo
o`009_ooool00ol0003o`lCKol?4f`03ol?4f`03ol;5g?o2`MWo`/7I00?o`/7I00?o`;kHokbhe_nl
^=H00_nl^=H3okVbdP03ok:[dOn_Y<go[jC=00;o[jC=1On/W/P2ojVIa@03oj6@`onORkooWh^o00;o
Wh^o1?nMQk/4oi^3^@?oVH2f0onHOK@2oiMk/P;oU7bf0onDNkD4oi=j]0?oTgVc1?nBN;<3oi9h/PCo
TWNa1?nBM[03oi9e[`CoTWB^0_nCLjd00onETLgoUiC?oiNDc`03oiNDc`?oVIOA1?nKV]82oifLd`?o
000000?oWikCog;Ok?mbgn`00onBIih4oi5VW0?oTFFK1?n@I9X3oi1SVPCoT6>I1on@HYT3oi1SV@04
oiE/XOnGKJ7oUffQoiM]X@GoV6jQ0onIKj44oiY`X@OoVg6R00?o[8jgojN6/?nWQ[000onWQ[03ojAo
Z`GoXW^X0onPN:H00onmbNCo^kCCok^dd`02ok^dd`Co^:K700?oXWj/ojV:]?nXR;801?nXR;84ojN6
/P?oYHJc00?o/ig2ok2G__n`Ukh00_n`Ukh5ojfC_004ojV@_?naX<Oo/J37ok6Pa`Go[Yc500CoZi[6
okBceond/mOo];?G1Onb[]@00on^Z]?o/KWOok6ig`02ok6ig`Co/;KM00Go[KCMok32ion``^Oo/<;W
o`000002ojjoiP?o[/G[1?n]`nX00on]`^Wo[<G/ojc5k002ojc5k0?o[<?[0_n[a>`4oj_2jaCooooo
00?o0000ooooooooool07_ooool001_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`00
0?oooooo`lCK00Go`lCK0oo2`MT00onn_]Wo_;SFokbheP04okbheP04okVbd_nbZm7o/Z_Aok:[d@Co
[jC=0_n/W/P2ojBFa`CoXI330onORkl4oif7^`CoVh>i0onIP;H2oiQm]003oiEn^?nDO;KoU7bf00;o
U7bf1?nDNkD3oi=j]0CoTgVc0onBN;<4oi9h/PCoTWNa0onBM[02oi9e[`03oi>:aonDS/[oU8k:00;o
U8k:1?nETLd4oiNDc`?oVIOA0onKV]83o`000003oifLdomego7oMMoa00?oTfVP0onBIih4oi5VW0?o
TFFK1?n@I9X4oi1SVP?oT6>I1on@HYT01?n@HiWoUFbQoiE/XOnEK:44oiM]X@CoV6jQ0onIKj45oiY`
X@CoVg6R0on/S[L5ojN6/0?oY7n[1OnRNjP00onPN:Ko_LWTokg9i002okg9i0Co^kCC00?o^:K7ojB0
[?nROZ`00_nYR[@5ojR8/PCoYhJb00?oYHJcok>M`_ncWL800_ncWL83ok2G_PCo[I>l00?o/jK;ok6P
aonaX<L00onaX<L3ojjLa@03okNjg?nd/mOo];?G00?o];?G0onb[]@00onc_^;o/KWOok6ig`03ok6i
g`;o/;KM0onaaNT3ok32i`03ojk8kOl0003o[/G[00Co[/G[0_n]`nX2ojc6k@Go[<G/00?o[<?[oj_4
k?n[a>`00_n[a>`2oj_2j`;oZ/;[5?ooool00ol0003oooooooooo`0Mooooo`006oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01_o3a=/01?o2`MWo_[kIokjnfOnn_]T4
okbheP03okJbe_nbZm7o/Z_A00;o/Z_A0on_Y<d00onWWLcoY9K7ojBFa`03ojBFa`?oXI331?nORkl3
oif7^`;oVh>i0_nFPk`3oiF0^PCoUGjh0onDO;H4oiAk]@?oTgZd1?nCNK<4oi9h/`?oTWRb1?nBMk42
oi9f/003oi:7aOnCR/OoTh[700;oTh[71?nDS/X3oiFAc@CoUiC?0onIUm43o`0000?oNmog0onCK:83
oi=YX0?oTVNN1?nAIY`3oi5UV`CoT6BJ1?n@HiX3oi1SV@KoT6:I00?oU6^QoiE/XOnEK:400_nEK:44
oiM]X@CoV6jQ0onIKj45oiY`X@;oVg6R00?o/9[1ojb>]on/S[L00on/S[L4ojN6/0CoY7n[0onRNjP2
okKUmPGo_LWT0_nk]=<2ojB0[003ojZ=]onYR[CoZHZd00;oZHZd1?nXR;84ojN6/PGo/ig21?n`Ukh0
0on]Tkco/jK;ok>Vb`02ok>Vb`Co/J3700?o[Yc5okNjg?ng^]`00_ng^]`4okBce`03ok:^e?nc_^;o
/kkR00;o/kkR0ona^Ml2ok7:k@Go/LGY00Go/<;Wojk8kOn^b>go0000ojk8k@02ojk5j`;o[<S^1On/
a^d2ojc5k0;oZlG/1?n[a>`00onZ`ncoZ/;[oj[2j`03oj[2ja?ooooo0_l0000Nooooo`006oooool0
1Ol@413ooooooooooooooooo410@00Kooooo0_l00002ooooo`Co`lCK00?o`LCLokjnfOnn_]T00onn
_]T00onl^=Ko][;FokJbeP02okJbePCo/Z_A00Co[jC=ojNMc?nWWLcoYig<1?nTU/L3oj6@``CoWh^o
0_nMQk/00onGQ[ooUX>loiJ3_002oiJ3_0CoUH2j0onEO[P4oiAl]P?oU7^e1?nCN[@3oi=i/`CoTWRc
0_nBN;800onCQ<3oTXG2oi:5`P02oi:5`PCoTXO50onCR/L4oiB>bPCoUI7=0onGU<l3o`0000;oP]kl
0onDKZD4oi=/XP?oTfVP0onBIih4oi5VW0CoTFFK0on@I9X4oi1SVP?oT6>I0_n@HYT2oi=[X@?oU6^Q
1?nEK:44oiM]X@CoV6jQ0onIKj45oiY`X@04oi]aX_n`V/7o/9[1ok2J`@Co[8jg1?nWQ[04ojAoZ`03
oj9kZ?nfiOKo]^Gf00?o]^Gf0_nmbN@3ojF1[@;oY82/0_nZSKL4ojV:]0GoZ8Rb0_nWQ[82okJTa`Co
/ig20on`Ukh00one[M7o/jK;ok>Vb`03ok>Vb`?o/J3700?o^<?RokNjg?ng^]`01?ng^]`2okBce`;o
]<CW1Onc_^800ona^Moo/L[]ok7:k@02ok7:k@;o/LGY0_n]bnl4ojk8k@03o`000?n/b>ko[<S^00?o
[<S^0_n/a^d2oj_6kPGoZlG/00?oZlC/oj[3k?nZ`n`00_nZ`n`3oj[2j`03ojW1jooooooooooo013o
oooo00?o0000ooooool000007_ooool001_ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00;ooooo00?o`lCKol74g?o1a=`00_o1a=`3okjnf@;o^K_K1Onf/]H2ok:[d@03
ojZUd_nWWLcoYig<00?oYig<0onTU/L4oj6@``;oWh^o00?oV8[3oiN6_onGQ[l00_nGQ[l4oiJ3_0?o
UH2j0onEO[P4oiAl]PCoU7^e0onCN[@3oi=i/`;oTWRc0_nCPkl4oi>4`0CoTXG20onBQlD3oi>:a`Go
U8k:0_nETLd2ohoEo`;o00000_n9fol3oiEaY`?oU6jU1?nCK:83oi=YX0CoTVNN0onAIY`4oi5UV`?o
T6BJ1?n@HiX2oi1SV@03oi9ZXOnCJj7oTf^Q00;oTf^Q0onDJj44oiE/X@CoUffQ1?nHKZ44oiU_X@?o
VW2Q00?o]JW=ok2J`On`V/400_n`V/44ojb>]`GoYhJ`0_nTOj/3ohCZi0;o]^Gf0onVPjl4ojF1[@03
ojB0[?nZSKOoZXfg00;oZXfg0onYR[@5ojR8/P04ojN6/_nfY<Oo]ZC7okJTa`Go/ig200Co/9NnokF]
dOne[M7o]JgA1OncY//01?naX<Oo^<?RokS3h_nh`n84okNjg003ok;<kOnda>Oo]<CW00?o]<CW0_nc
_^82ojo>l0Co/L[]0_n/c_84ojg;k`05ojk8kOn[b_3oZl[`oj_:l?l000000_n/b>h3oj[7k`CoZlK^
0_n[aN`3oj[4k@CoZ/?/00?oZ/;[ojW1jonY`N/00_nY`N/Dooooo`03o`000?oooooooooo01_ooooo
000Kooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`Go`LCL
00?o_[kIokVkfoni^m/00_ni^m/3okJbeP03ojf]f?nZYM;oZZGB00;oZZGB1?nWWL`4ojBFa`;oXI33
00?oVXo7oiR:`onHR/<00_nHR/<3oiN6_`CoUX>l0onEP;X4oiEn^0?oU7bf1?nDNkD2oi=j]003oiB4
_onCPkooTh>o00KoTh>o0onCQ<04oi:5`P?oTXO51?nCR/L2oiB>bP?oU<kl0ol000001?n?eOooUWB[
oiIdZonFM:/3oiEaY`?oU6jU1?nCK:84oi=YX0?oTVNN0onAIY`4oi5UV`?oT6BJ0_n@HiX2oi1YX@?o
TVZQ1?nCJj44oiA[X@?oUFbQ1?nGKJ44oiQ^X@CoVFnQ0_nJL:43okFYc@?o/9[11On/S[L4ojN6/004
ojAoZon4j^CoQ>[TohCZi0;oYXFa1OnVPjl2ojF1[@03oj^A^_nZSKOoZXfg00?oZXfg1?nYR[@3ojR8
/P03okR]confY<Oo]ZC700;o]ZC71?ncWL800onf]mWo]JgAokF]d@02okF]d@Co/jK;00?o]lg[okS3
h_nh`n800onh`n800ong^]co//c]ok;<k@02ok;<k@;o]<CW0on/do@4ojo>l003ok7:kOn/c_;o[<kb
00?o[<kb0_n]bnl2ojW;l@?oZl[`00?o0000ojW8l?nZanl01?nZanl2oj_6kP;oZLC]1OnZa>d2oj[3
k0;oZL;/0onY`N/00onX`N_oooooooooo`0Cooooo`03o`000?oooooooooo01[ooooo000Kooooo`05
oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`05ooooo`?o`LCL0_nka>45okVk
f`04okJbe_n][MSo[JgHojf]f0?oZZGB1OnWWL`2ojBFa`03oi^Dc?nJSlOoVXo700;oVXo70onHR/<3
oiN6_`CoUX>l1?nEP;X3oiEn^0?oU7bf0_nDNkD2oiB5`0CoU8Bo1onCPkl3oi>4`0CoTXG21?nBQlD2
oi>:a`?oUlKg0ol000000onDc_coSmGooiIg[P04oiIdZ`CoUG6W0onDKZD3oi=/XPCoTfVP0onBIih3
oi5VW0CoTFFK0_n@I9X00on?J:7oT6VQoi1YX@02oi1YX@?oTVZQ1?nCJj44oiA[X@CoUFbQ0onGKJ45
oiQ^X@?oVFnQ00?oVW2QokFYcOneZLd00_neZLd4ok2J`@Co[8jg0_nWQ[05ojJ7/`?oYXFa1OnVPjl0
1?nUPJgoZi6joj^A^_n[TKX4ojZ=]`CoZHZd00?oZ8RbokR]conh[Ll00_nh[Ll4okJTa`03ok>M`_nf
]mWo][OI00;o][OI1?ne[M400oncY/_o]lg[okO=j`02okO=j`;o^<?R0on_do<3ok;<k@;oYmKh1On/
do@2ojo>l0?oZM3d0_n/c_82ojS<l`GoZL_a00GoZl[`ojW8l?nYb?3o0000ojW8l002oj[7k`;oZ<G^
1OnYa>d2oj[4k@;oZL?/1OnY`^`01?nY`N_oZ<7[ojS1jonX`N/Dooooo`03o`000?oooooooooo01[o
oooo000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000Oooooo00?o`LCLok_4hOnk
a>400_nka>42okVkf`;o/;OO1?n][MP4ojZUdP;oYig<0_nMVm44oi^Dc0?oVXo70onHR/<4oiN6_`Co
UX>l0onEP;X2oiEn^004oi>7a?nCQ/;oThK2oi>6`PGoU8G00onDQ;l7oi>3_`CoThC01?nBQL82oi:7
a@;oVKka00GoUlKgo`000?l0003o0000oiO6m`02oiC>o004oiMj/OnFMjkoUWN^oiIg[P?oUWB[1?nE
LJL3oiA^Y@?oTfbR1?nCJJ03oi9WWP;oTFJL00?oSFNRohiWXOn>Ij400_n>Ij43ohmXX@CoT6VQ1?nB
JZ43oi=[X@CoU6^Q1?nEK:44oiM]X@CoV6jQ0_nIKj400onj_Mco]JW=okFYc@03okFYc@Co/9[10_n/
S[L00onVRkSoYXVfojJ9]P02ojJ9]PCoYXNc1?nVQK43ojJ3[`03ojbE_on[TK[oZi6j00;oZi6j1OnZ
SKL2ojV:]003okVhfOnh[Loo^:g?00?o^:g?0onfY<L00onf`^?o][OIokJgf@04okJgf@;o]JgA0_nb
e_<3okO=j`;oZ=Wi1On_do<00onbc>goYmKhojOFn002ojOFn0;o[=?d0onVd_L2ojW@m0;oYLcd1OnX
c?<2ojW;l@;oZ<Wa1?nYb?000ol0003oZ<G_ojS5kP03ojS5kP;oZLC]0_nX`nd5ojW3k0;oZL;/0_nX
`N`5ojS1jaCooooo00?o0000ooooooooool06Oooool001_ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`03o`000?oooooooooo00Oooooo0onka>42ok;2iPCo/;OO1?n][MP2ojZUdP03oinReonM
Vm7oWI_A00?oWI_A0onKU<`3oiZ?a`CoV8[30onGQ[l4oiJ3_0;oUH2j00?oTXW6oi>7a?nCQl@00_nC
Ql@3oi>6`PCoU8G00onDQ;l8oi>3_`?oThC00_nBQL83oiZgk004oiVnlOl0003o0000o`0000;oUlKg
0_nIOK<3oiMj/@?oUWN^0onFM:/4oiEaY`?oU6jU0_nCK:800on;IZ?oS6JRohaVXP02ohaVXP?oS6NR
0on=Ij84ohiWX@?oSfRQ1?n@JJ44oi9ZX@?oTf^Q1?nDJj44oiE/X@CoUffQ1?nHKZ401?nIKj7o^[gL
okZmg?nj_M`5okFYc@;o/9[100CoW7RYojJ;^?nVRkSoYX^h1?nVRKH5ojJ7/`?oYXFa00?oYX>_ojbE
_on/UKl00_n/UKl3oj^A^PGoZXfg00CoZHZdokVhfOni^=Wo^KSI1Onh[Ll01?nfY<Oo]/;SokK2honf
`^<4okJgf@03ojWMn_nbe_?o/]Kc00?o/]Kc00?o]lg[ojSInOnXfOT00_nXfOT2ojoCl`?oX]Oj0_nW
e_P3oj;Bn@?oY];g0_nTc?D4ojG<m0;oZ<cc0onVbO84ojS9l@06ojW8l?nXaNooZ<G_ojS5kol0003o
Z<G_0_nXaNh6ojS3k@;oZL?/0onX`^`4ojS1k0CoZ<7[5?ooool00ol0003oooooooooo`0Iooooo`00
9Oooool00ol0003oooooooooo`08ooooo`03ok_4hOnb`^Ko//;V00;o//;V1?n`]ml2ojf]f003oj:[
gOnOX]OoWj;G00;oWj;G1?nMVm43oi^Dc0CoVXo70onHR/<2oiN6_`03oi6>cOnBS<WoTXc900;oTXc9
1?nBRLH3oi>7a0?oThK21?nDQL04oiB4_`OoTh>o0_nCQ<02oiZbj0;oV[O/0ol00002oiVnl@03oi^1
]_nIOK?oVGfc00;oVGfc0_nGN[401?n>K:SoS6ZWohaZYon<JZL3oh]YY@CoRfRU0on;Ij@3oh]VX`Co
S6JR0on<Ij83oheWXPCoSVNQ1?n?J:43oi1YX@CoTVZQ1?nCJj43oiA[X@CoUFbQ1?nGKJ42oiQ^X@?o
^]?]1?nj_M`2okFYc@04oiYfZOnKMjWoVgNYojF<^`GoYX^h0onVRKH5ojJ7/`;oYXFa00?o[9[4ojbE
_on/UKl00on/UKl4oj^A^P?oZXfg00?o^<?SokVhfOni^=T00oni^=T2okR]c`;o/lk^1Onf`^<00onf
]mWoZMgjojWMnP02ojWMnP;o/]Kc1?nOgO`2ojSIn@?oWMOl0_nReoX2oioBnPGoX];i00?oY];gojC<
mOnTc?D00_nTc?D2ojG<m0;oYLSb1OnVbO82ojS9l@;oYlG_0onXaNl00ol0003oYl?^ojS3k@06ojS3
k@OoZ<;/0_nX`N`6ojS1ja;ooooo00?o0000ooooool000006_ooool002Gooooo00?o0000oooooooo
ool02_ooool4ok;2iP;o/;OO00?oXkCUoj:[gOnRZmd00_nRZmd4oinRe`CoWI_A0onKU<`2oiZ?a`04
oi6Ee?nATM3oTI7@oi6Ad0CoTHk=1?nBS<T3oi:9aP?oThO40onCQ/85oiB5`0?oU8Bo0_nCPkl2oiR[
i0CoVJkU0_nJ/^P3o`000003oiZgk?nNQKSoWXFh00;oVh6f00?oTW:[oi1_ZOn@KjT00_n@KjT3ohi/
Z0?oS6ZW0on;JJD4oh]XY@?oRfNT0on;IZ<4ohaVXP?oS6NR1?n=Ij83ohiWX@CoSfRQ0on@JJ44oi9Z
X@CoTf^Q0onDJj44oiE/X@?oUffQ0_nbi_P5ok[Ck@;o^[gL1?nJMZT01?nKMjWoYHbkojF<^onUS;/4
ojJ;^0CoYXVf0onVQk<00on/WlWo[9[4ojbJa002ojbJa0Co[9Fo1?n[TKX00onZSKOo^<?SokS3h`02
okS3h`?o^KSI0_n/fOL4ok?>kP;o]/;S1?nNhOd2ojWMnP?oUmkn0_nOgO`3oiWFo@;oWMOl0_nNdOX5
oioBnP;oX];i0onRboD2ojC<m@;oY<Sb1OnUb?82ojK9lP;oY/G_1OnWaNl01OnXaNooYl?^ojO3k_l0
003oYl?^00;oZ<?]0_nW`^`7ojS2k0;oZ<7/1onX`N/2ojS0jaCooooo00?o0000ooooooooool05ooo
ool002Gooooo0_l0000<ooooo`;o//;V0_nT_nd3oj>di@CoXZ_M1?nOX]L2oifKd@04oi:Og?nBV]So
TY[Hoi:Jf0CoTIGD0onATM03oi6>c@CoTXc90onBRLH4oi>7a0?oThK21?nDQL02oiB4_`03oiFXhonH
ZnCoV:_T00?oV:_T0onI[^D2o`000003oiZbj?nRRk_oXX^k00;oWXFh00CoUGJ^oi9bZonBLZ_oTW:[
1?n@KjT3ohi/Z0CoS6ZW0on;JJD3oh]XY@?oRfNT1?n;IZ<3ohaVXPCoS6NR0on=Ij83ohiWX@CoSfRQ
1?n@JJ43oi9ZX@CoTf^Q1?nDJj43oiE/X@03oiM]XOnbi_So/^Kh00?o/^Kh0_njdnd4oiUeZ@?oVWJY
00?oY8fmojF<^onUS;/00_nUS;/4ojJ;^0CoYXVf00?oYXNcojbObOn/WlT00_n/WlT3ojbJa0Go[9Fo
0_n[TKX2okC?k@Co^<?S00?o^KSIojcImon/fOL00on/fOL2ok?>kP?oT^7n0_nNhOd3oi3MoP;oUmkn
1?nHe?d2oiWFo@;oWLoi1?nNdOX2oioBnPCoX/[d0_nRboD2ojC7lPCoY<Sb0_nUb?83ojK4k`CoY/G_
0_nWaNl6ojO3kP03o`000?nW`^coYl;/00?oYl;/0_nX`^`7ojS1k0;oZ<7[1onX`>/Cooooo`03o`00
0?oooooooooo01Oooooo000Tooooo`03o`000?oooooooooo00gooooo1?nT_nd3oj>di@;oXZ_M0_nC
ZnL3oi>Uh@CoTYoL0onBV]P3oi6Ee0?oTI7@0onAS/d5oi:<b@?oTXW60onCQl@2oi>6`P;oT:GS0onC
Y^<4oiFXh`CoV:_T0ol00002ojNA_P;oXX^k00CoUgZ`oiEf[_nEMZkoUGJ^1?nBLZ/3oi1_Z@?oSVbX
1?n<JZL3oh]YY@?oRfRU0on;Ij@4oh]VX`?oS6JR1?n<Ij83oheWXP?oSVNQ1?n?J:44oi1YX@?oTVZQ
1?nCJj44oiA[X@;oUFbQ0onPkOP2ok;Vn003oiMdZOnHM:WoV7BY00;oV7BY0onIMJT00onJMZWoY8fm
ojB=_@02ojB=_@?oYHbk1OnVRkP2ojJ9]P03ojbTcon/WlWo[9o900?o[9o90on/V/@4ojbE_`03ojkI
m_ndcngo]<o]00?o]<o]0_nh`n<3oj;Po0;o[=Wg1?n:god2oi;QoP?oSMcn0_n@gOh3oiSBo0;oV=Cm
0_nNcOP5oig?n@;oW]7j0onRb?@2oj;:m0;oY<Ga1OnTao82ojC8lP;oYLC_1OnVa>l2ojK5k`;oY/?^
1OnW`nh3ojO2k004o`000?nW`^coYl;/ojO2k0;oYl7/1_nX`N`3ojO0j`KoZ<3[0_nW`>/Dooooo`03
o`000?oooooooooo01Kooooo000Tooooo`03o`000?oooooooooo00kooooo0_nT_nd2oi:jlPCoTk;/
0onCZnL3oi>Uh@?oTYoL1?nBV]P3oi6Ee0?oTI7@0onAS/d2oi:<b@;oRJ;U0on;Xn@3ohfTi0GoT:GS
0onCY^<4oiFXh`?o000000?oZiS2ojNA__nWTKh00_nJOk@3oiMj/0CoUGJ^0onBLZ/3oi1_Z@?oSVbX
1?n<JZL3oh]YY@?oRfRU0on;Ij@4oh]VX`?oS6JR1?n<Ij83oheWXPCoSVNQ0on?J:44oi1YX@CoTVZQ
0onCJj44oiA[X@04oiE/XOnPkOSoX>ghoj3]n0CoUgBY1?nHM:T2oiUeZ@03oj>>__nTSKgoY8fm00?o
Y8fm1?nUS;/4ojJ;^004ojJ9]_n/Y<oo[:C?ojbTc`Co[9o91?n/V/@00on/UKoo[]WfojkImP02ojkI
mP;o]<o]1?nEhod2oj;Po0?oQMkm0_n:god3ohgKo`;oSMcn0onJdO/2oiSBo0?oWl_g1?nNcOP2oig?
n@?oX/Oc0_nRb?@3ojC4l0CoY<Ga0_nTao82ojG3kPGoYLC_0_nVa>l2ojK2k@GoY/?^0_nW`nh2ojO1
k0?oYl;/00?o0000ojO1k?nW`N`01?nW`N`2ojS1k0OoYl3[0_nX`>/6ojO0jaCooooo00?o0000oooo
ooooool05Oooool002Cooooo0ol0000?ooooo`CoT[[b1?nC/^`3oi>[i`?oTjGQ0onBWm`2oi:Jf004
ohFUjOn5XnSoQJ?XohFSj0CoQZ?W0on7X^H4ohVRi@?oRj?T0on=Y>@5oi2Uh`?oTjKS0ol000001?n`
WlOoZiS2oj^H`_nNQ;P4oiYo]0?oUgZ`1?nEMZh3oi9bZ`CoT6nY0on>K:P3ohaZY`?oRfVU1?n;J:D3
oh]WY0?oRfJS1?n<IZ83ohaWXP?oSFNR1?n>Ij43ohmXX@CoT6VQ1?nBJZ43oi=[X@;oU6^Q0_n;j_80
0onELZWoUW>YoiIcZ@02oiIcZ@?oUgBY0_nHM:T2oj6>_`CoXhjn1?nTSKd4ojF<^`;oYX^h0_n/ZM@4
ojbTc`Go[9o90_n/V/@3ojKPn`;o[]Wf0on8hoX2oiGSo@?oQ=gm0_n5g_d4ohoJo`;oSM_o0onLcoX2
oi[An`;oX<We1OnOboL2oik=n0?oXlKb0_nRao<2ojG3k`GoY<C`0_nTaO42ojG2kPCoYL?^0_nUa>l7
ojK2k@;oY/?^1onW`N`01?nW`^coYl7/ojO1k?l00003ojO1k0;oYl3/4_nW`>/Booooo`;o00002Ooo
ool4o`000003oa0@4?oooooooooo00Oooooo000Tooooo`03o`000?oooooooooo013ooooo1?nB^_82
oi>bk004ohBal_n4[O3oQ:g`ohB]l0CoQJ[]0on5Yn/3ohFUj@?oQJ?X1?n6XnL3ohNRiPCoRJ;U0on;
Xn@3ohfTi0;oT:GS00?o^:k@okBWc?l000000_l00003ok2Oa`04oj:;_?nNQ;SoWXBhoij4^0CoVWnd
0onGN[04oiEf[P?oTW:[1?n@KjT3ohi/Z0?oS6ZW0on;JJD4oh]XY@?oRfNT0on;IZ<4ohaVXP?oS6NR
0on=Ij84ohiWX@CoSfRQ0on@JJ44oi9ZX@;oTf^Q0_mni?45oiEbZ@?oUW>Y0_nGM:T00onOSL3oXHjo
oj6>_`03oj6>_`?oXhjn1OnTSKd2ojF<^`03oj^^fOn/ZMCo[:WD00?o[:WD1?n/Y<l2ojbOb@?oW>?m
0_nVh?/4ogoRm`;oR>?j00CoQ]gnoiGGo_nEeokoUMOn1?nBfOh2ohoJo`?oW/gh0_nLcoX3oj;8l`Co
X<We0_nOboL2ojC5l0CoXlKb0_nU`nh4ojG3k`;oY<C`0_nV`^d5ojG2kP;oYL?^0_nV`Nd7ojK2k@ko
Yl7/00?o0000ojO0k?nW`>`00onW`>`BojO0ja?ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`09ooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go
00001_ooool00ol0003oooooooooo`0Booooo`?oPkCe0on4/O83ohB]l0CoQJ[]0on5Yn/3ohFUj@?o
QJ?X1?n6XnL3ohNRiP;oRJ;U0om4`>`2oc6hf003ol;Ok_o3hNko^:k@00?o00001?ndYl`01?n`WlOo
XX^loj:;_?nRRk`3oij4^0CoVWnd0onGN[03oiEf[P?oTW:[1?n@KjT3ohi/Z0CoS6ZW0on;JJD3oh]X
Y@?oRfNT0on;IZ<4ohaVXPCoS6NR0on=Ij83ohiWX@CoSfRQ0on@JJ42oi9ZX@?oOn7h1?nDLZT4oiEb
Z@;oUW>Y00?oWH_0oin=`?nOSL000_nOSL04oj6>_`?oXhjn1OnTSKd01?nUS;_oZjkIoj^^fOn[[]T4
ojbYe0;o[:C?1?nCiO`2oicSo@?oNN3c0_moh_L2ohWMoP;oV=Km1OnEeoh2oi;IoP?oWl_f0_nNcOP2
oj?6lPGoX/Sc0_nPbOD2ojC4k`CoY<G`00?oXlKbojG3k_nU`nh00onU`nh2ojG3k`;oY/7]1?nV`^d2
ojG2kP;oY/7/1OnV`Nd2ojK2kA3oYl7/0_nW`>`00ol0003oYl3/ojO0k002ojO0k1?oYl3[5?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oo
oooooooo01?ooooo0on3]?D3ohBalP?oQ:g`0_n5Z^d2og>fnPCoL;Sk0om/^od4ofJnoP?oG/7l0_mC
`_P3oj7ckP?o`]o^0ol00004okR^d0;o]:O<00?oYY;1oj:;_?nRRk`00_nRRk`3oij4^0CoVWnd0onG
N[03oiEf[PCoTW:[0on@KjT3ohi/Z0CoS6ZW0on;JJD3oh]XY@?oRfNT1?n;IZ<3ohaVXPCoS6NR0on=
Ij83ohiWX@CoSfRQ0_n@JJ43ohOIo`04ogoQn?nCLZ[oTg:Zoi=bZP?oU7:Y0_nELZT2oi^8_`CoWH_0
0onOSL04oj6>_`CoXhjn0_nTSKd2ojZag@GoZjkI0_n/ZM@3ohcUnP;oTnGl0_mfgo83oi7LoP;oSMcn
0onKe?`4oiSFo@;oUMOn0onQb_D2oio;mP?oY<Ga1?nSa_82oj;8l`;oYL?_1OnTa>l2ojC5l0?oY/;^
0_nU`nh2ojK1k0GoY/7]0_nV`^d2ojO1k0CoY/7/0_nV`Nd9ojO1k0;oYl3/1onW`N`5ojO0k003o`00
0?nW`>coYl3/01GoYl3[4oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo
0009ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP06ooooo`03o`00
0?oooooooooo01Gooooo0omk/OH3ogRbm`CoM[Ch0omc]_X4og2hn`?oK;_m0_mV__h2odO4j0;oM^;W
0onXl?H3ol3MkP;o00000_nj]M@4okR^d003ojZJaOnVT/7oYY;100;oYY;10onRRk`3oij4^0CoVWnd
0onGN[04oiEf[P?oTW:[0on@KjT3ohi/Z0CoS6ZW0on;JJD3oh]XY@?oRfNT1?n;IZ<3ohaVXPCoS6NR
0on=Ij83ohiWX@;oSfRQ1?n>a_X2ohOIo`03oi=bZonCLZ[oTg:Z00;oTg:Z0_nDLZT00onHQKgoVhRo
oi^8_`02oi^8_`CoWH_00onOSL05oj6>_`;oXhjn00?oZK?PojZagOnZ/Md00onZ/Md3oj^^f@?oQ^Ch
0_n<iOX2ogGOl@?oU=cn0_nAg?h2oigCnPGoVmCl0_nHe_d3oj?9m0;oXL[e0_nUa?05ojC5l@;oXlKb
0_nV`^h4ojG3k`;oY<C_0_nV`Nd4ojK2kP;oYl7/1?nV`N`2ojK1k@;oYl3/1OnW`N`2ojK1k0;oYl3/
1onW`N`6ojO0k0;oYl7/0_nW`>/7ojO0k003ojO0jol0003oYl3[01KoYl3[4oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP05ooooo`?o00005_ooool3og^amP?oN;;g0_mf]?P3ogFmo@CoK/;n
0omTa_d2oeO7m`;oC/cN1?n]jOT00onXl?Ko`=g^o`000002o`000003okbjf?nj]MCo^[GD00;o^[GD
00?o^:k@ojZJaOnZV/D00_nZV/D3ojJB`@CoXX^l0onNQ;P3oiYo]0?oUgZ`1?nEMZh2oi9bZ`04oha/
Z?n;JJKoRfVVoh]YYP?oRFRV1?n9IjH3ohQXY`?oR6VY0on8KJh4oh]VX`?oS6JR0_n<Ij82ohb7b0?o
SiSH1On@[^/2ohk6nP;oTW:/0onCLZ/2oi=bZP;oUH6k1?nHQKd4oi^8_`?oWH_01?nOSL02oj6>_`;o
Z;CR1?nY/n05ojZag@03oj^^fOn6i?SoQ^Ch00;oM^3a0onGfoh2oiCLoP?oWm;i1?nMdoX2oi_Do0?o
Y<Sb0_nSbO@3ojG4k`CoYLC`0_nTaO42ojK2k@GoY/;^0_nU`nl6ojK1k@03ojK2k_nW`NcoYl7/00?o
Yl7/0_nV`N`6ojO0k0;oYl7/1onW`>`2ojO1k0;oYl3[1onW`>`6ojO0j`;oYl3/1_nW`>/00ol0003o
Yl3[ojO0j`0EojO0ja7ooooo0ol00007ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo01So
oooo0omo/oD4ogZhn@?oMKgm0_m^`_h3ogCBoP;oI=?d0_n7iOP3ojgYn@05okkIkOl0003o0000o`00
0?o0gNh01?nl^]P2okZee003ojjQb_nZV/GoZY[500?oZY[50onVT/44oj:;_0?oWXBh0_nJOk@01?nA
M[7oSg:^ohmb[_n?LZh4ohe^Z`?oS6bX0on;JJH3ohUXYPCoRFNV0on8J:L3ohQYZ@?oR6f^1?n9L[@3
ohYk_0GoS8O80on?V=P3oi2^j`;oSWJc0on@NKH3oi=m^@GoUH6k0onHQKd4oi^8_`CoWH_00_nOSL00
0onW]>;oZ;CRojRdhP03ojRdhPCoZK?P0_nZ/Md2oh?TmP;oN>7a0onJfod2oiOKoP;oXM7h1OnOd_T2
oigCnP?oY<Ob0_nTb?82ojK3kPGoYLC_0_nUa?06ojK2k@;oY/;^0_nW`N`7ojK1k@KoYl7/2?nW`>`2
ojO0j`KoYl3/1onW`>/2ojO0k1;oYl3[00?o0000ojO0jonW`>/05OnW`>/>ooooo`Co000000?ooooo
o`000?ooool01_ooool00ol0003oooooooooo`09ooooo`002Oooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`?oOk?e0_mj^?T3
ohO1nP?oP<_o0_mdd_h3oi;OoP;o[^3h00Co_=?/o`000?l0003o00000_nnfNd2okbnf`?o_;[H00?o
/JS?ojjQb_n^XLX00_n^XLX4ojZJa@CoYY;10_nRRk`01?nGP;WoTg^eoi=k]OnCNkD3oi5f/@?oSg:^
1?n=KZ/3oha/Z0CoRfVV0on9J:H3ohUWYPCoR6RW0on8JJT2ohQ][PGoRG:d0on:Nk`4ohb7b0CoSiSH
00CoT:k[ohif/on>M[?oSWJc1?n@NKH3oi=m^@CoUH6k0onHQKd4oi^8_`;oWH_00_nU/^44ojNdhPGo
Z;CR0_nY/n000on2i?GoNn;bog_RlP04oicKo@;oV]_m0_nRd?P4oj7An0;oWm;i0onUa_42ojC7lPOo
Y/?^0_nUa>l2ojO1k@OoY/;]0_nW`>`4ojO1k0;oY/7]0onW`>`5ojO1k0KoYl3/1onW`>/2ojO0k1oo
Yl3[00?o0000ojO0jonW`>/05OnW`>/:ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`03
oeEEEOmVIVKo000000_ooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@00Gooooo0_l0000Kooooo`CoS;Sc0_n7`OX2oic9m`CoVMCl0on^eO@3o`00
00?o_=?/00?o_]W]okbnfonl_]/00_nl_]/01?nl^]So/JS?ok6XconaZ<l3ojjQbPGoZY[50_nVT/40
1?nJQ[goUh2ioiN0^OnGP;T3oi=k]@CoTGJa0on?LZh3ohe^Z`?oS6bX1?n;JJH3ohUXYP?oRFNV1?n8
J:L3ohQYZ@?oR6f^1?n9L[@3ohYk_0GoS8O80_n?V=P2ohac/@CoSWJc0on@NKH3oi=m^@CoUH6k1?nH
QKd2oi^8_`03ojB^gonU/^7oYK;Q00?oYK;Q1?nW]>82ojRdhP;oP^Cd0_mmho83oigKo@;oW=_m0_nS
d?L5oj;@n0;oXM7h0onVa_02ojG6l@;oY/;]1onV`nh2ojO1k0CoYl7]0_nV`^d7ojO0k0;oYl7/1onW
`>`2ojO1k0;oYl3[0onW`>`/ojO0j`03o`000?nW`>_oYl3[01CoYl3[1_ooool4o`0000Sooooo00?o
0000ooooooooool04Oooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`0Kooooo`;oS;Sc0_nN_Nl4oic9m`03oiWD
o?n^eOCo[]Gd00?o000000?o^/kYokcCk?nldn`00_nldn`2okc1g@?o_;kK00?o]:oCok6XconaZ<l0
0_naZ<l4ojjQbP;oZY[50_nNSL44oiZ6_@?oUh2i0onCNkD3oi5f/@?oSg:^0on=KZ/3oha/Z0CoRfVV
0on9J:H3ohUWYPCoR6RW0on8JJT3ohQ][PCoRG:d1?n:Nk`2ohb7b0?oRg6_1?n<Lk43ohif/`?oT7Vf
0onCOKT5oiF1^`;oV8Fm00?oXZ[LojB^gonT[]l00_nT[]l5ojFbh@;oYkCR0_n3iOD2oh3Tl`;oWmcl
0onMfod2ojC@m`CoXm3g0_nRd?P6ojK6l0;oYl;]1?nV`^d2ojK3kPOoYl7/0_nW`Nd8ojO0k0?oYl3[
1_nW`>`7ojO0j`03ojO0k?nW`>_oYl3[02_oYl3[00?o0000ojO0jonW`>/05OnW`>/2ooooo`?o0000
3?ooool00ol0003oooooooooo`0Aooooo`008_ooool00ol0003oooooooooo`0Mooooo`CoW[g_0_nL
bOL01On^bnoo0000o`000?l0003o[]Gd00Co^/kY00?o_=?/okc1gOnl`Md00onl`Md01?nl_]_o]:oC
okB_dond[m<4ok6Xc`;o[Z7:00?oXiC6oij=`OnNSL400_nNSL44oiZ6_@?oUh2i0onCNkD3oi5f/@?o
Sg:^1?n=KZ/3oha/Z0?oRfVV0on9J:H4ohUWYP?oR6RW0on8JJT3ohQ][PGoRG:d0_n:Nk`3oh]_[P?o
Rg6_1?n<Lk43ohif/`CoT7Vf0onCOKT2oiF1^`;oX:CH1?nRZ]`4ojB^g`;oYK;Q0_n5i_H4oh;Ul`03
oh3TlonOg?coWmcl00;oWmcl00?oWM_mojC@monTd?L00_nTd?L2oj?@m`;oY/G`1_nVa_04ojO2k@;o
Y/;]2?nW`N`3ojO0j`KoYl3/1onW`>/2ojO0k3WoYl3[00?o0000ojO0jonW`>/05OnW`>/00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo01kooooo
0_nN_Nl2ojc1j@;o00000_n^bnl2okS8i`?o^/kY0onl`]l3okc1g@03okNeeond[m?o]:oC00?o]:oC
0_naZ<l00onWVl[oXiC6oj>DaP02oj>DaPCoWXg10onJQ[d3oiN0^@?oTg^e0onAM[43ohmb[PCoSFj[
0on<K:P3oh]YYP?oRFRV1?n9IjH3ohQXY`?oR6VY1?n8KJh4ohUb]003ohYk_?n<L:koRfn^00;oRfn^
0on;LJl4ohac/@CoSWJc0on@NKH2oi=m^@03oifMdonPY=SoX:CH00?oX:CH1?nRZ]`2ojB^g`;oR>Kg
0on5i_<2oh;Ul`?oX=gl0_nOg?`4ojG@mP;oY=3g0_nWaNl4ojK5l0;oY/K`1OnW`^d9ojO1k0OoYl3[
0_nW`>a6ojO0j`03o`000?nW`>_oYl3[01GoYl3[4?ooool00ol0003oooooooooo`0@ooooo`008_oo
ool2o`00023ooooo0ol00002ojc1j@03ojk;konhb>Oo^<SW00;o^<SW00?o^/kYokc2gonl`]l00onl
`]l01?nl`Mgo]kGGokNeeong]ML3okB_d`03oj^SconWVl[oYi_:00;oYi_:0onSU<H4oij=`@CoVXJm
0onGP;T3oi=k]@?oTGJa0on?LZh3ohe^Z`?oS6bX1?n;JJH3ohUXYP?oRFNV1?n8J:L3ohQYZ@?oR6f^
0_n9L[@01?n>LZooS72^oha`[_n<L:h4oh]_[P?oRg6_0on<Lk44ohif/`;oT7Vf00?oVYK>oifMdonM
WM<00_nMWM<5oj2Tf0;oXZ[L0on<i_P01?n8i_OoQNKcohGVlon5i_<3oj7No0;oX=gl0onVdOH2ojG@
mP;oYlK_1OnWaNl2ojK5l0GoYl;]2OnW`NaCojO0j`03o`000?nW`>_oYl3[01CoYl3[4?ooool00ol0
003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0Looooo`?o000000?oooooojc1jOn/
`NT01?nf`n@2okS8i`;o^l?P1?nl`]l2okRjfPCo]kGG00Co]:oCoj^Scon[XlooZj??0onWVlX3oj>D
aPCoWXg11?nJQ[d3oiN0^@?oTg^e0onAM[43ohmb[P?oSFj[0on<K:P4oh]YYP?oRFRV0on9IjH4ohQX
Y`?oR6VY0_n8KJh01?mJe=[oSW:_ohib[on>LZl3oha`[PCoRfn^0on;LJl2ohac/@03oiB8a?nGSlWo
Uho900;oUho91?nJU/h3oifMd`CoX:CH0on?i_X2ohcVn003ohOWlonRgocoX]ol00;oX]ol0_nQg_`3
ojKAm`;oY]7f1_nWa^l2ojO5k`SoYl;]1_nW`NaGojO0j`03o`000?nW`>_oYl3[01GoYl3[3oooool0
0ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0Iooooo`?o00001_ooool3okK3
i0;o^l?Q1?nk`n000onl`]oo^;[JokRjfP03okRjfP;o]kGG00?o[Z_Doj^Scon[Xll00_n[Xll3ojNK
bPCoXiC60_nNSL400onERlKoT8G3oi25``02oi25``?oS8310on8O;l3ohEj_`?oPgVo0on2N/43oha/
Z0CoRfVV0on9J:H3ohUWYP;oR6RW1?n@^_<2ohOGo`;oRgFe0on;M[H3ohei^0CoSWbk0onAP[l4oiB8
a0CoUho90onJU/h4oifMd`04oj2Tf?n?i_[oSnKjohoVnP;oRNSc0onShO`2oj;Oo0CoYm?g0_nVdOL8
ojO6k`WoYl;]1OnW`NaKojO0j`03o`000?nW`>_oYl3[01CoYl3[3oooool00ol0003oooooooooo`0@
ooooo`008_ooool00ol0003oooooooooo`0Fooooo`?o00002_ooool00onf`nCo^l?Qok_3h@02ok_3
h@;o^l?P0onj_mh3okRjfP03ok:bfOn^ZmCo[Z_D00;o[Z_D1?n[Xll3ojNKbP;oXiC600?oVI7:oiF;
a_nERlH00_nERlH3oi25``CoS8310on8O;l3ohEj_`?oPgVo0_n2N/43oh9ma@CoQ8C;0on7Sm@4ohbQ
hPCoT;[c0_n=MkH3oh]e]@CoRgJf0on=NKP4ohil^`?oTH:o0onDR<@4oiN?b@CoVYK>0_nMWM<2oi?U
o0;oRnWd0onSh_`2oj?Qo0?oYmCg0_nWdoL2ojS7l0OoYlK_2?nW`^d6ojO1k5ooYl3[00?o0000ojO0
jonW`>/05?nW`>/>ooooo`03o`000?oooooooooo013ooooo000Rooooo`;o00005?ooool3o`0000ko
oooo0onk`n400onj`n7o^[oNokZogP04okZogP04okRjf_nb/]Wo/[;Iok:bf@Co[Z_D0_n[Xll01?nR
Wm;oWIS>oifHc_nMV<h4oiVAbP?oUH_61?n@QL<3ohb0`@?oR7bo0on5N[l3oh=i_`?oPW[10on2OLD4
ohB4b`?oQhoD1?n<XN800on@^_?oT7Zhoheg]P03oheg]P?oRgFe0on;M[H3ohei^0CoSWbk0onAP[l3
oiB8a0GoUho90_nJU/h01?nGh_goS^WfohkYm_n>jOH3ojCTo0;oXn;l0onXe_P2ojODm`KoZ<O`0_nW
a^l9ojO2k@OoYl7/H_nW`>/00ol0003oYl3[ojO0j`0DojO0j`gooooo00?o0000ooooooooool04?oo
ool0027ooooo0_l0000Booooo`?o00004_ooool01?nk`n7o^/?Qok[3hOnj`n44okZogP03okBkg_nb
/]Wo/[;I00?o/[;I0_n^Zm@00onUYmSoXYoBoj:OdP02oj:OdP?oWIS>0onITLX3oiF;aPCoT8G30on<
P<43ohQl_`?oQGZo0on3NKl3oh9j`@?oPWg51?n4Q</4ohN?e0;oS:7R00CoUH6koi1j^?n@N[SoT7Zh
0on=MkH3oh]e]@?oRgJf0on=NKP4ohil^`?oTH:o1?nDR<@2oiN?b@;oVMcm0onAjOP01?n>jOKoY>Cl
ojCTo?nTi?`3ojSHn0?oZ=Kh0_nXb?06ojS7l0;oZ<;]1onW`^d8ojO1k6CoYl3[00?o0000ojO0jonW
`>/05OnW`>/<ooooo`03o`000?oooooooooo013ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00oo
oooo0_l0000Fooooo`Co^/?Q00?o^[oNokBkg_nd^mh00_nd^mh3ok:bf@03ojV`gOnUYmSoYJOH00;o
YJOH0onRWm83oifHcPCoVI7:0onERlH3oi25``CoS8310on8O;l3ohEj_`?oPgVo0_n2N/43oh9ma@Go
Q8C;0_n7Sm@4oiF1^`?oT7Zh0on=MkH3oh]e]@CoRgJf0on=NKP4ohil^`?oTH:o0_nDR<@3oi_Cn`04
oiWLoOnAjOSoTNWhoi7Yn0;oY>Kk0_nXf_T5ojSHn003ojSFn?nXb?3oZ<S`00;oZ<S`0_nXao02ojS3
k@CoZ<;]0_nW`^d9ojO1k6SoYl3[00?o0000ojO0jonW`>/05?nW`>/=ooooo`03o`000?oooooooooo
00oooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0<ooooo`?o00006Oooool2ok[3h@?o]/?T1?nd^mh01?nb
/]WoZK3MojV`gOnY/=d3ojFWf0CoXYoB0onMV<h2oiVAbP04oi2Hf?n<UMOoS9GGohbEe`?oQi?H1?n3
U=`3og^Ji0?oKZKc0on3NKl3oh9j`@?oPWg50_n4Q</00onTUlSoVh_1oi^;`@02oi^;`@?oUH6k0on@
N[P4oheg]P?oRgFe0on;M[H3ohei^0;oSWbk0onG^Nl4oi[7m`;oVm?k0_nFj?X3oj?Wn`03ojCVnonX
f_WoZ=[i00;oZ=[i0_nXf?P4ojW9l@;oZ<S`1_nX`nd2ojS2k@SoYl7/KOnW`>/00ol0003oYl3[ojO0
j`0DojO0j`cooooo00?o0000ooooooooool03oooool000Oooooo00Go410@oooooooooooooooooa0@
400;ooooo`Go00001Oooool2o`0000[ooooo0ol0000Mooooo`Go]/?T0_nd^mh2oj^hh`CoZK3M0onU
YmP2oj:OdP04oiRSgOnDWM[oU9gJoiBMfPCoT9SH0on<UML3ohNCf0CoPiCL0omkV^@4ofjVl`04od>b
mone]=So]KCHokFdf0Co[:G@0onTUlP3oi^;`@?oUH6k0on@N[P4oheg]P?oRgFe0_n;M[H00on?Vm_o
Tj[Uoi>Zi@02oi>Zi@GoUkW_0_nJaoL2oiWUo0?oXnSk0_nSio/3ojSMnP;oZ=[i0onYbo42ojW9l@;o
Z<C]1onX`nd8ojO1k73oYl3[00?o0000ojO0jonW`>/05OnW`>/;ooooo`03o`000?oooooooooo00oo
oooo0007ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00006oooo
o`03o`000?oooooooooo00Kooooo0ol0000Qooooo`;o]/?T0on]`NT4oj^hh`;oZK3M00CoW[3Toi^Y
h?nKZN3oVjWP1?nHXmd3oiBMfP?oT9SH0on<UML3ohNCf0GoPiCL0omkV^@2ofjVl`?o^l;O0one]=P2
ojbUd004oiR;`onBQL7oTXG1oi:5`@?oSH710on:Ol83ohR2a@CoRHO;0on<T=84ohnKf`CoTj[U0_nG
^Nl4oicNo@04oiWUo?nSj?_oXnSkoj?Xn`?oZ=oj0_nXgOX3oj[=lP;oZL_a0_nXaNh4ojS4k@;oZ<?]
0onX`N`6ojO1k7CoYl3[00?o0000ojO0jonW`>/05OnW`>/:ooooo`03o`000?oooooooooo00oooooo
0007ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00006ooooo`03
o`000?oooooooooo00?ooooo0ol0000Vooooo`Co[L7Y0_n[^><00onP]nWoW[3Toij`i002oij`i0?o
VjWP1?nHXmd3oiBMfP?oT9SH0on<UML3ohNCf0;oPiCL0omHb_D00onjmO7o_LcVokg<iP03ok_2g`04
ojJLc?nPTlOoX9?7oj2Ca`CoV8_30onBQL43ohf1`@?oRWo20on8P/D4ohV7b`?oS93B1?n?Vm/2oi>Z
i@?oWMGk0_nLg_d3oj;Xn`?oZ>;k0_nXgoX2oj_?l`?oZ/gb0_nYa^h4ojS5kP;oZ<C]1onX`N`2ojO1
k7SoYl3[00?o0000ojO0jonW`>/05?nW`>/:ooooo`03o`000?oooooooooo00oooooo0007ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000005ooooo`04o`000?oooooooooo
ooooo`?o0000:_ooool2ojg1j@;oXKk]0onP]nT4oij`i0?oVjWP0_nHXmd2ohbak`?oQk;b0on1]?H5
ogVkn`;oKL?n00?o/O;eok[elOnmc>H01?nmc>H01?nk`]ooYYc<ojJLc?nVW<`3oj2Ca`?oV8_30onB
QL43ohf1`@?oRWo20on8P/D5ohV7b`?oS93B0_n?Vm/3oic7mP;oWMGk1?nRj?/3ojSRn`;oZm7d1On[
co<00onZcO;oZLK^ojW6kP02ojW6kP;oZ<G^0_nX`^`6ojS1k7goYl3[00?o0000ojO0jonW`>/05?nW
`>/9ooooo`03o`000?oooooooooo00oooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00oo^k^koA4A4o`000005ooooo`Co0000;_ooool4oj6nk@?oX;OY0_nN/>@2oi>fk`?oT;?^1?n<
/Nl3ohNblP?oPKCf0_mi^o/01?mjiNKo/O;eok7bmOnal_D3okgCjP;o_LcV0_n]Y]44ojJLc0?oX9?7
0onHRl<3oi:5`@?oSH711?n:Ol83ohR2a@;oRHO;0_nEZ^@5oiZikP;oW<Of0onQiO`2oj;Xn`;oYnCk
0_n/doD4oj_Am0;oZloc1?nYanl2ojW6kPKoZ<;/0_nX`Nb0ojO0j`03o`000?nW`>_oYl3[01CoYl3[
2Oooool00ol0003oooooooooo`0?ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo
00?oMgMgo`000?ooool01?ooool2o`00037ooooo0_nQ_^d2oiNkl@?oU[S_1?nC]^l3oi2ckP;oS;7_
1?mlb_l2of_?o0;oQNCh0_nZk?T2ok[Ek@?o_M?Z00?o/JoFojfVdOn]Y]400on]Y]43ojJLc0CoX9?7
0onHRl<3oi:5`@?oSH710_n:Ol801?n?UMCoTYkLoi:Ng?nBW]`5oiFZi0?oV[W^0onOhOd2oj7Uo0Co
YnCk1?n/doD2oj_Am0?oZ/W`0_nYanl2ojS3k@OoZ<;/Q?nW`>/00ol0003oYl3[ojO0j`0DojO0j`So
oooo00?o0000ooooooooool03oooool002;ooooo00?o0000ooooooooool0;oooool4oiNkl@?oU[S_
0_nC]^l2ohc0n0CoQ/Gl0_mlb_l3ohcLoP?oY^Ck00?oZ^ciok[EkOnjeNd00_njeNd01?nmdn[o/JoF
ok6_e_na[mH4ojfVd@CoYYc<0_nPTlL01?nGT/coTXk<oi:>c?nBS/`3oi2=c@?oSho?1?n?UM@3oi:N
g0GoUJ[T00CoV[W^oioQoOnOhOgoWn7m0onVi?/2ojOTn`?o[=Kf0_n/doD3oj[;l@;oZ/W`1_nX`nd2
ojS2k0?oZ<7[Q_nW`>/00ol0003oYl3[ojO0j`0CojO0j`Wooooo00?o0000ooooooooool03_ooool0
02?ooooo00?o0000ooooooooool0;oooool2oiNkl@;oTk[b1?n@_OD3ohc0n0;oQ/Gl1?nAdoh01?n<
g?koY^CkojKTnonVi?/3okODk`;o^]G]0_nd]m/4ok6_eP;o[JKA00?oXYkAoibGc_nLUlh00_nLUlh4
oiNBc0?oTXk<0on@SLd3ohn?c`CoSiGD0onBW]`2oiFZi0?oWMWl0onTh_`2ojKTn`?o[=Sg0_n/e_H3
oj_=lP;oZ/_a0_nYa>d6ojS3k@;oZ<7/1OnX`N^5ojO0j`03o`000?nW`>_oYl3[01CoYl3[2?ooool0
0ol0003oooooooooo`0>ooooo`009?ooool00ol0003oooooooooo`0_ooooo`CoTk[b0_n@_OD2oiK2
m@GoU<[j0_nAdoh2ojCJn`;o/m3_0onge>l00one_Moo];OKokBgf`03okBgf`;o/JoF00?oYZKEoj:N
dOnRW]400_nRW]43oibGcPCoUi;<0onBS/`3oi2=c@CoSho?0_n?UM@2oiO3mPCoVloj00CoWMWlojCR
o?nTh_coY>;l1?n/f_P2ojcHm`;oZloc0on[cO82ojW5kPCoZLC]0_nX`nd6ojS1k0;oZ<7[R?nW`>/0
0ol0003oYl3[ojO0j`0DojO0j`Oooooo00?o0000ooooooooool03_ooool002Gooooo0_l0000`oooo
o`;oTk[b0_nI_?04oiK2m@;oU<[j1?nSd?L00onTf__o/m3_ok?@k`02ok?@k`04okODkone_Moo]KgO
okFmg`?o];OK00?oZjgIojJVeOnVY]D00_nVY]D3oj:Nd@CoW9O>1?nGT/`3oi:>c0?oT8g=0_n?Sll2
oiBgk`CoUl?f0_nKcoX2oj?No0?oZm_h0_n/f_P2ojcAm0GoZloc00?oZlgbojW5k_nYaNh00_nYaNh2
ojW4k@;oZ<;/1_nX`Nb<ojO0j`03o`000?nW`>_oYl3[01CoYl3[1_ooool00ol0003oooooooooo`0>
ooooo`009oooool00ol0003oooooooooo`0^ooooo`CoVKc`0_nF`_D4oj;6lP;oXm3g0on`bnh2ok?@
k`;o]<3S1?ne_Ml01?nd]m_oZjgIoj^]fOn[[MT3ojJVe@CoXYkA0onLUlh2oiNBc0;oTj7M1?nAY>83
oi:/j0CoU;O_0_nG`oH3oj7Gn`04oj?No?n[foSoZm_hoj_Kn0;o[=?e1?n/dO@2oj_?l`CoZ/K^0_nY
aNh6ojS2k0;oZ<7/T?nW`>/00ol0003oYl3[ojO0j`0CojO0j`Kooooo00?o0000ooooooooool03_oo
ool002Sooooo00?o0000ooooooooool0;_ooool2oiVll0CoX[k]0_nRa_82ojg6k0?o/<_^0_nc`^D4
okC0h`;o]KgO0_n^/m`4oj^]f@?oYZKE0_nRW]400onJXM[oUYoKoiJOf`02oiJOf`CoTj7M1?nAY>83
oi:/j0;oU;O_0onNcoP2oj7Gn`?oZM[i00?oZm_hojcCmOn/doD00_n/doD2ojcAm0?oZ/S_0_nZa^h2
ojS3k@OoZ<;/0_nX`N^AojO0j`03o`000?nW`>_oYl3[01CoYl3[1Oooool00ol0003oooooooooo`0>
ooooo`00:Oooool00ol0003oooooooooo`0_ooooo`;oX[k]0on/`NT4ojg6k003ok3;k_nc`^Go/l;U
00;o/l;U0_nd`><2ok2hg`Co[[?L0_n[[MT01?nSZM_oWZGJoijUf_nNYMX4oiZQfPCoUYoK1?nCXMd2
oi6ThP;oVKc`1?nKaOD2oik?n0?oY]Si0_nYf_T3oj_EmP;o[=?e0on[bO02oj[8k`;oZLC]1?nX`nd2
ojS2k0?oZ<7/1?nX`N^AojO0j`03o`000?nW`>_oYl3[01CoYl3[1?ooool00ol0003oooooooooo`0>
ooooo`00:_ooool2o`00037ooooo1?n/`NT2ojg6k0?o//;V0_nc`^D2ok6lhPCo/;SO0_n^/m`00onW
[mgoXjWKoj>Yf`02oj>Yf`?oWZGJ1?nJXMX2oiJOf`03oiR_ionH]>_oV;C[00?oV;C[1?nI_?02oi_5
m@?oXmCi0_nVf?T3oj[EmP;oZmGf0on[bo42oj_9l0;oZLG^1?nYa>d2ojS3k@OoZ<7/0_nX`N^CojO0
j`03o`000?nW`>_oYl3[01CoYl3[0oooool00ol0003oooooooooo`0>ooooo`00;?ooool00ol0003o
ooooooooo`0_ooooo`;o[<7Y0_na`^L3ok;2iP03ok6oiOna_>;o/KcR00?o/KcR0_n`^=l00onZ]>3o
YjoMojN_g@02ojN_g@CoXjWK0onNYMX2oiZQfP;oVZgU0onH[nL5oiRdj`;oVKc`0onQcoP2oj?Dn@?o
Z=Cg0_nZeOH3oj_=l@;oZl_a0_nYa^h4ojW5kP;oZLC]2?nX`NbHojO0j`03o`000?nW`>_oYl3[01Co
Yl3[0oooool00ol0003oooooooooo`0=ooooo`00;Oooool00ol0003oooooooooo`0_ooooo`Co/L;W
00Co//;Vok6oiOna_nGo/KoU0ona_>800on/^N;oZ[CPojZdh002ojZdh0CoYjoM0_nSZM/00onO[n?o
W:gSoib]h`02oib]h`CoVZgU0onH[nL2oiRdj`CoW/Wf0_nQcoP3ojKBm`;oZ=Cg0_nZcO83oj_=l@;o
Z/O_1?nYa^h2ojW5kP;oZ<;/1_nX`N`2ojS0jiWoYl3[00?o0000ojO0jonW`>/05?nW`>/3ooooo`03
o`000?oooooooooo00gooooo000^ooooo`03o`000?oooooooooo02oooooo0_na`^L2ok32i`Co/KoU
00Co/KcRojbih_n/^N;o[;WR1?nZ]>02ojN_g@;oX[;S0onO[n<4oib]h`;oVZgU0_nK__44oic3l`;o
W/Wf1?nTcoH2ojKBm`;oZLkc1?nZcO800on[cO7oZ/O_oj[7k`02oj[7k`;oZLK^0_nX`n`4ojS2k0;o
Z<7/0_nX`N/4ojS0jiWoYl3[00?o0000ojO0jonW`>/05?nW`>/2ooooo`03o`000?oooooooooo00go
oooo000_ooooo`03o`000?oooooooooo02oooooo1?n``^L2ok6oi@;o[KgU1?n/^N82ojZdh0;oYKGT
1?nR/^<3oin_h`;oW:gS0_nL^nh4oi^nl@;oW<?c0onRboD2ojC?mP?oZ<gc1?nYc_<2oj[=lP?oZ/S`
0_nZanl2ojW3k@CoZ<?/0_nX`^`2ojS1k0CoZ<7[0_nX`>^KojO0j`03o`000?nW`>_oYl3[01?oYl3[
0_ooool00ol0003oooooooooo`0=ooooo`00<?ooool2o`00033ooooo0_n``^L2ojk1j0Co[KgU0_n/
^N82ojNiiPCoYKGT0_nR/^<2oinij`?oWKW/1?nL^nh2oi^nl@?oX<Oc0_nRboD2ojK<l`GoZ<gc0_nY
c_<3ojW9l0;oZ/S`0_nYa>d4ojW3k@;oZ<?/1_nX`N`2ojS1jikoYl3[00?o0000ojO0jonW`>/05?nW
`>/00ooooooo0000ooooo`0>ooooo`00<_ooool00ol0003oooooooooo`0^ooooo`Co[/7X0_n]_ND2
ojRmj0CoYkWV0_nU]N@2oj6jj`CoWkW[0onM^N`2oibkkP?oWl?b0_nPao<2ojC9l`CoY/cc0_nXcO<3
ojW9l@;oZLW`0onYaNh4ojW4k@;oZL?]0_nX`^`6ojS1k:;oYl3[00?o0000ojO0jonW`>/04onW`>/0
0ooooooo0000ooooo`0>ooooo`00<oooool00ol0003oooooooooo`0^ooooo`;o[/7X0_nY`>/4ojRm
j0;oYkWV0_nS^n/4oj6jj`;oWkW[0_nO_^l4oio0l0;oWl?b0_nSao84ojC9l`;oY/cc0onXbO42ojW9
l@OoZLG^0_nYa>d6ojS2k0;oZ<7/0onX`>^SojO0j`03o`000?nW`>_oYl3[01?oYl3[00?o0000oooo
ooooool03Oooool003Cooooo00?o0000ooooooooool0;_ooool4ojW0j`;oZ;gX0_nT_N/4oj>kj`;o
XK[[0_nP_^h4oinnk`;oWl3`0_nRaO84oj?7lP;oY<Wc0onWb?42ojS9l@;oZ<G^1_nYaNh9ojS2k0?o
Z<7[0_nX`>^UojO0j`03o`000?nW`>_oYl3[017oYl3[00?oooooo`000?ooool03_ooool003Gooooo
0_l0000_ooooo`;oZL3[0onU_n`3ojBmj`;oXk_[0_nQ_^d4oj2nkP;oWkk_0_nQ`o44oj;5lP;oXlOb
0onUao42ojO8l@;oZ<G_1?nXaNh2ojW5kP;oZ<?]1_nX`^`3ojS1k0;oZ<7[ZOnW`>/00ol0003oYl3[
ojO0j`0=ojO0j`Kooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0;_oo
ool2ojFok0;oXko]1?nR_^d3oj6nk@;oX;k^0_nQ`O04oj73l@;oX/Gb0onTaO42ojG7l@;oYlG_1?nX
aNl2ojS5kPKoZ<?]0_nX`^`5ojS1k:goYl3[00?o0000ojO0jonW`>/02OnW`>/9ooooo`03o`000?oo
oooooooo00cooooo000hooooo`03o`000?oooooooooo02kooooo1?nS_nd2oj:nk@;oX[o^1?nQ`>l3
oj71l0;oXL?a0onTa?02ojC5l@;oY/C_1?nWaNl2ojS5k`SoZ<?]1OnX`N`2ojS0jjooYl3[00?o0000
ojO0jonW`>/01OnW`>/<ooooo`03o`000?oooooooooo00cooooo000iooooo`03o`000?oooooooooo
02kooooo0_nS_nd2oj:nk@CoX[o^0_nQ`>l2oj?1kPCoXl;_0_nTa?02ojG3k`CoY/C_0_nWaNl2ojO3
k@KoZ<?]0onX`^`2ojS1k0;oZ<7[1?nX`>^_ojO0j`03o`000?nW`>_oYl3[013ooooo00?o0000oooo
ooooool03?ooool003[ooooo0_l0000_ooooo`CoX[k]0_nR_nh2oj?0kPCoXl7^0_nS`^l2ojG2kPCo
YL?_0_nVa>l2ojO3kPCoYl?]0_nX`nd5ojS2k0;oZ<7/1?nX`N/2ojS0jk3oYl3[00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0<ooooo`00??ooool00ol0003oooooooooo`0]ooooo`;oX[k]
0_nS_nd4oj?0kP;oXl7^0_nT`Nh4ojG2kP;oYL?_0onV`^d3ojO3kP;oYl?]1OnX`^`6ojS1k0;oZ<7[
[onW`>/5ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03?ooool003gooooo00?o
0000ooooooooool0;Oooool4oj>ok@;oXl3^0_nT`>d4ojC1kP;oYL;^1OnV`^d2ojO1k0CoYl;/0_nX
`^`2ojO1k0KoZ<7/[onW`>/9ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?oo
ool003kooooo00?o0000ooooooooool0;Oooool2oj>ok@?oY;o]0onT`>d2ojC1kP?oY/7]0_nV`^d6
ojO1k0;oYl;/1_nW`N`2ojS1k:_oYl3[4?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00cooooo000oooooo`;o0000;oooool2ojBok@;oYKo/1?nU`>d2ojK1k@;oY/7/3_nW`Nb[ojO0
jaCooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`00@Oooool00ol0003o
ooooooooo`0]ooooo`CoYKo/0_nU`>d2ojK0k0CoY/7/2_nW`Nb[ojO0jaSooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0;ooooo`00@_ooool00ol0003oooooooooo`0]ooooo`;oYKo/
0_nV_n`4ojK0k0;oY/7/0_nW`>`6ojO1k0;oYl3/Z?nW`>/Mooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool004?ooooo00?o0000ooooooooool0;Oooool4ojJok0;oY/3/1_nW
`>`2ojO1k0KoYl3/Y?nW`>/Pooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool004Cooooo00?o0000ooooooooool0;Oooool2ojJok0;oYl3[1_nW`>`3ojO0j`GoYl3/X_nW`>/T
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool004Gooooo0_l0000_oooo
o`?oYl3[0_nW`>bYojO0jbWooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;oooo
o`00Aoooool00ol0003oooooooooo`0]oooooj[oYl3[;?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00_ooooo0018ooooo`03o`000?oooooooooo02goooooY_nW`>/`ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02oooool004Wooooo00?o0000ooooooooool0;Ooo
oonRojO0jcCooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00B_ooool2
o`0002koooooWOnW`>/iooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool0
04cooooo00?o0000ooooooooool0;?oooonIojO0jccooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0:ooooo`00COooool00ol0003oooooooooo`0/oooooi;oYl3[@oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00[ooooo001>ooooo`03o`000?oooooooooo02gooooo
SOnW`>]7ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool004oooooo0_l0
000^ooooohSoYl3[C?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo001A
ooooo`03o`000?oooooooooo02coooooQ?nW`>]?ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02_ooool005;ooooo00?o0000ooooooooool0:ooooon1ojO0je?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0:ooooo`00Doooool00ol0003oooooooooo`0[oooooggo
Yl3[Eoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo001Dooooo`;o0000
;OoooomhojO0je[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`00E_oo
ool00ol0003oooooooooo`0[ooooogCoYl3[G_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Wooooo001Gooooo`03o`000?oooooooooo02_oooooK?nW`>]Vooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02Oooool005Sooooo00?o0000ooooooooool0;?oooomWojO0
jf[ooooo00Go0000ooooooooooooooooo`00000;ooooo`00FOooool00ol0003oooooooooo`0/oooo
of?oYl3[KOooool01Ol0003ooooooooooooooooo000000_ooooo001Jooooo`;o0000;OoooomOojO0
jg7ooooo00Co0000oooooooooooo00002oooool005cooooo00?o0000ooooooooool0:ooooomKojO0
jgGooooo00?o0000ooooool000002oooool005gooooo00?o0000ooooooooool0:ooooomGojO0jgSo
oooo00Co0000oooooooooooo00002_ooool005kooooo00?o0000ooooooooool0:ooooomCojO0jgco
oooo00?o0000ooooool000002_ooool005oooooo0_l0000/ooooodcoYl3[Poooool2o`0000[ooooo
001Qooooo`03o`000?oooooooooo02[oooooB?nW`>^5ooooo`?o00002_ooool006;ooooo00?o0000
ooooooooool0:ooooom3ojO0jhCooooo1?l0000=ooooo`00Hoooool00ol0003oooooooooo`0[oooo
ocooYl3[Poooool4o`00017ooooo001Tooooo`;o0000;?oooolkojO0jh?ooooo0ol0000Eooooo`00
I_ooool00ol0003oooooooooo`0[oooooc?oYl3[QOooool4o`0001Sooooo001Wooooo`03o`000?oo
oooooooo02[ooooo<?nW`>^4ooooo`Co00007?ooool006Sooooo00?o0000ooooooooool0:_ooool/
ojO0jh?ooooo1?l0000Pooooo`00JOooool2o`0002cooooo9onW`>^2ooooo`Co00009?ooool006_o
oooo00?o0000ooooooooool0:_oooolSojO0jh;ooooo0ol0000Xooooo`00K?ooool00ol0003ooooo
ooooo`0ZoooooagoYl3[Poooool4o`0002_ooooo001]ooooo`03o`000?oooooooooo02_ooooo6?nW
`>^2ooooo`Co0000;oooool006kooooo00?o0000ooooooooool0:_oooolEojO0jh7ooooo1?l0000c
ooooo`00Koooool2o`0002_ooooo4OnW`>^0ooooo`Co0000=oooool0077ooooo00?o0000oooooooo
ool0:_ooool9ojO0jh;ooooo1?l0000kooooo`00L_ooool00ol0003oooooooooo`0Zooooo`GoYl3[
P_ooool3o`0003oooooo001cooooo`03o`000?oooooooooo02[ooooo00?oYl3[ooooooooool0Oooo
ool4o`0004;ooooo001dooooo`;o0000:_ooool00ol0003oooooooooo`1kooooo`Co0000A_ooool0
07Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1hooooo`Co0000B_ooool007Oo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1dooooo`Co0000C_ooool007Sooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`1aooooo`?o0000D_ooool007Wooooo0_l0
000Tooooo`03o`000?oooooooooo06gooooo1?l0001Eooooo`00Noooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo06Wooooo1?l0001Iooooo`00O?ooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo06Gooooo1?l0001Mooooo`00OOooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo067ooooo1?l0001Qooooo`00O_ooool2o`0001oooooo00?o0000ooooooooool0
GOooool4o`0006Gooooo0020ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0F_oo
ool3o`0006Wooooo0021ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0E_ooool4
o`0006cooooo0022ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0D_ooool4o`00
073ooooo0023ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0C_ooool4o`0007Co
oooo0024ooooo`;o00006Oooool00ol0003oooooooooo`1:ooooo`Co0000N?ooool008Kooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`16ooooo`Co0000O?ooool008Oooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`13ooooo`?o0000P?ooool008Sooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0oooooo`Co0000Poooool008Wooooo0_l0000Dooooo`03
o`000?oooooooooo03_ooooo1?l00027ooooo`00Roooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo03Oooooo1?l0002;ooooo`00S?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo03?ooooo1?l0002?ooooo`00SOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo033ooooo0ol0002Cooooo`00S_ooool2o`0000oooooo00?o0000ooooooooool0;?ooool4o`00
09Kooooo002@ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:?ooool4o`0009[o
oooo002Aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09?ooool4o`0009kooooo
002Booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool4o`000:;ooooo002C
ooooo`;o00002Oooool00ol0003oooooooooo`0Mooooo`Co0000Y_ooool009Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Jooooo`?o0000Z_ooool009Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Fooooo`Co0000[Oooool009Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Booooo`Co0000/Oooool009Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0>ooooo`Co0000]Oooool009Wooooo0_l00003ooooo`03o`000?oooooo
oooo00[ooooo1?l0002iooooo`00Voooool01?l0003oooooooooool00009ooooo`?o0000_Oooool0
09cooooo00?o0000ooooool000001Oooool4o`000<3ooooo002Mooooo`;o000000?oooooo`000?l0
00000_l00034ooooo`00W_ooool2o`000<Sooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002^oooo
o`05oiRHV?l0003o0000odA4A?nj^[X02Oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Gooooo0_lQ
8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0Uoooool00:kooooo00Go410@okZj^_o^k^koMgMg
oa0@4002ooooo`Ko000000Koooooob4Q8OnHV9SooooooiRHV?lQ8B45ooooo`;o8B4Q1?ooool01OlQ
8B7oV9RHoooooonHV9So8B4Q09Oooooo002^ooooo`03o`000?oooooooooo00_ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool00000Uoooool00:kooooo00?o0000
ooooooooool01?ooool6o`000006oooooolb<S;oV9RHoooooonHV9So<S8b2oooool01Olb<S;oV9RH
oooooonHV9So<S8b09Oooooo002^ooooo`03o`000?oooooooooo00_ooooo00Goc<c<o`000?l0003o
0000olc<c00;ooooo`05olc<c?l0003o0000o`000?o<c<`0Uoooool00:cooooo00?o410@o`000?l0
00000ol0000:ooooo`05oa0@4?nj^[[ooooookZj^_l@41002oooool01Ol@413o^[Zjoooooonj^[[o
410@09Oooooo002^ooooo`03o`000?oooooooooo00_ooooo00Go0000okZj^_oooooo^[Zjo`00000;
ooooo`05o`000?nj^[[ooooookZj^_l00000Uoooool00:kooooo00?o0000ooooooooool02oooool0
1OnYZJWo410@o`000?l@413oZJVY00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2Gooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -17 0 ]
[.5 .82364 17 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9.6) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69467 Mtetra
.4053 .69467 .41061 .69934 .41957 .69681 .41427 .69213 Mtetra
.41427 .69213 .41957 .69681 .42855 .69428 .42327 .68958 Mtetra
.42327 .68958 .42855 .69428 .43756 .69174 .43231 .68703 Mtetra
.43231 .68703 .43756 .69174 .4466 .68919 .44137 .68446 Mtetra
.44137 .68446 .4466 .68919 .45567 .68663 .45046 .68189 Mtetra
.45046 .68189 .45567 .68663 .46478 .68407 .45958 .67931 Mtetra
.45958 .67931 .46478 .68407 .47391 .68149 .46873 .67671 Mtetra
.46873 .67671 .47391 .68149 .48307 .67891 .47792 .67412 Mtetra
.47792 .67412 .48307 .67891 .49227 .67632 .48713 .67151 Mtetra
.48713 .67151 .49227 .67632 .50149 .67371 .49638 .66889 Mtetra
.49638 .66889 .50149 .67371 .51075 .6711 .50565 .66626 Mtetra
.50565 .66626 .51075 .6711 .52004 .66849 .51496 .66363 Mtetra
.51496 .66363 .52004 .66849 .52936 .66586 .5243 .66098 Mtetra
.5243 .66098 .52936 .66586 .53871 .66322 .53367 .65833 Mtetra
.53367 .65833 .53871 .66322 .54809 .66058 .54308 .65567 Mtetra
.54308 .65567 .54809 .66058 .55751 .65792 .55251 .653 Mtetra
.55251 .653 .55751 .65792 .56695 .65526 .56198 .65032 Mtetra
.56198 .65032 .56695 .65526 .57643 .65259 .57148 .64763 Mtetra
.57148 .64763 .57643 .65259 .58595 .6499 .58102 .64493 Mtetra
.58102 .64493 .58595 .6499 .59549 .64721 .59058 .64222 Mtetra
.59058 .64222 .59549 .64721 .60507 .64451 .60018 .6395 Mtetra
.60018 .6395 .60507 .64451 .61468 .6418 .60982 .63678 Mtetra
.60982 .63678 .61468 .6418 .62432 .63908 .61948 .63404 Mtetra
.61948 .63404 .62432 .63908 .634 .63636 .62918 .63129 Mtetra
.62918 .63129 .634 .63636 .64371 .63362 .63892 .62854 Mtetra
.63892 .62854 .64371 .63362 .65345 .63087 .64868 .62577 Mtetra
.64868 .62577 .65345 .63087 .66323 .62811 .65848 .623 Mtetra
.65848 .623 .66323 .62811 .67304 .62535 .66832 .62021 Mtetra
.66832 .62021 .67304 .62535 .68289 .62257 .67819 .61742 Mtetra
.67819 .61742 .68289 .62257 .69277 .61979 .68809 .61462 Mtetra
.68809 .61462 .69277 .61979 .70269 .61699 .69803 .6118 Mtetra
.69803 .6118 .70269 .61699 .71264 .61418 .70801 .60898 Mtetra
.70801 .60898 .71264 .61418 .72262 .61137 .71802 .60615 Mtetra
.71802 .60615 .72262 .61137 .73264 .60854 .72806 .6033 Mtetra
.72806 .6033 .73264 .60854 .7427 .60571 .73814 .60045 Mtetra
.73814 .60045 .7427 .60571 .75279 .60286 .74826 .59759 Mtetra
.74826 .59759 .75279 .60286 .76291 .60001 .75841 .59471 Mtetra
.75841 .59471 .76291 .60001 .77308 .59714 .7686 .59183 Mtetra
.7686 .59183 .77308 .59714 .78328 .59427 .77882 .58893 Mtetra
.77882 .58893 .78328 .59427 .79351 .59138 .78908 .58603 Mtetra
.78908 .58603 .79351 .59138 .80378 .58849 .79938 .58311 Mtetra
.79938 .58311 .80378 .58849 .81409 .58558 .80971 .58019 Mtetra
.80971 .58019 .81409 .58558 .82443 .58267 .82008 .57725 Mtetra
.82008 .57725 .82443 .58267 .83482 .57974 .83049 .57431 Mtetra
.83049 .57431 .83482 .57974 .84523 .5768 .84094 .57135 Mtetra
.84094 .57135 .84523 .5768 .85569 .57385 .85142 .56838 Mtetra
.85142 .56838 .85569 .57385 .86618 .57089 .86194 .5654 Mtetra
.86194 .5654 .86618 .57089 .87672 .56792 .8725 .56241 Mtetra
.8725 .56241 .87672 .56792 .88729 .56494 .8831 .55941 Mtetra
.8831 .55941 .88729 .56494 .89789 .56195 .89374 .5564 Mtetra
.89374 .5564 .89789 .56195 .90854 .55895 .90441 .55338 Mtetra
.90441 .55338 .90854 .55895 .91923 .55594 .91512 .55035 Mtetra
.91512 .55035 .91923 .55594 .92995 .55292 .92588 .5473 Mtetra
.92588 .5473 .92995 .55292 .94071 .54988 .93667 .54425 Mtetra
.93667 .54425 .94071 .54988 .95152 .54684 .9475 .54118 Mtetra
.9475 .54118 .95152 .54684 .96236 .54378 .95837 .53811 Mtetra
.95837 .53811 .96236 .54378 .97324 .54071 .96928 .53502 Mtetra
.96928 .53502 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.391 .69252 .39636 .6972 .4053 .69467 .39996 .68998 Mtetra
.39996 .68998 .4053 .69467 .41427 .69213 .40895 .68742 Mtetra
.40895 .68742 .41427 .69213 .42327 .68958 .41797 .68486 Mtetra
.41797 .68486 .42327 .68958 .43231 .68703 .42702 .68228 Mtetra
.42702 .68228 .43231 .68703 .44137 .68446 .4361 .6797 Mtetra
.4361 .6797 .44137 .68446 .45046 .68189 .44521 .67711 Mtetra
.44521 .67711 .45046 .68189 .45958 .67931 .45435 .67452 Mtetra
.45435 .67452 .45958 .67931 .46873 .67671 .46352 .67191 Mtetra
.46352 .67191 .46873 .67671 .47792 .67412 .47273 .66929 Mtetra
.47273 .66929 .47792 .67412 .48713 .67151 .48196 .66667 Mtetra
.48196 .66667 .48713 .67151 .49638 .66889 .49123 .66403 Mtetra
.49123 .66403 .49638 .66889 .50565 .66626 .50053 .66139 Mtetra
.50053 .66139 .50565 .66626 .51496 .66363 .50985 .65874 Mtetra
.50985 .65874 .51496 .66363 .5243 .66098 .51922 .65608 Mtetra
.51922 .65608 .5243 .66098 .53367 .65833 .52861 .65341 Mtetra
.52861 .65341 .53367 .65833 .54308 .65567 .53803 .65073 Mtetra
.53803 .65073 .54308 .65567 .55251 .653 .54749 .64804 Mtetra
.54749 .64804 .55251 .653 .56198 .65032 .55698 .64534 Mtetra
.55698 .64534 .56198 .65032 .57148 .64763 .5665 .64264 Mtetra
.5665 .64264 .57148 .64763 .58102 .64493 .57606 .63992 Mtetra
.57606 .63992 .58102 .64493 .59058 .64222 .58565 .6372 Mtetra
.58565 .6372 .59058 .64222 .60018 .6395 .59527 .63446 Mtetra
.59527 .63446 .60018 .6395 .60982 .63678 .60493 .63172 Mtetra
.60493 .63172 .60982 .63678 .61948 .63404 .61461 .62896 Mtetra
.61461 .62896 .61948 .63404 .62918 .63129 .62434 .6262 Mtetra
.62434 .6262 .62918 .63129 .63892 .62854 .63409 .62343 Mtetra
.63409 .62343 .63892 .62854 .64868 .62577 .64388 .62064 Mtetra
.64388 .62064 .64868 .62577 .65848 .623 .65371 .61785 Mtetra
.65371 .61785 .65848 .623 .66832 .62021 .66357 .61505 Mtetra
.66357 .61505 .66832 .62021 .67819 .61742 .67346 .61224 Mtetra
.67346 .61224 .67819 .61742 .68809 .61462 .68339 .60942 Mtetra
.68339 .60942 .68809 .61462 .69803 .6118 .69335 .60658 Mtetra
.69335 .60658 .69803 .6118 .70801 .60898 .70335 .60374 Mtetra
.70335 .60374 .70801 .60898 .71802 .60615 .71338 .60089 Mtetra
.71338 .60089 .71802 .60615 .72806 .6033 .72345 .59803 Mtetra
.72345 .59803 .72806 .6033 .73814 .60045 .73356 .59516 Mtetra
.73356 .59516 .73814 .60045 .74826 .59759 .7437 .59227 Mtetra
.7437 .59227 .74826 .59759 .75841 .59471 .75387 .58938 Mtetra
.75387 .58938 .75841 .59471 .7686 .59183 .76409 .58648 Mtetra
.76409 .58648 .7686 .59183 .77882 .58893 .77434 .58356 Mtetra
.77434 .58356 .77882 .58893 .78908 .58603 .78462 .58064 Mtetra
.78462 .58064 .78908 .58603 .79938 .58311 .79495 .57771 Mtetra
.79495 .57771 .79938 .58311 .80971 .58019 .80531 .57476 Mtetra
.80531 .57476 .80971 .58019 .82008 .57725 .81571 .57181 Mtetra
.81571 .57181 .82008 .57725 .83049 .57431 .82614 .56884 Mtetra
.82614 .56884 .83049 .57431 .84094 .57135 .83661 .56586 Mtetra
.83661 .56586 .84094 .57135 .85142 .56838 .84712 .56288 Mtetra
.84712 .56288 .85142 .56838 .86194 .5654 .85767 .55988 Mtetra
.85767 .55988 .86194 .5654 .8725 .56241 .86826 .55687 Mtetra
.86826 .55687 .8725 .56241 .8831 .55941 .87889 .55385 Mtetra
.87889 .55385 .8831 .55941 .89374 .5564 .88955 .55082 Mtetra
.88955 .55082 .89374 .5564 .90441 .55338 .90025 .54777 Mtetra
.90025 .54777 .90441 .55338 .91512 .55035 .911 .54472 Mtetra
.911 .54472 .91512 .55035 .92588 .5473 .92178 .54166 Mtetra
.92178 .54166 .92588 .5473 .93667 .54425 .9326 .53858 Mtetra
.9326 .53858 .93667 .54425 .9475 .54118 .94346 .53549 Mtetra
.94346 .53549 .9475 .54118 .95837 .53811 .95436 .53239 Mtetra
.95436 .53239 .95837 .53811 .96928 .53502 .9653 .52928 Mtetra
.9653 .52928 .96928 .53502 .98024 .53192 .97628 .52616 Mtetra
.38561 .68781 .391 .69252 .39996 .68998 .39459 .68525 Mtetra
.39459 .68525 .39996 .68998 .40895 .68742 .40359 .68268 Mtetra
.40359 .68268 .40895 .68742 .41797 .68486 .41263 .6801 Mtetra
.41263 .6801 .41797 .68486 .42702 .68228 .4217 .67751 Mtetra
.4217 .67751 .42702 .68228 .4361 .6797 .4308 .67492 Mtetra
.4308 .67492 .4361 .6797 .44521 .67711 .43993 .67231 Mtetra
.43993 .67231 .44521 .67711 .45435 .67452 .44909 .6697 Mtetra
.44909 .6697 .45435 .67452 .46352 .67191 .45828 .66707 Mtetra
.45828 .66707 .46352 .67191 .47273 .66929 .46751 .66444 Mtetra
.46751 .66444 .47273 .66929 .48196 .66667 .47676 .6618 Mtetra
.47676 .6618 .48196 .66667 .49123 .66403 .48605 .65915 Mtetra
.48605 .65915 .49123 .66403 .50053 .66139 .49537 .65649 Mtetra
.49537 .65649 .50053 .66139 .50985 .65874 .50472 .65382 Mtetra
.50472 .65382 .50985 .65874 .51922 .65608 .5141 .65114 Mtetra
.5141 .65114 .51922 .65608 .52861 .65341 .52351 .64846 Mtetra
.52351 .64846 .52861 .65341 .53803 .65073 .53296 .64576 Mtetra
.53296 .64576 .53803 .65073 .54749 .64804 .54244 .64305 Mtetra
.54244 .64305 .54749 .64804 .55698 .64534 .55195 .64034 Mtetra
.55195 .64034 .55698 .64534 .5665 .64264 .56149 .63762 Mtetra
.56149 .63762 .5665 .64264 .57606 .63992 .57107 .63488 Mtetra
.57107 .63488 .57606 .63992 .58565 .6372 .58068 .63214 Mtetra
.58068 .63214 .58565 .6372 .59527 .63446 .59032 .62939 Mtetra
.59032 .62939 .59527 .63446 .60493 .63172 .6 .62663 Mtetra
.6 .62663 .60493 .63172 .61461 .62896 .60971 .62385 Mtetra
.60971 .62385 .61461 .62896 .62434 .6262 .61946 .62107 Mtetra
.61946 .62107 .62434 .6262 .63409 .62343 .62924 .61828 Mtetra
.62924 .61828 .63409 .62343 .64388 .62064 .63905 .61548 Mtetra
.63905 .61548 .64388 .62064 .65371 .61785 .6489 .61267 Mtetra
.6489 .61267 .65371 .61785 .66357 .61505 .65878 .60985 Mtetra
.65878 .60985 .66357 .61505 .67346 .61224 .6687 .60702 Mtetra
.6687 .60702 .67346 .61224 .68339 .60942 .67865 .60418 Mtetra
.67865 .60418 .68339 .60942 .69335 .60658 .68864 .60133 Mtetra
.68864 .60133 .69335 .60658 .70335 .60374 .69866 .59847 Mtetra
.69866 .59847 .70335 .60374 .71338 .60089 .70872 .5956 Mtetra
.70872 .5956 .71338 .60089 .72345 .59803 .71881 .59272 Mtetra
.71881 .59272 .72345 .59803 .73356 .59516 .72894 .58983 Mtetra
.72894 .58983 .73356 .59516 .7437 .59227 .73911 .58692 Mtetra
.73911 .58692 .7437 .59227 .75387 .58938 .74931 .58401 Mtetra
.74931 .58401 .75387 .58938 .76409 .58648 .75955 .58109 Mtetra
.75955 .58109 .76409 .58648 .77434 .58356 .76982 .57816 Mtetra
.76982 .57816 .77434 .58356 .78462 .58064 .78014 .57521 Mtetra
.78014 .57521 .78462 .58064 .79495 .57771 .79049 .57226 Mtetra
.79049 .57226 .79495 .57771 .80531 .57476 .80087 .5693 Mtetra
.80087 .5693 .80531 .57476 .81571 .57181 .8113 .56632 Mtetra
.8113 .56632 .81571 .57181 .82614 .56884 .82176 .56334 Mtetra
.82176 .56334 .82614 .56884 .83661 .56586 .83226 .56034 Mtetra
.83226 .56034 .83661 .56586 .84712 .56288 .8428 .55733 Mtetra
.8428 .55733 .84712 .56288 .85767 .55988 .85337 .55431 Mtetra
.85337 .55431 .85767 .55988 .86826 .55687 .86399 .55128 Mtetra
.86399 .55128 .86826 .55687 .87889 .55385 .87464 .54824 Mtetra
.87464 .54824 .87889 .55385 .88955 .55082 .88533 .54519 Mtetra
.88533 .54519 .88955 .55082 .90025 .54777 .89607 .54213 Mtetra
.89607 .54213 .90025 .54777 .911 .54472 .90684 .53905 Mtetra
.90684 .53905 .911 .54472 .92178 .54166 .91765 .53597 Mtetra
.91765 .53597 .92178 .54166 .9326 .53858 .9285 .53287 Mtetra
.9285 .53287 .9326 .53858 .94346 .53549 .93939 .52976 Mtetra
.93939 .52976 .94346 .53549 .95436 .53239 .95032 .52664 Mtetra
.95032 .52664 .95436 .53239 .9653 .52928 .96129 .52351 Mtetra
.96129 .52351 .9653 .52928 .97628 .52616 .9723 .52037 Mtetra
.38018 .68308 .38561 .68781 .39459 .68525 .38918 .6805 Mtetra
.38918 .6805 .39459 .68525 .40359 .68268 .3982 .67791 Mtetra
.3982 .67791 .40359 .68268 .41263 .6801 .40726 .67532 Mtetra
.40726 .67532 .41263 .6801 .4217 .67751 .41635 .67271 Mtetra
.41635 .67271 .4217 .67751 .4308 .67492 .42547 .6701 Mtetra
.42547 .6701 .4308 .67492 .43993 .67231 .43462 .66748 Mtetra
.43462 .66748 .43993 .67231 .44909 .6697 .4438 .66485 Mtetra
.4438 .66485 .44909 .6697 .45828 .66707 .45301 .66221 Mtetra
.45301 .66221 .45828 .66707 .46751 .66444 .46225 .65956 Mtetra
.46225 .65956 .46751 .66444 .47676 .6618 .47153 .6569 Mtetra
.47153 .6569 .47676 .6618 .48605 .65915 .48083 .65423 Mtetra
.48083 .65423 .48605 .65915 .49537 .65649 .49017 .65156 Mtetra
.49017 .65156 .49537 .65649 .50472 .65382 .49954 .64887 Mtetra
.49954 .64887 .50472 .65382 .5141 .65114 .50895 .64618 Mtetra
.50895 .64618 .5141 .65114 .52351 .64846 .51838 .64347 Mtetra
.51838 .64347 .52351 .64846 .53296 .64576 .52785 .64076 Mtetra
.52785 .64076 .53296 .64576 .54244 .64305 .53735 .63804 Mtetra
.53735 .63804 .54244 .64305 .55195 .64034 .54688 .6353 Mtetra
.54688 .6353 .55195 .64034 .56149 .63762 .55645 .63256 Mtetra
.55645 .63256 .56149 .63762 .57107 .63488 .56605 .62981 Mtetra
.56605 .62981 .57107 .63488 .58068 .63214 .57568 .62705 Mtetra
.57568 .62705 .58068 .63214 .59032 .62939 .58535 .62428 Mtetra
.58535 .62428 .59032 .62939 .6 .62663 .59505 .6215 Mtetra
.59505 .6215 .6 .62663 .60971 .62385 .60478 .61871 Mtetra
.60478 .61871 .60971 .62385 .61946 .62107 .61455 .61591 Mtetra
.61455 .61591 .61946 .62107 .62924 .61828 .62435 .6131 Mtetra
.62435 .6131 .62924 .61828 .63905 .61548 .63419 .61028 Mtetra
.63419 .61028 .63905 .61548 .6489 .61267 .64406 .60746 Mtetra
.64406 .60746 .6489 .61267 .65878 .60985 .65396 .60462 Mtetra
.65396 .60462 .65878 .60985 .6687 .60702 .66391 .60177 Mtetra
.66391 .60177 .6687 .60702 .67865 .60418 .67388 .59891 Mtetra
.67388 .59891 .67865 .60418 .68864 .60133 .68389 .59604 Mtetra
.68389 .59604 .68864 .60133 .69866 .59847 .69394 .59316 Mtetra
.69394 .59316 .69866 .59847 .70872 .5956 .70402 .59027 Mtetra
.70402 .59027 .70872 .5956 .71881 .59272 .71414 .58737 Mtetra
.71414 .58737 .71881 .59272 .72894 .58983 .7243 .58446 Mtetra
.7243 .58446 .72894 .58983 .73911 .58692 .73449 .58154 Mtetra
.73449 .58154 .73911 .58692 .74931 .58401 .74472 .57861 Mtetra
.74472 .57861 .74931 .58401 .75955 .58109 .75498 .57567 Mtetra
.75498 .57567 .75955 .58109 .76982 .57816 .76528 .57272 Mtetra
.76528 .57272 .76982 .57816 .78014 .57521 .77562 .56975 Mtetra
.77562 .56975 .78014 .57521 .79049 .57226 .786 .56678 Mtetra
.786 .56678 .79049 .57226 .80087 .5693 .79641 .5638 Mtetra
.79641 .5638 .80087 .5693 .8113 .56632 .80686 .5608 Mtetra
.80686 .5608 .8113 .56632 .82176 .56334 .81735 .55779 Mtetra
.81735 .55779 .82176 .56334 .83226 .56034 .82788 .55478 Mtetra
.82788 .55478 .83226 .56034 .8428 .55733 .83844 .55175 Mtetra
.83844 .55175 .8428 .55733 .85337 .55431 .84905 .54871 Mtetra
.84905 .54871 .85337 .55431 .86399 .55128 .85969 .54566 Mtetra
.85969 .54566 .86399 .55128 .87464 .54824 .87037 .5426 Mtetra
.87037 .5426 .87464 .54824 .88533 .54519 .88109 .53953 Mtetra
.88109 .53953 .88533 .54519 .89607 .54213 .89185 .53644 Mtetra
.89185 .53644 .89607 .54213 .90684 .53905 .90265 .53335 Mtetra
.90265 .53335 .90684 .53905 .91765 .53597 .91349 .53024 Mtetra
.91349 .53024 .91765 .53597 .9285 .53287 .92437 .52712 Mtetra
.92437 .52712 .9285 .53287 .93939 .52976 .93529 .524 Mtetra
.93529 .524 .93939 .52976 .95032 .52664 .94625 .52085 Mtetra
.94625 .52085 .95032 .52664 .96129 .52351 .95725 .5177 Mtetra
.95725 .5177 .96129 .52351 .9723 .52037 .96829 .51454 Mtetra
.37472 .67831 .38018 .68308 .38918 .6805 .38373 .67572 Mtetra
.38373 .67572 .38918 .6805 .3982 .67791 .39278 .67311 Mtetra
.39278 .67311 .3982 .67791 .40726 .67532 .40186 .6705 Mtetra
.40186 .6705 .40726 .67532 .41635 .67271 .41096 .66788 Mtetra
.41096 .66788 .41635 .67271 .42547 .6701 .4201 .66525 Mtetra
.4201 .66525 .42547 .6701 .43462 .66748 .42927 .66261 Mtetra
.42927 .66261 .43462 .66748 .4438 .66485 .43847 .65996 Mtetra
.43847 .65996 .4438 .66485 .45301 .66221 .4477 .65731 Mtetra
.4477 .65731 .45301 .66221 .46225 .65956 .45697 .65464 Mtetra
.45697 .65464 .46225 .65956 .47153 .6569 .46626 .65197 Mtetra
.46626 .65197 .47153 .6569 .48083 .65423 .47559 .64928 Mtetra
.47559 .64928 .48083 .65423 .49017 .65156 .48495 .64659 Mtetra
.48495 .64659 .49017 .65156 .49954 .64887 .49434 .64389 Mtetra
.49434 .64389 .49954 .64887 .50895 .64618 .50376 .64118 Mtetra
.50376 .64118 .50895 .64618 .51838 .64347 .51322 .63846 Mtetra
.51322 .63846 .51838 .64347 .52785 .64076 .52271 .63572 Mtetra
.52271 .63572 .52785 .64076 .53735 .63804 .53223 .63298 Mtetra
.53223 .63298 .53735 .63804 .54688 .6353 .54178 .63024 Mtetra
.54178 .63024 .54688 .6353 .55645 .63256 .55137 .62748 Mtetra
.55137 .62748 .55645 .63256 .56605 .62981 .56099 .62471 Mtetra
.56099 .62471 .56605 .62981 .57568 .62705 .57065 .62193 Mtetra
.57065 .62193 .57568 .62705 .58535 .62428 .58034 .61914 Mtetra
.58034 .61914 .58535 .62428 .59505 .6215 .59006 .61634 Mtetra
.59006 .61634 .59505 .6215 .60478 .61871 .59982 .61354 Mtetra
.59982 .61354 .60478 .61871 .61455 .61591 .60961 .61072 Mtetra
.60961 .61072 .61455 .61591 .62435 .6131 .61943 .60789 Mtetra
.61943 .60789 .62435 .6131 .63419 .61028 .62929 .60505 Mtetra
.62929 .60505 .63419 .61028 .64406 .60746 .63919 .60221 Mtetra
.63919 .60221 .64406 .60746 .65396 .60462 .64912 .59935 Mtetra
.64912 .59935 .65396 .60462 .66391 .60177 .65908 .59648 Mtetra
.65908 .59648 .66391 .60177 .67388 .59891 .66908 .5936 Mtetra
.66908 .5936 .67388 .59891 .68389 .59604 .67912 .59072 Mtetra
.67912 .59072 .68389 .59604 .69394 .59316 .68919 .58782 Mtetra
.68919 .58782 .69394 .59316 .70402 .59027 .6993 .58491 Mtetra
.6993 .58491 .70402 .59027 .71414 .58737 .70944 .58199 Mtetra
.70944 .58199 .71414 .58737 .7243 .58446 .71962 .57906 Mtetra
.71962 .57906 .7243 .58446 .73449 .58154 .72984 .57612 Mtetra
.72984 .57612 .73449 .58154 .74472 .57861 .74009 .57317 Mtetra
.74009 .57317 .74472 .57861 .75498 .57567 .75038 .57021 Mtetra
.75038 .57021 .75498 .57567 .76528 .57272 .76071 .56724 Mtetra
.76071 .56724 .76528 .57272 .77562 .56975 .77107 .56426 Mtetra
.77107 .56426 .77562 .56975 .786 .56678 .78148 .56126 Mtetra
.78148 .56126 .786 .56678 .79641 .5638 .79192 .55826 Mtetra
.79192 .55826 .79641 .5638 .80686 .5608 .80239 .55524 Mtetra
.80239 .55524 .80686 .5608 .81735 .55779 .81291 .55222 Mtetra
.81291 .55222 .81735 .55779 .82788 .55478 .82346 .54918 Mtetra
.82346 .54918 .82788 .55478 .83844 .55175 .83406 .54613 Mtetra
.83406 .54613 .83844 .55175 .84905 .54871 .84469 .54307 Mtetra
.84469 .54307 .84905 .54871 .85969 .54566 .85536 .54 Mtetra
.85536 .54 .85969 .54566 .87037 .5426 .86607 .53692 Mtetra
.86607 .53692 .87037 .5426 .88109 .53953 .87682 .53383 Mtetra
.87682 .53383 .88109 .53953 .89185 .53644 .88761 .53072 Mtetra
.88761 .53072 .89185 .53644 .90265 .53335 .89844 .52761 Mtetra
.89844 .52761 .90265 .53335 .91349 .53024 .90931 .52448 Mtetra
.90931 .52448 .91349 .53024 .92437 .52712 .92022 .52134 Mtetra
.92022 .52134 .92437 .52712 .93529 .524 .93116 .51819 Mtetra
.93116 .51819 .93529 .524 .94625 .52085 .94216 .51503 Mtetra
.94216 .51503 .94625 .52085 .95725 .5177 .95319 .51185 Mtetra
.95319 .51185 .95725 .5177 .96829 .51454 .96426 .50866 Mtetra
.36922 .67351 .37472 .67831 .38373 .67572 .37826 .6709 Mtetra
.37826 .6709 .38373 .67572 .39278 .67311 .38732 .66828 Mtetra
.38732 .66828 .39278 .67311 .40186 .6705 .39642 .66566 Mtetra
.39642 .66566 .40186 .6705 .41096 .66788 .40554 .66302 Mtetra
.40554 .66302 .41096 .66788 .4201 .66525 .4147 .66037 Mtetra
.4147 .66037 .4201 .66525 .42927 .66261 .42389 .65772 Mtetra
.42389 .65772 .42927 .66261 .43847 .65996 .43311 .65505 Mtetra
.43311 .65505 .43847 .65996 .4477 .65731 .44236 .65238 Mtetra
.44236 .65238 .4477 .65731 .45697 .65464 .45165 .6497 Mtetra
.45165 .6497 .45697 .65464 .46626 .65197 .46096 .64701 Mtetra
.46096 .64701 .46626 .65197 .47559 .64928 .47031 .6443 Mtetra
.47031 .6443 .47559 .64928 .48495 .64659 .47969 .64159 Mtetra
.47969 .64159 .48495 .64659 .49434 .64389 .4891 .63887 Mtetra
.4891 .63887 .49434 .64389 .50376 .64118 .49855 .63615 Mtetra
.49855 .63615 .50376 .64118 .51322 .63846 .50802 .63341 Mtetra
.50802 .63341 .51322 .63846 .52271 .63572 .51753 .63066 Mtetra
.51753 .63066 .52271 .63572 .53223 .63298 .52708 .6279 Mtetra
.52708 .6279 .53223 .63298 .54178 .63024 .53665 .62513 Mtetra
.53665 .62513 .54178 .63024 .55137 .62748 .54626 .62236 Mtetra
.54626 .62236 .55137 .62748 .56099 .62471 .55591 .61957 Mtetra
.55591 .61957 .56099 .62471 .57065 .62193 .56558 .61677 Mtetra
.56558 .61677 .57065 .62193 .58034 .61914 .57529 .61397 Mtetra
.57529 .61397 .58034 .61914 .59006 .61634 .58504 .61115 Mtetra
.58504 .61115 .59006 .61634 .59982 .61354 .59482 .60833 Mtetra
.59482 .60833 .59982 .61354 .60961 .61072 .60463 .60549 Mtetra
.60463 .60549 .60961 .61072 .61943 .60789 .61448 .60265 Mtetra
.61448 .60265 .61943 .60789 .62929 .60505 .62437 .59979 Mtetra
.62437 .59979 .62929 .60505 .63919 .60221 .63428 .59692 Mtetra
.63428 .59692 .63919 .60221 .64912 .59935 .64424 .59405 Mtetra
.64424 .59405 .64912 .59935 .65908 .59648 .65423 .59116 Mtetra
.65423 .59116 .65908 .59648 .66908 .5936 .66425 .58826 Mtetra
.66425 .58826 .66908 .5936 .67912 .59072 .67431 .58536 Mtetra
.67431 .58536 .67912 .59072 .68919 .58782 .68441 .58244 Mtetra
.68441 .58244 .68919 .58782 .6993 .58491 .69454 .57951 Mtetra
.69454 .57951 .6993 .58491 .70944 .58199 .70471 .57657 Mtetra
.70471 .57657 .70944 .58199 .71962 .57906 .71491 .57363 Mtetra
.71491 .57363 .71962 .57906 .72984 .57612 .72516 .57067 Mtetra
.72516 .57067 .72984 .57612 .74009 .57317 .73544 .5677 Mtetra
.73544 .5677 .74009 .57317 .75038 .57021 .74575 .56471 Mtetra
.74575 .56471 .75038 .57021 .76071 .56724 .75611 .56172 Mtetra
.75611 .56172 .76071 .56724 .77107 .56426 .7665 .55872 Mtetra
.7665 .55872 .77107 .56426 .78148 .56126 .77693 .55571 Mtetra
.77693 .55571 .78148 .56126 .79192 .55826 .78739 .55268 Mtetra
.78739 .55268 .79192 .55826 .80239 .55524 .7979 .54965 Mtetra
.7979 .54965 .80239 .55524 .81291 .55222 .80844 .5466 Mtetra
.80844 .5466 .81291 .55222 .82346 .54918 .81902 .54354 Mtetra
.81902 .54354 .82346 .54918 .83406 .54613 .82964 .54047 Mtetra
.82964 .54047 .83406 .54613 .84469 .54307 .8403 .53739 Mtetra
.8403 .53739 .84469 .54307 .85536 .54 .851 .5343 Mtetra
.851 .5343 .85536 .54 .86607 .53692 .86174 .5312 Mtetra
.86174 .5312 .86607 .53692 .87682 .53383 .87252 .52809 Mtetra
.87252 .52809 .87682 .53383 .88761 .53072 .88334 .52496 Mtetra
.88334 .52496 .88761 .53072 .89844 .52761 .89419 .52182 Mtetra
.89419 .52182 .89844 .52761 .90931 .52448 .90509 .51867 Mtetra
.90509 .51867 .90931 .52448 .92022 .52134 .91603 .51551 Mtetra
.91603 .51551 .92022 .52134 .93116 .51819 .92701 .51234 Mtetra
.92701 .51234 .93116 .51819 .94216 .51503 .93803 .50916 Mtetra
.93803 .50916 .94216 .51503 .95319 .51185 .94909 .50596 Mtetra
.94909 .50596 .95319 .51185 .96426 .50866 .9602 .50275 Mtetra
.36369 .66869 .36922 .67351 .37826 .6709 .37275 .66606 Mtetra
.37275 .66606 .37826 .6709 .38732 .66828 .38183 .66342 Mtetra
.38183 .66342 .38732 .66828 .39642 .66566 .39094 .66078 Mtetra
.39094 .66078 .39642 .66566 .40554 .66302 .40009 .65813 Mtetra
.40009 .65813 .40554 .66302 .4147 .66037 .40927 .65546 Mtetra
.40927 .65546 .4147 .66037 .42389 .65772 .41848 .65279 Mtetra
.41848 .65279 .42389 .65772 .43311 .65505 .42772 .65011 Mtetra
.42772 .65011 .43311 .65505 .44236 .65238 .43699 .64742 Mtetra
.43699 .64742 .44236 .65238 .45165 .6497 .44629 .64472 Mtetra
.44629 .64472 .45165 .6497 .46096 .64701 .45563 .64201 Mtetra
.45563 .64201 .46096 .64701 .47031 .6443 .465 .63929 Mtetra
.465 .63929 .47031 .6443 .47969 .64159 .4744 .63657 Mtetra
.4744 .63657 .47969 .64159 .4891 .63887 .48383 .63383 Mtetra
.48383 .63383 .4891 .63887 .49855 .63615 .4933 .63108 Mtetra
.4933 .63108 .49855 .63615 .50802 .63341 .50279 .62833 Mtetra
.50279 .62833 .50802 .63341 .51753 .63066 .51233 .62556 Mtetra
.51233 .62556 .51753 .63066 .52708 .6279 .52189 .62279 Mtetra
.52189 .62279 .52708 .6279 .53665 .62513 .53149 .62 Mtetra
.53149 .62 .53665 .62513 .54626 .62236 .54112 .61721 Mtetra
.54112 .61721 .54626 .62236 .55591 .61957 .55079 .6144 Mtetra
.55079 .6144 .55591 .61957 .56558 .61677 .56049 .61159 Mtetra
.56049 .61159 .56558 .61677 .57529 .61397 .57022 .60876 Mtetra
.57022 .60876 .57529 .61397 .58504 .61115 .57999 .60593 Mtetra
.57999 .60593 .58504 .61115 .59482 .60833 .58979 .60308 Mtetra
.58979 .60308 .59482 .60833 .60463 .60549 .59963 .60023 Mtetra
.59963 .60023 .60463 .60549 .61448 .60265 .6095 .59737 Mtetra
.6095 .59737 .61448 .60265 .62437 .59979 .61941 .59449 Mtetra
.61941 .59449 .62437 .59979 .63428 .59692 .62935 .59161 Mtetra
.62935 .59161 .63428 .59692 .64424 .59405 .63933 .58871 Mtetra
.63933 .58871 .64424 .59405 .65423 .59116 .64934 .58581 Mtetra
.64934 .58581 .65423 .59116 .66425 .58826 .65939 .58289 Mtetra
.65939 .58289 .66425 .58826 .67431 .58536 .66947 .57996 Mtetra
.66947 .57996 .67431 .58536 .68441 .58244 .67959 .57703 Mtetra
.67959 .57703 .68441 .58244 .69454 .57951 .68975 .57408 Mtetra
.68975 .57408 .69454 .57951 .70471 .57657 .69995 .57112 Mtetra
.69995 .57112 .70471 .57657 .71491 .57363 .71018 .56815 Mtetra
.71018 .56815 .71491 .57363 .72516 .57067 .72044 .56517 Mtetra
.72044 .56517 .72516 .57067 .73544 .5677 .73075 .56218 Mtetra
.73075 .56218 .73544 .5677 .74575 .56471 .74109 .55918 Mtetra
.74109 .55918 .74575 .56471 .75611 .56172 .75147 .55617 Mtetra
.75147 .55617 .75611 .56172 .7665 .55872 .76189 .55315 Mtetra
.76189 .55315 .7665 .55872 .77693 .55571 .77234 .55012 Mtetra
.77234 .55012 .77693 .55571 .78739 .55268 .78284 .54707 Mtetra
.78284 .54707 .78739 .55268 .7979 .54965 .79337 .54401 Mtetra
.79337 .54401 .7979 .54965 .80844 .5466 .80394 .54095 Mtetra
.80394 .54095 .80844 .5466 .81902 .54354 .81455 .53787 Mtetra
.81455 .53787 .81902 .54354 .82964 .54047 .8252 .53478 Mtetra
.8252 .53478 .82964 .54047 .8403 .53739 .83589 .53168 Mtetra
.83589 .53168 .8403 .53739 .851 .5343 .84661 .52857 Mtetra
.84661 .52857 .851 .5343 .86174 .5312 .85738 .52544 Mtetra
.85738 .52544 .86174 .5312 .87252 .52809 .86819 .52231 Mtetra
.86819 .52231 .87252 .52809 .88334 .52496 .87903 .51916 Mtetra
.87903 .51916 .88334 .52496 .89419 .52182 .88992 .516 Mtetra
.88992 .516 .89419 .52182 .90509 .51867 .90085 .51283 Mtetra
.90085 .51283 .90509 .51867 .91603 .51551 .91182 .50965 Mtetra
.91182 .50965 .91603 .51551 .92701 .51234 .92283 .50645 Mtetra
.92283 .50645 .92701 .51234 .93803 .50916 .93388 .50324 Mtetra
.93388 .50324 .93803 .50916 .94909 .50596 .94497 .50003 Mtetra
.94497 .50003 .94909 .50596 .9602 .50275 .9561 .4968 Mtetra
.35813 .66383 .36369 .66869 .37275 .66606 .3672 .66119 Mtetra
.3672 .66119 .37275 .66606 .38183 .66342 .3763 .65854 Mtetra
.3763 .65854 .38183 .66342 .39094 .66078 .38544 .65587 Mtetra
.38544 .65587 .39094 .66078 .40009 .65813 .3946 .6532 Mtetra
.3946 .6532 .40009 .65813 .40927 .65546 .4038 .65052 Mtetra
.4038 .65052 .40927 .65546 .41848 .65279 .41303 .64783 Mtetra
.41303 .64783 .41848 .65279 .42772 .65011 .42229 .64514 Mtetra
.42229 .64514 .42772 .65011 .43699 .64742 .43158 .64243 Mtetra
.43158 .64243 .43699 .64742 .44629 .64472 .4409 .63971 Mtetra
.4409 .63971 .44629 .64472 .45563 .64201 .45026 .63699 Mtetra
.45026 .63699 .45563 .64201 .465 .63929 .45965 .63425 Mtetra
.45965 .63425 .465 .63929 .4744 .63657 .46907 .63151 Mtetra
.46907 .63151 .4744 .63657 .48383 .63383 .47853 .62875 Mtetra
.47853 .62875 .48383 .63383 .4933 .63108 .48801 .62599 Mtetra
.48801 .62599 .4933 .63108 .50279 .62833 .49753 .62321 Mtetra
.49753 .62321 .50279 .62833 .51233 .62556 .50709 .62043 Mtetra
.50709 .62043 .51233 .62556 .52189 .62279 .51667 .61764 Mtetra
.51667 .61764 .52189 .62279 .53149 .62 .52629 .61483 Mtetra
.52629 .61483 .53149 .62 .54112 .61721 .53595 .61202 Mtetra
.53595 .61202 .54112 .61721 .55079 .6144 .54563 .6092 Mtetra
.54563 .6092 .55079 .6144 .56049 .61159 .55536 .60636 Mtetra
.55536 .60636 .56049 .61159 .57022 .60876 .56511 .60352 Mtetra
.56511 .60352 .57022 .60876 .57999 .60593 .5749 .60067 Mtetra
.5749 .60067 .57999 .60593 .58979 .60308 .58473 .59781 Mtetra
.58473 .59781 .58979 .60308 .59963 .60023 .59459 .59493 Mtetra
.59459 .59493 .59963 .60023 .6095 .59737 .60448 .59205 Mtetra
.60448 .59205 .6095 .59737 .61941 .59449 .61441 .58916 Mtetra
.61441 .58916 .61941 .59449 .62935 .59161 .62438 .58625 Mtetra
.62438 .58625 .62935 .59161 .63933 .58871 .63438 .58334 Mtetra
.63438 .58334 .63933 .58871 .64934 .58581 .64442 .58041 Mtetra
.64442 .58041 .64934 .58581 .65939 .58289 .65449 .57748 Mtetra
.65449 .57748 .65939 .58289 .66947 .57996 .6646 .57453 Mtetra
.6646 .57453 .66947 .57996 .67959 .57703 .67475 .57158 Mtetra
.67475 .57158 .67959 .57703 .68975 .57408 .68493 .56861 Mtetra
.68493 .56861 .68975 .57408 .69995 .57112 .69515 .56563 Mtetra
.69515 .56563 .69995 .57112 .71018 .56815 .70541 .56264 Mtetra
.70541 .56264 .71018 .56815 .72044 .56517 .7157 .55965 Mtetra
.7157 .55965 .72044 .56517 .73075 .56218 .72603 .55664 Mtetra
.72603 .55664 .73075 .56218 .74109 .55918 .7364 .55361 Mtetra
.7364 .55361 .74109 .55918 .75147 .55617 .7468 .55058 Mtetra
.7468 .55058 .75147 .55617 .76189 .55315 .75725 .54754 Mtetra
.75725 .54754 .76189 .55315 .77234 .55012 .76773 .54449 Mtetra
.76773 .54449 .77234 .55012 .78284 .54707 .77825 .54142 Mtetra
.77825 .54142 .78284 .54707 .79337 .54401 .78881 .53834 Mtetra
.78881 .53834 .79337 .54401 .80394 .54095 .79941 .53526 Mtetra
.79941 .53526 .80394 .54095 .81455 .53787 .81005 .53216 Mtetra
.81005 .53216 .81455 .53787 .8252 .53478 .82072 .52905 Mtetra
.82072 .52905 .8252 .53478 .83589 .53168 .83144 .52592 Mtetra
.83144 .52592 .83589 .53168 .84661 .52857 .84219 .52279 Mtetra
.84219 .52279 .84661 .52857 .85738 .52544 .85299 .51964 Mtetra
.85299 .51964 .85738 .52544 .86819 .52231 .86383 .51649 Mtetra
.86383 .51649 .86819 .52231 .87903 .51916 .8747 .51332 Mtetra
.8747 .51332 .87903 .51916 .88992 .516 .88562 .51014 Mtetra
.88562 .51014 .88992 .516 .90085 .51283 .89658 .50694 Mtetra
.89658 .50694 .90085 .51283 .91182 .50965 .90758 .50374 Mtetra
.90758 .50374 .91182 .50965 .92283 .50645 .91862 .50052 Mtetra
.91862 .50052 .92283 .50645 .93388 .50324 .9297 .49729 Mtetra
.9297 .49729 .93388 .50324 .94497 .50003 .94082 .49405 Mtetra
.94082 .49405 .94497 .50003 .9561 .4968 .95198 .4908 Mtetra
.35253 .65894 .35813 .66383 .3672 .66119 .36162 .65628 Mtetra
.36162 .65628 .3672 .66119 .3763 .65854 .37074 .65361 Mtetra
.37074 .65361 .3763 .65854 .38544 .65587 .3799 .65094 Mtetra
.3799 .65094 .38544 .65587 .3946 .6532 .38908 .64825 Mtetra
.38908 .64825 .3946 .6532 .4038 .65052 .3983 .64555 Mtetra
.3983 .64555 .4038 .65052 .41303 .64783 .40755 .64285 Mtetra
.40755 .64285 .41303 .64783 .42229 .64514 .41683 .64013 Mtetra
.41683 .64013 .42229 .64514 .43158 .64243 .42614 .63741 Mtetra
.42614 .63741 .43158 .64243 .4409 .63971 .43548 .63467 Mtetra
.43548 .63467 .4409 .63971 .45026 .63699 .44486 .63193 Mtetra
.44486 .63193 .45026 .63699 .45965 .63425 .45427 .62918 Mtetra
.45427 .62918 .45965 .63425 .46907 .63151 .46371 .62641 Mtetra
.46371 .62641 .46907 .63151 .47853 .62875 .47319 .62364 Mtetra
.47319 .62364 .47853 .62875 .48801 .62599 .48269 .62086 Mtetra
.48269 .62086 .48801 .62599 .49753 .62321 .49224 .61807 Mtetra
.49224 .61807 .49753 .62321 .50709 .62043 .50181 .61527 Mtetra
.50181 .61527 .50709 .62043 .51667 .61764 .51142 .61245 Mtetra
.51142 .61245 .51667 .61764 .52629 .61483 .52106 .60963 Mtetra
.52106 .60963 .52629 .61483 .53595 .61202 .53074 .6068 Mtetra
.53074 .6068 .53595 .61202 .54563 .6092 .54045 .60396 Mtetra
.54045 .60396 .54563 .6092 .55536 .60636 .55019 .60111 Mtetra
.55019 .60111 .55536 .60636 .56511 .60352 .55997 .59825 Mtetra
.55997 .59825 .56511 .60352 .5749 .60067 .56978 .59538 Mtetra
.56978 .59538 .5749 .60067 .58473 .59781 .57963 .59249 Mtetra
.57963 .59249 .58473 .59781 .59459 .59493 .58952 .5896 Mtetra
.58952 .5896 .59459 .59493 .60448 .59205 .59944 .5867 Mtetra
.59944 .5867 .60448 .59205 .61441 .58916 .60939 .58379 Mtetra
.60939 .58379 .61441 .58916 .62438 .58625 .61938 .58087 Mtetra
.61938 .58087 .62438 .58625 .63438 .58334 .62941 .57793 Mtetra
.62941 .57793 .63438 .58334 .64442 .58041 .63947 .57499 Mtetra
.63947 .57499 .64442 .58041 .65449 .57748 .64957 .57203 Mtetra
.64957 .57203 .65449 .57748 .6646 .57453 .6597 .56907 Mtetra
.6597 .56907 .6646 .57453 .67475 .57158 .66987 .56609 Mtetra
.66987 .56609 .67475 .57158 .68493 .56861 .68008 .56311 Mtetra
.68008 .56311 .68493 .56861 .69515 .56563 .69032 .56011 Mtetra
.69032 .56011 .69515 .56563 .70541 .56264 .7006 .5571 Mtetra
.7006 .5571 .70541 .56264 .7157 .55965 .71092 .55408 Mtetra
.71092 .55408 .7157 .55965 .72603 .55664 .72128 .55105 Mtetra
.72128 .55105 .72603 .55664 .7364 .55361 .73168 .54801 Mtetra
.73168 .54801 .7364 .55361 .7468 .55058 .74211 .54496 Mtetra
.74211 .54496 .7468 .55058 .75725 .54754 .75258 .54189 Mtetra
.75258 .54189 .75725 .54754 .76773 .54449 .76309 .53882 Mtetra
.76309 .53882 .76773 .54449 .77825 .54142 .77364 .53573 Mtetra
.77364 .53573 .77825 .54142 .78881 .53834 .78422 .53263 Mtetra
.78422 .53263 .78881 .53834 .79941 .53526 .79485 .52952 Mtetra
.79485 .52952 .79941 .53526 .81005 .53216 .80551 .5264 Mtetra
.80551 .5264 .81005 .53216 .82072 .52905 .81622 .52327 Mtetra
.81622 .52327 .82072 .52905 .83144 .52592 .82696 .52013 Mtetra
.82696 .52013 .83144 .52592 .84219 .52279 .83775 .51697 Mtetra
.83775 .51697 .84219 .52279 .85299 .51964 .84857 .51381 Mtetra
.84857 .51381 .85299 .51964 .86383 .51649 .85944 .51063 Mtetra
.85944 .51063 .86383 .51649 .8747 .51332 .87034 .50744 Mtetra
.87034 .50744 .8747 .51332 .88562 .51014 .88129 .50423 Mtetra
.88129 .50423 .88562 .51014 .89658 .50694 .89227 .50102 Mtetra
.89227 .50102 .89658 .50694 .90758 .50374 .9033 .49779 Mtetra
.9033 .49779 .90758 .50374 .91862 .50052 .91437 .49455 Mtetra
.91437 .49455 .91862 .50052 .9297 .49729 .92549 .4913 Mtetra
.92549 .4913 .9297 .49729 .94082 .49405 .93664 .48804 Mtetra
.93664 .48804 .94082 .49405 .95198 .4908 .94784 .48476 Mtetra
.34689 .65403 .35253 .65894 .36162 .65628 .356 .65135 Mtetra
.356 .65135 .36162 .65628 .37074 .65361 .36515 .64866 Mtetra
.36515 .64866 .37074 .65361 .3799 .65094 .37432 .64597 Mtetra
.37432 .64597 .3799 .65094 .38908 .64825 .38352 .64326 Mtetra
.38352 .64326 .38908 .64825 .3983 .64555 .39276 .64055 Mtetra
.39276 .64055 .3983 .64555 .40755 .64285 .40203 .63783 Mtetra
.40203 .63783 .40755 .64285 .41683 .64013 .41133 .63509 Mtetra
.41133 .63509 .41683 .64013 .42614 .63741 .42066 .63235 Mtetra
.42066 .63235 .42614 .63741 .43548 .63467 .43003 .6296 Mtetra
.43003 .6296 .43548 .63467 .44486 .63193 .43942 .62684 Mtetra
.43942 .62684 .44486 .63193 .45427 .62918 .44885 .62407 Mtetra
.44885 .62407 .45427 .62918 .46371 .62641 .45832 .62129 Mtetra
.45832 .62129 .46371 .62641 .47319 .62364 .46781 .6185 Mtetra
.46781 .6185 .47319 .62364 .48269 .62086 .47734 .6157 Mtetra
.47734 .6157 .48269 .62086 .49224 .61807 .4869 .61289 Mtetra
.4869 .61289 .49224 .61807 .50181 .61527 .4965 .61007 Mtetra
.4965 .61007 .50181 .61527 .51142 .61245 .50613 .60724 Mtetra
.50613 .60724 .51142 .61245 .52106 .60963 .5158 .6044 Mtetra
.5158 .6044 .52106 .60963 .53074 .6068 .52549 .60155 Mtetra
.52549 .60155 .53074 .6068 .54045 .60396 .53523 .59869 Mtetra
.53523 .59869 .54045 .60396 .55019 .60111 .54499 .59582 Mtetra
.54499 .59582 .55019 .60111 .55997 .59825 .5548 .59294 Mtetra
.5548 .59294 .55997 .59825 .56978 .59538 .56463 .59005 Mtetra
.56463 .59005 .56978 .59538 .57963 .59249 .5745 .58715 Mtetra
.5745 .58715 .57963 .59249 .58952 .5896 .58441 .58424 Mtetra
.58441 .58424 .58952 .5896 .59944 .5867 .59435 .58132 Mtetra
.59435 .58132 .59944 .5867 .60939 .58379 .60433 .57838 Mtetra
.60433 .57838 .60939 .58379 .61938 .58087 .61435 .57544 Mtetra
.61435 .57544 .61938 .58087 .62941 .57793 .6244 .57249 Mtetra
.6244 .57249 .62941 .57793 .63947 .57499 .63448 .56952 Mtetra
.63448 .56952 .63947 .57499 .64957 .57203 .6446 .56655 Mtetra
.6446 .56655 .64957 .57203 .6597 .56907 .65476 .56357 Mtetra
.65476 .56357 .6597 .56907 .66987 .56609 .66496 .56057 Mtetra
.66496 .56057 .66987 .56609 .68008 .56311 .67519 .55756 Mtetra
.67519 .55756 .68008 .56311 .69032 .56011 .68546 .55455 Mtetra
.68546 .55455 .69032 .56011 .7006 .5571 .69577 .55152 Mtetra
.69577 .55152 .7006 .5571 .71092 .55408 .70612 .54848 Mtetra
.70612 .54848 .71092 .55408 .72128 .55105 .7165 .54543 Mtetra
.7165 .54543 .72128 .55105 .73168 .54801 .72692 .54236 Mtetra
.72692 .54236 .73168 .54801 .74211 .54496 .73738 .53929 Mtetra
.73738 .53929 .74211 .54496 .75258 .54189 .74788 .53621 Mtetra
.74788 .53621 .75258 .54189 .76309 .53882 .75841 .53311 Mtetra
.75841 .53311 .76309 .53882 .77364 .53573 .76899 .53 Mtetra
.76899 .53 .77364 .53573 .78422 .53263 .7796 .52688 Mtetra
.7796 .52688 .78422 .53263 .79485 .52952 .79026 .52375 Mtetra
.79026 .52375 .79485 .52952 .80551 .5264 .80095 .52061 Mtetra
.80095 .52061 .80551 .5264 .81622 .52327 .81168 .51746 Mtetra
.81168 .51746 .81622 .52327 .82696 .52013 .82245 .51429 Mtetra
.82245 .51429 .82696 .52013 .83775 .51697 .83327 .51112 Mtetra
.83327 .51112 .83775 .51697 .84857 .51381 .84412 .50793 Mtetra
.84412 .50793 .84857 .51381 .85944 .51063 .85501 .50473 Mtetra
.85501 .50473 .85944 .51063 .87034 .50744 .86595 .50151 Mtetra
.86595 .50151 .87034 .50744 .88129 .50423 .87693 .49829 Mtetra
.87693 .49829 .88129 .50423 .89227 .50102 .88794 .49505 Mtetra
.88794 .49505 .89227 .50102 .9033 .49779 .899 .4918 Mtetra
.899 .4918 .9033 .49779 .91437 .49455 .9101 .48854 Mtetra
.9101 .48854 .91437 .49455 .92549 .4913 .92125 .48527 Mtetra
.92125 .48527 .92549 .4913 .93664 .48804 .93243 .48198 Mtetra
.93243 .48198 .93664 .48804 .94784 .48476 .94366 .47868 Mtetra
.34122 .64908 .34689 .65403 .356 .65135 .35035 .64638 Mtetra
.35035 .64638 .356 .65135 .36515 .64866 .35951 .64368 Mtetra
.35951 .64368 .36515 .64866 .37432 .64597 .36871 .64097 Mtetra
.36871 .64097 .37432 .64597 .38352 .64326 .37793 .63825 Mtetra
.37793 .63825 .38352 .64326 .39276 .64055 .38719 .63551 Mtetra
.38719 .63551 .39276 .64055 .40203 .63783 .39647 .63277 Mtetra
.39647 .63277 .40203 .63783 .41133 .63509 .40579 .63002 Mtetra
.40579 .63002 .41133 .63509 .42066 .63235 .41515 .62726 Mtetra
.41515 .62726 .42066 .63235 .43003 .6296 .42453 .62449 Mtetra
.42453 .62449 .43003 .6296 .43942 .62684 .43395 .62172 Mtetra
.43395 .62172 .43942 .62684 .44885 .62407 .4434 .61893 Mtetra
.4434 .61893 .44885 .62407 .45832 .62129 .45289 .61613 Mtetra
.45289 .61613 .45832 .62129 .46781 .6185 .4624 .61332 Mtetra
.4624 .61332 .46781 .6185 .47734 .6157 .47195 .6105 Mtetra
.47195 .6105 .47734 .6157 .4869 .61289 .48154 .60767 Mtetra
.48154 .60767 .4869 .61289 .4965 .61007 .49116 .60484 Mtetra
.49116 .60484 .4965 .61007 .50613 .60724 .50081 .60199 Mtetra
.50081 .60199 .50613 .60724 .5158 .6044 .5105 .59913 Mtetra
.5105 .59913 .5158 .6044 .52549 .60155 .52022 .59626 Mtetra
.52022 .59626 .52549 .60155 .53523 .59869 .52997 .59338 Mtetra
.52997 .59338 .53523 .59869 .54499 .59582 .53976 .59049 Mtetra
.53976 .59049 .54499 .59582 .5548 .59294 .54959 .58759 Mtetra
.54959 .58759 .5548 .59294 .56463 .59005 .55945 .58469 Mtetra
.55945 .58469 .56463 .59005 .5745 .58715 .56934 .58177 Mtetra
.56934 .58177 .5745 .58715 .58441 .58424 .57927 .57884 Mtetra
.57927 .57884 .58441 .58424 .59435 .58132 .58924 .57589 Mtetra
.58924 .57589 .59435 .58132 .60433 .57838 .59924 .57294 Mtetra
.59924 .57294 .60433 .57838 .61435 .57544 .60928 .56998 Mtetra
.60928 .56998 .61435 .57544 .6244 .57249 .61935 .56701 Mtetra
.61935 .56701 .6244 .57249 .63448 .56952 .62946 .56403 Mtetra
.62946 .56403 .63448 .56952 .6446 .56655 .63961 .56103 Mtetra
.63961 .56103 .6446 .56655 .65476 .56357 .64979 .55803 Mtetra
.64979 .55803 .65476 .56357 .66496 .56057 .66002 .55501 Mtetra
.66002 .55501 .66496 .56057 .67519 .55756 .67027 .55198 Mtetra
.67027 .55198 .67519 .55756 .68546 .55455 .68057 .54895 Mtetra
.68057 .54895 .68546 .55455 .69577 .55152 .6909 .5459 Mtetra
.6909 .5459 .69577 .55152 .70612 .54848 .70127 .54284 Mtetra
.70127 .54284 .70612 .54848 .7165 .54543 .71168 .53976 Mtetra
.71168 .53976 .7165 .54543 .72692 .54236 .72213 .53668 Mtetra
.72213 .53668 .72692 .54236 .73738 .53929 .73262 .53359 Mtetra
.73262 .53359 .73738 .53929 .74788 .53621 .74314 .53048 Mtetra
.74314 .53048 .74788 .53621 .75841 .53311 .75371 .52737 Mtetra
.75371 .52737 .75841 .53311 .76899 .53 .76431 .52424 Mtetra
.76431 .52424 .76899 .53 .7796 .52688 .77495 .5211 Mtetra
.77495 .5211 .7796 .52688 .79026 .52375 .78563 .51794 Mtetra
.78563 .51794 .79026 .52375 .80095 .52061 .79635 .51478 Mtetra
.79635 .51478 .80095 .52061 .81168 .51746 .80711 .51161 Mtetra
.80711 .51161 .81168 .51746 .82245 .51429 .81792 .50842 Mtetra
.81792 .50842 .82245 .51429 .83327 .51112 .82876 .50522 Mtetra
.82876 .50522 .83327 .51112 .84412 .50793 .83964 .50201 Mtetra
.83964 .50201 .84412 .50793 .85501 .50473 .85056 .49879 Mtetra
.85056 .49879 .85501 .50473 .86595 .50151 .86153 .49555 Mtetra
.86153 .49555 .86595 .50151 .87693 .49829 .87253 .4923 Mtetra
.87253 .4923 .87693 .49829 .88794 .49505 .88358 .48904 Mtetra
.88358 .48904 .88794 .49505 .899 .4918 .89467 .48577 Mtetra
.89467 .48577 .899 .4918 .9101 .48854 .9058 .48249 Mtetra
.9058 .48249 .9101 .48854 .92125 .48527 .91698 .47919 Mtetra
.91698 .47919 .92125 .48527 .93243 .48198 .92819 .47588 Mtetra
.92819 .47588 .93243 .48198 .94366 .47868 .93945 .47256 Mtetra
.33552 .6441 .34122 .64908 .35035 .64638 .34467 .64139 Mtetra
.34467 .64139 .35035 .64638 .35951 .64368 .35385 .63867 Mtetra
.35385 .63867 .35951 .64368 .36871 .64097 .36306 .63594 Mtetra
.36306 .63594 .36871 .64097 .37793 .63825 .3723 .6332 Mtetra
.3723 .6332 .37793 .63825 .38719 .63551 .38158 .63045 Mtetra
.38158 .63045 .38719 .63551 .39647 .63277 .39089 .62769 Mtetra
.39089 .62769 .39647 .63277 .40579 .63002 .40023 .62492 Mtetra
.40023 .62492 .40579 .63002 .41515 .62726 .4096 .62214 Mtetra
.4096 .62214 .41515 .62726 .42453 .62449 .41901 .61936 Mtetra
.41901 .61936 .42453 .62449 .43395 .62172 .42844 .61656 Mtetra
.42844 .61656 .43395 .62172 .4434 .61893 .43792 .61375 Mtetra
.43792 .61375 .4434 .61893 .45289 .61613 .44742 .61094 Mtetra
.44742 .61094 .45289 .61613 .4624 .61332 .45696 .60811 Mtetra
.45696 .60811 .4624 .61332 .47195 .6105 .46653 .60527 Mtetra
.46653 .60527 .47195 .6105 .48154 .60767 .47614 .60243 Mtetra
.47614 .60243 .48154 .60767 .49116 .60484 .48578 .59957 Mtetra
.48578 .59957 .49116 .60484 .50081 .60199 .49545 .5967 Mtetra
.49545 .5967 .50081 .60199 .5105 .59913 .50516 .59383 Mtetra
.50516 .59383 .5105 .59913 .52022 .59626 .5149 .59094 Mtetra
.5149 .59094 .52022 .59626 .52997 .59338 .52468 .58804 Mtetra
.52468 .58804 .52997 .59338 .53976 .59049 .5345 .58513 Mtetra
.5345 .58513 .53976 .59049 .54959 .58759 .54434 .58222 Mtetra
.54434 .58222 .54959 .58759 .55945 .58469 .55423 .57929 Mtetra
.55423 .57929 .55945 .58469 .56934 .58177 .56414 .57635 Mtetra
.56414 .57635 .56934 .58177 .57927 .57884 .5741 .5734 Mtetra
.5741 .5734 .57927 .57884 .58924 .57589 .58409 .57044 Mtetra
.58409 .57044 .58924 .57589 .59924 .57294 .59412 .56747 Mtetra
.59412 .56747 .59924 .57294 .60928 .56998 .60418 .56449 Mtetra
.60418 .56449 .60928 .56998 .61935 .56701 .61428 .56149 Mtetra
.61428 .56149 .61935 .56701 .62946 .56403 .62441 .55849 Mtetra
.62441 .55849 .62946 .56403 .63961 .56103 .63458 .55547 Mtetra
.63458 .55547 .63961 .56103 .64979 .55803 .64479 .55245 Mtetra
.64479 .55245 .64979 .55803 .66002 .55501 .65504 .54941 Mtetra
.65504 .54941 .66002 .55501 .67027 .55198 .66532 .54637 Mtetra
.66532 .54637 .67027 .55198 .68057 .54895 .67564 .54331 Mtetra
.67564 .54331 .68057 .54895 .6909 .5459 .686 .54024 Mtetra
.686 .54024 .6909 .5459 .70127 .54284 .6964 .53716 Mtetra
.6964 .53716 .70127 .54284 .71168 .53976 .70684 .53406 Mtetra
.70684 .53406 .71168 .53976 .72213 .53668 .71731 .53096 Mtetra
.71731 .53096 .72213 .53668 .73262 .53359 .72782 .52785 Mtetra
.72782 .52785 .73262 .53359 .74314 .53048 .73838 .52472 Mtetra
.73838 .52472 .74314 .53048 .75371 .52737 .74897 .52158 Mtetra
.74897 .52158 .75371 .52737 .76431 .52424 .7596 .51843 Mtetra
.7596 .51843 .76431 .52424 .77495 .5211 .77027 .51527 Mtetra
.77027 .51527 .77495 .5211 .78563 .51794 .78098 .5121 Mtetra
.78098 .5121 .78563 .51794 .79635 .51478 .79173 .50891 Mtetra
.79173 .50891 .79635 .51478 .80711 .51161 .80251 .50571 Mtetra
.80251 .50571 .80711 .51161 .81792 .50842 .81335 .5025 Mtetra
.81335 .5025 .81792 .50842 .82876 .50522 .82422 .49928 Mtetra
.82422 .49928 .82876 .50522 .83964 .50201 .83513 .49605 Mtetra
.83513 .49605 .83964 .50201 .85056 .49879 .84608 .4928 Mtetra
.84608 .4928 .85056 .49879 .86153 .49555 .85707 .48955 Mtetra
.85707 .48955 .86153 .49555 .87253 .4923 .86811 .48627 Mtetra
.86811 .48627 .87253 .4923 .88358 .48904 .87919 .48299 Mtetra
.87919 .48299 .88358 .48904 .89467 .48577 .89031 .4797 Mtetra
.89031 .4797 .89467 .48577 .9058 .48249 .90147 .47639 Mtetra
.90147 .47639 .9058 .48249 .91698 .47919 .91268 .47307 Mtetra
.91268 .47307 .91698 .47919 .92819 .47588 .92392 .46974 Mtetra
.92392 .46974 .92819 .47588 .93945 .47256 .93521 .46639 Mtetra
.32977 .63908 .33552 .6441 .34467 .64139 .33894 .63636 Mtetra
.33894 .63636 .34467 .64139 .35385 .63867 .34814 .63362 Mtetra
.34814 .63362 .35385 .63867 .36306 .63594 .35737 .63087 Mtetra
.35737 .63087 .36306 .63594 .3723 .6332 .36664 .62811 Mtetra
.36664 .62811 .3723 .6332 .38158 .63045 .37593 .62535 Mtetra
.37593 .62535 .38158 .63045 .39089 .62769 .38526 .62257 Mtetra
.38526 .62257 .39089 .62769 .40023 .62492 .39462 .61979 Mtetra
.39462 .61979 .40023 .62492 .4096 .62214 .40402 .61699 Mtetra
.40402 .61699 .4096 .62214 .41901 .61936 .41344 .61419 Mtetra
.41344 .61419 .41901 .61936 .42844 .61656 .4229 .61137 Mtetra
.4229 .61137 .42844 .61656 .43792 .61375 .43239 .60854 Mtetra
.43239 .60854 .43792 .61375 .44742 .61094 .44192 .60571 Mtetra
.44192 .60571 .44742 .61094 .45696 .60811 .45148 .60286 Mtetra
.45148 .60286 .45696 .60811 .46653 .60527 .46108 .60001 Mtetra
.46108 .60001 .46653 .60527 .47614 .60243 .4707 .59714 Mtetra
.4707 .59714 .47614 .60243 .48578 .59957 .48037 .59427 Mtetra
.48037 .59427 .48578 .59957 .49545 .5967 .49006 .59138 Mtetra
.49006 .59138 .49545 .5967 .50516 .59383 .49979 .58849 Mtetra
.49979 .58849 .50516 .59383 .5149 .59094 .50956 .58558 Mtetra
.50956 .58558 .5149 .59094 .52468 .58804 .51936 .58267 Mtetra
.51936 .58267 .52468 .58804 .5345 .58513 .52919 .57974 Mtetra
.52919 .57974 .5345 .58513 .54434 .58222 .53907 .5768 Mtetra
.53907 .5768 .54434 .58222 .55423 .57929 .54897 .57385 Mtetra
.54897 .57385 .55423 .57929 .56414 .57635 .55891 .57089 Mtetra
.55891 .57089 .56414 .57635 .5741 .5734 .56889 .56792 Mtetra
.56889 .56792 .5741 .5734 .58409 .57044 .57891 .56494 Mtetra
.57891 .56494 .58409 .57044 .59412 .56747 .58896 .56195 Mtetra
.58896 .56195 .59412 .56747 .60418 .56449 .59904 .55895 Mtetra
.59904 .55895 .60418 .56449 .61428 .56149 .60917 .55594 Mtetra
.60917 .55594 .61428 .56149 .62441 .55849 .61933 .55292 Mtetra
.61933 .55292 .62441 .55849 .63458 .55547 .62952 .54988 Mtetra
.62952 .54988 .63458 .55547 .64479 .55245 .63976 .54684 Mtetra
.63976 .54684 .64479 .55245 .65504 .54941 .65003 .54378 Mtetra
.65003 .54378 .65504 .54941 .66532 .54637 .66034 .54071 Mtetra
.66034 .54071 .66532 .54637 .67564 .54331 .67069 .53763 Mtetra
.67069 .53763 .67564 .54331 .686 .54024 .68107 .53454 Mtetra
.68107 .53454 .686 .54024 .6964 .53716 .69149 .53144 Mtetra
.69149 .53144 .6964 .53716 .70684 .53406 .70196 .52833 Mtetra
.70196 .52833 .70684 .53406 .71731 .53096 .71246 .5252 Mtetra
.71246 .5252 .71731 .53096 .72782 .52785 .723 .52206 Mtetra
.723 .52206 .72782 .52785 .73838 .52472 .73358 .51892 Mtetra
.73358 .51892 .73838 .52472 .74897 .52158 .74419 .51576 Mtetra
.74419 .51576 .74897 .52158 .7596 .51843 .75485 .51258 Mtetra
.75485 .51258 .7596 .51843 .77027 .51527 .76555 .5094 Mtetra
.76555 .5094 .77027 .51527 .78098 .5121 .77629 .50621 Mtetra
.77629 .50621 .78098 .5121 .79173 .50891 .78707 .503 Mtetra
.78707 .503 .79173 .50891 .80251 .50571 .79788 .49978 Mtetra
.79788 .49978 .80251 .50571 .81335 .5025 .80874 .49655 Mtetra
.80874 .49655 .81335 .5025 .82422 .49928 .81964 .4933 Mtetra
.81964 .4933 .82422 .49928 .83513 .49605 .83058 .49005 Mtetra
.83058 .49005 .83513 .49605 .84608 .4928 .84157 .48678 Mtetra
.84157 .48678 .84608 .4928 .85707 .48955 .85259 .4835 Mtetra
.85259 .4835 .85707 .48955 .86811 .48627 .86366 .48021 Mtetra
.86366 .48021 .86811 .48627 .87919 .48299 .87477 .4769 Mtetra
.87477 .4769 .87919 .48299 .89031 .4797 .88592 .47358 Mtetra
.88592 .47358 .89031 .4797 .90147 .47639 .89711 .47025 Mtetra
.89711 .47025 .90147 .47639 .91268 .47307 .90834 .46691 Mtetra
.90834 .46691 .91268 .47307 .92392 .46974 .91962 .46355 Mtetra
.91962 .46355 .92392 .46974 .93521 .46639 .93095 .46018 Mtetra
.32399 .63404 .32977 .63908 .33894 .63636 .33318 .63129 Mtetra
.33318 .63129 .33894 .63636 .34814 .63362 .3424 .62854 Mtetra
.3424 .62854 .34814 .63362 .35737 .63087 .35165 .62577 Mtetra
.35165 .62577 .35737 .63087 .36664 .62811 .36094 .623 Mtetra
.36094 .623 .36664 .62811 .37593 .62535 .37025 .62022 Mtetra
.37025 .62022 .37593 .62535 .38526 .62257 .3796 .61742 Mtetra
.3796 .61742 .38526 .62257 .39462 .61979 .38898 .61462 Mtetra
.38898 .61462 .39462 .61979 .40402 .61699 .3984 .6118 Mtetra
.3984 .6118 .40402 .61699 .41344 .61419 .40784 .60898 Mtetra
.40784 .60898 .41344 .61419 .4229 .61137 .41732 .60615 Mtetra
.41732 .60615 .4229 .61137 .43239 .60854 .42684 .6033 Mtetra
.42684 .6033 .43239 .60854 .44192 .60571 .43639 .60045 Mtetra
.43639 .60045 .44192 .60571 .45148 .60286 .44597 .59759 Mtetra
.44597 .59759 .45148 .60286 .46108 .60001 .45558 .59471 Mtetra
.45558 .59471 .46108 .60001 .4707 .59714 .46523 .59183 Mtetra
.46523 .59183 .4707 .59714 .48037 .59427 .47492 .58893 Mtetra
.47492 .58893 .48037 .59427 .49006 .59138 .48463 .58603 Mtetra
.48463 .58603 .49006 .59138 .49979 .58849 .49439 .58311 Mtetra
.49439 .58311 .49979 .58849 .50956 .58558 .50418 .58019 Mtetra
.50418 .58019 .50956 .58558 .51936 .58267 .514 .57725 Mtetra
.514 .57725 .51936 .58267 .52919 .57974 .52386 .57431 Mtetra
.52386 .57431 .52919 .57974 .53907 .5768 .53375 .57135 Mtetra
.53375 .57135 .53907 .5768 .54897 .57385 .54368 .56838 Mtetra
.54368 .56838 .54897 .57385 .55891 .57089 .55365 .5654 Mtetra
.55365 .5654 .55891 .57089 .56889 .56792 .56365 .56241 Mtetra
.56365 .56241 .56889 .56792 .57891 .56494 .57369 .55941 Mtetra
.57369 .55941 .57891 .56494 .58896 .56195 .58376 .5564 Mtetra
.58376 .5564 .58896 .56195 .59904 .55895 .59387 .55338 Mtetra
.59387 .55338 .59904 .55895 .60917 .55594 .60402 .55035 Mtetra
.60402 .55035 .60917 .55594 .61933 .55292 .61421 .5473 Mtetra
.61421 .5473 .61933 .55292 .62952 .54988 .62443 .54425 Mtetra
.62443 .54425 .62952 .54988 .63976 .54684 .63469 .54118 Mtetra
.63469 .54118 .63976 .54684 .65003 .54378 .64498 .53811 Mtetra
.64498 .53811 .65003 .54378 .66034 .54071 .65532 .53502 Mtetra
.65532 .53502 .66034 .54071 .67069 .53763 .66569 .53192 Mtetra
.66569 .53192 .67069 .53763 .68107 .53454 .6761 .52881 Mtetra
.6761 .52881 .68107 .53454 .69149 .53144 .68655 .52568 Mtetra
.68655 .52568 .69149 .53144 .70196 .52833 .69704 .52255 Mtetra
.69704 .52255 .70196 .52833 .71246 .5252 .70757 .5194 Mtetra
.70757 .5194 .71246 .5252 .723 .52206 .71814 .51624 Mtetra
.71814 .51624 .723 .52206 .73358 .51892 .72874 .51307 Mtetra
.72874 .51307 .73358 .51892 .74419 .51576 .73939 .50989 Mtetra
.73939 .50989 .74419 .51576 .75485 .51258 .75008 .5067 Mtetra
.75008 .5067 .75485 .51258 .76555 .5094 .7608 .50349 Mtetra
.7608 .50349 .76555 .5094 .77629 .50621 .77157 .50027 Mtetra
.77157 .50027 .77629 .50621 .78707 .503 .78237 .49704 Mtetra
.78237 .49704 .78707 .503 .79788 .49978 .79322 .4938 Mtetra
.79322 .4938 .79788 .49978 .80874 .49655 .80411 .49055 Mtetra
.80411 .49055 .80874 .49655 .81964 .4933 .81504 .48728 Mtetra
.81504 .48728 .81964 .4933 .83058 .49005 .82601 .484 Mtetra
.82601 .484 .83058 .49005 .84157 .48678 .83702 .48071 Mtetra
.83702 .48071 .84157 .48678 .85259 .4835 .84808 .47741 Mtetra
.84808 .47741 .85259 .4835 .86366 .48021 .85917 .47409 Mtetra
.85917 .47409 .86366 .48021 .87477 .4769 .87031 .47076 Mtetra
.87031 .47076 .87477 .4769 .88592 .47358 .88149 .46742 Mtetra
.88149 .46742 .88592 .47358 .89711 .47025 .89272 .46407 Mtetra
.89272 .46407 .89711 .47025 .90834 .46691 .90398 .4607 Mtetra
.90398 .4607 .90834 .46691 .91962 .46355 .91529 .45732 Mtetra
.91529 .45732 .91962 .46355 .93095 .46018 .92665 .45393 Mtetra
.31818 .62896 .32399 .63404 .33318 .63129 .32738 .6262 Mtetra
.32738 .6262 .33318 .63129 .3424 .62854 .33662 .62343 Mtetra
.33662 .62343 .3424 .62854 .35165 .62577 .34589 .62065 Mtetra
.34589 .62065 .35165 .62577 .36094 .623 .3552 .61785 Mtetra
.3552 .61785 .36094 .623 .37025 .62022 .36453 .61505 Mtetra
.36453 .61505 .37025 .62022 .3796 .61742 .3739 .61224 Mtetra
.3739 .61224 .3796 .61742 .38898 .61462 .3833 .60942 Mtetra
.3833 .60942 .38898 .61462 .3984 .6118 .39274 .60658 Mtetra
.39274 .60658 .3984 .6118 .40784 .60898 .40221 .60374 Mtetra
.40221 .60374 .40784 .60898 .41732 .60615 .41171 .60089 Mtetra
.41171 .60089 .41732 .60615 .42684 .6033 .42124 .59803 Mtetra
.42124 .59803 .42684 .6033 .43639 .60045 .43081 .59516 Mtetra
.43081 .59516 .43639 .60045 .44597 .59759 .44042 .59227 Mtetra
.44042 .59227 .44597 .59759 .45558 .59471 .45005 .58938 Mtetra
.45005 .58938 .45558 .59471 .46523 .59183 .45972 .58648 Mtetra
.45972 .58648 .46523 .59183 .47492 .58893 .46943 .58356 Mtetra
.46943 .58356 .47492 .58893 .48463 .58603 .47917 .58064 Mtetra
.47917 .58064 .48463 .58603 .49439 .58311 .48895 .57771 Mtetra
.48895 .57771 .49439 .58311 .50418 .58019 .49876 .57476 Mtetra
.49876 .57476 .50418 .58019 .514 .57725 .5086 .57181 Mtetra
.5086 .57181 .514 .57725 .52386 .57431 .51849 .56884 Mtetra
.51849 .56884 .52386 .57431 .53375 .57135 .5284 .56586 Mtetra
.5284 .56586 .53375 .57135 .54368 .56838 .53836 .56288 Mtetra
.53836 .56288 .54368 .56838 .55365 .5654 .54835 .55988 Mtetra
.54835 .55988 .55365 .5654 .56365 .56241 .55837 .55687 Mtetra
.55837 .55687 .56365 .56241 .57369 .55941 .56843 .55385 Mtetra
.56843 .55385 .57369 .55941 .58376 .5564 .57853 .55082 Mtetra
.57853 .55082 .58376 .5564 .59387 .55338 .58867 .54777 Mtetra
.58867 .54777 .59387 .55338 .60402 .55035 .59884 .54472 Mtetra
.59884 .54472 .60402 .55035 .61421 .5473 .60905 .54166 Mtetra
.60905 .54166 .61421 .5473 .62443 .54425 .6193 .53858 Mtetra
.6193 .53858 .62443 .54425 .63469 .54118 .62958 .53549 Mtetra
.62958 .53549 .63469 .54118 .64498 .53811 .63991 .53239 Mtetra
.63991 .53239 .64498 .53811 .65532 .53502 .65027 .52928 Mtetra
.65027 .52928 .65532 .53502 .66569 .53192 .66067 .52616 Mtetra
.66067 .52616 .66569 .53192 .6761 .52881 .6711 .52303 Mtetra
.6711 .52303 .6761 .52881 .68655 .52568 .68158 .51989 Mtetra
.68158 .51989 .68655 .52568 .69704 .52255 .6921 .51673 Mtetra
.6921 .51673 .69704 .52255 .70757 .5194 .70265 .51356 Mtetra
.70265 .51356 .70757 .5194 .71814 .51624 .71324 .51038 Mtetra
.71324 .51038 .71814 .51624 .72874 .51307 .72388 .50719 Mtetra
.72388 .50719 .72874 .51307 .73939 .50989 .73455 .50399 Mtetra
.73455 .50399 .73939 .50989 .75008 .5067 .74527 .50077 Mtetra
.74527 .50077 .75008 .5067 .7608 .50349 .75602 .49754 Mtetra
.75602 .49754 .7608 .50349 .77157 .50027 .76681 .4943 Mtetra
.76681 .4943 .77157 .50027 .78237 .49704 .77765 .49105 Mtetra
.77765 .49105 .78237 .49704 .79322 .4938 .78852 .48779 Mtetra
.78852 .48779 .79322 .4938 .80411 .49055 .79944 .48451 Mtetra
.79944 .48451 .80411 .49055 .81504 .48728 .8104 .48122 Mtetra
.8104 .48122 .81504 .48728 .82601 .484 .8214 .47792 Mtetra
.8214 .47792 .82601 .484 .83702 .48071 .83244 .4746 Mtetra
.83244 .4746 .83702 .48071 .84808 .47741 .84353 .47128 Mtetra
.84353 .47128 .84808 .47741 .85917 .47409 .85466 .46794 Mtetra
.85466 .46794 .85917 .47409 .87031 .47076 .86582 .46459 Mtetra
.86582 .46459 .87031 .47076 .88149 .46742 .87704 .46122 Mtetra
.87704 .46122 .88149 .46742 .89272 .46407 .88829 .45784 Mtetra
.88829 .45784 .89272 .46407 .90398 .4607 .89959 .45445 Mtetra
.89959 .45445 .90398 .4607 .91529 .45732 .91093 .45104 Mtetra
.91093 .45104 .91529 .45732 .92665 .45393 .92232 .44763 Mtetra
.31232 .62385 .31818 .62896 .32738 .6262 .32155 .62107 Mtetra
.32155 .62107 .32738 .6262 .33662 .62343 .33081 .61828 Mtetra
.33081 .61828 .33662 .62343 .34589 .62065 .3401 .61548 Mtetra
.3401 .61548 .34589 .62065 .3552 .61785 .34942 .61267 Mtetra
.34942 .61267 .3552 .61785 .36453 .61505 .35878 .60985 Mtetra
.35878 .60985 .36453 .61505 .3739 .61224 .36817 .60702 Mtetra
.36817 .60702 .3739 .61224 .3833 .60942 .37759 .60418 Mtetra
.37759 .60418 .3833 .60942 .39274 .60658 .38704 .60133 Mtetra
.38704 .60133 .39274 .60658 .40221 .60374 .39653 .59847 Mtetra
.39653 .59847 .40221 .60374 .41171 .60089 .40606 .5956 Mtetra
.40606 .5956 .41171 .60089 .42124 .59803 .41561 .59272 Mtetra
.41561 .59272 .42124 .59803 .43081 .59516 .4252 .58983 Mtetra
.4252 .58983 .43081 .59516 .44042 .59227 .43483 .58692 Mtetra
.43483 .58692 .44042 .59227 .45005 .58938 .44449 .58401 Mtetra
.44449 .58401 .45005 .58938 .45972 .58648 .45418 .58109 Mtetra
.45418 .58109 .45972 .58648 .46943 .58356 .46391 .57816 Mtetra
.46391 .57816 .46943 .58356 .47917 .58064 .47367 .57521 Mtetra
.47367 .57521 .47917 .58064 .48895 .57771 .48347 .57226 Mtetra
.48347 .57226 .48895 .57771 .49876 .57476 .4933 .5693 Mtetra
.4933 .5693 .49876 .57476 .5086 .57181 .50317 .56632 Mtetra
.50317 .56632 .5086 .57181 .51849 .56884 .51308 .56334 Mtetra
.51308 .56334 .51849 .56884 .5284 .56586 .52302 .56034 Mtetra
.52302 .56034 .5284 .56586 .53836 .56288 .533 .55733 Mtetra
.533 .55733 .53836 .56288 .54835 .55988 .54301 .55431 Mtetra
.54301 .55431 .54835 .55988 .55837 .55687 .55306 .55128 Mtetra
.55306 .55128 .55837 .55687 .56843 .55385 .56314 .54824 Mtetra
.56314 .54824 .56843 .55385 .57853 .55082 .57327 .54519 Mtetra
.57327 .54519 .57853 .55082 .58867 .54777 .58343 .54213 Mtetra
.58343 .54213 .58867 .54777 .59884 .54472 .59363 .53905 Mtetra
.59363 .53905 .59884 .54472 .60905 .54166 .60386 .53597 Mtetra
.60386 .53597 .60905 .54166 .6193 .53858 .61413 .53287 Mtetra
.61413 .53287 .6193 .53858 .62958 .53549 .62444 .52976 Mtetra
.62444 .52976 .62958 .53549 .63991 .53239 .63479 .52664 Mtetra
.63479 .52664 .63991 .53239 .65027 .52928 .64518 .52351 Mtetra
.64518 .52351 .65027 .52928 .66067 .52616 .6556 .52037 Mtetra
.6556 .52037 .66067 .52616 .6711 .52303 .66607 .51722 Mtetra
.66607 .51722 .6711 .52303 .68158 .51989 .67657 .51405 Mtetra
.67657 .51405 .68158 .51989 .6921 .51673 .68711 .51087 Mtetra
.68711 .51087 .6921 .51673 .70265 .51356 .6977 .50768 Mtetra
.6977 .50768 .70265 .51356 .71324 .51038 .70832 .50448 Mtetra
.70832 .50448 .71324 .51038 .72388 .50719 .71898 .50127 Mtetra
.71898 .50127 .72388 .50719 .73455 .50399 .72968 .49804 Mtetra
.72968 .49804 .73455 .50399 .74527 .50077 .74042 .4948 Mtetra
.74042 .4948 .74527 .50077 .75602 .49754 .7512 .49155 Mtetra
.7512 .49155 .75602 .49754 .76681 .4943 .76203 .48829 Mtetra
.76203 .48829 .76681 .4943 .77765 .49105 .77289 .48501 Mtetra
.77289 .48501 .77765 .49105 .78852 .48779 .7838 .48173 Mtetra
.7838 .48173 .78852 .48779 .79944 .48451 .79474 .47843 Mtetra
.79474 .47843 .79944 .48451 .8104 .48122 .80573 .47511 Mtetra
.80573 .47511 .8104 .48122 .8214 .47792 .81676 .47179 Mtetra
.81676 .47179 .8214 .47792 .83244 .4746 .82783 .46845 Mtetra
.82783 .46845 .83244 .4746 .84353 .47128 .83895 .4651 Mtetra
.83895 .4651 .84353 .47128 .85466 .46794 .85011 .46174 Mtetra
.85011 .46174 .85466 .46794 .86582 .46459 .86131 .45836 Mtetra
.86131 .45836 .86582 .46459 .87704 .46122 .87255 .45497 Mtetra
.87255 .45497 .87704 .46122 .88829 .45784 .88384 .45157 Mtetra
.88384 .45157 .88829 .45784 .89959 .45445 .89517 .44816 Mtetra
.89517 .44816 .89959 .45445 .91093 .45104 .90654 .44473 Mtetra
.90654 .44473 .91093 .45104 .92232 .44763 .91796 .44128 Mtetra
.30643 .61871 .31232 .62385 .32155 .62107 .31568 .61592 Mtetra
.31568 .61592 .32155 .62107 .33081 .61828 .32495 .61311 Mtetra
.32495 .61311 .33081 .61828 .3401 .61548 .33427 .61029 Mtetra
.656 .752 .92 r
.33427 .61029 .3401 .61548 .34942 .61267 .34361 .60746 Mtetra
.34361 .60746 .34942 .61267 .35878 .60985 .35299 .60462 Mtetra
.35299 .60462 .35878 .60985 .36817 .60702 .36239 .60177 Mtetra
.36239 .60177 .36817 .60702 .37759 .60418 .37184 .59891 Mtetra
.37184 .59891 .37759 .60418 .38704 .60133 .38131 .59604 Mtetra
.656 .751 .92 r
.38131 .59604 .38704 .60133 .39653 .59847 .39082 .59316 Mtetra
.39082 .59316 .39653 .59847 .40606 .5956 .40037 .59027 Mtetra
.40037 .59027 .40606 .5956 .41561 .59272 .40995 .58737 Mtetra
.40995 .58737 .41561 .59272 .4252 .58983 .41956 .58446 Mtetra
.41956 .58446 .4252 .58983 .43483 .58692 .4292 .58154 Mtetra
.4292 .58154 .43483 .58692 .44449 .58401 .43888 .57861 Mtetra
.43888 .57861 .44449 .58401 .45418 .58109 .4486 .57567 Mtetra
.4486 .57567 .45418 .58109 .46391 .57816 .45835 .57272 Mtetra
.45835 .57272 .46391 .57816 .47367 .57521 .46814 .56975 Mtetra
.46814 .56975 .47367 .57521 .48347 .57226 .47796 .56678 Mtetra
.47796 .56678 .48347 .57226 .4933 .5693 .48781 .5638 Mtetra
.48781 .5638 .4933 .5693 .50317 .56632 .49771 .5608 Mtetra
.49771 .5608 .50317 .56632 .51308 .56334 .50763 .55779 Mtetra
.50763 .55779 .51308 .56334 .52302 .56034 .5176 .55478 Mtetra
.5176 .55478 .52302 .56034 .533 .55733 .5276 .55175 Mtetra
.5276 .55175 .533 .55733 .54301 .55431 .53764 .54871 Mtetra
.53764 .54871 .54301 .55431 .55306 .55128 .54771 .54566 Mtetra
.54771 .54566 .55306 .55128 .56314 .54824 .55782 .5426 Mtetra
.55782 .5426 .56314 .54824 .57327 .54519 .56797 .53953 Mtetra
.56797 .53953 .57327 .54519 .58343 .54213 .57815 .53644 Mtetra
.57815 .53644 .58343 .54213 .59363 .53905 .58837 .53335 Mtetra
.58837 .53335 .59363 .53905 .60386 .53597 .59864 .53024 Mtetra
.59864 .53024 .60386 .53597 .61413 .53287 .60893 .52712 Mtetra
.60893 .52712 .61413 .53287 .62444 .52976 .61927 .524 Mtetra
.61927 .524 .62444 .52976 .63479 .52664 .62964 .52085 Mtetra
.62964 .52085 .63479 .52664 .64518 .52351 .64006 .5177 Mtetra
.64006 .5177 .64518 .52351 .6556 .52037 .65051 .51454 Mtetra
.65051 .51454 .6556 .52037 .66607 .51722 .661 .51136 Mtetra
.661 .51136 .66607 .51722 .67657 .51405 .67153 .50817 Mtetra
.67153 .50817 .67657 .51405 .68711 .51087 .6821 .50497 Mtetra
.6821 .50497 .68711 .51087 .6977 .50768 .69271 .50176 Mtetra
.69271 .50176 .6977 .50768 .70832 .50448 .70336 .49854 Mtetra
.70336 .49854 .70832 .50448 .71898 .50127 .71405 .4953 Mtetra
.71405 .4953 .71898 .50127 .72968 .49804 .72477 .49205 Mtetra
.72477 .49205 .72968 .49804 .74042 .4948 .73554 .48879 Mtetra
.73554 .48879 .74042 .4948 .7512 .49155 .74636 .48552 Mtetra
.74636 .48552 .7512 .49155 .76203 .48829 .75721 .48223 Mtetra
.75721 .48223 .76203 .48829 .77289 .48501 .7681 .47894 Mtetra
.7681 .47894 .77289 .48501 .7838 .48173 .77903 .47563 Mtetra
.77903 .47563 .7838 .48173 .79474 .47843 .79001 .4723 Mtetra
.79001 .4723 .79474 .47843 .80573 .47511 .80103 .46897 Mtetra
.80103 .46897 .80573 .47511 .81676 .47179 .81209 .46562 Mtetra
.81209 .46562 .81676 .47179 .82783 .46845 .82319 .46226 Mtetra
.82319 .46226 .82783 .46845 .83895 .4651 .83434 .45889 Mtetra
.83434 .45889 .83895 .4651 .85011 .46174 .84553 .4555 Mtetra
.656 .752 .92 r
.84553 .4555 .85011 .46174 .86131 .45836 .85676 .4521 Mtetra
.85676 .4521 .86131 .45836 .87255 .45497 .86803 .44869 Mtetra
.86803 .44869 .87255 .45497 .88384 .45157 .87935 .44526 Mtetra
.87935 .44526 .88384 .45157 .89517 .44816 .89071 .44182 Mtetra
.89071 .44182 .89517 .44816 .90654 .44473 .90212 .43836 Mtetra
.90212 .43836 .90654 .44473 .91796 .44128 .91357 .43489 Mtetra
.656 .751 .92 r
.3005 .61354 .30643 .61871 .31568 .61592 .30977 .61073 Mtetra
.30977 .61073 .31568 .61592 .32495 .61311 .31906 .6079 Mtetra
.656 .752 .92 r
.31906 .6079 .32495 .61311 .33427 .61029 .32839 .60507 Mtetra
.656 .752 .921 r
.32839 .60507 .33427 .61029 .34361 .60746 .33776 .60222 Mtetra
.33776 .60222 .34361 .60746 .35299 .60462 .34715 .59937 Mtetra
.656 .752 .92 r
.34715 .59937 .35299 .60462 .36239 .60177 .35658 .5965 Mtetra
.35658 .5965 .36239 .60177 .37184 .59891 .36605 .59362 Mtetra
.36605 .59362 .37184 .59891 .38131 .59604 .37555 .59073 Mtetra
.37555 .59073 .38131 .59604 .39082 .59316 .38508 .58782 Mtetra
.38508 .58782 .39082 .59316 .40037 .59027 .39464 .58491 Mtetra
.39464 .58491 .40037 .59027 .40995 .58737 .40424 .58199 Mtetra
.656 .751 .92 r
.40424 .58199 .40995 .58737 .41956 .58446 .41387 .57906 Mtetra
.41387 .57906 .41956 .58446 .4292 .58154 .42354 .57612 Mtetra
.42354 .57612 .4292 .58154 .43888 .57861 .43324 .57317 Mtetra
.43324 .57317 .43888 .57861 .4486 .57567 .44298 .57021 Mtetra
.44298 .57021 .4486 .57567 .45835 .57272 .45276 .56724 Mtetra
.45276 .56724 .45835 .57272 .46814 .56975 .46256 .56426 Mtetra
.46256 .56426 .46814 .56975 .47796 .56678 .47241 .56126 Mtetra
.47241 .56126 .47796 .56678 .48781 .5638 .48229 .55826 Mtetra
.48229 .55826 .48781 .5638 .49771 .5608 .4922 .55524 Mtetra
.4922 .55524 .49771 .5608 .50763 .55779 .50215 .55222 Mtetra
.50215 .55222 .50763 .55779 .5176 .55478 .51214 .54918 Mtetra
.51214 .54918 .5176 .55478 .5276 .55175 .52217 .54613 Mtetra
.52217 .54613 .5276 .55175 .53764 .54871 .53223 .54307 Mtetra
.53223 .54307 .53764 .54871 .54771 .54566 .54232 .54 Mtetra
.54232 .54 .54771 .54566 .55782 .5426 .55246 .53692 Mtetra
.55246 .53692 .55782 .5426 .56797 .53953 .56263 .53383 Mtetra
.56263 .53383 .56797 .53953 .57815 .53644 .57284 .53072 Mtetra
.57284 .53072 .57815 .53644 .58837 .53335 .58309 .52761 Mtetra
.58309 .52761 .58837 .53335 .59864 .53024 .59337 .52448 Mtetra
.59337 .52448 .59864 .53024 .60893 .52712 .6037 .52134 Mtetra
.6037 .52134 .60893 .52712 .61927 .524 .61406 .51819 Mtetra
.61406 .51819 .61927 .524 .62964 .52085 .62446 .51503 Mtetra
.62446 .51503 .62964 .52085 .64006 .5177 .6349 .51185 Mtetra
.6349 .51185 .64006 .5177 .65051 .51454 .64538 .50866 Mtetra
.64538 .50866 .65051 .51454 .661 .51136 .65589 .50547 Mtetra
.65589 .50547 .661 .51136 .67153 .50817 .66645 .50226 Mtetra
.66645 .50226 .67153 .50817 .6821 .50497 .67705 .49903 Mtetra
.67705 .49903 .6821 .50497 .69271 .50176 .68768 .4958 Mtetra
.68768 .4958 .69271 .50176 .70336 .49854 .69836 .49255 Mtetra
.69836 .49255 .70336 .49854 .71405 .4953 .70908 .48929 Mtetra
.70908 .48929 .71405 .4953 .72477 .49205 .71984 .48602 Mtetra
.71984 .48602 .72477 .49205 .73554 .48879 .73063 .48274 Mtetra
.73063 .48274 .73554 .48879 .74636 .48552 .74147 .47944 Mtetra
.74147 .47944 .74636 .48552 .75721 .48223 .75235 .47614 Mtetra
.75235 .47614 .75721 .48223 .7681 .47894 .76328 .47281 Mtetra
.76328 .47281 .7681 .47894 .77903 .47563 .77424 .46948 Mtetra
.77424 .46948 .77903 .47563 .79001 .4723 .78524 .46614 Mtetra
.78524 .46614 .79001 .4723 .80103 .46897 .79629 .46278 Mtetra
.79629 .46278 .80103 .46897 .81209 .46562 .80738 .45941 Mtetra
.80738 .45941 .81209 .46562 .82319 .46226 .81852 .45602 Mtetra
.656 .752 .92 r
.81852 .45602 .82319 .46226 .83434 .45889 .82969 .45263 Mtetra
.82969 .45263 .83434 .45889 .84553 .4555 .84091 .44922 Mtetra
.656 .752 .921 r
.84091 .44922 .84553 .4555 .85676 .4521 .85218 .4458 Mtetra
.85218 .4458 .85676 .4521 .86803 .44869 .86348 .44236 Mtetra
.656 .752 .92 r
.86348 .44236 .86803 .44869 .87935 .44526 .87483 .43891 Mtetra
.87483 .43891 .87935 .44526 .89071 .44182 .88623 .43544 Mtetra
.88623 .43544 .89071 .44182 .90212 .43836 .89766 .43195 Mtetra
.89766 .43195 .90212 .43836 .91357 .43489 .90915 .42846 Mtetra
.655 .751 .92 r
.29453 .60833 .3005 .61354 .30977 .61073 .30382 .6055 Mtetra
.655 .752 .921 r
.30382 .6055 .30977 .61073 .31906 .6079 .31313 .60267 Mtetra
.31313 .60267 .31906 .6079 .32839 .60507 .32248 .59982 Mtetra
.656 .752 .921 r
.32248 .59982 .32839 .60507 .33776 .60222 .33187 .59696 Mtetra
.33187 .59696 .33776 .60222 .34715 .59937 .34128 .59408 Mtetra
.34128 .59408 .34715 .59937 .35658 .5965 .35074 .59119 Mtetra
.35074 .59119 .35658 .5965 .36605 .59362 .36022 .58829 Mtetra
.36022 .58829 .36605 .59362 .37555 .59073 .36974 .58538 Mtetra
.656 .752 .92 r
.36974 .58538 .37555 .59073 .38508 .58782 .37929 .58245 Mtetra
.37929 .58245 .38508 .58782 .39464 .58491 .38888 .57952 Mtetra
.38888 .57952 .39464 .58491 .40424 .58199 .3985 .57658 Mtetra
.3985 .57658 .40424 .58199 .41387 .57906 .40815 .57363 Mtetra
.40815 .57363 .41387 .57906 .42354 .57612 .41784 .57067 Mtetra
.656 .751 .92 r
.41784 .57067 .42354 .57612 .43324 .57317 .42757 .5677 Mtetra
.42757 .5677 .43324 .57317 .44298 .57021 .43733 .56472 Mtetra
.43733 .56472 .44298 .57021 .45276 .56724 .44712 .56172 Mtetra
.44712 .56172 .45276 .56724 .46256 .56426 .45695 .55872 Mtetra
.45695 .55872 .46256 .56426 .47241 .56126 .46682 .55571 Mtetra
.46682 .55571 .47241 .56126 .48229 .55826 .47672 .55268 Mtetra
.47672 .55268 .48229 .55826 .4922 .55524 .48666 .54965 Mtetra
.48666 .54965 .4922 .55524 .50215 .55222 .49664 .5466 Mtetra
.49664 .5466 .50215 .55222 .51214 .54918 .50665 .54354 Mtetra
.50665 .54354 .51214 .54918 .52217 .54613 .5167 .54047 Mtetra
.5167 .54047 .52217 .54613 .53223 .54307 .52678 .53739 Mtetra
.52678 .53739 .53223 .54307 .54232 .54 .5369 .5343 Mtetra
.5369 .5343 .54232 .54 .55246 .53692 .54706 .5312 Mtetra
.54706 .5312 .55246 .53692 .56263 .53383 .55726 .52809 Mtetra
.55726 .52809 .56263 .53383 .57284 .53072 .56749 .52496 Mtetra
.56749 .52496 .57284 .53072 .58309 .52761 .57777 .52182 Mtetra
.57777 .52182 .58309 .52761 .59337 .52448 .58808 .51867 Mtetra
.58808 .51867 .59337 .52448 .6037 .52134 .59843 .51551 Mtetra
.59843 .51551 .6037 .52134 .61406 .51819 .60881 .51234 Mtetra
.60881 .51234 .61406 .51819 .62446 .51503 .61924 .50916 Mtetra
.61924 .50916 .62446 .51503 .6349 .51185 .62971 .50596 Mtetra
.62971 .50596 .6349 .51185 .64538 .50866 .64021 .50275 Mtetra
.64021 .50275 .64538 .50866 .65589 .50547 .65075 .49953 Mtetra
.65075 .49953 .65589 .50547 .66645 .50226 .66134 .4963 Mtetra
.66134 .4963 .66645 .50226 .67705 .49903 .67196 .49305 Mtetra
.67196 .49305 .67705 .49903 .68768 .4958 .68263 .4898 Mtetra
.68263 .4898 .68768 .4958 .69836 .49255 .69333 .48653 Mtetra
.69333 .48653 .69836 .49255 .70908 .48929 .70408 .48325 Mtetra
.70408 .48325 .70908 .48929 .71984 .48602 .71486 .47995 Mtetra
.71486 .47995 .71984 .48602 .73063 .48274 .72569 .47664 Mtetra
.72569 .47664 .73063 .48274 .74147 .47944 .73656 .47333 Mtetra
.73656 .47333 .74147 .47944 .75235 .47614 .74747 .46999 Mtetra
.74747 .46999 .75235 .47614 .76328 .47281 .75842 .46665 Mtetra
.75842 .46665 .76328 .47281 .77424 .46948 .76941 .4633 Mtetra
.76941 .4633 .77424 .46948 .78524 .46614 .78045 .45993 Mtetra
.78045 .45993 .78524 .46614 .79629 .46278 .79152 .45655 Mtetra
.656 .752 .92 r
.79152 .45655 .79629 .46278 .80738 .45941 .80264 .45316 Mtetra
.656 .752 .921 r
.80264 .45316 .80738 .45941 .81852 .45602 .81381 .44975 Mtetra
.81381 .44975 .81852 .45602 .82969 .45263 .82502 .44633 Mtetra
.82502 .44633 .82969 .45263 .84091 .44922 .83627 .4429 Mtetra
.83627 .4429 .84091 .44922 .85218 .4458 .84756 .43946 Mtetra
.84756 .43946 .85218 .4458 .86348 .44236 .8589 .43599 Mtetra
.8589 .43599 .86348 .44236 .87483 .43891 .87028 .43251 Mtetra
.87028 .43251 .87483 .43891 .88623 .43544 .88171 .42902 Mtetra
.656 .752 .92 r
.88171 .42902 .88623 .43544 .89766 .43195 .89318 .4255 Mtetra
.89318 .4255 .89766 .43195 .90915 .42846 .90469 .42197 Mtetra
.655 .751 .921 r
.28853 .60308 .29453 .60833 .30382 .6055 .29783 .60025 Mtetra
.655 .752 .921 r
.29783 .60025 .30382 .6055 .31313 .60267 .30716 .59741 Mtetra
.30716 .59741 .31313 .60267 .32248 .59982 .31653 .59455 Mtetra
.31653 .59455 .32248 .59982 .33187 .59696 .32594 .59167 Mtetra
.656 .753 .921 r
.32594 .59167 .33187 .59696 .34128 .59408 .33538 .58878 Mtetra
.33538 .58878 .34128 .59408 .35074 .59119 .34485 .58587 Mtetra
.34485 .58587 .35074 .59119 .36022 .58829 .35435 .58295 Mtetra
.35435 .58295 .36022 .58829 .36974 .58538 .36389 .58001 Mtetra
.656 .752 .921 r
.36389 .58001 .36974 .58538 .37929 .58245 .37347 .57706 Mtetra
.37347 .57706 .37929 .58245 .38888 .57952 .38307 .5741 Mtetra
.38307 .5741 .38888 .57952 .3985 .57658 .39272 .57114 Mtetra
.656 .752 .92 r
.39272 .57114 .3985 .57658 .40815 .57363 .40239 .56816 Mtetra
.40239 .56816 .40815 .57363 .41784 .57067 .41211 .56518 Mtetra
.41211 .56518 .41784 .57067 .42757 .5677 .42185 .56219 Mtetra
.656 .751 .92 r
.42185 .56219 .42757 .5677 .43733 .56472 .43163 .55919 Mtetra
.43163 .55919 .43733 .56472 .44712 .56172 .44145 .55617 Mtetra
.44145 .55617 .44712 .56172 .45695 .55872 .45131 .55315 Mtetra
.45131 .55315 .45695 .55872 .46682 .55571 .4612 .55012 Mtetra
.4612 .55012 .46682 .55571 .47672 .55268 .47112 .54707 Mtetra
.47112 .54707 .47672 .55268 .48666 .54965 .48108 .54401 Mtetra
.48108 .54401 .48666 .54965 .49664 .5466 .49108 .54095 Mtetra
.49108 .54095 .49664 .5466 .50665 .54354 .50112 .53787 Mtetra
.50112 .53787 .50665 .54354 .5167 .54047 .51119 .53478 Mtetra
.51119 .53478 .5167 .54047 .52678 .53739 .5213 .53168 Mtetra
.5213 .53168 .52678 .53739 .5369 .5343 .53144 .52857 Mtetra
.53144 .52857 .5369 .5343 .54706 .5312 .54163 .52544 Mtetra
.54163 .52544 .54706 .5312 .55726 .52809 .55185 .52231 Mtetra
.55185 .52231 .55726 .52809 .56749 .52496 .56211 .51916 Mtetra
.56211 .51916 .56749 .52496 .57777 .52182 .57241 .516 Mtetra
.57241 .516 .57777 .52182 .58808 .51867 .58274 .51283 Mtetra
.58274 .51283 .58808 .51867 .59843 .51551 .59312 .50965 Mtetra
.59312 .50965 .59843 .51551 .60881 .51234 .60353 .50645 Mtetra
.60353 .50645 .60881 .51234 .61924 .50916 .61398 .50324 Mtetra
.61398 .50324 .61924 .50916 .62971 .50596 .62448 .50003 Mtetra
.62448 .50003 .62971 .50596 .64021 .50275 .63501 .4968 Mtetra
.63501 .4968 .64021 .50275 .65075 .49953 .64558 .49355 Mtetra
.64558 .49355 .65075 .49953 .66134 .4963 .65619 .4903 Mtetra
.65619 .4903 .66134 .4963 .67196 .49305 .66684 .48703 Mtetra
.66684 .48703 .67196 .49305 .68263 .4898 .67753 .48375 Mtetra
.67753 .48375 .68263 .4898 .69333 .48653 .68826 .48046 Mtetra
.68826 .48046 .69333 .48653 .70408 .48325 .69904 .47715 Mtetra
.69904 .47715 .70408 .48325 .71486 .47995 .70985 .47384 Mtetra
.70985 .47384 .71486 .47995 .72569 .47664 .72071 .47051 Mtetra
.72071 .47051 .72569 .47664 .73656 .47333 .7316 .46717 Mtetra
.7316 .46717 .73656 .47333 .74747 .46999 .74254 .46381 Mtetra
.74254 .46381 .74747 .46999 .75842 .46665 .75352 .46045 Mtetra
.75352 .46045 .75842 .46665 .76941 .4633 .76455 .45707 Mtetra
.656 .752 .921 r
.76455 .45707 .76941 .4633 .78045 .45993 .77561 .45368 Mtetra
.655 .752 .921 r
.77561 .45368 .78045 .45993 .79152 .45655 .78672 .45028 Mtetra
.78672 .45028 .79152 .45655 .80264 .45316 .79787 .44687 Mtetra
.79787 .44687 .80264 .45316 .81381 .44975 .80907 .44345 Mtetra
.80907 .44345 .81381 .44975 .82502 .44633 .82031 .44001 Mtetra
.82031 .44001 .82502 .44633 .83627 .4429 .83159 .43656 Mtetra
.656 .753 .921 r
.83159 .43656 .83627 .4429 .84756 .43946 .84292 .43309 Mtetra
.84292 .43309 .84756 .43946 .8589 .43599 .85429 .4296 Mtetra
.85429 .4296 .8589 .43599 .87028 .43251 .8657 .42609 Mtetra
.8657 .42609 .87028 .43251 .88171 .42902 .87716 .42256 Mtetra
.87716 .42256 .88171 .42902 .89318 .4255 .88866 .41901 Mtetra
.657 .752 .92 r
.88866 .41901 .89318 .4255 .90469 .42197 .90021 .41544 Mtetra
.654 .751 .921 r
.28248 .59781 .28853 .60308 .29783 .60025 .2918 .59498 Mtetra
.654 .752 .922 r
.2918 .59498 .29783 .60025 .30716 .59741 .30115 .59213 Mtetra
.30115 .59213 .30716 .59741 .31653 .59455 .31054 .58927 Mtetra
.655 .753 .922 r
.31054 .58927 .31653 .59455 .32594 .59167 .31997 .58638 Mtetra
.655 .754 .922 r
.31997 .58638 .32594 .59167 .33538 .58878 .32943 .58347 Mtetra
.656 .754 .922 r
.32943 .58347 .33538 .58878 .34485 .58587 .33892 .58054 Mtetra
.33892 .58054 .34485 .58587 .35435 .58295 .34844 .57759 Mtetra
.34844 .57759 .35435 .58295 .36389 .58001 .35801 .57463 Mtetra
.657 .753 .921 r
.35801 .57463 .36389 .58001 .37347 .57706 .3676 .57165 Mtetra
.3676 .57165 .37347 .57706 .38307 .5741 .37723 .56867 Mtetra
.656 .753 .921 r
.37723 .56867 .38307 .5741 .39272 .57114 .3869 .56567 Mtetra
.656 .752 .921 r
.3869 .56567 .39272 .57114 .40239 .56816 .39659 .56267 Mtetra
.39659 .56267 .40239 .56816 .41211 .56518 .40633 .55966 Mtetra
.656 .752 .92 r
.40633 .55966 .41211 .56518 .42185 .56219 .4161 .55665 Mtetra
.4161 .55665 .42185 .56219 .43163 .55919 .4259 .55362 Mtetra
.4259 .55362 .43163 .55919 .44145 .55617 .43574 .55059 Mtetra
.43574 .55059 .44145 .55617 .45131 .55315 .44562 .54754 Mtetra
.656 .751 .92 r
.44562 .54754 .45131 .55315 .4612 .55012 .45553 .54449 Mtetra
.45553 .54449 .4612 .55012 .47112 .54707 .46548 .54142 Mtetra
.46548 .54142 .47112 .54707 .48108 .54401 .47547 .53834 Mtetra
.47547 .53834 .48108 .54401 .49108 .54095 .48549 .53526 Mtetra
.48549 .53526 .49108 .54095 .50112 .53787 .49555 .53216 Mtetra
.49555 .53216 .50112 .53787 .51119 .53478 .50564 .52905 Mtetra
.50564 .52905 .51119 .53478 .5213 .53168 .51578 .52592 Mtetra
.51578 .52592 .5213 .53168 .53144 .52857 .52595 .52279 Mtetra
.52595 .52279 .53144 .52857 .54163 .52544 .53616 .51964 Mtetra
.53616 .51964 .54163 .52544 .55185 .52231 .5464 .51649 Mtetra
.5464 .51649 .55185 .52231 .56211 .51916 .55669 .51332 Mtetra
.55669 .51332 .56211 .51916 .57241 .516 .56701 .51014 Mtetra
.56701 .51014 .57241 .516 .58274 .51283 .57737 .50694 Mtetra
.57737 .50694 .58274 .51283 .59312 .50965 .58777 .50374 Mtetra
.58777 .50374 .59312 .50965 .60353 .50645 .59821 .50052 Mtetra
.59821 .50052 .60353 .50645 .61398 .50324 .60869 .49729 Mtetra
.60869 .49729 .61398 .50324 .62448 .50003 .61921 .49405 Mtetra
.61921 .49405 .62448 .50003 .63501 .4968 .62977 .4908 Mtetra
.62977 .4908 .63501 .4968 .64558 .49355 .64037 .48753 Mtetra
.64037 .48753 .64558 .49355 .65619 .4903 .65101 .48426 Mtetra
.65101 .48426 .65619 .4903 .66684 .48703 .66168 .48097 Mtetra
.66168 .48097 .66684 .48703 .67753 .48375 .6724 .47766 Mtetra
.6724 .47766 .67753 .48375 .68826 .48046 .68316 .47435 Mtetra
.68316 .47435 .68826 .48046 .69904 .47715 .69396 .47102 Mtetra
.69396 .47102 .69904 .47715 .70985 .47384 .70481 .46768 Mtetra
.70481 .46768 .70985 .47384 .72071 .47051 .71569 .46433 Mtetra
.71569 .46433 .72071 .47051 .7316 .46717 .72662 .46097 Mtetra
.72662 .46097 .7316 .46717 .74254 .46381 .73759 .45759 Mtetra
.656 .752 .921 r
.73759 .45759 .74254 .46381 .75352 .46045 .7486 .4542 Mtetra
.655 .752 .921 r
.7486 .4542 .75352 .46045 .76455 .45707 .75965 .45081 Mtetra
.75965 .45081 .76455 .45707 .77561 .45368 .77075 .4474 Mtetra
.77075 .4474 .77561 .45368 .78672 .45028 .78189 .44399 Mtetra
.78189 .44399 .78672 .45028 .79787 .44687 .79307 .44056 Mtetra
.655 .753 .922 r
.79307 .44056 .79787 .44687 .80907 .44345 .8043 .43713 Mtetra
.8043 .43713 .80907 .44345 .82031 .44001 .81557 .43367 Mtetra
.81557 .43367 .82031 .44001 .83159 .43656 .82688 .4302 Mtetra
.655 .754 .922 r
.82688 .4302 .83159 .43656 .84292 .43309 .83824 .42671 Mtetra
.656 .754 .922 r
.83824 .42671 .84292 .43309 .85429 .4296 .84964 .42319 Mtetra
.84964 .42319 .85429 .4296 .8657 .42609 .86109 .41965 Mtetra
.657 .754 .921 r
.86109 .41965 .8657 .42609 .87716 .42256 .87258 .41607 Mtetra
.657 .753 .921 r
.87258 .41607 .87716 .42256 .88866 .41901 .88411 .41248 Mtetra
.657 .753 .92 r
.88411 .41248 .88866 .41901 .90021 .41544 .89569 .40886 Mtetra
.652 .751 .922 r
.27639 .59249 .28248 .59781 .2918 .59498 .28573 .58968 Mtetra
.653 .752 .922 r
.28573 .58968 .2918 .59498 .30115 .59213 .2951 .58685 Mtetra
.653 .753 .923 r
.2951 .58685 .30115 .59213 .31054 .58927 .30451 .58399 Mtetra
.654 .754 .924 r
.30451 .58399 .31054 .58927 .31997 .58638 .31395 .58111 Mtetra
.655 .755 .924 r
.31395 .58111 .31997 .58638 .32943 .58347 .32343 .57819 Mtetra
.656 .756 .924 r
.32343 .57819 .32943 .58347 .33892 .58054 .33295 .57524 Mtetra
.656 .756 .923 r
.33295 .57524 .33892 .58054 .34844 .57759 .34249 .57227 Mtetra
.657 .756 .923 r
.34249 .57227 .34844 .57759 .35801 .57463 .35208 .56927 Mtetra
.35208 .56927 .35801 .57463 .3676 .57165 .3617 .56625 Mtetra
.657 .755 .922 r
.3617 .56625 .3676 .57165 .37723 .56867 .37135 .56323 Mtetra
.657 .754 .922 r
.37135 .56323 .37723 .56867 .3869 .56567 .38103 .5602 Mtetra
.657 .754 .921 r
.38103 .5602 .3869 .56567 .39659 .56267 .39076 .55716 Mtetra
.657 .753 .921 r
.39076 .55716 .39659 .56267 .40633 .55966 .40051 .55412 Mtetra
.656 .752 .921 r
.40051 .55412 .40633 .55966 .4161 .55665 .41031 .55108 Mtetra
.41031 .55108 .4161 .55665 .4259 .55362 .42013 .54802 Mtetra
.656 .752 .92 r
.42013 .54802 .4259 .55362 .43574 .55059 .43 .54497 Mtetra
.43 .54497 .43574 .55059 .44562 .54754 .4399 .5419 Mtetra
.4399 .5419 .44562 .54754 .45553 .54449 .44983 .53882 Mtetra
.656 .751 .92 r
.44983 .53882 .45553 .54449 .46548 .54142 .4598 .53573 Mtetra
.4598 .53573 .46548 .54142 .47547 .53834 .46981 .53263 Mtetra
.46981 .53263 .47547 .53834 .48549 .53526 .47986 .52952 Mtetra
.47986 .52952 .48549 .53526 .49555 .53216 .48994 .5264 Mtetra
.48994 .5264 .49555 .53216 .50564 .52905 .50006 .52327 Mtetra
.50006 .52327 .50564 .52905 .51578 .52592 .51022 .52013 Mtetra
.51022 .52013 .51578 .52592 .52595 .52279 .52041 .51697 Mtetra
.52041 .51697 .52595 .52279 .53616 .51964 .53065 .51381 Mtetra
.53065 .51381 .53616 .51964 .5464 .51649 .54092 .51063 Mtetra
.54092 .51063 .5464 .51649 .55669 .51332 .55123 .50744 Mtetra
.55123 .50744 .55669 .51332 .56701 .51014 .56158 .50423 Mtetra
.56158 .50423 .56701 .51014 .57737 .50694 .57197 .50102 Mtetra
.57197 .50102 .57737 .50694 .58777 .50374 .58239 .49779 Mtetra
.58239 .49779 .58777 .50374 .59821 .50052 .59286 .49455 Mtetra
.59286 .49455 .59821 .50052 .60869 .49729 .60336 .4913 Mtetra
.60336 .4913 .60869 .49729 .61921 .49405 .61391 .48804 Mtetra
.61391 .48804 .61921 .49405 .62977 .4908 .62449 .48476 Mtetra
.62449 .48476 .62977 .4908 .64037 .48753 .63512 .48147 Mtetra
.63512 .48147 .64037 .48753 .65101 .48426 .64578 .47817 Mtetra
.64578 .47817 .65101 .48426 .66168 .48097 .65649 .47486 Mtetra
.65649 .47486 .66168 .48097 .6724 .47766 .66724 .47153 Mtetra
.66724 .47153 .6724 .47766 .68316 .47435 .67803 .4682 Mtetra
.67803 .4682 .68316 .47435 .69396 .47102 .68886 .46485 Mtetra
.68886 .46485 .69396 .47102 .70481 .46768 .69973 .46148 Mtetra
.69973 .46148 .70481 .46768 .71569 .46433 .71064 .45811 Mtetra
.656 .752 .921 r
.71064 .45811 .71569 .46433 .72662 .46097 .7216 .45473 Mtetra
.655 .752 .921 r
.7216 .45473 .72662 .46097 .73759 .45759 .73259 .45133 Mtetra
.73259 .45133 .73759 .45759 .7486 .4542 .74363 .44793 Mtetra
.74363 .44793 .7486 .4542 .75965 .45081 .75472 .44452 Mtetra
.655 .752 .922 r
.75472 .44452 .75965 .45081 .77075 .4474 .76585 .44111 Mtetra
.654 .753 .922 r
.76585 .44111 .77075 .4474 .78189 .44399 .77702 .43769 Mtetra
.654 .753 .923 r
.77702 .43769 .78189 .44399 .79307 .44056 .78823 .43426 Mtetra
.654 .754 .923 r
.78823 .43426 .79307 .44056 .8043 .43713 .79949 .43081 Mtetra
.654 .755 .924 r
.79949 .43081 .8043 .43713 .81557 .43367 .8108 .42735 Mtetra
.655 .755 .924 r
.8108 .42735 .81557 .43367 .82688 .4302 .82215 .42386 Mtetra
.655 .756 .924 r
.82215 .42386 .82688 .4302 .83824 .42671 .83354 .42034 Mtetra
.656 .756 .924 r
.83354 .42034 .83824 .42671 .84964 .42319 .84497 .41679 Mtetra
.657 .756 .923 r
.84497 .41679 .84964 .42319 .86109 .41965 .85645 .41319 Mtetra
.658 .756 .922 r
.85645 .41319 .86109 .41965 .87258 .41607 .86796 .40957 Mtetra
.658 .755 .921 r
.86796 .40957 .87258 .41607 .88411 .41248 .87953 .40592 Mtetra
.659 .754 .92 r
.87953 .40592 .88411 .41248 .89569 .40886 .89113 .40224 Mtetra
.65 .75 .923 r
.27027 .58715 .27639 .59249 .28573 .58968 .27962 .58437 Mtetra
.651 .752 .924 r
.27962 .58437 .28573 .58968 .2951 .58685 .28901 .58156 Mtetra
.651 .754 .925 r
.28901 .58156 .2951 .58685 .30451 .58399 .29844 .57873 Mtetra
.652 .756 .926 r
.29844 .57873 .30451 .58399 .31395 .58111 .3079 .57586 Mtetra
.654 .757 .926 r
.3079 .57586 .31395 .58111 .32343 .57819 .31739 .57295 Mtetra
.655 .759 .926 r
.31739 .57295 .32343 .57819 .33295 .57524 .32693 .56999 Mtetra
.656 .759 .926 r
.32693 .56999 .33295 .57524 .34249 .57227 .3365 .56699 Mtetra
.657 .76 .925 r
.3365 .56699 .34249 .57227 .35208 .56927 .3461 .56396 Mtetra
.658 .759 .925 r
.3461 .56396 .35208 .56927 .3617 .56625 .35575 .5609 Mtetra
.658 .758 .924 r
.35575 .5609 .3617 .56625 .37135 .56323 .36542 .55783 Mtetra
.658 .757 .923 r
.36542 .55783 .37135 .56323 .38103 .5602 .37513 .55474 Mtetra
.658 .756 .922 r
.37513 .55474 .38103 .5602 .39076 .55716 .38488 .55166 Mtetra
.657 .755 .922 r
.38488 .55166 .39076 .55716 .40051 .55412 .39466 .54858 Mtetra
.657 .754 .921 r
.39466 .54858 .40051 .55412 .41031 .55108 .40447 .54549 Mtetra
.657 .753 .921 r
.40447 .54549 .41031 .55108 .42013 .54802 .41432 .54241 Mtetra
.656 .753 .921 r
.41432 .54241 .42013 .54802 .43 .54497 .42421 .53932 Mtetra
.656 .752 .921 r
.42421 .53932 .43 .54497 .4399 .5419 .43413 .53622 Mtetra
.656 .752 .92 r
.43413 .53622 .4399 .5419 .44983 .53882 .44409 .53312 Mtetra
.44409 .53312 .44983 .53882 .4598 .53573 .45409 .53001 Mtetra
.45409 .53001 .4598 .53573 .46981 .53263 .46412 .52689 Mtetra
.46412 .52689 .46981 .53263 .47986 .52952 .47419 .52376 Mtetra
.656 .751 .92 r
.47419 .52376 .47986 .52952 .48994 .5264 .4843 .52061 Mtetra
.4843 .52061 .48994 .5264 .50006 .52327 .49444 .51746 Mtetra
.49444 .51746 .50006 .52327 .51022 .52013 .50462 .51429 Mtetra
.50462 .51429 .51022 .52013 .52041 .51697 .51484 .51112 Mtetra
.51484 .51112 .52041 .51697 .53065 .51381 .5251 .50793 Mtetra
.5251 .50793 .53065 .51381 .54092 .51063 .5354 .50473 Mtetra
.5354 .50473 .54092 .51063 .55123 .50744 .54573 .50151 Mtetra
.54573 .50151 .55123 .50744 .56158 .50423 .55611 .49829 Mtetra
.55611 .49829 .56158 .50423 .57197 .50102 .56652 .49505 Mtetra
.56652 .49505 .57197 .50102 .58239 .49779 .57697 .4918 Mtetra
.57697 .4918 .58239 .49779 .59286 .49455 .58747 .48854 Mtetra
.58747 .48854 .59286 .49455 .60336 .4913 .598 .48527 Mtetra
.598 .48527 .60336 .4913 .61391 .48804 .60857 .48198 Mtetra
.60857 .48198 .61391 .48804 .62449 .48476 .61918 .47868 Mtetra
.61918 .47868 .62449 .48476 .63512 .48147 .62983 .47537 Mtetra
.62983 .47537 .63512 .48147 .64578 .47817 .64053 .47205 Mtetra
.64053 .47205 .64578 .47817 .65649 .47486 .65126 .46871 Mtetra
.65126 .46871 .65649 .47486 .66724 .47153 .66204 .46536 Mtetra
.66204 .46536 .66724 .47153 .67803 .4682 .67285 .462 Mtetra
.656 .752 .92 r
.67285 .462 .67803 .4682 .68886 .46485 .68371 .45863 Mtetra
.656 .752 .921 r
.68371 .45863 .68886 .46485 .69973 .46148 .69461 .45525 Mtetra
.655 .752 .921 r
.69461 .45525 .69973 .46148 .71064 .45811 .70555 .45186 Mtetra
.70555 .45186 .71064 .45811 .7216 .45473 .71654 .44846 Mtetra
.71654 .44846 .7216 .45473 .73259 .45133 .72757 .44506 Mtetra
.654 .752 .922 r
.72757 .44506 .73259 .45133 .74363 .44793 .73864 .44165 Mtetra
.654 .753 .922 r
.73864 .44165 .74363 .44793 .75472 .44452 .74975 .43824 Mtetra
.653 .753 .923 r
.74975 .43824 .75472 .44452 .76585 .44111 .76092 .43483 Mtetra
.653 .754 .924 r
.76092 .43483 .76585 .44111 .77702 .43769 .77212 .43141 Mtetra
.653 .755 .925 r
.77212 .43141 .77702 .43769 .78823 .43426 .78337 .42799 Mtetra
.653 .757 .926 r
.78337 .42799 .78823 .43426 .79949 .43081 .79466 .42455 Mtetra
.653 .758 .926 r
.79466 .42455 .79949 .43081 .8108 .42735 .806 .42108 Mtetra
.654 .759 .926 r
.806 .42108 .8108 .42735 .82215 .42386 .81738 .41757 Mtetra
.656 .759 .926 r
.81738 .41757 .82215 .42386 .83354 .42034 .82881 .41401 Mtetra
.657 .759 .925 r
.82881 .41401 .83354 .42034 .84497 .41679 .84027 .4104 Mtetra
.658 .759 .924 r
.84027 .4104 .84497 .41679 .85645 .41319 .85178 .40675 Mtetra
.659 .758 .923 r
.85178 .40675 .85645 .41319 .86796 .40957 .86332 .40305 Mtetra
.66 .757 .922 r
.86332 .40305 .86796 .40957 .87953 .40592 .87491 .39932 Mtetra
.661 .755 .92 r
.87491 .39932 .87953 .40592 .89113 .40224 .88655 .39556 Mtetra
.647 .749 .924 r
.2641 .58177 .27027 .58715 .27962 .58437 .27347 .57903 Mtetra
.647 .752 .926 r
.27347 .57903 .27962 .58437 .28901 .58156 .28287 .57628 Mtetra
.648 .755 .927 r
.28287 .57628 .28901 .58156 .29844 .57873 .29231 .5735 Mtetra
.649 .758 .929 r
.29231 .5735 .29844 .57873 .3079 .57586 .30179 .57067 Mtetra
.651 .76 .929 r
.30179 .57067 .3079 .57586 .31739 .57295 .31131 .56779 Mtetra
.653 .763 .93 r
.31131 .56779 .31739 .57295 .32693 .56999 .32086 .56485 Mtetra
.655 .765 .93 r
.32086 .56485 .32693 .56999 .3365 .56699 .33045 .56184 Mtetra
.657 .766 .929 r
.33045 .56184 .3365 .56699 .3461 .56396 .34008 .55878 Mtetra
.659 .766 .928 r
.34008 .55878 .3461 .56396 .35575 .5609 .34975 .55567 Mtetra
.66 .765 .927 r
.34975 .55567 .35575 .5609 .36542 .55783 .35945 .55253 Mtetra
.66 .763 .926 r
.35945 .55253 .36542 .55783 .37513 .55474 .36918 .54938 Mtetra
.66 .761 .925 r
.36918 .54938 .37513 .55474 .38488 .55166 .37895 .54622 Mtetra
.659 .759 .924 r
.37895 .54622 .38488 .55166 .39466 .54858 .38876 .54307 Mtetra
.659 .757 .923 r
.38876 .54307 .39466 .54858 .40447 .54549 .3986 .53993 Mtetra
.658 .755 .922 r
.3986 .53993 .40447 .54549 .41432 .54241 .40847 .53679 Mtetra
.657 .754 .921 r
.40847 .53679 .41432 .54241 .42421 .53932 .41838 .53366 Mtetra
.657 .753 .921 r
.41838 .53366 .42421 .53932 .43413 .53622 .42833 .53053 Mtetra
.656 .753 .921 r
.42833 .53053 .43413 .53622 .44409 .53312 .43831 .52739 Mtetra
.656 .752 .921 r
.43831 .52739 .44409 .53312 .45409 .53001 .44833 .52425 Mtetra
.656 .752 .92 r
.44833 .52425 .45409 .53001 .46412 .52689 .45839 .52111 Mtetra
.45839 .52111 .46412 .52689 .47419 .52376 .46848 .51795 Mtetra
.46848 .51795 .47419 .52376 .4843 .52061 .47861 .51479 Mtetra
.47861 .51479 .4843 .52061 .49444 .51746 .48878 .51161 Mtetra
.656 .751 .92 r
.48878 .51161 .49444 .51746 .50462 .51429 .49899 .50842 Mtetra
.49899 .50842 .50462 .51429 .51484 .51112 .50923 .50522 Mtetra
.50923 .50522 .51484 .51112 .5251 .50793 .51952 .50201 Mtetra
.51952 .50201 .5251 .50793 .5354 .50473 .52984 .49879 Mtetra
.52984 .49879 .5354 .50473 .54573 .50151 .5402 .49555 Mtetra
.5402 .49555 .54573 .50151 .55611 .49829 .5506 .4923 Mtetra
.5506 .4923 .55611 .49829 .56652 .49505 .56104 .48904 Mtetra
.56104 .48904 .56652 .49505 .57697 .4918 .57152 .48577 Mtetra
.57152 .48577 .57697 .4918 .58747 .48854 .58203 .48249 Mtetra
.58203 .48249 .58747 .48854 .598 .48527 .59259 .47919 Mtetra
.59259 .47919 .598 .48527 .60857 .48198 .60319 .47588 Mtetra
.60319 .47588 .60857 .48198 .61918 .47868 .61383 .47256 Mtetra
.61383 .47256 .61918 .47868 .62983 .47537 .62451 .46923 Mtetra
.62451 .46923 .62983 .47537 .64053 .47205 .63523 .46588 Mtetra
.63523 .46588 .64053 .47205 .65126 .46871 .64599 .46252 Mtetra
.64599 .46252 .65126 .46871 .66204 .46536 .6568 .45915 Mtetra
.656 .752 .921 r
.6568 .45915 .66204 .46536 .67285 .462 .66764 .45577 Mtetra
.655 .752 .921 r
.66764 .45577 .67285 .462 .68371 .45863 .67853 .45238 Mtetra
.67853 .45238 .68371 .45863 .69461 .45525 .68946 .44899 Mtetra
.68946 .44899 .69461 .45525 .70555 .45186 .70043 .44559 Mtetra
.654 .752 .922 r
.70043 .44559 .70555 .45186 .71654 .44846 .71145 .44219 Mtetra
.654 .753 .923 r
.71145 .44219 .71654 .44846 .72757 .44506 .72251 .43879 Mtetra
.653 .754 .924 r
.72251 .43879 .72757 .44506 .73864 .44165 .73361 .4354 Mtetra
.652 .755 .925 r
.73361 .4354 .73864 .44165 .74975 .43824 .74476 .43201 Mtetra
.651 .756 .927 r
.74476 .43201 .74975 .43824 .76092 .43483 .75596 .42863 Mtetra
.651 .758 .928 r
.75596 .42863 .76092 .43483 .77212 .43141 .7672 .42525 Mtetra
.65 .76 .929 r
.7672 .42525 .77212 .43141 .78337 .42799 .77848 .42184 Mtetra
.651 .762 .93 r
.77848 .42184 .78337 .42799 .79466 .42455 .78981 .41841 Mtetra
.652 .764 .931 r
.78981 .41841 .79466 .42455 .806 .42108 .80119 .41492 Mtetra
.654 .765 .931 r
.80119 .41492 .806 .42108 .81738 .41757 .8126 .41137 Mtetra
.656 .765 .93 r
.8126 .41137 .81738 .41757 .82881 .41401 .82405 .40776 Mtetra
.658 .765 .928 r
.82405 .40776 .82881 .41401 .84027 .4104 .83554 .40407 Mtetra
.66 .763 .926 r
.83554 .40407 .84027 .4104 .85178 .40675 .84708 .40033 Mtetra
.662 .762 .924 r
.84708 .40033 .85178 .40675 .86332 .40305 .85865 .39653 Mtetra
.663 .76 .922 r
.85865 .39653 .86332 .40305 .87491 .39932 .87027 .3927 Mtetra
.663 .757 .92 r
.87027 .3927 .87491 .39932 .88655 .39556 .88193 .38884 Mtetra
.643 .748 .925 r
.25789 .57635 .2641 .58177 .27347 .57903 .26727 .57368 Mtetra
.643 .751 .928 r
.26727 .57368 .27347 .57903 .28287 .57628 .27669 .571 Mtetra
.644 .755 .93 r
.27669 .571 .28287 .57628 .29231 .5735 .28615 .56829 Mtetra
.645 .758 .932 r
.28615 .56829 .29231 .5735 .30179 .57067 .29564 .56553 Mtetra
.647 .762 .933 r
.29564 .56553 .30179 .57067 .31131 .56779 .30517 .56272 Mtetra
.649 .766 .934 r
.30517 .56272 .31131 .56779 .32086 .56485 .31474 .55982 Mtetra
.653 .77 .935 r
.31474 .55982 .32086 .56485 .33045 .56184 .32435 .55684 Mtetra
.656 .772 .935 r
.32435 .55684 .33045 .56184 .34008 .55878 .33401 .55377 Mtetra
.659 .773 .934 r
.33401 .55377 .34008 .55878 .34975 .55567 .3437 .55062 Mtetra
.661 .773 .932 r
.3437 .55062 .34975 .55567 .35945 .55253 .35342 .54741 Mtetra
.662 .772 .931 r
.35342 .54741 .35945 .55253 .36918 .54938 .36318 .54417 Mtetra
.663 .769 .929 r
.36318 .54417 .36918 .54938 .37895 .54622 .37298 .54092 Mtetra
.662 .766 .927 r
.37298 .54092 .37895 .54622 .38876 .54307 .38281 .53768 Mtetra
.661 .763 .926 r
.38281 .53768 .38876 .54307 .3986 .53993 .39268 .53444 Mtetra
.66 .76 .924 r
.39268 .53444 .3986 .53993 .40847 .53679 .40258 .53123 Mtetra
.659 .758 .923 r
.40258 .53123 .40847 .53679 .41838 .53366 .41251 .52803 Mtetra
.658 .756 .922 r
.41251 .52803 .41838 .53366 .42833 .53053 .42248 .52485 Mtetra
.657 .755 .922 r
.42248 .52485 .42833 .53053 .43831 .52739 .43249 .52167 Mtetra
.657 .754 .921 r
.43249 .52167 .43831 .52739 .44833 .52425 .44253 .51849 Mtetra
.656 .753 .921 r
.44253 .51849 .44833 .52425 .45839 .52111 .45262 .51531 Mtetra
.45262 .51531 .45839 .52111 .46848 .51795 .46273 .51212 Mtetra
.656 .752 .921 r
.46273 .51212 .46848 .51795 .47861 .51479 .47289 .50893 Mtetra
.47289 .50893 .47861 .51479 .48878 .51161 .48308 .50573 Mtetra
.48308 .50573 .48878 .51161 .49899 .50842 .49331 .50251 Mtetra
.656 .752 .92 r
.49331 .50251 .49899 .50842 .50923 .50522 .50358 .49929 Mtetra
.50358 .49929 .50923 .50522 .51952 .50201 .51389 .49606 Mtetra
.51389 .49606 .51952 .50201 .52984 .49879 .52424 .49281 Mtetra
.52424 .49281 .52984 .49879 .5402 .49555 .53463 .48955 Mtetra
.53463 .48955 .5402 .49555 .5506 .4923 .54505 .48628 Mtetra
.54505 .48628 .5506 .4923 .56104 .48904 .55552 .483 Mtetra
.55552 .483 .56104 .48904 .57152 .48577 .56602 .4797 Mtetra
.56602 .4797 .57152 .48577 .58203 .48249 .57657 .4764 Mtetra
.57657 .4764 .58203 .48249 .59259 .47919 .58715 .47308 Mtetra
.58715 .47308 .59259 .47919 .60319 .47588 .59778 .46974 Mtetra
.59778 .46974 .60319 .47588 .61383 .47256 .60844 .4664 Mtetra
.656 .752 .921 r
.60844 .4664 .61383 .47256 .62451 .46923 .61915 .46305 Mtetra
.61915 .46305 .62451 .46923 .63523 .46588 .6299 .45968 Mtetra
.655 .752 .921 r
.6299 .45968 .63523 .46588 .64599 .46252 .64069 .4563 Mtetra
.64069 .4563 .64599 .46252 .6568 .45915 .65152 .45292 Mtetra
.65152 .45292 .6568 .45915 .66764 .45577 .6624 .44953 Mtetra
.655 .752 .922 r
.6624 .44953 .66764 .45577 .67853 .45238 .67331 .44613 Mtetra
.654 .753 .922 r
.67331 .44613 .67853 .45238 .68946 .44899 .68427 .44274 Mtetra
.653 .753 .923 r
.68427 .44274 .68946 .44899 .70043 .44559 .69528 .43935 Mtetra
.652 .754 .924 r
.69528 .43935 .70043 .44559 .71145 .44219 .70633 .43597 Mtetra
.651 .756 .926 r
.70633 .43597 .71145 .44219 .72251 .43879 .71742 .4326 Mtetra
.65 .757 .928 r
.71742 .4326 .72251 .43879 .73361 .4354 .72856 .42926 Mtetra
.648 .759 .93 r
.72856 .42926 .73361 .4354 .74476 .43201 .73975 .42592 Mtetra
.647 .761 .932 r
.73975 .42592 .74476 .43201 .75596 .42863 .75098 .4226 Mtetra
.647 .764 .934 r
.75098 .4226 .75596 .42863 .7672 .42525 .76226 .41926 Mtetra
.648 .767 .936 r
.76226 .41926 .7672 .42525 .77848 .42184 .77358 .41588 Mtetra
.649 .77 .937 r
.77358 .41588 .77848 .42184 .78981 .41841 .78494 .41244 Mtetra
.652 .771 .936 r
.78494 .41244 .78981 .41841 .80119 .41492 .79635 .40891 Mtetra
.655 .772 .935 r
.79635 .40891 .80119 .41492 .8126 .41137 .80779 .40529 Mtetra
.659 .772 .933 r
.80779 .40529 .8126 .41137 .82405 .40776 .81927 .40157 Mtetra
.661 .77 .93 r
.81927 .40157 .82405 .40776 .83554 .40407 .83079 .39778 Mtetra
.664 .768 .927 r
.83079 .39778 .83554 .40407 .84708 .40033 .84235 .39391 Mtetra
.665 .765 .924 r
.84235 .39391 .84708 .40033 .85865 .39653 .85395 .38999 Mtetra
.666 .762 .922 r
.85395 .38999 .85865 .39653 .87027 .3927 .86559 .38604 Mtetra
.666 .759 .919 r
.86559 .38604 .87027 .3927 .88193 .38884 .87727 .38207 Mtetra
.64 .747 .927 r
.25164 .57089 .25789 .57635 .26727 .57368 .26104 .56828 Mtetra
.639 .75 .929 r
.26104 .56828 .26727 .57368 .27669 .571 .27047 .56566 Mtetra
.639 .753 .931 r
.27047 .56566 .27669 .571 .28615 .56829 .27994 .56303 Mtetra
.639 .757 .933 r
.27994 .56303 .28615 .56829 .29564 .56553 .28944 .56038 Mtetra
.64 .762 .936 r
.28944 .56038 .29564 .56553 .30517 .56272 .29899 .55767 Mtetra
.643 .767 .939 r
.29899 .55767 .30517 .56272 .31474 .55982 .30857 .55489 Mtetra
.647 .773 .94 r
.30857 .55489 .31474 .55982 .32435 .55684 .3182 .55201 Mtetra
.651 .779 .942 r
.3182 .55201 .32435 .55684 .33401 .55377 .32787 .54901 Mtetra
.656 .784 .942 r
.32787 .54901 .33401 .55377 .3437 .55062 .33758 .54587 Mtetra
.66 .786 .941 r
.33758 .54587 .3437 .55062 .35342 .54741 .34733 .54263 Mtetra
.664 .786 .939 r
.34733 .54263 .35342 .54741 .36318 .54417 .35712 .53931 Mtetra
.666 .784 .937 r
.35712 .53931 .36318 .54417 .37298 .54092 .36695 .53594 Mtetra
.666 .781 .935 r
.36695 .53594 .37298 .54092 .38281 .53768 .37681 .53256 Mtetra
.665 .776 .932 r
.37681 .53256 .38281 .53768 .39268 .53444 .38671 .52919 Mtetra
.664 .771 .93 r
.38671 .52919 .39268 .53444 .40258 .53123 .39664 .52584 Mtetra
.662 .767 .927 r
.39664 .52584 .40258 .53123 .41251 .52803 .4066 .52253 Mtetra
.661 .763 .926 r
.4066 .52253 .41251 .52803 .42248 .52485 .4166 .51925 Mtetra
.659 .76 .924 r
.4166 .51925 .42248 .52485 .43249 .52167 .42663 .51599 Mtetra
.658 .757 .923 r
.42663 .51599 .43249 .52167 .44253 .51849 .4367 .51275 Mtetra
.658 .756 .922 r
.4367 .51275 .44253 .51849 .45262 .51531 .4468 .50952 Mtetra
.657 .754 .922 r
.4468 .50952 .45262 .51531 .46273 .51212 .45694 .50629 Mtetra
.657 .754 .921 r
.45694 .50629 .46273 .51212 .47289 .50893 .46712 .50306 Mtetra
.656 .753 .921 r
.46712 .50306 .47289 .50893 .48308 .50573 .47734 .49982 Mtetra
.656 .752 .921 r
.47734 .49982 .48308 .50573 .49331 .50251 .4876 .49658 Mtetra
.4876 .49658 .49331 .50251 .50358 .49929 .49789 .49333 Mtetra
.49789 .49333 .50358 .49929 .51389 .49606 .50823 .49007 Mtetra
.50823 .49007 .51389 .49606 .52424 .49281 .5186 .48679 Mtetra
.656 .752 .92 r
.5186 .48679 .52424 .49281 .53463 .48955 .52901 .48351 Mtetra
.52901 .48351 .53463 .48955 .54505 .48628 .53946 .48022 Mtetra
.53946 .48022 .54505 .48628 .55552 .483 .54996 .47691 Mtetra
.54996 .47691 .55552 .483 .56602 .4797 .56049 .47359 Mtetra
.656 .752 .921 r
.56049 .47359 .56602 .4797 .57657 .4764 .57106 .47027 Mtetra
.57106 .47027 .57657 .4764 .58715 .47308 .58167 .46692 Mtetra
.58167 .46692 .58715 .47308 .59778 .46974 .59232 .46357 Mtetra
.655 .752 .921 r
.59232 .46357 .59778 .46974 .60844 .4664 .60302 .46021 Mtetra
.60302 .46021 .60844 .4664 .61915 .46305 .61375 .45684 Mtetra
.61375 .45684 .61915 .46305 .6299 .45968 .62453 .45346 Mtetra
.655 .752 .922 r
.62453 .45346 .6299 .45968 .64069 .4563 .63535 .45008 Mtetra
.654 .753 .922 r
.63535 .45008 .64069 .4563 .65152 .45292 .64621 .44669 Mtetra
.654 .753 .923 r
.64621 .44669 .65152 .45292 .6624 .44953 .65711 .4433 Mtetra
.653 .754 .924 r
.65711 .4433 .6624 .44953 .67331 .44613 .66806 .43993 Mtetra
.652 .755 .926 r
.66806 .43993 .67331 .44613 .68427 .44274 .67906 .43657 Mtetra
.65 .757 .927 r
.67906 .43657 .68427 .44274 .69528 .43935 .69009 .43323 Mtetra
.648 .759 .93 r
.69009 .43323 .69528 .43935 .70633 .43597 .70118 .42992 Mtetra
.646 .761 .933 r
.70118 .42992 .70633 .43597 .71742 .4326 .71231 .42664 Mtetra
.644 .765 .937 r
.71231 .42664 .71742 .4326 .72856 .42926 .72349 .4234 Mtetra
.642 .769 .94 r
.72349 .4234 .72856 .42926 .73975 .42592 .73471 .42016 Mtetra
.641 .773 .943 r
.73471 .42016 .73975 .42592 .75098 .4226 .74599 .4169 Mtetra
.642 .777 .945 r
.74599 .4169 .75098 .4226 .76226 .41926 .7573 .4136 Mtetra
.645 .781 .946 r
.7573 .4136 .76226 .41926 .77358 .41588 .76866 .41021 Mtetra
.649 .783 .945 r
.76866 .41021 .77358 .41588 .78494 .41244 .78006 .40671 Mtetra
.654 .783 .943 r
.78006 .40671 .78494 .41244 .79635 .40891 .79149 .40307 Mtetra
.659 .782 .939 r
.79149 .40307 .79635 .40891 .80779 .40529 .80296 .3993 Mtetra
.664 .779 .935 r
.80296 .3993 .80779 .40529 .81927 .40157 .81446 .39542 Mtetra
.667 .775 .93 r
.81446 .39542 .81927 .40157 .83079 .39778 .826 .39145 Mtetra
.668 .77 .926 r
.826 .39145 .83079 .39778 .84235 .39391 .83758 .38744 Mtetra
.669 .766 .923 r
.83758 .38744 .84235 .39391 .85395 .38999 .84921 .38339 Mtetra
.669 .763 .92 r
.84921 .38339 .85395 .38999 .86559 .38604 .86087 .37931 Mtetra
.669 .759 .918 r
.86087 .37931 .86559 .38604 .87727 .38207 .87259 .37524 Mtetra
.639 .747 .927 r
.24535 .5654 .25164 .57089 .26104 .56828 .25477 .56279 Mtetra
.637 .748 .928 r
.25477 .56279 .26104 .56828 .27047 .56566 .26421 .56021 Mtetra
.635 .749 .93 r
.26421 .56021 .27047 .56566 .27994 .56303 .27369 .55765 Mtetra
.634 .752 .933 r
.27369 .55765 .27994 .56303 .28944 .56038 .28321 .55509 Mtetra
.633 .756 .936 r
.28321 .55509 .28944 .56038 .29899 .55767 .29277 .55253 Mtetra
.634 .762 .94 r
.29277 .55253 .29899 .55767 .30857 .55489 .30236 .54992 Mtetra
.637 .77 .944 r
.30236 .54992 .30857 .55489 .3182 .55201 .312 .54721 Mtetra
.642 .779 .947 r
.312 .54721 .3182 .55201 .32787 .54901 .32168 .54437 Mtetra
.649 .788 .949 r
.32168 .54437 .32787 .54901 .33758 .54587 .33141 .54135 Mtetra
.655 .795 .949 r
.33141 .54135 .33758 .54587 .34733 .54263 .34118 .53816 Mtetra
.662 .8 .948 r
.34118 .53816 .34733 .54263 .35712 .53931 .351 .53481 Mtetra
.667 .8 .946 r
.351 .53481 .35712 .53931 .36695 .53594 .36086 .53135 Mtetra
.669 .798 .944 r
.36086 .53135 .36695 .53594 .37681 .53256 .37075 .52783 Mtetra
.67 .794 .94 r
.37075 .52783 .37681 .53256 .38671 .52919 .38068 .52429 Mtetra
.669 .788 .937 r
.38068 .52429 .38671 .52919 .39664 .52584 .39064 .52077 Mtetra
.667 .781 .934 r
.39064 .52077 .39664 .52584 .4066 .52253 .40063 .5173 Mtetra
.665 .775 .932 r
.40063 .5173 .4066 .52253 .4166 .51925 .41066 .51387 Mtetra
.663 .77 .929 r
.41066 .51387 .4166 .51925 .42663 .51599 .42072 .51049 Mtetra
.661 .766 .927 r
.42072 .51049 .42663 .51599 .4367 .51275 .43081 .50714 Mtetra
.66 .763 .926 r
.43081 .50714 .4367 .51275 .4468 .50952 .44095 .50382 Mtetra
.659 .76 .925 r
.44095 .50382 .4468 .50952 .45694 .50629 .45111 .50052 Mtetra
.658 .758 .924 r
.45111 .50052 .45694 .50629 .46712 .50306 .46132 .49723 Mtetra
.657 .757 .923 r
.46132 .49723 .46712 .50306 .47734 .49982 .47156 .49395 Mtetra
.657 .755 .923 r
.47156 .49395 .47734 .49982 .4876 .49658 .48184 .49067 Mtetra
.656 .755 .922 r
.48184 .49067 .4876 .49658 .49789 .49333 .49217 .48738 Mtetra
.656 .754 .922 r
.49217 .48738 .49789 .49333 .50823 .49007 .50252 .48409 Mtetra
.50252 .48409 .50823 .49007 .5186 .48679 .51292 .48078 Mtetra
.656 .753 .922 r
.51292 .48078 .5186 .48679 .52901 .48351 .52336 .47747 Mtetra
.52336 .47747 .52901 .48351 .53946 .48022 .53384 .47416 Mtetra
.53384 .47416 .53946 .48022 .54996 .47691 .54436 .47083 Mtetra
.54436 .47083 .54996 .47691 .56049 .47359 .55492 .46749 Mtetra
.655 .753 .922 r
.55492 .46749 .56049 .47359 .57106 .47027 .56551 .46414 Mtetra
.56551 .46414 .57106 .47027 .58167 .46692 .57615 .46078 Mtetra
.57615 .46078 .58167 .46692 .59232 .46357 .58683 .45742 Mtetra
.655 .754 .922 r
.58683 .45742 .59232 .46357 .60302 .46021 .59756 .45404 Mtetra
.654 .754 .923 r
.59756 .45404 .60302 .46021 .61375 .45684 .60832 .45067 Mtetra
.654 .754 .924 r
.60832 .45067 .61375 .45684 .62453 .45346 .61913 .44729 Mtetra
.653 .755 .925 r
.61913 .44729 .62453 .45346 .63535 .45008 .62997 .44392 Mtetra
.652 .756 .926 r
.62997 .44392 .63535 .45008 .64621 .44669 .64087 .44055 Mtetra
.651 .757 .927 r
.64087 .44055 .64621 .44669 .65711 .4433 .6518 .43721 Mtetra
.649 .759 .93 r
.6518 .43721 .65711 .4433 .66806 .43993 .66278 .43389 Mtetra
.647 .761 .933 r
.66278 .43389 .66806 .43993 .67906 .43657 .67381 .43061 Mtetra
.644 .764 .936 r
.67381 .43061 .67906 .43657 .69009 .43323 .68489 .42738 Mtetra
.64 .767 .94 r
.68489 .42738 .69009 .43323 .70118 .42992 .69601 .4242 Mtetra
.637 .772 .945 r
.69601 .4242 .70118 .42992 .71231 .42664 .70718 .42105 Mtetra
.634 .777 .949 r
.70718 .42105 .71231 .42664 .72349 .4234 .7184 .41793 Mtetra
.633 .782 .953 r
.7184 .41793 .72349 .4234 .73471 .42016 .72967 .41479 Mtetra
.635 .788 .955 r
.72967 .41479 .73471 .42016 .74599 .4169 .74099 .41158 Mtetra
.638 .792 .956 r
.74099 .41158 .74599 .4169 .7573 .4136 .75234 .40826 Mtetra
.645 .795 .954 r
.75234 .40826 .7573 .4136 .76866 .41021 .76373 .40477 Mtetra
.653 .795 .951 r
.76373 .40477 .76866 .41021 .78006 .40671 .77515 .40111 Mtetra
.661 .793 .945 r
.77515 .40111 .78006 .40671 .79149 .40307 .7866 .39725 Mtetra
.667 .788 .938 r
.7866 .39725 .79149 .40307 .80296 .3993 .79809 .39325 Mtetra
.671 .781 .932 r
.79809 .39325 .80296 .3993 .81446 .39542 .80961 .38915 Mtetra
.673 .775 .927 r
.80961 .38915 .81446 .39542 .826 .39145 .82117 .38499 Mtetra
.673 .769 .922 r
.82117 .38499 .826 .39145 .83758 .38744 .83277 .38082 Mtetra
.672 .764 .92 r
.83277 .38082 .83758 .38744 .84921 .38339 .84442 .37665 Mtetra
.671 .761 .918 r
.84442 .37665 .84921 .38339 .86087 .37931 .85612 .3725 Mtetra
.67 .758 .917 r
.85612 .3725 .86087 .37931 .87259 .37524 .86786 .36837 Mtetra
.643 .748 .926 r
.23902 .55988 .24535 .5654 .25477 .56279 .24846 .55717 Mtetra
.64 .745 .925 r
.24846 .55717 .25477 .56279 .26421 .56021 .25793 .55451 Mtetra
.637 .742 .924 r
.25793 .55451 .26421 .56021 .27369 .55765 .26743 .55191 Mtetra
.634 .74 .925 r
.26743 .55191 .27369 .55765 .28321 .55509 .27697 .54937 Mtetra
.629 .74 .928 r
.27697 .54937 .28321 .55509 .29277 .55253 .28653 .54692 Mtetra
.627 .744 .932 r
.28653 .54692 .29277 .55253 .30236 .54992 .29613 .5445 Mtetra
.625 .752 .937 r
.29613 .5445 .30236 .54992 .312 .54721 .30577 .54206 Mtetra
.628 .763 .944 r
.30577 .54206 .312 .54721 .32168 .54437 .31545 .53953 Mtetra
.633 .778 .95 r
.31545 .53953 .32168 .54437 .33141 .54135 .32519 .53683 Mtetra
.641 .793 .955 r
.32519 .53683 .33141 .54135 .34118 .53816 .33497 .53391 Mtetra
.651 .807 .958 r
.33497 .53391 .34118 .53816 .351 .53481 .3448 .53074 Mtetra
.659 .817 .959 r
.3448 .53074 .351 .53481 .36086 .53135 .35468 .52735 Mtetra
.667 .822 .958 r
.35468 .52735 .36086 .53135 .37075 .52783 .36461 .52378 Mtetra
.671 .822 .956 r
.36461 .52378 .37075 .52783 .38068 .52429 .37457 .52011 Mtetra
.673 .818 .953 r
.37457 .52011 .38068 .52429 .39064 .52077 .38456 .5164 Mtetra
.673 .811 .949 r
.38456 .5164 .39064 .52077 .40063 .5173 .39459 .51269 Mtetra
.672 .803 .945 r
.39459 .51269 .40063 .5173 .41066 .51387 .40465 .50904 Mtetra
.67 .794 .941 r
.40465 .50904 .41066 .51387 .42072 .51049 .41475 .50544 Mtetra
.667 .786 .938 r
.41475 .50544 .42072 .51049 .43081 .50714 .42488 .5019 Mtetra
.665 .779 .934 r
.42488 .5019 .43081 .50714 .44095 .50382 .43504 .49842 Mtetra
.663 .773 .932 r
.43504 .49842 .44095 .50382 .45111 .50052 .44524 .49499 Mtetra
.661 .769 .93 r
.44524 .49499 .45111 .50052 .46132 .49723 .45547 .49159 Mtetra
.66 .765 .928 r
.45547 .49159 .46132 .49723 .47156 .49395 .46574 .48822 Mtetra
.658 .762 .927 r
.46574 .48822 .47156 .49395 .48184 .49067 .47605 .48486 Mtetra
.658 .76 .926 r
.47605 .48486 .48184 .49067 .49217 .48738 .48639 .48151 Mtetra
.657 .759 .925 r
.48639 .48151 .49217 .48738 .50252 .48409 .49678 .47817 Mtetra
.657 .758 .924 r
.49678 .47817 .50252 .48409 .51292 .48078 .5072 .47483 Mtetra
.656 .757 .924 r
.5072 .47483 .51292 .48078 .52336 .47747 .51767 .47148 Mtetra
.656 .756 .924 r
.51767 .47148 .52336 .47747 .53384 .47416 .52817 .46813 Mtetra
.52817 .46813 .53384 .47416 .54436 .47083 .53872 .46478 Mtetra
.655 .756 .924 r
.53872 .46478 .54436 .47083 .55492 .46749 .5493 .46142 Mtetra
.5493 .46142 .55492 .46749 .56551 .46414 .55993 .45806 Mtetra
.654 .756 .925 r
.55993 .45806 .56551 .46414 .57615 .46078 .5706 .4547 Mtetra
.654 .757 .925 r
.5706 .4547 .57615 .46078 .58683 .45742 .58131 .45134 Mtetra
.653 .757 .926 r
.58131 .45134 .58683 .45742 .59756 .45404 .59206 .44798 Mtetra
.652 .758 .928 r
.59206 .44798 .59756 .45404 .60832 .45067 .60285 .44463 Mtetra
.651 .76 .929 r
.60285 .44463 .60832 .45067 .61913 .44729 .61369 .4413 Mtetra
.649 .762 .932 r
.61369 .4413 .61913 .44729 .62997 .44392 .62457 .43799 Mtetra
.647 .764 .934 r
.62457 .43799 .62997 .44392 .64087 .44055 .63549 .43472 Mtetra
.644 .767 .938 r
.63549 .43472 .64087 .44055 .6518 .43721 .64647 .43149 Mtetra
.64 .771 .943 r
.64647 .43149 .6518 .43721 .66278 .43389 .65749 .42832 Mtetra
.635 .776 .948 r
.65749 .42832 .66278 .43389 .67381 .43061 .66855 .42522 Mtetra
.63 .782 .954 r
.66855 .42522 .67381 .43061 .68489 .42738 .67967 .42217 Mtetra
.625 .788 .96 r
.67967 .42217 .68489 .42738 .69601 .4242 .69084 .41917 Mtetra
.621 .796 .966 r
.69084 .41917 .69601 .4242 .70718 .42105 .70206 .41618 Mtetra
.62 .803 .97 r
.70206 .41618 .70718 .42105 .7184 .41793 .71332 .41315 Mtetra
.623 .808 .971 r
.71332 .41315 .7184 .41793 .72967 .41479 .72463 .41001 Mtetra
.632 .813 .97 r
.72463 .41001 .72967 .41479 .74099 .41158 .73597 .40669 Mtetra
.643 .813 .965 r
.73597 .40669 .74099 .41158 .75234 .40826 .74735 .40314 Mtetra
.656 .81 .957 r
.74735 .40314 .75234 .40826 .76373 .40477 .75875 .39933 Mtetra
.667 .801 .947 r
.75875 .39933 .76373 .40477 .77515 .40111 .77019 .39529 Mtetra
.675 .791 .936 r
.77019 .39529 .77515 .40111 .7866 .39725 .78165 .39106 Mtetra
.679 .78 .926 r
.78165 .39106 .7866 .39725 .79809 .39325 .79314 .38673 Mtetra
.679 .769 .919 r
.79314 .38673 .79809 .39325 .80961 .38915 .80468 .38238 Mtetra
.678 .761 .914 r
.80468 .38238 .80961 .38915 .82117 .38499 .81626 .37806 Mtetra
.674 .755 .912 r
.81626 .37806 .82117 .38499 .83277 .38082 .82789 .37382 Mtetra
.672 .753 .911 r
.82789 .37382 .83277 .38082 .84442 .37665 .83958 .36964 Mtetra
.669 .752 .913 r
.83958 .36964 .84442 .37665 .85612 .3725 .85132 .36551 Mtetra
.667 .753 .915 r
.85132 .36551 .85612 .3725 .86786 .36837 .8631 .36144 Mtetra
.652 .75 .922 r
.23264 .55431 .23902 .55988 .24846 .55717 .24212 .55138 Mtetra
.649 .743 .918 r
.24212 .55138 .24846 .55717 .25793 .55451 .25163 .54851 Mtetra
.645 .735 .915 r
.25163 .54851 .25793 .55451 .26743 .55191 .26116 .54574 Mtetra
.639 .728 .913 r
.26116 .54574 .26743 .55191 .27697 .54937 .27072 .5431 Mtetra
.63 .723 .914 r
.27072 .5431 .27697 .54937 .28653 .54692 .2803 .54065 Mtetra
.623 .721 .917 r
.2803 .54065 .28653 .54692 .29613 .5445 .28991 .53834 Mtetra
.616 .723 .923 r
.28991 .53834 .29613 .5445 .30577 .54206 .29955 .53618 Mtetra
.613 .733 .931 r
.29955 .53618 .30577 .54206 .31545 .53953 .30922 .53403 Mtetra
.613 .748 .941 r
.30922 .53403 .31545 .53953 .32519 .53683 .31895 .5318 Mtetra
.619 .768 .952 r
.31895 .5318 .32519 .53683 .33497 .53391 .32872 .52938 Mtetra
.63 .792 .96 r
.32872 .52938 .33497 .53391 .3448 .53074 .33856 .52663 Mtetra
.641 .813 .966 r
.33856 .52663 .3448 .53074 .35468 .52735 .34845 .52356 Mtetra
.655 .83 .967 r
.34845 .52356 .35468 .52735 .36461 .52378 .35839 .52015 Mtetra
.664 .839 .967 r
.35839 .52015 .36461 .52378 .37457 .52011 .36838 .51651 Mtetra
.672 .843 .965 r
.36838 .51651 .37457 .52011 .38456 .5164 .37841 .51269 Mtetra
.676 .84 .962 r
.37841 .51269 .38456 .5164 .39459 .51269 .38848 .50879 Mtetra
.677 .833 .959 r
.38848 .50879 .39459 .51269 .40465 .50904 .39858 .5049 Mtetra
.676 .824 .955 r
.39858 .5049 .40465 .50904 .41475 .50544 .40871 .50104 Mtetra
.674 .814 .951 r
.40871 .50104 .41475 .50544 .42488 .5019 .41887 .49726 Mtetra
.671 .805 .947 r
.41887 .49726 .42488 .5019 .43504 .49842 .42907 .49355 Mtetra
.668 .796 .943 r
.42907 .49355 .43504 .49842 .44524 .49499 .4393 .48993 Mtetra
.665 .789 .94 r
.4393 .48993 .44524 .49499 .45547 .49159 .44957 .48636 Mtetra
.663 .783 .938 r
.44957 .48636 .45547 .49159 .46574 .48822 .45987 .48285 Mtetra
.661 .778 .936 r
.45987 .48285 .46574 .48822 .47605 .48486 .4702 .47938 Mtetra
.66 .774 .934 r
.4702 .47938 .47605 .48486 .48639 .48151 .48058 .47594 Mtetra
.658 .771 .933 r
.48058 .47594 .48639 .48151 .49678 .47817 .49099 .47252 Mtetra
.657 .769 .932 r
.49099 .47252 .49678 .47817 .5072 .47483 .50144 .46912 Mtetra
.656 .767 .931 r
.50144 .46912 .5072 .47483 .51767 .47148 .51194 .46573 Mtetra
.656 .766 .931 r
.51194 .46573 .51767 .47148 .52817 .46813 .52247 .46234 Mtetra
.655 .766 .931 r
.52247 .46234 .52817 .46813 .53872 .46478 .53304 .45897 Mtetra
.654 .765 .931 r
.53304 .45897 .53872 .46478 .5493 .46142 .54365 .4556 Mtetra
.653 .766 .932 r
.54365 .4556 .5493 .46142 .55993 .45806 .55431 .45224 Mtetra
.652 .766 .933 r
.55431 .45224 .55993 .45806 .5706 .4547 .565 .44889 Mtetra
.651 .767 .934 r
.565 .44889 .5706 .4547 .58131 .45134 .57574 .44555 Mtetra
.649 .768 .936 r
.57574 .44555 .58131 .45134 .59206 .44798 .58652 .44224 Mtetra
.647 .77 .938 r
.58652 .44224 .59206 .44798 .60285 .44463 .59735 .43896 Mtetra
.644 .773 .942 r
.59735 .43896 .60285 .44463 .61369 .4413 .60822 .43572 Mtetra
.64 .776 .945 r
.60822 .43572 .61369 .4413 .62457 .43799 .61914 .43254 Mtetra
.636 .78 .95 r
.61914 .43254 .62457 .43799 .63549 .43472 .6301 .42942 Mtetra
.63 .785 .956 r
.6301 .42942 .63549 .43472 .64647 .43149 .64111 .42637 Mtetra
.623 .791 .962 r
.64111 .42637 .64647 .43149 .65749 .42832 .65217 .42341 Mtetra
.616 .797 .969 r
.65217 .42341 .65749 .42832 .66855 .42522 .66329 .42052 Mtetra
.609 .804 .975 r
.66329 .42052 .66855 .42522 .67967 .42217 .67445 .41767 Mtetra
.604 .812 .98 r
.67445 .41767 .67967 .42217 .69084 .41917 .68567 .41483 Mtetra
.604 .819 .982 r
.68567 .41483 .69084 .41917 .70206 .41618 .69693 .4119 Mtetra
.611 .826 .982 r
.69693 .4119 .70206 .41618 .71332 .41315 .70823 .4088 Mtetra
.625 .829 .979 r
.70823 .4088 .71332 .41315 .72463 .41001 .71956 .40546 Mtetra
.645 .828 .971 r
.71956 .40546 .72463 .41001 .73597 .40669 .73092 .40175 Mtetra
.664 .82 .959 r
.73092 .40175 .73597 .40669 .74735 .40314 .7423 .39772 Mtetra
.68 .807 .943 r
.7423 .39772 .74735 .40314 .75875 .39933 .75371 .39335 Mtetra
.688 .79 .928 r
.75371 .39335 .75875 .39933 .77019 .39529 .76513 .38876 Mtetra
.69 .773 .914 r
.76513 .38876 .77019 .39529 .78165 .39106 .7766 .38409 Mtetra
.689 .758 .905 r
.7766 .38409 .78165 .39106 .79314 .38673 .7881 .37943 Mtetra
.683 .746 .899 r
.7881 .37943 .79314 .38673 .80468 .38238 .79966 .37491 Mtetra
.677 .739 .898 r
.79966 .37491 .80468 .38238 .81626 .37806 .81127 .37053 Mtetra
.671 .736 .899 r
.81127 .37053 .81626 .37806 .82789 .37382 .82294 .36635 Mtetra
.666 .737 .903 r
.82294 .36635 .82789 .37382 .83958 .36964 .83467 .3623 Mtetra
.662 .74 .908 r
.83467 .3623 .83958 .36964 .85132 .36551 .84646 .35835 Mtetra
.66 .746 .914 r
.84646 .35835 .85132 .36551 .8631 .36144 .85831 .35446 Mtetra
.665 .754 .916 r
.22623 .54871 .23264 .55431 .24212 .55138 .23575 .54544 Mtetra
.663 .742 .909 r
.23575 .54544 .24212 .55138 .25163 .54851 .2453 .5422 Mtetra
.659 .729 .902 r
.2453 .5422 .25163 .54851 .26116 .54574 .25488 .53906 Mtetra
.652 .716 .895 r
.25488 .53906 .26116 .54574 .27072 .5431 .26448 .53607 Mtetra
.642 .703 .891 r
.26448 .53607 .27072 .5431 .2803 .54065 .2741 .53332 Mtetra
.632 .692 .888 r
.2741 .53332 .2803 .54065 .28991 .53834 .28374 .53083 Mtetra
.618 .683 .888 r
.28374 .53083 .28991 .53834 .29955 .53618 .29339 .52867 Mtetra
.609 .68 .892 r
.29339 .52867 .29955 .53618 .30922 .53403 .30307 .52674 Mtetra
.6 .683 .9 r
.30307 .52674 .30922 .53403 .31895 .5318 .31277 .52498 Mtetra
.598 .698 .913 r
.31277 .52498 .31895 .5318 .32872 .52938 .32253 .5232 Mtetra
.603 .723 .929 r
.32253 .5232 .32872 .52938 .33856 .52663 .33234 .52123 Mtetra
.611 .755 .947 r
.33234 .52123 .33856 .52663 .34845 .52356 .3422 .51897 Mtetra
.625 .791 .962 r
.3422 .51897 .34845 .52356 .35839 .52015 .35214 .51626 Mtetra
.637 .823 .972 r
.35214 .51626 .35839 .52015 .36838 .51651 .36213 .51315 Mtetra
.65 .849 .977 r
.36213 .51315 .36838 .51651 .37841 .51269 .37218 .50966 Mtetra
.658 .865 .978 r
.37218 .50966 .37841 .51269 .38848 .50879 .38227 .50589 Mtetra
.664 .873 .977 r
.38227 .50589 .38848 .50879 .39858 .5049 .3924 .50195 Mtetra
.669 .873 .976 r
.3924 .50195 .39858 .5049 .40871 .50104 .40258 .49793 Mtetra
.67 .867 .974 r
.40258 .49793 .40871 .50104 .41887 .49726 .41278 .49391 Mtetra
.671 .859 .971 r
.41278 .49391 .41887 .49726 .42907 .49355 .42302 .48993 Mtetra
.669 .848 .968 r
.42302 .48993 .42907 .49355 .4393 .48993 .43329 .48603 Mtetra
.668 .837 .965 r
.43329 .48603 .4393 .48993 .44957 .48636 .44359 .4822 Mtetra
.666 .827 .961 r
.44359 .4822 .44957 .48636 .45987 .48285 .45393 .47846 Mtetra
.663 .818 .958 r
.45393 .47846 .45987 .48285 .4702 .47938 .4643 .47479 Mtetra
.661 .811 .955 r
.4643 .47479 .4702 .47938 .48058 .47594 .47471 .47118 Mtetra
.659 .804 .953 r
.47471 .47118 .48058 .47594 .49099 .47252 .48515 .46763 Mtetra
.657 .799 .951 r
.48515 .46763 .49099 .47252 .50144 .46912 .49563 .46412 Mtetra
.655 .796 .95 r
.49563 .46412 .50144 .46912 .51194 .46573 .50616 .46065 Mtetra
.653 .793 .949 r
.50616 .46065 .51194 .46573 .52247 .46234 .51672 .45722 Mtetra
.651 .791 .949 r
.51672 .45722 .52247 .46234 .53304 .45897 .52732 .45382 Mtetra
.649 .791 .95 r
.52732 .45382 .53304 .45897 .54365 .4556 .53796 .45045 Mtetra
.647 .791 .951 r
.53796 .45045 .54365 .4556 .55431 .45224 .54865 .44712 Mtetra
.644 .792 .953 r
.54865 .44712 .55431 .45224 .565 .44889 .55938 .44383 Mtetra
.641 .794 .956 r
.55938 .44383 .565 .44889 .57574 .44555 .57015 .44059 Mtetra
.636 .797 .96 r
.57015 .44059 .57574 .44555 .58652 .44224 .58097 .4374 Mtetra
.631 .801 .965 r
.58097 .4374 .58652 .44224 .59735 .43896 .59183 .43428 Mtetra
.624 .806 .97 r
.59183 .43428 .59735 .43896 .60822 .43572 .60274 .43123 Mtetra
.615 .812 .976 r
.60274 .43123 .60822 .43572 .61914 .43254 .6137 .42826 Mtetra
.606 .819 .982 r
.6137 .42826 .61914 .43254 .6301 .42942 .6247 .42538 Mtetra
.594 .825 .987 r
.6247 .42538 .6301 .42942 .64111 .42637 .63576 .42257 Mtetra
.584 .832 .992 r
.63576 .42257 .64111 .42637 .65217 .42341 .64687 .41981 Mtetra
.576 .839 .995 r
.64687 .41981 .65217 .42341 .66329 .42052 .65803 .41704 Mtetra
.576 .845 .995 r
.65803 .41704 .66329 .42052 .67445 .41767 .66923 .4142 Mtetra
.586 .85 .994 r
.66923 .4142 .67445 .41767 .68567 .41483 .68048 .41117 Mtetra
.607 .851 .99 r
.68048 .41117 .68567 .41483 .69693 .4119 .69176 .40788 Mtetra
.637 .847 .98 r
.69176 .40788 .69693 .4119 .70823 .4088 .70307 .40417 Mtetra
.665 .832 .964 r
.70307 .40417 .70823 .4088 .71956 .40546 .7144 .40006 Mtetra
.688 .81 .941 r
.7144 .40006 .71956 .40546 .73092 .40175 .72574 .39548 Mtetra
.699 .783 .916 r
.72574 .39548 .73092 .40175 .7423 .39772 .7371 .39058 Mtetra
.702 .757 .894 r
.7371 .39058 .7423 .39772 .75371 .39335 .74849 .38549 Mtetra
.699 .735 .879 r
.74849 .38549 .75371 .39335 .76513 .38876 .75991 .38037 Mtetra
.691 .717 .87 r
.75991 .38037 .76513 .38876 .7766 .38409 .77138 .37543 Mtetra
.683 .708 .867 r
.77138 .37543 .7766 .38409 .7881 .37943 .78291 .37071 Mtetra
.673 .703 .87 r
.78291 .37071 .7881 .37943 .79966 .37491 .79451 .36632 Mtetra
.665 .704 .876 r
.79451 .36632 .79966 .37491 .81127 .37053 .80617 .36221 Mtetra
.658 .709 .885 r
.80617 .36221 .81127 .37053 .82294 .36635 .81791 .35834 Mtetra
.653 .716 .895 r
.81791 .35834 .82294 .36635 .83467 .3623 .82971 .35463 Mtetra
.65 .726 .905 r
.82971 .35463 .83467 .3623 .84646 .35835 .84156 .35102 Mtetra
.648 .737 .914 r
.84156 .35102 .84646 .35835 .85831 .35446 .85348 .34743 Mtetra
.679 .757 .91 r
.21976 .54307 .22623 .54871 .23575 .54544 .22934 .53943 Mtetra
.679 .745 .901 r
.22934 .53943 .23575 .54544 .2453 .5422 .23895 .53575 Mtetra
.676 .731 .891 r
.23895 .53575 .2453 .5422 .25488 .53906 .24858 .53212 Mtetra
.67 .715 .882 r
.24858 .53212 .25488 .53906 .26448 .53607 .25824 .5286 Mtetra
.661 .698 .873 r
.25824 .5286 .26448 .53607 .2741 .53332 .26792 .52528 Mtetra
.648 .679 .865 r
.26792 .52528 .2741 .53332 .28374 .53083 .2776 .52229 Mtetra
.631 .66 .86 r
.2776 .52229 .28374 .53083 .29339 .52867 .28729 .51975 Mtetra
.615 .645 .857 r
.28729 .51975 .29339 .52867 .30307 .52674 .29699 .51766 Mtetra
.596 .634 .859 r
.29699 .51766 .30307 .52674 .31277 .52498 .30669 .5161 Mtetra
.583 .634 .868 r
.30669 .5161 .31277 .52498 .32253 .5232 .31642 .51484 Mtetra
.574 .645 .882 r
.31642 .51484 .32253 .5232 .33234 .52123 .32619 .51373 Mtetra
.574 .67 .904 r
.32619 .51373 .33234 .52123 .3422 .51897 .33602 .51251 Mtetra
.584 .709 .929 r
.33602 .51251 .3422 .51897 .35214 .51626 .34591 .5109 Mtetra
.597 .755 .953 r
.34591 .5109 .35214 .51626 .36213 .51315 .35587 .50883 Mtetra
.616 .802 .971 r
.35587 .50883 .36213 .51315 .37218 .50966 .36591 .50615 Mtetra
.63 .84 .981 r
.36591 .50615 .37218 .50966 .38227 .50589 .37601 .50298 Mtetra
.643 .868 .983 r
.37601 .50298 .38227 .50589 .3924 .50195 .38616 .49937 Mtetra
.651 .884 .983 r
.38616 .49937 .3924 .50195 .40258 .49793 .39636 .49548 Mtetra
.657 .891 .981 r
.39636 .49548 .40258 .49793 .41278 .49391 .4066 .49142 Mtetra
.661 .891 .98 r
.4066 .49142 .41278 .49391 .42302 .48993 .41688 .48729 Mtetra
.662 .887 .98 r
.41688 .48729 .42302 .48993 .43329 .48603 .42719 .48318 Mtetra
.663 .879 .979 r
.42719 .48318 .43329 .48603 .44359 .4822 .43754 .47911 Mtetra
.661 .871 .978 r
.43754 .47911 .44359 .4822 .45393 .47846 .44791 .47513 Mtetra
.66 .862 .976 r
.44791 .47513 .45393 .47846 .4643 .47479 .45832 .47124 Mtetra
.657 .853 .975 r
.45832 .47124 .4643 .47479 .47471 .47118 .46877 .46744 Mtetra
.655 .846 .973 r
.46877 .46744 .47471 .47118 .48515 .46763 .47925 .46373 Mtetra
.652 .839 .972 r
.47925 .46373 .48515 .46763 .49563 .46412 .48977 .46009 Mtetra
.648 .834 .972 r
.48977 .46009 .49563 .46412 .50616 .46065 .50032 .45653 Mtetra
.645 .83 .972 r
.50032 .45653 .50616 .46065 .51672 .45722 .51092 .45304 Mtetra
.641 .828 .972 r
.51092 .45304 .51672 .45722 .52732 .45382 .52155 .44962 Mtetra
.637 .827 .973 r
.52155 .44962 .52732 .45382 .53796 .45045 .53223 .44627 Mtetra
.632 .826 .975 r
.53223 .44627 .53796 .45045 .54865 .44712 .54295 .44299 Mtetra
.626 .827 .978 r
.54295 .44299 .54865 .44712 .55938 .44383 .55372 .43978 Mtetra
.619 .829 .981 r
.55372 .43978 .55938 .44383 .57015 .44059 .56453 .43665 Mtetra
.61 .832 .985 r
.56453 .43665 .57015 .44059 .58097 .4374 .57538 .43361 Mtetra
.599 .836 .989 r
.57538 .43361 .58097 .4374 .59183 .43428 .58628 .43067 Mtetra
.587 .84 .993 r
.58628 .43067 .59183 .43428 .60274 .43123 .59723 .42781 Mtetra
.574 .843 .996 r
.59723 .42781 .60274 .43123 .6137 .42826 .60824 .42505 Mtetra
.561 .848 .997 r
.60824 .42505 .6137 .42826 .6247 .42538 .61929 .42233 Mtetra
.551 .851 .998 r
.61929 .42233 .6247 .42538 .63576 .42257 .63039 .41963 Mtetra
.55 .856 .997 r
.63039 .41963 .63576 .42257 .64687 .41981 .64154 .41687 Mtetra
.56 .861 .997 r
.64154 .41687 .64687 .41981 .65803 .41704 .65274 .41393 Mtetra
.586 .864 .995 r
.65274 .41393 .65803 .41704 .66923 .4142 .66397 .4107 Mtetra
.624 .864 .988 r
.66397 .4107 .66923 .4142 .68048 .41117 .67523 .40703 Mtetra
.663 .851 .972 r
.67523 .40703 .68048 .41117 .69176 .40788 .6865 .40284 Mtetra
.696 .826 .945 r
.6865 .40284 .69176 .40788 .70307 .40417 .69779 .39803 Mtetra
.713 .792 .913 r
.69779 .39803 .70307 .40417 .7144 .40006 .70909 .39272 Mtetra
.718 .756 .882 r
.70909 .39272 .7144 .40006 .72574 .39548 .72039 .38702 Mtetra
.714 .724 .858 r
.72039 .38702 .72574 .39548 .7371 .39058 .73172 .38118 Mtetra
.703 .697 .842 r
.73172 .38118 .7371 .39058 .74849 .38549 .7431 .3755 Mtetra
.692 .68 .834 r
.7431 .3755 .74849 .38549 .75991 .38037 .75452 .37012 Mtetra
.677 .669 .834 r
.75452 .37012 .75991 .38037 .77138 .37543 .76603 .36527 Mtetra
.666 .666 .841 r
.76603 .36527 .77138 .37543 .78291 .37071 .77761 .3609 Mtetra
.655 .669 .852 r
.77761 .3609 .78291 .37071 .79451 .36632 .78927 .35699 Mtetra
.647 .678 .865 r
.78927 .35699 .79451 .36632 .80617 .36221 .80101 .35341 Mtetra
.641 .69 .88 r
.80101 .35341 .80617 .36221 .81791 .35834 .81282 .35004 Mtetra
.637 .702 .894 r
.81282 .35004 .81791 .35834 .82971 .35463 .82469 .3468 Mtetra
.635 .716 .906 r
.82469 .3468 .82971 .35463 .84156 .35102 .83663 .34359 Mtetra
.635 .73 .917 r
.83663 .34359 .84156 .35102 .85348 .34743 .84861 .34035 Mtetra
.684 .758 .907 r
.21326 .53739 .21976 .54307 .22934 .53943 .22287 .53358 Mtetra
.687 .753 .902 r
.22287 .53358 .22934 .53943 .23895 .53575 .23252 .52965 Mtetra
.688 .746 .895 r
.23252 .52965 .23895 .53575 .24858 .53212 .24221 .52566 Mtetra
.687 .735 .887 r
.24221 .52566 .24858 .53212 .25824 .5286 .25192 .52165 Mtetra
.685 .721 .877 r
.25192 .52165 .25824 .5286 .26792 .52528 .26167 .51764 Mtetra
.675 .699 .864 r
.26167 .51764 .26792 .52528 .2776 .52229 .27143 .51382 Mtetra
.662 .674 .851 r
.27143 .51382 .2776 .52229 .28729 .51975 .2812 .51031 Mtetra
.643 .646 .838 r
.2812 .51031 .28729 .51975 .29699 .51766 .29097 .50729 Mtetra
.62 .617 .826 r
.29097 .50729 .29699 .51766 .30669 .5161 .30073 .50495 Mtetra
.599 .593 .817 r
.30073 .50495 .30669 .5161 .31642 .51484 .31049 .50324 Mtetra
.579 .576 .814 r
.31049 .50324 .31642 .51484 .32619 .51373 .32026 .50217 Mtetra
.567 .571 .817 r
.32026 .50217 .32619 .51373 .33602 .51251 .33006 .50146 Mtetra
.561 .578 .828 r
.33006 .50146 .33602 .51251 .34591 .5109 .33989 .50088 Mtetra
.564 .602 .849 r
.33989 .50088 .34591 .5109 .35587 .50883 .34979 .50013 Mtetra
.576 .64 .877 r
.34979 .50013 .35587 .50883 .36591 .50615 .35977 .49895 Mtetra
.591 .691 .911 r
.35977 .49895 .36591 .50615 .37601 .50298 .36982 .49726 Mtetra
.61 .749 .943 r
.36982 .49726 .37601 .50298 .38616 .49937 .37994 .49494 Mtetra
.623 .803 .969 r
.37994 .49494 .38616 .49937 .39636 .49548 .39013 .49211 Mtetra
.63 .849 .983 r
.39013 .49211 .39636 .49548 .4066 .49142 .40037 .48882 Mtetra
.629 .88 .988 r
.40037 .48882 .4066 .49142 .41688 .48729 .41067 .48521 Mtetra
.624 .899 .986 r
.41067 .48521 .41688 .48729 .42719 .48318 .42101 .4814 Mtetra
.618 .908 .983 r
.42101 .4814 .42719 .48318 .43754 .47911 .43139 .47747 Mtetra
.613 .911 .981 r
.43139 .47747 .43754 .47911 .44791 .47513 .4418 .47351 Mtetra
.609 .911 .981 r
.4418 .47351 .44791 .47513 .45832 .47124 .45225 .46957 Mtetra
.605 .909 .982 r
.45225 .46957 .45832 .47124 .46877 .46744 .46274 .46568 Mtetra
.601 .906 .983 r
.46274 .46568 .46877 .46744 .47925 .46373 .47326 .46186 Mtetra
.597 .902 .985 r
.47326 .46186 .47925 .46373 .48977 .46009 .48382 .45813 Mtetra
.593 .898 .987 r
.48382 .45813 .48977 .46009 .50032 .45653 .49442 .4545 Mtetra
.587 .894 .988 r
.49442 .4545 .50032 .45653 .51092 .45304 .50506 .45096 Mtetra
.58 .891 .989 r
.50506 .45096 .51092 .45304 .52155 .44962 .51573 .44752 Mtetra
.571 .888 .989 r
.51573 .44752 .52155 .44962 .53223 .44627 .52645 .44417 Mtetra
.561 .885 .989 r
.52645 .44417 .53223 .44627 .54295 .44299 .53721 .44092 Mtetra
.55 .882 .989 r
.53721 .44092 .54295 .44299 .55372 .43978 .54802 .43777 Mtetra
.537 .88 .987 r
.54802 .43777 .55372 .43978 .56453 .43665 .55887 .43471 Mtetra
.525 .877 .985 r
.55887 .43471 .56453 .43665 .57538 .43361 .56977 .43171 Mtetra
.515 .875 .984 r
.56977 .43171 .57538 .43361 .58628 .43067 .58072 .42878 Mtetra
.51 .874 .983 r
.58072 .42878 .58628 .43067 .59723 .42781 .59171 .42586 Mtetra
.515 .875 .984 r
.59171 .42586 .59723 .42781 .60824 .42505 .60275 .42292 Mtetra
.533 .877 .988 r
.60275 .42292 .60824 .42505 .61929 .42233 .61384 .41985 Mtetra
.565 .879 .992 r
.61384 .41985 .61929 .42233 .63039 .41963 .62497 .41658 Mtetra
.609 .874 .991 r
.62497 .41658 .63039 .41963 .64154 .41687 .63613 .41298 Mtetra
.654 .857 .977 r
.63613 .41298 .64154 .41687 .65274 .41393 .64732 .40892 Mtetra
.689 .823 .947 r
.64732 .40892 .65274 .41393 .66397 .4107 .65853 .40432 Mtetra
.71 .781 .907 r
.65853 .40432 .66397 .4107 .67523 .40703 .66975 .39908 Mtetra
.716 .736 .867 r
.66975 .39908 .67523 .40703 .6865 .40284 .68098 .3933 Mtetra
.715 .697 .832 r
.68098 .3933 .6865 .40284 .69779 .39803 .69222 .38707 Mtetra
.707 .666 .807 r
.69222 .38707 .69779 .39803 .70909 .39272 .70348 .38065 Mtetra
.696 .643 .792 r
.70348 .38065 .70909 .39272 .72039 .38702 .71477 .37436 Mtetra
.686 .629 .787 r
.71477 .37436 .72039 .38702 .73172 .38118 .72611 .36842 Mtetra
.672 .621 .79 r
.72611 .36842 .73172 .38118 .7431 .3755 .73752 .36315 Mtetra
.661 .623 .801 r
.73752 .36315 .7431 .3755 .75452 .37012 .74902 .35851 Mtetra
.648 .63 .818 r
.74902 .35851 .75452 .37012 .76603 .36527 .76061 .35458 Mtetra
.638 .643 .838 r
.76061 .35458 .76603 .36527 .77761 .3609 .77228 .35115 Mtetra
.631 .661 .861 r
.77228 .35115 .77761 .3609 .78927 .35699 .78404 .34805 Mtetra
.626 .679 .881 r
.78404 .34805 .78927 .35699 .80101 .35341 .79586 .34515 Mtetra
.625 .699 .898 r
.79586 .34515 .80101 .35341 .81282 .35004 .80775 .34224 Mtetra
.624 .713 .91 r
.80775 .34224 .81282 .35004 .82469 .3468 .81968 .33932 Mtetra
.625 .725 .918 r
.81968 .33932 .82469 .3468 .83663 .34359 .83167 .33632 Mtetra
.628 .734 .923 r
.83167 .33632 .83663 .34359 .84861 .34035 .8437 .33321 Mtetra
.679 .757 .91 r
.20671 .53168 .21326 .53739 .22287 .53358 .21633 .52797 Mtetra
.685 .762 .91 r
.21633 .52797 .22287 .53358 .23252 .52965 .226 .5241 Mtetra
.692 .766 .909 r
.226 .5241 .23252 .52965 .24221 .52566 .23571 .52004 Mtetra
.699 .766 .904 r
.23571 .52004 .24221 .52566 .25192 .52165 .24547 .51576 Mtetra
.707 .759 .893 r
.24547 .51576 .25192 .52165 .26167 .51764 .25528 .5112 Mtetra
.707 .743 .879 r
.25528 .5112 .26167 .51764 .27143 .51382 .26513 .50651 Mtetra
.703 .718 .861 r
.26513 .50651 .27143 .51382 .2812 .51031 .27501 .50177 Mtetra
.687 .683 .841 r
.27501 .50177 .2812 .51031 .29097 .50729 .2849 .49732 Mtetra
.664 .644 .82 r
.2849 .49732 .29097 .50729 .30073 .50495 .29477 .4934 Mtetra
.637 .605 .801 r
.29477 .4934 .30073 .50495 .31049 .50324 .30463 .49028 Mtetra
.605 .568 .786 r
.30463 .49028 .31049 .50324 .32026 .50217 .31446 .48822 Mtetra
.58 .541 .776 r
.31446 .48822 .32026 .50217 .33006 .50146 .32427 .48707 Mtetra
.555 .523 .774 r
.32427 .48707 .33006 .50146 .33989 .50088 .33408 .48682 Mtetra
.542 .52 .781 r
.33408 .48682 .33989 .50088 .34979 .50013 .34392 .487 Mtetra
.536 .531 .796 r
.34392 .487 .34979 .50013 .35977 .49895 .35382 .48729 Mtetra
.539 .558 .822 r
.35382 .48729 .35977 .49895 .36982 .49726 .36379 .48733 Mtetra
.553 .601 .856 r
.36379 .48733 .36982 .49726 .37994 .49494 .37384 .4868 Mtetra
.569 .656 .895 r
.37384 .4868 .37994 .49494 .39013 .49211 .38397 .48566 Mtetra
.591 .719 .933 r
.38397 .48566 .39013 .49211 .40037 .48882 .39418 .48381 Mtetra
.605 .778 .963 r
.39418 .48381 .40037 .48882 .41067 .48521 .40446 .48137 Mtetra
.614 .829 .983 r
.40446 .48137 .41067 .48521 .42101 .4814 .4148 .47843 Mtetra
.614 .864 .99 r
.4148 .47843 .42101 .4814 .43139 .47747 .4252 .47514 Mtetra
.608 .887 .99 r
.4252 .47514 .43139 .47747 .4418 .47351 .43564 .4716 Mtetra
.599 .9 .986 r
.43564 .4716 .4418 .47351 .45225 .46957 .44613 .46792 Mtetra
.589 .905 .982 r
.44613 .46792 .45225 .46957 .46274 .46568 .45665 .46418 Mtetra
.58 .907 .979 r
.45665 .46418 .46274 .46568 .47326 .46186 .46721 .46044 Mtetra
.57 .906 .976 r
.46721 .46044 .47326 .46186 .48382 .45813 .47781 .45674 Mtetra
.56 .904 .975 r
.47781 .45674 .48382 .45813 .49442 .4545 .48845 .45311 Mtetra
.55 .901 .974 r
.48845 .45311 .49442 .4545 .50506 .45096 .49913 .44955 Mtetra
.541 .898 .974 r
.49913 .44955 .50506 .45096 .51573 .44752 .50985 .44609 Mtetra
.532 .894 .973 r
.50985 .44609 .51573 .44752 .52645 .44417 .52062 .44272 Mtetra
.524 .89 .973 r
.52062 .44272 .52645 .44417 .53721 .44092 .53142 .43943 Mtetra
.518 .887 .974 r
.53142 .43943 .53721 .44092 .54802 .43777 .54227 .4362 Mtetra
.517 .885 .975 r
.54227 .4362 .54802 .43777 .55887 .43471 .55316 .43302 Mtetra
.522 .885 .978 r
.55316 .43302 .55887 .43471 .56977 .43171 .5641 .42984 Mtetra
.537 .886 .983 r
.5641 .42984 .56977 .43171 .58072 .42878 .57509 .42659 Mtetra
.563 .887 .989 r
.57509 .42659 .58072 .42878 .59171 .42586 .58612 .42321 Mtetra
.6 .885 .991 r
.58612 .42321 .59171 .42586 .60275 .42292 .59719 .41958 Mtetra
.642 .873 .984 r
.59719 .41958 .60275 .42292 .61384 .41985 .60829 .41558 Mtetra
.682 .849 .963 r
.60829 .41558 .61384 .41985 .62497 .41658 .61942 .41107 Mtetra
.709 .809 .928 r
.61942 .41107 .62497 .41658 .63613 .41298 .63057 .40595 Mtetra
.725 .764 .884 r
.63057 .40595 .63613 .41298 .64732 .40892 .64173 .40011 Mtetra
.727 .718 .842 r
.64173 .40011 .64732 .40892 .65853 .40432 .65289 .39362 Mtetra
.722 .677 .805 r
.65289 .39362 .65853 .40432 .66975 .39908 .66405 .38654 Mtetra
.712 .643 .778 r
.66405 .38654 .66975 .39908 .68098 .3933 .67522 .3792 Mtetra
.699 .616 .76 r
.67522 .3792 .68098 .3933 .69222 .38707 .68642 .37194 Mtetra
.685 .597 .752 r
.68642 .37194 .69222 .38707 .70348 .38065 .69766 .36513 Mtetra
.668 .584 .752 r
.69766 .36513 .70348 .38065 .71477 .37436 .70897 .35922 Mtetra
.653 .581 .761 r
.70897 .35922 .71477 .37436 .72611 .36842 .72038 .35425 Mtetra
.636 .584 .779 r
.72038 .35425 .72611 .36842 .73752 .36315 .7319 .35037 Mtetra
.623 .597 .804 r
.7319 .35037 .73752 .36315 .74902 .35851 .74352 .34731 Mtetra
.611 .62 .835 r
.74352 .34731 .74902 .35851 .76061 .35458 .75523 .34481 Mtetra
.603 .648 .867 r
.75523 .34481 .76061 .35458 .77228 .35115 .76702 .34261 Mtetra
.602 .68 .896 r
.76702 .34261 .77228 .35115 .78404 .34805 .77888 .34036 Mtetra
.603 .707 .917 r
.77888 .34036 .78404 .34805 .79586 .34515 .79078 .33798 Mtetra
.611 .729 .929 r
.79078 .33798 .79586 .34515 .80775 .34224 .80272 .3353 Mtetra
.618 .741 .934 r
.80272 .3353 .80775 .34224 .81968 .33932 .81469 .3324 Mtetra
.626 .746 .933 r
.81469 .3324 .81968 .33932 .83167 .33632 .82671 .3293 Mtetra
.632 .746 .93 r
.82671 .3293 .83167 .33632 .8437 .33321 .83876 .32602 Mtetra
.659 .752 .919 r
.20012 .52592 .20671 .53168 .21633 .52797 .20971 .52271 Mtetra
.664 .771 .93 r
.20971 .52271 .21633 .52797 .226 .5241 .21935 .51937 Mtetra
.672 .793 .94 r
.21935 .51937 .226 .5241 .23571 .52004 .22904 .5158 Mtetra
.684 .815 .946 r
.22904 .5158 .23571 .52004 .24547 .51576 .2388 .5119 Mtetra
.701 .833 .946 r
.2388 .5119 .24547 .51576 .25528 .5112 .24862 .50755 Mtetra
.718 .844 .942 r
.24862 .50755 .25528 .5112 .26513 .50651 .2585 .50278 Mtetra
.735 .843 .931 r
.2585 .50278 .26513 .50651 .27501 .50177 .26845 .49753 Mtetra
.741 .825 .916 r
.26845 .49753 .27501 .50177 .2849 .49732 .27844 .49206 Mtetra
.738 .79 .895 r
.27844 .49206 .2849 .49732 .29477 .4934 .28846 .48653 Mtetra
.716 .737 .867 r
.28846 .48653 .29477 .4934 .30463 .49028 .29847 .48136 Mtetra
.684 .676 .836 r
.29847 .48136 .30463 .49028 .31446 .48822 .30847 .47689 Mtetra
.647 .615 .803 r
.30847 .47689 .31446 .48822 .32427 .48707 .31843 .47336 Mtetra
.609 .561 .775 r
.31843 .47336 .32427 .48707 .33408 .48682 .32836 .47104 Mtetra
.581 .522 .753 r
.32836 .47104 .33408 .48682 .34392 .487 .33827 .46972 Mtetra
.559 .494 .739 r
.33827 .46972 .34392 .487 .35382 .48729 .34818 .46932 Mtetra
.547 .482 .734 r
.34818 .46932 .35382 .48729 .36379 .48733 .35813 .46943 Mtetra
.543 .48 .735 r
.35813 .46943 .36379 .48733 .37384 .4868 .36812 .46971 Mtetra
.545 .489 .744 r
.36812 .46971 .37384 .4868 .38397 .48566 .37818 .46988 Mtetra
.554 .509 .759 r
.37818 .46988 .38397 .48566 .39418 .48381 .38831 .46965 Mtetra
.565 .535 .781 r
.38831 .46965 .39418 .48381 .40446 .48137 .39853 .46896 Mtetra
.581 .57 .806 r
.39853 .46896 .40446 .48137 .4148 .47843 .40881 .46771 Mtetra
.596 .609 .835 r
.40881 .46771 .4148 .47843 .4252 .47514 .41917 .46596 Mtetra
.611 .65 .864 r
.41917 .46596 .4252 .47514 .43564 .4716 .42959 .46375 Mtetra
.624 .692 .893 r
.42959 .46375 .43564 .4716 .44613 .46792 .44007 .46118 Mtetra
.633 .73 .918 r
.44007 .46118 .44613 .46792 .45665 .46418 .45059 .45832 Mtetra
.638 .763 .938 r
.45059 .45832 .45665 .46418 .46721 .46044 .46117 .45524 Mtetra
.641 .789 .953 r
.46117 .45524 .46721 .46044 .47781 .45674 .4718 .45201 Mtetra
.641 .808 .964 r
.4718 .45201 .47781 .45674 .48845 .45311 .48246 .44867 Mtetra
.64 .821 .97 r
.48246 .44867 .48845 .45311 .49913 .44955 .49318 .44525 Mtetra
.641 .827 .972 r
.49318 .44525 .49913 .44955 .50985 .44609 .50393 .44176 Mtetra
.644 .828 .971 r
.50393 .44176 .50985 .44609 .52062 .44272 .51473 .43821 Mtetra
.649 .823 .967 r
.51473 .43821 .52062 .44272 .53142 .43943 .52557 .43458 Mtetra
.657 .813 .958 r
.52557 .43458 .53142 .43943 .54227 .4362 .53645 .43084 Mtetra
.666 .797 .945 r
.53645 .43084 .54227 .4362 .55316 .43302 .54737 .42694 Mtetra
.676 .775 .925 r
.54737 .42694 .55316 .43302 .5641 .42984 .55833 .42282 Mtetra
.684 .747 .899 r
.55833 .42282 .5641 .42984 .57509 .42659 .56932 .4184 Mtetra
.69 .716 .869 r
.56932 .4184 .57509 .42659 .58612 .42321 .58035 .41361 Mtetra
.693 .684 .837 r
.58035 .41361 .58612 .42321 .59719 .41958 .59141 .40835 Mtetra
.693 .653 .806 r
.59141 .40835 .59719 .41958 .60829 .41558 .60248 .40258 Mtetra
.691 .625 .777 r
.60248 .40258 .60829 .41558 .61942 .41107 .61357 .39623 Mtetra
.687 .6 .753 r
.61357 .39623 .61942 .41107 .63057 .40595 .62467 .3894 Mtetra
.683 .581 .735 r
.62467 .3894 .63057 .40595 .64173 .40011 .63578 .38215 Mtetra
.677 .566 .722 r
.63578 .38215 .64173 .40011 .65289 .39362 .64691 .37476 Mtetra
.67 .555 .716 r
.64691 .37476 .65289 .39362 .66405 .38654 .65806 .36754 Mtetra
.662 .55 .717 r
.65806 .36754 .66405 .38654 .67522 .3792 .66925 .36083 Mtetra
.652 .549 .725 r
.66925 .36083 .67522 .3792 .68642 .37194 .68052 .35505 Mtetra
.641 .556 .743 r
.68052 .35505 .68642 .37194 .69766 .36513 .69187 .3503 Mtetra
.626 .57 .772 r
.69187 .3503 .69766 .36513 .70897 .35922 .70333 .34679 Mtetra
.611 .597 .812 r
.70333 .34679 .70897 .35922 .72038 .35425 .71489 .34424 Mtetra
.59 .635 .864 r
.71489 .34424 .72038 .35425 .7319 .35037 .72656 .34243 Mtetra
.567 .681 .916 r
.72656 .34243 .7319 .35037 .74352 .34731 .73832 .341 Mtetra
.549 .729 .958 r
.73832 .341 .74352 .34731 .75523 .34481 .75014 .3395 Mtetra
.54 .765 .981 r
.75014 .3395 .75523 .34481 .76702 .34261 .76201 .33779 Mtetra
.555 .794 .988 r
.76201 .33779 .76702 .34261 .77888 .34036 .77391 .33558 Mtetra
.578 .806 .986 r
.77391 .33558 .77888 .34036 .79078 .33798 .78584 .33292 Mtetra
.608 .809 .977 r
.78584 .33292 .79078 .33798 .80272 .3353 .79778 .3298 Mtetra
.629 .801 .965 r
.79778 .3298 .80272 .3353 .81469 .3324 .80974 .32633 Mtetra
.644 .786 .95 r
.80974 .32633 .81469 .3324 .82671 .3293 .82174 .32262 Mtetra
.652 .768 .934 r
.82174 .32262 .82671 .3293 .83876 .32602 .83378 .31877 Mtetra
.626 .744 .932 r
.19348 .52013 .20012 .52592 .20971 .52271 .20302 .51762 Mtetra
.622 .769 .95 r
.20302 .51762 .20971 .52271 .21935 .51937 .2126 .51509 Mtetra
.622 .801 .968 r
.2126 .51509 .21935 .51937 .22904 .5158 .22224 .5124 Mtetra
.625 .838 .982 r
.22224 .5124 .22904 .5158 .2388 .5119 .23195 .5094 Mtetra
.632 .875 .987 r
.23195 .5094 .2388 .5119 .24862 .50755 .24172 .50597 Mtetra
.644 .911 .981 r
.24172 .50597 .24862 .50755 .2585 .50278 .25158 .50194 Mtetra
.672 .939 .965 r
.25158 .50194 .2585 .50278 .26845 .49753 .26154 .49711 Mtetra
.706 .956 .95 r
.26154 .49711 .26845 .49753 .27844 .49206 .27158 .49149 Mtetra
.756 .956 .938 r
.27158 .49149 .27844 .49206 .28846 .48653 .28171 .48499 Mtetra
.788 .927 .927 r
.28171 .48499 .28846 .48653 .29847 .48136 .29189 .47802 Mtetra
.793 .862 .9 r
.29189 .47802 .29847 .48136 .30847 .47689 .3021 .4708 Mtetra
.762 .77 .86 r
.3021 .4708 .30847 .47689 .31843 .47336 .31229 .46399 Mtetra
.713 .678 .815 r
.31229 .46399 .31843 .47336 .32836 .47104 .32245 .4581 Mtetra
.663 .599 .774 r
.32245 .4581 .32836 .47104 .33827 .46972 .33256 .45344 Mtetra
.617 .538 .742 r
.33256 .45344 .33827 .46972 .34818 .46932 .34261 .45038 Mtetra
.585 .496 .721 r
.34261 .45038 .34818 .46932 .35813 .46943 .35262 .44866 Mtetra
.559 .468 .708 r
.35262 .44866 .35813 .46943 .36812 .46971 .36262 .44816 Mtetra
.545 .454 .703 r
.36262 .44816 .36812 .46971 .37818 .46988 .37265 .44839 Mtetra
.538 .45 .704 r
.37265 .44839 .37818 .46988 .38831 .46965 .38272 .44898 Mtetra
.537 .456 .711 r
.38272 .44898 .38831 .46965 .39853 .46896 .39285 .44957 Mtetra
.543 .469 .723 r
.39285 .44957 .39853 .46896 .40881 .46771 .40306 .44986 Mtetra
.551 .488 .738 r
.40306 .44986 .40881 .46771 .41917 .46596 .41335 .44973 Mtetra
.564 .511 .755 r
.41335 .44973 .41917 .46596 .42959 .46375 .42371 .44907 Mtetra
.577 .537 .774 r
.42371 .44907 .42959 .46375 .44007 .46118 .43414 .44788 Mtetra
.591 .564 .793 r
.43414 .44788 .44007 .46118 .45059 .45832 .44465 .44619 Mtetra
.604 .59 .81 r
.44465 .44619 .45059 .45832 .46117 .45524 .45521 .44405 Mtetra
.617 .613 .824 r
.45521 .44405 .46117 .45524 .4718 .45201 .46583 .44151 Mtetra
.629 .633 .835 r
.46583 .44151 .4718 .45201 .48246 .44867 .47651 .43862 Mtetra
.639 .647 .842 r
.47651 .43862 .48246 .44867 .49318 .44525 .48723 .4354 Mtetra
.648 .656 .844 r
.48723 .4354 .49318 .44525 .50393 .44176 .498 .43189 Mtetra
.656 .66 .842 r
.498 .43189 .50393 .44176 .51473 .43821 .50882 .42807 Mtetra
.663 .658 .834 r
.50882 .42807 .51473 .43821 .52557 .43458 .51967 .42393 Mtetra
.669 .65 .823 r
.51967 .42393 .52557 .43458 .53645 .43084 .53057 .41944 Mtetra
.674 .639 .808 r
.53057 .41944 .53645 .43084 .54737 .42694 .54149 .41453 Mtetra
.677 .625 .79 r
.54149 .41453 .54737 .42694 .55833 .42282 .55245 .40917 Mtetra
.679 .609 .771 r
.55245 .40917 .55833 .42282 .56932 .4184 .56344 .40329 Mtetra
.679 .592 .751 r
.56344 .40329 .56932 .4184 .58035 .41361 .57445 .39687 Mtetra
.678 .576 .733 r
.57445 .39687 .58035 .41361 .59141 .40835 .58547 .3899 Mtetra
.675 .56 .717 r
.58547 .3899 .59141 .40835 .60248 .40258 .5965 .38249 Mtetra
.671 .546 .705 r
.5965 .38249 .60248 .40258 .61357 .39623 .60754 .37476 Mtetra
.664 .534 .696 r
.60754 .37476 .61357 .39623 .62467 .3894 .6186 .36702 Mtetra
.656 .524 .691 r
.6186 .36702 .62467 .3894 .63578 .38215 .62968 .35962 Mtetra
.647 .518 .692 r
.62968 .35962 .63578 .38215 .64691 .37476 .64082 .35296 Mtetra
.633 .514 .7 r
.64082 .35296 .64691 .37476 .65806 .36754 .65202 .34754 Mtetra
.619 .517 .716 r
.65202 .34754 .65806 .36754 .66925 .36083 .66332 .34349 Mtetra
.597 .526 .746 r
.66332 .34349 .66925 .36083 .68052 .35505 .67475 .34108 Mtetra
.573 .552 .793 r
.67475 .34108 .68052 .35505 .69187 .3503 .68629 .33994 Mtetra
.534 .598 .864 r
.68629 .33994 .69187 .3503 .70333 .34679 .69795 .33976 Mtetra
.47 .663 .946 r
.69795 .33976 .70333 .34679 .71489 .34424 .70971 .34 Mtetra
.379 .727 .99 r
.70971 .34 .71489 .34424 .72656 .34243 .72154 .34001 Mtetra
.292 .747 .955 r
.72154 .34001 .72656 .34243 .73832 .341 .73341 .33953 Mtetra
.292 .774 .919 r
.73341 .33953 .73832 .341 .75014 .3395 .74529 .33815 Mtetra
.358 .817 .929 r
.74529 .33815 .75014 .3395 .76201 .33779 .75718 .33596 Mtetra
.469 .867 .966 r
.75718 .33596 .76201 .33779 .77391 .33558 .76907 .33293 Mtetra
.563 .887 .989 r
.76907 .33293 .77391 .33558 .78584 .33292 .78097 .32927 Mtetra
.627 .875 .988 r
.78097 .32927 .78584 .33292 .79778 .3298 .79287 .32516 Mtetra
.661 .85 .972 r
.79287 .32516 .79778 .3298 .80974 .32633 .8048 .32072 Mtetra
.676 .818 .951 r
.8048 .32072 .80974 .32633 .82174 .32262 .81676 .31611 Mtetra
.68 .787 .931 r
.81676 .31611 .82174 .32262 .83378 .31877 .82876 .31146 Mtetra
.601 .737 .94 r
.18679 .51429 .19348 .52013 .20302 .51762 .19631 .51226 Mtetra
.592 .752 .954 r
.19631 .51226 .20302 .51762 .2126 .51509 .20585 .5103 Mtetra
.584 .772 .969 r
.20585 .5103 .2126 .51509 .22224 .5124 .21545 .50833 Mtetra
.576 .799 .984 r
.21545 .50833 .22224 .5124 .23195 .5094 .22509 .50624 Mtetra
.561 .832 .996 r
.22509 .50624 .23195 .5094 .24172 .50597 .23479 .50399 Mtetra
.546 .87 .994 r
.23479 .50399 .24172 .50597 .25158 .50194 .24457 .50133 Mtetra
.521 .898 .959 r
.24457 .50133 .25158 .50194 .26154 .49711 .25443 .49807 Mtetra
.481 .898 .876 r
.25443 .49807 .26154 .49711 .27158 .49149 .2644 .49399 Mtetra
.451 .876 .769 r
.2644 .49399 .27158 .49149 .28171 .48499 .27448 .48885 Mtetra
.422 .839 .666 r
.27448 .48885 .28171 .48499 .29189 .47802 .28466 .4827 Mtetra
.447 .837 .622 r
.28466 .4827 .29189 .47802 .3021 .4708 .29493 .47551 Mtetra
.499 .867 .641 r
.29493 .47551 .3021 .4708 .31229 .46399 .30525 .46774 Mtetra
.606 .936 .734 r
.30525 .46774 .31229 .46399 .32245 .4581 .3156 .45973 Mtetra
.727 .989 .867 r
.3156 .45973 .32245 .4581 .33256 .45344 .32594 .45205 Mtetra
.777 .939 .933 r
.32594 .45205 .33256 .45344 .34261 .45038 .33624 .4452 Mtetra
.743 .802 .9 r
.33624 .4452 .34261 .45038 .35262 .44866 .3465 .43941 Mtetra
.68 .673 .836 r
.3465 .43941 .35262 .44866 .36262 .44816 .35671 .43492 Mtetra
.633 .583 .78 r
.35671 .43492 .36262 .44816 .37265 .44839 .36691 .43157 Mtetra
.599 .524 .741 r
.36691 .43157 .37265 .44839 .38272 .44898 .37709 .42924 Mtetra
.58 .489 .716 r
.37709 .42924 .38272 .44898 .39285 .44957 .38729 .42761 Mtetra
.57 .468 .7 r
.38729 .42761 .39285 .44957 .40306 .44986 .39753 .42641 Mtetra
.566 .458 .69 r
.39753 .42641 .40306 .44986 .41335 .44973 .40781 .42538 Mtetra
.566 .454 .685 r
.40781 .42538 .41335 .44973 .42371 .44907 .41815 .4243 Mtetra
.568 .454 .683 r
.41815 .4243 .42371 .44907 .43414 .44788 .42855 .42305 Mtetra
.573 .456 .682 r
.42855 .42305 .43414 .44788 .44465 .44619 .43901 .42149 Mtetra
.578 .461 .683 r
.43901 .42149 .44465 .44619 .45521 .44405 .44953 .41958 Mtetra
.584 .466 .684 r
.44953 .41958 .45521 .44405 .46583 .44151 .46011 .41727 Mtetra
.59 .471 .686 r
.46011 .41727 .46583 .44151 .47651 .43862 .47075 .41455 Mtetra
.597 .477 .686 r
.47075 .41455 .47651 .43862 .48723 .4354 .48144 .41142 Mtetra
.603 .481 .687 r
.48144 .41142 .48723 .4354 .498 .43189 .49218 .40786 Mtetra
.608 .485 .686 r
.49218 .40786 .498 .43189 .50882 .42807 .50297 .40388 Mtetra
.613 .487 .685 r
.50297 .40388 .50882 .42807 .51967 .42393 .5138 .39948 Mtetra
.618 .489 .683 r
.5138 .39948 .51967 .42393 .53057 .41944 .52466 .39467 Mtetra
.622 .49 .681 r
.52466 .39467 .53057 .41944 .54149 .41453 .53556 .38945 Mtetra
.626 .491 .679 r
.53556 .38945 .54149 .41453 .55245 .40917 .54649 .38388 Mtetra
.629 .492 .677 r
.54649 .38388 .55245 .40917 .56344 .40329 .55744 .37798 Mtetra
.631 .494 .677 r
.55744 .37798 .56344 .40329 .57445 .39687 .56842 .3719 Mtetra
.632 .496 .679 r
.56842 .3719 .57445 .39687 .58547 .3899 .57943 .36576 Mtetra
.633 .5 .683 r
.57943 .36576 .58547 .3899 .5965 .38249 .59046 .35978 Mtetra
.632 .507 .693 r
.59046 .35978 .5965 .38249 .60754 .37476 .60154 .35424 Mtetra
.629 .519 .709 r
.60154 .35424 .60754 .37476 .6186 .36702 .61267 .34939 Mtetra
.622 .537 .738 r
.61267 .34939 .6186 .36702 .62968 .35962 .62387 .34559 Mtetra
.609 .57 .785 r
.62387 .34559 .62968 .35962 .64082 .35296 .63515 .34294 Mtetra
.572 .625 .866 r
.63515 .34294 .64082 .35296 .65202 .34754 .64654 .34164 Mtetra
.466 .703 .971 r
.64654 .34164 .65202 .34754 .66332 .34349 .65804 .34143 Mtetra
.142 .657 .893 r
.65804 .34143 .66332 .34349 .67475 .34108 .66965 .34208 Mtetra
.191 0 0 r
.66965 .34208 .67475 .34108 .68629 .33994 .68135 .34309 Mtetra
.305 0 0 r
.68135 .34309 .68629 .33994 .69795 .33976 .69313 .34386 Mtetra
.31 0 0 r
.69313 .34386 .69795 .33976 .70971 .34 .70496 .34405 Mtetra
.238 0 0 r
.70496 .34405 .70971 .34 .72154 .34001 .7168 .34317 Mtetra
.105 0 0 r
.7168 .34317 .72154 .34001 .73341 .33953 .72865 .34125 Mtetra
0 0 0 r
.72865 .34125 .73341 .33953 .74529 .33815 .74049 .33824 Mtetra
.375 .841 .841 r
.74049 .33824 .74529 .33815 .75718 .33596 .75232 .33436 Mtetra
.563 .917 .959 r
.75232 .33436 .75718 .33596 .76907 .33293 .76415 .32986 Mtetra
.654 .908 .98 r
.76415 .32986 .76907 .33293 .78097 .32927 .77599 .32493 Mtetra
.687 .871 .968 r
.77599 .32493 .78097 .32927 .79287 .32516 .78787 .31981 Mtetra
.699 .836 .949 r
.78787 .31981 .79287 .32516 .8048 .32072 .79977 .31456 Mtetra
.701 .808 .932 r
.79977 .31456 .8048 .32072 .81676 .31611 .81171 .3093 Mtetra
.697 .785 .919 r
.81171 .3093 .81676 .31611 .82876 .31146 .82371 .3041 Mtetra
.596 .735 .941 r
.18006 .50842 .18679 .51429 .19631 .51226 .18958 .50645 Mtetra
.587 .735 .946 r
.18958 .50645 .19631 .51226 .20585 .5103 .19913 .50464 Mtetra
.575 .738 .953 r
.19913 .50464 .20585 .5103 .21545 .50833 .20871 .50298 Mtetra
.559 .745 .964 r
.20871 .50298 .21545 .50833 .22509 .50624 .21832 .50149 Mtetra
.53 .759 .98 r
.21832 .50149 .22509 .50624 .23479 .50399 .22796 .50021 Mtetra
.493 .785 .997 r
.22796 .50021 .23479 .50399 .24457 .50133 .23763 .49898 Mtetra
.415 .806 .988 r
.23763 .49898 .24457 .50133 .25443 .49807 .24736 .49773 Mtetra
.283 .78 .88 r
.24736 .49773 .25443 .49807 .2644 .49399 .25717 .49611 Mtetra
0 0 0 r
.25717 .49611 .2644 .49399 .27448 .48885 .26707 .49387 Mtetra
.038 0 0 r
.26707 .49387 .27448 .48885 .28466 .4827 .27709 .4906 Mtetra
.092 0 0 r
.27709 .4906 .28466 .4827 .29493 .47551 .28725 .48593 Mtetra
.105 0 0 r
.28725 .48593 .29493 .47551 .30525 .46774 .29755 .47974 Mtetra
.064 0 0 r
.29755 .47974 .30525 .46774 .3156 .45973 .30797 .47187 Mtetra
0 0 0 r
.30797 .47187 .3156 .45973 .32594 .45205 .31848 .46282 Mtetra
.31848 .46282 .32594 .45205 .33624 .4452 .32905 .45291 Mtetra
.32905 .45291 .33624 .4452 .3465 .43941 .33962 .44291 Mtetra
.714 .977 .763 r
.33962 .44291 .3465 .43941 .35671 .43492 .35015 .43343 Mtetra
.827 .933 .9 r
.35015 .43343 .35671 .43492 .36691 .43157 .36065 .4249 Mtetra
.764 .763 .851 r
.36065 .4249 .36691 .43157 .37709 .42924 .37108 .41767 Mtetra
.697 .639 .788 r
.37108 .41767 .37709 .42924 .38729 .42761 .38148 .41168 Mtetra
.648 .561 .743 r
.38148 .41168 .38729 .42761 .39753 .42641 .39185 .40692 Mtetra
.619 .515 .714 r
.39185 .40692 .39753 .42641 .40781 .42538 .40222 .40307 Mtetra
.6 .486 .695 r
.40222 .40307 .40781 .42538 .41815 .4243 .4126 .39991 Mtetra
.59 .469 .683 r
.4126 .39991 .41815 .4243 .42855 .42305 .42301 .39718 Mtetra
.585 .459 .675 r
.42301 .39718 .42855 .42305 .43901 .42149 .43346 .39462 Mtetra
.583 .454 .67 r
.43346 .39462 .43901 .42149 .44953 .41958 .44395 .39208 Mtetra
.584 .453 .667 r
.44395 .39208 .44953 .41958 .46011 .41727 .4545 .38938 Mtetra
.587 .453 .666 r
.4545 .38938 .46011 .41727 .47075 .41455 .4651 .38644 Mtetra
.59 .455 .665 r
.4651 .38644 .47075 .41455 .48144 .41142 .47574 .38318 Mtetra
.594 .457 .664 r
.47574 .38318 .48144 .41142 .49218 .40786 .48644 .37958 Mtetra
.598 .46 .664 r
.48644 .37958 .49218 .40786 .50297 .40388 .49718 .37564 Mtetra
.602 .462 .664 r
.49718 .37564 .50297 .40388 .5138 .39948 .50796 .37137 Mtetra
.605 .465 .664 r
.50796 .37137 .5138 .39948 .52466 .39467 .51878 .36687 Mtetra
.607 .468 .666 r
.51878 .36687 .52466 .39467 .53556 .38945 .52964 .3622 Mtetra
.609 .471 .668 r
.52964 .3622 .53556 .38945 .54649 .38388 .54054 .35754 Mtetra
.608 .474 .673 r
.54054 .35754 .54649 .38388 .55744 .37798 .55147 .35306 Mtetra
.606 .479 .681 r
.55147 .35306 .55744 .37798 .56842 .3719 .56244 .349 Mtetra
.601 .486 .695 r
.56244 .349 .56842 .3719 .57943 .36576 .57347 .34564 Mtetra
.591 .498 .718 r
.57347 .34564 .57943 .36576 .59046 .35978 .58456 .34321 Mtetra
.572 .518 .756 r
.58456 .34321 .59046 .35978 .60154 .35424 .59573 .34203 Mtetra
.532 .557 .827 r
.59573 .34203 .60154 .35424 .61267 .34939 .607 .34212 Mtetra
.399 .616 .939 r
.607 .34212 .61267 .34939 .62387 .34559 .61839 .34356 Mtetra
0 .505 .789 r
.61839 .34356 .62387 .34559 .63515 .34294 .62988 .34598 Mtetra
.438 0 0 r
.62988 .34598 .63515 .34294 .64654 .34164 .64149 .34895 Mtetra
.505 .032 .065 r
.64149 .34895 .64654 .34164 .65804 .34143 .6532 .35185 Mtetra
.5 .072 .158 r
.6532 .35185 .65804 .34143 .66965 .34208 .66496 .3539 Mtetra
.475 .064 .18 r
.66496 .3539 .66965 .34208 .68135 .34309 .67675 .35474 Mtetra
.423 .014 .155 r
.67675 .35474 .68135 .34309 .69313 .34386 .68854 .35386 Mtetra
.346 0 .078 r
.68854 .35386 .69313 .34386 .70496 .34405 .70032 .35143 Mtetra
.202 0 0 r
.70032 .35143 .70496 .34405 .7168 .34317 .71207 .34753 Mtetra
0 0 0 r
.71207 .34753 .7168 .34317 .72865 .34125 .7238 .34257 Mtetra
.409 .851 .751 r
.7238 .34257 .72865 .34125 .74049 .33824 .73553 .33695 Mtetra
.646 .955 .94 r
.73553 .33695 .74049 .33824 .75232 .33436 .74727 .33094 Mtetra
.715 .913 .963 r
.74727 .33094 .75232 .33436 .76415 .32986 .75904 .3249 Mtetra
.726 .859 .944 r
.75904 .3249 .76415 .32986 .77599 .32493 .77085 .3189 Mtetra
.719 .818 .927 r
.77085 .3189 .77599 .32493 .78787 .31981 .78271 .31311 Mtetra
.711 .794 .916 r
.78271 .31311 .78787 .31981 .79977 .31456 .79462 .30748 Mtetra
.705 .78 .91 r
.79462 .30748 .79977 .31456 .81171 .3093 .80659 .30201 Mtetra
.699 .772 .908 r
.80659 .30201 .81171 .3093 .82371 .3041 .81861 .29669 Mtetra
.622 .743 .933 r
.17328 .5025 .18006 .50842 .18958 .50645 .18287 .50002 Mtetra
.617 .724 .922 r
.18287 .50002 .18958 .50645 .19913 .50464 .19249 .49768 Mtetra
.608 .705 .913 r
.19249 .49768 .19913 .50464 .20871 .50298 .20213 .49557 Mtetra
.595 .687 .906 r
.20213 .49557 .20871 .50298 .21832 .50149 .21178 .49376 Mtetra
.577 .671 .903 r
.21178 .49376 .21832 .50149 .22796 .50021 .22143 .49236 Mtetra
.559 .661 .905 r
.22143 .49236 .22796 .50021 .23763 .49898 .2311 .49133 Mtetra
.535 .658 .915 r
.2311 .49133 .23763 .49898 .24736 .49773 .24079 .49071 Mtetra
.515 .671 .934 r
.24079 .49071 .24736 .49773 .25717 .49611 .25051 .49028 Mtetra
.486 .703 .965 r
.25051 .49028 .25717 .49611 .26707 .49387 .26028 .48989 Mtetra
.45 .762 .996 r
.26028 .48989 .26707 .49387 .27709 .4906 .27014 .48914 Mtetra
.362 .806 .954 r
.27014 .48914 .27709 .4906 .28725 .48593 .2801 .48768 Mtetra
.181 .708 .694 r
.2801 .48768 .28725 .48593 .29755 .47974 .29019 .48512 Mtetra
0 0 0 r
.29019 .48512 .29755 .47974 .30797 .47187 .30042 .48108 Mtetra
.099 0 0 r
.30042 .48108 .30797 .47187 .31848 .46282 .31078 .47559 Mtetra
.149 0 .033 r
.31078 .47559 .31848 .46282 .32905 .45291 .32126 .46857 Mtetra
.184 0 .111 r
.32126 .46857 .32905 .45291 .33962 .44291 .33182 .46049 Mtetra
.202 0 .15 r
.33182 .46049 .33962 .44291 .35015 .43343 .34243 .45167 Mtetra
.211 0 .164 r
.34243 .45167 .35015 .43343 .36065 .4249 .35306 .44265 Mtetra
.211 0 .16 r
.35306 .44265 .36065 .4249 .37108 .41767 .36368 .43386 Mtetra
.197 0 .131 r
.36368 .43386 .37108 .41767 .38148 .41168 .37428 .42556 Mtetra
.17 0 .077 r
.37428 .42556 .38148 .41168 .39185 .40692 .38487 .41798 Mtetra
.113 0 0 r
.38487 .41798 .39185 .40692 .40222 .40307 .39543 .41113 Mtetra
.014 0 0 r
.39543 .41113 .40222 .40307 .4126 .39991 .40599 .40502 Mtetra
0 0 0 r
.40599 .40502 .4126 .39991 .42301 .39718 .41655 .39954 Mtetra
.371 .825 .72 r
.41655 .39954 .42301 .39718 .43346 .39462 .42713 .3946 Mtetra
.549 .925 .921 r
.42713 .3946 .43346 .39462 .44395 .39208 .43772 .39007 Mtetra
.63 .91 .982 r
.43772 .39007 .44395 .39208 .4545 .38938 .44834 .38586 Mtetra
.654 .863 .979 r
.44834 .38586 .4545 .38938 .4651 .38644 .45899 .38189 Mtetra
.657 .824 .964 r
.45899 .38189 .4651 .38644 .47574 .38318 .46968 .37811 Mtetra
.653 .804 .956 r
.46968 .37811 .47574 .38318 .48644 .37958 .48041 .37448 Mtetra
.645 .801 .958 r
.48041 .37448 .48644 .37958 .49718 .37564 .49118 .37102 Mtetra
.629 .816 .972 r
.49118 .37102 .49718 .37564 .50796 .37137 .50199 .36774 Mtetra
.594 .844 .992 r
.50199 .36774 .50796 .37137 .51878 .36687 .51285 .3647 Mtetra
.506 .864 .988 r
.51285 .3647 .51878 .36687 .52964 .3622 .52375 .36199 Mtetra
.299 .793 .862 r
.52375 .36199 .52964 .3622 .54054 .35754 .5347 .3597 Mtetra
.012 0 0 r
.5347 .3597 .54054 .35754 .55147 .35306 .54571 .35795 Mtetra
.255 0 0 r
.54571 .35795 .55147 .35306 .56244 .349 .55679 .35685 Mtetra
.388 0 .027 r
.55679 .35685 .56244 .349 .57347 .34564 .56794 .35651 Mtetra
.456 .036 .153 r
.56794 .35651 .57347 .34564 .58456 .34321 .57917 .35691 Mtetra
.493 .102 .227 r
.57917 .35691 .58456 .34321 .59573 .34203 .59049 .35807 Mtetra
.511 .138 .269 r
.59049 .35807 .59573 .34203 .607 .34212 .6019 .35975 Mtetra
.519 .155 .29 r
.6019 .35975 .607 .34212 .61839 .34356 .61341 .36167 Mtetra
.516 .155 .293 r
.61341 .36167 .61839 .34356 .62988 .34598 .625 .36341 Mtetra
.5 .136 .279 r
.625 .36341 .62988 .34598 .64149 .34895 .63665 .36441 Mtetra
.47 .093 .242 r
.63665 .36441 .64149 .34895 .6532 .35185 .64834 .36433 Mtetra
.406 .006 .163 r
.64834 .36433 .6532 .35185 .66496 .3539 .66004 .3627 Mtetra
.282 0 .005 r
.66004 .3627 .66496 .3539 .67675 .35474 .67174 .35956 Mtetra
0 0 0 r
.67174 .35956 .67675 .35474 .68854 .35386 .68341 .3549 Mtetra
.467 .887 .795 r
.68341 .3549 .68854 .35386 .70032 .35143 .69507 .3491 Mtetra
.72 .947 .954 r
.69507 .3491 .70032 .35143 .71207 .34753 .70672 .34255 Mtetra
.759 .862 .925 r
.70672 .34255 .71207 .34753 .7238 .34257 .71838 .33561 Mtetra
.748 .793 .889 r
.71838 .33561 .7238 .34257 .73553 .33695 .73006 .32871 Mtetra
.733 .752 .867 r
.73006 .32871 .73553 .33695 .74727 .33094 .74179 .32198 Mtetra
.718 .728 .859 r
.74179 .32198 .74727 .33094 .75904 .3249 .75357 .31567 Mtetra
.706 .718 .858 r
.75357 .31567 .75904 .3249 .77085 .3189 .76542 .30974 Mtetra
.696 .716 .865 r
.76542 .30974 .77085 .3189 .78271 .31311 .77734 .30422 Mtetra
.689 .721 .874 r
.77734 .30422 .78271 .31311 .79462 .30748 .78932 .29902 Mtetra
.684 .731 .886 r
.78932 .29902 .79462 .30748 .80659 .30201 .80137 .29404 Mtetra
.681 .745 .9 r
.80137 .29404 .80659 .30201 .81861 .29669 .81347 .28921 Mtetra
.663 .753 .917 r
.16646 .49655 .17328 .5025 .18287 .50002 .17616 .49314 Mtetra
.658 .723 .897 r
.17616 .49314 .18287 .50002 .19249 .49768 .1859 .48981 Mtetra
.648 .692 .877 r
.1859 .48981 .19249 .49768 .20213 .49557 .19565 .48667 Mtetra
.635 .662 .859 r
.19565 .48667 .20213 .49557 .21178 .49376 .2054 .48384 Mtetra
.619 .632 .842 r
.2054 .48384 .21178 .49376 .22143 .49236 .21516 .48141 Mtetra
.601 .604 .827 r
.21516 .48141 .22143 .49236 .2311 .49133 .22491 .47947 Mtetra
.581 .578 .815 r
.22491 .47947 .2311 .49133 .24079 .49071 .23466 .47813 Mtetra
.56 .556 .806 r
.23466 .47813 .24079 .49071 .25051 .49028 .2444 .4774 Mtetra
.538 .54 .805 r
.2444 .4774 .25051 .49028 .26028 .48989 .25414 .47736 Mtetra
.515 .534 .814 r
.25414 .47736 .26028 .48989 .27014 .48914 .26389 .47789 Mtetra
.483 .543 .842 r
.26389 .47789 .27014 .48914 .2801 .48768 .27366 .47895 Mtetra
.436 .584 .902 r
.27366 .47895 .2801 .48768 .29019 .48512 .28348 .48021 Mtetra
.294 .651 .969 r
.28348 .48021 .29019 .48512 .30042 .48108 .29337 .48138 Mtetra
.106 0 0 r
.29337 .48138 .30042 .48108 .31078 .47559 .30338 .48193 Mtetra
.339 0 0 r
.30338 .48193 .31078 .47559 .32126 .46857 .31351 .48139 Mtetra
.388 0 .162 r
.31351 .48139 .32126 .46857 .33182 .46049 .32379 .47938 Mtetra
.391 .045 .253 r
.32379 .47938 .33182 .46049 .34243 .45167 .33423 .47558 Mtetra
.389 .069 .297 r
.33423 .47558 .34243 .45167 .35306 .44265 .34478 .47019 Mtetra
.381 .076 .317 r
.34478 .47019 .35306 .44265 .36368 .43386 .35545 .46331 Mtetra
.375 .076 .325 r
.35545 .46331 .36368 .43386 .37428 .42556 .36618 .45546 Mtetra
.367 .071 .325 r
.36618 .45546 .37428 .42556 .38487 .41798 .37694 .44703 Mtetra
.359 .062 .318 r
.37694 .44703 .38487 .41798 .39543 .41113 .38773 .43846 Mtetra
.352 .051 .307 r
.38773 .43846 .39543 .41113 .40599 .40502 .39851 .43011 Mtetra
.344 .035 .29 r
.39851 .43011 .40599 .40502 .41655 .39954 .40929 .42219 Mtetra
.338 .019 .269 r
.40929 .42219 .41655 .39954 .42713 .3946 .42007 .41488 Mtetra
.332 .001 .245 r
.42007 .41488 .42713 .3946 .43772 .39007 .43084 .40825 Mtetra
.33 0 .221 r
.43084 .40825 .43772 .39007 .44834 .38586 .44161 .40237 Mtetra
.332 0 .2 r
.44161 .40237 .44834 .38586 .45899 .38189 .45239 .39722 Mtetra
.342 0 .187 r
.45239 .39722 .45899 .38189 .46968 .37811 .46319 .39284 Mtetra
.361 0 .186 r
.46319 .39284 .46968 .37811 .48041 .37448 .47402 .38921 Mtetra
.386 .01 .197 r
.47402 .38921 .48041 .37448 .49118 .37102 .48488 .38633 Mtetra
.414 .042 .219 r
.48488 .38633 .49118 .37102 .50199 .36774 .49578 .38421 Mtetra
.443 .078 .248 r
.49578 .38421 .50199 .36774 .51285 .3647 .50673 .38285 Mtetra
.469 .113 .278 r
.50673 .38285 .51285 .3647 .52375 .36199 .51774 .38224 Mtetra
.49 .144 .307 r
.51774 .38224 .52375 .36199 .5347 .3597 .52882 .38233 Mtetra
.505 .169 .331 r
.52882 .38233 .5347 .3597 .54571 .35795 .53997 .38306 Mtetra
.515 .187 .35 r
.53997 .38306 .54571 .35795 .55679 .35685 .5512 .38423 Mtetra
.52 .199 .364 r
.5512 .38423 .55679 .35685 .56794 .35651 .56251 .38564 Mtetra
.519 .203 .372 r
.56251 .38564 .56794 .35651 .57917 .35691 .57391 .38692 Mtetra
.512 .2 .373 r
.57391 .38692 .57917 .35691 .59049 .35807 .58537 .38763 Mtetra
.5 .187 .368 r
.58537 .38763 .59049 .35807 .6019 .35975 .5969 .38737 Mtetra
.476 .16 .351 r
.5969 .38737 .6019 .35975 .61341 .36167 .60845 .3856 Mtetra
.439 .114 .317 r
.60845 .3856 .61341 .36167 .625 .36341 .62002 .3822 Mtetra
.368 .025 .246 r
.62002 .3822 .625 .36341 .63665 .36441 .63158 .37695 Mtetra
.218 0 .085 r
.63158 .37695 .63665 .36441 .64834 .36433 .64313 .37021 Mtetra
0 0 0 r
.64313 .37021 .64834 .36433 .66004 .3627 .65465 .36231 Mtetra
.751 .99 .887 r
.65465 .36231 .66004 .3627 .67174 .35956 .66617 .35376 Mtetra
.799 .838 .881 r
.66617 .35376 .67174 .35956 .68341 .3549 .67769 .34511 Mtetra
.756 .72 .819 r
.67769 .34511 .68341 .3549 .69507 .3491 .68924 .33663 Mtetra
.722 .658 .786 r
.68924 .33663 .69507 .3491 .70672 .34255 .70083 .32869 Mtetra
.701 .629 .773 r
.70083 .32869 .70672 .34255 .71838 .33561 .71248 .32133 Mtetra
.686 .616 .772 r
.71248 .32133 .71838 .33561 .73006 .32871 .72419 .31466 Mtetra
.676 .615 .779 r
.72419 .31466 .73006 .32871 .74179 .32198 .73598 .30863 Mtetra
.668 .621 .793 r
.73598 .30863 .74179 .32198 .75357 .31567 .74784 .3032 Mtetra
.662 .632 .81 r
.74784 .3032 .75357 .31567 .76542 .30974 .75979 .29828 Mtetra
.657 .649 .83 r
.75979 .29828 .76542 .30974 .77734 .30422 .77181 .29378 Mtetra
.653 .669 .853 r
.77181 .29378 .77734 .30422 .78932 .29902 .78391 .28959 Mtetra
.651 .693 .876 r
.78391 .28959 .78932 .29902 .80137 .29404 .79607 .28559 Mtetra
.65 .72 .9 r
.79607 .28559 .80137 .29404 .81347 .28921 .8083 .28168 Mtetra
.697 .76 .901 r
.15958 .49055 .16646 .49655 .17616 .49314 .16941 .48618 Mtetra
.692 .731 .88 r
.16941 .48618 .17616 .49314 .1859 .48981 .17927 .48182 Mtetra
.683 .701 .86 r
.17927 .48182 .1859 .48981 .19565 .48667 .18915 .47756 Mtetra
.671 .671 .841 r
.18915 .47756 .19565 .48667 .2054 .48384 .19904 .47349 Mtetra
.657 .64 .822 r
.19904 .47349 .2054 .48384 .21516 .48141 .20893 .4697 Mtetra
.639 .609 .803 r
.20893 .4697 .21516 .48141 .22491 .47947 .21881 .46633 Mtetra
.62 .578 .785 r
.21881 .46633 .22491 .47947 .23466 .47813 .22869 .4635 Mtetra
.599 .548 .769 r
.22869 .4635 .23466 .47813 .2444 .4774 .23855 .46133 Mtetra
.577 .519 .754 r
.23855 .46133 .2444 .4774 .25414 .47736 .24838 .45994 Mtetra
.556 .494 .741 r
.24838 .45994 .25414 .47736 .26389 .47789 .2582 .45938 Mtetra
.534 .471 .731 r
.2582 .45938 .26389 .47789 .27366 .47895 .268 .45971 Mtetra
.517 .455 .725 r
.268 .45971 .27366 .47895 .28348 .48021 .27781 .46076 Mtetra
.502 .444 .724 r
.27781 .46076 .28348 .48021 .29337 .48138 .28764 .46243 Mtetra
.496 .445 .73 r
.28764 .46243 .29337 .48138 .30338 .48193 .29753 .46429 Mtetra
.496 .458 .745 r
.29753 .46429 .30338 .48193 .31351 .48139 .3075 .46598 Mtetra
.506 .49 .774 r
.3075 .46598 .31351 .48139 .32379 .47938 .31758 .46708 Mtetra
.527 .55 .823 r
.31758 .46708 .32379 .47938 .33423 .47558 .32778 .4672 Mtetra
.552 .654 .903 r
.32778 .4672 .33423 .47558 .34478 .47019 .33811 .46623 Mtetra
.555 .813 .994 r
.33811 .46623 .34478 .47019 .35545 .46331 .34856 .46402 Mtetra
.355 .829 .838 r
.34856 .46402 .35545 .46331 .36618 .45546 .35911 .46079 Mtetra
0 0 0 r
.35911 .46079 .36618 .45546 .37694 .44703 .36975 .45665 Mtetra
.179 0 0 r
.36975 .45665 .37694 .44703 .38773 .43846 .38045 .45192 Mtetra
.271 0 .11 r
.38045 .45192 .38773 .43846 .39851 .43011 .3912 .44682 Mtetra
.323 0 .192 r
.3912 .44682 .39851 .43011 .40929 .42219 .40199 .44156 Mtetra
.357 .015 .241 r
.40199 .44156 .40929 .42219 .42007 .41488 .41281 .43635 Mtetra
.381 .049 .272 r
.41281 .43635 .42007 .41488 .43084 .40825 .42365 .43131 Mtetra
.399 .073 .293 r
.42365 .43131 .43084 .40825 .44161 .40237 .43452 .42654 Mtetra
.414 .091 .307 r
.43452 .42654 .44161 .40237 .45239 .39722 .44542 .42211 Mtetra
.425 .105 .316 r
.44542 .42211 .45239 .39722 .46319 .39284 .45635 .41807 Mtetra
.435 .115 .322 r
.45635 .41807 .46319 .39284 .47402 .38921 .46731 .41444 Mtetra
.442 .121 .325 r
.46731 .41444 .47402 .38921 .48488 .38633 .47831 .41122 Mtetra
.448 .125 .325 r
.47831 .41122 .48488 .38633 .49578 .38421 .48935 .40838 Mtetra
.452 .126 .321 r
.48935 .40838 .49578 .38421 .50673 .38285 .50044 .4059 Mtetra
.453 .122 .313 r
.50044 .4059 .50673 .38285 .51774 .38224 .51158 .40369 Mtetra
.45 .111 .299 r
.51158 .40369 .51774 .38224 .52882 .38233 .52278 .40166 Mtetra
.442 .092 .275 r
.52278 .40166 .52882 .38233 .53997 .38306 .53404 .39968 Mtetra
.422 .055 .235 r
.53404 .39968 .53997 .38306 .5512 .38423 .54535 .39755 Mtetra
.38 0 .162 r
.54535 .39755 .5512 .38423 .56251 .38564 .55672 .39505 Mtetra
.286 0 .016 r
.55672 .39505 .56251 .38564 .57391 .38692 .56813 .39194 Mtetra
.031 0 0 r
.56813 .39194 .57391 .38692 .58537 .38763 .57958 .38792 Mtetra
.505 .91 .874 r
.57958 .38792 .58537 .38763 .5969 .38737 .59106 .38284 Mtetra
.742 .866 .938 r
.59106 .38284 .5969 .38737 .60845 .3856 .60254 .3765 Mtetra
.743 .728 .838 r
.60254 .3765 .60845 .3856 .62002 .3822 .61402 .36902 Mtetra
.725 .648 .772 r
.61402 .36902 .62002 .3822 .63158 .37695 .6255 .36053 Mtetra
.709 .603 .735 r
.6255 .36053 .63158 .37695 .64313 .37021 .63696 .3514 Mtetra
.696 .575 .715 r
.63696 .3514 .64313 .37021 .65465 .36231 .64843 .34209 Mtetra
.686 .559 .706 r
.64843 .34209 .65465 .36231 .66617 .35376 .65991 .33296 Mtetra
.675 .549 .704 r
.65991 .33296 .66617 .35376 .67769 .34511 .67143 .32444 Mtetra
.667 .545 .707 r
.67143 .32444 .67769 .34511 .68924 .33663 .683 .31664 Mtetra
.657 .545 .715 r
.683 .31664 .68924 .33663 .70083 .32869 .69465 .30976 Mtetra
.65 .549 .727 r
.69465 .30976 .70083 .32869 .71248 .32133 .70637 .30372 Mtetra
.643 .556 .742 r
.70637 .30372 .71248 .32133 .72419 .31466 .71817 .29849 Mtetra
.637 .568 .761 r
.71817 .29849 .72419 .31466 .73598 .30863 .73006 .29393 Mtetra
.632 .584 .782 r
.73006 .29393 .73598 .30863 .74784 .3032 .74204 .28993 Mtetra
.627 .603 .806 r
.74204 .28993 .74784 .3032 .75979 .29828 .7541 .28637 Mtetra
.624 .625 .831 r
.7541 .28637 .75979 .29828 .77181 .29378 .76624 .28309 Mtetra
.62 .649 .857 r
.76624 .28309 .77181 .29378 .78391 .28959 .77845 .28002 Mtetra
.617 .675 .882 r
.77845 .28002 .78391 .28959 .79607 .28559 .79073 .27705 Mtetra
.616 .703 .907 r
.79073 .27705 .79607 .28559 .8083 .28168 .80308 .27409 Mtetra
.719 .764 .888 r
.15266 .48451 .15958 .49055 .16941 .48618 .16259 .47942 Mtetra
.716 .742 .873 r
.16259 .47942 .16941 .48618 .17927 .48182 .17256 .47425 Mtetra
.71 .72 .857 r
.17256 .47425 .17927 .48182 .18915 .47756 .18255 .46906 Mtetra
.702 .696 .841 r
.18255 .46906 .18915 .47756 .19904 .47349 .19256 .46391 Mtetra
.693 .67 .823 r
.19256 .46391 .19904 .47349 .20893 .4697 .20258 .45885 Mtetra
.679 .641 .805 r
.20258 .45885 .20893 .4697 .21881 .46633 .21262 .45399 Mtetra
.663 .611 .786 r
.21262 .45399 .21881 .46633 .22869 .4635 .22266 .44943 Mtetra
.645 .579 .766 r
.22266 .44943 .22869 .4635 .23855 .46133 .23269 .44528 Mtetra
.626 .548 .746 r
.23269 .44528 .23855 .46133 .24838 .45994 .2427 .44163 Mtetra
.608 .517 .726 r
.2427 .44163 .24838 .45994 .2582 .45938 .25271 .43852 Mtetra
.591 .488 .706 r
.25271 .43852 .2582 .45938 .268 .45971 .26271 .436 Mtetra
.576 .462 .687 r
.26271 .436 .268 .45971 .27781 .46076 .27271 .43408 Mtetra
.562 .439 .67 r
.27271 .43408 .27781 .46076 .28764 .46243 .28271 .43279 Mtetra
.55 .42 .656 r
.28271 .43279 .28764 .46243 .29753 .46429 .29271 .43221 Mtetra
.538 .404 .646 r
.29271 .43221 .29753 .46429 .3075 .46598 .30271 .4324 Mtetra
.528 .393 .641 r
.30271 .4324 .3075 .46598 .31758 .46708 .31273 .43332 Mtetra
.518 .386 .64 r
.31273 .43332 .31758 .46708 .32778 .4672 .32277 .43497 Mtetra
.511 .386 .646 r
.32277 .43497 .32778 .4672 .33811 .46623 .33286 .43707 Mtetra
.504 .392 .66 r
.33286 .43707 .33811 .46623 .34856 .46402 .343 .4394 Mtetra
.5 .41 .686 r
.343 .4394 .34856 .46402 .35911 .46079 .35324 .44162 Mtetra
.496 .447 .732 r
.35324 .44162 .35911 .46079 .36975 .45665 .36356 .44346 Mtetra
.486 .516 .813 r
.36356 .44346 .36975 .45665 .38045 .45192 .37399 .44475 Mtetra
.438 .645 .945 r
.37399 .44475 .38045 .45192 .3912 .44682 .38453 .44532 Mtetra
.168 .69 .879 r
.38453 .44532 .3912 .44682 .40199 .44156 .39516 .44518 Mtetra
.192 0 0 r
.39516 .44518 .40199 .44156 .41281 .43635 .40588 .44432 Mtetra
.319 0 0 r
.40588 .44432 .41281 .43635 .42365 .43131 .41669 .44279 Mtetra
.361 0 .109 r
.41669 .44279 .42365 .43131 .43452 .42654 .42757 .44065 Mtetra
.377 0 .172 r
.42757 .44065 .43452 .42654 .44542 .42211 .43852 .43798 Mtetra
.381 .009 .202 r
.43852 .43798 .44542 .42211 .45635 .41807 .44953 .43481 Mtetra
.376 .012 .213 r
.44953 .43481 .45635 .41807 .46731 .41444 .4606 .43117 Mtetra
.362 0 .207 r
.4606 .43117 .46731 .41444 .47831 .41122 .47172 .42706 Mtetra
.337 0 .182 r
.47172 .42706 .47831 .41122 .48935 .40838 .48289 .42246 Mtetra
.29 0 .131 r
.48289 .42246 .48935 .40838 .50044 .4059 .4941 .41731 Mtetra
.2 0 .027 r
.4941 .41731 .50044 .4059 .51158 .40369 .50535 .41153 Mtetra
.004 0 0 r
.50535 .41153 .51158 .40369 .52278 .40166 .51664 .40509 Mtetra
.427 .836 .647 r
.51664 .40509 .52278 .40166 .53404 .39968 .52795 .39789 Mtetra
.782 .956 .926 r
.52795 .39789 .53404 .39968 .54535 .39755 .53929 .38996 Mtetra
.781 .772 .844 r
.53929 .38996 .54535 .39755 .55672 .39505 .55063 .38129 Mtetra
.731 .641 .758 r
.55063 .38129 .55672 .39505 .56813 .39194 .56198 .37204 Mtetra
.694 .565 .705 r
.56198 .37204 .56813 .39194 .57958 .38792 .57333 .36238 Mtetra
.668 .519 .673 r
.57333 .36238 .57958 .38792 .59106 .38284 .58469 .35258 Mtetra
.649 .489 .653 r
.58469 .35258 .59106 .38284 .60254 .3765 .59605 .34301 Mtetra
.636 .471 .643 r
.59605 .34301 .60254 .3765 .61402 .36902 .60743 .33387 Mtetra
.625 .46 .638 r
.60743 .33387 .61402 .36902 .6255 .36053 .61884 .32546 Mtetra
.618 .455 .639 r
.61884 .32546 .6255 .36053 .63696 .3514 .63029 .31779 Mtetra
.614 .456 .644 r
.63029 .31779 .63696 .3514 .64843 .34209 .6418 .31089 Mtetra
.612 .462 .654 r
.6418 .31089 .64843 .34209 .65991 .33296 .65335 .3047 Mtetra
.612 .472 .667 r
.65335 .3047 .65991 .33296 .67143 .32444 .66497 .29916 Mtetra
.612 .485 .684 r
.66497 .29916 .67143 .32444 .683 .31664 .67666 .29424 Mtetra
.611 .501 .703 r
.67666 .29424 .683 .31664 .69465 .30976 .68842 .28991 Mtetra
.61 .518 .725 r
.68842 .28991 .69465 .30976 .70637 .30372 .70025 .28614 Mtetra
.607 .536 .749 r
.70025 .28614 .70637 .30372 .71817 .29849 .71218 .28289 Mtetra
.603 .557 .775 r
.71218 .28289 .71817 .29849 .73006 .29393 .72418 .28006 Mtetra
.599 .579 .802 r
.72418 .28006 .73006 .29393 .74204 .28993 .73627 .27755 Mtetra
.596 .602 .828 r
.73627 .27755 .74204 .28993 .7541 .28637 .74844 .27525 Mtetra
.593 .627 .854 r
.74844 .27525 .7541 .28637 .76624 .28309 .76068 .27304 Mtetra
.591 .65 .878 r
.76068 .27304 .76624 .28309 .77845 .28002 .773 .27088 Mtetra
.588 .674 .899 r
.773 .27088 .77845 .28002 .79073 .27705 .78538 .26869 Mtetra
.587 .697 .918 r
.78538 .26869 .79073 .27705 .80308 .27409 .79782 .26643 Mtetra
.721 .764 .887 r
.14569 .47843 .15266 .48451 .16259 .47942 .15566 .47322 Mtetra
.724 .762 .883 r
.15566 .47322 .16259 .47942 .17256 .47425 .16566 .46789 Mtetra
.726 .758 .878 r
.16566 .46789 .17256 .47425 .18255 .46906 .1757 .46242 Mtetra
.727 .751 .871 r
.1757 .46242 .18255 .46906 .19256 .46391 .18578 .45683 Mtetra
.727 .739 .861 r
.18578 .45683 .19256 .46391 .20258 .45885 .1959 .45109 Mtetra
.723 .721 .848 r
.1959 .45109 .20258 .45885 .21262 .45399 .20605 .44529 Mtetra
.715 .698 .832 r
.20605 .44529 .21262 .45399 .22266 .44943 .21621 .43949 Mtetra
.703 .669 .813 r
.21621 .43949 .22266 .44943 .23269 .44528 .2264 .43378 Mtetra
.688 .636 .792 r
.2264 .43378 .23269 .44528 .2427 .44163 .23659 .42827 Mtetra
.67 .602 .77 r
.23659 .42827 .2427 .44163 .25271 .43852 .24677 .42305 Mtetra
.651 .568 .748 r
.24677 .42305 .25271 .43852 .26271 .436 .25696 .41822 Mtetra
.632 .536 .728 r
.25696 .41822 .26271 .436 .27271 .43408 .26713 .41388 Mtetra
.613 .506 .709 r
.26713 .41388 .27271 .43408 .28271 .43279 .27729 .41016 Mtetra
.594 .48 .693 r
.27729 .41016 .28271 .43279 .29271 .43221 .28743 .40717 Mtetra
.576 .456 .679 r
.28743 .40717 .29271 .43221 .30271 .4324 .29756 .40503 Mtetra
.561 .436 .667 r
.29756 .40503 .30271 .4324 .31273 .43332 .30767 .40373 Mtetra
.547 .418 .657 r
.30767 .40373 .31273 .43332 .32277 .43497 .31779 .40328 Mtetra
.537 .405 .648 r
.31779 .40328 .32277 .43497 .33286 .43707 .32792 .40346 Mtetra
.531 .395 .641 r
.32792 .40346 .33286 .43707 .343 .4394 .33809 .4041 Mtetra
.529 .389 .635 r
.33809 .4041 .343 .4394 .35324 .44162 .34832 .40492 Mtetra
.53 .387 .631 r
.34832 .40492 .35324 .44162 .36356 .44346 .35862 .40568 Mtetra
.533 .387 .628 r
.35862 .40568 .36356 .44346 .37399 .44475 .369 .40619 Mtetra
.537 .389 .627 r
.369 .40619 .37399 .44475 .38453 .44532 .37947 .4063 Mtetra
.542 .392 .626 r
.37947 .4063 .38453 .44532 .39516 .44518 .39002 .40594 Mtetra
.548 .395 .626 r
.39002 .40594 .39516 .44518 .40588 .44432 .40066 .40504 Mtetra
.554 .4 .626 r
.40066 .40504 .40588 .44432 .41669 .44279 .41138 .40358 Mtetra
.56 .404 .627 r
.41138 .40358 .41669 .44279 .42757 .44065 .42217 .40157 Mtetra
.565 .408 .627 r
.42217 .40157 .42757 .44065 .43852 .43798 .43304 .39899 Mtetra
.571 .413 .628 r
.43304 .39899 .43852 .43798 .44953 .43481 .44396 .39586 Mtetra
.576 .417 .628 r
.44396 .39586 .44953 .43481 .4606 .43117 .45495 .39216 Mtetra
.581 .42 .628 r
.45495 .39216 .4606 .43117 .47172 .42706 .466 .38791 Mtetra
.586 .424 .628 r
.466 .38791 .47172 .42706 .48289 .42246 .47709 .38309 Mtetra
.591 .427 .627 r
.47709 .38309 .48289 .42246 .4941 .41731 .48822 .3777 Mtetra
.596 .429 .627 r
.48822 .3777 .4941 .41731 .50535 .41153 .4994 .37174 Mtetra
.6 .432 .626 r
.4994 .37174 .50535 .41153 .51664 .40509 .51061 .36522 Mtetra
.605 .435 .626 r
.51061 .36522 .51664 .40509 .52795 .39789 .52184 .35813 Mtetra
.609 .438 .626 r
.52184 .35813 .52795 .39789 .53929 .38996 .5331 .35056 Mtetra
.613 .442 .626 r
.5331 .35056 .53929 .38996 .55063 .38129 .54437 .34257 Mtetra
.616 .445 .628 r
.54437 .34257 .55063 .38129 .56198 .37204 .55566 .33431 Mtetra
.619 .449 .63 r
.55566 .33431 .56198 .37204 .57333 .36238 .56696 .32598 Mtetra
.62 .453 .634 r
.56696 .32598 .57333 .36238 .58469 .35258 .57828 .31781 Mtetra
.619 .456 .639 r
.57828 .31781 .58469 .35258 .59605 .34301 .58962 .31009 Mtetra
.617 .46 .646 r
.58962 .31009 .59605 .34301 .60743 .33387 .601 .303 Mtetra
.613 .463 .654 r
.601 .303 .60743 .33387 .61884 .32546 .61242 .29677 Mtetra
.609 .468 .664 r
.61242 .29677 .61884 .32546 .63029 .31779 .62391 .2914 Mtetra
.604 .474 .677 r
.62391 .2914 .63029 .31779 .6418 .31089 .63546 .28689 Mtetra
.599 .483 .693 r
.63546 .28689 .6418 .31089 .65335 .3047 .64709 .28314 Mtetra
.595 .496 .711 r
.64709 .28314 .65335 .3047 .66497 .29916 .65879 .28001 Mtetra
.591 .512 .734 r
.65879 .28001 .66497 .29916 .67666 .29424 .67058 .27739 Mtetra
.587 .532 .761 r
.67058 .27739 .67666 .29424 .68842 .28991 .68245 .27518 Mtetra
.583 .556 .79 r
.68245 .27518 .68842 .28991 .70025 .28614 .69439 .27327 Mtetra
.579 .583 .821 r
.69439 .27327 .70025 .28614 .71218 .28289 .70642 .27156 Mtetra
.574 .611 .852 r
.70642 .27156 .71218 .28289 .72418 .28006 .71852 .26997 Mtetra
.571 .639 .879 r
.71852 .26997 .72418 .28006 .73627 .27755 .7307 .26837 Mtetra
.569 .662 .901 r
.7307 .26837 .73627 .27755 .74844 .27525 .74294 .26672 Mtetra
.57 .682 .916 r
.74294 .26672 .74844 .27525 .76068 .27304 .75525 .26492 Mtetra
.572 .697 .926 r
.75525 .26492 .76068 .27304 .773 .27088 .76761 .26299 Mtetra
.575 .707 .932 r
.76761 .26299 .773 .27088 .78538 .26869 .78004 .26092 Mtetra
.579 .714 .935 r
.78004 .26092 .78538 .26869 .79782 .26643 .79252 .25872 Mtetra
.706 .762 .895 r
.13868 .4723 .14569 .47843 .15566 .47322 .14861 .46756 Mtetra
.713 .779 .903 r
.14861 .46756 .15566 .47322 .16566 .46789 .15859 .46267 Mtetra
.722 .795 .909 r
.15859 .46267 .16566 .46789 .1757 .46242 .16862 .45756 Mtetra
.731 .809 .913 r
.16862 .45756 .1757 .46242 .18578 .45683 .1787 .45219 Mtetra
.742 .818 .911 r
.1787 .45219 .18578 .45683 .1959 .45109 .18884 .44649 Mtetra
.751 .821 .907 r
.18884 .44649 .1959 .45109 .20605 .44529 .19904 .44049 Mtetra
.758 .815 .898 r
.19904 .44049 .20605 .44529 .21621 .43949 .20929 .43419 Mtetra
.759 .8 .886 r
.20929 .43419 .21621 .43949 .2264 .43378 .21957 .42771 Mtetra
.755 .777 .871 r
.21957 .42771 .2264 .43378 .23659 .42827 .22988 .42113 Mtetra
.743 .746 .854 r
.22988 .42113 .23659 .42827 .24677 .42305 .2402 .41464 Mtetra
.727 .711 .835 r
.2402 .41464 .24677 .42305 .25696 .41822 .25053 .4084 Mtetra
.707 .676 .817 r
.25053 .4084 .25696 .41822 .26713 .41388 .26084 .40253 Mtetra
.685 .64 .799 r
.26084 .40253 .26713 .41388 .27729 .41016 .27113 .39716 Mtetra
.666 .607 .779 r
.27113 .39716 .27729 .41016 .28743 .40717 .28142 .39222 Mtetra
.647 .573 .758 r
.28142 .39222 .28743 .40717 .29756 .40503 .29172 .38769 Mtetra
.632 .541 .733 r
.29172 .38769 .29756 .40503 .30767 .40373 .30203 .38336 Mtetra
.62 .511 .708 r
.30203 .38336 .30767 .40373 .31779 .40328 .31236 .37912 Mtetra
.608 .482 .683 r
.31236 .37912 .31779 .40328 .32792 .40346 .32274 .37489 Mtetra
.598 .457 .66 r
.32274 .37489 .32792 .40346 .33809 .4041 .33315 .37063 Mtetra
.589 .435 .641 r
.33315 .37063 .33809 .4041 .34832 .40492 .34359 .36642 Mtetra
.581 .418 .626 r
.34359 .36642 .34832 .40492 .35862 .40568 .35406 .3623 Mtetra
.574 .405 .614 r
.35406 .3623 .35862 .40568 .369 .40619 .36457 .35832 Mtetra
.568 .394 .606 r
.36457 .35832 .369 .40619 .37947 .4063 .3751 .35452 Mtetra
.564 .387 .599 r
.3751 .35452 .37947 .4063 .39002 .40594 .38567 .35088 Mtetra
.561 .381 .594 r
.38567 .35088 .39002 .40594 .40066 .40504 .39628 .34736 Mtetra
.559 .377 .591 r
.39628 .34736 .40066 .40504 .41138 .40358 .40692 .34391 Mtetra
.558 .374 .588 r
.40692 .34391 .41138 .40358 .42217 .40157 .41761 .34047 Mtetra
.558 .373 .587 r
.41761 .34047 .42217 .40157 .43304 .39899 .42834 .33696 Mtetra
.558 .372 .586 r
.42834 .33696 .43304 .39899 .44396 .39586 .43912 .33334 Mtetra
.559 .373 .586 r
.43912 .33334 .44396 .39586 .45495 .39216 .44995 .32957 Mtetra
.44995 .32957 .45495 .39216 .466 .38791 .46083 .32565 Mtetra
.56 .374 .586 r
.46083 .32565 .466 .38791 .47709 .38309 .47174 .32162 Mtetra
.561 .375 .587 r
.47174 .32162 .47709 .38309 .48822 .3777 .48271 .31753 Mtetra
.562 .377 .589 r
.48271 .31753 .48822 .3777 .4994 .37174 .49371 .31343 Mtetra
.562 .379 .591 r
.49371 .31343 .4994 .37174 .51061 .36522 .50476 .30941 Mtetra
.563 .382 .594 r
.50476 .30941 .51061 .36522 .52184 .35813 .51584 .30551 Mtetra
.563 .386 .599 r
.51584 .30551 .52184 .35813 .5331 .35056 .52698 .30177 Mtetra
.565 .392 .606 r
.52698 .30177 .5331 .35056 .54437 .34257 .53816 .2982 Mtetra
.567 .4 .614 r
.53816 .2982 .54437 .34257 .55566 .33431 .54939 .29478 Mtetra
.57 .411 .626 r
.54939 .29478 .55566 .33431 .56696 .32598 .56067 .29146 Mtetra
.575 .426 .642 r
.56067 .29146 .56696 .32598 .57828 .31781 .572 .28818 Mtetra
.582 .446 .661 r
.572 .28818 .57828 .31781 .58962 .31009 .58338 .28487 Mtetra
.589 .47 .684 r
.58338 .28487 .58962 .31009 .601 .303 .59482 .28158 Mtetra
.596 .496 .711 r
.59482 .28158 .601 .303 .61242 .29677 .60631 .27838 Mtetra
.599 .522 .739 r
.60631 .27838 .61242 .29677 .62391 .2914 .61786 .27538 Mtetra
.596 .546 .768 r
.61786 .27538 .62391 .2914 .63546 .28689 .62948 .2728 Mtetra
.589 .568 .797 r
.62948 .2728 .63546 .28689 .64709 .28314 .64118 .27067 Mtetra
.576 .587 .827 r
.64118 .27067 .64709 .28314 .65879 .28001 .65296 .26906 Mtetra
.561 .611 .86 r
.65296 .26906 .65879 .28001 .67058 .27739 .66482 .26783 Mtetra
.545 .637 .893 r
.66482 .26783 .67058 .27739 .68245 .27518 .67678 .26687 Mtetra
.529 .666 .924 r
.67678 .26687 .68245 .27518 .69439 .27327 .68881 .26601 Mtetra
.518 .696 .95 r
.68881 .26601 .69439 .27327 .70642 .27156 .70091 .26506 Mtetra
.513 .722 .967 r
.70091 .26506 .70642 .27156 .71852 .26997 .71308 .26392 Mtetra
.52 .743 .976 r
.71308 .26392 .71852 .26997 .7307 .26837 .7253 .26248 Mtetra
.532 .756 .979 r
.7253 .26248 .7307 .26837 .74294 .26672 .73758 .26073 Mtetra
.552 .763 .976 r
.73758 .26073 .74294 .26672 .75525 .26492 .74991 .25864 Mtetra
.57 .762 .969 r
.74991 .25864 .75525 .26492 .76761 .26299 .76228 .25628 Mtetra
.585 .754 .958 r
.76228 .25628 .76761 .26299 .78004 .26092 .7747 .2537 Mtetra
.597 .742 .946 r
.7747 .2537 .78004 .26092 .79252 .25872 .78718 .25095 Mtetra
.67 .755 .914 r
.13161 .46613 .13868 .4723 .14861 .46756 .14145 .46241 Mtetra
.675 .791 .936 r
.14145 .46241 .14861 .46756 .15859 .46267 .15133 .45855 Mtetra
.681 .83 .955 r
.15133 .45855 .15859 .46267 .16862 .45756 .16127 .45449 Mtetra
.685 .87 .969 r
.16127 .45449 .16862 .45756 .1787 .45219 .17128 .45014 Mtetra
.688 .907 .972 r
.17128 .45014 .1787 .45219 .18884 .44649 .18136 .44543 Mtetra
.685 .937 .966 r
.18136 .44543 .18884 .44649 .19904 .44049 .1915 .44034 Mtetra
.68 .957 .948 r
.1915 .44034 .19904 .44049 .20929 .43419 .20171 .43482 Mtetra
.669 .967 .923 r
.20171 .43482 .20929 .43419 .21957 .42771 .21199 .42894 Mtetra
.66 .97 .898 r
.21199 .42894 .21957 .42771 .22988 .42113 .22232 .42271 Mtetra
.653 .97 .88 r
.22232 .42271 .22988 .42113 .2402 .41464 .23269 .41626 Mtetra
.657 .971 .877 r
.23269 .41626 .2402 .41464 .25053 .4084 .24309 .40969 Mtetra
.676 .976 .891 r
.24309 .40969 .25053 .4084 .26084 .40253 .25351 .40308 Mtetra
.705 .976 .918 r
.25351 .40308 .26084 .40253 .27113 .39716 .26395 .39652 Mtetra
.741 .96 .941 r
.26395 .39652 .27113 .39716 .28142 .39222 .27441 .39001 Mtetra
.761 .916 .942 r
.27441 .39001 .28142 .39222 .29172 .38769 .28488 .38356 Mtetra
.762 .85 .917 r
.28488 .38356 .29172 .38769 .30203 .38336 .29537 .37714 Mtetra
.748 .78 .879 r
.29537 .37714 .30203 .38336 .31236 .37912 .30588 .37075 Mtetra
.728 .719 .842 r
.30588 .37075 .31236 .37912 .32274 .37489 .31641 .36446 Mtetra
.707 .669 .81 r
.31641 .36446 .32274 .37489 .33315 .37063 .32695 .35832 Mtetra
.688 .63 .786 r
.32695 .35832 .33315 .37063 .34359 .36642 .3375 .35242 Mtetra
.671 .599 .766 r
.3375 .35242 .34359 .36642 .35406 .3623 .34806 .34683 Mtetra
.657 .575 .751 r
.34806 .34683 .35406 .3623 .36457 .35832 .35863 .34155 Mtetra
.644 .555 .74 r
.35863 .34155 .36457 .35832 .3751 .35452 .36921 .3366 Mtetra
.634 .539 .73 r
.36921 .3366 .3751 .35452 .38567 .35088 .37981 .33195 Mtetra
.625 .526 .722 r
.37981 .33195 .38567 .35088 .39628 .34736 .39044 .32755 Mtetra
.619 .516 .715 r
.39044 .32755 .39628 .34736 .40692 .34391 .40109 .32336 Mtetra
.614 .508 .71 r
.40109 .32336 .40692 .34391 .41761 .34047 .41178 .31932 Mtetra
.61 .502 .706 r
.41178 .31932 .41761 .34047 .42834 .33696 .42251 .31538 Mtetra
.607 .498 .703 r
.42251 .31538 .42834 .33696 .43912 .33334 .43327 .31152 Mtetra
.606 .495 .702 r
.43327 .31152 .43912 .33334 .44995 .32957 .44408 .30771 Mtetra
.605 .495 .702 r
.44408 .30771 .44995 .32957 .46083 .32565 .45492 .30396 Mtetra
.604 .495 .704 r
.45492 .30396 .46083 .32565 .47174 .32162 .46581 .30028 Mtetra
.603 .497 .707 r
.46581 .30028 .47174 .32162 .48271 .31753 .47675 .2967 Mtetra
.601 .5 .711 r
.47675 .2967 .48271 .31753 .49371 .31343 .48772 .29328 Mtetra
.6 .504 .718 r
.48772 .29328 .49371 .31343 .50476 .30941 .49874 .29006 Mtetra
.597 .509 .726 r
.49874 .29006 .50476 .30941 .51584 .30551 .50981 .28711 Mtetra
.593 .516 .737 r
.50981 .28711 .51584 .30551 .52698 .30177 .52094 .28445 Mtetra
.589 .524 .75 r
.52094 .28445 .52698 .30177 .53816 .2982 .53211 .28214 Mtetra
.583 .535 .766 r
.53211 .28214 .53816 .2982 .54939 .29478 .54335 .28015 Mtetra
.577 .55 .788 r
.54335 .28015 .54939 .29478 .56067 .29146 .55465 .27847 Mtetra
.571 .573 .816 r
.55465 .27847 .56067 .29146 .572 .28818 .56601 .27704 Mtetra
.564 .605 .852 r
.56601 .27704 .572 .28818 .58338 .28487 .57745 .27578 Mtetra
.551 .649 .9 r
.57745 .27578 .58338 .28487 .59482 .28158 .58895 .27462 Mtetra
.526 .706 .953 r
.58895 .27462 .59482 .28158 .60631 .27838 .60052 .27349 Mtetra
.47 .759 .993 r
.60052 .27349 .60631 .27838 .61786 .27538 .61217 .27241 Mtetra
.366 .778 .98 r
.61217 .27241 .61786 .27538 .62948 .2728 .62388 .2714 Mtetra
.234 .738 .895 r
.62388 .2714 .62948 .2728 .64118 .27067 .63568 .27044 Mtetra
.114 .667 .779 r
.63568 .27044 .64118 .27067 .65296 .26906 .64754 .26954 Mtetra
0 0 0 r
.64754 .26954 .65296 .26906 .66482 .26783 .65948 .26862 Mtetra
.65948 .26862 .66482 .26783 .67678 .26687 .67149 .26757 Mtetra
.67149 .26757 .67678 .26687 .68881 .26601 .68357 .2663 Mtetra
.132 .68 .748 r
.68357 .2663 .68881 .26601 .70091 .26506 .6957 .26469 Mtetra
.23 .749 .831 r
.6957 .26469 .70091 .26506 .71308 .26392 .70788 .2627 Mtetra
.348 .815 .914 r
.70788 .2627 .71308 .26392 .7253 .26248 .7201 .26026 Mtetra
.454 .854 .972 r
.7201 .26026 .7253 .26248 .73758 .26073 .73236 .25743 Mtetra
.538 .862 .996 r
.73236 .25743 .73758 .26073 .74991 .25864 .74465 .25421 Mtetra
.592 .845 .992 r
.74465 .25421 .74991 .25864 .76228 .25628 .75699 .25071 Mtetra
.623 .815 .974 r
.75699 .25071 .76228 .25628 .7747 .2537 .76937 .24698 Mtetra
.638 .78 .949 r
.76937 .24698 .7747 .2537 .78718 .25095 .7818 .24311 Mtetra
.615 .741 .935 r
.12449 .45992 .13161 .46613 .14145 .46241 .1342 .45743 Mtetra
.608 .784 .965 r
.1342 .45743 .14145 .46241 .15133 .45855 .14396 .45487 Mtetra
.595 .829 .988 r
.14396 .45487 .15133 .45855 .16127 .45449 .15377 .45217 Mtetra
.569 .871 .995 r
.15377 .45217 .16127 .45449 .17128 .45014 .16365 .44925 Mtetra
.523 .894 .968 r
.16365 .44925 .17128 .45014 .18136 .44543 .17361 .44605 Mtetra
.448 .88 .891 r
.17361 .44605 .18136 .44543 .1915 .44034 .18363 .44251 Mtetra
.353 .823 .766 r
.18363 .44251 .1915 .44034 .20171 .43482 .19374 .43855 Mtetra
0 0 0 r
.19374 .43855 .20171 .43482 .21199 .42894 .20392 .43414 Mtetra
.20392 .43414 .21199 .42894 .22232 .42271 .21419 .42924 Mtetra
.21419 .42924 .22232 .42271 .23269 .41626 .22453 .42383 Mtetra
.22453 .42383 .23269 .41626 .24309 .40969 .23494 .41789 Mtetra
.23494 .41789 .24309 .40969 .25351 .40308 .24543 .41146 Mtetra
.24543 .41146 .25351 .40308 .26395 .39652 .25597 .40456 Mtetra
.25597 .40456 .26395 .39652 .27441 .39001 .26655 .39738 Mtetra
.26655 .39738 .27441 .39001 .28488 .38356 .27716 .39005 Mtetra
.27716 .39005 .28488 .38356 .29537 .37714 .28778 .38284 Mtetra
.28778 .38284 .29537 .37714 .30588 .37075 .2984 .37598 Mtetra
.2984 .37598 .30588 .37075 .31641 .36446 .309 .36957 Mtetra
.309 .36957 .31641 .36446 .32695 .35832 .31958 .36374 Mtetra
.31958 .36374 .32695 .35832 .3375 .35242 .33017 .35839 Mtetra
.33017 .35839 .3375 .35242 .34806 .34683 .34075 .35346 Mtetra
.014 0 0 r
.34075 .35346 .34806 .34683 .35863 .34155 .35136 .34883 Mtetra
.073 0 0 r
.35136 .34883 .35863 .34155 .36921 .3366 .36199 .34439 Mtetra
.112 0 0 r
.36199 .34439 .36921 .3366 .37981 .33195 .37265 .34008 Mtetra
.135 0 0 r
.37265 .34008 .37981 .33195 .39044 .32755 .38335 .33583 Mtetra
.149 0 0 r
.38335 .33583 .39044 .32755 .40109 .32336 .39408 .33165 Mtetra
.155 0 0 r
.39408 .33165 .40109 .32336 .41178 .31932 .40485 .32753 Mtetra
.159 0 0 r
.40485 .32753 .41178 .31932 .42251 .31538 .41565 .32349 Mtetra
.164 0 0 r
.41565 .32349 .42251 .31538 .43327 .31152 .4265 .31955 Mtetra
.17 0 0 r
.4265 .31955 .43327 .31152 .44408 .30771 .43738 .31573 Mtetra
.178 0 0 r
.43738 .31573 .44408 .30771 .45492 .30396 .44831 .31202 Mtetra
.188 0 0 r
.44831 .31202 .45492 .30396 .46581 .30028 .45928 .3084 Mtetra
.198 0 0 r
.45928 .3084 .46581 .30028 .47675 .2967 .47029 .30488 Mtetra
.205 0 0 r
.47029 .30488 .47675 .2967 .48772 .29328 .48135 .30141 Mtetra
.209 0 0 r
.48135 .30141 .48772 .29328 .49874 .29006 .49245 .29801 Mtetra
.208 0 0 r
.49245 .29801 .49874 .29006 .50981 .28711 .5036 .29468 Mtetra
.203 0 0 r
.5036 .29468 .50981 .28711 .52094 .28445 .51481 .29148 Mtetra
.195 0 0 r
.51481 .29148 .52094 .28445 .53211 .28214 .52606 .28847 Mtetra
.186 0 0 r
.52606 .28847 .53211 .28214 .54335 .28015 .53737 .28577 Mtetra
.185 0 0 r
.53737 .28577 .54335 .28015 .55465 .27847 .54874 .2835 Mtetra
.192 0 0 r
.54874 .2835 .55465 .27847 .56601 .27704 .56017 .28172 Mtetra
.219 0 0 r
.56017 .28172 .56601 .27704 .57745 .27578 .57168 .28053 Mtetra
.255 0 0 r
.57168 .28053 .57745 .27578 .58895 .27462 .58326 .27982 Mtetra
.295 0 0 r
.58326 .27982 .58895 .27462 .60052 .27349 .59493 .27947 Mtetra
.328 0 0 r
.59493 .27947 .60052 .27349 .61217 .27241 .60667 .27926 Mtetra
.343 0 0 r
.60667 .27926 .61217 .27241 .62388 .2714 .61849 .27891 Mtetra
.345 0 0 r
.61849 .27891 .62388 .2714 .63568 .27044 .63038 .27826 Mtetra
.33 0 0 r
.63038 .27826 .63568 .27044 .64754 .26954 .64233 .27715 Mtetra
.301 0 0 r
.64233 .27715 .64754 .26954 .65948 .26862 .65433 .27554 Mtetra
.252 0 0 r
.65433 .27554 .65948 .26862 .67149 .26757 .66638 .27339 Mtetra
.178 0 0 r
.66638 .27339 .67149 .26757 .68357 .2663 .67847 .27071 Mtetra
.067 0 0 r
.67847 .27071 .68357 .2663 .6957 .26469 .69059 .26752 Mtetra
0 0 0 r
.69059 .26752 .6957 .26469 .70788 .2627 .70275 .26386 Mtetra
.277 .774 .731 r
.70275 .26386 .70788 .2627 .7201 .26026 .71494 .25978 Mtetra
.455 .884 .89 r
.71494 .25978 .7201 .26026 .73236 .25743 .72716 .25532 Mtetra
.582 .918 .968 r
.72716 .25532 .73236 .25743 .74465 .25421 .73941 .25057 Mtetra
.65 .897 .983 r
.73941 .25057 .74465 .25421 .75699 .25071 .75169 .24558 Mtetra
.679 .855 .966 r
.75169 .24558 .75699 .25071 .76937 .24698 .76401 .24044 Mtetra
.688 .808 .939 r
.76401 .24044 .76937 .24698 .7818 .24311 .77637 .23521 Mtetra
.556 .722 .951 r
.11732 .45366 .12449 .45992 .1342 .45743 .12692 .4522 Mtetra
.539 .754 .976 r
.12692 .4522 .1342 .45743 .14396 .45487 .13657 .45074 Mtetra
.514 .788 .995 r
.13657 .45074 .14396 .45487 .15377 .45217 .14627 .4492 Mtetra
.477 .817 .999 r
.14627 .4492 .15377 .45217 .16365 .44925 .15604 .44755 Mtetra
.421 .831 .974 r
.15604 .44755 .16365 .44925 .17361 .44605 .16587 .44571 Mtetra
.341 .814 .902 r
.16587 .44571 .17361 .44605 .18363 .44251 .17578 .44363 Mtetra
.244 .758 .779 r
.17578 .44363 .18363 .44251 .19374 .43855 .18577 .44122 Mtetra
0 0 0 r
.18577 .44122 .19374 .43855 .20392 .43414 .19584 .43842 Mtetra
.19584 .43842 .20392 .43414 .21419 .42924 .206 .43517 Mtetra
.015 0 0 r
.206 .43517 .21419 .42924 .22453 .42383 .21625 .43142 Mtetra
.067 0 0 r
.21625 .43142 .22453 .42383 .23494 .41789 .22658 .42713 Mtetra
.112 0 0 r
.22658 .42713 .23494 .41789 .24543 .41146 .23699 .42236 Mtetra
.148 0 0 r
.23699 .42236 .24543 .41146 .25597 .40456 .24748 .41712 Mtetra
.187 0 .018 r
.24748 .41712 .25597 .40456 .26655 .39738 .25801 .41159 Mtetra
.224 0 .075 r
.25801 .41159 .26655 .39738 .27716 .39005 .26859 .40588 Mtetra
.26 0 .124 r
.26859 .40588 .27716 .39005 .28778 .38284 .2792 .40019 Mtetra
.293 0 .165 r
.2792 .40019 .28778 .38284 .2984 .37598 .28982 .39464 Mtetra
.318 0 .195 r
.28982 .39464 .2984 .37598 .309 .36957 .30046 .38928 Mtetra
.338 0 .217 r
.30046 .38928 .309 .36957 .31958 .36374 .31111 .38412 Mtetra
.35 .004 .23 r
.31111 .38412 .31958 .36374 .33017 .35839 .32179 .37911 Mtetra
.356 .012 .236 r
.32179 .37911 .33017 .35839 .34075 .35346 .33249 .37419 Mtetra
.358 .014 .238 r
.33249 .37419 .34075 .35346 .35136 .34883 .34323 .36932 Mtetra
.358 .012 .235 r
.34323 .36932 .35136 .34883 .36199 .34439 .354 .36447 Mtetra
.355 .008 .23 r
.354 .36447 .36199 .34439 .37265 .34008 .3648 .35966 Mtetra
.353 .003 .224 r
.3648 .35966 .37265 .34008 .38335 .33583 .37563 .35489 Mtetra
.351 0 .218 r
.37563 .35489 .38335 .33583 .39408 .33165 .3865 .35023 Mtetra
.351 0 .212 r
.3865 .35023 .39408 .33165 .40485 .32753 .3974 .34571 Mtetra
.354 0 .209 r
.3974 .34571 .40485 .32753 .41565 .32349 .40833 .34139 Mtetra
.359 0 .208 r
.40833 .34139 .41565 .32349 .4265 .31955 .41929 .3373 Mtetra
.365 .002 .209 r
.41929 .3373 .4265 .31955 .43738 .31573 .43029 .33346 Mtetra
.373 .01 .212 r
.43029 .33346 .43738 .31573 .44831 .31202 .44132 .32989 Mtetra
.381 .018 .217 r
.44132 .32989 .44831 .31202 .45928 .3084 .4524 .32654 Mtetra
.39 .027 .224 r
.4524 .32654 .45928 .3084 .47029 .30488 .46352 .3234 Mtetra
.397 .036 .232 r
.46352 .3234 .47029 .30488 .48135 .30141 .47469 .32041 Mtetra
.403 .045 .24 r
.47469 .32041 .48135 .30141 .49245 .29801 .48591 .31752 Mtetra
.408 .053 .247 r
.48591 .31752 .49245 .29801 .5036 .29468 .49718 .31468 Mtetra
.412 .059 .254 r
.49718 .31468 .5036 .29468 .51481 .29148 .50851 .31188 Mtetra
.415 .064 .259 r
.50851 .31188 .51481 .29148 .52606 .28847 .51989 .3091 Mtetra
.418 .068 .262 r
.51989 .3091 .52606 .28847 .53737 .28577 .53133 .30637 Mtetra
.42 .07 .262 r
.53133 .30637 .53737 .28577 .54874 .2835 .54282 .30375 Mtetra
.421 .069 .259 r
.54282 .30375 .54874 .2835 .56017 .28172 .55438 .30127 Mtetra
.423 .066 .252 r
.55438 .30127 .56017 .28172 .57168 .28053 .566 .29901 Mtetra
.421 .057 .239 r
.566 .29901 .57168 .28053 .58326 .27982 .57768 .29693 Mtetra
.416 .043 .219 r
.57768 .29693 .58326 .27982 .59493 .27947 .58944 .29502 Mtetra
.405 .02 .192 r
.58944 .29502 .59493 .27947 .60667 .27926 .60125 .29312 Mtetra
.385 0 .154 r
.60125 .29312 .60667 .27926 .61849 .27891 .61313 .29105 Mtetra
.354 0 .104 r
.61313 .29105 .61849 .27891 .63038 .27826 .62507 .28867 Mtetra
.307 0 .038 r
.62507 .28867 .63038 .27826 .64233 .27715 .63706 .28583 Mtetra
.241 0 0 r
.63706 .28583 .64233 .27715 .65433 .27554 .64908 .28248 Mtetra
.148 0 0 r
.64908 .28248 .65433 .27554 .66638 .27339 .66114 .27857 Mtetra
.021 0 0 r
.66114 .27857 .66638 .27339 .67847 .27071 .67323 .27415 Mtetra
0 0 0 r
.67323 .27415 .67847 .27071 .69059 .26752 .68535 .26925 Mtetra
.336 .803 .707 r
.68535 .26925 .69059 .26752 .70275 .26386 .69749 .26394 Mtetra
.508 .912 .861 r
.69749 .26394 .70275 .26386 .71494 .25978 .70965 .25828 Mtetra
.625 .947 .943 r
.70965 .25828 .71494 .25978 .72716 .25532 .72184 .25235 Mtetra
.689 .932 .967 r
.72184 .25235 .72716 .25532 .73941 .25057 .73406 .24622 Mtetra
.717 .895 .96 r
.73406 .24622 .73941 .25057 .75169 .24558 .74631 .23996 Mtetra
.726 .854 .942 r
.74631 .23996 .75169 .24558 .76401 .24044 .75858 .23362 Mtetra
.725 .813 .92 r
.75858 .23362 .76401 .24044 .77637 .23521 .7709 .22725 Mtetra
.512 .706 .958 r
.1101 .44736 .11732 .45366 .12692 .4522 .11964 .44654 Mtetra
.494 .723 .973 r
.11964 .44654 .12692 .4522 .13657 .45074 .12922 .44575 Mtetra
.473 .741 .987 r
.12922 .44575 .13657 .45074 .14627 .4492 .13885 .44498 Mtetra
.446 .759 .995 r
.13885 .44498 .14627 .4492 .15604 .44755 .14854 .44418 Mtetra
.407 .774 .994 r
.14854 .44418 .15604 .44755 .16587 .44571 .15829 .44333 Mtetra
.358 .782 .974 r
.15829 .44333 .16587 .44571 .17578 .44363 .1681 .44236 Mtetra
.292 .772 .922 r
.1681 .44236 .17578 .44363 .18577 .44122 .17799 .4412 Mtetra
.209 .734 .828 r
.17799 .4412 .18577 .44122 .19584 .43842 .18796 .4398 Mtetra
0 0 0 r
.18796 .4398 .19584 .43842 .206 .43517 .198 .4381 Mtetra
.198 .4381 .206 .43517 .21625 .43142 .20813 .4361 Mtetra
.083 0 0 r
.20813 .4361 .21625 .43142 .22658 .42713 .21833 .43379 Mtetra
.17 0 0 r
.21833 .43379 .22658 .42713 .23699 .42236 .22861 .43124 Mtetra
.241 0 0 r
.22861 .43124 .23699 .42236 .24748 .41712 .23895 .4285 Mtetra
.297 0 .049 r
.23895 .4285 .24748 .41712 .25801 .41159 .24934 .4256 Mtetra
.338 0 .13 r
.24934 .4256 .25801 .41159 .26859 .40588 .25979 .42259 Mtetra
.363 0 .186 r
.25979 .42259 .26859 .40588 .2792 .40019 .27031 .41936 Mtetra
.378 .02 .225 r
.27031 .41936 .2792 .40019 .28982 .39464 .28088 .41588 Mtetra
.384 .037 .249 r
.28088 .41588 .28982 .39464 .30046 .38928 .29153 .41203 Mtetra
.384 .045 .262 r
.29153 .41203 .30046 .38928 .31111 .38412 .30225 .40774 Mtetra
.38 .046 .267 r
.30225 .40774 .31111 .38412 .32179 .37911 .31303 .40305 Mtetra
.374 .042 .268 r
.31303 .40305 .32179 .37911 .33249 .37419 .32387 .39801 Mtetra
.369 .036 .264 r
.32387 .39801 .33249 .37419 .34323 .36932 .33475 .39274 Mtetra
.364 .03 .259 r
.33475 .39274 .34323 .36932 .354 .36447 .34568 .38734 Mtetra
.36 .024 .254 r
.34568 .38734 .354 .36447 .3648 .35966 .35664 .38196 Mtetra
.359 .021 .248 r
.35664 .38196 .3648 .35966 .37563 .35489 .36762 .37668 Mtetra
.36 .019 .245 r
.36762 .37668 .37563 .35489 .3865 .35023 .37863 .37159 Mtetra
.364 .021 .243 r
.37863 .37159 .3865 .35023 .3974 .34571 .38967 .36676 Mtetra
.37 .025 .242 r
.38967 .36676 .3974 .34571 .40833 .34139 .40073 .36224 Mtetra
.378 .031 .244 r
.40073 .36224 .40833 .34139 .41929 .3373 .41182 .35805 Mtetra
.386 .038 .246 r
.41182 .35805 .41929 .3373 .43029 .33346 .42294 .35421 Mtetra
.395 .046 .25 r
.42294 .35421 .43029 .33346 .44132 .32989 .43409 .35072 Mtetra
.404 .054 .255 r
.43409 .35072 .44132 .32989 .4524 .32654 .44529 .34757 Mtetra
.413 .063 .26 r
.44529 .34757 .4524 .32654 .46352 .3234 .45653 .34473 Mtetra
.42 .072 .265 r
.45653 .34473 .46352 .3234 .47469 .32041 .46782 .34215 Mtetra
.427 .079 .271 r
.46782 .34215 .47469 .32041 .48591 .31752 .47916 .33977 Mtetra
.432 .086 .277 r
.47916 .33977 .48591 .31752 .49718 .31468 .49057 .3375 Mtetra
.434 .091 .283 r
.49057 .3375 .49718 .31468 .50851 .31188 .50203 .33524 Mtetra
.434 .094 .287 r
.50203 .33524 .50851 .31188 .51989 .3091 .51355 .33287 Mtetra
.432 .093 .289 r
.51355 .33287 .51989 .3091 .53133 .30637 .52513 .33026 Mtetra
.426 .088 .288 r
.52513 .33026 .53133 .30637 .54282 .30375 .53677 .3273 Mtetra
.417 .079 .282 r
.53677 .3273 .54282 .30375 .55438 .30127 .54846 .32393 Mtetra
.403 .063 .27 r
.54846 .32393 .55438 .30127 .566 .29901 .56021 .32012 Mtetra
.386 .04 .25 r
.56021 .32012 .566 .29901 .57768 .29693 .57199 .31593 Mtetra
.364 .007 .219 r
.57199 .31593 .57768 .29693 .58944 .29502 .58383 .31147 Mtetra
.332 0 .173 r
.58383 .31147 .58944 .29502 .60125 .29312 .59571 .30679 Mtetra
.288 0 .106 r
.59571 .30679 .60125 .29312 .61313 .29105 .60763 .30198 Mtetra
.223 0 .011 r
.60763 .30198 .61313 .29105 .62507 .28867 .61959 .29701 Mtetra
.126 0 0 r
.61959 .29701 .62507 .28867 .63706 .28583 .63159 .29184 Mtetra
0 0 0 r
.63159 .29184 .63706 .28583 .64908 .28248 .64362 .28641 Mtetra
.64362 .28641 .64908 .28248 .66114 .27857 .65569 .28064 Mtetra
.379 .825 .7 r
.65569 .28064 .66114 .27857 .67323 .27415 .66778 .27457 Mtetra
.543 .928 .847 r
.66778 .27457 .67323 .27415 .68535 .26925 .67989 .26817 Mtetra
.652 .962 .925 r
.67989 .26817 .68535 .26925 .69749 .26394 .69202 .2615 Mtetra
.711 .952 .952 r
.69202 .2615 .69749 .26394 .70965 .25828 .70418 .25463 Mtetra
.739 .923 .953 r
.70418 .25463 .70965 .25828 .72184 .25235 .71636 .24762 Mtetra
.749 .89 .943 r
.71636 .24762 .72184 .25235 .73406 .24622 .72857 .24055 Mtetra
.751 .859 .929 r
.72857 .24055 .73406 .24622 .74631 .23996 .74081 .23343 Mtetra
.748 .831 .915 r
.74081 .23343 .74631 .23996 .75858 .23362 .75308 .22631 Mtetra
.743 .806 .902 r
.75308 .22631 .75858 .23362 .7709 .22725 .76539 .21923 Mtetra
.516 .707 .958 r
.10283 .44102 .1101 .44736 .11964 .44654 .11239 .44012 Mtetra
.511 .703 .957 r
.11239 .44012 .11964 .44654 .12922 .44575 .12198 .4393 Mtetra
.506 .701 .957 r
.12198 .4393 .12922 .44575 .13885 .44498 .13163 .43854 Mtetra
.5 .7 .959 r
.13163 .43854 .13885 .44498 .14854 .44418 .14131 .43786 Mtetra
.492 .701 .962 r
.14131 .43786 .14854 .44418 .15829 .44333 .15105 .43725 Mtetra
.484 .707 .968 r
.15105 .43725 .15829 .44333 .1681 .44236 .16083 .43666 Mtetra
.473 .718 .977 r
.16083 .43666 .1681 .44236 .17799 .4412 .17068 .43607 Mtetra
.459 .735 .987 r
.17068 .43607 .17799 .4412 .18796 .4398 .18058 .43542 Mtetra
.439 .755 .995 r
.18058 .43542 .18796 .4398 .198 .4381 .19055 .43467 Mtetra
.405 .774 .994 r
.19055 .43467 .198 .4381 .20813 .4361 .2006 .43379 Mtetra
.351 .783 .969 r
.2006 .43379 .20813 .4361 .21833 .43379 .21071 .43275 Mtetra
.27 .763 .903 r
.21071 .43275 .21833 .43379 .22861 .43124 .2209 .43153 Mtetra
.17 .708 .789 r
.2209 .43153 .22861 .43124 .23895 .4285 .23116 .43013 Mtetra
0 0 0 r
.23116 .43013 .23895 .4285 .24934 .4256 .24149 .42849 Mtetra
.001 0 0 r
.24149 .42849 .24934 .4256 .25979 .42259 .2519 .42658 Mtetra
.046 0 0 r
.2519 .42658 .25979 .42259 .27031 .41936 .26239 .42432 Mtetra
.068 0 0 r
.26239 .42432 .27031 .41936 .28088 .41588 .27296 .42164 Mtetra
.079 0 0 r
.27296 .42164 .28088 .41588 .29153 .41203 .28362 .41854 Mtetra
.087 0 0 r
.28362 .41854 .29153 .41203 .30225 .40774 .29435 .41504 Mtetra
.104 0 0 r
.29435 .41504 .30225 .40774 .31303 .40305 .30514 .41122 Mtetra
.129 0 0 r
.30514 .41122 .31303 .40305 .32387 .39801 .31599 .40718 Mtetra
.163 0 0 r
.31599 .40718 .32387 .39801 .33475 .39274 .32689 .40301 Mtetra
.2 0 0 r
.32689 .40301 .33475 .39274 .34568 .38734 .33784 .39879 Mtetra
.235 0 .013 r
.33784 .39879 .34568 .38734 .35664 .38196 .34882 .39458 Mtetra
.266 0 .059 r
.34882 .39458 .35664 .38196 .36762 .37668 .35985 .3904 Mtetra
.291 0 .096 r
.35985 .3904 .36762 .37668 .37863 .37159 .37091 .38629 Mtetra
.311 0 .125 r
.37091 .38629 .37863 .37159 .38967 .36676 .38201 .38224 Mtetra
.325 0 .146 r
.38201 .38224 .38967 .36676 .40073 .36224 .39316 .37826 Mtetra
.335 0 .159 r
.39316 .37826 .40073 .36224 .41182 .35805 .40434 .37435 Mtetra
.342 0 .167 r
.40434 .37435 .41182 .35805 .42294 .35421 .41557 .3705 Mtetra
.344 0 .168 r
.41557 .3705 .42294 .35421 .43409 .35072 .42685 .36672 Mtetra
.344 0 .163 r
.42685 .36672 .43409 .35072 .44529 .34757 .43817 .363 Mtetra
.34 0 .152 r
.43817 .363 .44529 .34757 .45653 .34473 .44953 .35935 Mtetra
.332 0 .135 r
.44953 .35935 .45653 .34473 .46782 .34215 .46095 .35577 Mtetra
.32 0 .11 r
.46095 .35577 .46782 .34215 .47916 .33977 .47241 .35225 Mtetra
.304 0 .078 r
.47241 .35225 .47916 .33977 .49057 .3375 .48393 .34878 Mtetra
.281 0 .037 r
.48393 .34878 .49057 .3375 .50203 .33524 .49549 .3453 Mtetra
.251 0 0 r
.49549 .3453 .50203 .33524 .51355 .33287 .50711 .34178 Mtetra
.212 0 0 r
.50711 .34178 .51355 .33287 .52513 .33026 .51879 .33813 Mtetra
.162 0 0 r
.51879 .33813 .52513 .33026 .53677 .3273 .53051 .33424 Mtetra
.102 0 0 r
.53051 .33424 .53677 .3273 .54846 .32393 .54229 .33004 Mtetra
.029 0 0 r
.54229 .33004 .54846 .32393 .56021 .32012 .5541 .32542 Mtetra
0 0 0 r
.5541 .32542 .56021 .32012 .57199 .31593 .56597 .32036 Mtetra
.56597 .32036 .57199 .31593 .58383 .31147 .57786 .31488 Mtetra
.57786 .31488 .58383 .31147 .59571 .30679 .58979 .30902 Mtetra
.396 .836 .709 r
.58979 .30902 .59571 .30679 .60763 .30198 .60175 .30288 Mtetra
.526 .919 .828 r
.60175 .30288 .60763 .30198 .61959 .29701 .61375 .29648 Mtetra
.633 .96 .911 r
.61375 .29648 .61959 .29701 .63159 .29184 .62577 .28988 Mtetra
.702 .957 .949 r
.62577 .28988 .63159 .29184 .64362 .28641 .63781 .28309 Mtetra
.738 .928 .953 r
.63781 .28309 .64362 .28641 .65569 .28064 .64989 .27612 Mtetra
.752 .892 .941 r
.64989 .27612 .65569 .28064 .66778 .27457 .66198 .269 Mtetra
.756 .859 .925 r
.66198 .269 .66778 .27457 .67989 .26817 .67411 .26176 Mtetra
.755 .832 .911 r
.67411 .26176 .67989 .26817 .69202 .2615 .68625 .25445 Mtetra
.752 .812 .9 r
.68625 .25445 .69202 .2615 .70418 .25463 .69843 .24712 Mtetra
.748 .798 .892 r
.69843 .24712 .70418 .25463 .71636 .24762 .71064 .2398 Mtetra
.744 .789 .888 r
.71064 .2398 .71636 .24762 .72857 .24055 .72288 .23254 Mtetra
.742 .784 .887 r
.72288 .23254 .72857 .24055 .74081 .23343 .73516 .22535 Mtetra
.739 .782 .887 r
.73516 .22535 .74081 .23343 .75308 .22631 .74747 .21821 Mtetra
.737 .781 .888 r
.74747 .21821 .75308 .22631 .76539 .21923 .75983 .21113 Mtetra
.557 .722 .95 r
.09551 .43462 .10283 .44102 .11239 .44012 .10516 .43308 Mtetra
.559 .701 .936 r
.10516 .43308 .11239 .44012 .12198 .4393 .11485 .43162 Mtetra
.557 .681 .922 r
.11485 .43162 .12198 .4393 .13163 .43854 .12457 .43026 Mtetra
.554 .662 .909 r
.12457 .43026 .13163 .43854 .14131 .43786 .13433 .42905 Mtetra
.548 .645 .898 r
.13433 .42905 .14131 .43786 .15105 .43725 .14412 .428 Mtetra
.543 .632 .89 r
.14412 .428 .15105 .43725 .16083 .43666 .15394 .42712 Mtetra
.536 .622 .884 r
.15394 .42712 .16083 .43666 .17068 .43607 .16381 .42638 Mtetra
.532 .617 .883 r
.16381 .42638 .17068 .43607 .18058 .43542 .17371 .42576 Mtetra
.527 .616 .884 r
.17371 .42576 .18058 .43542 .19055 .43467 .18367 .42521 Mtetra
.526 .622 .89 r
.18367 .42521 .19055 .43467 .2006 .43379 .19368 .42466 Mtetra
.526 .632 .898 r
.19368 .42466 .2006 .43379 .21071 .43275 .20376 .42404 Mtetra
.531 .647 .908 r
.20376 .42404 .21071 .43275 .2209 .43153 .21392 .42325 Mtetra
.541 .664 .917 r
.21392 .42325 .2209 .43153 .23116 .43013 .22416 .42219 Mtetra
.556 .682 .923 r
.22416 .42219 .23116 .43013 .24149 .42849 .23448 .42078 Mtetra
.575 .697 .925 r
.23448 .42078 .24149 .42849 .2519 .42658 .2449 .41894 Mtetra
.592 .707 .923 r
.2449 .41894 .2519 .42658 .26239 .42432 .25541 .41672 Mtetra
.608 .714 .92 r
.25541 .41672 .26239 .42432 .27296 .42164 .26599 .41414 Mtetra
.615 .721 .921 r
.26599 .41414 .27296 .42164 .28362 .41854 .27664 .41138 Mtetra
.616 .732 .929 r
.27664 .41138 .28362 .41854 .29435 .41504 .28734 .40855 Mtetra
.61 .753 .946 r
.28734 .40855 .29435 .41504 .30514 .41122 .29809 .40576 Mtetra
.593 .784 .971 r
.29809 .40576 .30514 .41122 .31599 .40718 .30888 .4031 Mtetra
.559 .824 .995 r
.30888 .4031 .31599 .40718 .32689 .40301 .31971 .40053 Mtetra
.491 .851 .991 r
.31971 .40053 .32689 .40301 .33784 .39879 .33059 .39803 Mtetra
.377 .833 .92 r
.33059 .39803 .33784 .39879 .34882 .39458 .34153 .39552 Mtetra
.234 .752 .774 r
.34153 .39552 .34882 .39458 .35985 .3904 .35252 .39293 Mtetra
0 0 0 r
.35252 .39293 .35985 .3904 .37091 .38629 .36358 .39018 Mtetra
.36358 .39018 .37091 .38629 .38201 .38224 .3747 .38721 Mtetra
.033 0 0 r
.3747 .38721 .38201 .38224 .39316 .37826 .38588 .38397 Mtetra
.054 0 0 r
.38588 .38397 .39316 .37826 .40434 .37435 .39712 .38042 Mtetra
.051 0 0 r
.39712 .38042 .40434 .37435 .41557 .3705 .40843 .37655 Mtetra
.026 0 0 r
.40843 .37655 .41557 .3705 .42685 .36672 .41979 .37237 Mtetra
0 0 0 r
.41979 .37237 .42685 .36672 .43817 .363 .43121 .36787 Mtetra
.43121 .36787 .43817 .363 .44953 .35935 .44267 .36311 Mtetra
.44267 .36311 .44953 .35935 .46095 .35577 .45419 .35811 Mtetra
.351 .814 .717 r
.45419 .35811 .46095 .35577 .47241 .35225 .46575 .35295 Mtetra
.495 .906 .86 r
.46575 .35295 .47241 .35225 .48393 .34878 .47735 .3477 Mtetra
.607 .938 .951 r
.47735 .3477 .48393 .34878 .49549 .3453 .48899 .34243 Mtetra
.665 .912 .978 r
.48899 .34243 .49549 .3453 .50711 .34178 .50067 .33723 Mtetra
.685 .862 .966 r
.50067 .33723 .50711 .34178 .51879 .33813 .51239 .33212 Mtetra
.687 .813 .943 r
.51239 .33212 .51879 .33813 .53051 .33424 .52415 .32713 Mtetra
.684 .777 .921 r
.52415 .32713 .53051 .33424 .54229 .33004 .53596 .32218 Mtetra
.684 .755 .905 r
.53596 .32218 .54229 .33004 .5541 .32542 .54781 .31716 Mtetra
.688 .746 .895 r
.54781 .31716 .5541 .32542 .56597 .32036 .5597 .31194 Mtetra
.698 .746 .888 r
.5597 .31194 .56597 .32036 .57786 .31488 .57163 .30635 Mtetra
.709 .748 .882 r
.57163 .30635 .57786 .31488 .58979 .30902 .58359 .30036 Mtetra
.719 .749 .875 r
.58359 .30036 .58979 .30902 .60175 .30288 .59558 .29392 Mtetra
.726 .744 .866 r
.59558 .29392 .60175 .30288 .61375 .29648 .6076 .2871 Mtetra
.73 .736 .856 r
.6076 .2871 .61375 .29648 .62577 .28988 .61963 .28 Mtetra
.73 .725 .846 r
.61963 .28 .62577 .28988 .63781 .28309 .6317 .27271 Mtetra
.727 .714 .838 r
.6317 .27271 .63781 .28309 .64989 .27612 .64379 .26533 Mtetra
.724 .705 .832 r
.64379 .26533 .64989 .27612 .66198 .269 .6559 .25793 Mtetra
.72 .698 .828 r
.6559 .25793 .66198 .269 .67411 .26176 .66805 .25061 Mtetra
.717 .696 .829 r
.66805 .25061 .67411 .26176 .68625 .25445 .68023 .24338 Mtetra
.715 .697 .832 r
.68023 .24338 .68625 .25445 .69843 .24712 .69246 .2363 Mtetra
.713 .703 .838 r
.69246 .2363 .69843 .24712 .71064 .2398 .70472 .22936 Mtetra
.712 .711 .847 r
.70472 .22936 .71064 .2398 .72288 .23254 .71703 .2226 Mtetra
.713 .724 .858 r
.71703 .2226 .72288 .23254 .73516 .22535 .72938 .21596 Mtetra
.714 .739 .871 r
.72938 .21596 .73516 .22535 .74747 .21821 .74178 .20943 Mtetra
.716 .757 .885 r
.74178 .20943 .74747 .21821 .75983 .21113 .75422 .20298 Mtetra
.62 .742 .934 r
.08813 .42819 .09551 .43462 .10516 .43308 .09795 .42548 Mtetra
.619 .706 .907 r
.09795 .42548 .10516 .43308 .11485 .43162 .1078 .42284 Mtetra
.614 .672 .882 r
.1078 .42284 .11485 .43162 .12457 .43026 .11767 .42032 Mtetra
.606 .641 .859 r
.11767 .42032 .12457 .43026 .13433 .42905 .12758 .41795 Mtetra
.597 .613 .838 r
.12758 .41795 .13433 .42905 .14412 .428 .1375 .41577 Mtetra
.589 .588 .819 r
.1375 .41577 .14412 .428 .15394 .42712 .14745 .41378 Mtetra
.581 .566 .802 r
.14745 .41378 .15394 .42712 .16381 .42638 .15742 .41201 Mtetra
.574 .548 .787 r
.15742 .41201 .16381 .42638 .17371 .42576 .16743 .41039 Mtetra
.569 .532 .774 r
.16743 .41039 .17371 .42576 .18367 .42521 .17747 .40892 Mtetra
.566 .519 .762 r
.17747 .40892 .18367 .42521 .19368 .42466 .18756 .40751 Mtetra
.565 .51 .752 r
.18756 .40751 .19368 .42466 .20376 .42404 .1977 .40611 Mtetra
.565 .502 .744 r
.1977 .40611 .20376 .42404 .21392 .42325 .2079 .40464 Mtetra
.567 .498 .737 r
.2079 .40464 .21392 .42325 .22416 .42219 .21817 .40303 Mtetra
.57 .495 .731 r
.21817 .40303 .22416 .42219 .23448 .42078 .22851 .40125 Mtetra
.574 .494 .728 r
.22851 .40125 .23448 .42078 .2449 .41894 .23892 .39928 Mtetra
.576 .495 .727 r
.23892 .39928 .2449 .41894 .25541 .41672 .24939 .39719 Mtetra
.578 .497 .728 r
.24939 .39719 .25541 .41672 .26599 .41414 .25992 .39503 Mtetra
.578 .502 .733 r
.25992 .39503 .26599 .41414 .27664 .41138 .2705 .39289 Mtetra
.577 .507 .74 r
.2705 .39289 .27664 .41138 .28734 .40855 .28113 .39082 Mtetra
.577 .515 .749 r
.28113 .39082 .28734 .40855 .29809 .40576 .29181 .38883 Mtetra
.576 .524 .759 r
.29181 .38883 .29809 .40576 .30888 .4031 .30253 .38691 Mtetra
.578 .533 .769 r
.30253 .38691 .30888 .4031 .31971 .40053 .31332 .38496 Mtetra
.581 .543 .778 r
.31332 .38496 .31971 .40053 .33059 .39803 .32416 .38294 Mtetra
.585 .553 .784 r
.32416 .38294 .33059 .39803 .34153 .39552 .33508 .38076 Mtetra
.591 .561 .789 r
.33508 .38076 .34153 .39552 .35252 .39293 .34606 .37837 Mtetra
.598 .568 .791 r
.34606 .37837 .35252 .39293 .36358 .39018 .3571 .37573 Mtetra
.606 .574 .792 r
.3571 .37573 .36358 .39018 .3747 .38721 .36822 .37279 Mtetra
.613 .579 .791 r
.36822 .37279 .3747 .38721 .38588 .38397 .3794 .36954 Mtetra
.621 .583 .79 r
.3794 .36954 .38588 .38397 .39712 .38042 .39065 .36596 Mtetra
.628 .587 .789 r
.39065 .36596 .39712 .38042 .40843 .37655 .40196 .36206 Mtetra
.635 .591 .787 r
.40196 .36206 .40843 .37655 .41979 .37237 .41333 .35783 Mtetra
.642 .594 .785 r
.41333 .35783 .41979 .37237 .43121 .36787 .42475 .35327 Mtetra
.648 .597 .783 r
.42475 .35327 .43121 .36787 .44267 .36311 .43623 .34839 Mtetra
.654 .598 .78 r
.43623 .34839 .44267 .36311 .45419 .35811 .44775 .34322 Mtetra
.658 .599 .777 r
.44775 .34322 .45419 .35811 .46575 .35295 .45932 .33778 Mtetra
.66 .597 .773 r
.45932 .33778 .46575 .35295 .47735 .3477 .47094 .33212 Mtetra
.661 .592 .768 r
.47094 .33212 .47735 .3477 .48899 .34243 .48259 .3263 Mtetra
.659 .586 .761 r
.48259 .3263 .48899 .34243 .50067 .33723 .49428 .32039 Mtetra
.656 .576 .754 r
.49428 .32039 .50067 .33723 .51239 .33212 .506 .31445 Mtetra
.65 .565 .746 r
.506 .31445 .51239 .33212 .52415 .32713 .51776 .30858 Mtetra
.645 .554 .737 r
.51776 .30858 .52415 .32713 .53596 .32218 .52956 .30276 Mtetra
.64 .544 .73 r
.52956 .30276 .53596 .32218 .54781 .31716 .5414 .29702 Mtetra
.636 .536 .724 r
.5414 .29702 .54781 .31716 .5597 .31194 .55327 .2913 Mtetra
.635 .532 .72 r
.55327 .2913 .5597 .31194 .57163 .30635 .56519 .28549 Mtetra
.636 .531 .718 r
.56519 .28549 .57163 .30635 .58359 .30036 .57714 .27955 Mtetra
.639 .533 .718 r
.57714 .27955 .58359 .30036 .59558 .29392 .58912 .2734 Mtetra
.643 .538 .72 r
.58912 .2734 .59558 .29392 .6076 .2871 .60114 .26707 Mtetra
.648 .545 .724 r
.60114 .26707 .6076 .2871 .61963 .28 .61319 .26059 Mtetra
.652 .552 .73 r
.61319 .26059 .61963 .28 .6317 .27271 .62527 .25402 Mtetra
.655 .561 .737 r
.62527 .25402 .6317 .27271 .64379 .26533 .63739 .24746 Mtetra
.658 .571 .745 r
.63739 .24746 .64379 .26533 .6559 .25793 .64955 .24095 Mtetra
.661 .582 .756 r
.64955 .24095 .6559 .25793 .66805 .25061 .66175 .23457 Mtetra
.663 .594 .768 r
.66175 .23457 .66805 .25061 .68023 .24338 .67399 .22836 Mtetra
.665 .609 .782 r
.67399 .22836 .68023 .24338 .69246 .2363 .68628 .22234 Mtetra
.667 .626 .799 r
.68628 .22234 .69246 .2363 .70472 .22936 .69863 .21652 Mtetra
.67 .646 .817 r
.69863 .21652 .70472 .22936 .71703 .2226 .71103 .2109 Mtetra
.673 .669 .839 r
.71103 .2109 .71703 .2226 .72938 .21596 .72349 .20542 Mtetra
.676 .697 .862 r
.72349 .20542 .72938 .21596 .74178 .20943 .736 .20005 Mtetra
.679 .728 .886 r
.736 .20005 .74178 .20943 .75422 .20298 .74857 .19475 Mtetra
.678 .756 .91 r
.0807 .4217 .08813 .42819 .09795 .42548 .09072 .4176 Mtetra
.671 .715 .882 r
.09072 .4176 .09795 .42548 .1078 .42284 .10077 .41355 Mtetra
.661 .677 .855 r
.10077 .41355 .1078 .42284 .11767 .42032 .11084 .40959 Mtetra
.65 .643 .83 r
.11084 .40959 .11767 .42032 .12758 .41795 .12093 .40576 Mtetra
.637 .612 .807 r
.12093 .40576 .12758 .41795 .1375 .41577 .13103 .40211 Mtetra
.626 .584 .787 r
.13103 .40211 .1375 .41577 .14745 .41378 .14115 .39863 Mtetra
.615 .559 .768 r
.14115 .39863 .14745 .41378 .15742 .41201 .15129 .39536 Mtetra
.606 .537 .751 r
.15129 .39536 .15742 .41201 .16743 .41039 .16145 .39225 Mtetra
.598 .518 .736 r
.16145 .39225 .16743 .41039 .17747 .40892 .17163 .38929 Mtetra
.591 .502 .722 r
.17163 .38929 .17747 .40892 .18756 .40751 .18185 .38645 Mtetra
.586 .488 .71 r
.18185 .38645 .18756 .40751 .1977 .40611 .1921 .38368 Mtetra
.582 .477 .7 r
.1921 .38368 .1977 .40611 .2079 .40464 .20239 .38098 Mtetra
.578 .467 .691 r
.20239 .38098 .2079 .40464 .21817 .40303 .21273 .37834 Mtetra
.574 .459 .685 r
.21273 .37834 .21817 .40303 .22851 .40125 .2231 .37581 Mtetra
.57 .453 .68 r
.2231 .37581 .22851 .40125 .23892 .39928 .2335 .37341 Mtetra
.566 .449 .678 r
.2335 .37341 .23892 .39928 .24939 .39719 .24394 .3712 Mtetra
.563 .446 .678 r
.24394 .3712 .24939 .39719 .25992 .39503 .25442 .3692 Mtetra
.561 .446 .679 r
.25442 .3692 .25992 .39503 .2705 .39289 .26494 .36734 Mtetra
.559 .447 .682 r
.26494 .36734 .2705 .39289 .28113 .39082 .2755 .36556 Mtetra
.56 .449 .684 r
.2755 .36556 .28113 .39082 .29181 .38883 .28612 .36374 Mtetra
.563 .452 .685 r
.28612 .36374 .29181 .38883 .30253 .38691 .29682 .36178 Mtetra
.566 .454 .685 r
.29682 .36178 .30253 .38691 .31332 .38496 .30758 .3596 Mtetra
.57 .456 .684 r
.30758 .3596 .31332 .38496 .32416 .38294 .31841 .35715 Mtetra
.574 .457 .681 r
.31841 .35715 .32416 .38294 .33508 .38076 .32931 .35443 Mtetra
.577 .456 .678 r
.32931 .35443 .33508 .38076 .34606 .37837 .34029 .35143 Mtetra
.58 .455 .675 r
.34029 .35143 .34606 .37837 .3571 .37573 .35132 .3482 Mtetra
.581 .454 .672 r
.35132 .3482 .3571 .37573 .36822 .37279 .36242 .34475 Mtetra
.583 .453 .669 r
.36242 .34475 .36822 .37279 .3794 .36954 .37358 .34111 Mtetra
.584 .453 .667 r
.37358 .34111 .3794 .36954 .39065 .36596 .38479 .33731 Mtetra
.586 .453 .666 r
.38479 .33731 .39065 .36596 .40196 .36206 .39605 .33336 Mtetra
.588 .454 .666 r
.39605 .33336 .40196 .36206 .41333 .35783 .40737 .32925 Mtetra
.59 .456 .667 r
.40737 .32925 .41333 .35783 .42475 .35327 .41874 .32498 Mtetra
.593 .46 .668 r
.41874 .32498 .42475 .35327 .43623 .34839 .43016 .32053 Mtetra
.597 .464 .671 r
.43016 .32053 .43623 .34839 .44775 .34322 .44163 .31585 Mtetra
.601 .469 .673 r
.44163 .31585 .44775 .34322 .45932 .33778 .45315 .31093 Mtetra
.606 .475 .676 r
.45315 .31093 .45932 .33778 .47094 .33212 .46472 .30572 Mtetra
.611 .48 .678 r
.46472 .30572 .47094 .33212 .48259 .3263 .47633 .30024 Mtetra
.615 .485 .68 r
.47633 .30024 .48259 .3263 .49428 .32039 .48798 .29448 Mtetra
.619 .488 .681 r
.48798 .29448 .49428 .32039 .506 .31445 .49967 .28849 Mtetra
.62 .489 .68 r
.49967 .28849 .506 .31445 .51776 .30858 .5114 .28234 Mtetra
.62 .488 .679 r
.5114 .28234 .51776 .30858 .52956 .30276 .52317 .27615 Mtetra
.618 .484 .677 r
.52317 .27615 .52956 .30276 .5414 .29702 .53497 .27003 Mtetra
.615 .481 .675 r
.53497 .27003 .5414 .29702 .55327 .2913 .5468 .26404 Mtetra
.611 .477 .675 r
.5468 .26404 .55327 .2913 .56519 .28549 .55868 .25827 Mtetra
.609 .476 .675 r
.55868 .25827 .56519 .28549 .57714 .27955 .5706 .25267 Mtetra
.608 .477 .678 r
.5706 .25267 .57714 .27955 .58912 .2734 .58256 .24721 Mtetra
.608 .481 .682 r
.58256 .24721 .58912 .2734 .60114 .26707 .59457 .24185 Mtetra
.61 .488 .688 r
.59457 .24185 .60114 .26707 .61319 .26059 .60662 .23654 Mtetra
.613 .496 .696 r
.60662 .23654 .61319 .26059 .62527 .25402 .61872 .2313 Mtetra
.616 .507 .706 r
.61872 .2313 .62527 .25402 .63739 .24746 .63087 .22614 Mtetra
.619 .519 .718 r
.63087 .22614 .63739 .24746 .64955 .24095 .64307 .22108 Mtetra
.621 .532 .732 r
.64307 .22108 .64955 .24095 .66175 .23457 .65532 .21617 Mtetra
.624 .547 .748 r
.65532 .21617 .66175 .23457 .67399 .22836 .66764 .21143 Mtetra
.626 .565 .766 r
.66764 .21143 .67399 .22836 .68628 .22234 .68001 .20689 Mtetra
.628 .585 .786 r
.68001 .20689 .68628 .22234 .69863 .21652 .69245 .20254 Mtetra
.63 .608 .809 r
.69245 .20254 .69863 .21652 .71103 .2109 .70496 .19836 Mtetra
.632 .634 .835 r
.70496 .19836 .71103 .2109 .72349 .20542 .71753 .19432 Mtetra
.633 .666 .863 r
.71753 .19432 .72349 .20542 .736 .20005 .73017 .19037 Mtetra
.634 .701 .894 r
.73017 .19037 .736 .20005 .74857 .19475 .74288 .18646 Mtetra
.72 .764 .887 r
.07322 .41517 .0807 .4217 .09072 .4176 .08344 .40972 Mtetra
.71 .726 .863 r
.08344 .40972 .09072 .4176 .10077 .41355 .09368 .4043 Mtetra
.699 .691 .839 r
.09368 .4043 .10077 .41355 .11084 .40959 .10395 .39894 Mtetra
.686 .659 .818 r
.10395 .39894 .11084 .40959 .12093 .40576 .11423 .39368 Mtetra
.673 .63 .798 r
.11423 .39368 .12093 .40576 .13103 .40211 .12452 .38857 Mtetra
.66 .603 .78 r
.12452 .38857 .13103 .40211 .14115 .39863 .13481 .38363 Mtetra
.648 .578 .763 r
.13481 .38363 .14115 .39863 .15129 .39536 .14512 .37888 Mtetra
.636 .556 .747 r
.14512 .37888 .15129 .39536 .16145 .39225 .15543 .37433 Mtetra
.626 .537 .734 r
.15543 .37433 .16145 .39225 .17163 .38929 .16576 .36997 Mtetra
.617 .52 .721 r
.16576 .36997 .17163 .38929 .18185 .38645 .1761 .3658 Mtetra
.609 .505 .711 r
.1761 .3658 .18185 .38645 .1921 .38368 .18646 .36181 Mtetra
.602 .493 .702 r
.18646 .36181 .1921 .38368 .20239 .38098 .19684 .35799 Mtetra
.596 .482 .694 r
.19684 .35799 .20239 .38098 .21273 .37834 .20724 .35436 Mtetra
.59 .473 .688 r
.20724 .35436 .21273 .37834 .2231 .37581 .21767 .35091 Mtetra
.585 .465 .682 r
.21767 .35091 .2231 .37581 .2335 .37341 .22812 .34764 Mtetra
.58 .458 .677 r
.22812 .34764 .2335 .37341 .24394 .3712 .2386 .34452 Mtetra
.577 .451 .673 r
.2386 .34452 .24394 .3712 .25442 .3692 .24911 .34151 Mtetra
.574 .446 .667 r
.24911 .34151 .25442 .3692 .26494 .36734 .25968 .33851 Mtetra
.573 .44 .662 r
.25968 .33851 .26494 .36734 .2755 .36556 .27029 .33545 Mtetra
.573 .435 .656 r
.27029 .33545 .2755 .36556 .28612 .36374 .28097 .33226 Mtetra
.573 .431 .65 r
.28097 .33226 .28612 .36374 .29682 .36178 .2917 .32888 Mtetra
.573 .426 .644 r
.2917 .32888 .29682 .36178 .30758 .3596 .30249 .32533 Mtetra
.573 .422 .639 r
.30249 .32533 .30758 .3596 .31841 .35715 .31334 .32161 Mtetra
.572 .419 .635 r
.31334 .32161 .31841 .35715 .32931 .35443 .32425 .31776 Mtetra
.572 .416 .631 r
.32425 .31776 .32931 .35443 .34029 .35143 .3352 .31382 Mtetra
.571 .413 .628 r
.3352 .31382 .34029 .35143 .35132 .3482 .3462 .30982 Mtetra
.57 .411 .626 r
.3462 .30982 .35132 .3482 .36242 .34475 .35725 .30578 Mtetra
.569 .409 .624 r
.35725 .30578 .36242 .34475 .37358 .34111 .36834 .30175 Mtetra
.569 .408 .623 r
.36834 .30175 .37358 .34111 .38479 .33731 .37948 .29772 Mtetra
.568 .407 .623 r
.37948 .29772 .38479 .33731 .39605 .33336 .39066 .29371 Mtetra
.39066 .29371 .39605 .33336 .40737 .32925 .40188 .28972 Mtetra
.40188 .28972 .40737 .32925 .41874 .32498 .41316 .28574 Mtetra
.568 .408 .624 r
.41316 .28574 .41874 .32498 .43016 .32053 .42448 .28175 Mtetra
.569 .41 .626 r
.42448 .28175 .43016 .32053 .44163 .31585 .43585 .27773 Mtetra
.57 .412 .628 r
.43585 .27773 .44163 .31585 .45315 .31093 .44727 .27366 Mtetra
.572 .416 .631 r
.44727 .27366 .45315 .31093 .46472 .30572 .45873 .26948 Mtetra
.575 .421 .634 r
.45873 .26948 .46472 .30572 .47633 .30024 .47025 .26518 Mtetra
.579 .426 .639 r
.47025 .26518 .47633 .30024 .48798 .29448 .48182 .2607 Mtetra
.583 .433 .644 r
.48182 .2607 .48798 .29448 .49967 .28849 .49344 .25604 Mtetra
.587 .44 .649 r
.49344 .25604 .49967 .28849 .5114 .28234 .5051 .25119 Mtetra
.591 .448 .655 r
.5051 .25119 .5114 .28234 .52317 .27615 .51681 .2462 Mtetra
.595 .455 .661 r
.51681 .2462 .52317 .27615 .53497 .27003 .52856 .24114 Mtetra
.597 .46 .666 r
.52856 .24114 .53497 .27003 .5468 .26404 .54036 .23609 Mtetra
.598 .465 .671 r
.54036 .23609 .5468 .26404 .55868 .25827 .5522 .23115 Mtetra
.598 .469 .676 r
.5522 .23115 .55868 .25827 .5706 .25267 .56409 .22636 Mtetra
.597 .473 .682 r
.56409 .22636 .5706 .25267 .58256 .24721 .57604 .22175 Mtetra
.596 .477 .687 r
.57604 .22175 .58256 .24721 .59457 .24185 .58803 .21732 Mtetra
.596 .482 .694 r
.58803 .21732 .59457 .24185 .60662 .23654 .60008 .21308 Mtetra
.596 .489 .703 r
.60008 .21308 .60662 .23654 .61872 .2313 .61219 .20901 Mtetra
.596 .497 .712 r
.61219 .20901 .61872 .2313 .63087 .22614 .62436 .20513 Mtetra
.596 .507 .724 r
.62436 .20513 .63087 .22614 .64307 .22108 .6366 .20144 Mtetra
.596 .519 .738 r
.6366 .20144 .64307 .22108 .65532 .21617 .6489 .19795 Mtetra
.596 .533 .755 r
.6489 .19795 .65532 .21617 .66764 .21143 .66128 .19466 Mtetra
.595 .55 .774 r
.66128 .19466 .66764 .21143 .68001 .20689 .67372 .19158 Mtetra
.595 .569 .795 r
.67372 .19158 .68001 .20689 .69245 .20254 .68625 .18866 Mtetra
.593 .591 .819 r
.68625 .18866 .69245 .20254 .70496 .19836 .69885 .1859 Mtetra
.592 .617 .846 r
.69885 .1859 .70496 .19836 .71753 .19432 .71154 .18325 Mtetra
.59 .646 .874 r
.71154 .18325 .71753 .19432 .73017 .19037 .7243 .18066 Mtetra
.586 .68 .905 r
.7243 .18066 .73017 .19037 .74288 .18646 .73713 .1781 Mtetra
.747 .767 .869 r
.06568 .40859 .07322 .41517 .08344 .40972 .07607 .40207 Mtetra
.738 .738 .852 r
.07607 .40207 .08344 .40972 .09368 .4043 .08649 .39555 Mtetra
.728 .711 .835 r
.08649 .39555 .09368 .4043 .10395 .39894 .09692 .38907 Mtetra
.717 .685 .819 r
.09692 .38907 .10395 .39894 .11423 .39368 .10736 .38266 Mtetra
.705 .661 .803 r
.10736 .38266 .11423 .39368 .12452 .38857 .11781 .37636 Mtetra
.693 .637 .789 r
.11781 .37636 .12452 .38857 .13481 .38363 .12826 .3702 Mtetra
.681 .615 .775 r
.12826 .3702 .13481 .38363 .14512 .37888 .13872 .36423 Mtetra
.669 .594 .762 r
.13872 .36423 .14512 .37888 .15543 .37433 .14918 .35846 Mtetra
.658 .574 .75 r
.14918 .35846 .15543 .37433 .16576 .36997 .15963 .35292 Mtetra
.647 .557 .739 r
.15963 .35292 .16576 .36997 .1761 .3658 .17009 .34763 Mtetra
.637 .541 .73 r
.17009 .34763 .1761 .3658 .18646 .36181 .18055 .34258 Mtetra
.628 .528 .721 r
.18055 .34258 .18646 .36181 .19684 .35799 .19102 .33776 Mtetra
.62 .515 .713 r
.19102 .33776 .19684 .35799 .20724 .35436 .20149 .33317 Mtetra
.614 .505 .706 r
.20149 .33317 .20724 .35436 .21767 .35091 .21199 .32872 Mtetra
.609 .495 .699 r
.21199 .32872 .21767 .35091 .22812 .34764 .22252 .32438 Mtetra
.605 .487 .692 r
.22252 .32438 .22812 .34764 .2386 .34452 .23308 .32004 Mtetra
.603 .479 .684 r
.23308 .32004 .2386 .34452 .24911 .34151 .24369 .31562 Mtetra
.601 .471 .675 r
.24369 .31562 .24911 .34151 .25968 .33851 .25435 .31106 Mtetra
.599 .463 .667 r
.25435 .31106 .25968 .33851 .27029 .33545 .26506 .30631 Mtetra
.597 .454 .658 r
.26506 .30631 .27029 .33545 .28097 .33226 .27582 .30142 Mtetra
.594 .447 .651 r
.27582 .30142 .28097 .33226 .2917 .32888 .28662 .29643 Mtetra
.59 .439 .644 r
.28662 .29643 .2917 .32888 .30249 .32533 .29745 .29142 Mtetra
.587 .432 .639 r
.29745 .29142 .30249 .32533 .31334 .32161 .30833 .28646 Mtetra
.583 .427 .635 r
.30833 .28646 .31334 .32161 .32425 .31776 .31923 .28159 Mtetra
.58 .422 .631 r
.31923 .28159 .32425 .31776 .3352 .31382 .33016 .27684 Mtetra
.577 .418 .629 r
.33016 .27684 .3352 .31382 .3462 .30982 .34112 .27224 Mtetra
.575 .415 .627 r
.34112 .27224 .3462 .30982 .35725 .30578 .35211 .26778 Mtetra
.572 .412 .626 r
.35211 .26778 .35725 .30578 .36834 .30175 .36314 .26346 Mtetra
.571 .41 .625 r
.36314 .26346 .36834 .30175 .37948 .29772 .3742 .25927 Mtetra
.569 .409 .625 r
.3742 .25927 .37948 .29772 .39066 .29371 .3853 .2552 Mtetra
.567 .408 .625 r
.3853 .2552 .39066 .29371 .40188 .28972 .39644 .25126 Mtetra
.566 .407 .625 r
.39644 .25126 .40188 .28972 .41316 .28574 .40763 .24746 Mtetra
.565 .407 .626 r
.40763 .24746 .41316 .28574 .42448 .28175 .41885 .24379 Mtetra
.563 .407 .627 r
.41885 .24379 .42448 .28175 .43585 .27773 .43013 .24027 Mtetra
.562 .407 .629 r
.43013 .24027 .43585 .27773 .44727 .27366 .44145 .23689 Mtetra
.561 .409 .631 r
.44145 .23689 .44727 .27366 .45873 .26948 .45281 .23364 Mtetra
.561 .411 .635 r
.45281 .23364 .45873 .26948 .47025 .26518 .46424 .23049 Mtetra
.562 .415 .639 r
.46424 .23049 .47025 .26518 .48182 .2607 .47571 .22738 Mtetra
.564 .421 .645 r
.47571 .22738 .48182 .2607 .49344 .25604 .48725 .22426 Mtetra
.567 .429 .652 r
.48725 .22426 .49344 .25604 .5051 .25119 .49884 .22103 Mtetra
.572 .438 .66 r
.49884 .22103 .5051 .25119 .51681 .2462 .51049 .21767 Mtetra
.577 .448 .668 r
.51049 .21767 .51681 .2462 .52856 .24114 .5222 .21411 Mtetra
.582 .458 .677 r
.5222 .21411 .52856 .24114 .54036 .23609 .53396 .21041 Mtetra
.586 .468 .685 r
.53396 .21041 .54036 .23609 .5522 .23115 .54577 .20663 Mtetra
.589 .476 .694 r
.54577 .20663 .5522 .23115 .56409 .22636 .55765 .20284 Mtetra
.589 .483 .701 r
.55765 .20284 .56409 .22636 .57604 .22175 .56957 .19916 Mtetra
.589 .49 .709 r
.56957 .19916 .57604 .22175 .58803 .21732 .58156 .19564 Mtetra
.587 .495 .718 r
.58156 .19564 .58803 .21732 .60008 .21308 .59362 .19234 Mtetra
.585 .502 .727 r
.59362 .19234 .60008 .21308 .61219 .20901 .60574 .18928 Mtetra
.582 .509 .738 r
.60574 .18928 .61219 .20901 .62436 .20513 .61793 .18648 Mtetra
.579 .518 .751 r
.61793 .18648 .62436 .20513 .6366 .20144 .6302 .18392 Mtetra
.576 .529 .766 r
.6302 .18392 .6366 .20144 .6489 .19795 .64254 .18161 Mtetra
.572 .542 .783 r
.64254 .18161 .6489 .19795 .66128 .19466 .65497 .17951 Mtetra
.568 .557 .801 r
.65497 .17951 .66128 .19466 .67372 .19158 .66749 .17761 Mtetra
.564 .574 .822 r
.66749 .17761 .67372 .19158 .68625 .18866 .68008 .17586 Mtetra
.56 .594 .844 r
.68008 .17586 .68625 .18866 .69885 .1859 .69277 .17424 Mtetra
.555 .615 .868 r
.69277 .17424 .69885 .1859 .71154 .18325 .70554 .17269 Mtetra
.549 .639 .892 r
.70554 .17269 .71154 .18325 .7243 .18066 .7184 .17118 Mtetra
.542 .665 .917 r
.7184 .17118 .7243 .18066 .73713 .1781 .73134 .16968 Mtetra
.756 .768 .862 r
.05808 .40196 .06568 .40859 .07607 .40207 .06857 .39498 Mtetra
.753 .756 .855 r
.06857 .39498 .07607 .40207 .08649 .39555 .07907 .38799 Mtetra
.748 .744 .848 r
.07907 .38799 .08649 .39555 .09692 .38907 .0896 .38101 Mtetra
.743 .732 .842 r
.0896 .38101 .09692 .38907 .10736 .38266 .10013 .37407 Mtetra
.737 .719 .835 r
.10013 .37407 .10736 .38266 .11781 .37636 .11067 .36722 Mtetra
.729 .706 .828 r
.11067 .36722 .11781 .37636 .12826 .3702 .12122 .36047 Mtetra
.721 .692 .822 r
.12122 .36047 .12826 .3702 .13872 .36423 .13177 .35386 Mtetra
.713 .678 .814 r
.13177 .35386 .13872 .36423 .14918 .35846 .14232 .34742 Mtetra
.704 .663 .807 r
.14232 .34742 .14918 .35846 .15963 .35292 .15287 .34116 Mtetra
.694 .647 .798 r
.15287 .34116 .15963 .35292 .17009 .34763 .16343 .33507 Mtetra
.685 .631 .79 r
.16343 .33507 .17009 .34763 .18055 .34258 .17399 .32917 Mtetra
.676 .615 .78 r
.17399 .32917 .18055 .34258 .19102 .33776 .18457 .32341 Mtetra
.668 .599 .769 r
.18457 .32341 .19102 .33776 .20149 .33317 .19515 .31778 Mtetra
.66 .583 .758 r
.19515 .31778 .20149 .33317 .21199 .32872 .20576 .31221 Mtetra
.653 .567 .746 r
.20576 .31221 .21199 .32872 .22252 .32438 .2164 .30667 Mtetra
.647 .553 .734 r
.2164 .30667 .22252 .32438 .23308 .32004 .22706 .30112 Mtetra
.641 .539 .723 r
.22706 .30112 .23308 .32004 .24369 .31562 .23777 .29553 Mtetra
.636 .527 .713 r
.23777 .29553 .24369 .31562 .25435 .31106 .2485 .28993 Mtetra
.631 .517 .706 r
.2485 .28993 .25435 .31106 .26506 .30631 .25926 .28435 Mtetra
.626 .509 .7 r
.25926 .28435 .26506 .30631 .27582 .30142 .27004 .27887 Mtetra
.621 .502 .696 r
.27004 .27887 .27582 .30142 .28662 .29643 .28084 .27355 Mtetra
.617 .498 .694 r
.28084 .27355 .28662 .29643 .29745 .29142 .29167 .26842 Mtetra
.613 .495 .694 r
.29167 .26842 .29745 .29142 .30833 .28646 .30251 .2635 Mtetra
.61 .493 .695 r
.30251 .2635 .30833 .28646 .31923 .28159 .31337 .25878 Mtetra
.607 .493 .697 r
.31337 .25878 .31923 .28159 .33016 .27684 .32426 .25425 Mtetra
.606 .493 .699 r
.32426 .25425 .33016 .27684 .34112 .27224 .33518 .24986 Mtetra
.604 .494 .701 r
.33518 .24986 .34112 .27224 .35211 .26778 .34614 .24559 Mtetra
.603 .495 .703 r
.34614 .24559 .35211 .26778 .36314 .26346 .35714 .24139 Mtetra
.603 .495 .704 r
.35714 .24139 .36314 .26346 .3742 .25927 .36817 .23724 Mtetra
.602 .496 .705 r
.36817 .23724 .3742 .25927 .3853 .2552 .37925 .23313 Mtetra
.601 .495 .705 r
.37925 .23313 .3853 .2552 .39644 .25126 .39037 .22907 Mtetra
.6 .494 .705 r
.39037 .22907 .39644 .25126 .40763 .24746 .40154 .22505 Mtetra
.598 .491 .704 r
.40154 .22505 .40763 .24746 .41885 .24379 .41275 .22112 Mtetra
.595 .488 .702 r
.41275 .22112 .41885 .24379 .43013 .24027 .424 .21729 Mtetra
.591 .484 .701 r
.424 .21729 .43013 .24027 .44145 .23689 .4353 .21362 Mtetra
.587 .48 .699 r
.4353 .21362 .44145 .23689 .45281 .23364 .44665 .21013 Mtetra
.583 .476 .698 r
.44665 .21013 .45281 .23364 .46424 .23049 .45804 .20683 Mtetra
.579 .473 .698 r
.45804 .20683 .46424 .23049 .47571 .22738 .46949 .20376 Mtetra
.576 .472 .699 r
.46949 .20376 .47571 .22738 .48725 .22426 .48099 .20089 Mtetra
.573 .472 .701 r
.48099 .20089 .48725 .22426 .49884 .22103 .49254 .19818 Mtetra
.572 .475 .706 r
.49254 .19818 .49884 .22103 .51049 .21767 .50416 .19558 Mtetra
.573 .482 .713 r
.50416 .19558 .51049 .21767 .5222 .21411 .51584 .19299 Mtetra
.575 .49 .722 r
.51584 .19299 .5222 .21411 .53396 .21041 .52758 .1904 Mtetra
.578 .502 .733 r
.52758 .1904 .53396 .21041 .54577 .20663 .53939 .18777 Mtetra
.58 .515 .746 r
.53939 .18777 .54577 .20663 .55765 .20284 .55126 .18513 Mtetra
.582 .528 .76 r
.55126 .18513 .55765 .20284 .56957 .19916 .5632 .18252 Mtetra
.582 .541 .774 r
.5632 .18252 .56957 .19916 .58156 .19564 .5752 .17999 Mtetra
.581 .554 .789 r
.5752 .17999 .58156 .19564 .59362 .19234 .58728 .17758 Mtetra
.578 .566 .804 r
.58728 .17758 .59362 .19234 .60574 .18928 .59942 .17533 Mtetra
.574 .577 .818 r
.59942 .17533 .60574 .18928 .61793 .18648 .61165 .17327 Mtetra
.568 .588 .833 r
.61165 .17327 .61793 .18648 .6302 .18392 .62395 .17139 Mtetra
.561 .598 .847 r
.62395 .17139 .6302 .18392 .64254 .18161 .63634 .1697 Mtetra
.554 .608 .861 r
.63634 .1697 .64254 .18161 .65497 .17951 .64881 .16819 Mtetra
.547 .618 .875 r
.64881 .16819 .65497 .17951 .66749 .17761 .66137 .16683 Mtetra
.54 .628 .888 r
.66137 .16683 .66749 .17761 .68008 .17586 .67401 .16559 Mtetra
.533 .638 .9 r
.67401 .16559 .68008 .17586 .69277 .17424 .68675 .16444 Mtetra
.527 .649 .912 r
.68675 .16444 .69277 .17424 .70554 .17269 .69958 .16334 Mtetra
.521 .66 .923 r
.69958 .16334 .70554 .17269 .7184 .17118 .7125 .16227 Mtetra
.517 .671 .933 r
.7125 .16227 .7184 .17118 .73134 .16968 .7255 .16118 Mtetra
.754 .768 .864 r
.05043 .39529 .05808 .40196 .06857 .39498 .06093 .38838 Mtetra
.755 .771 .866 r
.06093 .38838 .06857 .39498 .07907 .38799 .07146 .38145 Mtetra
.756 .773 .868 r
.07146 .38145 .07907 .38799 .0896 .38101 .082 .37452 Mtetra
.756 .776 .87 r
.082 .37452 .0896 .38101 .10013 .37407 .09256 .36761 Mtetra
.755 .777 .871 r
.09256 .36761 .10013 .37407 .11067 .36722 .10313 .36074 Mtetra
.753 .778 .873 r
.10313 .36074 .11067 .36722 .12122 .36047 .11371 .35394 Mtetra
.751 .777 .874 r
.11371 .35394 .12122 .36047 .13177 .35386 .1243 .34723 Mtetra
.747 .774 .875 r
.1243 .34723 .13177 .35386 .14232 .34742 .13491 .34061 Mtetra
.743 .77 .875 r
.13491 .34061 .14232 .34742 .15287 .34116 .14552 .3341 Mtetra
.739 .763 .872 r
.14552 .3341 .15287 .34116 .16343 .33507 .15614 .32768 Mtetra
.735 .754 .868 r
.15614 .32768 .16343 .33507 .17399 .32917 .16677 .32133 Mtetra
.73 .743 .862 r
.16677 .32133 .17399 .32917 .18457 .32341 .17743 .31502 Mtetra
.725 .728 .853 r
.17743 .31502 .18457 .32341 .19515 .31778 .18811 .30872 Mtetra
.72 .712 .842 r
.18811 .30872 .19515 .31778 .20576 .31221 .19882 .30242 Mtetra
.714 .695 .831 r
.19882 .30242 .20576 .31221 .2164 .30667 .20955 .2961 Mtetra
.707 .678 .819 r
.20955 .2961 .2164 .30667 .22706 .30112 .2203 .28982 Mtetra
.7 .662 .809 r
.2203 .28982 .22706 .30112 .23777 .29553 .23107 .28361 Mtetra
.691 .648 .802 r
.23107 .28361 .23777 .29553 .2485 .28993 .24186 .27758 Mtetra
.682 .638 .799 r
.24186 .27758 .2485 .28993 .25926 .28435 .25265 .27181 Mtetra
.674 .632 .799 r
.25265 .27181 .25926 .28435 .27004 .27887 .26344 .26635 Mtetra
.666 .629 .803 r
.26344 .26635 .27004 .27887 .28084 .27355 .27423 .26127 Mtetra
.659 .631 .81 r
.27423 .26127 .28084 .27355 .29167 .26842 .28503 .25651 Mtetra
.654 .635 .819 r
.28503 .25651 .29167 .26842 .30251 .2635 .29585 .25204 Mtetra
.65 .643 .829 r
.29585 .25204 .30251 .2635 .31337 .25878 .30669 .24779 Mtetra
.648 .652 .84 r
.30669 .24779 .31337 .25878 .32426 .25425 .31757 .24368 Mtetra
.648 .661 .85 r
.31757 .24368 .32426 .25425 .33518 .24986 .32848 .23966 Mtetra
.648 .67 .858 r
.32848 .23966 .33518 .24986 .34614 .24559 .33944 .23566 Mtetra
.65 .678 .864 r
.33944 .23566 .34614 .24559 .35714 .24139 .35044 .23164 Mtetra
.651 .684 .868 r
.35044 .23164 .35714 .24139 .36817 .23724 .36149 .22757 Mtetra
.653 .687 .869 r
.36149 .22757 .36817 .23724 .37925 .23313 .37259 .22343 Mtetra
.655 .688 .869 r
.37259 .22343 .37925 .23313 .39037 .22907 .38374 .21922 Mtetra
.656 .686 .866 r
.38374 .21922 .39037 .22907 .40154 .22505 .39494 .21496 Mtetra
.655 .68 .862 r
.39494 .21496 .40154 .22505 .41275 .22112 .40618 .21068 Mtetra
.652 .672 .856 r
.40618 .21068 .41275 .22112 .424 .21729 .41747 .20642 Mtetra
.648 .661 .85 r
.41747 .20642 .424 .21729 .4353 .21362 .4288 .20225 Mtetra
.641 .649 .842 r
.4288 .20225 .4353 .21362 .44665 .21013 .44018 .19822 Mtetra
.632 .635 .835 r
.44018 .19822 .44665 .21013 .45804 .20683 .4516 .1944 Mtetra
.621 .62 .828 r
.4516 .1944 .45804 .20683 .46949 .20376 .46306 .19089 Mtetra
.61 .607 .823 r
.46306 .19089 .46949 .20376 .48099 .20089 .47457 .1877 Mtetra
.598 .597 .821 r
.47457 .1877 .48099 .20089 .49254 .19818 .48614 .18489 Mtetra
.588 .59 .822 r
.48614 .18489 .49254 .19818 .50416 .19558 .49776 .18241 Mtetra
.58 .589 .826 r
.49776 .18241 .50416 .19558 .51584 .19299 .50945 .18019 Mtetra
.574 .594 .835 r
.50945 .18019 .51584 .19299 .52758 .1904 .5212 .17816 Mtetra
.572 .604 .846 r
.5212 .17816 .52758 .1904 .53939 .18777 .53302 .17621 Mtetra
.57 .618 .861 r
.53302 .17621 .53939 .18777 .55126 .18513 .54491 .17429 Mtetra
.568 .635 .877 r
.54491 .17429 .55126 .18513 .5632 .18252 .55688 .17237 Mtetra
.566 .651 .893 r
.55688 .17237 .5632 .18252 .5752 .17999 .56891 .17045 Mtetra
.563 .667 .908 r
.56891 .17045 .5752 .17999 .58728 .17758 .58102 .16855 Mtetra
.557 .679 .92 r
.58102 .16855 .58728 .17758 .59942 .17533 .59321 .16668 Mtetra
.55 .689 .931 r
.59321 .16668 .59942 .17533 .61165 .17327 .60547 .1649 Mtetra
.543 .695 .939 r
.60547 .1649 .61165 .17327 .62395 .17139 .61781 .16322 Mtetra
.534 .698 .944 r
.61781 .16322 .62395 .17139 .63634 .1697 .63023 .16165 Mtetra
.527 .699 .948 r
.63023 .16165 .63634 .1697 .64881 .16819 .64274 .16018 Mtetra
.521 .698 .95 r
.64274 .16018 .64881 .16819 .66137 .16683 .65533 .15881 Mtetra
.516 .697 .951 r
.65533 .15881 .66137 .16683 .67401 .16559 .66801 .15752 Mtetra
.514 .695 .951 r
.66801 .15752 .67401 .16559 .68675 .16444 .68078 .15627 Mtetra
.513 .692 .949 r
.68078 .15627 .68675 .16444 .69958 .16334 .69364 .15506 Mtetra
.513 .69 .948 r
.69364 .15506 .69958 .16334 .7125 .16227 .70658 .15384 Mtetra
.515 .688 .945 r
.70658 .15384 .7125 .16227 .7255 .16118 .71961 .15261 Mtetra
.738 .766 .876 r
.04273 .38856 .05043 .39529 .06093 .38838 .05316 .38232 Mtetra
.743 .787 .888 r
.05316 .38232 .06093 .38838 .07146 .38145 .06362 .37604 Mtetra
.748 .807 .9 r
.06362 .37604 .07146 .38145 .082 .37452 .0741 .36974 Mtetra
.751 .828 .911 r
.0741 .36974 .082 .37452 .09256 .36761 .08461 .36343 Mtetra
.753 .849 .922 r
.08461 .36343 .09256 .36761 .10313 .36074 .09514 .35713 Mtetra
.753 .869 .932 r
.09514 .35713 .10313 .36074 .11371 .35394 .10569 .35084 Mtetra
.751 .887 .941 r
.10569 .35084 .11371 .35394 .1243 .34723 .11626 .34461 Mtetra
.746 .903 .948 r
.11626 .34461 .1243 .34723 .13491 .34061 .12685 .33842 Mtetra
.739 .917 .953 r
.12685 .33842 .13491 .34061 .14552 .3341 .13745 .3323 Mtetra
.73 .929 .956 r
.13745 .3323 .14552 .3341 .15614 .32768 .14807 .32625 Mtetra
.72 .939 .957 r
.14807 .32625 .15614 .32768 .16677 .32133 .15871 .32026 Mtetra
.707 .947 .956 r
.15871 .32026 .16677 .32133 .17743 .31502 .16937 .31434 Mtetra
.691 .953 .953 r
.16937 .31434 .17743 .31502 .18811 .30872 .18005 .30847 Mtetra
.67 .958 .945 r
.18005 .30847 .18811 .30872 .19882 .30242 .19075 .30268 Mtetra
.641 .957 .929 r
.19075 .30268 .19882 .30242 .20955 .2961 .20147 .29696 Mtetra
.598 .949 .903 r
.20147 .29696 .20955 .2961 .2203 .28982 .21221 .29135 Mtetra
.54 .927 .861 r
.21221 .29135 .2203 .28982 .23107 .28361 .22297 .28587 Mtetra
.464 .887 .8 r
.22297 .28587 .23107 .28361 .24186 .27758 .23375 .28056 Mtetra
.38 .831 .726 r
.23375 .28056 .24186 .27758 .25265 .27181 .24454 .27544 Mtetra
.301 .771 .651 r
.24454 .27544 .25265 .27181 .26344 .26635 .25535 .27049 Mtetra
0 0 0 r
.25535 .27049 .26344 .26635 .27423 .26127 .26618 .2657 Mtetra
.26618 .2657 .27423 .26127 .28503 .25651 .27704 .26103 Mtetra
.27704 .26103 .28503 .25651 .29585 .25204 .28793 .25647 Mtetra
.28793 .25647 .29585 .25204 .30669 .24779 .29886 .25198 Mtetra
.29886 .25198 .30669 .24779 .31757 .24368 .30982 .24756 Mtetra
.30982 .24756 .31757 .24368 .32848 .23966 .32082 .2432 Mtetra
.32082 .2432 .32848 .23966 .33944 .23566 .33187 .23889 Mtetra
.33187 .23889 .33944 .23566 .35044 .23164 .34295 .23462 Mtetra
.34295 .23462 .35044 .23164 .36149 .22757 .35407 .23041 Mtetra
.35407 .23041 .36149 .22757 .37259 .22343 .36524 .22624 Mtetra
.36524 .22624 .37259 .22343 .38374 .21922 .37645 .22213 Mtetra
.37645 .22213 .38374 .21922 .39494 .21496 .3877 .21807 Mtetra
.3877 .21807 .39494 .21496 .40618 .21068 .399 .21405 Mtetra
.399 .21405 .40618 .21068 .41747 .20642 .41035 .21009 Mtetra
.41035 .21009 .41747 .20642 .4288 .20225 .42174 .20618 Mtetra
.42174 .20618 .4288 .20225 .44018 .19822 .43318 .20234 Mtetra
.43318 .20234 .44018 .19822 .4516 .1944 .44467 .19858 Mtetra
.44467 .19858 .4516 .1944 .46306 .19089 .45622 .19492 Mtetra
.45622 .19492 .46306 .19089 .47457 .1877 .46781 .19139 Mtetra
.46781 .19139 .47457 .1877 .48614 .18489 .47946 .18802 Mtetra
.47946 .18802 .48614 .18489 .49776 .18241 .49116 .18483 Mtetra
.49116 .18483 .49776 .18241 .50945 .18019 .50292 .18183 Mtetra
.50292 .18183 .50945 .18019 .5212 .17816 .51474 .179 Mtetra
.209 .733 .754 r
.51474 .179 .5212 .17816 .53302 .17621 .52662 .17631 Mtetra
.256 .767 .817 r
.52662 .17631 .53302 .17621 .54491 .17429 .53857 .17373 Mtetra
.299 .792 .868 r
.53857 .17373 .54491 .17429 .55688 .17237 .55059 .17124 Mtetra
.333 .808 .906 r
.55059 .17124 .55688 .17237 .56891 .17045 .56268 .16881 Mtetra
.361 .817 .933 r
.56268 .16881 .56891 .17045 .58102 .16855 .57484 .16646 Mtetra
.383 .821 .953 r
.57484 .16646 .58102 .16855 .59321 .16668 .58707 .16417 Mtetra
.401 .822 .969 r
.58707 .16417 .59321 .16668 .60547 .1649 .59938 .16195 Mtetra
.418 .82 .981 r
.59938 .16195 .60547 .1649 .61781 .16322 .61176 .1598 Mtetra
.435 .816 .99 r
.61176 .1598 .61781 .16322 .63023 .16165 .62422 .15772 Mtetra
.452 .809 .997 r
.62422 .15772 .63023 .16165 .64274 .16018 .63675 .1557 Mtetra
.469 .8 .999 r
.63675 .1557 .64274 .16018 .65533 .15881 .64937 .15374 Mtetra
.487 .788 .998 r
.64937 .15374 .65533 .15881 .66801 .15752 .66207 .15179 Mtetra
.504 .774 .993 r
.66207 .15179 .66801 .15752 .68078 .15627 .67485 .14986 Mtetra
.519 .758 .983 r
.67485 .14986 .68078 .15627 .69364 .15506 .68771 .14792 Mtetra
.531 .74 .971 r
.68771 .14792 .69364 .15506 .70658 .15384 .70065 .14596 Mtetra
.542 .721 .956 r
.70065 .14596 .70658 .15384 .71961 .15261 .71368 .14397 Mtetra
.708 .762 .894 r
.03496 .38178 .04273 .38856 .05316 .38232 .04526 .3766 Mtetra
.714 .796 .915 r
.04526 .3766 .05316 .38232 .06362 .37604 .05559 .37138 Mtetra
.718 .831 .935 r
.05559 .37138 .06362 .37604 .0741 .36974 .06596 .36611 Mtetra
.717 .866 .952 r
.06596 .36611 .0741 .36974 .08461 .36343 .07636 .36082 Mtetra
.71 .899 .964 r
.07636 .36082 .08461 .36343 .09514 .35713 .08679 .35549 Mtetra
.695 .927 .968 r
.08679 .35549 .09514 .35713 .10569 .35084 .09726 .35015 Mtetra
.669 .945 .96 r
.09726 .35015 .10569 .35084 .11626 .34461 .10776 .34481 Mtetra
.63 .951 .939 r
.10776 .34481 .11626 .34461 .12685 .33842 .11828 .33948 Mtetra
.579 .941 .902 r
.11828 .33948 .12685 .33842 .13745 .3323 .12883 .33419 Mtetra
.516 .916 .85 r
.12883 .33419 .13745 .3323 .14807 .32625 .13941 .32895 Mtetra
.443 .874 .782 r
.13941 .32895 .14807 .32625 .15871 .32026 .15001 .32379 Mtetra
.36 .815 .701 r
.15001 .32379 .15871 .32026 .16937 .31434 .16063 .31872 Mtetra
0 0 0 r
.16063 .31872 .16937 .31434 .18005 .30847 .17127 .31378 Mtetra
.17127 .31378 .18005 .30847 .19075 .30268 .18192 .30899 Mtetra
.18192 .30899 .19075 .30268 .20147 .29696 .1926 .30436 Mtetra
.002 0 0 r
.1926 .30436 .20147 .29696 .21221 .29135 .2033 .29989 Mtetra
.075 0 0 r
.2033 .29989 .21221 .29135 .22297 .28587 .21402 .29557 Mtetra
.13 0 0 r
.21402 .29557 .22297 .28587 .23375 .28056 .22477 .29133 Mtetra
.169 0 0 r
.22477 .29133 .23375 .28056 .24454 .27544 .23557 .28711 Mtetra
.193 0 0 r
.23557 .28711 .24454 .27544 .25535 .27049 .24641 .28283 Mtetra
.204 0 0 r
.24641 .28283 .25535 .27049 .26618 .2657 .2573 .27842 Mtetra
.208 0 0 r
.2573 .27842 .26618 .2657 .27704 .26103 .26824 .27387 Mtetra
.205 0 0 r
.26824 .27387 .27704 .26103 .28793 .25647 .27924 .2692 Mtetra
.2 0 0 r
.27924 .2692 .28793 .25647 .29886 .25198 .29028 .26444 Mtetra
.194 0 0 r
.29028 .26444 .29886 .25198 .30982 .24756 .30137 .25966 Mtetra
.188 0 0 r
.30137 .25966 .30982 .24756 .32082 .2432 .31249 .25491 Mtetra
.184 0 0 r
.31249 .25491 .32082 .2432 .33187 .23889 .32365 .25025 Mtetra
.183 0 0 r
.32365 .25025 .33187 .23889 .34295 .23462 .33484 .24572 Mtetra
.186 0 0 r
.33484 .24572 .34295 .23462 .35407 .23041 .34607 .24136 Mtetra
.194 0 0 r
.34607 .24136 .35407 .23041 .36524 .22624 .35733 .23717 Mtetra
.205 0 0 r
.35733 .23717 .36524 .22624 .37645 .22213 .36863 .23317 Mtetra
.218 0 0 r
.36863 .23317 .37645 .22213 .3877 .21807 .37997 .22934 Mtetra
.232 0 0 r
.37997 .22934 .3877 .21807 .399 .21405 .39135 .22564 Mtetra
.244 0 0 r
.39135 .22564 .399 .21405 .41035 .21009 .40278 .22203 Mtetra
.254 0 .009 r
.40278 .22203 .41035 .21009 .42174 .20618 .41427 .21845 Mtetra
.261 0 .02 r
.41427 .21845 .42174 .20618 .43318 .20234 .42581 .21484 Mtetra
.263 0 .027 r
.42581 .21484 .43318 .20234 .44467 .19858 .4374 .21116 Mtetra
.259 0 .028 r
.4374 .21116 .44467 .19858 .45622 .19492 .44905 .20734 Mtetra
.251 0 .02 r
.44905 .20734 .45622 .19492 .46781 .19139 .46076 .20339 Mtetra
.238 0 .004 r
.46076 .20339 .46781 .19139 .47946 .18802 .47253 .19931 Mtetra
.22 0 0 r
.47253 .19931 .47946 .18802 .49116 .18483 .48435 .19516 Mtetra
.197 0 0 r
.48435 .19516 .49116 .18483 .50292 .18183 .49622 .19103 Mtetra
.169 0 0 r
.49622 .19103 .50292 .18183 .51474 .179 .50815 .18698 Mtetra
.137 0 0 r
.50815 .18698 .51474 .179 .52662 .17631 .52013 .18309 Mtetra
.099 0 0 r
.52013 .18309 .52662 .17631 .53857 .17373 .53217 .17935 Mtetra
.056 0 0 r
.53217 .17935 .53857 .17373 .55059 .17124 .54426 .17579 Mtetra
.009 0 0 r
.54426 .17579 .55059 .17124 .56268 .16881 .55642 .17237 Mtetra
0 0 0 r
.55642 .17237 .56268 .16881 .57484 .16646 .56865 .16908 Mtetra
.56865 .16908 .57484 .16646 .58707 .16417 .58094 .16589 Mtetra
.58094 .16589 .58707 .16417 .59938 .16195 .5933 .16278 Mtetra
.222 .742 .752 r
.5933 .16278 .59938 .16195 .61176 .1598 .60573 .15972 Mtetra
.29 .789 .831 r
.60573 .15972 .61176 .1598 .62422 .15772 .61823 .1567 Mtetra
.357 .825 .899 r
.61823 .1567 .62422 .15772 .63675 .1557 .63079 .1537 Mtetra
.421 .847 .952 r
.63079 .1537 .63675 .1557 .64937 .15374 .64343 .1507 Mtetra
.477 .852 .985 r
.64343 .1507 .64937 .15374 .66207 .15179 .65614 .14768 Mtetra
.522 .842 .999 r
.65614 .14768 .66207 .15179 .67485 .14986 .66892 .14464 Mtetra
.554 .82 .995 r
.66892 .14464 .67485 .14986 .68771 .14792 .68177 .14155 Mtetra
.577 .79 .98 r
.68177 .14155 .68771 .14792 .70065 .14596 .6947 .13843 Mtetra
.591 .758 .958 r
.6947 .13843 .70065 .14596 .71368 .14397 .70769 .13525 Mtetra
.661 .753 .918 r
.02714 .37496 .03496 .38178 .04526 .3766 .03726 .3711 Mtetra
.662 .796 .946 r
.03726 .3711 .04526 .3766 .05559 .37138 .04742 .36719 Mtetra
.657 .84 .97 r
.04742 .36719 .05559 .37138 .06596 .36611 .05762 .36323 Mtetra
.641 .881 .985 r
.05762 .36323 .06596 .36611 .07636 .36082 .06788 .35922 Mtetra
.609 .91 .982 r
.06788 .35922 .07636 .36082 .08679 .35549 .07817 .35516 Mtetra
.555 .918 .952 r
.07817 .35516 .08679 .35549 .09726 .35015 .08851 .35105 Mtetra
.48 .897 .89 r
.08851 .35105 .09726 .35015 .10776 .34481 .0989 .34691 Mtetra
.388 .846 .799 r
.0989 .34691 .10776 .34481 .11828 .33948 .10932 .34274 Mtetra
.288 .773 .689 r
.10932 .34274 .11828 .33948 .12883 .33419 .11978 .33858 Mtetra
0 0 0 r
.11978 .33858 .12883 .33419 .13941 .32895 .13028 .33443 Mtetra
.13028 .33443 .13941 .32895 .15001 .32379 .14082 .33033 Mtetra
.14082 .33033 .15001 .32379 .16063 .31872 .15138 .32631 Mtetra
.051 0 0 r
.15138 .32631 .16063 .31872 .17127 .31378 .16197 .32241 Mtetra
.111 0 0 r
.16197 .32241 .17127 .31378 .18192 .30899 .17259 .31864 Mtetra
.162 0 0 r
.17259 .31864 .18192 .30899 .1926 .30436 .18323 .31503 Mtetra
.202 0 0 r
.18323 .31503 .1926 .30436 .2033 .29989 .19391 .31153 Mtetra
.233 0 0 r
.19391 .31153 .2033 .29989 .21402 .29557 .20462 .30813 Mtetra
.253 0 .012 r
.20462 .30813 .21402 .29557 .22477 .29133 .21539 .30471 Mtetra
.265 0 .037 r
.21539 .30471 .22477 .29133 .23557 .28711 .2262 .30119 Mtetra
.269 0 .054 r
.2262 .30119 .23557 .28711 .24641 .28283 .23709 .29747 Mtetra
.267 0 .064 r
.23709 .29747 .24641 .28283 .2573 .27842 .24805 .29347 Mtetra
.264 0 .069 r
.24805 .29347 .2573 .27842 .26824 .27387 .25907 .28922 Mtetra
.259 0 .072 r
.25907 .28922 .26824 .27387 .27924 .2692 .27016 .28471 Mtetra
.256 0 .074 r
.27016 .28471 .27924 .2692 .29028 .26444 .2813 .28005 Mtetra
.255 0 .076 r
.2813 .28005 .29028 .26444 .30137 .25966 .29249 .27531 Mtetra
.257 0 .078 r
.29249 .27531 .30137 .25966 .31249 .25491 .30372 .27056 Mtetra
.261 0 .08 r
.30372 .27056 .31249 .25491 .32365 .25025 .31499 .26588 Mtetra
.267 0 .083 r
.31499 .26588 .32365 .25025 .33484 .24572 .3263 .26132 Mtetra
.274 0 .087 r
.3263 .26132 .33484 .24572 .34607 .24136 .33763 .25693 Mtetra
.282 0 .091 r
.33763 .25693 .34607 .24136 .35733 .23717 .34901 .25273 Mtetra
.29 0 .095 r
.34901 .25273 .35733 .23717 .36863 .23317 .36042 .24873 Mtetra
.297 0 .098 r
.36042 .24873 .36863 .23317 .37997 .22934 .37187 .24489 Mtetra
.302 0 .101 r
.37187 .24489 .37997 .22934 .39135 .22564 .38337 .24118 Mtetra
.305 0 .102 r
.38337 .24118 .39135 .22564 .40278 .22203 .39492 .23754 Mtetra
.306 0 .102 r
.39492 .23754 .40278 .22203 .41427 .21845 .40652 .23389 Mtetra
.302 0 .099 r
.40652 .23389 .41427 .21845 .42581 .21484 .41818 .23016 Mtetra
.296 0 .094 r
.41818 .23016 .42581 .21484 .4374 .21116 .4299 .22627 Mtetra
.285 0 .086 r
.4299 .22627 .4374 .21116 .44905 .20734 .44168 .22214 Mtetra
.271 0 .074 r
.44168 .22214 .44905 .20734 .46076 .20339 .45352 .21773 Mtetra
.253 0 .057 r
.45352 .21773 .46076 .20339 .47253 .19931 .46541 .21305 Mtetra
.235 0 .037 r
.46541 .21305 .47253 .19931 .48435 .19516 .47736 .20815 Mtetra
.217 0 .012 r
.47736 .20815 .48435 .19516 .49622 .19103 .48936 .20315 Mtetra
.197 0 0 r
.48936 .20315 .49622 .19103 .50815 .18698 .50141 .19813 Mtetra
.178 0 0 r
.50141 .19813 .50815 .18698 .52013 .18309 .5135 .1932 Mtetra
.156 0 0 r
.5135 .1932 .52013 .18309 .53217 .17935 .52565 .18839 Mtetra
.13 0 0 r
.52565 .18839 .53217 .17935 .54426 .17579 .53784 .18373 Mtetra
.098 0 0 r
.53784 .18373 .54426 .17579 .55642 .17237 .55009 .1792 Mtetra
.059 0 0 r
.55009 .1792 .55642 .17237 .56865 .16908 .5624 .17479 Mtetra
.01 0 0 r
.5624 .17479 .56865 .16908 .58094 .16589 .57477 .17046 Mtetra
0 0 0 r
.57477 .17046 .58094 .16589 .5933 .16278 .58719 .16618 Mtetra
.58719 .16618 .5933 .16278 .60573 .15972 .59967 .16191 Mtetra
.59967 .16191 .60573 .15972 .61823 .1567 .61221 .15764 Mtetra
.317 .803 .773 r
.61221 .15764 .61823 .1567 .63079 .1537 .62481 .15334 Mtetra
.417 .864 .875 r
.62481 .15334 .63079 .1537 .64343 .1507 .63747 .149 Mtetra
.504 .896 .947 r
.63747 .149 .64343 .1507 .65614 .14768 .65019 .14461 Mtetra
.57 .896 .984 r
.65019 .14461 .65614 .14768 .66892 .14464 .66297 .14017 Mtetra
.613 .873 .991 r
.66297 .14017 .66892 .14464 .68177 .14155 .67581 .13566 Mtetra
.637 .835 .976 r
.67581 .13566 .68177 .14155 .6947 .13843 .6887 .13109 Mtetra
.649 .792 .951 r
.6887 .13109 .6947 .13843 .70769 .13525 .70165 .12647 Mtetra
.593 .734 .942 r
.01926 .36808 .02714 .37496 .03726 .3711 .02917 .36568 Mtetra
.583 .78 .973 r
.02917 .36568 .03726 .3711 .04742 .36719 .03913 .36321 Mtetra
.56 .824 .995 r
.03913 .36321 .04742 .36719 .05762 .36323 .04915 .36069 Mtetra
.517 .855 .995 r
.04915 .36069 .05762 .36323 .06788 .35922 .05923 .35811 Mtetra
.448 .86 .959 r
.05923 .35811 .06788 .35922 .07817 .35516 .06936 .35547 Mtetra
.353 .827 .876 r
.06936 .35547 .07817 .35516 .08851 .35105 .07954 .35277 Mtetra
.244 .756 .755 r
.07954 .35277 .08851 .35105 .0989 .34691 .08978 .35001 Mtetra
0 0 0 r
.08978 .35001 .0989 .34691 .10932 .34274 .10008 .34719 Mtetra
.10008 .34719 .10932 .34274 .11978 .33858 .11043 .34431 Mtetra
.034 0 0 r
.11043 .34431 .11978 .33858 .13028 .33443 .12084 .34137 Mtetra
.092 0 0 r
.12084 .34137 .13028 .33443 .14082 .33033 .1313 .33837 Mtetra
.136 0 0 r
.1313 .33837 .14082 .33033 .15138 .32631 .14182 .33531 Mtetra
.167 0 0 r
.14182 .33531 .15138 .32631 .16197 .32241 .15239 .33219 Mtetra
.189 0 0 r
.15239 .33219 .16197 .32241 .17259 .31864 .16302 .329 Mtetra
.203 0 0 r
.16302 .329 .17259 .31864 .18323 .31503 .1737 .32575 Mtetra
.21 0 0 r
.1737 .32575 .18323 .31503 .19391 .31153 .18444 .32244 Mtetra
.212 0 0 r
.18444 .32244 .19391 .31153 .20462 .30813 .19523 .31907 Mtetra
.211 0 0 r
.19523 .31907 .20462 .30813 .21539 .30471 .20608 .31563 Mtetra
.208 0 0 r
.20608 .31563 .21539 .30471 .2262 .30119 .21698 .31214 Mtetra
.205 0 0 r
.21698 .31214 .2262 .30119 .23709 .29747 .22793 .30857 Mtetra
.207 0 0 r
.22793 .30857 .23709 .29747 .24805 .29347 .23894 .30495 Mtetra
.214 0 0 r
.23894 .30495 .24805 .29347 .25907 .28922 .25001 .30126 Mtetra
.225 0 0 r
.25001 .30126 .25907 .28922 .27016 .28471 .26113 .2975 Mtetra
.239 0 .005 r
.26113 .2975 .27016 .28471 .2813 .28005 .2723 .29368 Mtetra
.253 0 .031 r
.2723 .29368 .2813 .28005 .29249 .27531 .28352 .2898 Mtetra
.267 0 .056 r
.28352 .2898 .29249 .27531 .30372 .27056 .2948 .28585 Mtetra
.278 0 .077 r
.2948 .28585 .30372 .27056 .31499 .26588 .30613 .28184 Mtetra
.286 0 .092 r
.30613 .28184 .31499 .26588 .3263 .26132 .31752 .27776 Mtetra
.291 0 .103 r
.31752 .27776 .3263 .26132 .33763 .25693 .32896 .27361 Mtetra
.292 0 .108 r
.32896 .27361 .33763 .25693 .34901 .25273 .34045 .2694 Mtetra
.29 0 .107 r
.34045 .2694 .34901 .25273 .36042 .24873 .35199 .26512 Mtetra
.285 0 .1 r
.35199 .26512 .36042 .24873 .37187 .24489 .36359 .26077 Mtetra
.277 0 .088 r
.36359 .26077 .37187 .24489 .38337 .24118 .37523 .25636 Mtetra
.264 0 .07 r
.37523 .25636 .38337 .24118 .39492 .23754 .38693 .25188 Mtetra
.249 0 .047 r
.38693 .25188 .39492 .23754 .40652 .23389 .39869 .24734 Mtetra
.23 0 .019 r
.39869 .24734 .40652 .23389 .41818 .23016 .41049 .24273 Mtetra
.209 0 0 r
.41049 .24273 .41818 .23016 .4299 .22627 .42234 .23805 Mtetra
.188 0 0 r
.42234 .23805 .4299 .22627 .44168 .22214 .43425 .2333 Mtetra
.17 0 0 r
.43425 .2333 .44168 .22214 .45352 .21773 .44621 .22848 Mtetra
.157 0 0 r
.44621 .22848 .45352 .21773 .46541 .21305 .45821 .2236 Mtetra
.149 0 0 r
.45821 .2236 .46541 .21305 .47736 .20815 .47027 .21864 Mtetra
.146 0 0 r
.47027 .21864 .47736 .20815 .48936 .20315 .48238 .21362 Mtetra
.143 0 0 r
.48238 .21362 .48936 .20315 .50141 .19813 .49453 .20853 Mtetra
.14 0 0 r
.49453 .20853 .50141 .19813 .5135 .1932 .50674 .20337 Mtetra
.131 0 0 r
.50674 .20337 .5135 .1932 .52565 .18839 .519 .19814 Mtetra
.115 0 0 r
.519 .19814 .52565 .18839 .53784 .18373 .5313 .19284 Mtetra
.09 0 0 r
.5313 .19284 .53784 .18373 .55009 .1792 .54365 .18748 Mtetra
.055 0 0 r
.54365 .18748 .55009 .1792 .5624 .17479 .55606 .18204 Mtetra
.006 0 0 r
.55606 .18204 .5624 .17479 .57477 .17046 .56851 .17653 Mtetra
0 0 0 r
.56851 .17653 .57477 .17046 .58719 .16618 .581 .17096 Mtetra
.581 .17096 .58719 .16618 .59967 .16191 .59355 .16531 Mtetra
.59355 .16531 .59967 .16191 .61221 .15764 .60614 .1596 Mtetra
.359 .818 .717 r
.60614 .1596 .61221 .15764 .62481 .15334 .61878 .15381 Mtetra
.473 .894 .835 r
.61878 .15381 .62481 .15334 .63747 .149 .63146 .14795 Mtetra
.571 .935 .92 r
.63146 .14795 .63747 .149 .65019 .14461 .64419 .14202 Mtetra
.64 .937 .965 r
.64419 .14202 .65019 .14461 .66297 .14017 .65697 .13603 Mtetra
.681 .909 .974 r
.65697 .13603 .66297 .14017 .67581 .13566 .66979 .12996 Mtetra
.7 .866 .96 r
.66979 .12996 .67581 .13566 .6887 .13109 .68265 .12382 Mtetra
.705 .817 .935 r
.68265 .12382 .6887 .13109 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Sooooo`03okCAkol0003ooooo01Gooooo00?o
0000ooooooooool0DOooool0063ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`0Mooooo`?o00000_ooool00ol0003oooooooooo`1Oooooo`?o]=7_00?o
0000okCAkoooool05Oooool00ol0003oooooooooo`1@ooooo`00H?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol0000Looooo`;o0000IOooool2ok?Mm@?o]=7_00?o0000ojK:loooool05?oo
ool00ol0003oooooo`00001Aooooo`00H?ooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00006_ooool3o`0006Gooooo1OncgOD00onddNooY/[co`000002ojK:laKooooo
00?o0000ooooooooool0Coooool0063ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgM
gOmEEEGoooooo`0001Sooooo0_l0001Uooooo`Co[^Si0_ncgOD3oj?En@03ojK:lol0003oY/[c00;o
Y/[c5_ooool00ol0003oooooooooo`1>ooooo`00H?ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l000005Oooool3o`0000;ooooo00?o0000ooooooooool0Goooool2oj?_m`Co
[^Si00?oW=omoj?EnOnSeOT01?nSeOT01?l0003oY/[coiO2mOnG`_DFooooo`03o`000?oooooooooo
04kooooo001Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000Coooo
o`;o0000IOooool5oj?_m`03ojkXnOnLgogoW=om00;oW=om0onSeOT2oi?:nP03o`000?nG`_GoUl;e
00;oUl;e5_ooool00ol0003oooooooooo`1=ooooo`00H?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00gooooo00?oMgMgo`000?ooool03oooool3o`0006Gooooo0_nBkn/3oj?_m`?oTNGk0_nLgod3ohgA
oPCoTl[j00?o0000oiO2mOnG`_D00onG`_DFooooo`03o`000?oooooooooo04cooooo0022ooooo`;o
0000I_ooool3oi;_j`?oPNGb0_nAiO/3ohGGo`GoSM7n0onCb_X01?l0003oUl;eoiO2mOnG`_D2ohZh
m1Kooooo00?o0000ooooooooool0C?ooool007oooooo0ol00002ooooo`03o`000?oooooooooo067o
oooo0_mii=D01?nBkn_oPNGboh7Ul_n1iO84og[Jo0CoQMOo0_n=dOh3ohC2n`;oQkgh00?o0000ohNm
n?n:^?@01?n:^?@Dooooo`?o0000COooool007cooooo0ol0001Vooooo`?oNNCE0_mZgMl4of_Hl`;o
N][l0omlbOl4oh76oPGoQ<;k00CoQkgho`000?n7_OSoQkgh1?n:^?@Gooooo`03o`000?oooooooooo
04[ooooo001jooooo`;o0000Ioooool00omKdKOoDLg5oe7=a@04oe_CiP;oJmSc0omhc?l5ogc9o`Co
PLKn0_n4`_/2oh>alP;oPk3b00?o0000oh>`l_n3/?401?n3/?4Fooooo`03o`000?oooooooooo04[o
oooo001gooooo`?o0000Ioooool00ol0003oB/WDod[9e003ofo@o@GoLloo1?mhc?l2ogc9o`;oQ;;c
1On3/O<4oh>alP04oh>`l_l0003oPk3boh>`lPGoPk3a5_ooool00ol0003oooooooooo`19ooooo`00
MOooool2o`0000;ooooo00?o0000ooooooooool0H_ooool00ol0003o>;g0of_An`03of_An`CoKm3m
0_mccol2ohJblPGoQK;c1?n4/_<5oh>al`CoPk7b00Co0000oh>`l_n3/?;oPk3b0_n3/?42ohB[kQOo
oooo00?o0000ooooooooool0B?ooool007;ooooo0ol00005ooooo`03o`000?oooooooooo05cooooo
1?l00003ofKBn0;oJm7k0_n;/O05ohRbl@CoQ[;b1On5/_<4ohBbl`;oPk7c0_n8XnH4ohJVj@04o`00
0?n5Z>coQJS/ohFXk0GoQ:_^5_ooool00ol0003oooooooooo`18ooooo`00L?ooool2o`0006?ooooo
0_l000001Ol2003o0000o`000?l0003oSZg[00GoS;3^1?n;/O05ohRbl@CoQ[;b0_n5/_<2ohbNg`Co
RZ3S1On8XnH3ohJVj@03o`000?n5Z>coQJS/00;oQJS/1On4ZnhFooooo`03o`000?oooooooooo04Oo
oooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000Pooooo`?o
0000HOooool01_l2003o0000o`l00?l?003o0P00o`4000?o00000on>[N/5ohb`kPCoRk7`0_n8/_42
ohnIf0CoSI_L1On<W]l4ohZPh`CoR:?V0on6Y^T00ol0003oQZKYohFXk003ohFXk0;oQ:_^0_n:Z^XE
ooooo`?o0000B?ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A401kooooo0_l00003ooooo`03o`000?oooooooooo05Kooooo0_lI
0003o`h00003o`800?lI003o6@0000?o3`000_l100001?l0003oT:[Xoi2Zj?n@Z^P4ohj]j`;oS;3^
0_nBTm44oi6Fe@GoSiWH1?n=Vm`4ohbNg`GoRZ3S1?n8XnH2ohJVj@03o`000?n>WMkoS:?T00?oS:?T
1On:Z^XFooooo`03o`000?oooooooooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool2o`000003oa0@4?oooooooooo02Wooooo000hooooo`05oa0@4?ooooooooooooooool@
41003?ooool00onHV9So8B4Qonk^kP0Looooo`?o0000F_ooool2ob<000?o6@0000?o3P00ob400?lQ
00000olI00001?l?003o3P00o`h00?l10003oi2Vi0CoT:[X0_n>[N/00onCT<goTY?Aoi:Cd@03oi:C
d@CoTIKE1?n?VMP5ohfKg0CoS9kO0_n:X><2oi2BdPCoSiSH0_n>WMh00ol0003oSYgNohjMgP04ohbS
i0GoRZ[Z5_ooool00ol0003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool0:_ooool003Sooooo00Go0000ooooooooooooooooo`00000=
ooooo`03oiRHV?lQ8B7ok^k^01Sooooo0ol0001Hooooo`;o000000Go:`00ob<00?lS003o8`00oaT0
0002obL000Co8@0000?o6@00oaL00?l>00000_l>00000onAX^3oT:KToi2Vi002oiB:aPCoU8g91?nC
T<d4oi:Cd@CoTIKE1On?VMP2ohfKg0;oTX[81?nAS/d5oi2BdPCoSiSH00?oSYgNo`000?n>WMh00_n>
WMh4ohbSi0;oRZ[Z0onF[^LFooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooo
oa0@400;ooooo`Go0000:oooool003Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMg
MomVIVKooooo01Gooooo0ol0001Fooooo`;o00000_lb0003ob/00003ob<00?l]003o9`0000?o9`00
0olQ0003oaL00004o`h00?nAX^3oU8O2oiB7`PGoU8[61?nDSLT3oi>@c@GoTY?A1?nAU]D2ohnIf0;o
ThO41OnBR/P4oi6>c@CoT9;B1On?V=P01?l0003oSYgNoiNMf?nGWMP4oiNUg`KoUZkW5Oooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0
000/ooooo`00>?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool04Ooo
ool3o`0000?ooooo00?o0000ooooooooool0D?ooool00ol0003o>000ocP00004oc8000;o:`000ol]
0003obL00003ob400?lM003o7@0000?o5`0000?oU8>noiB7`_nDQl800onDQl84oiB:aPCoU8g91?nC
T<d2oi:Cd@;oU8:l1?nDQ<05oi>7a0CoTX[81?nAS/d5oi2BdP;oSiSH0_nGUm400ol0003oUigHoiNM
f002oiNMf0CoUjGO1?nF[^L00onR/nCoooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002cooooo000hooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@017ooooo0_l0001Eoooo
o`;o000000?o?001ocP00?lh00000_lh0003oc800003ob/00?lb003o;@0000;o;@000_lW00001OlQ
003o7@00oad00?lM003o5`0000GoU8>n1?nDQl84oiB:aPGoU8g90_nCT<d00onEP;[oU8:loiB2_003
oiB2_0CoU8C01?nCQl@4oi::b0GoTHk=0_n@T]82oiRAb`CoUiOA00?o0000oiNMf?nGWMP00_nGWMP5
oiNUg`03oiJ^ionR/nCoX[?T00;oX[?T5_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00omgMgOoc<c<o`00000/ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00>ooooo`?o0000Doooool2o`0000;o@005
0oll0043ocP00003oc800?lg00?o=`0300?o<P000ol]0003ob400003oad00?nCP;_oTh2k00;oTh2k
1?nDPkh4oiB7`PGoU8[60_nDSLT2oiIn]`?oUH2j1OnDP[`4oiB4`0CoThO41OnBR/P2oi6>c@;oV8c6
1OnHTL/3oiNGd@03o`000?nGWMSoUigH00?oUigH0_nGYMl2oj:Zg0KoX[?T5?ooool2o`0000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002cooooo001Iooooo`?o0000
D_ooool00ol0003o@P07od801`04od001@;o?0010_lh00000oll00Wo=`03ocL00`02ocL00`;o<P00
00?o;@00ob<00?lS00000olQ0003oi=m^0?oTh2k1?nDPkh5oiB7`P;oU8[60_nFOKD4oiIn]`CoUH2j
1?nDP[`4oiB4`0GoThO40_nBR/P2oiR8`@GoV8c61?nHTL/3oiNGd@04o`000?nGUm7oUigHoiNMf0;o
XJ;E1OnRZ]`4oj:ci003ojfjh_oooooooooo017ooooo00Co0000oooooooooooo00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0:oooool005Kooooo0ol00003oooo
o`03o`000?oooooooooo04_ooooo0_l000000om300Ko@P07od801`02od801`?o@0050oll0043oc`0
2@?o=`0300?o<P00ob@00?lS00000olS00000olQ003oTW^foi=m^003oi=m^0?oTh2k1OnDPkh3oiB7
`P03oiIk/onFOKGoUWfe00;oUWfe1OnFO[L3oiF0^PGoU8:l1?nDQ<02oi>7a0;oV8Bl1OnHR<44oiR<
aPCoV97;0onGUm400ol0003oXI_?oj6Re@04oj6Re@GoXZ[L00?oX[?Tojfjh_n]^^800_n]^^8Foooo
o`03o`000?oooooooooo043ooooo001Dooooo`;o0000DOooool2o`000004od801Om300Ko@`06od<0
1P?o@P070om000D00oll007o@00>od003P03oc`02@?o=`030olT0003ob<000?oTW^f1?nCOKP4oi>0
^`CoU8>n00CoU8O2oiIk/onFNk?oUW^c1OnFOKD4oiIn]`?oUH2j1OnDP[`2oiB4`0;oV86i1OnHQ;`4
oiR8`@CoV8c61OnHTL/00onGUm7oXI_?o`000002oj6Kc`GoXJ;E0_nRZ]`2ojfbg0Go[K[R5_ooool0
0ol0003oooooooooo`10ooooo`00DOooool3o`0005;ooooo00Co0000od801Om200Go@P050_m300H4
od801`03od001Om501;o@00>00?o@00>0oll00T00olg00?o9@00ob@00002ob@00003ob<00?nBNKCo
TWVd00CoTW^f1OnCOKP3oi>0^`;oU8>n0_nFNK45oiIk/`CoUWfe1?nFO[L4oiF0^P?oU8:l00?oV7nf
oiR1^OnHPKT00onHPKT4oiR4_0CoV8S11OnHS<H2oiRAb`;oX9G90_nQVll00ol0003oXI_?oj6Kc`04
oj6Re@03ojb[e_n]/]co[K;L00?o[K;L0on]^^82okO1hQKooooo00?o0000ooooooooool0?oooool0
04kooooo1Ol0001@ooooo`03o`000?m100;o@@0200?o@P050om300H00om200OoB00FodP05P03odD0
4P?o@00>0_ll00T01_lV003o9@00obD00?lU003o9000oi9h/`CoTWVd1OnBNkH4oi=m^0;oTh2k00?o
UWN_oiIi/OnFNK400_nFNK45oiIk/`CoUWfe1OnFO[L3oiF0^P04oiB2_?nHOkKoV7nfoiQo]PGoV86i
1?nHQ;`5oiR8`@;oV8c60_nPT<@5oj2Eb@03oj6Kcol0003oXI_?00;oXI_?00?oXJ;Eojb[e_n/ZmH0
0_n/ZmH5ojfbg003ojfjh_ng`N;o]l7R00;o]l7R5_ooool00ol0003oooooooooo`0nooooo`00C?oo
ool2o`0000Gooooo00?o0000ooooooooool0B_ooool00ol0003o?P00od400P03od400P;o@P0500?o
@`06od/06?m;01P01?m801H2odD04PCo@00>0olV0002obD000?oTWRc1OnBNK@4oi9k]P;oTgfh0_nD
MJd3oiIg[`GoUWVa1?nFNk<5oiIm]@CoUWjg0_nEP;X00onHOK?oV7nfoiQo]P03oiQo]PCoV86i1OnH
Q;`3oiR8`@03oin<_onPT<CoX93400?oX9341?nPULT01OnQVloo0000oj6KconQVlooZjGA00Go[:_F
1?n]/]`00onf_Mko]l7RokO1hP02okO1hP03okc7hooooooooooo01Cooooo00?o0000ooooooooool0
?_ooool004Wooooo0ol0001Aooooo`;o>`000oln0003od400P03od801Om=01WoB`0H00?oB`0H0om8
01H3odD04P03od003_lX003o:00000?o9P0000?o9@00oi=h/_nCN;801?nBN;<4oi9i]0;oTW^f0_nC
LZ/4oiAe[@CoUWN_1?nFNK44oiIk/`GoUWfe0_nFO[L2oiQk/@?oV7fc1OnHOkH5oiR1^@CoV8Bl00?o
V8S1oin<_onOS;l00_nOS;l4oj2@a0GoX9G900?oXI_?o`000?n[YM400_n[YM45ojb[eP03ojfbg?nf
_Mko][gN00;o][gN00?o]l7Rokc7honlan<00_nlan<Dooooo`?o0000?oooool002;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0Pooooo`;o0000DOooool00olg003o>`00oc/00002oc/000;o?P001?m1
0082odd06@?oB`0H0om801H2odD04P03ob/00?lX003o:00000;o:0000_lV0005oi=h/P?oTWRc0_nB
NK@2oi9`Z0CoTg:[1OnDMJd3oiIg[`CoUWVa1OnFNk<3oiIm]@03oiQj[onHNk7oV7^a00;oV7^a1?nH
OK<4oiQo]PGoV86i0_nHQ;`2oij8^`GoWhbo1?nPT<@4oj2Eb@03ojZPc?n[YM7o000000?oZjGA1?n/
ZmH00onf^M_o][gNokJmgP02okJmgP03okg8honlan?o_<OS00Co_<OS5Oooool00ol0003ooooooooo
o`0mooooo`008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo0ol00002ooooo`03o`000?oo
oooooooo04cooooo00?o0000ocL00?lg00000olk0003och00003od400_m>01[oCP0J00;oC@0I1?m;
01P3odP05P?o:`000olX00001?lV003oU7VboiAi/_nDNK84oi=h/P;oTWRc00?oTFfVoi9`Z?nBL:P0
0_nBL:P5oi=bZ`CoU7F]0onFMjl5oiIi/@CoUW^c00CoUWfeoiQj[onHNZooV7Z_1OnHNk43oiQm/`Go
V7nf0onHPKT00onNQ;OoWXRkoij8^`03oij8^`CoWhbo1OnPT<@00onPULWoZZ3<ojZPc002ojZPc003
o`000?n[YM7oZjGA00;oZjGA00?o[:_FokJifonf^M/00_nf^M/2okJmgP?o_LSS1?nlan<2okk>iQGo
oooo00?o0000ooooooooool0??ooool002;ooooo00Go410@oooooooooooooooooa0@400Kooooo`;o
0000DOooool00ol0003o=000oc@00002ocL000?o>`0000?o?P00odh06_m>01X01?m>01X2odd06@Co
B`0H00?oB00Foc000?l[00000_l[0002obP000;oUGVb1?nDNK82oi=h/P;oT6^U0onAKJH5oi9`Z0Co
Tg:[1?nDMJd3oiIg[`GoUWVa0_nFNk<2oiQi[PGoV7Z_1?nHNk43oiQm/`GoV7nf00CoV86ioij4]onN
Q;OoWXBg1OnNR;/5oin<_`?oX93400?oZY_8ojZPc?nZX<`00onZX<`01Ol0003oZjGAoj^UdOn[YM7o
][KH00Go][WK00?o][gNokg8honmb><00onmb><00onlan?o_/kVokk>iP03okk>iQGooooo00?o0000
ooooooooool0>oooool002;ooooo00Go0000ooooooooooooooooo`00000Hooooo`?o0000D?ooool0
0ol0003o<@00oc@00002oc@000?o=`0000?o>`00odd06Om>01X01_m>01X3odd06@03od/06?le003o
=@0000?o<0000ol[00001?nFN[;oUGVboiEi/_nENK82oiAi/P;oSfZS1?n@JjD4oi5]YPCoTW2X1?nC
LZ/4oiAe[@CoUWN_0onFNK400onIN:goV7V^oiQi[P02oiQi[PGoV7Z_1?nHNk44oiQm/`?oV7nf00?o
WH6doij4]onNQ;L00onNQ;L4oij8^`GoWhbo00?oX934ojZKb?nZVlP00_nZVlP4ojZPc003o`000?n[
YM7o][KH00?o][KH0onf^M/6okg8h`;o_mCZ1?nnc^H00onid>_oooooooooo`0Cooooo`03o`000?oo
oooooooo03_ooooo000Rooooo`05o`000?ooooooooooooooool000005_ooool3o`00053ooooo00Co
;`00oc400?la003o<@000_ld00000olg003oC00Iod`06@03odd06@KoCP0J00?oC@0IocX01?lj00@0
1?le0002oc000003ob/00?nFN[;oUWZb00;oUWZb0_nENK800on?JJ;oSfZSohmZX`02ohmZX`GoT6^U
0onAKJH4oi9`Z0CoTg:[1OnDMJd3oiIg[`04oiIi/OnIN:goVGR]oiUh[@GoV7V^1?nHNZl5oiQk/@?o
V7fc00CoV7nfoif1]?nMPKCoWH6d1OnNQ;L5oij8^`?oWhbo00?oZIS4ojZKb?nZVlP00onZVlP4ojZP
c003o`000?nf]]So][KH00Co][KH00?o][WKokg8honmb><00onmb><5okoDjP03okk>i_nid>_o^M3[
00;o^M3[5Oooool00ol0003oooooooooo`0jooooo`008_ooool01Ol@413ooooooooooooooooo410@
01?ooooo0ol00002ooooo`03o`000?oooooooooo04cooooo0ol_0002oc400003oc@00?m:01SoC00I
00?oC00I0_m=01T5odh06P03ocl03?lj00Co>P0400;o>P040ole00001?l`003oUg^coiMk/onGNk<2
oiIj/P;oSfRQ0on?JJ84ohmZX`GoT6^U0onAKJH4oi9`Z0CoTg:[1OnDMJd2oiIg[`03oiUgZonIN:go
VGR]00?oVGR]1?nHNJh4oiQj[`GoV7^a0_nHOK<00onLO[;oWH6doif1]003oif1]0CoWXBg1OnNR;/0
0onOS;ooZIS4ojVHa002ojVHa0GoZY_800GoZZ3<okJce_nf/mKo0000okJceP04okJff003okk9honm
b>?o_LSS00;o_LSS0_o0fnd4okoDjP03okWJlOnid>_o^M3[00?o^M3[5_ooool00ol0003ooooooooo
o`0iooooo`008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg013ooooo0ol0001@ooooo`;o000000Co
;P00obl00?l_003o;`000ola0002odX060?oC00I0om=01T4odh06P;o?`0<0olj00@3ocD000;oV7bc
0_nGNk<5ohmXX@?oSfVR1On?JZ<4oi1[Y@?oTFfV1?nBL:P5oi=bZ`?oU7F]00CoV7FZoiUgZonIMj_o
VGN[1OnIN:d4oiQi[PGoV7Z_0onHNk400onLO;3oW7jboian/P02oian/PCoWH6d1OnNQ;L3oij8^`03
ojVD`OnYV<CoZIS400?oZIS41?nZVlP01Ong/]Co][?FokJce_nf/mKo000000;o][?F00?o][KHokk9
honnbN<00_nnbN<2okg8h`Co`=_]00?o_mCZokWJlOnif_400_nif_43okW@j`;o/<k`5?ooool2o`00
03_ooooo000Rooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool2o`00053ooooo00?o0000obl0
0?l_00000_l^0003obl00003oc400?m801OoB00G00;oBP0H0om<01T4odd06@03odh06_m3017o@`0A
00;o?`0<0olj00@00ole003oVGfdoiQl/`02oiQl/`03oi1XX?n?J:7oSfRQ00GoSfRQ1?n?JJ84ohmZ
X`CoT6^U0onAKJH5oi9`Z0CoTg:[00CoU7F]oiQeZ_nHMJ[oV7FZ1?nIMj/4oiUh[@CoV7V^1OnHNZl0
1?nHNk7oW7b`oial/?nLO;04oian/PCoWH6d1OnNQ;L00onNR;_oZIC1ojVD`@02ojVD`@GoZIS400?o
ZY_8okNbe?ng/]@00_ng/]@2okJceP03o`000?nf/mKo_lcT00Go_/WS00?o_LSSol3KkOo0fnd00_o0
fnd2okOUm@Go^M[a00?o^M3[ok3>l?n`c_000_n`c_0Eooooo`03o`000?oooooooooo03Sooooo000b
ooooo`Go0000C_ooool00ol`003o;`00obl00002obl00004obh00?l_003oAP0FodH05PCoB00G0_m:
01P3od`06@03odd06Om601KoAP0F00Co@`0A0_lo00`00olj00CoVGjdoiUm]002oiUm]004oiQl/on@
J:3oT6RPoi1XX0SoSfRQ0on?JJ84ohmZX`CoT6^U1?nAKJH4oi9`Z0;oTg:[0_nHM:T5oiQeZP?oVGN[
1?nIN:d5oiQi[P?oV7Z_00?oVg^^oial/?nLO;000onLO;04oian/PCoWH6d0onNQ;L00onXT[koZIC1
ojVD`@03ojVD`@CoZIS41_ng/]@00onf/mKo0000o`000003oko<i0?o_/WS0onoho400oo0fngo]nGe
okOUm@03okOUm@;o^M[a0_n]f_L4ok3>l003oj?7l_oooooooooo01Cooooo00?o0000ooooooooool0
=oooool0033ooooo0_l0001Booooo`;o<0000ol_00000om401GoAP0FodH05P02odH05P?oB00G0om:
01P00om<01WoB00IodH05P03odH05P?o@`0A0olo00`2oiUn]0;oVGfd1On@J:08ohmXX@?oSfVR1?n?
JZ<5oi1[Y@?oTFfV0onBL:P00onGLZOoV7BYoiQdZ@02oiQdZ@GoV7FZ0onIMj/5oiUh[@CoV7V^00Co
V7Z_oi]k[_nKNjkoVg^^1OnLO;04oian/PCoWH6d00?oWXBgojRB__nXT[h00_nXT[h4ojVD`@?oZIS4
1Ong/]@3o`000003okJce_l0003o_lcT00;o_lcT00?o_/WSokoSlOnoho400_noho42ok3^m`Co]nGe
00?oY^GkojgJmon]f_L00on]f_L00on`c_3oXlOboj?7lP02oj?7lQGooooo00?o0000ooooooooool0
=oooool002gooooo0ol0001@ooooo`03o`000?la003o<@0000;o<0000ol_0002od@05@?oAP0F0om8
01L00om:01SoBP0KodX06`03odP06@?oAP0F0om301401?lo00coVGjdoiUn]?nIO[@2oi1XW`OoT6RP
2?n?J:43ohmYXPCoSfZS1On@JjD3oi5]YP04oi9`Z?nGLZOoUg:WoiMbY`GoV7BY1?nHMJX3oiUgZ`Go
VGR]0_nHNJh2oi]j[@GoVg^^1?nLO;04oian/P?oWH6d00?oYhnlojRB__nXT[h00onXT[h5ojVD`@04
ojVHa?ng/]Co]k;DokNbe0?o00000_ng/]@2ol3?iP03oko<i?l0003o_lcT00?o_Ncc00?o_n?aok3^
mon`k_L00on`k_L00ongiOGoY^GkojKUn`02ojKUn`;o[M[g0onOd?T5oj?7lQGooooo00?o0000oooo
ooooool0=_ooool002cooooo0_l0001?ooooo`03o`000?lc003o<@0000?o<@0000Co<000obl00?m2
01Co@P0D0_m401D3odH05P;oB00G1Om:01/2odP06@?oAP0F0_m30142oiUn]0;oTFRO1?n@J9l7oi1X
X0SoSfRQ0on?JJ85ohmZX`CoT6^U0_nAKJH00onFL:KoUg:WoiMbY`03oiMbY`CoV7BY1?nHMJX4oiUg
Z`?oVGR]00?oVgV/oi]j[OnKNZd00_nKNZd5oi]k[PCoW7b`1OnLO[801?nMPKCoYhnlojN?_?nWSk`4
ojRB_PCoZIC100?o^;;CokNbe?l000000_l00003okNbe0Go`<oV00Co_lcTo`000?nmk??o_Ncc0onO
l_42ok3^m`?oU>_g0_nViO/3oiOHo@GoWm3i0_nSao83oiRmlQGooooo00?o0000ooooooooool0=Ooo
ool002cooooo0ol0001=ooooo`03o`000?lc003o<`0000?o<@0000?o@@0Cod805?m201@00_m201@2
od@05@?oAP0F1_m:01/3odP06@?oAP0F00?oVWjdoi5XWonAJ9l00onAJ9l4oi1XW`OoT6RP2?n?J:44
ohmYXPCoSfZS0on@JjD01?nEKZCoUW2VoiI`Y_nFL:H5oiMbY`CoV7BY1?nHMJX4oiUgZ`04oiUh[OnK
NJcoVgV/oi]i[0GoVgZ]1?nKNjh5oial/0?oW7jb00?oYXfjojN?_?nWSk`00_nWSk`5ojRB_P03ojVD
`Onh/]?o000000;o00001?ng/]@2ol7Dj@Co`<oV0_nflo<00onmk??o0000oiobl@02oiobl@?oM>;S
0_nDjoL3ohWLoPCoUmSm0_nOd?T3oiG1m@GoV;gb5?ooool00ol0003oooooooooo`0eooooo`00;?oo
ool01?l0003oooooo`000?l00019ooooo`03o`000?ld003o=00000;o<`000ola0002od404`?o@P0D
0om401D00om601KoBP0JodX06`05odX06`CoB00I00?oAP0FoiYn]?nJO[@01_nAJ9l4oi1XW`SoT6RP
1on?J:44ohmYXPCoSfZS00CoT6^UoiE^Y?nEKZCoUFjT1?nFL:H4oiMbY`CoV7BY1OnHMJX2oiUgZ`03
oiaj[?nKNJcoVgV/00?oVgV/1?nKNZd4oi]k[PGoW7b`00?oW7jbojJ=^_nVSKX00_nVSKX3ojN?_0Co
Z9:n0ol00004okRbd`03okNbe?o1e>Wo`MCY00?o`MCY00Co`<oVokKclonflo?o]_?c0_n2jM`00ol0
003oWo;aogCRh`02ogCRh`?oM=[h0_n9g?h3ohg3n@CoTL?h1OnE`OD2oiRmlP;oU;K_4oooool00ol0
003oooooo`000008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c00Iooooo`00;?ooool2o`0000;ooooo00?o0000ooooooooool0@oooool0
0ol0003o=@00oc@00003oc@00003oc<00?la003o@@0C00?o@@0C0om201@2od@05@04odT05om:01[o
BP0JodX06PKoBP0K00CoB00IoiYn/onJO[CoVWjd0_nBJ9l8oi5XW`?oT6RO2?n@J:08ohmXX@?oSfVR
0_n?JZ<2oiA]X`CoUFjT1?nFL:H4oiMbY`CoV7BY1OnHMJX00onIMj_oW7Z/oiaj[005oi]i[0CoVgZ]
1OnKNjh3oial/003ojF;^OnVSK[oYXfj00?oYXfj1?nWSk`3o`0000;o^KCD1?nh/]<2ol7Kk0Co`MCY
0_nVm^`01?nflo?oP^WLoh;Yg?n2jM`2odK6^`03o`000?mId>WoFM3Y00;oM=[h0on8`OX5ohg3n@Co
TL?h0_nE`OD2oi>dkPGoU;K_5Oooool00ol0003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0Iooooo`00:oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo047ooooo00?o0000ocD00?le00000old00000om1
01;o@@0Cod404`04od404`?o@P0D0om901L2odX06PGoBP0K0onJO[<00onBJJ3oTVROoi9XW`02oi9X
W`SoTFRO0on@J9l8oi1XX0SoSfRQ0_n?JJ800onCJj;oU6fSoiA]X`02oiA]X`GoUFjT0onFL:H4oiMb
Y`GoV7BY0onHMJX00onMNjcoW7Z/oiaj[002oiaj[0CoVgV/1?nKNZd5oi]k[P03oial/?nURkWoYH^i
00;oYH^i1?nVSKX2ojN?_0;o00001Oni]=@3okRbd`Co`M_/00Go`MCYojKfk?nVm^coY_K/oeK=]002
ohBbl`CoPkSg00?oQKkio`000?n5__T00_n5__T4ohS1nP;oSL?i0_nA[^X4oi:bk@GoTkC^1?nD]^lE
ooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oo
ooooooooooooool000006Oooool002_ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0mooooo`03odg5Y_ld003o=00000;o=@000old0002od404PKo@@0C00?o@P0DodL04om901L00_m9
01L3odX06P?oBP0K0_nJO[<01?nCJZ3oTVVPoi9YX?nBJJ04oi9XW`SoTFRO1?n@J9l7oi1XX0SoSfRQ
00?oSfVRoi=[X_nCJj801?nDKJ<5oiE^Y0?oUW2V1OnGLZL4oiQdZ@04oiQeZ_nMNjcoWG^/oiek[0Co
W7Z/1?nKNJ`5oi]j[@?oVg^^00?oY8VhojF;^OnURkT00onURkT3ojJ=^P?o000000?oYhnlokZfe_nj
]]H01Oni]=@00onh/]?o`M_/ol7Kk002ol7Kk0?oRngH00?oY_K/ohBblon4/_<00on4/_<4oh>hm`04
o`000?n5__WoTZ?Qoi:Sh@CoTJWV1OnA[^X4oi:bk@CoTkC^0_nD]^l3oiJbjaGooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q
8@0Iooooo`00:oooool3o`0000Gooooo00?o0000ooooooooool0>Oooool00omQe;Wo<@00oc@00003
oc@00004ocD00?ld003o@P0Bod804P;o@@0B1Om101<01?m400koA`0CodL04om701<2odT05`CoBP0J
00?oBP0Koi]n/_nJO[<00onCJZ03oi9YX0GoTVRO1onAJ9l4oi1XW`OoT6RP1_n?J:42oi9ZX@?oTf^R
1OnDKJ<4oiE^Y0?oUW2V1OnGLZL3oiQdZ@03oiik[OnMNjcoWG^/00?oWG^/0onLNZ`4oi]i[0GoVgZ]
00?oVg^^ojB9^?nTRKP00_nTRKP4ojF;^@?o00000_nVSKX01?nWSkco^[KFokZfe_nj]]H4okVde0?o
`>C`00Co`M_/oh_]f?n;kMSoRngH1?n7Z^`2ohBbl`;oU9GB1?nBW=X00onBXn7o0000oi:Sh@02oi:S
h@CoTJWV1?nA[^X2oi:bk@;oUjKP1OnF[>H5oiJbjaGooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Iooooo`00:oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Oooooo00?oHMBioc400?la00000old0000
0om3017o@P0Bod804P02od804P03od404_m101?o@@0C00;o@@0C0om400h2odL04`?oB@0G00?oBP0J
oi]n/_nKO[800_nKO[800onCJj7oTfZPoi=ZX002oi=ZX0CoTVVP1?nBJ9l7oi5XW`CoT6RO1on@J:02
ohmXX@;oTFVP1?nBJZ44oi=[XPCoU6fS1?nEKZ@4oiI`YPCoUg:W00CoV7BYoiik[OnNNjgoWW^]1OnM
Nj`3oiaj[0GoVgV/0onKNZd00onSR;OoY8VhojB9^003ojB9^005ojF;^Ol0003o0000o`000?nURkT0
0onVSKX00onj^MSo^[KFokZfeP03okZfeP03okVde?o0i?3o`>C`00;o`>C`0_mQdk<4oh^Si0;oQj[/
00?oUHk:oiBEd_nDUM800onDUM84oi:LfP03oi:ShOl0003oTZ?Q00;oTZ?Q1?nAZNH2oi6^jP03oiNP
f_nGY^3oUjKP00?oUjKP1OnF[>H2oiJbj`;oWK?X5Oooool00ol0003oooooooooo`03ooooo`05oa0@
4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Kooooo`00:oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo03Cooooo0_l[0002oc4000?o=0000_m30143od804P;o@@0B
00?o@@0Cod001om000L00om400h2odL04`;oB@0G00GoW7jaoi]n/_nKO[;oVgjboiA/X@03oi=[X@Go
TfZP0onBJJ04oi9XW`OoTFRO1?n@J9l6oi1XX003oi5XX?nAJJ3oTFVP00;oTFVP1?nBJZ44oi=[XPCo
U6fS1?nEKZ@4oiI`YP?oUg:W00?oWWb]oiik[OnNNjd00onNNjd4oiek[0?oW7Z/1OnKNJ`01?nKNZgo
XhRgoj>8]onSR;L3ojB9^0?o00001?nURkT00onVSK[o^[WHokZif002okZif0?o^[KF0onlkO<00oo0
i?3oHM>cof7C/`02oiN3^`CoUXS21?nES/X4oiBEdPGoTYcJ00CoTZ?Qo`000?nIU<goVIC=1?nHV]<4
oiNPfPGoUjKP0_nF[>H2oif/h@GoWK?X4oooool3o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH01_ooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0<?ooool01?lQ003o:`00ob/00?l[0002oc400003oc@00?m4013oA00@00;o@`0A
0om201800om101;o?@01od001`03od001`;oA00>0om701<3oian/@04oi]n/_nDK:7oU6bQoiA/X@?o
Tf^Q1OnCJZ03oi9YX0CoTVRO2?nAJ9l3oi1XW`GoT6RP0_nAJ:04oi5YX0GoTVZQ0onCJj84oiA]X`Go
UFjT0onFL:H01?nGLZOoWWb]oiil[OnNO:d5oiik[@CoWG^/1?nLNZ`3oi]i[003oj:7]onSR;OoXhRg
00;oXhRg0ol00003ojB9^0?oYH^i00?o^[cKokZif?nj^MP01?nj^MP01_nj]]Ko_>gcokc]lonlkO?o
0000oiQn]PGoUh>k1?nFR<83oiF>bPGoU9GB0_nBW=X2oiZ>aP03oiVDcOl0003oVIC=00;oVIC=1?nH
V]<4oiNPfP;oUjKP0_nNY]/5oif/h@GoWK?X5Oooool02Ol0003oooooooooooooooook^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@41Wooooo000@ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01?ooool3o`0000[ooooo00?o0000
ooooooooool0;_ooool2ob4000;o:`0000?o<@00od@03Om401000om401000om3017o@P0Bod804P02
od804P;o?@010om000L3od@03P03odL04onLO[7oW7ja00;oW7ja00?oUFfRoiA/XOnDK:400_nDK:44
oi=[X@CoTfZP0onBJJ04oi9XW`SoTFRO0on@J9l2oi1XX0;oTFRO0onAJ:05oi5YX0CoTVZQ0onCJj84
oiA]X`GoUFjT0_nFL:H00onNOJkoWWb]oiil[@03oiil[@CoWW^]1?nMNj`4oiaj[005oi]i[?nRQkOo
XXNgoj:7]onSR;L00ol000000onSR;OoY8VhojB9^003ojB9^003ojF;^Onj_=_o^[cK00;o^[cK1?nj
^MP2ok?dlP03okc]lonHO[KoV7jf00?oV7jf1?nGPk/4oiJ8`PCoUHk:0_nDUM82oi^9_`GoVXk600Co
VIC=o`000?nIU<goVIC=1?nHV]<2oiNPfP;oWioD1OnNY]/5oif/h@;oWK?X0_nV^>HEooooo`03o`00
0?oooooooooo02oooooo0008ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00_ooooo
1Ol00005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:oooool01OlC003o8@00
ob400?l[003o@`0900?oA00=0om40102od<04@03od804_li003o>@0000;o?@010om000L01?m400ko
WGnaoieo/OnMOk42oian/@04oiI^XonEKJ;oUFfRoiE]XPGoU6bQ0onCJj44oi=ZX0?oTVVP1?nBJ9l8
oi5XW`;oT6RO1OnAJ9l4oi5XX0CoTFVP1?nBJZ43oi=[XPGoU6fS1?nEKZ@00onFL:KoWWf^oiim[P05
oiil[@CoWW^]1OnMNj`2oiaj[004oj:8^?nRQkOoXXNgoj:7]`;o00001?nSR;L4ojB9^003okVngOnj
_=_o^[cK00Co^[cK00Co^[WHok?dl_ncm?;o/oCb0_nINk45oiQn]PCoUh>k1OnFR<82oiF>bP03oib4
^OnKRKooVhVo00?oVhVo1?nJS/H2oiVDc@03o`000?nIU<goVIC=00;oV9[C00?oX9[>oinOe?nOWm@0
0onOWm@5oijVf`;oWJcQ0_nV/N05ojJhiQGooooo00?o0000ooooooooool0;_ooool0013ooooo00Go
0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Yooooo`04oa<00?lQ003o8@00ob4000;o@`090_m400d3od@0
4003od<04Olf003o>@0000?o>@000_lm00400om000OoWX2boij0/P04oieo/@03oian/OnFKZ?oUVjS
00?oUFfR1OnDK:43oi=[X@CoTfZP0onBJJ05oi9XW`koTFRO1?nAJ:04oi5YX0CoTVZQ0onCJj85oiA]
X`?oUFjT00?oWWb^oiim[_nNOJh00_nNOJh4oiil[@GoWW^]1?nMNj`00onLNZcoXXRhoj:8^003o`00
00;oXXNg1OnSR;L2ojB9^0?o^KkM1?nj_=/3oj;ej@03ok?dl_nINk7oVG^a00;oVG^a1?nHO[H5oiN3
^`?oUXS200?oW82coib4^OnLQ;T00_nLQ;T4oi^9_`CoVXk60_nIU<d00ol0003oVIC=oj6Eb004oj2J
cPGoWioD0_nNY]/2ojN[fPGoY[7P0onV^>H2ojjniQGooooo00?o0000ooooooooool0;Oooool0013o
oooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Uooooo`04o`000?lC003o4`00ob4000;o@0030_m3
00T2od@03@;oA00@00Co=000ocH00?lf003o=P000oli00000olm007oX8:coij0/P03oij0/P;oWGna
0_nGL:@3oiI^X`CoUFfR1?nDK:43oi=[X@CoTfZP1?nBJJ04oi9XW`ooTFRO0onAJ:04oi5YX0CoTVZQ
1?nCJj84oiA]X`04oiE^Y?nNO:koWWb^oiil[PCoWWf^1?nNO:d5oiik[@;oWG^/0_nRRKT3o`000003
oj:8^?nRQkOoXXNg00;oXXNg1OnSR;L00onTRKSo^KkMokVng@03okVng@04okZlfonRmNWoX_GYoj;e
j@CoVWV]0onINk45oiQn]PCoUh>k00CoUXS2oib0/onLP;?oW82c1?nLQ;T4oi^9_`GoVXk600CoVIC=
oj6Eb?l0003oXIG81?nPV/h4oinOe003ojRVe?nWZm[oYj_J00?oYj_J1?nV/N000onV^>Ko[[kVojjn
iP03ojjniQCooooo00?o0000ooooooooool0;Oooool0013ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03ogMgMoo<c<co000000Kooooo0_l0000?ooooo`;o00008_ooool3o`000003oa<00?lk
003o@00300?o@00300Co@`09od@03Om400goA00=0old0002ocH000?o>@001?nPP[<2oij0/P03oiQb
Y_nGL:CoUg2T00;oUg2T1?nFKZ<3oiE]XPCoU6bQ0onCJj45oi=ZX0?oTVVP1?nBJ9l?oi5XW`?oTFRP
1?nAJJ05oi9ZX@?oTf^R0onDKJ<00onMO:koWWb^oiil[P03oiil[P?oWWf^1OnNO:d3oiik[@03oj>;
^_nRRKWo000000;o000000?oXXVioj:8^?nRR;P00_nRR;P4oj:7]`?oXhRg0_nh_ml4okVng@;oQ^_C
0_nKMjT5oiYi[@?oVG^a1OnHO[H2oiN3^`;oW7b_1OnLP;<3oib4^@GoVhVo0_nJS/H2oj>A`P?oXIG8
00?o0000oj6Eb?nPV/h00onPV/h00onOWmCoZ:KDojRVe002ojRVe0GoYj_J0_nV/N02ojnkhPCo[[kV
00?o//GXooooooooool04oooool00ol0003oooooooooo`0/ooooo`004?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo01kooooo0_l000001?lc003o>`00oc/00?lk0003od000`;o@`0900?oA00=oc@00?ld
00000_ld0003ocH00003ocT00?nQQ;CoXHBd00CoX8:c00?oWX2boiQbY_nHLZH01?nGL:@4oiI^X`?o
UFfR1?nDK:43oi=[X@GoTfZP0onBJJ02oi9XWa7oTFRO0onAJ:04oi5YX0GoTVZQ0onCJj801?nDKJ?o
WGb^oiel[_nMO:h5oiil[P?oWWf^1OnNO:d00onNNjgoXh^jo`000002o`0000CoXXVi1?nRR;P4oj:7
]`03oj>8]onh_moo^;oO00?o^;oO00?o^KkMohK[don6jm<01OnKMjT4oiYi[@CoVG^a0onHO[H00onL
N:[oW7b_oial[`02oial[`GoW82c1?nLQ;T3oi^9_`03ojB>_OnSTL;oXi7200?oXi720onQULP00ol0
003oX9[>oj2JcP02ojVQc`GoZ:KD1?nWZmX00on`^=oo[k_RojnkhP03ojnkhP03ojjni_nbaNSo//GX
00;o//GX4oooool2o`0002kooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omg
MgOo0000ooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06oooool2o`00
00?o<`000_lk0003od000`03od<02Ole003o=00000Co=00000?o=P00oj:6]_nRQ[H01?nQQ;@2oj22
/`;oV7BX0onHLZH4oiM`Y0CoUVjS0onEKJ84oiA/X@CoTf^Q1?nCJZ02oi9YX1CoTFRO0onAJ:05oi5Y
X0CoTVZQ0_nCJj800onLNZgoWGb^oiel[P03oiel[PCoWWb^1?nNOJh3oiil[@?o00000onSRkX4oj:9
^@GoXXRh0_nRQkL2okFoh@Co^;oO0_mUe[D3oiafY`CoVgNY1?nJNJd4oiUk/@04oiQn]_nLN:[oW7RZ
oiahZPGoW7b_1?nLP;<4oib4^@03oi^9_onTS[goY8jm00;oY8jm1?nSTL83oj6Eb003o`000?nYXLoo
ZJ7?00?oZJ7?1OnXY]@00onWZm[o/;SOok2hg`02ok2hg`?o[k_R0_ndanP4ok;5j1Gooooo00?o0000
ooooooooool0:oooool002Wooooo0_l0000Dooooo`03o`000?oooooooooo01Sooooo0_l000001?lY
003o<`00oc<00?lc0002oc/00003od000olf003o=P0000;o=@001?ld0002ojB9^@CoXXJf0_nQQ;@0
0onIMZ[oV7BXoiQdZ002oiQdZ0CoV7:V0onGL:@4oiI^X`?oUFfR1OnDK:43oi=[X@?oTfZP00?oTFVP
oi5XWonAJ9l05?nAJ9l4oi5XX0CoTFVP0onBJZ401?nKNJgoW7Z]oiaj[OnLNZd5oiel[PCoWWb^1?nN
OJh3o`0000;oYHfl1?nSRkX5oj:9^@?oXXRh00?o/[kSokFohOne_n400one_n401?nh_mooIMJeofGF
]OnMMJD4oiafY`CoVgNY1OnJNJd2oiUk/@03oiafYonLN:[oW7RZ00?oW7RZ1?nLO:l5oib0/`;oW8Bi
00?oYXbjojB>_OnTS[d00onTS[d5oj>A`P04oj6Eb?n[W/_oZik;o`0000CoZJ7?1?nXY]@00onb]mgo
/;SOok2hg`03ok2hg`03ojnkh_ndanSo]<OX00?o]<OX0_nbaNP2ok;8jaGooooo00?o0000oooooooo
ool0:_ooool002Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Eooooo`04o`00
0?lL003o:@00obT000?o<`0000?o>`00ocH00?lf00000_lf0002ocD00003oc@00?nUSK_oYHfk00Go
Y8Vi0onRQ[H00onQQ;CoVGJZoiUfZP04oiQdZ0CoV7:V1?nGL:@3oiI^X`CoUFfR1?nDK:43oi=[X@04
oi=ZX?nAJJ3oTFVPoi5YX1KoTFRO1?nAJ:04oi5YX004oi9ZXOnKNJgoVgV]oi]i[@CoW7Z]1?nMO:h5
oiil[P03oiim[_l0003o000000GoYHfl1?nSRkX5oj:9^@03oj:8^?nb_^?o/[kS00;o/[kS0one_n40
0ol0003oUWR_oieeY@03oieeY@?oW7JW1?nKMjT5oiYi[@04oiUk/OnLMZOoW7JWoiafY`CoW7RZ1?nL
O:l5oib0/`04oib4^OnVS;[oYXbjojJ<^PCoY8jm1?nSTL800on]WLOoZik;oj^Nb`02oj^Nb`03o`00
0?nYXLooZJ7?00;oZJ7?00?oZ:KDok:ggOnb]md00_nb]md3ok2hg`;o]/_Z1?ndanP00oncc^ko//S[
ok;8j`03ok;8jaCooooo00?o0000ooooooooool0:_ooool002Wooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Cooooo`05o`000?lL003o:@00obT00?lc00000_le0005ocH00003ocD0
0?nWTKkoYi6n00?oYHfk1OnTRKT2oj:6]P03oiUh[?nIMZ[oVGJZ00;oVGJZ0onHM:P4oiQbYPCoUg2T
1?nFKZ<3oiE]XPCoU6bQ0_nCJj400onBJJ3oTFVPoi5YX002oi5YX1OoTFRO0onAJ:02oi5YX0;oVGR/
1OnKNJd3oiaj[@CoWGb^0onNO:h3o`0000?oYY2n1?nUSK`5oj>;^P?oXXVi00?o/;kUok:nhonb_^<0
1?nb_^<00one_n7oU7:YoiidX`05oieeY@CoW7JW1?nKMjT3oiYi[@03oiedY?nLMZOoW7JW00;oW7JW
1?nLN:X5oial[`?oW82c00?oZ8^gojJ<^_nVS;X00_nVS;X5ojB>_@03oj>A`_n]WLOo[Ig700;o[Ig7
1?n[W//00ol0003oZJ7?okBgf`02okBgf`Co/[OM00?o/;SOokK;j_nfbnX00onfbnX00ondanSo/lk^
ok?>kP02ok?>kP?o//S[0_n^bNhDooooo`03o`000?oooooooooo02Wooooo000Yooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool04?ooool2o`d00003oa`00?lY003o<`0000Co=@000_lf
0002ojRE`PCoYi6n1?nUSK/3ojB9^@04oiYj[onIN:coVGR/oiUh[0CoVGJZ0onHM:P4oiQbYPCoUg2T
1?nFKZ<3oiE]XP;oU6bQ0_nBJZ43oi9YX0CoTFVP5onAJ9l2oi5XX003oiQfZonIN:coVGR/00;oVGR/
1OnKNJd3oiaj[@CoWGb^0ol000000onNO:koYi?1ojJ@_P03ojJ@_PGoYHfl1?nSRkX00onRRKWo/;kU
ok2ni@02ok2ni@Co/[kS00CoTffToiAbZOnNM:?oWWBS1OnMMJD4oiafY`CoVgNY00CoVWV]oiedY?nM
M:CoWGBT1?nLMZL4oiahZPGoW7b_00?oW82cojR;]onXRkL00_nXRkL3ojJ<^PCoY8jm00?o[ig5ojfM
aon]WLL00on]WLL3oj^Nb`03okNjfol0003o];OK00Co];OK0_nb]md2okSAk@Co]/_Z00?o/]Kbok?>
k_ncc^h00oncc^h00onbb>_o[/W^ojk9kP03ojk9kQCooooo00?o0000ooooooooool0:?ooool002Wo
oooo0ol0000Gooooo`03o`000?oooooooooo00cooooo00Go0000o`d00?l=003o3@00oc000003oc<0
00?o=@0000?oZiW4ojRE`_nXUL800_nXUL84ojNA_PCoYHfk00CoY8VioiYj[onJNZooVWZ_1?nIN:`3
oiUfZPCoV7BX0onHLZH4oiM`Y0CoUVjS0_nEKJ800onBJj;oTVZQoi9ZX@02oi9ZX@?oTVVP1?nAJJ0G
oi5XW`03oi5XX?nHMZ_oV7J[00GoVGR/1?nKNJd3oiaj[@06oiel[_l0003o0000o`000?nMO:koWWb^
1?nWTl43ojJ@_PGoYHfl0_nSRkX3ojo1i`Go/;kU00Co/[kSoi=]Y?nCKJCoWW>R1?nNM:<4oieeY@Co
W7JW1?nKMjT5oiedY0CoW7JW1?nLN:X3oial[`03ojZ;]?nXRkOoZ8^g00?oZ8^g1?nVS;X00onTS[go
[ig5ojnMa@02ojnMa@Go[Ig700GoZik;okNjfong^]_o]k[Ko`000003okBgf`03okWKlOnhdNgo^=7]
00?o^=7]00?o]/_Zok;Fl_nbe_800_nbe_82ok?>kP?o[M7c1?n^bNh00onVa>ooooooooooo`0Aoooo
o`;o0000:_ooool002Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:ooooo`04
o`000?l=003o3@00o`d000;o<0000_lc0003ocD000?oZiW41?nXUL84ojNA_P;oYHfk00?oVWbaoiYj
[onJNZl00_nJNZl4oiUh[0?oVGJZ1?nHM:P4oiQbYP?oUg2T0_nFKZ<2oi9/X`?oTV^R1?nBJZ44oi9Y
X0?oTFVP5OnAJ9l2oiMeZ`CoV7J[1?nIN:`4oi]i[@04oiaj[Ol0003o0000o`0000?oWGb^00?oZ9K2
ojNC`OnWTl400onWTl44ojJ@_P?oYHfl00?o[lK[ojo1ion_`NL01?n_`NL2ok2ni@;oTFVP0_nCKJ@2
oiicXPCoWWBS1?nMMJD5oiafY`;oVgNY00?oWWBSoiedY?nMM:@00onMM:@4oiafY`CoW7RZ00?oW7b_
ojZ;]?nZRk@00_nZRk@4ojR;]`CoYXbj1On_WLD4ojfMa`03ok_0gOng^]_o]k[K00?o]k[K00?o0000
okWKlOnifo400_nifo42okSAk@Co[mkg0_nbe_82ojWIn0Go[M7c00?o[/W^ojK4konVa>l00_nVa>lD
ooooo`03o`000?oooooooooo02Oooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol00005ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01oooool2
o`000003o`d00?lZ003o:P0000;o<0000_lc00000ole003o^[kLojfMa`04oj^Ia0CoZ9G20onWTKh0
1?nKO[;oVWbaoiYl/OnJO;44oiYj[`CoVGR/0onIMZX4oiQdZ0CoV7:V0_nGL:@00onBKJCoTVbSoi9/
X`02oi9/X`?oTV^R1?nBJZ44oi9YX0CoTFVP4OnAJ9l00onGM:[oUgF[oiMeZ`02oiMeZ`CoV7J[1?nI
N:`2oi]i[@?o00000onLNZd00onMO:koZ9K2ojRF`P02ojRF`PCoYi?11?nVT;h00onUSKco[lK[ojo6
j`02ojo6j`Co[l7W00?oTFJMoi5YX?nAJJ000_nAJJ001?nCKJCoWW>RoiicX_nNLj84oiidX`GoWGFU
1?nLMZL00onKMjWoWWBSoiidX`05oiedY0CoW7JW1?nLN:X5ojZ;]0GoZ8^g0_nVS;X2ok>Qa@Co[ig5
0on]WLL3ok_0g@?o]k[K00?o]nWfo`000?nifo400_nifo42ojOXnPCo[mkg00?oX=olojWIn?nYfOP0
0onYfOP2ojgAl`;oY<Wc1OnVa>lEooooo`03o`000?oooooooooo02Kooooo000>ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool01?ooool2o`000004ob800?lZ003o:P00obX0
00;o<00000?o<`00okc1g_nj_]`01?n]WLL3oj^Ia0CoZ9G200CoYi6noi]n/_nKO[;oVgjb1?nJO;44
oiYj[`?oVGR/1?nIMZX3oiQdZ0CoV7:V00?oUg2Toi9]Y?nBKJ@01?nBK:<4oi9[XP?oTVZQ1?nBJJ04
oi5YX0ooTFRO0onGM:X5oiMeZ`?oV7J[0onIN:`3o`0000?oVgV]0_nLNZd00onYUlCoZ9K2ojRF`P03
ojRF`PGoYi?10_nVT;h3ojo@l@Co[lK[00Co[l7Woi5VWOnAIYgoTFJM0onAJJ000onNLZ7oWW>Roiic
XP03oiicXP?oWWBS1OnMMJD3oiafY`03oimeXonNM:?oWWBS00;oWWBS1?nMM:@5oiafY`;oW7RZ00?o
[8bdojZ;]?nZRk@00onZRk@5ojR;]`04ojJ<^_ncXLGo/j75ok>Qa@Go[ig500?o[Ig7ok_0gOnk`=d0
0_nk`=d00ong^]_o]nWfokOYmP02okOYmP03o`000?nifo7oYnSj00?oYnSj00?o[mkgoj3Oo?nPgo`0
0_nPgo`2ojWIn0?oXLgg1?nTbO<2ojK4k`?oXKk^5?ooool00ol0003oooooooooo`0Vooooo`001_oo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo
0_l0000Mooooo`06o`000?ooooooooooooooool0003o5`000_lR0003obX00005oc000?nl`Mko_<7N
okc1g_n_XLX01On]WLL4oj^Ia0;oZ9G200?oWH6doi]n/_nKO[800onKO[83oiYl/@CoVWZ_0onIN:`4
oiUfZP?oV7BX0_nHLZH2oi9^YP?oTVfT1?nBK:<4oi9[XP?oTVZQ1?nBJJ04oi5YX0goTFRO00?oUWBZ
oiMdZ_nGM:X00onGM:X4oiMeZ`?oV7J[00?oVGR/o`000?l000000_nIN:`4oi]i[@04oiaj[OnYUlCo
ZIO4ojVGa0CoZ9K21OnWTl400onVT;ko[m3aojo@l@03ojo@l@;o[lK[0_n@I9/3oi5VW@04oi5YX?nN
LZ7oWW:QoiibX@GoWW>R0onNM:<5oieeY@04oiafYonOMJ?oWgFSoimeX`CoWWBS1?nMM:@5oiafY`04
oiahZ_n/S;Co[8bdojb<]0GoZX^d0onXRkL00onhZ<Wo/j75ok>Qa@02ok>Qa@Co[ig50_nobn<3ok_0
g@?oYOC`0_ngjOH2oi3Zm@03o`000?nWj?[oYnSj00?oT>?m0_nPgo`3oi_?nPGoXLgg0_nTbO<2oj2n
kPGoXKk^5?ooool00ol0003oooooooooo`0Uooooo`003_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`0Mooooo`04o`000?l8003o5`00
oaL000;o8P0000?o:P00okk5gonm`ml00onm`ml01?nl`Mko[j7:ojnQb_n_XLX5ojfMa`;oZiW400Co
WX>foif1]?nMPKCoWH6d1OnKO[83oiYl/@CoVWZ_1?nIN:`3oiUfZP;oV7BX00?oTVnWoi9^Y_nBKZH0
0_nBKZH4oi9]Y0?oTVbS1?nBJj84oi9ZX@?oTVVP1?nAJJ09oi5XW`;oUW>Z0onFM:X5oiMdZPCoUgF[
00CoV7J[o`000?l0003o00001?nIN:`2oi]i[@;oZ9S51?nYUl@5ojRF`P;oYi?10on_g?L4ojo@l@Go
T6BK0onAIYd4oiibX@GoWW>R1?nNM:<3oieeY@03oj9hY?nOMJ?oWgFS00;oWgFS1?nNM:<5oiedY0?o
W7JW00?o[hndojb<]?n/S;@00_n/S;@5ojZ;]004ojR;]onhZ<Wo^:S9okRXb@Go/j7500?o[ig5oko;
honobn<00onobn<01?nk`=goYOC`ojGdl?nUm?02oeoGe`;oT>[e0_mhgOL01?l0003oN=ggoi3SoOn@
hod3oi?>o0CoVloj0_nQcOL2oijmk`GoX;k^0_nQ_^h2oj2kk1Gooooo00?o0000ooooooooool09?oo
ool000kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o
0000ooooooooool07?ooool2o`P000;o5`0000?o8P00okk5gonnaMl00onnaMl2okg3g`03ok6Uc?n_
XL[o[j7:00?o[j7:0on]WLL01?nPQkSoWX>foij3]_nNPkH4oif1]0CoVgjb0onJO;44oiYj[`CoVGR/
0_nIMZX01?nBL:WoTVnWoi9_YonBKjL4oi9^YPCoTVfT0onBK:<4oi9[XPCoTVZQ0onBJJ04oi5YX0Ko
TFRO00?oUG>ZoiIcZ_nFLjX00_nFLjX4oiIdZPCoUgBZ0_nGMJ/3o`0000?oV7J[0onIN:`00onXVLKo
Z9S5ojRHa@03ojRHa@?oZIO41?nXU/82oj[YnPGo[mcg00Co[m3aoi1RVOn@HYWoT6:I1?n@I9/2oi5V
W@03oieaX?nNLZ7oWW:Q00?oWW:Q1?nNLj84oiidX`;oWGFU0_nRN:@5oimeX`?oWWBS1OnMM:@2oiaf
Y`?o[hnd0on/S;@4ojZ;]003ol6hdOnhZ<Wo^:S900?o^:S90oncXLD2ol;Lk0Co_l_S0_mXfL001OnU
m?3oGmOGoeoGeomOemOoFm7]00?oR/?k00CoS/_lo`000?n>bocoS/_l0_nCc_`2oiZdjPCoW;[]1OnN
_Nl2oj2nkP?oWkW[1?nP^n`Cooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`02Oooool000kooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00?ooooo0_l0000Kooooo`?o200000Co5`00okkWl_no
a]oo_lKO1?nnaMl00ondZLko/JG<ok6Uc002ok6Uc0Go[j7:00?o[Ig7oj27^?nPQkP01?nNPkH3oif1
]0CoVgjb1?nJO;43oiYj[`;oVGR/0_nBLZX3oi9`Z@CoTVnW0onBKZH4oi9]Y0CoTVbS0onBJj84oi9Z
X@CoTVVP0onAJJ03oi5XW`04oiEcZonELj[oUG>ZoiEcZPGoUW>Z0onFM:X3oiMdZP?o00000_nGMJ/4
oiQfZ`03oiUh[?nXVLKoZ9W600;oZ9W61?nXV<D4ojVGa003ojRF`_nZjO[oZ^Wj00?oZ^Wj0_n_g?L2
oi1QV0CoT6:I1?n@I9/00onAIYgoWG6PoieaX005oiibX@CoWW>R1?nNM:<01?nMMJGoXWRToj9hY?nR
N:@5oimeX`?oWWBS1OnMM:@00onLMZOo[hndojn?]002ojn?]0Co[8bd0_nZRk@3ol6hd@Co^:S900?o
/j75ol;Lk?o2g>`00oo2g>`00onobn?oJ=W0ofSI`002oi6^jPCoS;[e1On:`o/00on>boco0000oiZ^
i@05oiZdjPCoW;[]0_nN_Nl3oinfj0GoWkW[0_nP^n`2oj:jjQCooooo00?o0000ooooooooool01Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ
8B402Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001?ooool2o`0001Wooooo00CoHmS<oj7cl?nQlo3oXO?`0onnio84oko6g`03okk5gondZLko
]:W>00;o]:W>0onaYL`4ojnQbP03oj>:^_nPQkSoX8Nh00;oX8Nh0onNPkH3oif1]0GoVgjb0onJO;42
oiYj[`03oi=c[?nBLZ[oTW:Z00;oTW:Z1?nBL:T3oi9_Y`?oTVjV1?nBKJ@4oi9/X`?oTV^R1?nBJZ44
oi9YX0?oTFVP00CoTFROoiEcZonELj_oUG>[1?nELjX4oiIcZP?oUWBZ0ol000000onGM:[oUgF[oiMe
Z`03oiMeZ`;oV7J[00?oYiW7ojRIa_nXVLH00onXVLH4ojRHa@?oZIO40onKl?<2oj[YnP;oSf6G1?n@
HIP4oi1RV@?oT6BK00?oW76PoieaX?nMLJ000_nMLJ04oiibX@GoWW>R0onNM:<5oj9hY0CoWgFS1?nN
M:<3oiedY003ok:C]on_SkCo[hnd00?o[hnd1?n/S;@00onZRkCo`KSAol6hd@02ol6hd@?o^:S90_nh
l_@4ol;Lk0;oUj;M1OnA[^X4ohbjm@;oR/?k0_nJYMd2oiZ^i@03o`000?nJ[^GoV[CZ00CoV[CZ0_nL
^^d2oinbi@GoWkKX0_nO^N/2oj:gi`GoX[[Z5?ooool00ol0003oooooooooo`04ooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Wooooo000>ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo00?o0000oooo
ooooool05Oooool2og[Uh`?oZo7e0oo0ho000oo0a]oo_lKOoko6g`03oko6g`Go]:W>1?naYL`01?n_
XL[oXhZjoj>:^_nSR[X4oj27^0?oWX>f1?nMPK@4oi]n/P;oVWba00CoU7F]oi=c[?nCLjcoTg>/1?nB
LZX4oi9`Z@?oTVnW1?nBKZH3oi9]Y0CoTVbS1?nBJj83oi9ZX@CoTVVP0_nAJJ000onDM:coUG>[oiEc
Z`03oiEcZ`?oUG>Z1?nFLjX3o`0000GoUgBZ1?nGMJ/01?nHMZ_oYiW7ojNIaonWVLL4ojRIaPGoZ9S5
00CoZIO4oi_`lonKl??oVo3c0_n?H9H3ohmQU`GoT66H0on@HYT01?n@I9_oW76PoiaaX?nLLJ04oiea
X0CoWW:Q1OnNLj82oiidX`03ojImYonRN:CoXWRT00?oXWRT1?nOMJ<4oiidX`;oWGBT0onbTkL5ojn?
]0;o[8bd00?oc=KQol6hdOo1^=401?o1^=400onhZ<Wo^?;dokSbm002okSbm003ol;Lk?nLV<ooUj;M
00?oUj;M0_nA[^X2oinHc@CoW9kE1OnJYMd2oiZ^i@04o`000?nJ[^GoV[CZoiZdjP;oX:gQ1OnO/^D2
oinfj0;oXk?T1OnR]nL3oj:jjP03ojFljOoooooooooo01;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P09ooooo`009ooo
ool00ol0003oooooooooo`0Aooooo`;o?/7100?oN^GSok7]monakOL00_nakOL01?n[lOGo`>?`ol3S
l?o0ho03ol36g`?o_lKO0_nf[M05okBYcP;o/JG<00?oYHjmoj>:^_nSR[X00_nSR[X4oj27^0CoWX>f
0onMPK@2oi]n/P;oUGN^0onDMJd4oi=c[0?oTW:Z1?nBL:T3oi9_Y`CoTVjV1?nBKJ@3oi9/X`CoTV^R
0onBJZ42oi9YX0GoU7B/1OnELj/3oiEcZP04oiIcZ_l0003o0000o`0000?oUWBZ1OnGM:X2oiMeZ`;o
YIS81?nWVLL5ojRIaP;oZ9S50_mnim`2ohmOUPCoSf2F1?n?HIL4oi1QV0?oT6:I1?nLLJ04oieaX0Co
WW:Q1OnNLj800onNM:?oYWfWojImY`05oj9hY0CoWgFS1?nNM:<00onMM:Co/Y>gok:C]`02ok:C]`Go
[hnd00Co[8bdolcFhOo<e^7oc=KQ1?o1^=42ogOSb`;o^?;d1?nLV<l3oiNRg@03oj:EaonOV<goWiS=
00?oWiS=1?nLW]D4oiZUg@;oVZkU00?o0000oj6Yg?nP[N401?nP[N42oinbi@;oY;3Q1OnS/n@4oj:g
i`03oj:jj_nU_>WoYKcY00;oYKcY5?ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Wooooo000Wooooo`;o00003oooool3
oe[Ch0;oS^_c1?nakOL3ol3NkP03ol3Sl?o0a]oo`<KO00?o`<KO00?o_lKOokJ]d?nf[M000_nf[M03
okBYcP03ojRB_onUS[goYHjm00;oYHjm1?nSR[X4oj27^0?oWX>f0_nMPK@00onGNK3oUGN^oiEg[P02
oiEg[PCoU7F]0onCLj`4oi9bZP?oTW2Y0onBKjL4oi9^YPCoTVfT0onBK:<4oi9[XP;oTVZQ00?oTgB]
oiAd[?nDM:`01_nDM:`4oiEcZ`;oUG>Z0_l00003oiIcZPCoUWBZ0onGM:X00onTV<SoYIS8ojFHb003
ojFHb0?oYiW71?nXVLH00omId;OoSenFohmOUP04ohmOUPCoSf2F1?n?HIL4oi1QV0;oT6:I00?oVg2P
oiaaX?nLLJ000onLLJ03oieaX0GoWW:Q0onNLj800on[Q:coYWfWojImY`02ojImY`CoXWRT1OnOMJ<3
oiidX`Go/Y>g1?n_Sk@00oo0oN?oc=KQolcFh@03olcFh@04ol6hdOmghl_oMn?;ogOSb`?oX9751OnL
V<l01?nGX]goXYG7oj:EaonRULL4oinHc@CoW9kE0_nJYMd2oj>TeP?oXJWL00?o0000oj6Yg?nP[N40
0_nP[N400onU[MgoY;3QojB`h@03ojB`h@CoXk?T0_nR]nL3ojJii`CoYKcY5Oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@
00Wooooo000Wooooo`03o`000?oooooooooo00_ooooo0ombg?D3oi_Xn`?o]NKf00?o/Nggol3Nk_o0
g^h00_o0g^h3ol37g`?o`<KO00?o^;7BokJ]d?nf[M001?nf[M001?ndZLkoZ9:oojRB_onXT[l3ojF>
_@CoXhZj1?nPQkP2oij3]P04oiQk/OnGNK3oUgV`oiMi/0CoUGN^1?nDMJd3oi=c[0CoTW:Z0onBL:T4
oi9_Y`?oTVjV1?nBKJ@3oi9/X`;oTV^R0_nBM:h3oi=d[@SoU7B/0onELj/3o`000003oiEcZ_nFLj[o
UW>Z00?oUW>Z0onFM:X00onGM:[oY9S8ojBHb002ojBHb0CoYIS81?nWVLL00onXVLKoSenFohmOUP07
ohmOUPGoSf2F0on?HIL4oi1QV003oi1RVOnKL:3oVg2P00GoW76P0onMLJ05oiibX@;oWW>R0_n[Q:`4
ojImY`CoXWRT1OnOMJ<2oiidX`;o]IZl1OnbTkL2ojn?]0?o`?gS0_o<e^400onVS;WoY8jnojB>_P03
ojB>_PCoX9750_nLV<l2ojND`PCoXYG71OnOV<d2oibNe@03ojFQdOnSY=KoXjCF00?oXjCF0onQZM`0
0ol0003oXJWLoj2]h@03ojF]g@GoY;3Q0_nS/n@2ojNgi@GoY[WW0_nU_>T2ojRnjA;ooooo0ol00004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Wooooo
000Wooooo`03o`000?oooooooooo00Sooooo0on4f_h3ojCQo003oi_Xnonei_Ko]NKf00;o]NKf1?o0
fN`00oo0g^ko`<OOol37g`03ol37g`04ol36gonh/M;o^;7BokRadPCo]Zg@00?oZiS3ojRB_onXT[l0
0_nXT[l3ojF>_@CoXhZj0_nPQkP2oiYn/`?oV7^a1?nGNK03oiEg[PCoU7F]0onCLj`4oi9bZPCoTW2Y
0onBKjL3oi9^YP;oTVfT0_n@M:l3oi5d[`CoTWB^1?nCM:d7oiAd[0?o000000?oUG>[oiEcZ_nELjX0
0_nELjX4oiIcZP;oUWBZ00?oXYO9ojBHb?nTV<P00onTV<P5ojFHb0;oYiW72on?GiH5ohmPUP?oSf6G
0on@HIP00onJKj3oVg2Poi]`X002oi]`X0CoW76P0onMLJ05oiibX@03oiicX_n[Q:coZhB/00;oZhB/
0onVOJL5oj9hY0CoWgFS00CoWWBSokFJ_?neV[co]IZl1OnbTkL01On_SkCo`?gSol3mhoo0oN?oV8Jn
00CoYXbi1?nTS[h3oj2Aa@03oj^E`?nWU<;oYiC200?oYiC21?nRULL2oinHc@;oZIo=1?nUXM45oj>T
eP;oXJWL00?o0000ojN[f_nU[Md01?nU[Md2ojB`h@;oZ;GR1OnW]nD2ojJii`;oZKgX1OnX_^TDoooo
o`09o`000?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@09ooooo`009_ooool3o`0000?ooooo0_nEaoT4ohoBoP?oZ=Oh0_nThO`4okOMl`03okGV
m_o0fNco`=W/00;o`=W/0_o1a]h4ol37g`03okZddonh/M;o^;7B00?o^;7B00?o]Zg@oj^H`on[V<<0
0_n[V<<3ojRB_`CoYHjm0_nSR[X00onKPKKoVWjcoiYn/`02oiYn/`CoV7^a0onGNK04oiEg[P?oU7F]
1?nCLj`3oi9bZPCoTW2Y0onBKjL2oi9^YP03oi1c[on@M:ooT7B_00;oT7B_0onAM:l5oi9d[P?oTgB]
1?nDM:`3o`0000GoUG>[0onELjX2oiIcZP;oX9K91?nRUlT4ojBHb0CoYIS83on?GiH4ohmPUP?oSf6G
00CoT66HoiY_X?nJKj3oVVnP1?nKL:04oiaaX0CoWG6P0onNLZ400onaT;CoZhB/oj^4[003oj^4[0?o
YWfW1OnRN:@3oimeX`03okVUaOneV[co]IZl00;o]IZl1?nbTkL01Ol0003oXX>coij4]onNQ;OoZHbg
00GoYXbi1OnTS[h01?nPTLGoZiG0oj^E`?n[UL04ojND`P?oXYG700?o[9k:ojVOcOnYWld00onYWld4
ojFQd@;oXjCF0_nZZ]L3ojN[fP04o`000?nWZm[oYJgMojF]g@;oZ[CP1OnX]N82ojNgi@;oZ[cW1OnY
_NP2ojRnj@;oZ/3Z5Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003ooooooiNkl@02
oiNkl@CoULOi00?oSm;nojSGn?nXeoP00_nXeoP3okODk`?o]mgc1?o0dnT00oo0fNco`LKNol76gP02
ol76gP03ol37gonj]=?o^[CC00;o^[CC0onh/M800on^WLKoZiS3oj^H``03oj^H``CoZ9:o0_nUS[d0
1?nMQKSoVh6foi^1]_nKPKH4oiYn/`CoV7^a0onGNK04oiEg[PCoU7F]0onCLj`3oi9bZP;oTW2Y0_n?
LZh3ohmb[`?oT7>_1On@M:l3oi5d[`CoTWB^0onCM:d01?nDM:co0000o`000?l00003oiAd[0GoUG>[
0_nELjX00onNUL[oX9K9oj2Fb@03oj2Fb@?oXYO91OnTV<P01?nUV<SoSUnFohiOU_n>GiH>ohmOUPCo
Sf2F0_n?HIL00onIKZ3oVVnPoiY_X002oiY_X0CoVg2P1?nLLJ04oieaX0;oWW:Q0_naT;@5oj^4[0?o
YWfW1OnRN:@00onOMJ?o^JG5okVUa@02okVUa@Co]IZl0_nbTkL3oj:3/`04oij4]onYS;OoZHbgojV<
]`CoYXbi1?nTS[h00on_V<3oZiG0oj^E`002oj^E`0GoYiC200CoXYG7ojbNb_n/W/[o[9k:1?nYWld3
ojFQd@03ojf[eOnZZ]OoZZ[G00?oZZ[G0onWZmX00ol0003oZ[CPojZdh003ojZdh0?oZ;GR00?oZkcV
ojZlionZ_>L00onZ_>L3ojVmj0;oZl3Y1?nZ`>XDooooo`03o`000?oooooooooo01kooooo000Koooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooooiNkl@03oiNkl@;oULOi1?nYbo80
0onXeoSo]mC_okODk`03okODk`03okOMloo0dnWo`=?Y00;o`=?Y1Oo1a]h2okbhe@Go^[CC00Co^;7B
ojjMa_n^WLKo[Yg61?n[V<<4ojRB_`03ojF>_OnMQKSoWHFh00CoVh6f1?nJO[<3oiQk/@CoUgV`0onE
Mjh4oiAe[@;oTg>/00CoT7:]ohmb[On?LZgoSg:]1?n?LZh3ohmb[`CoT7>_1?n@M:l3oi5d[`CoTWB^
00CoTgB]o`000?l0003o00001onDM:`3oiEcZ`03oibDb_nNUL[oWYG:00;oWYG:1?nPU/T4oj:Gb@;o
Y9S81_n>GiH>ohmOUPCoSf2F00?oSf6GoiU^X?nIKZ001OnJKj03oi]`X0CoW76P1?nMLJ000onNLZ7o
/I2dok6@]002ok6@]0CoZhB/1?nVOJL3oj9hY003okjje_niYLGo^JG500?o^JG51?neV[`01OnbTkOo
XX>coj:3/onRPk?oZhjg00CoZHbg1OnVS;T01?nTS[ko[iS0ojnH`?n_V<04oj^E`0CoYiC200?o[j79
ojbNb_n/W/X00_n/W/X5ojVOc@04ojFQdOn]ZmGo[J_Eojf[e@GoZZ[G00CoYj_Jojbcg_n//mko0000
1OnZ]>001?nX]N;oZkcVoj^li_n[_>H5ojZli`03ojVmj?n[`>WoZl3Y00;oZl3Y0_nZ`>X2oj_2jQCo
oooo00?o0000ooooooooool07Oooool001_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03
o`000?oooooooooo00;oUk_a0onY`>/3ojW;lP;o]/_Z1?nge>l3oko>iP03ol3CjOo1a]ko`LKN00Co
`LKN1?nl^=D3okZdd`03ok6SbOn^WLKo[Yg600;o[Yg61On[V<<2ojRB_`03oj29^onMQKSoWHFh00;o
WHFh0onKPKH4oiYn/`CoV7^a0onGNK03oiEg[P;oU7F]1On@LZd3ohmb[@CoSg:^1?n?LZl3oi1c[`Co
T7B_0onAM:l2oi9d[P?o00000onCM:d7oiAd[003oiEcZonLU<[oW9C:00;oW9C:0onNULX4oj2Fb@?o
XYO92On>GiH>ohmOUP?oSf2F00CoV6fPoiU^X?nIKZ3oVFjP1OnJKj03oi]`X0GoW76P0onMLJ05ok6@
]0CoZhB/1?nVOJL2oj9hY0?o_[[F1?niYLD3okFJ_0;oYHBa00?oXX>coj^>]on[S[L00_n[S[L3ojV<
]`CoYXbi00?o/Yg2ojnH`?n_V<000on_V<04oj^E`004ojND`_n_XLWo[j79ojnQb@Go[9k:0_nYWld2
ok6^e@Go[J_E0_nZZ]L2ojjeg@?o[;?N00Co0000ojbcg_nZ]>3oZ[CP0_n]_ND5oj^liP;oZ[cW0_n/
`>T4oj_0j@03oj_2jon[`^[oZl;Z00?oZl;Z4oooool2o`0001kooooo000Kooooo`05oa0@4?oooooo
ooooooooool@41001_ooool2o`0000;ooooo1OnY`>/00onYbo;o]/_ZokK;jP02okK;jP03okODkono
c^Ko_lkV00;o_lkV0oo1aMh3ol76gP03okjkeonl^=Go_;SE00Co_;SE00Co^[CCok6SbOnaXlWo/J?9
1?n^WLH2oj^H``;oXXjo1?nPRK/3oif5^0?oVh6f1?nJO[<4oiQk/@;oUgV`00CoTWF_oi5c[_nALjko
TG>^2?n@LZd3ohmb[@?oSg:^1?n?LZl3oi1c[`CoT7B_0_nAM:l3o`0000?oTWB^0onCM:d2oiAd[0;o
VI7:0onKT/X5oibDbP?oWYG:1OnPU/T00onRUlWoSUnFohiOUP08ohiOUPkoSenF00CoSf2FoiQ]X?nH
KJ3oV6fP1?nIKZ04oiY_X0?oVg2P1OnLLJ02oieaX003ok^T`_naT;Co/I2d00?o/I2d1On[Q:`3ojIm
Y`03oj9hY?nn^]Ko_[[F00;o_[[F1OniYLD01?neV[coYHBaojF4/On]T;P5oj^>]`CoZHbg0_nVS;T3
ok:M`PCo[iS00on[UL000onbY<[o[j79ojnQb@03ojnQb@?o[9k:00?o/k;Gok6^eOna[]D00ona[]D3
ojf[e@03ok2gg_n^]Mgo[[GM00?o[[GM0on//mh00ol0003o[KgUojfmi@03ojfmi@;oZkcV0_n/`NT5
ojc0j@03oj_0jOn[`^_oZl;[00;oZl;[0on[`^X00on[`^_oooooooooo`0@ooooo`03o`000?oooooo
000001kooooo000Kooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02
ooooo`;oZL3[0one`n@3okK;jPCo_/WS00?o_lkVol75g_o1aMh00oo1aMh01?o1a]ko_[_Gokjkeonn
^mL4okbhe@03okBYcOnaXlWo/J?900;o/J?90on^WLH00onUTl?oXXjooj:>_`02oj:>_`CoX8Vk0onM
QKP4oi^1]P?oVWjc0_nHNk42oi=g/0?oTWF_0onALjh8oi1b[@?oSg:]1?n?LZh3ohmb[`?oT7>_1?n@
M:l2o`0000;oTGB_1?nBM:h2oi=d[@03oiN?bOnITL[oVI7:00?oVI7:0onKT/X4oibDbPCoWYG:0_nP
U/T2ohmPU`_oSUnF3On?GiH00onGKJ3oV6fPoiQ]X002oiQ]X0CoVFjP1?nJKj03oi]`X0GoW76P00Co
WG6Pok^T`_nkY<;o^jC21?naT;@5oj^4[0;oYWfW00?o_Mg`okjje_nn^]H00onn^]H4okVUa@;oYhJ`
00CoYHBaojf@^?n]T;So[I2h1?n[S[L4ojV<]`03ojJ<^OnbWL;o/Yg200;o/Yg21?n_V<000on[UL3o
/ZC:ok:TbP02ok:TbPCo[j7900?o[9k:ok>beonc/]L00_nc/]L4ok6^e@03ojf[eOn`]mko/;ON00;o
/;ON1?n^]Md01On//mko[[kVojjni_n^_^Ko000000?o[KgU0_n]`^T4ojc1j@;o[<3Y0on/`n/4oj_2
j`03oj_2j_n[`^_oZl;[00;oZl;[5?ooool00ol0003oooooooooo`0Kooooo`006oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool5okG3i003okK;j_nnbN?o_/WS
00;o_/WS0_o1aMd4ol75gP03oknnfOnn^mOo_[_G00?o_[_G00?o_;SEokBYcOndZLd00_ndZLd4ok6S
b@04ojjMa_nUTl?oYI?3ojFC``?oXXjo1?nPRK/4oif5^0?oVh6f0_nJO[<00onDN[?oTgN`oi=g/002
oi=g/0CoTWF_0onALjh7oi1b[@?oSg:]1?n?LZh3ohmb[`CoT7>_0ol000001?n@M:ooTGB_oi5d[onA
M:l2oi9d[P;oUHg81?nGSlT4oiVAbP?oVi;:1OnLU<X2oijEbP;oSf6H0on?H9L;ohiOUPcoSenF0_nG
KJ05oiQ]X0?oVFjP1?nJKj04oi]`X0?oW76P00?oalGHok^T`_nkY<800_nkY<85ok6@]0CoZhB/00Co
YWfWokgMl?nmgO3o_Mg`1Onn^]H01OniYLGoYhJ`ojN6/?nWQ[3o[YBl00Co[I2h1On[S[L2ojV<]`03
okJTaonbWL;o/Yg200?o/Yg20on_V<000ondZ/ko/ZC:ok:TbP03ok:TbP?o[j7900?o][WKok>beonc
/]L00onc/]L3ok6^e@03ok:lhOn`]mko/;ON00Co/;ON0_n^]Md2ok32i`?o[[kV00?o0000ojfmiOn]
`^T01?n]`^T2ojc1j@;o[<C/1On/`n/2oj_2j`;oZl?[0on[`^/00onZ`^_oooooooooo`0Cooooo`03
o`000?oooooooooo01[ooooo000Kooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003o
ooooooooo`05ooooo`?o]L?T1?nla>000onnbN?o`LGMol75g@02ol75g@03ol75g_no_]Wo_kkI00;o
_kkI0onn^mL00ong[m7o]:W=okBYc@03okBYc@?o/J?900?oZ9[7ojFC`onUTl<00_nUTl<4oj:>_`Co
X8Vk0onMQKP2oi^1]P04oiIl]OnDN[?oU7ZcoiAj/`CoTgN`1?nBMJl3oi5c[POoT7:]0on?LZd4ohmb
[PCoSg:_0ol00002oi1d[`;oThS40onDRlL5oiF=b0?oUho91?nITLX4oi^BbP;oW9C:0on@HiT3ohmQ
V0?oSf2G2on>GiH9ohmOUP;oUVbP0onGKJ05oiQ]X0?oVFjP1?nJKj04oi]`X0;oW76P0oo7aMP3ok^T
`PGo/I2d0_n[Q:`4oh7Xg`?o_Mg`0_nn^]H3ojV8/P;oYhJ`0on^U;`3ojf@^0GoZhjg00CoZHbgokJT
aonfY<Oo]ZC71OnbWL801?n_V<3o]:[>okBZc_ndZ/h5ok:TbP04ojnQbOnf^M_o][WKokJif`Go/k;G
00Co/JkEok:lhOnb_>7o/[cQ1?n`]mh00on`aNWo/<;Wok32i`03ok32i`;o[[kV00?o[LC[o`000?n]
`^T00on]`^T00on/a^go[<C/ojc4k003ojc4k0;o[<?[0_n[a>`5oj_3j`04oj_2jonZ`^_oZ/;[oj[2
jaCooooo00?o0000ooooooooool06_ooool001_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o00001oooool00one`nCo_<CPokc4h002okc4h003ol74gOo1aMgo`LGM00?o`LGM00?o`<7Joknn
fOno_]T00ono_]T01?nn^mOo]joAokN_dOng[m45okBYc@04ok6SbOnXV/OoZ9[7ojRJa`?oYI?31?nR
S[l4oj29^`;oWHFh00CoUh2hoiIl]OnFO;GoUWbe1?nDN[<3oi=g/0CoTWF_0onALjh7oi1b[@CoSg:]
0on?LZh01?n?LZoo0000o`000?l00002oi1c[`03oi>6`_nCR<CoThS400?oThS40onDRlL4oiF=b0?o
Uho91OnITLX2oi^BbP;oTFBK1?n@HiT3ohmQV0CoSf2G2_n>GiH6ohmOUP03oiA[X?nFK:3oUVbP00;o
UVbP1?nGKJ04oiQ]X0?oVFjP1OnJKj03oi]`X003oiaaX?o7aMSoalGH00;oalGH1?nkY<83ok6@]0?o
XGj]00CoXWn^ojb?]on/SkOo[8ng1?n[Rk@4ojV8/P03ojN6/?n^U;co[YBl00;o[YBl1?n]T;P3oj^>
]`03okR]c_nfY<Oo]ZC700;o]ZC71?nbWL800ong/]Co]:[>okBZcP02okBZcPCo/ZC:00?o]l7QokJi
fonf^M/00onf^M/2ok>be`;o/l7T1Onb_>400on`]mko/<GYok35j@02ok35j@;o/<;W0_n]and4ojg4
j`03o`000?n]`^Wo[<K]00?o[<K]0_n/a>`2oj_5k@GoZlC/0_n[`n/2oj[3k0GoZ/;[5?ooool00ol0
003oooooooooo`0Iooooo`006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooo
ooooool01oooool3okc4h0?o`LCM0oo1aMd3ol31fP?o_kkI00?o^[KEokN_dOng[m400ong[m42okBY
c@;o[:7<1?nXV/L4ojFC``?oXXjo0_nPRK/2oiV4_0?oUh2h1?nFO;D3oiAj/`CoTgN`0onBMJl3oi5c
[PSoT7:]0on?LZd01?n?LZko0000o`000?l00003oi>3_`CoThK21?nCR<@3oiB;a`CoUHg81?nGSlT2
oiVAbP?oTVNM0onAI9/4oi1SV@?oSf6H1?n?H9L:ohiOUPGoSenF0_nDJj04oiI/X0CoUffP1?nHKJ03
oiU^X0GoVVnP0_nKL:02olSdk@CoalGH1?nkY<800onaT;CoXGj]oj5n[@02oj5n[@03ojfC^on/SkOo
[8ng00;o[8ng1On[Rk@2ojV8/P03ojnI`?n^U;co[YBl00?o[YBl1?n]T;P00on[S[Oo^:g>okR]cP02
okR]cPCo]ZC700?o/Yg2okNbe?ng/]@00_ng/]@4okBZcP03ok:Tb_ng`N7o]l7Q00;o]l7Q0onf^M/2
ok;8jPCo/l7T0_nb_>43ok3:k@?o/<GY0_n/b^l4ojg7k@;o[LC[0_n[anh01?l0003o[<K]ojc6kOn/
a^d2oj[6kPCoZlG]0_n[a>`7oj[3k0;oZ/;[0_nY`N/Dooooo`03o`000?oooooooooo01Wooooo000U
ooooo`03o`000?oooooooooo00Sooooo00?o_<CPol74gOo1a=d00oo1a=d00oo1aMgo`<7Jol31fP03
ol31fP04oknnfOnj]]Go^[KEokZfe@?o]joA00?o[jSAojbQc?n/XL`00on/XL`3ojRJa`CoYI?30_nR
S[l00onKRL3oVHBloiV4_003oiV4_0?oUh2h0onFO;D3oiAj/`CoTgN`0onBMJl4oi5c[POoT7:]00Co
Sg:]o`000?l0003o00000onCPKd4oi>3_`?oThK21?nCR<@3oiB;a`GoUHg80_nGSlT3oiA[X0?oTVNM
1?nAI9/3oi1SV@?oSf6H1?n?H9L:ohiOUP;oSenF0_nCJZ03oiA[X0CoUVbP1?nGKJ04oiQ]X0?oVFjP
1OnJKj000onKL:3ob?C]olSdk@02olSdk@CoalGH0_nkY<84oj5n[@Co[I>k0on/SkL5oj^;]004ojV8
/_n_VL3o[iW0ojnI`0Go[YBl0_n]T;P00onj]mOo^:g>okR]cP03okR]cP?o]ZC700?o]kcMokNbe?ng
/]@00ong/]@3okBZcP;o]/[Y1?ng`N400onf^M_o//SZok;8jP03ok;8jP;o/l7T0_n^c_45ok3:k@03
ok35jOn/b^oo[<[_00;o[<[_0_n]and2oj[9l0?oZlO^00?o0000oj_7k_n/a^d01?nZa^h2oj_5k@;o
ZLC]1onZ`n`2ojW2k0CoZL7[4_ooool00ol0003oooooo`00000Jooooo`009Oooool00ol0003ooooo
ooooo`0:ooooo`?o`LCM0_o1a=`4ol31fP03okblf_nj]]Go^[KE00?o^[KE00Co]joAojnXdOn_Z=7o
[jSA1?n/XL`4ojRJa`;oYI?300?oWHo4oi^9`?nKRL000_nKRL04oiV4_0?oUh2h0onFO;D3oiAj/`Co
TgN`1?nBMJl3oi5c[P;oT7:]00?oTgjjoi=o^_nCOkX00ol00003oi>0^`?oTh6m1?nCPkl3oi>6`PGo
ThS40onDRlL2oiF=b004of3EjonFKjCoUVnToiI_Y0?oU6^P0onBIid4oi5TV`?oT6>I0on?HIP4ohmP
U`WoSUnF00?oTVVPoi=ZX?nCJZ000_nCJZ04oiA[X0?oUVbP1?nGKJ04oiQ]X0CoVFjP0onJKj03ofgF
Y@;ob?C]0onPOJd4oj5m[@;oXGj]00?o[IO0ojfC^on]Tk/00on]Tk/4ojb?]`?oZh^d00?o/9o6ojnI
`?n_VL000_n_VL05ojjD_004ojf@^?nj]mOo^[OGokZge`Go^:g>00Co]ZC7okNlgOng_=go]kcM1Ong
/]@00ondZ/ko]/[YokK:j@02okK:j@;o]l7Q0_n`co04ok;8jP03ojWAmOn^c_7o[/ka00?o[/ka0_n`
b^d3oj[=lP;o[<[_0_nYbo45oj[9l0;oZlO^00?oZLO_o`000?nZa^h00onZa^h00onYaNkoZLC]ojW4
k@03ojW4k@;oZ/?/0_nY`n`5ojW2k0CoZL7[5?ooool00ol0003oooooooooo`0Gooooo`009Oooool2
o`0000cooooo00?o`LCMol74g?o1a=`00_o1a=`00oo0`M[o_;cJokblfP02okblfP?o^[KE00?o/[3F
ojnXdOn_Z=400on_Z=44ojbQc0;oZ9[700?oX9G9oif?a?nMSl@00_nMSl@3oi^9`0CoVHBl0onGP;P4
oiIl]@?oU7Zc0onCMk04oi9e[`;oTG>^00CoTWjjoi=n^_nCO[[oTgjj0_l00003oi=o^P?oTh2k0onC
PKd4oi>3_`CoThK20_nCR<@4ohoBoP;oOMWm00?oVGBXoiI_Y?nFKj@00_nFKj@3oiA[X0?oTVNM1?nA
I9/3oi1SV@?oSf6H1?n?H9L5ohiOUP;oT6RP0onBJJ04oi=ZX0CoU6^P0onFK:04oiM]X0CoV6fP1?nI
KZ02oiY_X0;oKMJU0onOOJh4oj1m[@CoXGf]00CoXGj]ojfG`?n]Ul3o[IO01?n]Tk/4ojb?]`03oj^;
]?n`WlKo/9o600;o/9o60on_VL04ojjD_003okW3h_nj]mOo^[OG00;o^[OG1?nh[Lh00oneanSo]kcM
okNlg@03okNlg@;o]k;D0onbdo42okK:j@;oZ]Cf1On`co000onbb>[oZM7eojWAm@02ojWAm@;o[/ka
0_nWco@4oj[=lP;oYl_c1?nYbo42oj[9l0;oZ<S`1?nYanl00ol0003oZ/K^ojW5kP03ojW5kP;oZLC]
0_nX`nd5ojW3k0;oZL;/0_nX`N`5ojW1ja?ooooo00?o0000ooooooooool05oooool002Cooooo00?o
0000ooooooooool03Oooool3ol74g0?o_lCN1?nl_=X01?nj]]Go/[3Fok:`e_nb/=H5ojnXd@;o[:7<
00?oXic>oj2EbOnPULT00_nPULT3oif?a0?oVhW01OnIQ;`3oiN0^0?oUWbe0onDN[<2oi=g/003oi5o
_?nAO[_oTGjk00;oTGjk0onBO[X3o`000003oi=n^_nCOk[oTgnj00;oTgnj0onCP;/4oi>1_@CoTh>o
0_nCQ/83oiO8n0;oSm;n0_n9IjD3ohMUY0?oQf>R00CoUVnToiA[X?nDJj3oU6^P0onBIid4oi5TV`?o
T6>I0on?HIP2ohmPU`;oSFJP0on?Ij04oi1XX0?oTVVP1?nCJZ04oiA[X0CoUVbP0onGKJ05oiQ]X0?o
VFjP00CoVVnPoiim[_nNOJkoWWf^0onOOJh4oj1m[@?oXGf]00?o[I_5ojfG`?n]Ul000_n]Ul05ojfC
^`;o[8ng00?o/JO>ok2Oa_n`WlH00on`WlH4ojnI`003ojjD_?ni`n;o^L?R00;o^L?R1?nj]mL00onh
[Lko]LOXokG7j002okG7j0;o]kcM0onYfOP3ok;Cl@;oXmSj1?nZe?H2ok3?l0CoYM?h0_nYdOD2ojC@
m`CoYlod00?oZ/gbojO;lonWbo<00onWbo<2ojW;l@;oYlSa1?nXb?02ojW7k`;oZ<G^00Co0000ojW5
k_nYaNkoZLG^1_nX`nd2ojW3k0?oZ<;/1?nX`N`2ojW1j`;oZ<7[5?ooool00ol0003oooooooooo`0F
ooooo`009?ooool00ol0003oooooooooo`0>ooooo`03ol74g?noa=ko_lCN00?o_lCN0_nl_=X2okFi
g0Co/[3F0_n_Z=42ojJTe0CoXic>0onPULT3oif?a0CoVhW01?nIQ;`3oiN0^0;oUWbe00CoT8;0oi20
__n@P;koT82n1?nAOk`3oi5n^`?o000000CoTWjjoi=n^_nCO[[oTgjj1?nCOkX4oi>0^`?oTh6m0_nC
Pkl3oic0lP?oUlSh0_n<JjP3ohUWY@?oQfFT1?n7Hj83ohMSX@?oR6>P1?n9Hj03ohYTX0?oS6FP1?n=
IZ03ohmWX0CoT6RP1?nBJJ03oi=ZX0CoU6^P1?nFK:03oiM]X0GoV6fP0_nIKZ000onLO:ooWWf^oiim
[P02oiim[P?oWgf^1?nPOJd00onQOJgo[I_5ojfKa@02ojfKa@?o[IO01On]Tk/01?n/SkOo/JO>ok6W
c_naYlh4ok2OaP?o[iW00_necnd5okW3hP;o^[OG0_n`d_83okG7j0;oWmgl1OnYfOP00onbdo7oXmSj
oj?HnP02oj?HnP;oZ]Cf0onOe?X2ojGCn0;oXM3h1OnTd?L2ojO?m0?oYL_d0_nWbo<2ojK8l@GoYlSa
0_nXb?02ojO5k`?oZ<G^00?o0000ojS5k_nYaNh01_nX`nd7ojS2k0;oZ<7/1_nX`N/Dooooo`03o`00
0?oooooooooo01Gooooo000Tooooo`?o00003oooool4oko4gP03okS3hone^Mco]KWL00?o]KWL0_nb
/=H00onY[M[oYZCDojJTe003ojJTe0?oXic>0onPULT4oif?a0;oVhW000?oTXc9oi68a_nAR<H00_nA
R<H3oi24``CoT8;00on@P;h3oi5o_0?o000000CoTGjkoi9n^_nBO[[oTWjj1?nCO[X4oi=o^P?oTh2k
0_nCPKd3oifkk@CoW<3b00?oUlShoha[Z?n<JjP00_n<JjP2ohUWY@?oQfFT1?n7Hj83ohMSX@?oR6>P
1?n9Hj03ohYTX0?oS6FP1?n=IZ03ohmWX0CoT6RP1?nBJJ03oi=ZX0CoU6^P1?nFK:04oiM]X0CoV6fP
00?oVFjPoial[onLO:l01?nNOJh4oimm[P;oX7f]00?o[Io:ojfKaOn]VlD00on]VlD4ojfG`0;o[I>k
0_na[mH4ok6WcPGo/9o600?o[iW0okG?kOnecnd00_necnd2okW3hP;oYm_j1On`d_800oneanSoWmgl
oioMo002oioMo0;oZMWh0onKfOd2oj?HnP?oW=?k0_nOe?X3oio>n0CoXM3h0_nTd?L3oj?:m0;oYL_d
0onUao84ojK8l@;oYlSa0_nVaNl5ojO5k`;oZ<G^00?oYl?^o`000?nX`nd00onX`nd8ojS2k0;oZ<7/
1onX`N/2ojS0ja;ooooo0_l00009ooooo`Co000000?o410@ooooooooool01oooool002Cooooo00?o
0000ooooooooool04?ooool00onoa=ko^<?SokS3h`02okS3h`?o]KWL00?oZkOQojV]f_nY[MX00_nY
[MX4ojJTe0CoXic>0onPULT2oif?a003oiB@cOnBS<WoTXc900;oTXc91?nAR<H3oi24``?oT8;00on@
P;h3o`0000CoTGjk1?nBO[X3oi=n^PCoTgnj0_nCP;/2oifhj`GoWK_]0_nL`?82ohm_ZPCoS6^X0on9
IjD3ohMUY0?oQf>R0on7Hj43ohQSX0CoRF>P0on:I:03ohaUX0CoSFJP1?n?Ij03oi1XX0CoTVVP1?nC
JZ03oiA[X0CoUVbP1?nGKJ03oiQ]X004oi]l[onLO:ooW7b_oial[`GoWWf^0onOOJh01?nPOJgo[Io:
ojfOb_n]WlX4ojfKa@?o[IO000?o/;ONok6_e_na[mH00ona[mH4ok6WcP;o/9o60on^fOH2okG?k@Co
Vmom0onWfoX2ok3BlP?oU]gn0_nOgO`4oiKIoP;oVmWm0onJdO/2oicCn`;oW/gh1OnOc_P2oj7@n0;o
X/Wd0onSb_@2ojC6l@GoYLOb0_nVb?46ojK5k`;oYlG_1_nW`nh00ol0003oZ<?]ojS2k005ojS2k0Oo
Z<7/0_nX`N/7ojS0ja?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`00
2Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`0Booooo`Co^<?S00Co]KWLoj^ghOn[]n7oZkOQ1?nY[MX4ojJTe0;oXic>00CoV9cFoiJF
dOnFU]7oUYKA1?nDT<d3oi:<b@CoTHS60on@Q<<3oi22`0?o00001?nAOk`4oi5n^`?oTWjj0_nCO[X0
0onG]>coVkK[oi^fj`03oi^fj`CoWKS[0_nM^nd3oi=d[@?oSfnZ1?n<JjP3ohUWY@?oQfFT0on7Hj84
ohMSX@?oR6>P0on9Hj04ohYTX0?oS6FP0on=IZ04ohmWX0?oT6RP1?nBJJ04oi=ZX0?oU6^P1?nFK:04
oiM]X004oiQ]X?nKO:ooVgb_oi]l[`?oW7b_1OnNOJh2oimm[P03ojbSc_n]Wl[o[Io:00;o[Io:1On]
VlD01?n]Ul3o/;ONok2gg_n`]mh5ok6_eP;o/JO>0onTgo/2ojkImP?oT>7m0_nKgod3ohcKo`CoSmco
0_nFgOh3oi?HoP;oU]Wn0onJcoX2oi[An`?oW/_g1?nNcOP2oio>n0;oX/Sc1OnRbO@00onSb_CoY<Ka
ojC6l@02ojC6l@;oYLOb0_nUa>l7ojK5k`;oY/?^1_nW`nh00onW`^go0000ojO2k@03ojS2k003ojO1
k?nX`NcoZ<7/00GoZ<7/0_nX`N/9ojS0jaCooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`09ooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0Cooooo`;o^<?S0_n]`NP4oj^gh@Co
ZJgJ0_nVY=@00onKY=_oV9cFoiRLeP02oiRLeP?oUYKA0onDT<d3oi:<b@CoTHS60on@Q<<3o`000004
oi22`?n@P;koT82noi20_P?oTGnl1?nAO[/2oi9n^P03oi>bk?nG]>coUkC/00;oUkC/1OnK]^/2oifh
j`?oV7Za1?nCM:d3ohm_ZP?oS6^X0on9IjD3ohMUY0?oQf>R1?n7Hj43ohQSX0?oRF>P1?n:I:03ohaU
X0?oSFJP1?n?Ij04oi1XX0?oTVVP1?nCJZ04oiA[X0?oUVbP0_nGKJ02oiYk[`CoVgb_1?nLO:l3oiim
[P03oj^Vd_n/Xlko[:?>00;o[:?>1?n]WlX2ojfKa@;o[koV1?n`]mh4ok6_eP;oVN;m0_nTgo/4ohSP
o0;oT>7m0on=fOl2ohcKo`;oUMCm1OnCe_h2oi?HoP?oVlgi0_nJcoX2oio9m@GoW/_g0_nNcOP2oj;6
lPCoX/Sc0_nRbO@3ojC5l@;oY<Ka0onU`nl4ojG4k`;oY/G_1onV`nh2ojO3kPGoYl;]00?o0000ojO2
kOnX`^`00onW`N`3ojS1k0;oYl7/1?nX`N/2ojS0j`?oYl3[1?nX`>/Cooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02Oooool000Wooooo00Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool05Oooool4ojg1j0;oZkOQ0_nN]>P3oif/
h@CoVjCK0onHW=H3oiJFd@?oU93=1?nBS<T4oi68aP;o000000CoT8C3oi22`?n@P/3oT8;00on@P;h2
oi5o_0;oRZWZ1?n>[^`3oi>bk0CoUkC/0_nK]^/01?nQRK[oW86eoib1]OnLPKD3oiQj/@CoTgB]0on?
KjX3oha[Z0?oRFNU0on7IJ@4ohMSXP?oQf>Q0on8Hj03ohUSX0CoRVBP0on<IJ04oheVX0?oSfNP1?n@
J:03oi9YX0CoTfZP1?nDJj02oiI/X0;oV7Z_0onJNjl5oi]l[`?oW7b_00CoWWf^oj^Vd_n[Y];oZjKB
1?n/Xlh3ojfObP03ojg6k?n__nKo[koV00?o[koV1?n`]mh01?na[mKoVN;moiWRoOnIh_d3oh?On`;o
R>3l0on?fOl2ohgIo`?oV=?l1?nEe?d2oi?FoP?oWLch0_nKcOT2oj78m0GoWlWe0_nNboL2oj?5l@Go
X/Kb0_nRb?<3ojC4l0;oY<Ga0_nU`^h5ojG3k`;oYLC_0_nV`^d6ojK3kPWoYl;]00?oYl7/o`000?nW
`N`01?nW`N`00onX`NcoYl7/ojO1k002ojO1k0;oZ<7[1onW`>/2ojS0j`;oYl3[4oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP05ooooo`?o00005_ooool2ojg1j0;oW[g_1?nN]>P3oif/h@Co
VjCK0onHW=H3oiJFd@?oU93=0_nBS<T2ohRMhP?o00000on6Wn<3ohJQi@CoQjGX1?n:ZNX4ohj^k0?o
Tk;/0_nG]>`01?nVTKooXHVjoj69^_nQRKX3oib1]@CoV7Za0onCM:d3ohm_ZPCoS6^X0_n9IjD3ohMU
Y0CoQf>R0on7Hj43ohQSX0CoRF>P0on:I:03ohaUX0CoSFJP0on?Ij04oi1XX0CoTVVP0onCJZ04oiA[
X004oiI/X?nHNZooV7Z_oiQj[`CoVW^_1?nKO:l2oial[`03ojVXeOn[Y];oZjKB00?oZjKB1?n/Xlh0
1?n]Wl[o[LK/ojg6k?n]a^`5ojnoiP;o/;ON00?oT>?moh;Onon2go/00_n2go/2oh?On`?oT]On0_n?
fOl3oi_An`CoV=?l0_nEe?d3oio:mP;oWLch0_nRa_84oj78m0;oWlWe0onSa?04oj?5l@;oX/Kb0onT
`nl2ojC4l0OoYL;^0_nU`nl7ojK2k@;oY/?^0_nW`Nd6ojO2k@KoYl7/00?o0000ojO1k?nW`N`01_nW
`N`?ojO0ja7ooooo0ol00007ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo01Sooooo0onN
_Nl4oijdj0?oWJcQ0_nKY=/01?n=ZNSoS:GUohbUiOn<YND3oh^Qh`?oRIoR00GoR9gRo`000?l0003o
0000ohRMhP03ohJMhP?oQYoS0on6XND4ohNUj0CoRZWZ0_n>[^`4oj^Ja@?oYY6o1?nQRKX3oib1]@?o
V7Za0onCM:d3ohm_ZPCoS6^X0on9IjD2ohMUY0CoQf>R0on7Hj43ohQSX0CoRF>P0on:I:03ohaUX0Co
SFJP0on?Ij04oi1XX0CoTVVP0onCJZ02oiA[X0?oUgR_1?nHNZl3oiYk[`;oVgb_0_nWZ=L4ojVXe@Co
ZjKB0_n/Xlh3oj[<l@Co[LK/0_n__nH2ohWRn`?oPmok0_n2go/3oiKGoP;oT]On1?nMcoT2oi_An`;o
X/Oc1?nQb?@2oio:mP;oXlGa1OnRa_82oj78m0;oY<?_1OnSa?02oj?5l@?oYL;^0_nT`nl2ojK1k@Ko
YL;^0onV`Nd6ojK2k@;oYl7/1OnW`Nd2ojO2k@WoYl7/00?o0000ojO1k?nW`N`01?nW`N`AojO0j`ko
oooo1?l000000ooooooo0000ooooo`06ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05oa0@
4?ooooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wo
oooo0onN_Nl2oijdj003ohnckon>[^coSZk/00;oSZk/0on=ZNP3ohbUi@?oRj7S0ol00005ohRMhP?o
QYgR0on6Wn<3ohJQi@;oQjGX0_m5`nL00oo2c>;o`LKNok2RbP02ok2RbPCoZi[51?nVTKl3oj69^P?o
W86e0_nHN[401?n<JjOoRFNUohUWYOn9IjD3ohMTY0CoS6^X0on9IjD3ohMUY0?oQf>R0on7Hj43ohQS
X0CoRF>P0on:I:03ohaUX0CoSFJP1?n?Ij03oi1XX0CoTVVP0_nCJZ02oiEg[`CoUgR_1?nHNZl2oiYk
[`03ojFWf?nWZ=OoYjSG00?oYjSG1?nYZ=D2oj^VdP;oZ=3e1OnZc?42ojg6k003ohGRn_n6h?coQ^3l
00;oQ^3l0_n3go/3oiWFo@;oU]On0onOc_P2oig?n@;oXlKa1OnRao<2oj78m0;oY<C`1?nSaO42oj;6
lP?oYL;^1?nT`nl2oj?4l0KoYL;^1_nV`Nd2ojG2kP;oY/7/1OnV`Nd2ojK2k@KoYl7/0_nW`Nd9ojO1
k0;oYl3/0onW`N`01?l0003oYl7/ojO1k?nW`N`DojO0j`[ooooo0ol00005ooooo`03o`000?oooooo
oooo00?ooooo00?oEEEEofIVI_l000002oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool2o`0001_ooooo0on>^?<3ohnck`CoSZk/0on=
ZNP2ohbUi@?o000000CoRj7SohVOh_n9Wn;oRIoR0_n8WN83ogFlo0CoL<7n0omWa_h2oeW8n0?o`/cR
00?o/j_@ok2Rb_n`X/X00_n`X/X4oj^Ja@CoYY6o0_nQRKX01?nCMZooSg2[ohm`Zon?L:/3oha[Y`?o
RFNU0on7I:@4ohARX`?oPV:U0on7IJ@3ohMSXPCoQf>Q0on8Hj03ohUSX0CoRVBP0on<IJ03oheVX0Co
SfNP0on@J:02oi9YX0?oTgJ^1?nEMjl3oiMh[`;oV7Z_0_nSYML4ojFWf0CoYjSG0_nYZ=D3ojKBm`Co
Z=3e0_nZc?42ohCRn@?oRN7l0_n6h?`4oicDo0;oVMKm0_nQcOL3oio>n0;oY<Ga1?nSa_42oj;7l`;o
YL?_1OnTa?02oj?5l@;oY/;^1OnU`^h2ojC3k`;oY/7]1OnU`^h6ojK1k@?oYl7/1?nV`N`2ojK1k@;o
Yl3/1onW`N`2ojO0k0KoYl7/1onW`>`2ojO1k003ojO0jol0003oYl3[01GoYl3[1_ooool4o`0000So
oooo00?o0000ooooooooool04Oooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`0Kooooo`?oS[Sc0on?/nl2ohj^
k0;oPK?d00CoOk?eo`000?l0003o00000_mm/oH4og^dm`CoNKOj0ome_?`2og31oP;o[_Cb1Oo2d>D0
1?o2c>;o/j_@ok>[d?ncZm04ok2RbP;oZi[500?oVhBioiMl]?nGO;@00_nGO;@3oi=f[`?oSg2[0on<
JjL3ohUWY@?oQfBT1?n4HZ<3oh9RY@?oPFBX0on7Hj84ohMSX@?oR6>P0on9Hj04ohYTX0?oS6FP0on=
IZ04ohmWX0;oT6RP0_nBM:h5oi=f[P?oUGN_0_nGN:l00onQX]GoXjGGoj>Ue`03oj>Ue`CoYJOH0_nW
Z=L2ojCCn0GoY];g0_nXd?D2ohCSn@?oS>7m0_n9hO`3oikDn`;oW=Cl0_nRc?D5oj7=m`03oio>n?nT
aO7oY<Ga00;oY<Ga0_nSa_42ojK3kPCoYL?_0_nTa?03ojK1k@CoY/;^0_nU`^h7ojK1k@;oYL;^0_nV
`N`3ojK1k@;oYl3/1OnW`N`2ojK1k0KoYl3/0_nW`N`7ojO0k0;oYl7/2?nW`>`5ojO0j`03o`000?nW
`>_oYl3[01GoYl3[0_ooool3o`0000cooooo00?o0000ooooooooool04Oooool002;ooooo00?o0000
ooooooooool07Oooool3ohBdm@?oP[?d00CoPK?do`000?l0003o00000omo/oD3ogfcmPCoNkCg0_mi
]oX2od[5k004ock2aomJd/Co[nogojo_m`?o`=;X0oo2d>D00ong/]Co/j_@ok>[d002ok>[d0?o/:;:
00CoX8bnoi^4^OnKQ;WoVhBi1?nGO;@3oi=f[`?oSg2[1?n<JjL3ohUWY@?oQfBT0on4HZ<3oh9RY@?o
PFBX0omoJ:l3ogib^`04ohMSXOn8Hj3oR6>PohQSX0?oRF>P1?n:I:03ohaUX0?oSFJP0_n?Ij04oi5d
[P?oTWB^1?nCMZh2oiEg[`03oifLd_nQX]GoXJ;E00;oXJ;E1OnSYML2ojFWf0KoY=?h0_nVd_L2ohKS
n@?oSn;m0_n<hOd4oj3CnP;oW]Ck0_nTbo@4oj;<m@;oXLgg0onUaO02ojC5l@?oY/;]1?nV`nh2ojG3
k`OoY/7]0_nV`^h2ojO1k0KoY/7]0_nW`>`5ojK1k003ojK1kOnW`>coYl3/00;oYl3/0_nW`N`AojO0
k0;oYl3[1onW`>`9ojO0j`03o`000?nW`>_oYl3[01GoYl3[00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0Nooooo`?oQ;Ce00?oP[?do`000?l0
00000_n1/o@3ogVmo0CoL/;n0omXa_h2oe_8n@;oEm3V0_mbhN@2ojo_m`Go`=;X00Co`]3UokNbe?ng
/]Co]k;D1?ncZm001?n`X/[oX8bnoj2<__nPS;h3oi^4^@?oUgbd0onCMZl3ohm`Z`CoS6^W0on9IjD3
ohMTY0?oQ6:S0on2HZD3oh5TZ0CoOfR_0omnL[/3ogb4d0?oL:Ga0_n:I:001?l[/>7oTGNcoi5g/onA
Mk<3oi1e/0CoT7B_0onAM:h3oi9d[P;oTgJ^0_nJUll4oifLdP?oXJ;E1?nSYML2oj?Bn0KoY=?h0_n8
i?T3oi;So@;oSn;m0onQdoT2oj3CnP;oY<[c1OnTbo@2oj;<m@?oY/C_0_nUaO07ojK2k@;oY/?^0_nW
`N`6ojK1k@;oYl3/1OnW`N`2ojK1k@KoYl3/0_nV`N`6ojO0k0;oYl3[1_nW`>`2ojO0j`OoYl3/1_nW
`>/2ojO0k0koYl3[00?o0000ojO0jonW`>/05OnW`>/@ooooo`03o`000?oooooooooo013ooooo000R
ooooo`;o00008?ooool3o`000003oh>dmOmn^OWoO[Wi00;oO[Wi0omi_O`2og;2oP?oN]7o0_m[e?T3
ohGTm`;o/>Sh0onmdNT2ol3Bj0?o^KSI1?ng/]@2ok>[d003ojFDa?nPS;koX8bn00;oX8bn0onKQ;T4
oiMl]0?oTgJ_0on?L:/3oha[Y`?oRFNU0on7I:@3ohARX`?oPV:U1?n1I:P3ogmX[`CoOW:k0omlQ=03
og2Ul@;oU7fg0onAMk<3oi1e/0CoT7B_0_nAM:h01?nCRLKoUi3;oiN@bonGT</5oiZGc`?oWIcB1?nQ
X]D00onSYMOoXm;hoj?Bn003oj?Bn0;oY=?h00?oR^GioiCToOnDi?d00_nDi?d2oi;So@?oXm?i0_nQ
doT2ojG:l`CoY<[c0_nTbo@6ojK4k`;oYl7]1_nV`^d7ojO1k0;oY/7]1_nW`>`2ojO1k0WoYl3/0_nW
`>/5ojO0k0GoYl3[0_nW`>`6ojO0j`;oYl3/6onW`>/00ol0003oYl3[ojO0j`0DojO0ja3ooooo00?o
0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool07?ooool3o`000003oooooon3]?Go
PkCe00;oPkCe0_mn^OT2ohW1n@CoPlWn0_mjdOl2oi7NoPCo[mkh00Co/>ShokgAjOnmdNWo_M7Y0_nj
_M`5okVhf@;o]k;D00?oZIc9ojFDa?nUU<@00_nUU<@3oj2<_P?oVhBi1?nGO;@3oi=f[`?oSg2[0on<
JjL3ohUWY@?oQfBT1?n4HZ<3oh9RY@?oPFBX0omoJ:l4ogib^`CoO8C@00CoL:GaohUd]_n9M;KoRGBf
0on;N;T3ohel_0CoT8;11?nCRLH3oiN@b`CoVYO?1?nMW=82oj6Re@?oY<kf0_nSd_P2ohcVn@?oU^Cl
0_nDi?d3ojCCn0;oXm?i0onVb_<4ojG:l`;oY<[c0onVa>h2ojK4k`;oYl7/1OnW`Nd2ojK2k@SoYl7/
2OnW`>`2ojO0j`KoYl3/1onW`>/2ojO0k2coYl3[00?o0000ojO0jonW`>/05OnW`>/?ooooo`03o`00
0?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo01Wooooo0ol00006ooooo`CoS[Sc0on9
`OT2oh?9oP;oV=Cl1?n^e?@2ojoNn0?o^loY00?o_M7YokZmg?nj_M`00_nj_M`3okVhf@03ojfTc_nY
W<WoZIc900;oZIc90onUU<@4oj2<_P?oVhBi0onGO;@3oi=f[`?oSg2[0on<JjL3ohUWY@?oQfBT1?n4
HZ<3oh9RY@?oPFBX1?moJ:l4ogib^`;oO8C@0_n9Lk@4ohUd]P?oRgRi0on=O;`3oi22`@CoThW60onG
T</5oiZGc`;oWIcB0onTbO<2ojC>mP;oSnOi0onGiO`2oiKTo0?oYMCh0_nTdoP2ojK:lPGoY/[c0_nU
b_<2ojO4kP?oY/C^1_nW`N`2ojO1k@WoYl7/0_nW`>/6ojO0k0OoYl3[0_nW`>`iojO0j`03o`000?nW
`>_oYl3[01CoYl3[3oooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0F
ooooo`?o00002_ooool2ohjhl`;oWKg_1?nKb?L00onHe?co[]CdojkDm002ojkDm0;o^<_X0onkcnT2
ok[0gPGo^[gL00Co^KSIojfTc_n]Y<ko[JC>0onYW<T3ojFDa0CoX8bn0onKQ;T3oiMl]0?oTgJ_0on?
L:/4oha[Y`?oRFNU0on7I:@3ohARX`?oPV:U1?n1I:P3ogmX[`;oOW:k0on;M;<3ohUc]0CoRGBf0on;
N;T3ohel_0CoT8;10onCRLH4oiN@b`;oVYO?0onS`o02ojC9l`CoTNOi00CoSnOioiOUo?nGiOcoUnGl
0onUeOP2ojGDn0;oYl_b1?nVb_82ojK:l`;oYl?^1OnWa>h00onVa>koYl7/ojO1k004ojO1k0;oYl3/
1_nW`N`7ojO0j`;oYl3/A_nW`>/00ol0003oYl3[ojO0j`0DojO0j`kooooo00?o0000ooooooooool0
4?ooool002;ooooo0_l0000Dooooo`?o00003_ooool4oifmk`;oVlSg1?n/b^l00on^e?Co^<_XokS;
j002okS;j003ok_?jOnj`=ko^/3N00;o^/3N0_nj_M`2ok6[dPCo[JC>1?nYW<T3ojFDa0;oX8bn00Co
ThC1ohin_On>O[goSWjm0on8N;/3ohAd^@?oP76i1?n<JjL3ohUWY@?oQfBT0on4HZ<3oh9RY@CoPFBX
0_moJ:l00omJe=KoSgNeohmg]@03oh]d/`CoRG>d0on9M;H3oh]h^@?oSGbl1?n@P/44oi>9aP;oUi3;
0_nR^^/3oj?3l0?oU>Sj0_nAioT2oiSVo0?oY]Kh0_nUeOP3ojO;l`CoYl_b0_nVb_82ojO4kPCoYl?^
0_nWa>h6ojO1k0KoYl3/0_nW`NaCojO0j`03o`000?nW`>_oYl3[01CoYl3[3Oooool00ol0003ooooo
ooooo`0@ooooo`008Oooool2o`0001;ooooo0ol0000Booooo`;oWKg_0_n[`NT4ojc:k`;o]/OW0onh
bnP2okW2h0?o^/3N00?o/k;Gok6[d_naZm800onaZm84ojfTcP;oZIc900CoWY?8oiV<a?nIS<CoVHc4
1?nCQ<43ohin_@?oR7Rk0_n4M;T3oh1a^@?oOW6j00CoS6^WohUWYOn9IjGoRFNU0on7I:@3ohARX`?o
PV:U0_n1I:P3ohk@oP;oUGjh0on?MkD3oh]d/`?oRG>d1?n9M;H3oh]h^@?oSGbl0_n@P/400onLY]go
Wk7Toinai003oinai0CoX[[[00CoXl?`oiCXn_nDj?[oU>Sj0_nIio/2ojOHn@?oY]Kh0_nXc?<5ojO;
l`;oYl_b1_nWa>h2ojO3kPKoYl7/2?nW`>aFojO0j`03o`000?nW`>_oYl3[01GoYl3[3?ooool00ol0
003oooooooooo`0@ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool00oooool00ol0003oooooooooo`0?ooooo`;o00005_ooool4oj_1
j@03ojc:konfanOo]/OW00?o]/OW00?o^<_XokW2h?ni`^000_ni`^001?nj`=ko/k;Gok>beonc/]L5
ok6[dP;o[JC>00?oXi_=oijCb?nNTlP00_nNTlP3oiV<a0?oThC10on>O[d3ohQh^`?oQ7Bi0on0LKT3
ogia^P?oOWFn0on1OLH3ohJ<dPKoSJOW00CoS]3noiEn^?nEO[SoUGjh0on?MkD3oh]d/`?oRG>d1?n9
M;H3oh]h^@;oSGbl00?oV9_EoibVgOnLY]d00_nLY]d5oinai0;oX[[[0_nFio/3oi[Xn`03oiWWnonW
f?WoYmSi00;oYmSi00?oY]KhojS<lonXc?<00_nXc?<2ojO;l`WoYlC^1onW`N`6ojO0k5_oYl3[00?o
0000ojO0jonW`>/05?nW`>/=ooooo`03o`000?oooooooooo00oooooo0007ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0<ooooo`?o00006Oooool2oj_1j@Co]<?U0_nfanL2okW3hP?o^L;P00?o]KSKok>beonc/]L00onc
/]L2ok6[dP;oZ:?B1?nSVld3oijCb0?oVHc40onCQ<43ohin_@?oR7Rk0on4M;T3oh1a^@?oOW6j1?mn
MKh3oh5maP?oQXcB1?n=YnL2ohmn_@?oS7^k0on;N[`3oh]m_P?oSH;21?n@R<L3oiBAcPCoV9_E1?nL
Y]d2oinai0;oVNKl1?nKjO/2oi[Xn`?oZ=[i0_nWf?T3ojS=l`;oZ<cc0_nXa>h6ojO4kPWoYl7/1OnW
`>aOojO0j`03o`000?nW`>_oYl3[01CoYl3[3?ooool00ol0003oooooooooo`0?ooooo`001oooool0
1Ol@413ooooooooooooooooo410@00_ooooo1Ol00005ooooo`;o00002_ooool3o`0001gooooo1?nd
`nD2okS3h`Co^L?R00Co^L;PokFhfone^=_o]KSK0onc/]L00on[ZmOoZ:?BojRSdP02ojRSdPCoXi_=
0onNTlP3oiV<a0CoThC10on>O[d3ohQh^`;oQ7Bi0on0LKT4ogia^P?oOWFn0on1OLH4ohJ<dP03ohfW
ionDQL3oSgjm00;oSgjm1?n<Nk/3oh]j_0?oRgfn0on=P/84oi28a`?oU97>1?nHVmD2oibVg@;oVn?m
0onLjO/2oi_Yn`CoZ=ci0_nXf_T3ojW?m0;oZ<gc0_nXaNh4ojS4kP;oYlC^2OnW`N`5ojO0k6;oYl3[
00?o0000ojO0jonW`>/05OnW`>/;ooooo`03o`000?oooooooooo00oooooo0007ooooo`05o`000?oo
ooooooooooooool000002oooool01?m4A4CogMgMooooool00006ooooo`03o`000?oooooooooo00Ko
oooo0ol0000Qooooo`03okC3iOnh`n?o^<?S00?o^<?S0_ni`n82okNmg`Co]KSK00Co/k;Goj^[eon[
ZmOoZj_G1?nXXm84oj>Kc@?oWY?80onIS<@3oi>4`@?oSWjm0on8N;/3ohAd^@?oP76i0omnLKX3ogie
_PCoPGg60_n6S=83oiB5`0?oSgjm1?n<Nk/3oh]j_0?oRgfn0on=P/84oi28a`CoU97>0_nHVmD3oigM
o@04oi_SoOnLjO_oW>WkoicYn`?oZMkj0_nXg?T3ojWAm@;oZLod0onXa^l4ojS5kP;oZ<C^0_nX`^`6
ojO1k0SoYl3/I?nW`>/00ol0003oYl3[ojO0j`0EojO0j`[ooooo00?o0000ooooooooool03oooool0
00Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o
0000ooooooooool00oooool3o`0002Kooooo1Onh`n<4okNmg`;o]KSK00?o[[?Loj^[eon[ZmL00_n[
ZmL4ojRSdP;oXi_=0_nIV]<3oiBCd0?oShk>0on9R/h3oh>8d0?oNh_G0om_UNH3oh1a^@?oOW6j1?mn
MKh2oh5maP?oVho61?nDQL03ohmn_@?oS7^k0on;N[`3oh]m_P?oSH;21On@R<L2oiBAcP?oWMCk0_nM
gOd2oikXn`?oZN7j0_nYg_X3oj[CmP;oZM7e0_nYanl5ojS6k`;oZ<G^1_nX`^`2ojO1k0SoYl3/J?nW
`>/00ol0003oYl3[ojO0j`0DojO0j`[ooooo00?o0000ooooooooool03oooool000Oooooo00Go410@
oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Gooooo00Co0000oooooooooooooooo
0ol0000Zooooo`Go^<?S0_ng_Ml00ona^n7o[[?Lojjcg002ojjcg0CoZj_G0_nXXm800onNXMOoVI[C
oiVJd`03oiVJd`?oU9?@0on?S/h3ohV:cP?oPhS@0omkRmL4ofnEiP;oBjKh00?o]kcMojn]e_n_[MH0
0_n_[MH3ojFMc@?oVho61?nDQL03ohmn_@CoS7^k0on;N[`3oh]m_P?oSH;20_n@R<L3oi[7mP;oWMCk
1?nOi_`01?nNj?_oZN7jojWQn_nYhOX2oj_Fm`?oZ]?f0_nYb?04ojW7k`;oZ<K_0_nX`^d7ojS2k0;o
Yl7/1_nW`>a/ojO0j`03o`000?nW`>_oYl3[01CoYl3[2Oooool00ol0003oooooooooo`0?ooooo`00
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001Oooool4o`0002ko
oooo0onh`n<00onb`^Ko/K_Qok6kh@02ok6kh@Co[[?L0_n[ZmL00onRZM_oWZ7GoijQe`02oijQe`Co
VI[C0onDTm03ohn>cP?oRH[>1?n3R=03og^;e`;oKiGV00?o`OC`olW]kOng_=d00_ng_=d4ojn]eP?o
YIg=0onKSlH3oiB5`0?oSgjm1?n<Nk/3oh]j_0;oRgfn0_nAYnD4oiNhkP;oV/Of0onQhO`2oioVo0?o
ZN?j0_n[fOL4oj_Fm`03oj[Cm_nYb?3oZLS`00;oZLS`0_nYanl2ojS3k@CoZ<;]0_nX`^`7ojO1k0;o
Yl3/KonW`>/00ol0003oYl3[ojO0j`0DojO0j`Wooooo00?o0000ooooooooool03oooool000Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Cooooo0_l0000aooooo`04
okS3honb`^Ko//;Vok;2iPCo/K_Q0_n^/m`2ojFah0?oXZWK1?nNXML4oiVJd`?oU9?@0on?S/h3ohV:
cP;oPhS@0omc`oh00omLc_Co`OC`ol7dl002okc:i@Co]kcM0_n_[MH01?nJTLWoU8[6oiB:a_nDR/H3
ohj5aP?oRXG70on9Ql/4ohV>dPCoSIWK1?nAYnD2oiNhkP?oXMWk0_nQhO`3ojWTnP03ojWSn_n[fOOo
ZmWg00?oZmWg0_n[e_L3oj[9l0;oZLS`1_nX`nd2ojS2k@SoYl7/M?nW`>/00ol0003oYl3[ojO0j`0D
ojO0j`Sooooo00?o0000ooooooooool03oooool002;ooooo00?o0000ooooooooool0;oooool4ok;2
iP;o/K_Q0_nX^ND4ojFah0?oXZWK0_nNXML2oi>[i`?oSjWW1?n8Z>X3oh>[k`CoO;?g0_mc`oh00ond
m??o_M?ZokgCjP04okc:i@;o]kcM00?oXi[=oiZAbOnJTLT00_nJTLT3oiB:aP?oSXG60on:QLL3ohV7
b`CoRHkB1?n=VM/2oi6Wi@?oWlgh0_nQfO/3ojSTn`;oZNCj0on[foP2oj_Im`?oZl_a0_nZbO03ojW4
kPKoZ<?]0_nX`N`6ojO1k7SoYl3[00?o0000ojO0jonW`>/04onW`>/9ooooo`03o`000?oooooooooo
00kooooo000Sooooo`03o`000?oooooooooo02oooooo0_nb`^H2ojW0jPCoZ;WU0_nU/N000onK]>Wo
V:oWoiR_i`02oiR_i`CoTj_W0on?ZNL4ohRXjP?oPj__0_ml/oL2okCdl`Go_M?Z0_nlb^D00onYY=7o
Xi[=oj>Jc@02oj>Jc@?oVY790onDR/H3ohj5aP?oRXG70on9Ql/5ohV>dP;oSIWK0_nL_o43oio=n0?o
Y^;k0_nXi?/3oj_Mn@;oZm_h0on[c_82oj_;l@;oZLG^1OnYa>h2ojS3k@KoZ<7/0_nW`NakojO0j`03
o`000?nW`>_oYl3[01CoYl3[2?ooool00ol0003oooooooooo`0>ooooo`009?ooool00ol0003ooooo
ooooo`0_ooooo`CoZL3Z0_nX^ND2oifik0?oVkCY1?nH[nL4oi>[i`?oSjWW0_n8Z>X2of[>o0;oQNGe
0_n/l?L3okcGkP;o_M?Z0_n_[]L4ojVTd@?oXi[=0onJTLT4oiB:aP?oSXG60on:QLL3ohV7b`;oRHkB
0onG/>T4oibol@04oio=n?nVh__oY^;kojKRn`?oZmoi0_n[gOT3ojc@l`;oZlkb0_nZanl4ojW5kP;o
ZLC^0_nX`^`7ojS1k7ooYl3[00?o0000ojO0jonW`>/05?nW`>/7ooooo`03o`000?oooooooooo00ko
oooo000Uooooo`;o0000<?ooool2ojW0jP;oWkk^1?nM^N`3oi^dj@;oV:oW0on?__H4ohO2nP;oO/So
0_n;g_h3ojCYn`05ojc`monlenko_=O^okcGk_nc]m`01On_[]L4ojVTd@?oXi[=0onJTLT2oiB:aP04
oi6BdOn?Tm?oSi?CohnCd`?oT9[I1?nCXn05oiN`j@;oW;oa0_nTg_/3ojWOnP;oZmoi0_n]d_@3ojc@
l`;oZ/W`1?nZanl2ojW5kPKoZ<;/0_nX`Nb4ojO0j`03o`000?nW`>_oYl3[01CoYl3[1_ooool00ol0
003oooooooooo`0>ooooo`009oooool00ol0003oooooooooo`0^ooooo`CoWkk^0_nM^N`3oiJllP?o
Tkcc1?n?__H2ohO2nP?oSmCn00CoRmknojCYnonTjO_oY>Wk0ongf?401?nlenko/kOLok>gg?nc]m`5
ojn^e`;oZJCA00CoWYgCoiVGdOnIUm7oVIOA0onDTm04oi6Bd@?oSi?C0on@V]T4oi>Sh0;oUk3Y0onQ
eo/00onTg__oZMojojWOnP02ojWOnP;o[MGe1?n]d_@00on/d??oZ/W`oj[9l002oj[9l0;oZ/O_0_nX
`nd6ojS2k0;oZ<7[Q_nW`>/00ol0003oYl3[ojO0j`0CojO0j`Kooooo00?o0000ooooooooool03_oo
ool002Sooooo00?o0000ooooooooool0;_ooool2oinnkP?oV;c`1?nF_?83oi>ll`;oSkkf0onCc?/2
ohoDoP;oXMol0onceO82okOHl@;o];kQ1?nc]m`2ojn^e`;oY:GF1?nNWM<3oiVGd@?oU9?@0onAT]44
ohnCd`?oT9[I0_nCXn03oig=n0;oXMOk0onXgOX00onYgo[o[MGeojgEm@03ojgEm@;o[M;d0on[bo02
oj[9l0;oZLC]1?nX`nd2ojS2k0;oZ<7/1?nX`N^5ojO0j`03o`000?nW`>_oYl3[01CoYl3[1Oooool0
0ol0003oooooooooo`0>ooooo`00:Oooool00ol0003oooooooooo`0_ooooo`CoV;c`0_nF_?82oiO0
m0CoULGh0_nCc?/3oioFn`04oj7Oo?nceO;o/mGbok?ElP;o]<;T1?nd_^42ok>gg003ojV/fOnTYMKo
Y:GF00?oY:GF0onNWM<3oiVGd@CoU9?@0onAT]42ohnCd`;oUKG]1?nH`O<2oig=n0?oY]Wj0_nXgOX3
ojgGmP;o[MGe0on/cO42oj_;l0?oZLG]1?nYa>d2ojS3k@KoZ<7/0_nX`N^7ojO0j`03o`000?nW`>_o
Yl3[01CoYl3[1?ooool00ol0003oooooooooo`0>ooooo`00:_ooool2o`00037ooooo1?nI_?03oiO0
m0;oULGh0onOcOL2oioFn`?o[m3b00?o/mGbokC2i?nd`^@00_nd`^@2okBnh@03ojbbgOnY[=WoZJcI
00;oZJcI1?nTYMH4oijMd`?oVIOA0_nDTm000onBYN7oTZ_Woi:[i`02oi:[i`CoUKG]0_nH`O<3oj?B
n0;oY]Wj0on/eoL2ojgGmP?o[<ob0_n/cO42oj[6kPGoZLG]0_nYa>d8ojS1k8_oYl3[00?o0000ojO0
jonW`>/05?nW`>/3ooooo`03o`000?oooooooooo00kooooo000/ooooo`03o`000?oooooooooo02oo
oooo0_nI_?02oj2nkPCoWlCc0_nOcOL3ojc;l0;o[m3b0_nba>L3okC2i003ojnhh?n//]go[;;M00;o
[;;M1?nY[=T2ojBUeP03oifUfonHX]_oV:;K00;oV:;K1?nEX]h3oi:Uh@CoTZ_W0_nE]Nd3oio:mP;o
Xm;h0onYe_L2ojcGm`?o[=7c0_n/co82oj[7k`CoZ/K^0_nYaNd2ojS2k0OoZ<7/SonW`>/00ol0003o
Yl3[ojO0j`0DojO0j`?ooooo00?o0000ooooooooool03Oooool002gooooo00?o0000ooooooooool0
;oooool4oj2nkP;oWlCc0_nYaNh3ojc;l0;o/LCX1?nba>L01?nd`^Co[kSPojnhh?n_^>04ojbbg@;o
ZJcI00?oXJSLoifUfonMYM/00_nMYM/4oiRRf`CoUJ;N0onBYN42oi:[i`?oW<7b0_nOb_H3ojODm`;o
ZMKg0_n[d_@3ojcAl`;oZlW_1?nZanl2oj[6kP;oZL?]1?nX`^`2ojS1k0;oZ<7[TOnW`>/00ol0003o
Yl3[ojO0j`0DojO0j`?ooooo00?o0000ooooooooool03Oooool002kooooo00?o0000ooooooooool0
;oooool2oj2nkP;oZ<3[1?nYaNh00on/bo3o/LCXok74j002ok74j0;o//CW0_n__><4ojnhh0;o[;;M
00?oYJgMoj6Xg?nQZ=`00_nQZ=`4oifUf`?oV:;K0_nEX]h3oiVbj@CoV[W]0_nL`O82ojC@m`?oYmCg
0_nZd_D4oj_Bm003ojcAlon[bNooZlW_00;oZlW_0_nZanl2ojW4k@CoZL?]0_nX`^`2ojS1k0CoZ<7[
TOnW`>/00ol0003oYl3[ojO0j`0DojO0j`;ooooo00?o0000ooooooooool03Oooool002oooooo00?o
0000ooooooooool0;oooool4ojS0j`;oZLG^0on_`nP2ok74j0;o/;kU1?n__><2ojnhh0;oZK;O0onU
[Md4oj6Xg0;oWJGK00?oVjkToiV^i_nI[^H00_nI[^H5oiVbj@;oV[W]0_nQb_D4ojC@m`03ojODmonZ
d_GoZ];e00;oZ];e0_n[d_@3oj_;l0;oZlW_0_nYaNh4ojW4k@;oZL?]1_nX`N`2ojS1ji?oYl3[00?o
0000ojO0jonW`>/04onW`>/2ooooo`03o`000?oooooooooo00gooooo000`ooooo`;o0000<?ooool2
ojS0j`;o[L7X0on_`nP2ojo0iPCo/;kU0_n__><2oj^gh@CoZK;O0onU[Md2oj6Xg0;oWZkS0onK[^@4
oiV^iP;oVK;Y0_nNa?<5oj7:m@;oY=3g0onXdOD2oj[Bm@?oZlca0_n[bo02oj[6kPCoZLG^0_nYa>d2
ojS2k0KoZ<7/U_nW`>/00ol0003oYl3[ojO0j`0DojO0j`03ooooool0003ooooo00kooooo000boooo
o`03o`000?oooooooooo02kooooo1?n]`NP00on_`nSo[l3Vojo0iP02ojo0iP;o/;kU0_n]^n@4oj^g
h@;oZK;O00?oY;?Toj6ahonQ/N<00_nQ/N<4oij^h`?oVjkT0_nI[^H2oibol0CoW/Cc0_nQb_D4ojK>
m@;oZ=7e0onZc?82oj_<l@;oZ/O_1?nZa^h2ojW5kPKoZ<;/0_nX`N`3ojS0jiOoYl3[00?o0000ojO0
jonW`>/04onW`>/00ooooooo0000ooooo`0>ooooo`00<oooool00ol0003oooooooooo`0^ooooo`;o
[L7X0on_`^P2ojo0iP;o[KkV1?n]^n@2oj^gh@03ojJgiOnT/nCoY;?T00;oY;?T1?nQ/N<2oij^h`;o
WKW/1?nL^nh3oibol0;oW/Cc0onTbo@2ojK>m@CoZLcb0_nZc?82oj[8k`CoZ/O_0_nZa^h2ojW3k@Ko
Z<;/0onX`N/2ojS0jiWoYl3[00?o0000ojO0jonW`>/04onW`>/00ol0003oooooooooo`0=ooooo`00
=?ooool00ol0003oooooooooo`0^ooooo`?o[l;X0_n]`NP4ojfniP;o[K_T0_nX^^H3ojJgi@CoY;?T
0_nQ/N<2oinhjPCoWKW/0_nL^nh2oj33l@CoX/Oc0_nTbo@3ojO;lP;oZLcb0_nYbO05oj[8k`;oZ/O_
0_nYa>d4ojW3k@;oZ<;/0onX`N`2ojS1jigoYl3[00?o0000ojO0jonW`>/04OnW`>/00ooooooo0000
ooooo`0>ooooo`00=Oooool2o`0002oooooo00?o[l;Xojg1j?n]`NP00_n]`NP2ojfniP;oZKgX1?nX
^^H3ojJgi@;oY;?T0_nQ^NT4oinhjP;oWKW/0_nO`>l4oj33l@;oX/Oc0onVbO82ojO;lP;oZ<W`1?nY
bO02oj[8k`OoZLC]0_nY`nd5ojS1k003ojS0jonW`>_oYl3[09goYl3[00?o0000ojO0jonW`>/03OnW
`>/6ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo02kooooo0_n]`NP2
oj[1jPCoZKgX0_nX^^H2ojFljP?oXk[Y1?nQ^NT2oinhjP;oX;k^1?nO`>l2oj33l@?oY<Ob0_nVbO82
ojO8l@CoZ<W`0_nYbO02ojW5kPKoZLC]0onX`^`2ojS1k0;oZ<7[1?nX`>^OojO0j`03o`000?nW`>_o
Yl3[00WoYl3[2Oooool00ol0003oooooooooo`0<ooooo`00>?ooool00ol0003oooooooooo`0^oooo
o`CoZ/7Z0_nY_NP2ojJnj`CoYKcZ0onS^^T2oj6ij@;oXKg]1?nP_^h2oio0k`?oXlGa0_nTao82ojK7
l@CoYlSa0_nXbO06ojW5kP;oZLC]1OnX`^`2ojS1k0CoZ<7[0_nX`>^QojO0j`03o`000?nW`>_oYl3[
00GoYl3[3?ooool00ol0003oooooooooo`0<ooooo`00>Oooool00ol0003oooooooooo`0^ooooo`;o
Z/7Z0_nV_n`4ojJnj`;oYKcZ0_nS_N`4oj:mk0?oXKg]0_nP_^h3oj;3l0;oXlGa0_nUaO04ojK7l@;o
YlSa0_nXaNl6ojW5kP?oZ<?]0_nX`^`6ojS1k0;oZ<7[YOnW`>/00ol0003oYl3[ojO0j`0@ooooo`03
o`000?oooooooooo00cooooo000jooooo`;o0000;oooool4ojJok0;oY[k[0_nS_^`4oj>mk0;oX[g/
0_nR`>h4oj;1k`;oX/?`0_nTa?04ojG5l0;oY/Oa0_nWaNl4ojS5k`;oZLG^1OnX`nd8ojS1k0;oZ<3[
Y_nW`>/00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo000looooo`03o`000?oo
oooooooo02gooooo0_nV_n`2ojBok@CoXkk/0_nS_N`2oj:okPCoX/3^0_nR`Nl2oj?3k`CoY<C`0_nU
aO06ojO5k`;oZ<G_0onXa>d2ojS3k@;oZ<;/1_nX`N`2ojS1j`CoZ<3[XOnW`>/5ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool03?ooool003gooooo00?o0000ooooooooool0;Oooool4
ojBok@;oXkk/0_nS_nd4oj:okP;oX/3^0_nS`Nh4oj?3k`;oY<C`0onVa>l2ojO5k`;oYl?^1_nXa>d6
ojS2k0CoZ<7/1?nX`N/2ojS0jiooYl3[2Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00cooooo000nooooo`03o`000?oooooooooo02gooooo0_nT_nd6oj>ok@;oX[o^0_nS`>h4oj?1
kP;oXl?_0onU`nh2ojK4k`KoYl?^0_nXa>d8ojS2k0KoZ<7/0_nX`N^KojO0ja3ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0<ooooo`00?oooool2o`0002oooooo2?nS_nd3oj?0kP;o
Xl7^0onU`^h2ojG3kP;oY/;]1_nW`nh2ojO2k@KoZ<;/2?nX`NbKojO0jaCooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0;ooooo`00@Oooool00ol0003oooooooooo`0]ooooo`KoXko]
0_nT`>d4ojC1kP;oYL;^1_nV`^d2ojO3kPKoYl;]0_nX`^`8ojS1k0?oZ<3[V?nW`>/Hooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool02oooool004;ooooo00?o0000ooooooooool0;Ooo
ool2oj>ok@;oY;o/1?nT`>d2ojC1kP;oYL7]1_nV`^d2ojO1k@KoYl;]0onW`N`5ojS1k0GoZ<3[UOnW
`>/Mooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool004?ooooo00?o0000
ooooooooool0;Oooool4ojBok0;oY<3]0_nU`>d4ojG1k@;oY/;]0_nV`Nd4ojO1k@;oYl;]2onW`N`2
ojS0jiGoYl3[8?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0014oooo
o`03o`000?oooooooooo02gooooo0_nT_n`2ojFok0CoYL3]0_nU`Nd3ojK1k0?oY/7]0_nW`Nd=ojO1
k9GoYl3[9?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0015ooooo`;o
0000;oooool3ojFok0;oYL3]0onV`>`2ojK1k0;oYl3/3_nW`NbDojO0jbWooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0;ooooo`00Aoooool00ol0003oooooooooo`0]ooooo`CoY[o/
0_nV`>`6ojO0k0;oYl7/0_nW`>`6ojO1k9CoYl3[;?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00_ooooo0018ooooo`03o`000?oooooooooo02gooooo0_nV_n`2ojK0k0coYl3/0_nW
`NbDojO0jc3ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`00BOooool0
0ol0003oooooooooo`0]ooooo`CoY/3/2_nW`>bDojO0jcCooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`00B_ooool2o`0002kooooo0_nV`>`2ojO0j`KoYl3/TonW`>/ioooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool004cooooo00?o0000oooooooo
ool0;?ooool4ojO0j`;oYl3/TonW`>/looooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02_ooool004gooooo00?o0000ooooooooool0;?oooonBojO0jd?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0:ooooo`00C_ooool00ol0003oooooooooo`0]ooooohgoYl3[Aooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo001?ooooo`;o0000;_oooon8
ojO0jdcooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`00DOooool00ol0
003oooooooooo`0/ooooohCoYl3[Coooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00[ooooo001Booooo`03o`000?oooooooooo02_oooooPOnW`>]Cooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02_ooool005?ooooo00?o0000ooooooooool0:ooooommojO0jeOooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`00E?ooool2o`0002goooooN?nW
`>]Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool005Kooooo00?o0000
ooooooooool0:ooooomdojO0jekooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09
ooooo`00Eoooool00ol0003oooooooooo`0[ooooofcoYl3[I_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Wooooo001Hooooo`03o`000?oooooooooo02coooooIonW`>]Zooooo`05
o`000?ooooooooooooooool000002oooool005Wooooo00?o0000ooooooooool0;?oooomSojO0jfgo
oooo00Go0000ooooooooooooooooo`00000;ooooo`00F_ooool2o`0002goooooGonW`>]aooooo`04
o`000?ooooooooooo`0000_ooooo001Looooo`03o`000?oooooooooo02_oooooFonW`>]eooooo`03
o`000?oooooo000000_ooooo001Mooooo`03o`000?oooooooooo02_oooooEonW`>]hooooo`04o`00
0?ooooooooooo`0000[ooooo001Nooooo`03o`000?oooooooooo02_oooooDonW`>]looooo`03o`00
0?oooooo000000[ooooo001Oooooo`;o0000;?oooom<ojO0jh?ooooo0_l0000:ooooo`00HOooool0
0ol0003oooooooooo`0ZooooodSoYl3[QOooool3o`0000[ooooo001Rooooo`03o`000?oooooooooo
02_ooooo@onW`>^4ooooo`Co00003Oooool006?ooooo00?o0000ooooooooool0:oooooloojO0jh?o
oooo1?l0000Aooooo`00I?ooool2o`0002cooooo>onW`>^3ooooo`?o00005Oooool006Kooooo00?o
0000ooooooooool0:ooooolcojO0jhGooooo1?l0000Hooooo`00Ioooool00ol0003oooooooooo`0Z
oooooc3oYl3[Q?ooool4o`0001cooooo001Xooooo`03o`000?oooooooooo02[ooooo;?nW`>^3oooo
o`Co00008?ooool006Wooooo0_l0000/ooooobOoYl3[P_ooool4o`0002Cooooo001[ooooo`03o`00
0?oooooooooo02[ooooo8onW`>^2ooooo`?o0000:?ooool006cooooo00?o0000ooooooooool0:_oo
oolMojO0jh?ooooo1?l0000[ooooo`00KOooool00ol0003oooooooooo`0[oooooaSoYl3[P_ooool4
o`0002oooooo001^ooooo`03o`000?oooooooooo02[ooooo5OnW`>^1ooooo`Co0000<oooool006oo
oooo0_l0000[oooooa7oYl3[P?ooool4o`0003Oooooo001aooooo`03o`000?oooooooooo02[ooooo
2OnW`>^2ooooo`Co0000>oooool007;ooooo00?o0000ooooooooool0:_ooool5ojO0jh;ooooo0ol0
000oooooo`00Loooool00ol0003oooooooooo`0Zooooo`03ojO0jooooooooooo07oooooo1?l00012
ooooo`00M?ooool2o`0002[ooooo00?o0000ooooooooool0Noooool4o`0004Kooooo001fooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0N?ooool4o`0004[ooooo001gooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0M?ooool4o`0004kooooo001hooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0LOooool3o`0005;ooooo001iooooo`;o00009?ooool0
0ol0003oooooooooo`1]ooooo`Co0000EOooool007_ooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`1Yooooo`Co0000FOooool007cooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`1Uooooo`Co0000GOooool007gooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`1Qooooo`Co0000HOooool007kooooo0_l0000Oooooo`03o`000?oooooooooo05gooooo1?l0
001Uooooo`00P?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05[ooooo0ol0001Y
ooooo`00POooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Kooooo1?l0001/oooo
o`00P_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05;ooooo1?l0001`ooooo`00
Poooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04kooooo1?l0001dooooo`00Q?oo
ool2o`0001Wooooo00?o0000ooooooooool0B_ooool4o`0007Sooooo0026ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0A_ooool4o`0007cooooo0027ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0@oooool3o`00083ooooo0028ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0?oooool4o`0008?ooooo0029ooooo`;o00005?ooool00ol0003ooooo
ooooo`0kooooo`Co0000Qoooool008_ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0gooooo`Co0000Roooool008cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0c
ooooo`Co0000Soooool008gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0`oooo
o`?o0000Toooool008kooooo0_l0000?ooooo`03o`000?oooooooooo02cooooo1?l0002Fooooo`00
T?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Sooooo1?l0002Jooooo`00TOoo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Cooooo1?l0002Nooooo`00T_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo1?l0002Rooooo`00Toooool2o`00
00Wooooo00?o0000ooooooooool07Oooool4o`000:Kooooo002Eooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool06_ooool3o`000:[ooooo002Fooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool05_ooool4o`000:gooooo002Gooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool04_ooool4o`000;7ooooo002Hooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool03_ooool4o`000;Gooooo002Iooooo`;o00000oooool00ol0003oooooooooo`0:oooo
o`Co0000^Oooool009_ooooo00Co0000oooooooooooo00002Oooool3o`000;gooooo002Looooo`03
o`000?oooooo000000Gooooo1?l00030ooooo`00WOooool2o`000003ooooool0003o000000;o0000
a?ooool009kooooo0_l00038ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00[_ooool01OnHV9So
0000o`000?m4A4Co^[Zj00Wooooo00Co410@o`000?m4A4Coc<c<1_ooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c02Gooooo`00[_ooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo1_l0
0003ooooo`03oiRHV?l@413ogMgM00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40
Uoooool00:kooooo00?o0000ooooooooool03_ooool00on7QhOoEEEEooooo`0:ooooo`05o`000?oo
ooooooooooooool00000Uoooool00:kooooo00?o0000ooooooooool01?ooool6o`000006ooooooo<
c<co8B4Qo`000?mEEEGo00002oooool01Ol0003oV9RHoooooonHV9So8B4Q09Oooooo002^ooooo`03
o`000?oooooooooo00_ooooo00Go8B4QohN7QoooooooV9RHo`00000;ooooo`05o`000?mEEEGo0000
oa0@4?o<c<`0Uoooool00:cooooo00?o410@o`000?l000000ol0000:ooooo`05o`000?oooooooooo
ooooool000002oooool00omEEEGoQhN7ooooo`2Iooooo`00[_ooool00ol0003oooooooooo`0;oooo
o`05ob4Q8OnHV9SoooooogMgMomEEED02oooool00ooMgMgo410@oiRHV02Iooooo`00[_ooool00ol0
003oooooooooo`0;ooooo`05olc<c?l@413o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@
412Gooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -20 0 ]
[.5 .82364 20 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10.4) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69467 Mtetra
.4053 .69467 .41061 .69934 .41957 .69681 .41427 .69213 Mtetra
.41427 .69213 .41957 .69681 .42855 .69428 .42327 .68958 Mtetra
.42327 .68958 .42855 .69428 .43756 .69174 .43231 .68703 Mtetra
.43231 .68703 .43756 .69174 .4466 .68919 .44137 .68446 Mtetra
.44137 .68446 .4466 .68919 .45567 .68663 .45046 .68189 Mtetra
.45046 .68189 .45567 .68663 .46478 .68407 .45958 .67931 Mtetra
.45958 .67931 .46478 .68407 .47391 .68149 .46873 .67671 Mtetra
.46873 .67671 .47391 .68149 .48307 .67891 .47792 .67412 Mtetra
.47792 .67412 .48307 .67891 .49227 .67632 .48713 .67151 Mtetra
.48713 .67151 .49227 .67632 .50149 .67371 .49638 .66889 Mtetra
.49638 .66889 .50149 .67371 .51075 .6711 .50565 .66626 Mtetra
.50565 .66626 .51075 .6711 .52004 .66849 .51496 .66363 Mtetra
.51496 .66363 .52004 .66849 .52936 .66586 .5243 .66098 Mtetra
.5243 .66098 .52936 .66586 .53871 .66322 .53367 .65833 Mtetra
.53367 .65833 .53871 .66322 .54809 .66058 .54308 .65567 Mtetra
.54308 .65567 .54809 .66058 .55751 .65792 .55251 .653 Mtetra
.55251 .653 .55751 .65792 .56695 .65526 .56198 .65032 Mtetra
.56198 .65032 .56695 .65526 .57643 .65259 .57148 .64763 Mtetra
.57148 .64763 .57643 .65259 .58595 .6499 .58102 .64493 Mtetra
.58102 .64493 .58595 .6499 .59549 .64721 .59058 .64222 Mtetra
.59058 .64222 .59549 .64721 .60507 .64451 .60018 .6395 Mtetra
.60018 .6395 .60507 .64451 .61468 .6418 .60982 .63678 Mtetra
.60982 .63678 .61468 .6418 .62432 .63908 .61948 .63404 Mtetra
.61948 .63404 .62432 .63908 .634 .63636 .62918 .63129 Mtetra
.62918 .63129 .634 .63636 .64371 .63362 .63892 .62854 Mtetra
.63892 .62854 .64371 .63362 .65345 .63087 .64868 .62577 Mtetra
.64868 .62577 .65345 .63087 .66323 .62811 .65848 .623 Mtetra
.65848 .623 .66323 .62811 .67304 .62535 .66832 .62021 Mtetra
.66832 .62021 .67304 .62535 .68289 .62257 .67819 .61742 Mtetra
.67819 .61742 .68289 .62257 .69277 .61979 .68809 .61462 Mtetra
.68809 .61462 .69277 .61979 .70269 .61699 .69803 .6118 Mtetra
.69803 .6118 .70269 .61699 .71264 .61418 .70801 .60898 Mtetra
.70801 .60898 .71264 .61418 .72262 .61137 .71802 .60615 Mtetra
.71802 .60615 .72262 .61137 .73264 .60854 .72806 .6033 Mtetra
.72806 .6033 .73264 .60854 .7427 .60571 .73814 .60045 Mtetra
.73814 .60045 .7427 .60571 .75279 .60286 .74826 .59759 Mtetra
.74826 .59759 .75279 .60286 .76291 .60001 .75841 .59471 Mtetra
.75841 .59471 .76291 .60001 .77308 .59714 .7686 .59183 Mtetra
.7686 .59183 .77308 .59714 .78328 .59427 .77882 .58893 Mtetra
.77882 .58893 .78328 .59427 .79351 .59138 .78908 .58603 Mtetra
.78908 .58603 .79351 .59138 .80378 .58849 .79938 .58311 Mtetra
.79938 .58311 .80378 .58849 .81409 .58558 .80971 .58019 Mtetra
.80971 .58019 .81409 .58558 .82443 .58267 .82008 .57725 Mtetra
.82008 .57725 .82443 .58267 .83482 .57974 .83049 .57431 Mtetra
.83049 .57431 .83482 .57974 .84523 .5768 .84094 .57135 Mtetra
.84094 .57135 .84523 .5768 .85569 .57385 .85142 .56838 Mtetra
.85142 .56838 .85569 .57385 .86618 .57089 .86194 .5654 Mtetra
.86194 .5654 .86618 .57089 .87672 .56792 .8725 .56241 Mtetra
.8725 .56241 .87672 .56792 .88729 .56494 .8831 .55941 Mtetra
.8831 .55941 .88729 .56494 .89789 .56195 .89374 .5564 Mtetra
.89374 .5564 .89789 .56195 .90854 .55895 .90441 .55338 Mtetra
.90441 .55338 .90854 .55895 .91923 .55594 .91512 .55035 Mtetra
.91512 .55035 .91923 .55594 .92995 .55292 .92588 .5473 Mtetra
.92588 .5473 .92995 .55292 .94071 .54988 .93667 .54425 Mtetra
.93667 .54425 .94071 .54988 .95152 .54684 .9475 .54118 Mtetra
.9475 .54118 .95152 .54684 .96236 .54378 .95837 .53811 Mtetra
.95837 .53811 .96236 .54378 .97324 .54071 .96928 .53502 Mtetra
.96928 .53502 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.391 .69252 .39636 .6972 .4053 .69467 .39996 .68998 Mtetra
.39996 .68998 .4053 .69467 .41427 .69213 .40895 .68742 Mtetra
.40895 .68742 .41427 .69213 .42327 .68958 .41797 .68486 Mtetra
.41797 .68486 .42327 .68958 .43231 .68703 .42702 .68228 Mtetra
.42702 .68228 .43231 .68703 .44137 .68446 .4361 .6797 Mtetra
.4361 .6797 .44137 .68446 .45046 .68189 .44521 .67711 Mtetra
.44521 .67711 .45046 .68189 .45958 .67931 .45435 .67452 Mtetra
.45435 .67452 .45958 .67931 .46873 .67671 .46352 .67191 Mtetra
.46352 .67191 .46873 .67671 .47792 .67412 .47273 .66929 Mtetra
.47273 .66929 .47792 .67412 .48713 .67151 .48196 .66667 Mtetra
.48196 .66667 .48713 .67151 .49638 .66889 .49123 .66403 Mtetra
.49123 .66403 .49638 .66889 .50565 .66626 .50053 .66139 Mtetra
.50053 .66139 .50565 .66626 .51496 .66363 .50985 .65874 Mtetra
.50985 .65874 .51496 .66363 .5243 .66098 .51922 .65608 Mtetra
.51922 .65608 .5243 .66098 .53367 .65833 .52861 .65341 Mtetra
.52861 .65341 .53367 .65833 .54308 .65567 .53803 .65073 Mtetra
.53803 .65073 .54308 .65567 .55251 .653 .54749 .64804 Mtetra
.54749 .64804 .55251 .653 .56198 .65032 .55698 .64534 Mtetra
.55698 .64534 .56198 .65032 .57148 .64763 .5665 .64264 Mtetra
.5665 .64264 .57148 .64763 .58102 .64493 .57606 .63992 Mtetra
.57606 .63992 .58102 .64493 .59058 .64222 .58565 .6372 Mtetra
.58565 .6372 .59058 .64222 .60018 .6395 .59527 .63446 Mtetra
.59527 .63446 .60018 .6395 .60982 .63678 .60493 .63172 Mtetra
.60493 .63172 .60982 .63678 .61948 .63404 .61461 .62896 Mtetra
.61461 .62896 .61948 .63404 .62918 .63129 .62434 .6262 Mtetra
.62434 .6262 .62918 .63129 .63892 .62854 .63409 .62343 Mtetra
.63409 .62343 .63892 .62854 .64868 .62577 .64388 .62064 Mtetra
.64388 .62064 .64868 .62577 .65848 .623 .65371 .61785 Mtetra
.65371 .61785 .65848 .623 .66832 .62021 .66357 .61505 Mtetra
.66357 .61505 .66832 .62021 .67819 .61742 .67346 .61224 Mtetra
.67346 .61224 .67819 .61742 .68809 .61462 .68339 .60942 Mtetra
.68339 .60942 .68809 .61462 .69803 .6118 .69335 .60658 Mtetra
.69335 .60658 .69803 .6118 .70801 .60898 .70335 .60374 Mtetra
.70335 .60374 .70801 .60898 .71802 .60615 .71338 .60089 Mtetra
.71338 .60089 .71802 .60615 .72806 .6033 .72345 .59803 Mtetra
.72345 .59803 .72806 .6033 .73814 .60045 .73356 .59516 Mtetra
.73356 .59516 .73814 .60045 .74826 .59759 .7437 .59227 Mtetra
.7437 .59227 .74826 .59759 .75841 .59471 .75387 .58938 Mtetra
.75387 .58938 .75841 .59471 .7686 .59183 .76409 .58648 Mtetra
.76409 .58648 .7686 .59183 .77882 .58893 .77434 .58356 Mtetra
.77434 .58356 .77882 .58893 .78908 .58603 .78462 .58064 Mtetra
.78462 .58064 .78908 .58603 .79938 .58311 .79495 .57771 Mtetra
.79495 .57771 .79938 .58311 .80971 .58019 .80531 .57476 Mtetra
.80531 .57476 .80971 .58019 .82008 .57725 .81571 .57181 Mtetra
.81571 .57181 .82008 .57725 .83049 .57431 .82614 .56884 Mtetra
.82614 .56884 .83049 .57431 .84094 .57135 .83661 .56586 Mtetra
.83661 .56586 .84094 .57135 .85142 .56838 .84712 .56288 Mtetra
.84712 .56288 .85142 .56838 .86194 .5654 .85767 .55988 Mtetra
.85767 .55988 .86194 .5654 .8725 .56241 .86826 .55687 Mtetra
.86826 .55687 .8725 .56241 .8831 .55941 .87889 .55385 Mtetra
.87889 .55385 .8831 .55941 .89374 .5564 .88955 .55082 Mtetra
.88955 .55082 .89374 .5564 .90441 .55338 .90025 .54777 Mtetra
.90025 .54777 .90441 .55338 .91512 .55035 .911 .54472 Mtetra
.911 .54472 .91512 .55035 .92588 .5473 .92178 .54166 Mtetra
.92178 .54166 .92588 .5473 .93667 .54425 .9326 .53858 Mtetra
.9326 .53858 .93667 .54425 .9475 .54118 .94346 .53549 Mtetra
.94346 .53549 .9475 .54118 .95837 .53811 .95436 .53239 Mtetra
.95436 .53239 .95837 .53811 .96928 .53502 .9653 .52928 Mtetra
.9653 .52928 .96928 .53502 .98024 .53192 .97628 .52616 Mtetra
.38561 .68781 .391 .69252 .39996 .68998 .39459 .68525 Mtetra
.39459 .68525 .39996 .68998 .40895 .68742 .40359 .68268 Mtetra
.40359 .68268 .40895 .68742 .41797 .68486 .41263 .6801 Mtetra
.41263 .6801 .41797 .68486 .42702 .68228 .4217 .67751 Mtetra
.4217 .67751 .42702 .68228 .4361 .6797 .4308 .67492 Mtetra
.4308 .67492 .4361 .6797 .44521 .67711 .43993 .67231 Mtetra
.43993 .67231 .44521 .67711 .45435 .67452 .44909 .6697 Mtetra
.44909 .6697 .45435 .67452 .46352 .67191 .45828 .66707 Mtetra
.45828 .66707 .46352 .67191 .47273 .66929 .46751 .66444 Mtetra
.46751 .66444 .47273 .66929 .48196 .66667 .47676 .6618 Mtetra
.47676 .6618 .48196 .66667 .49123 .66403 .48605 .65915 Mtetra
.48605 .65915 .49123 .66403 .50053 .66139 .49537 .65649 Mtetra
.49537 .65649 .50053 .66139 .50985 .65874 .50472 .65382 Mtetra
.50472 .65382 .50985 .65874 .51922 .65608 .5141 .65114 Mtetra
.5141 .65114 .51922 .65608 .52861 .65341 .52351 .64846 Mtetra
.52351 .64846 .52861 .65341 .53803 .65073 .53296 .64576 Mtetra
.53296 .64576 .53803 .65073 .54749 .64804 .54244 .64305 Mtetra
.54244 .64305 .54749 .64804 .55698 .64534 .55195 .64034 Mtetra
.55195 .64034 .55698 .64534 .5665 .64264 .56149 .63762 Mtetra
.56149 .63762 .5665 .64264 .57606 .63992 .57107 .63488 Mtetra
.57107 .63488 .57606 .63992 .58565 .6372 .58068 .63214 Mtetra
.58068 .63214 .58565 .6372 .59527 .63446 .59032 .62939 Mtetra
.59032 .62939 .59527 .63446 .60493 .63172 .6 .62663 Mtetra
.6 .62663 .60493 .63172 .61461 .62896 .60971 .62385 Mtetra
.60971 .62385 .61461 .62896 .62434 .6262 .61946 .62107 Mtetra
.61946 .62107 .62434 .6262 .63409 .62343 .62924 .61828 Mtetra
.62924 .61828 .63409 .62343 .64388 .62064 .63905 .61548 Mtetra
.63905 .61548 .64388 .62064 .65371 .61785 .6489 .61267 Mtetra
.6489 .61267 .65371 .61785 .66357 .61505 .65878 .60985 Mtetra
.65878 .60985 .66357 .61505 .67346 .61224 .6687 .60702 Mtetra
.6687 .60702 .67346 .61224 .68339 .60942 .67865 .60418 Mtetra
.67865 .60418 .68339 .60942 .69335 .60658 .68864 .60133 Mtetra
.68864 .60133 .69335 .60658 .70335 .60374 .69866 .59847 Mtetra
.69866 .59847 .70335 .60374 .71338 .60089 .70872 .5956 Mtetra
.70872 .5956 .71338 .60089 .72345 .59803 .71881 .59272 Mtetra
.71881 .59272 .72345 .59803 .73356 .59516 .72894 .58983 Mtetra
.72894 .58983 .73356 .59516 .7437 .59227 .73911 .58692 Mtetra
.73911 .58692 .7437 .59227 .75387 .58938 .74931 .58401 Mtetra
.74931 .58401 .75387 .58938 .76409 .58648 .75955 .58109 Mtetra
.75955 .58109 .76409 .58648 .77434 .58356 .76982 .57816 Mtetra
.76982 .57816 .77434 .58356 .78462 .58064 .78014 .57521 Mtetra
.78014 .57521 .78462 .58064 .79495 .57771 .79049 .57226 Mtetra
.79049 .57226 .79495 .57771 .80531 .57476 .80087 .5693 Mtetra
.80087 .5693 .80531 .57476 .81571 .57181 .8113 .56632 Mtetra
.8113 .56632 .81571 .57181 .82614 .56884 .82176 .56334 Mtetra
.82176 .56334 .82614 .56884 .83661 .56586 .83226 .56034 Mtetra
.83226 .56034 .83661 .56586 .84712 .56288 .8428 .55733 Mtetra
.8428 .55733 .84712 .56288 .85767 .55988 .85337 .55431 Mtetra
.85337 .55431 .85767 .55988 .86826 .55687 .86399 .55128 Mtetra
.86399 .55128 .86826 .55687 .87889 .55385 .87464 .54824 Mtetra
.87464 .54824 .87889 .55385 .88955 .55082 .88533 .54519 Mtetra
.88533 .54519 .88955 .55082 .90025 .54777 .89607 .54213 Mtetra
.89607 .54213 .90025 .54777 .911 .54472 .90684 .53905 Mtetra
.90684 .53905 .911 .54472 .92178 .54166 .91765 .53597 Mtetra
.91765 .53597 .92178 .54166 .9326 .53858 .9285 .53287 Mtetra
.9285 .53287 .9326 .53858 .94346 .53549 .93939 .52976 Mtetra
.93939 .52976 .94346 .53549 .95436 .53239 .95032 .52664 Mtetra
.95032 .52664 .95436 .53239 .9653 .52928 .96129 .52351 Mtetra
.96129 .52351 .9653 .52928 .97628 .52616 .9723 .52037 Mtetra
.38018 .68308 .38561 .68781 .39459 .68525 .38918 .6805 Mtetra
.38918 .6805 .39459 .68525 .40359 .68268 .3982 .67791 Mtetra
.3982 .67791 .40359 .68268 .41263 .6801 .40726 .67532 Mtetra
.40726 .67532 .41263 .6801 .4217 .67751 .41635 .67271 Mtetra
.41635 .67271 .4217 .67751 .4308 .67492 .42547 .6701 Mtetra
.42547 .6701 .4308 .67492 .43993 .67231 .43462 .66748 Mtetra
.43462 .66748 .43993 .67231 .44909 .6697 .4438 .66485 Mtetra
.4438 .66485 .44909 .6697 .45828 .66707 .45301 .66221 Mtetra
.45301 .66221 .45828 .66707 .46751 .66444 .46225 .65956 Mtetra
.46225 .65956 .46751 .66444 .47676 .6618 .47153 .6569 Mtetra
.47153 .6569 .47676 .6618 .48605 .65915 .48083 .65423 Mtetra
.48083 .65423 .48605 .65915 .49537 .65649 .49017 .65156 Mtetra
.49017 .65156 .49537 .65649 .50472 .65382 .49954 .64887 Mtetra
.49954 .64887 .50472 .65382 .5141 .65114 .50895 .64618 Mtetra
.50895 .64618 .5141 .65114 .52351 .64846 .51838 .64347 Mtetra
.51838 .64347 .52351 .64846 .53296 .64576 .52785 .64076 Mtetra
.52785 .64076 .53296 .64576 .54244 .64305 .53735 .63804 Mtetra
.53735 .63804 .54244 .64305 .55195 .64034 .54688 .6353 Mtetra
.54688 .6353 .55195 .64034 .56149 .63762 .55645 .63256 Mtetra
.55645 .63256 .56149 .63762 .57107 .63488 .56605 .62981 Mtetra
.56605 .62981 .57107 .63488 .58068 .63214 .57568 .62705 Mtetra
.57568 .62705 .58068 .63214 .59032 .62939 .58535 .62428 Mtetra
.58535 .62428 .59032 .62939 .6 .62663 .59505 .6215 Mtetra
.59505 .6215 .6 .62663 .60971 .62385 .60478 .61871 Mtetra
.60478 .61871 .60971 .62385 .61946 .62107 .61455 .61591 Mtetra
.61455 .61591 .61946 .62107 .62924 .61828 .62435 .6131 Mtetra
.62435 .6131 .62924 .61828 .63905 .61548 .63419 .61028 Mtetra
.63419 .61028 .63905 .61548 .6489 .61267 .64406 .60746 Mtetra
.64406 .60746 .6489 .61267 .65878 .60985 .65396 .60462 Mtetra
.65396 .60462 .65878 .60985 .6687 .60702 .66391 .60177 Mtetra
.66391 .60177 .6687 .60702 .67865 .60418 .67388 .59891 Mtetra
.67388 .59891 .67865 .60418 .68864 .60133 .68389 .59604 Mtetra
.68389 .59604 .68864 .60133 .69866 .59847 .69394 .59316 Mtetra
.69394 .59316 .69866 .59847 .70872 .5956 .70402 .59027 Mtetra
.70402 .59027 .70872 .5956 .71881 .59272 .71414 .58737 Mtetra
.71414 .58737 .71881 .59272 .72894 .58983 .7243 .58446 Mtetra
.7243 .58446 .72894 .58983 .73911 .58692 .73449 .58154 Mtetra
.73449 .58154 .73911 .58692 .74931 .58401 .74472 .57861 Mtetra
.74472 .57861 .74931 .58401 .75955 .58109 .75498 .57567 Mtetra
.75498 .57567 .75955 .58109 .76982 .57816 .76528 .57272 Mtetra
.76528 .57272 .76982 .57816 .78014 .57521 .77562 .56975 Mtetra
.77562 .56975 .78014 .57521 .79049 .57226 .786 .56678 Mtetra
.786 .56678 .79049 .57226 .80087 .5693 .79641 .5638 Mtetra
.79641 .5638 .80087 .5693 .8113 .56632 .80686 .5608 Mtetra
.80686 .5608 .8113 .56632 .82176 .56334 .81735 .55779 Mtetra
.81735 .55779 .82176 .56334 .83226 .56034 .82788 .55478 Mtetra
.82788 .55478 .83226 .56034 .8428 .55733 .83844 .55175 Mtetra
.83844 .55175 .8428 .55733 .85337 .55431 .84905 .54871 Mtetra
.84905 .54871 .85337 .55431 .86399 .55128 .85969 .54566 Mtetra
.85969 .54566 .86399 .55128 .87464 .54824 .87037 .5426 Mtetra
.87037 .5426 .87464 .54824 .88533 .54519 .88109 .53953 Mtetra
.88109 .53953 .88533 .54519 .89607 .54213 .89185 .53644 Mtetra
.89185 .53644 .89607 .54213 .90684 .53905 .90265 .53335 Mtetra
.90265 .53335 .90684 .53905 .91765 .53597 .91349 .53024 Mtetra
.91349 .53024 .91765 .53597 .9285 .53287 .92437 .52712 Mtetra
.92437 .52712 .9285 .53287 .93939 .52976 .93529 .524 Mtetra
.93529 .524 .93939 .52976 .95032 .52664 .94625 .52085 Mtetra
.94625 .52085 .95032 .52664 .96129 .52351 .95725 .5177 Mtetra
.95725 .5177 .96129 .52351 .9723 .52037 .96829 .51454 Mtetra
.37472 .67831 .38018 .68308 .38918 .6805 .38373 .67572 Mtetra
.38373 .67572 .38918 .6805 .3982 .67791 .39278 .67311 Mtetra
.39278 .67311 .3982 .67791 .40726 .67532 .40186 .6705 Mtetra
.40186 .6705 .40726 .67532 .41635 .67271 .41096 .66788 Mtetra
.41096 .66788 .41635 .67271 .42547 .6701 .4201 .66525 Mtetra
.4201 .66525 .42547 .6701 .43462 .66748 .42927 .66261 Mtetra
.42927 .66261 .43462 .66748 .4438 .66485 .43847 .65996 Mtetra
.43847 .65996 .4438 .66485 .45301 .66221 .4477 .65731 Mtetra
.4477 .65731 .45301 .66221 .46225 .65956 .45697 .65464 Mtetra
.45697 .65464 .46225 .65956 .47153 .6569 .46626 .65197 Mtetra
.46626 .65197 .47153 .6569 .48083 .65423 .47559 .64928 Mtetra
.47559 .64928 .48083 .65423 .49017 .65156 .48495 .64659 Mtetra
.48495 .64659 .49017 .65156 .49954 .64887 .49434 .64389 Mtetra
.49434 .64389 .49954 .64887 .50895 .64618 .50376 .64118 Mtetra
.50376 .64118 .50895 .64618 .51838 .64347 .51322 .63846 Mtetra
.51322 .63846 .51838 .64347 .52785 .64076 .52271 .63572 Mtetra
.52271 .63572 .52785 .64076 .53735 .63804 .53223 .63298 Mtetra
.53223 .63298 .53735 .63804 .54688 .6353 .54178 .63024 Mtetra
.54178 .63024 .54688 .6353 .55645 .63256 .55137 .62748 Mtetra
.55137 .62748 .55645 .63256 .56605 .62981 .56099 .62471 Mtetra
.56099 .62471 .56605 .62981 .57568 .62705 .57065 .62193 Mtetra
.57065 .62193 .57568 .62705 .58535 .62428 .58034 .61914 Mtetra
.58034 .61914 .58535 .62428 .59505 .6215 .59006 .61634 Mtetra
.59006 .61634 .59505 .6215 .60478 .61871 .59982 .61354 Mtetra
.59982 .61354 .60478 .61871 .61455 .61591 .60961 .61072 Mtetra
.60961 .61072 .61455 .61591 .62435 .6131 .61943 .60789 Mtetra
.61943 .60789 .62435 .6131 .63419 .61028 .62929 .60505 Mtetra
.62929 .60505 .63419 .61028 .64406 .60746 .63919 .60221 Mtetra
.63919 .60221 .64406 .60746 .65396 .60462 .64912 .59935 Mtetra
.64912 .59935 .65396 .60462 .66391 .60177 .65908 .59648 Mtetra
.65908 .59648 .66391 .60177 .67388 .59891 .66908 .5936 Mtetra
.66908 .5936 .67388 .59891 .68389 .59604 .67912 .59072 Mtetra
.67912 .59072 .68389 .59604 .69394 .59316 .68919 .58782 Mtetra
.68919 .58782 .69394 .59316 .70402 .59027 .6993 .58491 Mtetra
.6993 .58491 .70402 .59027 .71414 .58737 .70944 .58199 Mtetra
.70944 .58199 .71414 .58737 .7243 .58446 .71962 .57906 Mtetra
.71962 .57906 .7243 .58446 .73449 .58154 .72984 .57612 Mtetra
.72984 .57612 .73449 .58154 .74472 .57861 .74009 .57317 Mtetra
.74009 .57317 .74472 .57861 .75498 .57567 .75038 .57021 Mtetra
.75038 .57021 .75498 .57567 .76528 .57272 .76071 .56724 Mtetra
.76071 .56724 .76528 .57272 .77562 .56975 .77107 .56426 Mtetra
.77107 .56426 .77562 .56975 .786 .56678 .78148 .56126 Mtetra
.78148 .56126 .786 .56678 .79641 .5638 .79192 .55826 Mtetra
.79192 .55826 .79641 .5638 .80686 .5608 .80239 .55524 Mtetra
.80239 .55524 .80686 .5608 .81735 .55779 .81291 .55222 Mtetra
.81291 .55222 .81735 .55779 .82788 .55478 .82346 .54918 Mtetra
.82346 .54918 .82788 .55478 .83844 .55175 .83406 .54613 Mtetra
.83406 .54613 .83844 .55175 .84905 .54871 .84469 .54307 Mtetra
.84469 .54307 .84905 .54871 .85969 .54566 .85536 .54 Mtetra
.85536 .54 .85969 .54566 .87037 .5426 .86607 .53692 Mtetra
.86607 .53692 .87037 .5426 .88109 .53953 .87682 .53383 Mtetra
.87682 .53383 .88109 .53953 .89185 .53644 .88761 .53072 Mtetra
.88761 .53072 .89185 .53644 .90265 .53335 .89844 .52761 Mtetra
.89844 .52761 .90265 .53335 .91349 .53024 .90931 .52448 Mtetra
.90931 .52448 .91349 .53024 .92437 .52712 .92022 .52134 Mtetra
.92022 .52134 .92437 .52712 .93529 .524 .93116 .51819 Mtetra
.93116 .51819 .93529 .524 .94625 .52085 .94216 .51503 Mtetra
.94216 .51503 .94625 .52085 .95725 .5177 .95319 .51185 Mtetra
.95319 .51185 .95725 .5177 .96829 .51454 .96426 .50866 Mtetra
.36922 .67351 .37472 .67831 .38373 .67572 .37826 .6709 Mtetra
.37826 .6709 .38373 .67572 .39278 .67311 .38732 .66828 Mtetra
.38732 .66828 .39278 .67311 .40186 .6705 .39642 .66566 Mtetra
.39642 .66566 .40186 .6705 .41096 .66788 .40554 .66302 Mtetra
.40554 .66302 .41096 .66788 .4201 .66525 .4147 .66037 Mtetra
.4147 .66037 .4201 .66525 .42927 .66261 .42389 .65772 Mtetra
.42389 .65772 .42927 .66261 .43847 .65996 .43311 .65505 Mtetra
.43311 .65505 .43847 .65996 .4477 .65731 .44236 .65238 Mtetra
.44236 .65238 .4477 .65731 .45697 .65464 .45165 .6497 Mtetra
.45165 .6497 .45697 .65464 .46626 .65197 .46096 .64701 Mtetra
.46096 .64701 .46626 .65197 .47559 .64928 .47031 .6443 Mtetra
.47031 .6443 .47559 .64928 .48495 .64659 .47969 .64159 Mtetra
.47969 .64159 .48495 .64659 .49434 .64389 .4891 .63887 Mtetra
.4891 .63887 .49434 .64389 .50376 .64118 .49855 .63615 Mtetra
.49855 .63615 .50376 .64118 .51322 .63846 .50802 .63341 Mtetra
.50802 .63341 .51322 .63846 .52271 .63572 .51753 .63066 Mtetra
.51753 .63066 .52271 .63572 .53223 .63298 .52708 .6279 Mtetra
.52708 .6279 .53223 .63298 .54178 .63024 .53665 .62513 Mtetra
.53665 .62513 .54178 .63024 .55137 .62748 .54626 .62236 Mtetra
.54626 .62236 .55137 .62748 .56099 .62471 .55591 .61957 Mtetra
.55591 .61957 .56099 .62471 .57065 .62193 .56558 .61677 Mtetra
.56558 .61677 .57065 .62193 .58034 .61914 .57529 .61397 Mtetra
.57529 .61397 .58034 .61914 .59006 .61634 .58504 .61115 Mtetra
.58504 .61115 .59006 .61634 .59982 .61354 .59482 .60833 Mtetra
.59482 .60833 .59982 .61354 .60961 .61072 .60463 .60549 Mtetra
.60463 .60549 .60961 .61072 .61943 .60789 .61448 .60265 Mtetra
.61448 .60265 .61943 .60789 .62929 .60505 .62437 .59979 Mtetra
.62437 .59979 .62929 .60505 .63919 .60221 .63428 .59692 Mtetra
.63428 .59692 .63919 .60221 .64912 .59935 .64424 .59405 Mtetra
.64424 .59405 .64912 .59935 .65908 .59648 .65423 .59116 Mtetra
.65423 .59116 .65908 .59648 .66908 .5936 .66425 .58826 Mtetra
.66425 .58826 .66908 .5936 .67912 .59072 .67431 .58536 Mtetra
.67431 .58536 .67912 .59072 .68919 .58782 .68441 .58244 Mtetra
.68441 .58244 .68919 .58782 .6993 .58491 .69454 .57951 Mtetra
.69454 .57951 .6993 .58491 .70944 .58199 .70471 .57657 Mtetra
.70471 .57657 .70944 .58199 .71962 .57906 .71491 .57363 Mtetra
.71491 .57363 .71962 .57906 .72984 .57612 .72516 .57067 Mtetra
.72516 .57067 .72984 .57612 .74009 .57317 .73544 .5677 Mtetra
.73544 .5677 .74009 .57317 .75038 .57021 .74575 .56471 Mtetra
.74575 .56471 .75038 .57021 .76071 .56724 .75611 .56172 Mtetra
.75611 .56172 .76071 .56724 .77107 .56426 .7665 .55872 Mtetra
.7665 .55872 .77107 .56426 .78148 .56126 .77693 .55571 Mtetra
.77693 .55571 .78148 .56126 .79192 .55826 .78739 .55268 Mtetra
.78739 .55268 .79192 .55826 .80239 .55524 .7979 .54965 Mtetra
.7979 .54965 .80239 .55524 .81291 .55222 .80844 .5466 Mtetra
.80844 .5466 .81291 .55222 .82346 .54918 .81902 .54354 Mtetra
.81902 .54354 .82346 .54918 .83406 .54613 .82964 .54047 Mtetra
.82964 .54047 .83406 .54613 .84469 .54307 .8403 .53739 Mtetra
.8403 .53739 .84469 .54307 .85536 .54 .851 .5343 Mtetra
.851 .5343 .85536 .54 .86607 .53692 .86174 .5312 Mtetra
.86174 .5312 .86607 .53692 .87682 .53383 .87252 .52809 Mtetra
.87252 .52809 .87682 .53383 .88761 .53072 .88334 .52496 Mtetra
.88334 .52496 .88761 .53072 .89844 .52761 .89419 .52182 Mtetra
.89419 .52182 .89844 .52761 .90931 .52448 .90509 .51867 Mtetra
.90509 .51867 .90931 .52448 .92022 .52134 .91603 .51551 Mtetra
.91603 .51551 .92022 .52134 .93116 .51819 .92701 .51234 Mtetra
.92701 .51234 .93116 .51819 .94216 .51503 .93803 .50916 Mtetra
.93803 .50916 .94216 .51503 .95319 .51185 .94909 .50596 Mtetra
.94909 .50596 .95319 .51185 .96426 .50866 .9602 .50275 Mtetra
.36369 .66869 .36922 .67351 .37826 .6709 .37275 .66606 Mtetra
.37275 .66606 .37826 .6709 .38732 .66828 .38183 .66342 Mtetra
.38183 .66342 .38732 .66828 .39642 .66566 .39094 .66078 Mtetra
.39094 .66078 .39642 .66566 .40554 .66302 .40009 .65813 Mtetra
.40009 .65813 .40554 .66302 .4147 .66037 .40927 .65546 Mtetra
.40927 .65546 .4147 .66037 .42389 .65772 .41848 .65279 Mtetra
.41848 .65279 .42389 .65772 .43311 .65505 .42772 .65011 Mtetra
.42772 .65011 .43311 .65505 .44236 .65238 .43699 .64742 Mtetra
.43699 .64742 .44236 .65238 .45165 .6497 .44629 .64472 Mtetra
.44629 .64472 .45165 .6497 .46096 .64701 .45563 .64201 Mtetra
.45563 .64201 .46096 .64701 .47031 .6443 .465 .63929 Mtetra
.465 .63929 .47031 .6443 .47969 .64159 .4744 .63657 Mtetra
.4744 .63657 .47969 .64159 .4891 .63887 .48383 .63383 Mtetra
.48383 .63383 .4891 .63887 .49855 .63615 .4933 .63108 Mtetra
.4933 .63108 .49855 .63615 .50802 .63341 .50279 .62833 Mtetra
.50279 .62833 .50802 .63341 .51753 .63066 .51233 .62556 Mtetra
.51233 .62556 .51753 .63066 .52708 .6279 .52189 .62279 Mtetra
.52189 .62279 .52708 .6279 .53665 .62513 .53149 .62 Mtetra
.53149 .62 .53665 .62513 .54626 .62236 .54112 .61721 Mtetra
.54112 .61721 .54626 .62236 .55591 .61957 .55079 .6144 Mtetra
.55079 .6144 .55591 .61957 .56558 .61677 .56049 .61159 Mtetra
.56049 .61159 .56558 .61677 .57529 .61397 .57022 .60876 Mtetra
.57022 .60876 .57529 .61397 .58504 .61115 .57999 .60593 Mtetra
.57999 .60593 .58504 .61115 .59482 .60833 .58979 .60308 Mtetra
.58979 .60308 .59482 .60833 .60463 .60549 .59963 .60023 Mtetra
.59963 .60023 .60463 .60549 .61448 .60265 .6095 .59737 Mtetra
.6095 .59737 .61448 .60265 .62437 .59979 .61941 .59449 Mtetra
.61941 .59449 .62437 .59979 .63428 .59692 .62935 .59161 Mtetra
.62935 .59161 .63428 .59692 .64424 .59405 .63933 .58871 Mtetra
.63933 .58871 .64424 .59405 .65423 .59116 .64934 .58581 Mtetra
.64934 .58581 .65423 .59116 .66425 .58826 .65939 .58289 Mtetra
.65939 .58289 .66425 .58826 .67431 .58536 .66947 .57996 Mtetra
.66947 .57996 .67431 .58536 .68441 .58244 .67959 .57703 Mtetra
.67959 .57703 .68441 .58244 .69454 .57951 .68975 .57408 Mtetra
.68975 .57408 .69454 .57951 .70471 .57657 .69995 .57112 Mtetra
.69995 .57112 .70471 .57657 .71491 .57363 .71018 .56815 Mtetra
.71018 .56815 .71491 .57363 .72516 .57067 .72044 .56517 Mtetra
.72044 .56517 .72516 .57067 .73544 .5677 .73075 .56218 Mtetra
.73075 .56218 .73544 .5677 .74575 .56471 .74109 .55918 Mtetra
.74109 .55918 .74575 .56471 .75611 .56172 .75147 .55617 Mtetra
.75147 .55617 .75611 .56172 .7665 .55872 .76189 .55315 Mtetra
.76189 .55315 .7665 .55872 .77693 .55571 .77234 .55012 Mtetra
.77234 .55012 .77693 .55571 .78739 .55268 .78284 .54707 Mtetra
.78284 .54707 .78739 .55268 .7979 .54965 .79337 .54401 Mtetra
.79337 .54401 .7979 .54965 .80844 .5466 .80394 .54095 Mtetra
.80394 .54095 .80844 .5466 .81902 .54354 .81455 .53787 Mtetra
.81455 .53787 .81902 .54354 .82964 .54047 .8252 .53478 Mtetra
.8252 .53478 .82964 .54047 .8403 .53739 .83589 .53168 Mtetra
.83589 .53168 .8403 .53739 .851 .5343 .84661 .52857 Mtetra
.84661 .52857 .851 .5343 .86174 .5312 .85738 .52544 Mtetra
.85738 .52544 .86174 .5312 .87252 .52809 .86819 .52231 Mtetra
.86819 .52231 .87252 .52809 .88334 .52496 .87903 .51916 Mtetra
.87903 .51916 .88334 .52496 .89419 .52182 .88992 .516 Mtetra
.88992 .516 .89419 .52182 .90509 .51867 .90085 .51283 Mtetra
.90085 .51283 .90509 .51867 .91603 .51551 .91182 .50965 Mtetra
.91182 .50965 .91603 .51551 .92701 .51234 .92283 .50645 Mtetra
.92283 .50645 .92701 .51234 .93803 .50916 .93388 .50325 Mtetra
.93388 .50325 .93803 .50916 .94909 .50596 .94497 .50003 Mtetra
.94497 .50003 .94909 .50596 .9602 .50275 .9561 .4968 Mtetra
.35813 .66383 .36369 .66869 .37275 .66606 .3672 .66119 Mtetra
.3672 .66119 .37275 .66606 .38183 .66342 .3763 .65854 Mtetra
.3763 .65854 .38183 .66342 .39094 .66078 .38544 .65587 Mtetra
.38544 .65587 .39094 .66078 .40009 .65813 .3946 .6532 Mtetra
.3946 .6532 .40009 .65813 .40927 .65546 .4038 .65052 Mtetra
.4038 .65052 .40927 .65546 .41848 .65279 .41303 .64783 Mtetra
.41303 .64783 .41848 .65279 .42772 .65011 .42229 .64514 Mtetra
.42229 .64514 .42772 .65011 .43699 .64742 .43158 .64243 Mtetra
.43158 .64243 .43699 .64742 .44629 .64472 .4409 .63971 Mtetra
.4409 .63971 .44629 .64472 .45563 .64201 .45026 .63699 Mtetra
.45026 .63699 .45563 .64201 .465 .63929 .45965 .63425 Mtetra
.45965 .63425 .465 .63929 .4744 .63657 .46907 .63151 Mtetra
.46907 .63151 .4744 .63657 .48383 .63383 .47853 .62875 Mtetra
.47853 .62875 .48383 .63383 .4933 .63108 .48801 .62599 Mtetra
.48801 .62599 .4933 .63108 .50279 .62833 .49753 .62321 Mtetra
.49753 .62321 .50279 .62833 .51233 .62556 .50709 .62043 Mtetra
.50709 .62043 .51233 .62556 .52189 .62279 .51667 .61764 Mtetra
.51667 .61764 .52189 .62279 .53149 .62 .52629 .61483 Mtetra
.52629 .61483 .53149 .62 .54112 .61721 .53595 .61202 Mtetra
.53595 .61202 .54112 .61721 .55079 .6144 .54563 .6092 Mtetra
.54563 .6092 .55079 .6144 .56049 .61159 .55536 .60636 Mtetra
.55536 .60636 .56049 .61159 .57022 .60876 .56511 .60352 Mtetra
.56511 .60352 .57022 .60876 .57999 .60593 .5749 .60067 Mtetra
.5749 .60067 .57999 .60593 .58979 .60308 .58473 .59781 Mtetra
.58473 .59781 .58979 .60308 .59963 .60023 .59459 .59493 Mtetra
.59459 .59493 .59963 .60023 .6095 .59737 .60448 .59205 Mtetra
.60448 .59205 .6095 .59737 .61941 .59449 .61441 .58916 Mtetra
.61441 .58916 .61941 .59449 .62935 .59161 .62438 .58625 Mtetra
.62438 .58625 .62935 .59161 .63933 .58871 .63438 .58334 Mtetra
.63438 .58334 .63933 .58871 .64934 .58581 .64442 .58041 Mtetra
.64442 .58041 .64934 .58581 .65939 .58289 .65449 .57748 Mtetra
.65449 .57748 .65939 .58289 .66947 .57996 .6646 .57453 Mtetra
.6646 .57453 .66947 .57996 .67959 .57703 .67475 .57158 Mtetra
.67475 .57158 .67959 .57703 .68975 .57408 .68493 .56861 Mtetra
.68493 .56861 .68975 .57408 .69995 .57112 .69515 .56563 Mtetra
.69515 .56563 .69995 .57112 .71018 .56815 .70541 .56264 Mtetra
.70541 .56264 .71018 .56815 .72044 .56517 .7157 .55965 Mtetra
.7157 .55965 .72044 .56517 .73075 .56218 .72603 .55664 Mtetra
.72603 .55664 .73075 .56218 .74109 .55918 .7364 .55361 Mtetra
.7364 .55361 .74109 .55918 .75147 .55617 .7468 .55058 Mtetra
.7468 .55058 .75147 .55617 .76189 .55315 .75725 .54754 Mtetra
.75725 .54754 .76189 .55315 .77234 .55012 .76773 .54449 Mtetra
.76773 .54449 .77234 .55012 .78284 .54707 .77825 .54142 Mtetra
.77825 .54142 .78284 .54707 .79337 .54401 .78881 .53834 Mtetra
.78881 .53834 .79337 .54401 .80394 .54095 .79941 .53526 Mtetra
.79941 .53526 .80394 .54095 .81455 .53787 .81005 .53216 Mtetra
.81005 .53216 .81455 .53787 .8252 .53478 .82072 .52905 Mtetra
.82072 .52905 .8252 .53478 .83589 .53168 .83144 .52592 Mtetra
.83144 .52592 .83589 .53168 .84661 .52857 .84219 .52279 Mtetra
.84219 .52279 .84661 .52857 .85738 .52544 .85299 .51964 Mtetra
.85299 .51964 .85738 .52544 .86819 .52231 .86383 .51649 Mtetra
.86383 .51649 .86819 .52231 .87903 .51916 .8747 .51332 Mtetra
.8747 .51332 .87903 .51916 .88992 .516 .88562 .51014 Mtetra
.88562 .51014 .88992 .516 .90085 .51283 .89658 .50694 Mtetra
.89658 .50694 .90085 .51283 .91182 .50965 .90758 .50374 Mtetra
.90758 .50374 .91182 .50965 .92283 .50645 .91862 .50052 Mtetra
.91862 .50052 .92283 .50645 .93388 .50325 .9297 .49729 Mtetra
.9297 .49729 .93388 .50325 .94497 .50003 .94082 .49405 Mtetra
.94082 .49405 .94497 .50003 .9561 .4968 .95198 .4908 Mtetra
.35253 .65894 .35813 .66383 .3672 .66119 .36162 .65628 Mtetra
.36162 .65628 .3672 .66119 .3763 .65854 .37074 .65361 Mtetra
.37074 .65361 .3763 .65854 .38544 .65587 .3799 .65094 Mtetra
.3799 .65094 .38544 .65587 .3946 .6532 .38908 .64825 Mtetra
.38908 .64825 .3946 .6532 .4038 .65052 .3983 .64555 Mtetra
.3983 .64555 .4038 .65052 .41303 .64783 .40755 .64285 Mtetra
.40755 .64285 .41303 .64783 .42229 .64514 .41683 .64013 Mtetra
.41683 .64013 .42229 .64514 .43158 .64243 .42614 .63741 Mtetra
.42614 .63741 .43158 .64243 .4409 .63971 .43548 .63467 Mtetra
.43548 .63467 .4409 .63971 .45026 .63699 .44486 .63193 Mtetra
.44486 .63193 .45026 .63699 .45965 .63425 .45427 .62918 Mtetra
.45427 .62918 .45965 .63425 .46907 .63151 .46371 .62641 Mtetra
.46371 .62641 .46907 .63151 .47853 .62875 .47319 .62364 Mtetra
.47319 .62364 .47853 .62875 .48801 .62599 .48269 .62086 Mtetra
.48269 .62086 .48801 .62599 .49753 .62321 .49224 .61807 Mtetra
.49224 .61807 .49753 .62321 .50709 .62043 .50181 .61527 Mtetra
.50181 .61527 .50709 .62043 .51667 .61764 .51142 .61245 Mtetra
.51142 .61245 .51667 .61764 .52629 .61483 .52106 .60963 Mtetra
.52106 .60963 .52629 .61483 .53595 .61202 .53074 .6068 Mtetra
.53074 .6068 .53595 .61202 .54563 .6092 .54045 .60396 Mtetra
.54045 .60396 .54563 .6092 .55536 .60636 .55019 .60111 Mtetra
.55019 .60111 .55536 .60636 .56511 .60352 .55997 .59825 Mtetra
.55997 .59825 .56511 .60352 .5749 .60067 .56978 .59538 Mtetra
.56978 .59538 .5749 .60067 .58473 .59781 .57963 .59249 Mtetra
.57963 .59249 .58473 .59781 .59459 .59493 .58952 .5896 Mtetra
.58952 .5896 .59459 .59493 .60448 .59205 .59944 .5867 Mtetra
.59944 .5867 .60448 .59205 .61441 .58916 .60939 .58379 Mtetra
.60939 .58379 .61441 .58916 .62438 .58625 .61938 .58087 Mtetra
.61938 .58087 .62438 .58625 .63438 .58334 .62941 .57793 Mtetra
.62941 .57793 .63438 .58334 .64442 .58041 .63947 .57499 Mtetra
.63947 .57499 .64442 .58041 .65449 .57748 .64957 .57203 Mtetra
.64957 .57203 .65449 .57748 .6646 .57453 .6597 .56907 Mtetra
.6597 .56907 .6646 .57453 .67475 .57158 .66987 .56609 Mtetra
.66987 .56609 .67475 .57158 .68493 .56861 .68008 .56311 Mtetra
.68008 .56311 .68493 .56861 .69515 .56563 .69032 .56011 Mtetra
.69032 .56011 .69515 .56563 .70541 .56264 .7006 .5571 Mtetra
.7006 .5571 .70541 .56264 .7157 .55965 .71092 .55408 Mtetra
.71092 .55408 .7157 .55965 .72603 .55664 .72128 .55105 Mtetra
.72128 .55105 .72603 .55664 .7364 .55361 .73168 .54801 Mtetra
.73168 .54801 .7364 .55361 .7468 .55058 .74211 .54496 Mtetra
.74211 .54496 .7468 .55058 .75725 .54754 .75258 .54189 Mtetra
.75258 .54189 .75725 .54754 .76773 .54449 .76309 .53882 Mtetra
.76309 .53882 .76773 .54449 .77825 .54142 .77364 .53573 Mtetra
.77364 .53573 .77825 .54142 .78881 .53834 .78422 .53263 Mtetra
.78422 .53263 .78881 .53834 .79941 .53526 .79485 .52952 Mtetra
.79485 .52952 .79941 .53526 .81005 .53216 .80551 .5264 Mtetra
.80551 .5264 .81005 .53216 .82072 .52905 .81622 .52327 Mtetra
.81622 .52327 .82072 .52905 .83144 .52592 .82696 .52013 Mtetra
.82696 .52013 .83144 .52592 .84219 .52279 .83775 .51697 Mtetra
.83775 .51697 .84219 .52279 .85299 .51964 .84857 .51381 Mtetra
.84857 .51381 .85299 .51964 .86383 .51649 .85944 .51063 Mtetra
.85944 .51063 .86383 .51649 .8747 .51332 .87034 .50744 Mtetra
.87034 .50744 .8747 .51332 .88562 .51014 .88129 .50423 Mtetra
.88129 .50423 .88562 .51014 .89658 .50694 .89227 .50102 Mtetra
.89227 .50102 .89658 .50694 .90758 .50374 .9033 .49779 Mtetra
.9033 .49779 .90758 .50374 .91862 .50052 .91437 .49455 Mtetra
.91437 .49455 .91862 .50052 .9297 .49729 .92549 .4913 Mtetra
.92549 .4913 .9297 .49729 .94082 .49405 .93664 .48804 Mtetra
.93664 .48804 .94082 .49405 .95198 .4908 .94784 .48476 Mtetra
.34689 .65403 .35253 .65894 .36162 .65628 .356 .65135 Mtetra
.356 .65135 .36162 .65628 .37074 .65361 .36515 .64866 Mtetra
.36515 .64866 .37074 .65361 .3799 .65094 .37432 .64597 Mtetra
.37432 .64597 .3799 .65094 .38908 .64825 .38352 .64326 Mtetra
.38352 .64326 .38908 .64825 .3983 .64555 .39276 .64055 Mtetra
.39276 .64055 .3983 .64555 .40755 .64285 .40203 .63783 Mtetra
.40203 .63783 .40755 .64285 .41683 .64013 .41133 .63509 Mtetra
.41133 .63509 .41683 .64013 .42614 .63741 .42066 .63235 Mtetra
.42066 .63235 .42614 .63741 .43548 .63467 .43003 .6296 Mtetra
.43003 .6296 .43548 .63467 .44486 .63193 .43942 .62684 Mtetra
.43942 .62684 .44486 .63193 .45427 .62918 .44885 .62407 Mtetra
.44885 .62407 .45427 .62918 .46371 .62641 .45832 .62129 Mtetra
.45832 .62129 .46371 .62641 .47319 .62364 .46781 .6185 Mtetra
.46781 .6185 .47319 .62364 .48269 .62086 .47734 .6157 Mtetra
.47734 .6157 .48269 .62086 .49224 .61807 .4869 .61289 Mtetra
.4869 .61289 .49224 .61807 .50181 .61527 .4965 .61007 Mtetra
.4965 .61007 .50181 .61527 .51142 .61245 .50613 .60724 Mtetra
.50613 .60724 .51142 .61245 .52106 .60963 .5158 .6044 Mtetra
.5158 .6044 .52106 .60963 .53074 .6068 .52549 .60155 Mtetra
.52549 .60155 .53074 .6068 .54045 .60396 .53523 .59869 Mtetra
.53523 .59869 .54045 .60396 .55019 .60111 .54499 .59582 Mtetra
.54499 .59582 .55019 .60111 .55997 .59825 .5548 .59294 Mtetra
.5548 .59294 .55997 .59825 .56978 .59538 .56463 .59005 Mtetra
.56463 .59005 .56978 .59538 .57963 .59249 .5745 .58715 Mtetra
.5745 .58715 .57963 .59249 .58952 .5896 .58441 .58424 Mtetra
.58441 .58424 .58952 .5896 .59944 .5867 .59435 .58132 Mtetra
.59435 .58132 .59944 .5867 .60939 .58379 .60433 .57838 Mtetra
.60433 .57838 .60939 .58379 .61938 .58087 .61435 .57544 Mtetra
.61435 .57544 .61938 .58087 .62941 .57793 .6244 .57249 Mtetra
.6244 .57249 .62941 .57793 .63947 .57499 .63448 .56952 Mtetra
.63448 .56952 .63947 .57499 .64957 .57203 .6446 .56655 Mtetra
.6446 .56655 .64957 .57203 .6597 .56907 .65476 .56357 Mtetra
.65476 .56357 .6597 .56907 .66987 .56609 .66496 .56057 Mtetra
.66496 .56057 .66987 .56609 .68008 .56311 .67519 .55756 Mtetra
.67519 .55756 .68008 .56311 .69032 .56011 .68546 .55455 Mtetra
.68546 .55455 .69032 .56011 .7006 .5571 .69577 .55152 Mtetra
.69577 .55152 .7006 .5571 .71092 .55408 .70612 .54848 Mtetra
.70612 .54848 .71092 .55408 .72128 .55105 .7165 .54543 Mtetra
.7165 .54543 .72128 .55105 .73168 .54801 .72692 .54236 Mtetra
.72692 .54236 .73168 .54801 .74211 .54496 .73738 .53929 Mtetra
.73738 .53929 .74211 .54496 .75258 .54189 .74788 .53621 Mtetra
.74788 .53621 .75258 .54189 .76309 .53882 .75841 .53311 Mtetra
.75841 .53311 .76309 .53882 .77364 .53573 .76899 .53 Mtetra
.76899 .53 .77364 .53573 .78422 .53263 .7796 .52688 Mtetra
.7796 .52688 .78422 .53263 .79485 .52952 .79026 .52375 Mtetra
.79026 .52375 .79485 .52952 .80551 .5264 .80095 .52061 Mtetra
.80095 .52061 .80551 .5264 .81622 .52327 .81168 .51746 Mtetra
.81168 .51746 .81622 .52327 .82696 .52013 .82245 .51429 Mtetra
.82245 .51429 .82696 .52013 .83775 .51697 .83327 .51112 Mtetra
.83327 .51112 .83775 .51697 .84857 .51381 .84412 .50793 Mtetra
.84412 .50793 .84857 .51381 .85944 .51063 .85501 .50473 Mtetra
.85501 .50473 .85944 .51063 .87034 .50744 .86595 .50151 Mtetra
.86595 .50151 .87034 .50744 .88129 .50423 .87693 .49829 Mtetra
.87693 .49829 .88129 .50423 .89227 .50102 .88794 .49505 Mtetra
.88794 .49505 .89227 .50102 .9033 .49779 .899 .4918 Mtetra
.899 .4918 .9033 .49779 .91437 .49455 .9101 .48854 Mtetra
.9101 .48854 .91437 .49455 .92549 .4913 .92125 .48527 Mtetra
.92125 .48527 .92549 .4913 .93664 .48804 .93243 .48198 Mtetra
.93243 .48198 .93664 .48804 .94784 .48476 .94366 .47868 Mtetra
.34122 .64908 .34689 .65403 .356 .65135 .35035 .64638 Mtetra
.35035 .64638 .356 .65135 .36515 .64866 .35951 .64368 Mtetra
.35951 .64368 .36515 .64866 .37432 .64597 .36871 .64097 Mtetra
.36871 .64097 .37432 .64597 .38352 .64326 .37793 .63825 Mtetra
.37793 .63825 .38352 .64326 .39276 .64055 .38719 .63552 Mtetra
.38719 .63552 .39276 .64055 .40203 .63783 .39647 .63277 Mtetra
.39647 .63277 .40203 .63783 .41133 .63509 .40579 .63002 Mtetra
.40579 .63002 .41133 .63509 .42066 .63235 .41515 .62726 Mtetra
.41515 .62726 .42066 .63235 .43003 .6296 .42453 .62449 Mtetra
.42453 .62449 .43003 .6296 .43942 .62684 .43395 .62172 Mtetra
.43395 .62172 .43942 .62684 .44885 .62407 .4434 .61893 Mtetra
.4434 .61893 .44885 .62407 .45832 .62129 .45289 .61613 Mtetra
.45289 .61613 .45832 .62129 .46781 .6185 .4624 .61332 Mtetra
.4624 .61332 .46781 .6185 .47734 .6157 .47195 .6105 Mtetra
.47195 .6105 .47734 .6157 .4869 .61289 .48154 .60767 Mtetra
.48154 .60767 .4869 .61289 .4965 .61007 .49116 .60484 Mtetra
.49116 .60484 .4965 .61007 .50613 .60724 .50081 .60199 Mtetra
.50081 .60199 .50613 .60724 .5158 .6044 .5105 .59913 Mtetra
.5105 .59913 .5158 .6044 .52549 .60155 .52022 .59626 Mtetra
.52022 .59626 .52549 .60155 .53523 .59869 .52997 .59338 Mtetra
.52997 .59338 .53523 .59869 .54499 .59582 .53976 .59049 Mtetra
.53976 .59049 .54499 .59582 .5548 .59294 .54959 .58759 Mtetra
.54959 .58759 .5548 .59294 .56463 .59005 .55945 .58469 Mtetra
.55945 .58469 .56463 .59005 .5745 .58715 .56934 .58177 Mtetra
.56934 .58177 .5745 .58715 .58441 .58424 .57927 .57884 Mtetra
.57927 .57884 .58441 .58424 .59435 .58132 .58924 .57589 Mtetra
.58924 .57589 .59435 .58132 .60433 .57838 .59924 .57294 Mtetra
.59924 .57294 .60433 .57838 .61435 .57544 .60928 .56998 Mtetra
.60928 .56998 .61435 .57544 .6244 .57249 .61935 .56701 Mtetra
.61935 .56701 .6244 .57249 .63448 .56952 .62946 .56403 Mtetra
.62946 .56403 .63448 .56952 .6446 .56655 .63961 .56103 Mtetra
.63961 .56103 .6446 .56655 .65476 .56357 .64979 .55803 Mtetra
.64979 .55803 .65476 .56357 .66496 .56057 .66002 .55501 Mtetra
.66002 .55501 .66496 .56057 .67519 .55756 .67027 .55198 Mtetra
.67027 .55198 .67519 .55756 .68546 .55455 .68057 .54895 Mtetra
.68057 .54895 .68546 .55455 .69577 .55152 .6909 .5459 Mtetra
.6909 .5459 .69577 .55152 .70612 .54848 .70127 .54284 Mtetra
.70127 .54284 .70612 .54848 .7165 .54543 .71168 .53976 Mtetra
.71168 .53976 .7165 .54543 .72692 .54236 .72213 .53668 Mtetra
.72213 .53668 .72692 .54236 .73738 .53929 .73262 .53359 Mtetra
.73262 .53359 .73738 .53929 .74788 .53621 .74314 .53048 Mtetra
.74314 .53048 .74788 .53621 .75841 .53311 .75371 .52737 Mtetra
.75371 .52737 .75841 .53311 .76899 .53 .76431 .52424 Mtetra
.76431 .52424 .76899 .53 .7796 .52688 .77495 .5211 Mtetra
.77495 .5211 .7796 .52688 .79026 .52375 .78563 .51794 Mtetra
.78563 .51794 .79026 .52375 .80095 .52061 .79635 .51478 Mtetra
.79635 .51478 .80095 .52061 .81168 .51746 .80711 .51161 Mtetra
.80711 .51161 .81168 .51746 .82245 .51429 .81792 .50842 Mtetra
.81792 .50842 .82245 .51429 .83327 .51112 .82876 .50522 Mtetra
.82876 .50522 .83327 .51112 .84412 .50793 .83964 .50201 Mtetra
.83964 .50201 .84412 .50793 .85501 .50473 .85056 .49879 Mtetra
.85056 .49879 .85501 .50473 .86595 .50151 .86153 .49555 Mtetra
.86153 .49555 .86595 .50151 .87693 .49829 .87253 .4923 Mtetra
.87253 .4923 .87693 .49829 .88794 .49505 .88358 .48904 Mtetra
.88358 .48904 .88794 .49505 .899 .4918 .89467 .48577 Mtetra
.89467 .48577 .899 .4918 .9101 .48854 .9058 .48249 Mtetra
.9058 .48249 .9101 .48854 .92125 .48527 .91698 .47919 Mtetra
.91698 .47919 .92125 .48527 .93243 .48198 .92819 .47588 Mtetra
.92819 .47588 .93243 .48198 .94366 .47868 .93945 .47256 Mtetra
.33552 .6441 .34122 .64908 .35035 .64638 .34467 .64139 Mtetra
.34467 .64139 .35035 .64638 .35951 .64368 .35385 .63867 Mtetra
.35385 .63867 .35951 .64368 .36871 .64097 .36306 .63594 Mtetra
.36306 .63594 .36871 .64097 .37793 .63825 .3723 .6332 Mtetra
.3723 .6332 .37793 .63825 .38719 .63552 .38158 .63045 Mtetra
.38158 .63045 .38719 .63552 .39647 .63277 .39089 .62769 Mtetra
.39089 .62769 .39647 .63277 .40579 .63002 .40023 .62492 Mtetra
.40023 .62492 .40579 .63002 .41515 .62726 .4096 .62214 Mtetra
.4096 .62214 .41515 .62726 .42453 .62449 .41901 .61936 Mtetra
.41901 .61936 .42453 .62449 .43395 .62172 .42844 .61656 Mtetra
.42844 .61656 .43395 .62172 .4434 .61893 .43792 .61375 Mtetra
.43792 .61375 .4434 .61893 .45289 .61613 .44742 .61094 Mtetra
.44742 .61094 .45289 .61613 .4624 .61332 .45696 .60811 Mtetra
.45696 .60811 .4624 .61332 .47195 .6105 .46653 .60527 Mtetra
.46653 .60527 .47195 .6105 .48154 .60767 .47614 .60243 Mtetra
.47614 .60243 .48154 .60767 .49116 .60484 .48578 .59957 Mtetra
.48578 .59957 .49116 .60484 .50081 .60199 .49545 .5967 Mtetra
.49545 .5967 .50081 .60199 .5105 .59913 .50516 .59383 Mtetra
.50516 .59383 .5105 .59913 .52022 .59626 .5149 .59094 Mtetra
.5149 .59094 .52022 .59626 .52997 .59338 .52468 .58804 Mtetra
.52468 .58804 .52997 .59338 .53976 .59049 .5345 .58513 Mtetra
.5345 .58513 .53976 .59049 .54959 .58759 .54434 .58222 Mtetra
.54434 .58222 .54959 .58759 .55945 .58469 .55423 .57929 Mtetra
.55423 .57929 .55945 .58469 .56934 .58177 .56414 .57635 Mtetra
.56414 .57635 .56934 .58177 .57927 .57884 .5741 .5734 Mtetra
.5741 .5734 .57927 .57884 .58924 .57589 .58409 .57044 Mtetra
.58409 .57044 .58924 .57589 .59924 .57294 .59412 .56747 Mtetra
.59412 .56747 .59924 .57294 .60928 .56998 .60418 .56449 Mtetra
.60418 .56449 .60928 .56998 .61935 .56701 .61428 .56149 Mtetra
.61428 .56149 .61935 .56701 .62946 .56403 .62441 .55849 Mtetra
.62441 .55849 .62946 .56403 .63961 .56103 .63458 .55547 Mtetra
.63458 .55547 .63961 .56103 .64979 .55803 .64479 .55245 Mtetra
.64479 .55245 .64979 .55803 .66002 .55501 .65504 .54941 Mtetra
.65504 .54941 .66002 .55501 .67027 .55198 .66532 .54637 Mtetra
.66532 .54637 .67027 .55198 .68057 .54895 .67564 .54331 Mtetra
.67564 .54331 .68057 .54895 .6909 .5459 .686 .54024 Mtetra
.686 .54024 .6909 .5459 .70127 .54284 .6964 .53716 Mtetra
.6964 .53716 .70127 .54284 .71168 .53976 .70684 .53406 Mtetra
.70684 .53406 .71168 .53976 .72213 .53668 .71731 .53096 Mtetra
.71731 .53096 .72213 .53668 .73262 .53359 .72782 .52785 Mtetra
.72782 .52785 .73262 .53359 .74314 .53048 .73838 .52472 Mtetra
.73838 .52472 .74314 .53048 .75371 .52737 .74897 .52158 Mtetra
.74897 .52158 .75371 .52737 .76431 .52424 .7596 .51843 Mtetra
.7596 .51843 .76431 .52424 .77495 .5211 .77027 .51527 Mtetra
.77027 .51527 .77495 .5211 .78563 .51794 .78098 .5121 Mtetra
.78098 .5121 .78563 .51794 .79635 .51478 .79173 .50891 Mtetra
.79173 .50891 .79635 .51478 .80711 .51161 .80251 .50571 Mtetra
.80251 .50571 .80711 .51161 .81792 .50842 .81335 .5025 Mtetra
.81335 .5025 .81792 .50842 .82876 .50522 .82422 .49928 Mtetra
.82422 .49928 .82876 .50522 .83964 .50201 .83513 .49605 Mtetra
.83513 .49605 .83964 .50201 .85056 .49879 .84608 .4928 Mtetra
.84608 .4928 .85056 .49879 .86153 .49555 .85707 .48955 Mtetra
.85707 .48955 .86153 .49555 .87253 .4923 .86811 .48628 Mtetra
.86811 .48628 .87253 .4923 .88358 .48904 .87919 .48299 Mtetra
.87919 .48299 .88358 .48904 .89467 .48577 .89031 .4797 Mtetra
.89031 .4797 .89467 .48577 .9058 .48249 .90147 .47639 Mtetra
.90147 .47639 .9058 .48249 .91698 .47919 .91268 .47307 Mtetra
.91268 .47307 .91698 .47919 .92819 .47588 .92392 .46974 Mtetra
.92392 .46974 .92819 .47588 .93945 .47256 .93521 .46639 Mtetra
.32977 .63908 .33552 .6441 .34467 .64139 .33894 .63636 Mtetra
.33894 .63636 .34467 .64139 .35385 .63867 .34814 .63362 Mtetra
.34814 .63362 .35385 .63867 .36306 .63594 .35737 .63087 Mtetra
.35737 .63087 .36306 .63594 .3723 .6332 .36664 .62812 Mtetra
.36664 .62812 .3723 .6332 .38158 .63045 .37593 .62535 Mtetra
.37593 .62535 .38158 .63045 .39089 .62769 .38526 .62257 Mtetra
.38526 .62257 .39089 .62769 .40023 .62492 .39462 .61979 Mtetra
.39462 .61979 .40023 .62492 .4096 .62214 .40402 .61699 Mtetra
.40402 .61699 .4096 .62214 .41901 .61936 .41344 .61419 Mtetra
.41344 .61419 .41901 .61936 .42844 .61656 .4229 .61137 Mtetra
.4229 .61137 .42844 .61656 .43792 .61375 .43239 .60855 Mtetra
.43239 .60855 .43792 .61375 .44742 .61094 .44192 .60571 Mtetra
.44192 .60571 .44742 .61094 .45696 .60811 .45148 .60287 Mtetra
.45148 .60287 .45696 .60811 .46653 .60527 .46108 .60001 Mtetra
.46108 .60001 .46653 .60527 .47614 .60243 .4707 .59714 Mtetra
.4707 .59714 .47614 .60243 .48578 .59957 .48037 .59427 Mtetra
.48037 .59427 .48578 .59957 .49545 .5967 .49006 .59138 Mtetra
.49006 .59138 .49545 .5967 .50516 .59383 .49979 .58849 Mtetra
.49979 .58849 .50516 .59383 .5149 .59094 .50956 .58558 Mtetra
.50956 .58558 .5149 .59094 .52468 .58804 .51936 .58267 Mtetra
.51936 .58267 .52468 .58804 .5345 .58513 .52919 .57974 Mtetra
.52919 .57974 .5345 .58513 .54434 .58222 .53907 .5768 Mtetra
.53907 .5768 .54434 .58222 .55423 .57929 .54897 .57385 Mtetra
.54897 .57385 .55423 .57929 .56414 .57635 .55891 .57089 Mtetra
.55891 .57089 .56414 .57635 .5741 .5734 .56889 .56792 Mtetra
.56889 .56792 .5741 .5734 .58409 .57044 .57891 .56494 Mtetra
.57891 .56494 .58409 .57044 .59412 .56747 .58896 .56195 Mtetra
.58896 .56195 .59412 .56747 .60418 .56449 .59904 .55895 Mtetra
.59904 .55895 .60418 .56449 .61428 .56149 .60917 .55594 Mtetra
.60917 .55594 .61428 .56149 .62441 .55849 .61933 .55292 Mtetra
.61933 .55292 .62441 .55849 .63458 .55547 .62952 .54988 Mtetra
.62952 .54988 .63458 .55547 .64479 .55245 .63976 .54684 Mtetra
.63976 .54684 .64479 .55245 .65504 .54941 .65003 .54378 Mtetra
.65003 .54378 .65504 .54941 .66532 .54637 .66034 .54071 Mtetra
.66034 .54071 .66532 .54637 .67564 .54331 .67069 .53763 Mtetra
.67069 .53763 .67564 .54331 .686 .54024 .68107 .53454 Mtetra
.68107 .53454 .686 .54024 .6964 .53716 .69149 .53144 Mtetra
.69149 .53144 .6964 .53716 .70684 .53406 .70196 .52833 Mtetra
.70196 .52833 .70684 .53406 .71731 .53096 .71246 .5252 Mtetra
.71246 .5252 .71731 .53096 .72782 .52785 .723 .52206 Mtetra
.723 .52206 .72782 .52785 .73838 .52472 .73358 .51892 Mtetra
.73358 .51892 .73838 .52472 .74897 .52158 .74419 .51576 Mtetra
.74419 .51576 .74897 .52158 .7596 .51843 .75485 .51258 Mtetra
.75485 .51258 .7596 .51843 .77027 .51527 .76555 .5094 Mtetra
.76555 .5094 .77027 .51527 .78098 .5121 .77629 .50621 Mtetra
.77629 .50621 .78098 .5121 .79173 .50891 .78707 .503 Mtetra
.78707 .503 .79173 .50891 .80251 .50571 .79788 .49978 Mtetra
.79788 .49978 .80251 .50571 .81335 .5025 .80874 .49655 Mtetra
.80874 .49655 .81335 .5025 .82422 .49928 .81964 .4933 Mtetra
.81964 .4933 .82422 .49928 .83513 .49605 .83058 .49005 Mtetra
.83058 .49005 .83513 .49605 .84608 .4928 .84157 .48678 Mtetra
.84157 .48678 .84608 .4928 .85707 .48955 .85259 .4835 Mtetra
.85259 .4835 .85707 .48955 .86811 .48628 .86366 .48021 Mtetra
.86366 .48021 .86811 .48628 .87919 .48299 .87477 .4769 Mtetra
.87477 .4769 .87919 .48299 .89031 .4797 .88592 .47358 Mtetra
.88592 .47358 .89031 .4797 .90147 .47639 .89711 .47025 Mtetra
.89711 .47025 .90147 .47639 .91268 .47307 .90834 .46691 Mtetra
.90834 .46691 .91268 .47307 .92392 .46974 .91962 .46355 Mtetra
.91962 .46355 .92392 .46974 .93521 .46639 .93095 .46018 Mtetra
.32399 .63404 .32977 .63908 .33894 .63636 .33318 .6313 Mtetra
.33318 .6313 .33894 .63636 .34814 .63362 .3424 .62854 Mtetra
.3424 .62854 .34814 .63362 .35737 .63087 .35165 .62578 Mtetra
.656 .752 .92 r
.35165 .62578 .35737 .63087 .36664 .62812 .36093 .62301 Mtetra
.36093 .62301 .36664 .62812 .37593 .62535 .37025 .62022 Mtetra
.37025 .62022 .37593 .62535 .38526 .62257 .3796 .61743 Mtetra
.3796 .61743 .38526 .62257 .39462 .61979 .38898 .61462 Mtetra
.38898 .61462 .39462 .61979 .40402 .61699 .3984 .61181 Mtetra
.656 .751 .92 r
.3984 .61181 .40402 .61699 .41344 .61419 .40784 .60898 Mtetra
.40784 .60898 .41344 .61419 .4229 .61137 .41732 .60615 Mtetra
.41732 .60615 .4229 .61137 .43239 .60855 .42684 .6033 Mtetra
.42684 .6033 .43239 .60855 .44192 .60571 .43639 .60045 Mtetra
.43639 .60045 .44192 .60571 .45148 .60287 .44597 .59759 Mtetra
.44597 .59759 .45148 .60287 .46108 .60001 .45558 .59471 Mtetra
.45558 .59471 .46108 .60001 .4707 .59714 .46523 .59183 Mtetra
.46523 .59183 .4707 .59714 .48037 .59427 .47492 .58893 Mtetra
.47492 .58893 .48037 .59427 .49006 .59138 .48463 .58603 Mtetra
.48463 .58603 .49006 .59138 .49979 .58849 .49439 .58311 Mtetra
.49439 .58311 .49979 .58849 .50956 .58558 .50418 .58019 Mtetra
.50418 .58019 .50956 .58558 .51936 .58267 .514 .57725 Mtetra
.514 .57725 .51936 .58267 .52919 .57974 .52386 .57431 Mtetra
.52386 .57431 .52919 .57974 .53907 .5768 .53375 .57135 Mtetra
.53375 .57135 .53907 .5768 .54897 .57385 .54368 .56838 Mtetra
.54368 .56838 .54897 .57385 .55891 .57089 .55365 .5654 Mtetra
.55365 .5654 .55891 .57089 .56889 .56792 .56365 .56241 Mtetra
.56365 .56241 .56889 .56792 .57891 .56494 .57369 .55941 Mtetra
.57369 .55941 .57891 .56494 .58896 .56195 .58376 .5564 Mtetra
.58376 .5564 .58896 .56195 .59904 .55895 .59387 .55338 Mtetra
.59387 .55338 .59904 .55895 .60917 .55594 .60402 .55035 Mtetra
.60402 .55035 .60917 .55594 .61933 .55292 .61421 .5473 Mtetra
.61421 .5473 .61933 .55292 .62952 .54988 .62443 .54425 Mtetra
.62443 .54425 .62952 .54988 .63976 .54684 .63469 .54118 Mtetra
.63469 .54118 .63976 .54684 .65003 .54378 .64498 .53811 Mtetra
.64498 .53811 .65003 .54378 .66034 .54071 .65532 .53502 Mtetra
.65532 .53502 .66034 .54071 .67069 .53763 .66569 .53192 Mtetra
.66569 .53192 .67069 .53763 .68107 .53454 .6761 .52881 Mtetra
.6761 .52881 .68107 .53454 .69149 .53144 .68655 .52568 Mtetra
.68655 .52568 .69149 .53144 .70196 .52833 .69704 .52255 Mtetra
.69704 .52255 .70196 .52833 .71246 .5252 .70757 .5194 Mtetra
.70757 .5194 .71246 .5252 .723 .52206 .71814 .51624 Mtetra
.71814 .51624 .723 .52206 .73358 .51892 .72874 .51307 Mtetra
.72874 .51307 .73358 .51892 .74419 .51576 .73939 .50989 Mtetra
.73939 .50989 .74419 .51576 .75485 .51258 .75008 .5067 Mtetra
.75008 .5067 .75485 .51258 .76555 .5094 .7608 .50349 Mtetra
.7608 .50349 .76555 .5094 .77629 .50621 .77157 .50027 Mtetra
.77157 .50027 .77629 .50621 .78707 .503 .78237 .49705 Mtetra
.78237 .49705 .78707 .503 .79788 .49978 .79322 .4938 Mtetra
.79322 .4938 .79788 .49978 .80874 .49655 .80411 .49055 Mtetra
.80411 .49055 .80874 .49655 .81964 .4933 .81504 .48728 Mtetra
.81504 .48728 .81964 .4933 .83058 .49005 .82601 .48401 Mtetra
.82601 .48401 .83058 .49005 .84157 .48678 .83702 .48072 Mtetra
.83702 .48072 .84157 .48678 .85259 .4835 .84808 .47741 Mtetra
.84808 .47741 .85259 .4835 .86366 .48021 .85917 .4741 Mtetra
.656 .752 .92 r
.85917 .4741 .86366 .48021 .87477 .4769 .87031 .47077 Mtetra
.87031 .47077 .87477 .4769 .88592 .47358 .88149 .46743 Mtetra
.88149 .46743 .88592 .47358 .89711 .47025 .89272 .46407 Mtetra
.89272 .46407 .89711 .47025 .90834 .46691 .90398 .4607 Mtetra
.90398 .4607 .90834 .46691 .91962 .46355 .91529 .45732 Mtetra
.656 .751 .92 r
.91529 .45732 .91962 .46355 .93095 .46018 .92665 .45393 Mtetra
.31818 .62896 .32399 .63404 .33318 .6313 .32738 .62621 Mtetra
.32738 .62621 .33318 .6313 .3424 .62854 .33662 .62344 Mtetra
.656 .752 .92 r
.33662 .62344 .3424 .62854 .35165 .62578 .34589 .62066 Mtetra
.34589 .62066 .35165 .62578 .36093 .62301 .3552 .61787 Mtetra
.3552 .61787 .36093 .62301 .37025 .62022 .36453 .61506 Mtetra
.36453 .61506 .37025 .62022 .3796 .61743 .3739 .61225 Mtetra
.3739 .61225 .3796 .61743 .38898 .61462 .3833 .60943 Mtetra
.3833 .60943 .38898 .61462 .3984 .61181 .39274 .60659 Mtetra
.39274 .60659 .3984 .61181 .40784 .60898 .40221 .60375 Mtetra
.40221 .60375 .40784 .60898 .41732 .60615 .41171 .60089 Mtetra
.41171 .60089 .41732 .60615 .42684 .6033 .42124 .59803 Mtetra
.656 .751 .92 r
.42124 .59803 .42684 .6033 .43639 .60045 .43081 .59516 Mtetra
.43081 .59516 .43639 .60045 .44597 .59759 .44042 .59227 Mtetra
.44042 .59227 .44597 .59759 .45558 .59471 .45005 .58938 Mtetra
.45005 .58938 .45558 .59471 .46523 .59183 .45972 .58648 Mtetra
.45972 .58648 .46523 .59183 .47492 .58893 .46943 .58356 Mtetra
.46943 .58356 .47492 .58893 .48463 .58603 .47917 .58064 Mtetra
.47917 .58064 .48463 .58603 .49439 .58311 .48895 .57771 Mtetra
.48895 .57771 .49439 .58311 .50418 .58019 .49876 .57476 Mtetra
.49876 .57476 .50418 .58019 .514 .57725 .5086 .57181 Mtetra
.5086 .57181 .514 .57725 .52386 .57431 .51849 .56884 Mtetra
.51849 .56884 .52386 .57431 .53375 .57135 .5284 .56586 Mtetra
.5284 .56586 .53375 .57135 .54368 .56838 .53836 .56288 Mtetra
.53836 .56288 .54368 .56838 .55365 .5654 .54835 .55988 Mtetra
.54835 .55988 .55365 .5654 .56365 .56241 .55837 .55687 Mtetra
.55837 .55687 .56365 .56241 .57369 .55941 .56843 .55385 Mtetra
.56843 .55385 .57369 .55941 .58376 .5564 .57853 .55082 Mtetra
.57853 .55082 .58376 .5564 .59387 .55338 .58867 .54777 Mtetra
.58867 .54777 .59387 .55338 .60402 .55035 .59884 .54472 Mtetra
.59884 .54472 .60402 .55035 .61421 .5473 .60905 .54166 Mtetra
.60905 .54166 .61421 .5473 .62443 .54425 .6193 .53858 Mtetra
.6193 .53858 .62443 .54425 .63469 .54118 .62958 .53549 Mtetra
.62958 .53549 .63469 .54118 .64498 .53811 .63991 .53239 Mtetra
.63991 .53239 .64498 .53811 .65532 .53502 .65027 .52928 Mtetra
.65027 .52928 .65532 .53502 .66569 .53192 .66067 .52616 Mtetra
.66067 .52616 .66569 .53192 .6761 .52881 .6711 .52303 Mtetra
.6711 .52303 .6761 .52881 .68655 .52568 .68158 .51989 Mtetra
.68158 .51989 .68655 .52568 .69704 .52255 .6921 .51673 Mtetra
.6921 .51673 .69704 .52255 .70757 .5194 .70265 .51356 Mtetra
.70265 .51356 .70757 .5194 .71814 .51624 .71324 .51038 Mtetra
.71324 .51038 .71814 .51624 .72874 .51307 .72388 .50719 Mtetra
.72388 .50719 .72874 .51307 .73939 .50989 .73455 .50399 Mtetra
.73455 .50399 .73939 .50989 .75008 .5067 .74527 .50077 Mtetra
.74527 .50077 .75008 .5067 .7608 .50349 .75602 .49754 Mtetra
.75602 .49754 .7608 .50349 .77157 .50027 .76681 .4943 Mtetra
.76681 .4943 .77157 .50027 .78237 .49705 .77765 .49105 Mtetra
.77765 .49105 .78237 .49705 .79322 .4938 .78853 .48779 Mtetra
.78853 .48779 .79322 .4938 .80411 .49055 .79944 .48451 Mtetra
.79944 .48451 .80411 .49055 .81504 .48728 .8104 .48122 Mtetra
.8104 .48122 .81504 .48728 .82601 .48401 .8214 .47792 Mtetra
.8214 .47792 .82601 .48401 .83702 .48072 .83244 .47461 Mtetra
.656 .752 .92 r
.83244 .47461 .83702 .48072 .84808 .47741 .84353 .47129 Mtetra
.84353 .47129 .84808 .47741 .85917 .4741 .85466 .46795 Mtetra
.85466 .46795 .85917 .4741 .87031 .47077 .86583 .4646 Mtetra
.86583 .4646 .87031 .47077 .88149 .46743 .87704 .46123 Mtetra
.87704 .46123 .88149 .46743 .89272 .46407 .88829 .45785 Mtetra
.88829 .45785 .89272 .46407 .90398 .4607 .89959 .45446 Mtetra
.89959 .45446 .90398 .4607 .91529 .45732 .91093 .45105 Mtetra
.91093 .45105 .91529 .45732 .92665 .45393 .92232 .44763 Mtetra
.655 .751 .92 r
.31232 .62385 .31818 .62896 .32738 .62621 .32155 .62108 Mtetra
.655 .751 .921 r
.32155 .62108 .32738 .62621 .33662 .62344 .33081 .6183 Mtetra
.655 .752 .921 r
.33081 .6183 .33662 .62344 .34589 .62066 .3401 .61551 Mtetra
.656 .752 .921 r
.3401 .61551 .34589 .62066 .3552 .61787 .34942 .6127 Mtetra
.34942 .6127 .3552 .61787 .36453 .61506 .35878 .60988 Mtetra
.35878 .60988 .36453 .61506 .3739 .61225 .36817 .60705 Mtetra
.36817 .60705 .3739 .61225 .3833 .60943 .37759 .6042 Mtetra
.37759 .6042 .3833 .60943 .39274 .60659 .38704 .60135 Mtetra
.656 .752 .92 r
.38704 .60135 .39274 .60659 .40221 .60375 .39653 .59848 Mtetra
.39653 .59848 .40221 .60375 .41171 .60089 .40606 .59561 Mtetra
.40606 .59561 .41171 .60089 .42124 .59803 .41561 .59272 Mtetra
.41561 .59272 .42124 .59803 .43081 .59516 .4252 .58983 Mtetra
.4252 .58983 .43081 .59516 .44042 .59227 .43483 .58693 Mtetra
.656 .751 .92 r
.43483 .58693 .44042 .59227 .45005 .58938 .44449 .58401 Mtetra
.44449 .58401 .45005 .58938 .45972 .58648 .45418 .58109 Mtetra
.45418 .58109 .45972 .58648 .46943 .58356 .46391 .57816 Mtetra
.46391 .57816 .46943 .58356 .47917 .58064 .47367 .57521 Mtetra
.47367 .57521 .47917 .58064 .48895 .57771 .48347 .57226 Mtetra
.48347 .57226 .48895 .57771 .49876 .57476 .4933 .5693 Mtetra
.4933 .5693 .49876 .57476 .5086 .57181 .50317 .56632 Mtetra
.50317 .56632 .5086 .57181 .51849 .56884 .51308 .56334 Mtetra
.51308 .56334 .51849 .56884 .5284 .56586 .52302 .56034 Mtetra
.52302 .56034 .5284 .56586 .53836 .56288 .533 .55733 Mtetra
.533 .55733 .53836 .56288 .54835 .55988 .54301 .55431 Mtetra
.54301 .55431 .54835 .55988 .55837 .55687 .55306 .55128 Mtetra
.55306 .55128 .55837 .55687 .56843 .55385 .56314 .54824 Mtetra
.56314 .54824 .56843 .55385 .57853 .55082 .57327 .54519 Mtetra
.57327 .54519 .57853 .55082 .58867 .54777 .58343 .54213 Mtetra
.58343 .54213 .58867 .54777 .59884 .54472 .59363 .53905 Mtetra
.59363 .53905 .59884 .54472 .60905 .54166 .60386 .53597 Mtetra
.60386 .53597 .60905 .54166 .6193 .53858 .61413 .53287 Mtetra
.61413 .53287 .6193 .53858 .62958 .53549 .62444 .52976 Mtetra
.62444 .52976 .62958 .53549 .63991 .53239 .63479 .52664 Mtetra
.63479 .52664 .63991 .53239 .65027 .52928 .64518 .52351 Mtetra
.64518 .52351 .65027 .52928 .66067 .52616 .6556 .52037 Mtetra
.6556 .52037 .66067 .52616 .6711 .52303 .66607 .51722 Mtetra
.66607 .51722 .6711 .52303 .68158 .51989 .67657 .51405 Mtetra
.67657 .51405 .68158 .51989 .6921 .51673 .68711 .51087 Mtetra
.68711 .51087 .6921 .51673 .70265 .51356 .6977 .50768 Mtetra
.6977 .50768 .70265 .51356 .71324 .51038 .70832 .50448 Mtetra
.70832 .50448 .71324 .51038 .72388 .50719 .71898 .50127 Mtetra
.71898 .50127 .72388 .50719 .73455 .50399 .72968 .49804 Mtetra
.72968 .49804 .73455 .50399 .74527 .50077 .74042 .4948 Mtetra
.74042 .4948 .74527 .50077 .75602 .49754 .7512 .49155 Mtetra
.7512 .49155 .75602 .49754 .76681 .4943 .76203 .48829 Mtetra
.76203 .48829 .76681 .4943 .77765 .49105 .77289 .48502 Mtetra
.77289 .48502 .77765 .49105 .78853 .48779 .7838 .48173 Mtetra
.7838 .48173 .78853 .48779 .79944 .48451 .79474 .47843 Mtetra
.79474 .47843 .79944 .48451 .8104 .48122 .80573 .47513 Mtetra
.656 .752 .92 r
.80573 .47513 .8104 .48122 .8214 .47792 .81676 .4718 Mtetra
.656 .752 .921 r
.81676 .4718 .8214 .47792 .83244 .47461 .82784 .46847 Mtetra
.82784 .46847 .83244 .47461 .84353 .47129 .83895 .46513 Mtetra
.83895 .46513 .84353 .47129 .85466 .46795 .85011 .46177 Mtetra
.85011 .46177 .85466 .46795 .86583 .4646 .86131 .45839 Mtetra
.86131 .45839 .86583 .4646 .87704 .46123 .87255 .455 Mtetra
.87255 .455 .87704 .46123 .88829 .45785 .88384 .4516 Mtetra
.88384 .4516 .88829 .45785 .89959 .45446 .89517 .44817 Mtetra
.656 .752 .92 r
.89517 .44817 .89959 .45446 .91093 .45105 .90654 .44474 Mtetra
.90654 .44474 .91093 .45105 .92232 .44763 .91796 .44128 Mtetra
.655 .751 .921 r
.30643 .61871 .31232 .62385 .32155 .62108 .31568 .61593 Mtetra
.655 .752 .921 r
.31568 .61593 .32155 .62108 .33081 .6183 .32495 .61314 Mtetra
.32495 .61314 .33081 .6183 .3401 .61551 .33426 .61033 Mtetra
.33426 .61033 .3401 .61551 .34942 .6127 .34361 .60751 Mtetra
.656 .752 .921 r
.34361 .60751 .34942 .6127 .35878 .60988 .35298 .60467 Mtetra
.35298 .60467 .35878 .60988 .36817 .60705 .36239 .60182 Mtetra
.36239 .60182 .36817 .60705 .37759 .6042 .37184 .59896 Mtetra
.37184 .59896 .37759 .6042 .38704 .60135 .38131 .59608 Mtetra
.38131 .59608 .38704 .60135 .39653 .59848 .39082 .59319 Mtetra
.39082 .59319 .39653 .59848 .40606 .59561 .40037 .59029 Mtetra
.656 .752 .92 r
.40037 .59029 .40606 .59561 .41561 .59272 .40994 .58739 Mtetra
.40994 .58739 .41561 .59272 .4252 .58983 .41956 .58447 Mtetra
.41956 .58447 .4252 .58983 .43483 .58693 .4292 .58155 Mtetra
.4292 .58155 .43483 .58693 .44449 .58401 .43888 .57861 Mtetra
.656 .751 .92 r
.43888 .57861 .44449 .58401 .45418 .58109 .4486 .57567 Mtetra
.4486 .57567 .45418 .58109 .46391 .57816 .45835 .57272 Mtetra
.45835 .57272 .46391 .57816 .47367 .57521 .46814 .56975 Mtetra
.46814 .56975 .47367 .57521 .48347 .57226 .47796 .56678 Mtetra
.47796 .56678 .48347 .57226 .4933 .5693 .48781 .5638 Mtetra
.48781 .5638 .4933 .5693 .50317 .56632 .49771 .5608 Mtetra
.49771 .5608 .50317 .56632 .51308 .56334 .50763 .55779 Mtetra
.50763 .55779 .51308 .56334 .52302 .56034 .5176 .55478 Mtetra
.5176 .55478 .52302 .56034 .533 .55733 .5276 .55175 Mtetra
.5276 .55175 .533 .55733 .54301 .55431 .53764 .54871 Mtetra
.53764 .54871 .54301 .55431 .55306 .55128 .54771 .54566 Mtetra
.54771 .54566 .55306 .55128 .56314 .54824 .55782 .5426 Mtetra
.55782 .5426 .56314 .54824 .57327 .54519 .56797 .53953 Mtetra
.56797 .53953 .57327 .54519 .58343 .54213 .57815 .53644 Mtetra
.57815 .53644 .58343 .54213 .59363 .53905 .58837 .53335 Mtetra
.58837 .53335 .59363 .53905 .60386 .53597 .59864 .53024 Mtetra
.59864 .53024 .60386 .53597 .61413 .53287 .60893 .52712 Mtetra
.60893 .52712 .61413 .53287 .62444 .52976 .61927 .524 Mtetra
.61927 .524 .62444 .52976 .63479 .52664 .62964 .52085 Mtetra
.62964 .52085 .63479 .52664 .64518 .52351 .64006 .5177 Mtetra
.64006 .5177 .64518 .52351 .6556 .52037 .65051 .51454 Mtetra
.65051 .51454 .6556 .52037 .66607 .51722 .661 .51136 Mtetra
.661 .51136 .66607 .51722 .67657 .51405 .67153 .50817 Mtetra
.67153 .50817 .67657 .51405 .68711 .51087 .6821 .50497 Mtetra
.6821 .50497 .68711 .51087 .6977 .50768 .69271 .50176 Mtetra
.69271 .50176 .6977 .50768 .70832 .50448 .70336 .49854 Mtetra
.70336 .49854 .70832 .50448 .71898 .50127 .71405 .4953 Mtetra
.71405 .4953 .71898 .50127 .72968 .49804 .72477 .49205 Mtetra
.72477 .49205 .72968 .49804 .74042 .4948 .73554 .48879 Mtetra
.73554 .48879 .74042 .4948 .7512 .49155 .74636 .48552 Mtetra
.74636 .48552 .7512 .49155 .76203 .48829 .75721 .48224 Mtetra
.75721 .48224 .76203 .48829 .77289 .48502 .7681 .47894 Mtetra
.7681 .47894 .77289 .48502 .7838 .48173 .77904 .47563 Mtetra
.656 .752 .92 r
.77904 .47563 .7838 .48173 .79474 .47843 .79001 .47232 Mtetra
.655 .752 .921 r
.79001 .47232 .79474 .47843 .80573 .47513 .80103 .46899 Mtetra
.80103 .46899 .80573 .47513 .81676 .4718 .81209 .46565 Mtetra
.81209 .46565 .81676 .4718 .82784 .46847 .8232 .4623 Mtetra
.8232 .4623 .82784 .46847 .83895 .46513 .83434 .45893 Mtetra
.83434 .45893 .83895 .46513 .85011 .46177 .84553 .45555 Mtetra
.656 .752 .921 r
.84553 .45555 .85011 .46177 .86131 .45839 .85676 .45215 Mtetra
.85676 .45215 .86131 .45839 .87255 .455 .86804 .44874 Mtetra
.86804 .44874 .87255 .455 .88384 .4516 .87936 .4453 Mtetra
.87936 .4453 .88384 .4516 .89517 .44817 .89072 .44185 Mtetra
.89072 .44185 .89517 .44817 .90654 .44474 .90212 .43838 Mtetra
.656 .752 .92 r
.90212 .43838 .90654 .44474 .91796 .44128 .91357 .43489 Mtetra
.654 .751 .921 r
.3005 .61354 .30643 .61871 .31568 .61593 .30976 .61075 Mtetra
.654 .752 .921 r
.30976 .61075 .31568 .61593 .32495 .61314 .31906 .60795 Mtetra
.655 .752 .921 r
.31906 .60795 .32495 .61314 .33426 .61033 .32839 .60514 Mtetra
.655 .753 .922 r
.32839 .60514 .33426 .61033 .34361 .60751 .33775 .60231 Mtetra
.33775 .60231 .34361 .60751 .35298 .60467 .34715 .59946 Mtetra
.656 .753 .922 r
.34715 .59946 .35298 .60467 .36239 .60182 .35658 .59659 Mtetra
.35658 .59659 .36239 .60182 .37184 .59896 .36604 .5937 Mtetra
.656 .753 .921 r
.36604 .5937 .37184 .59896 .38131 .59608 .37554 .5908 Mtetra
.37554 .5908 .38131 .59608 .39082 .59319 .38507 .58788 Mtetra
.38507 .58788 .39082 .59319 .40037 .59029 .39464 .58496 Mtetra
.656 .752 .921 r
.39464 .58496 .40037 .59029 .40994 .58739 .40424 .58202 Mtetra
.40424 .58202 .40994 .58739 .41956 .58447 .41387 .57908 Mtetra
.656 .752 .92 r
.41387 .57908 .41956 .58447 .4292 .58155 .42354 .57614 Mtetra
.42354 .57614 .4292 .58155 .43888 .57861 .43324 .57318 Mtetra
.43324 .57318 .43888 .57861 .4486 .57567 .44298 .57021 Mtetra
.44298 .57021 .4486 .57567 .45835 .57272 .45276 .56724 Mtetra
.656 .751 .92 r
.45276 .56724 .45835 .57272 .46814 .56975 .46256 .56426 Mtetra
.46256 .56426 .46814 .56975 .47796 .56678 .47241 .56126 Mtetra
.47241 .56126 .47796 .56678 .48781 .5638 .48229 .55826 Mtetra
.48229 .55826 .48781 .5638 .49771 .5608 .4922 .55524 Mtetra
.4922 .55524 .49771 .5608 .50763 .55779 .50215 .55222 Mtetra
.50215 .55222 .50763 .55779 .5176 .55478 .51214 .54918 Mtetra
.51214 .54918 .5176 .55478 .5276 .55175 .52217 .54613 Mtetra
.52217 .54613 .5276 .55175 .53764 .54871 .53223 .54307 Mtetra
.53223 .54307 .53764 .54871 .54771 .54566 .54232 .54 Mtetra
.54232 .54 .54771 .54566 .55782 .5426 .55246 .53692 Mtetra
.55246 .53692 .55782 .5426 .56797 .53953 .56263 .53383 Mtetra
.56263 .53383 .56797 .53953 .57815 .53644 .57284 .53072 Mtetra
.57284 .53072 .57815 .53644 .58837 .53335 .58309 .52761 Mtetra
.58309 .52761 .58837 .53335 .59864 .53024 .59337 .52448 Mtetra
.59337 .52448 .59864 .53024 .60893 .52712 .6037 .52134 Mtetra
.6037 .52134 .60893 .52712 .61927 .524 .61406 .51819 Mtetra
.61406 .51819 .61927 .524 .62964 .52085 .62446 .51503 Mtetra
.62446 .51503 .62964 .52085 .64006 .5177 .6349 .51185 Mtetra
.6349 .51185 .64006 .5177 .65051 .51454 .64538 .50866 Mtetra
.64538 .50866 .65051 .51454 .661 .51136 .65589 .50547 Mtetra
.65589 .50547 .661 .51136 .67153 .50817 .66645 .50226 Mtetra
.66645 .50226 .67153 .50817 .6821 .50497 .67705 .49903 Mtetra
.67705 .49903 .6821 .50497 .69271 .50176 .68768 .4958 Mtetra
.68768 .4958 .69271 .50176 .70336 .49854 .69836 .49255 Mtetra
.69836 .49255 .70336 .49854 .71405 .4953 .70908 .48929 Mtetra
.70908 .48929 .71405 .4953 .72477 .49205 .71984 .48602 Mtetra
.71984 .48602 .72477 .49205 .73554 .48879 .73063 .48274 Mtetra
.73063 .48274 .73554 .48879 .74636 .48552 .74147 .47945 Mtetra
.74147 .47945 .74636 .48552 .75721 .48224 .75235 .47614 Mtetra
.75235 .47614 .75721 .48224 .7681 .47894 .76328 .47283 Mtetra
.655 .752 .921 r
.76328 .47283 .7681 .47894 .77904 .47563 .77424 .4695 Mtetra
.77424 .4695 .77904 .47563 .79001 .47232 .78525 .46617 Mtetra
.78525 .46617 .79001 .47232 .80103 .46899 .7963 .46282 Mtetra
.7963 .46282 .80103 .46899 .81209 .46565 .80739 .45947 Mtetra
.80739 .45947 .81209 .46565 .8232 .4623 .81852 .4561 Mtetra
.655 .753 .922 r
.81852 .4561 .8232 .4623 .83434 .45893 .8297 .45271 Mtetra
.8297 .45271 .83434 .45893 .84553 .45555 .84092 .44931 Mtetra
.656 .753 .922 r
.84092 .44931 .84553 .45555 .85676 .45215 .85218 .44589 Mtetra
.85218 .44589 .85676 .45215 .86804 .44874 .86349 .44245 Mtetra
.656 .753 .921 r
.86349 .44245 .86804 .44874 .87936 .4453 .87484 .43898 Mtetra
.657 .753 .921 r
.87484 .43898 .87936 .4453 .89072 .44185 .88623 .43549 Mtetra
.88623 .43549 .89072 .44185 .90212 .43838 .89767 .43198 Mtetra
.657 .752 .92 r
.89767 .43198 .90212 .43838 .91357 .43489 .90915 .42846 Mtetra
.653 .751 .921 r
.29453 .60833 .3005 .61354 .30976 .61075 .30381 .60555 Mtetra
.654 .752 .922 r
.30381 .60555 .30976 .61075 .31906 .60795 .31313 .60275 Mtetra
.654 .753 .922 r
.31313 .60275 .31906 .60795 .32839 .60514 .32248 .59994 Mtetra
.654 .753 .923 r
.32248 .59994 .32839 .60514 .33775 .60231 .33186 .5971 Mtetra
.655 .754 .923 r
.33186 .5971 .33775 .60231 .34715 .59946 .34128 .59424 Mtetra
.656 .754 .923 r
.34128 .59424 .34715 .59946 .35658 .59659 .35073 .59135 Mtetra
.656 .755 .922 r
.35073 .59135 .35658 .59659 .36604 .5937 .36021 .58844 Mtetra
.657 .755 .922 r
.36021 .58844 .36604 .5937 .37554 .5908 .36973 .58551 Mtetra
.657 .754 .922 r
.36973 .58551 .37554 .5908 .38507 .58788 .37929 .58256 Mtetra
.657 .754 .921 r
.37929 .58256 .38507 .58788 .39464 .58496 .38887 .57961 Mtetra
.657 .753 .921 r
.38887 .57961 .39464 .58496 .40424 .58202 .3985 .57664 Mtetra
.3985 .57664 .40424 .58202 .41387 .57908 .40815 .57367 Mtetra
.656 .753 .921 r
.40815 .57367 .41387 .57908 .42354 .57614 .41784 .5707 Mtetra
.656 .752 .921 r
.41784 .5707 .42354 .57614 .43324 .57318 .42757 .56772 Mtetra
.656 .752 .92 r
.42757 .56772 .43324 .57318 .44298 .57021 .43733 .56473 Mtetra
.43733 .56473 .44298 .57021 .45276 .56724 .44712 .56173 Mtetra
.44712 .56173 .45276 .56724 .46256 .56426 .45695 .55873 Mtetra
.45695 .55873 .46256 .56426 .47241 .56126 .46682 .55571 Mtetra
.656 .751 .92 r
.46682 .55571 .47241 .56126 .48229 .55826 .47672 .55268 Mtetra
.47672 .55268 .48229 .55826 .4922 .55524 .48666 .54965 Mtetra
.48666 .54965 .4922 .55524 .50215 .55222 .49664 .5466 Mtetra
.49664 .5466 .50215 .55222 .51214 .54918 .50665 .54354 Mtetra
.50665 .54354 .51214 .54918 .52217 .54613 .5167 .54047 Mtetra
.5167 .54047 .52217 .54613 .53223 .54307 .52678 .53739 Mtetra
.52678 .53739 .53223 .54307 .54232 .54 .5369 .5343 Mtetra
.5369 .5343 .54232 .54 .55246 .53692 .54706 .5312 Mtetra
.54706 .5312 .55246 .53692 .56263 .53383 .55726 .52809 Mtetra
.55726 .52809 .56263 .53383 .57284 .53072 .56749 .52496 Mtetra
.56749 .52496 .57284 .53072 .58309 .52761 .57777 .52182 Mtetra
.57777 .52182 .58309 .52761 .59337 .52448 .58808 .51867 Mtetra
.58808 .51867 .59337 .52448 .6037 .52134 .59843 .51551 Mtetra
.59843 .51551 .6037 .52134 .61406 .51819 .60881 .51234 Mtetra
.60881 .51234 .61406 .51819 .62446 .51503 .61924 .50916 Mtetra
.61924 .50916 .62446 .51503 .6349 .51185 .62971 .50596 Mtetra
.62971 .50596 .6349 .51185 .64538 .50866 .64021 .50275 Mtetra
.64021 .50275 .64538 .50866 .65589 .50547 .65075 .49953 Mtetra
.65075 .49953 .65589 .50547 .66645 .50226 .66134 .4963 Mtetra
.66134 .4963 .66645 .50226 .67705 .49903 .67196 .49305 Mtetra
.67196 .49305 .67705 .49903 .68768 .4958 .68263 .4898 Mtetra
.68263 .4898 .68768 .4958 .69836 .49255 .69333 .48653 Mtetra
.69333 .48653 .69836 .49255 .70908 .48929 .70408 .48325 Mtetra
.70408 .48325 .70908 .48929 .71984 .48602 .71486 .47996 Mtetra
.71486 .47996 .71984 .48602 .73063 .48274 .72569 .47665 Mtetra
.72569 .47665 .73063 .48274 .74147 .47945 .73656 .47334 Mtetra
.655 .752 .921 r
.73656 .47334 .74147 .47945 .75235 .47614 .74747 .47001 Mtetra
.74747 .47001 .75235 .47614 .76328 .47283 .75842 .46668 Mtetra
.75842 .46668 .76328 .47283 .77424 .4695 .76941 .46334 Mtetra
.76941 .46334 .77424 .4695 .78525 .46617 .78045 .45999 Mtetra
.655 .752 .922 r
.78045 .45999 .78525 .46617 .7963 .46282 .79153 .45664 Mtetra
.655 .753 .922 r
.79153 .45664 .7963 .46282 .80739 .45947 .80265 .45327 Mtetra
.80265 .45327 .80739 .45947 .81852 .4561 .81382 .44989 Mtetra
.655 .754 .923 r
.81382 .44989 .81852 .4561 .8297 .45271 .82503 .44649 Mtetra
.82503 .44649 .8297 .45271 .84092 .44931 .83628 .44307 Mtetra
.656 .755 .923 r
.83628 .44307 .84092 .44931 .85218 .44589 .84758 .43962 Mtetra
.656 .755 .922 r
.84758 .43962 .85218 .44589 .86349 .44245 .85892 .43614 Mtetra
.657 .755 .922 r
.85892 .43614 .86349 .44245 .87484 .43898 .8703 .43264 Mtetra
.657 .754 .922 r
.8703 .43264 .87484 .43898 .88623 .43549 .88172 .42911 Mtetra
.658 .754 .921 r
.88172 .42911 .88623 .43549 .89767 .43198 .89318 .42555 Mtetra
.658 .753 .92 r
.89318 .42555 .89767 .43198 .90915 .42846 .90469 .42197 Mtetra
.652 .75 .922 r
.28853 .60308 .29453 .60833 .30381 .60555 .29782 .60032 Mtetra
.652 .752 .923 r
.29782 .60032 .30381 .60555 .31313 .60275 .30716 .59754 Mtetra
.653 .753 .923 r
.30716 .59754 .31313 .60275 .32248 .59994 .31652 .59474 Mtetra
.653 .754 .924 r
.31652 .59474 .32248 .59994 .33186 .5971 .32592 .59191 Mtetra
.654 .756 .924 r
.32592 .59191 .33186 .5971 .34128 .59424 .33536 .58904 Mtetra
.655 .756 .924 r
.33536 .58904 .34128 .59424 .35073 .59135 .34483 .58614 Mtetra
.656 .757 .924 r
.34483 .58614 .35073 .59135 .36021 .58844 .35434 .58321 Mtetra
.657 .757 .924 r
.35434 .58321 .36021 .58844 .36973 .58551 .36388 .58025 Mtetra
.657 .757 .923 r
.36388 .58025 .36973 .58551 .37929 .58256 .37346 .57727 Mtetra
.658 .756 .923 r
.37346 .57727 .37929 .58256 .38887 .57961 .38307 .57427 Mtetra
.658 .755 .922 r
.38307 .57427 .38887 .57961 .3985 .57664 .39271 .57127 Mtetra
.657 .755 .922 r
.39271 .57127 .3985 .57664 .40815 .57367 .40239 .56826 Mtetra
.657 .754 .921 r
.40239 .56826 .40815 .57367 .41784 .5707 .4121 .56525 Mtetra
.657 .753 .921 r
.4121 .56525 .41784 .5707 .42757 .56772 .42185 .56223 Mtetra
.656 .753 .921 r
.42185 .56223 .42757 .56772 .43733 .56473 .43163 .55921 Mtetra
.656 .752 .921 r
.43163 .55921 .43733 .56473 .44712 .56173 .44145 .55619 Mtetra
.656 .752 .92 r
.44145 .55619 .44712 .56173 .45695 .55873 .45131 .55316 Mtetra
.45131 .55316 .45695 .55873 .46682 .55571 .4612 .55012 Mtetra
.4612 .55012 .46682 .55571 .47672 .55268 .47112 .54707 Mtetra
.656 .751 .92 r
.47112 .54707 .47672 .55268 .48666 .54965 .48108 .54402 Mtetra
.48108 .54402 .48666 .54965 .49664 .5466 .49108 .54095 Mtetra
.49108 .54095 .49664 .5466 .50665 .54354 .50112 .53787 Mtetra
.50112 .53787 .50665 .54354 .5167 .54047 .51119 .53478 Mtetra
.51119 .53478 .5167 .54047 .52678 .53739 .5213 .53168 Mtetra
.5213 .53168 .52678 .53739 .5369 .5343 .53144 .52857 Mtetra
.53144 .52857 .5369 .5343 .54706 .5312 .54163 .52544 Mtetra
.54163 .52544 .54706 .5312 .55726 .52809 .55185 .52231 Mtetra
.55185 .52231 .55726 .52809 .56749 .52496 .56211 .51916 Mtetra
.56211 .51916 .56749 .52496 .57777 .52182 .57241 .516 Mtetra
.57241 .516 .57777 .52182 .58808 .51867 .58274 .51283 Mtetra
.58274 .51283 .58808 .51867 .59843 .51551 .59312 .50965 Mtetra
.59312 .50965 .59843 .51551 .60881 .51234 .60353 .50645 Mtetra
.60353 .50645 .60881 .51234 .61924 .50916 .61398 .50325 Mtetra
.61398 .50325 .61924 .50916 .62971 .50596 .62448 .50003 Mtetra
.62448 .50003 .62971 .50596 .64021 .50275 .63501 .4968 Mtetra
.63501 .4968 .64021 .50275 .65075 .49953 .64558 .49355 Mtetra
.64558 .49355 .65075 .49953 .66134 .4963 .65619 .4903 Mtetra
.65619 .4903 .66134 .4963 .67196 .49305 .66684 .48703 Mtetra
.66684 .48703 .67196 .49305 .68263 .4898 .67753 .48375 Mtetra
.67753 .48375 .68263 .4898 .69333 .48653 .68826 .48046 Mtetra
.68826 .48046 .69333 .48653 .70408 .48325 .69904 .47716 Mtetra
.69904 .47716 .70408 .48325 .71486 .47996 .70985 .47385 Mtetra
.655 .752 .921 r
.70985 .47385 .71486 .47996 .72569 .47665 .72071 .47053 Mtetra
.72071 .47053 .72569 .47665 .73656 .47334 .73161 .46719 Mtetra
.73161 .46719 .73656 .47334 .74747 .47001 .74255 .46386 Mtetra
.74255 .46386 .74747 .47001 .75842 .46668 .75353 .46051 Mtetra
.654 .752 .922 r
.75353 .46051 .75842 .46668 .76941 .46334 .76455 .45717 Mtetra
.654 .753 .922 r
.76455 .45717 .76941 .46334 .78045 .45999 .77562 .45381 Mtetra
.654 .753 .923 r
.77562 .45381 .78045 .45999 .79153 .45664 .78674 .45046 Mtetra
.654 .754 .924 r
.78674 .45046 .79153 .45664 .80265 .45327 .79789 .44709 Mtetra
.654 .755 .924 r
.79789 .44709 .80265 .45327 .81382 .44989 .80909 .4437 Mtetra
.654 .756 .924 r
.80909 .4437 .81382 .44989 .82503 .44649 .82033 .44029 Mtetra
.655 .757 .925 r
.82033 .44029 .82503 .44649 .83628 .44307 .83162 .43685 Mtetra
.656 .757 .924 r
.83162 .43685 .83628 .44307 .84758 .43962 .84294 .43336 Mtetra
.657 .757 .924 r
.84294 .43336 .84758 .43962 .85892 .43614 .85431 .42985 Mtetra
.658 .757 .923 r
.85431 .42985 .85892 .43614 .8703 .43264 .86572 .42629 Mtetra
.658 .756 .922 r
.86572 .42629 .8703 .43264 .88172 .42911 .87717 .4227 Mtetra
.659 .755 .921 r
.87717 .4227 .88172 .42911 .89318 .42555 .88867 .41908 Mtetra
.659 .754 .92 r
.88867 .41908 .89318 .42555 .90469 .42197 .90021 .41544 Mtetra
.65 .75 .923 r
.28248 .59781 .28853 .60308 .29782 .60032 .29179 .59507 Mtetra
.65 .752 .924 r
.29179 .59507 .29782 .60032 .30716 .59754 .30114 .59232 Mtetra
.65 .754 .925 r
.30114 .59232 .30716 .59754 .31652 .59474 .31053 .58955 Mtetra
.651 .756 .926 r
.31053 .58955 .31652 .59474 .32592 .59191 .31995 .58673 Mtetra
.653 .757 .926 r
.31995 .58673 .32592 .59191 .33536 .58904 .3294 .58388 Mtetra
.654 .759 .927 r
.3294 .58388 .33536 .58904 .34483 .58614 .33889 .58098 Mtetra
.656 .76 .927 r
.33889 .58098 .34483 .58614 .35434 .58321 .34842 .57804 Mtetra
.657 .761 .926 r
.34842 .57804 .35434 .58321 .36388 .58025 .35798 .57505 Mtetra
.658 .76 .925 r
.35798 .57505 .36388 .58025 .37346 .57727 .36758 .57203 Mtetra
.659 .76 .925 r
.36758 .57203 .37346 .57727 .38307 .57427 .37722 .56898 Mtetra
.659 .759 .924 r
.37722 .56898 .38307 .57427 .39271 .57127 .38689 .56592 Mtetra
.659 .757 .923 r
.38689 .56592 .39271 .57127 .40239 .56826 .39659 .56286 Mtetra
.658 .756 .922 r
.39659 .56286 .40239 .56826 .4121 .56525 .40632 .5598 Mtetra
.658 .755 .922 r
.40632 .5598 .4121 .56525 .42185 .56223 .4161 .55674 Mtetra
.657 .754 .921 r
.4161 .55674 .42185 .56223 .43163 .55921 .4259 .55368 Mtetra
.657 .753 .921 r
.4259 .55368 .43163 .55921 .44145 .55619 .43574 .55063 Mtetra
.656 .753 .921 r
.43574 .55063 .44145 .55619 .45131 .55316 .44562 .54757 Mtetra
.656 .752 .921 r
.44562 .54757 .45131 .55316 .4612 .55012 .45553 .5445 Mtetra
.656 .752 .92 r
.45553 .5445 .4612 .55012 .47112 .54707 .46548 .54143 Mtetra
.46548 .54143 .47112 .54707 .48108 .54402 .47547 .53835 Mtetra
.47547 .53835 .48108 .54402 .49108 .54095 .48549 .53526 Mtetra
.48549 .53526 .49108 .54095 .50112 .53787 .49555 .53216 Mtetra
.656 .751 .92 r
.49555 .53216 .50112 .53787 .51119 .53478 .50564 .52905 Mtetra
.50564 .52905 .51119 .53478 .5213 .53168 .51578 .52592 Mtetra
.51578 .52592 .5213 .53168 .53144 .52857 .52595 .52279 Mtetra
.52595 .52279 .53144 .52857 .54163 .52544 .53616 .51964 Mtetra
.53616 .51964 .54163 .52544 .55185 .52231 .5464 .51649 Mtetra
.5464 .51649 .55185 .52231 .56211 .51916 .55669 .51332 Mtetra
.55669 .51332 .56211 .51916 .57241 .516 .56701 .51014 Mtetra
.56701 .51014 .57241 .516 .58274 .51283 .57737 .50694 Mtetra
.57737 .50694 .58274 .51283 .59312 .50965 .58777 .50374 Mtetra
.58777 .50374 .59312 .50965 .60353 .50645 .59821 .50052 Mtetra
.59821 .50052 .60353 .50645 .61398 .50325 .60869 .49729 Mtetra
.60869 .49729 .61398 .50325 .62448 .50003 .61921 .49405 Mtetra
.61921 .49405 .62448 .50003 .63501 .4968 .62977 .4908 Mtetra
.62977 .4908 .63501 .4968 .64558 .49355 .64037 .48754 Mtetra
.64037 .48754 .64558 .49355 .65619 .4903 .65101 .48426 Mtetra
.65101 .48426 .65619 .4903 .66684 .48703 .66168 .48097 Mtetra
.66168 .48097 .66684 .48703 .67753 .48375 .6724 .47767 Mtetra
.6724 .47767 .67753 .48375 .68826 .48046 .68316 .47436 Mtetra
.656 .752 .921 r
.68316 .47436 .68826 .48046 .69904 .47716 .69397 .47104 Mtetra
.655 .752 .921 r
.69397 .47104 .69904 .47716 .70985 .47385 .70481 .46771 Mtetra
.70481 .46771 .70985 .47385 .72071 .47053 .71569 .46437 Mtetra
.71569 .46437 .72071 .47053 .73161 .46719 .72662 .46103 Mtetra
.654 .752 .922 r
.72662 .46103 .73161 .46719 .74255 .46386 .73759 .45769 Mtetra
.654 .753 .922 r
.73759 .45769 .74255 .46386 .75353 .46051 .74861 .45434 Mtetra
.653 .753 .923 r
.74861 .45434 .75353 .46051 .76455 .45717 .75966 .451 Mtetra
.653 .754 .924 r
.75966 .451 .76455 .45717 .77562 .45381 .77076 .44766 Mtetra
.652 .755 .925 r
.77076 .44766 .77562 .45381 .78674 .45046 .78191 .44431 Mtetra
.652 .757 .926 r
.78191 .44431 .78674 .45046 .79789 .44709 .7931 .44095 Mtetra
.653 .758 .927 r
.7931 .44095 .79789 .44709 .80909 .4437 .80433 .43756 Mtetra
.653 .759 .927 r
.80433 .43756 .80909 .4437 .82033 .44029 .81561 .43413 Mtetra
.655 .76 .927 r
.81561 .43413 .82033 .44029 .83162 .43685 .82692 .43066 Mtetra
.656 .76 .926 r
.82692 .43066 .83162 .43685 .84294 .43336 .83828 .42714 Mtetra
.658 .76 .926 r
.83828 .42714 .84294 .43336 .85431 .42985 .84968 .42356 Mtetra
.659 .76 .924 r
.84968 .42356 .85431 .42985 .86572 .42629 .86112 .41994 Mtetra
.66 .758 .923 r
.86112 .41994 .86572 .42629 .87717 .4227 .8726 .41627 Mtetra
.661 .757 .921 r
.8726 .41627 .87717 .4227 .88867 .41908 .88412 .41258 Mtetra
.661 .755 .92 r
.88412 .41258 .88867 .41908 .90021 .41544 .89569 .40886 Mtetra
.647 .749 .924 r
.27639 .59249 .28248 .59781 .29179 .59507 .28572 .5898 Mtetra
.647 .751 .925 r
.28572 .5898 .29179 .59507 .30114 .59232 .29509 .58709 Mtetra
.648 .754 .927 r
.29509 .58709 .30114 .59232 .31053 .58955 .30449 .58436 Mtetra
.648 .756 .928 r
.30449 .58436 .31053 .58955 .31995 .58673 .31392 .58159 Mtetra
.65 .759 .929 r
.31392 .58159 .31995 .58673 .3294 .58388 .3234 .57877 Mtetra
.652 .762 .93 r
.3234 .57877 .3294 .58388 .33889 .58098 .33291 .5759 Mtetra
.654 .764 .93 r
.33291 .5759 .33889 .58098 .34842 .57804 .34246 .57296 Mtetra
.656 .765 .93 r
.34246 .57296 .34842 .57804 .35798 .57505 .35204 .56996 Mtetra
.658 .766 .929 r
.35204 .56996 .35798 .57505 .36758 .57203 .36166 .5669 Mtetra
.66 .766 .928 r
.36166 .5669 .36758 .57203 .37722 .56898 .37132 .5638 Mtetra
.66 .765 .927 r
.37132 .5638 .37722 .56898 .38689 .56592 .38101 .56067 Mtetra
.661 .763 .926 r
.38101 .56067 .38689 .56592 .39659 .56286 .39074 .55753 Mtetra
.66 .761 .924 r
.39074 .55753 .39659 .56286 .40632 .5598 .4005 .5544 Mtetra
.659 .759 .923 r
.4005 .5544 .40632 .5598 .4161 .55674 .4103 .55128 Mtetra
.658 .757 .922 r
.4103 .55128 .4161 .55674 .4259 .55368 .42013 .54816 Mtetra
.658 .755 .922 r
.42013 .54816 .4259 .55368 .43574 .55063 .42999 .54506 Mtetra
.657 .754 .921 r
.42999 .54506 .43574 .55063 .44562 .54757 .43989 .54196 Mtetra
.657 .753 .921 r
.43989 .54196 .44562 .54757 .45553 .5445 .44983 .53886 Mtetra
.656 .752 .921 r
.44983 .53886 .45553 .5445 .46548 .54143 .4598 .53576 Mtetra
.4598 .53576 .46548 .54143 .47547 .53835 .46981 .53265 Mtetra
.656 .752 .92 r
.46981 .53265 .47547 .53835 .48549 .53526 .47986 .52954 Mtetra
.47986 .52954 .48549 .53526 .49555 .53216 .48994 .52641 Mtetra
.48994 .52641 .49555 .53216 .50564 .52905 .50006 .52328 Mtetra
.50006 .52328 .50564 .52905 .51578 .52592 .51022 .52013 Mtetra
.656 .751 .92 r
.51022 .52013 .51578 .52592 .52595 .52279 .52041 .51697 Mtetra
.52041 .51697 .52595 .52279 .53616 .51964 .53065 .51381 Mtetra
.53065 .51381 .53616 .51964 .5464 .51649 .54092 .51063 Mtetra
.54092 .51063 .5464 .51649 .55669 .51332 .55123 .50744 Mtetra
.55123 .50744 .55669 .51332 .56701 .51014 .56158 .50423 Mtetra
.56158 .50423 .56701 .51014 .57737 .50694 .57197 .50102 Mtetra
.57197 .50102 .57737 .50694 .58777 .50374 .58239 .49779 Mtetra
.58239 .49779 .58777 .50374 .59821 .50052 .59286 .49455 Mtetra
.59286 .49455 .59821 .50052 .60869 .49729 .60336 .4913 Mtetra
.60336 .4913 .60869 .49729 .61921 .49405 .61391 .48804 Mtetra
.61391 .48804 .61921 .49405 .62977 .4908 .62449 .48476 Mtetra
.62449 .48476 .62977 .4908 .64037 .48754 .63512 .48148 Mtetra
.63512 .48148 .64037 .48754 .65101 .48426 .64578 .47818 Mtetra
.64578 .47818 .65101 .48426 .66168 .48097 .65649 .47487 Mtetra
.656 .752 .921 r
.65649 .47487 .66168 .48097 .6724 .47767 .66724 .47155 Mtetra
.655 .752 .921 r
.66724 .47155 .6724 .47767 .68316 .47436 .67803 .46822 Mtetra
.67803 .46822 .68316 .47436 .69397 .47104 .68886 .46489 Mtetra
.68886 .46489 .69397 .47104 .70481 .46771 .69973 .46155 Mtetra
.654 .752 .922 r
.69973 .46155 .70481 .46771 .71569 .46437 .71065 .4582 Mtetra
.654 .753 .923 r
.71065 .4582 .71569 .46437 .72662 .46103 .7216 .45487 Mtetra
.653 .753 .924 r
.7216 .45487 .72662 .46103 .73759 .45769 .73261 .45154 Mtetra
.652 .754 .925 r
.73261 .45154 .73759 .45769 .74861 .45434 .74365 .44822 Mtetra
.651 .756 .926 r
.74365 .44822 .74861 .45434 .75966 .451 .75475 .44491 Mtetra
.65 .757 .928 r
.75475 .44491 .75966 .451 .77076 .44766 .76588 .4416 Mtetra
.65 .759 .929 r
.76588 .4416 .77076 .44766 .78191 .44431 .77706 .43828 Mtetra
.65 .761 .931 r
.77706 .43828 .78191 .44431 .7931 .44095 .78829 .43493 Mtetra
.651 .763 .931 r
.78829 .43493 .7931 .44095 .80433 .43756 .79955 .43153 Mtetra
.653 .765 .931 r
.79955 .43153 .80433 .43756 .81561 .43413 .81086 .42807 Mtetra
.655 .765 .93 r
.81086 .42807 .81561 .43413 .82692 .43066 .82221 .42455 Mtetra
.658 .765 .929 r
.82221 .42455 .82692 .43066 .83828 .42714 .83359 .42095 Mtetra
.659 .764 .927 r
.83359 .42095 .83828 .42714 .84968 .42356 .84502 .41729 Mtetra
.661 .763 .925 r
.84502 .41729 .84968 .42356 .86112 .41994 .85649 .41358 Mtetra
.662 .761 .923 r
.85649 .41358 .86112 .41994 .8726 .41627 .86799 .40983 Mtetra
.663 .759 .921 r
.86799 .40983 .8726 .41627 .88412 .41258 .87954 .40604 Mtetra
.663 .757 .92 r
.87954 .40604 .88412 .41258 .89569 .40886 .89113 .40224 Mtetra
.644 .749 .925 r
.27027 .58715 .27639 .59249 .28572 .5898 .27961 .5845 Mtetra
.644 .751 .927 r
.27961 .5845 .28572 .5898 .29509 .58709 .28899 .58184 Mtetra
.644 .753 .929 r
.28899 .58184 .29509 .58709 .30449 .58436 .29841 .57916 Mtetra
.645 .756 .93 r
.29841 .57916 .30449 .58436 .31392 .58159 .30786 .57646 Mtetra
.646 .76 .932 r
.30786 .57646 .31392 .58159 .3234 .57877 .31735 .5737 Mtetra
.648 .763 .933 r
.31735 .5737 .3234 .57877 .33291 .5759 .32688 .57089 Mtetra
.651 .767 .934 r
.32688 .57089 .33291 .5759 .34246 .57296 .33644 .56799 Mtetra
.654 .77 .934 r
.33644 .56799 .34246 .57296 .35204 .56996 .34605 .565 Mtetra
.658 .772 .934 r
.34605 .565 .35204 .56996 .36166 .5669 .35569 .56192 Mtetra
.66 .773 .933 r
.35569 .56192 .36166 .5669 .37132 .5638 .36538 .55877 Mtetra
.662 .773 .931 r
.36538 .55877 .37132 .5638 .38101 .56067 .3751 .55557 Mtetra
.663 .771 .93 r
.3751 .55557 .38101 .56067 .39074 .55753 .38485 .55234 Mtetra
.663 .768 .928 r
.38485 .55234 .39074 .55753 .4005 .5544 .39464 .54911 Mtetra
.662 .765 .926 r
.39464 .54911 .4005 .5544 .4103 .55128 .40446 .5459 Mtetra
.661 .762 .925 r
.40446 .5459 .4103 .55128 .42013 .54816 .41431 .5427 Mtetra
.66 .759 .924 r
.41431 .5427 .42013 .54816 .42999 .54506 .4242 .53952 Mtetra
.659 .757 .923 r
.4242 .53952 .42999 .54506 .43989 .54196 .43413 .53636 Mtetra
.658 .755 .922 r
.43413 .53636 .43989 .54196 .44983 .53886 .44409 .53322 Mtetra
.657 .754 .921 r
.44409 .53322 .44983 .53886 .4598 .53576 .45409 .53007 Mtetra
.657 .753 .921 r
.45409 .53007 .4598 .53576 .46981 .53265 .46412 .52693 Mtetra
.656 .753 .921 r
.46412 .52693 .46981 .53265 .47986 .52954 .47419 .52379 Mtetra
.656 .752 .921 r
.47419 .52379 .47986 .52954 .48994 .52641 .4843 .52063 Mtetra
.4843 .52063 .48994 .52641 .50006 .52328 .49444 .51747 Mtetra
.49444 .51747 .50006 .52328 .51022 .52013 .50462 .51431 Mtetra
.656 .752 .92 r
.50462 .51431 .51022 .52013 .52041 .51697 .51484 .51113 Mtetra
.51484 .51113 .52041 .51697 .53065 .51381 .5251 .50793 Mtetra
.5251 .50793 .53065 .51381 .54092 .51063 .5354 .50473 Mtetra
.5354 .50473 .54092 .51063 .55123 .50744 .54573 .50152 Mtetra
.54573 .50152 .55123 .50744 .56158 .50423 .55611 .49829 Mtetra
.55611 .49829 .56158 .50423 .57197 .50102 .56652 .49506 Mtetra
.56652 .49506 .57197 .50102 .58239 .49779 .57697 .49181 Mtetra
.57697 .49181 .58239 .49779 .59286 .49455 .58747 .48855 Mtetra
.58747 .48855 .59286 .49455 .60336 .4913 .598 .48527 Mtetra
.598 .48527 .60336 .4913 .61391 .48804 .60857 .48199 Mtetra
.60857 .48199 .61391 .48804 .62449 .48476 .61918 .47869 Mtetra
.656 .752 .921 r
.61918 .47869 .62449 .48476 .63512 .48148 .62983 .47539 Mtetra
.655 .752 .921 r
.62983 .47539 .63512 .48148 .64578 .47818 .64053 .47207 Mtetra
.64053 .47207 .64578 .47818 .65649 .47487 .65126 .46874 Mtetra
.65126 .46874 .65649 .47487 .66724 .47155 .66204 .46541 Mtetra
.66204 .46541 .66724 .47155 .67803 .46822 .67286 .46207 Mtetra
.654 .752 .922 r
.67286 .46207 .67803 .46822 .68886 .46489 .68372 .45873 Mtetra
.654 .753 .923 r
.68372 .45873 .68886 .46489 .69973 .46155 .69462 .45539 Mtetra
.653 .754 .924 r
.69462 .45539 .69973 .46155 .71065 .4582 .70556 .45207 Mtetra
.651 .755 .925 r
.70556 .45207 .71065 .4582 .7216 .45487 .71656 .44876 Mtetra
.65 .756 .927 r
.71656 .44876 .7216 .45487 .73261 .45154 .72759 .44547 Mtetra
.648 .758 .929 r
.72759 .44547 .73261 .45154 .74365 .44822 .73868 .4422 Mtetra
.647 .76 .931 r
.73868 .4422 .74365 .44822 .75475 .44491 .7498 .43895 Mtetra
.646 .763 .934 r
.7498 .43895 .75475 .44491 .76588 .4416 .76098 .43569 Mtetra
.647 .765 .935 r
.76098 .43569 .76588 .4416 .77706 .43828 .7722 .4324 Mtetra
.648 .768 .936 r
.7722 .4324 .77706 .43828 .78829 .43493 .78346 .42905 Mtetra
.65 .77 .936 r
.78346 .42905 .78829 .43493 .79955 .43153 .79475 .42563 Mtetra
.654 .772 .935 r
.79475 .42563 .79955 .43153 .81086 .42807 .80609 .42211 Mtetra
.657 .771 .934 r
.80609 .42211 .81086 .42807 .82221 .42455 .81747 .4185 Mtetra
.66 .77 .931 r
.81747 .4185 .82221 .42455 .83359 .42095 .82888 .4148 Mtetra
.663 .768 .928 r
.82888 .4148 .83359 .42095 .84502 .41729 .84033 .41103 Mtetra
.664 .766 .926 r
.84033 .41103 .84502 .41729 .85649 .41358 .85182 .4072 Mtetra
.665 .763 .923 r
.85182 .4072 .85649 .41358 .86799 .40983 .86335 .40334 Mtetra
.666 .76 .921 r
.86335 .40334 .86799 .40983 .87954 .40604 .87493 .39946 Mtetra
.665 .758 .919 r
.87493 .39946 .87954 .40604 .89113 .40224 .88655 .39556 Mtetra
.643 .748 .926 r
.2641 .58177 .27027 .58715 .27961 .5845 .27346 .57913 Mtetra
.642 .749 .927 r
.27346 .57913 .27961 .5845 .28899 .58184 .28286 .57651 Mtetra
.641 .751 .929 r
.28286 .57651 .28899 .58184 .29841 .57916 .29229 .57389 Mtetra
.641 .754 .931 r
.29229 .57389 .29841 .57916 .30786 .57646 .30175 .57125 Mtetra
.641 .757 .933 r
.30175 .57125 .30786 .57646 .31735 .5737 .31126 .56859 Mtetra
.642 .762 .935 r
.31126 .56859 .31735 .5737 .32688 .57089 .3208 .56588 Mtetra
.645 .767 .937 r
.3208 .56588 .32688 .57089 .33644 .56799 .33038 .56308 Mtetra
.649 .773 .939 r
.33038 .56308 .33644 .56799 .34605 .565 .34 .56018 Mtetra
.654 .778 .94 r
.34 .56018 .34605 .565 .35569 .56192 .34967 .55715 Mtetra
.658 .782 .94 r
.34967 .55715 .35569 .56192 .36538 .55877 .35938 .554 Mtetra
.663 .784 .938 r
.35938 .554 .36538 .55877 .3751 .55557 .36912 .55075 Mtetra
.665 .783 .937 r
.36912 .55075 .3751 .55557 .38485 .55234 .3789 .54743 Mtetra
.666 .781 .934 r
.3789 .54743 .38485 .55234 .39464 .54911 .38872 .54408 Mtetra
.666 .777 .932 r
.38872 .54408 .39464 .54911 .40446 .5459 .39857 .54073 Mtetra
.665 .772 .93 r
.39857 .54073 .40446 .5459 .41431 .5427 .40845 .5374 Mtetra
.663 .768 .927 r
.40845 .5374 .41431 .5427 .4242 .53952 .41837 .53411 Mtetra
.661 .764 .926 r
.41837 .53411 .4242 .53952 .43413 .53636 .42832 .53085 Mtetra
.66 .76 .924 r
.42832 .53085 .43413 .53636 .44409 .53322 .43831 .52762 Mtetra
.659 .758 .923 r
.43831 .52762 .44409 .53322 .45409 .53007 .44833 .52441 Mtetra
.658 .756 .922 r
.44833 .52441 .45409 .53007 .46412 .52693 .45839 .52122 Mtetra
.657 .755 .922 r
.45839 .52122 .46412 .52693 .47419 .52379 .46848 .51803 Mtetra
.657 .754 .921 r
.46848 .51803 .47419 .52379 .4843 .52063 .47861 .51484 Mtetra
.656 .753 .921 r
.47861 .51484 .4843 .52063 .49444 .51747 .48878 .51165 Mtetra
.656 .752 .921 r
.48878 .51165 .49444 .51747 .50462 .51431 .49899 .50845 Mtetra
.49899 .50845 .50462 .51431 .51484 .51113 .50923 .50524 Mtetra
.50923 .50524 .51484 .51113 .5251 .50793 .51952 .50203 Mtetra
.51952 .50203 .5251 .50793 .5354 .50473 .52984 .4988 Mtetra
.52984 .4988 .5354 .50473 .54573 .50152 .5402 .49556 Mtetra
.656 .752 .92 r
.5402 .49556 .54573 .50152 .55611 .49829 .5506 .49232 Mtetra
.5506 .49232 .55611 .49829 .56652 .49506 .56104 .48906 Mtetra
.656 .752 .921 r
.56104 .48906 .56652 .49506 .57697 .49181 .57152 .48579 Mtetra
.57152 .48579 .57697 .49181 .58747 .48855 .58204 .4825 Mtetra
.58204 .4825 .58747 .48855 .598 .48527 .59259 .47921 Mtetra
.59259 .47921 .598 .48527 .60857 .48199 .60319 .4759 Mtetra
.655 .752 .921 r
.60319 .4759 .60857 .48199 .61918 .47869 .61383 .47259 Mtetra
.61383 .47259 .61918 .47869 .62983 .47539 .62451 .46927 Mtetra
.62451 .46927 .62983 .47539 .64053 .47207 .63523 .46594 Mtetra
.655 .752 .922 r
.63523 .46594 .64053 .47207 .65126 .46874 .646 .4626 Mtetra
.654 .753 .922 r
.646 .4626 .65126 .46874 .66204 .46541 .6568 .45927 Mtetra
.653 .753 .923 r
.6568 .45927 .66204 .46541 .67286 .46207 .66765 .45594 Mtetra
.652 .754 .924 r
.66765 .45594 .67286 .46207 .68372 .45873 .67854 .45262 Mtetra
.651 .755 .926 r
.67854 .45262 .68372 .45873 .69462 .45539 .68948 .44932 Mtetra
.649 .757 .928 r
.68948 .44932 .69462 .45539 .70556 .45207 .70046 .44605 Mtetra
.647 .759 .931 r
.70046 .44605 .70556 .45207 .71656 .44876 .71148 .44282 Mtetra
.645 .762 .934 r
.71148 .44282 .71656 .44876 .72759 .44547 .72256 .43961 Mtetra
.642 .765 .937 r
.72256 .43961 .72759 .44547 .73868 .4422 .73368 .43644 Mtetra
.641 .769 .94 r
.73368 .43644 .73868 .4422 .7498 .43895 .74485 .43326 Mtetra
.641 .773 .943 r
.74485 .43326 .7498 .43895 .76098 .43569 .75606 .43005 Mtetra
.643 .776 .944 r
.75606 .43005 .76098 .43569 .7722 .4324 .76731 .42677 Mtetra
.647 .779 .944 r
.76731 .42677 .7722 .4324 .78346 .42905 .7786 .42338 Mtetra
.652 .78 .942 r
.7786 .42338 .78346 .42905 .79475 .42563 .78993 .41987 Mtetra
.657 .78 .939 r
.78993 .41987 .79475 .42563 .80609 .42211 .8013 .41621 Mtetra
.662 .777 .935 r
.8013 .41621 .80609 .42211 .81747 .4185 .81269 .41245 Mtetra
.665 .774 .93 r
.81269 .41245 .81747 .4185 .82888 .4148 .82413 .40859 Mtetra
.667 .77 .927 r
.82413 .40859 .82888 .4148 .84033 .41103 .8356 .40467 Mtetra
.668 .766 .923 r
.8356 .40467 .84033 .41103 .85182 .4072 .84712 .40073 Mtetra
.668 .762 .921 r
.84712 .40073 .85182 .4072 .86335 .40334 .85868 .39677 Mtetra
.668 .76 .919 r
.85868 .39677 .86335 .40334 .87493 .39946 .87028 .3928 Mtetra
.667 .757 .918 r
.87028 .3928 .87493 .39946 .88655 .39556 .88193 .38884 Mtetra
.643 .748 .925 r
.25789 .57635 .2641 .58177 .27346 .57913 .26727 .57369 Mtetra
.641 .747 .926 r
.26727 .57369 .27346 .57913 .28286 .57651 .27669 .57106 Mtetra
.639 .747 .927 r
.27669 .57106 .28286 .57651 .29229 .57389 .28613 .56845 Mtetra
.638 .748 .929 r
.28613 .56845 .29229 .57389 .30175 .57125 .29562 .56587 Mtetra
.636 .751 .931 r
.29562 .56587 .30175 .57125 .31126 .56859 .30513 .56332 Mtetra
.635 .755 .935 r
.30513 .56332 .31126 .56859 .3208 .56588 .31469 .56075 Mtetra
.636 .762 .938 r
.31469 .56075 .3208 .56588 .33038 .56308 .32428 .55812 Mtetra
.64 .77 .942 r
.32428 .55812 .33038 .56308 .34 .56018 .33391 .55539 Mtetra
.646 .779 .944 r
.33391 .55539 .34 .56018 .34967 .55715 .34359 .5525 Mtetra
.652 .787 .946 r
.34359 .5525 .34967 .55715 .35938 .554 .35332 .54944 Mtetra
.66 .793 .946 r
.35332 .54944 .35938 .554 .36912 .55075 .36309 .5462 Mtetra
.665 .795 .944 r
.36309 .5462 .36912 .55075 .3789 .54743 .3729 .54283 Mtetra
.669 .795 .942 r
.3729 .54283 .3789 .54743 .38872 .54408 .38274 .53937 Mtetra
.67 .792 .939 r
.38274 .53937 .38872 .54408 .39857 .54073 .39262 .53587 Mtetra
.67 .787 .936 r
.39262 .53587 .39857 .54073 .40845 .5374 .40254 .53238 Mtetra
.668 .781 .933 r
.40254 .53238 .40845 .5374 .41837 .53411 .41248 .52892 Mtetra
.666 .775 .931 r
.41248 .52892 .41837 .53411 .42832 .53085 .42246 .52552 Mtetra
.664 .77 .928 r
.42246 .52552 .42832 .53085 .43831 .52762 .43248 .52217 Mtetra
.662 .765 .927 r
.43248 .52217 .43831 .52762 .44833 .52441 .44253 .51886 Mtetra
.66 .762 .925 r
.44253 .51886 .44833 .52441 .45839 .52122 .45261 .51558 Mtetra
.659 .759 .924 r
.45261 .51558 .45839 .52122 .46848 .51803 .46273 .51232 Mtetra
.658 .757 .923 r
.46273 .51232 .46848 .51803 .47861 .51484 .47289 .50908 Mtetra
.657 .756 .923 r
.47289 .50908 .47861 .51484 .48878 .51165 .48308 .50584 Mtetra
.657 .755 .922 r
.48308 .50584 .48878 .51165 .49899 .50845 .49331 .5026 Mtetra
.656 .754 .922 r
.49331 .5026 .49899 .50845 .50923 .50524 .50358 .49936 Mtetra
.50358 .49936 .50923 .50524 .51952 .50203 .51389 .49612 Mtetra
.656 .753 .921 r
.51389 .49612 .51952 .50203 .52984 .4988 .52424 .49286 Mtetra
.52424 .49286 .52984 .4988 .5402 .49556 .53463 .4896 Mtetra
.53463 .4896 .5402 .49556 .5506 .49232 .54505 .48633 Mtetra
.54505 .48633 .5506 .49232 .56104 .48906 .55552 .48304 Mtetra
.55552 .48304 .56104 .48906 .57152 .48579 .56602 .47975 Mtetra
.56602 .47975 .57152 .48579 .58204 .4825 .57657 .47645 Mtetra
.655 .753 .921 r
.57657 .47645 .58204 .4825 .59259 .47921 .58715 .47314 Mtetra
.655 .753 .922 r
.58715 .47314 .59259 .47921 .60319 .4759 .59778 .46982 Mtetra
.59778 .46982 .60319 .4759 .61383 .47259 .60845 .46649 Mtetra
.60845 .46649 .61383 .47259 .62451 .46927 .61915 .46316 Mtetra
.654 .754 .923 r
.61915 .46316 .62451 .46927 .63523 .46594 .6299 .45983 Mtetra
.653 .754 .924 r
.6299 .45983 .63523 .46594 .646 .4626 .6407 .45651 Mtetra
.652 .755 .925 r
.6407 .45651 .646 .4626 .6568 .45927 .65153 .45319 Mtetra
.651 .756 .927 r
.65153 .45319 .6568 .45927 .66765 .45594 .66241 .4499 Mtetra
.649 .758 .929 r
.66241 .4499 .66765 .45594 .67854 .45262 .67334 .44664 Mtetra
.646 .76 .932 r
.67334 .44664 .67854 .45262 .68948 .44932 .68431 .44343 Mtetra
.643 .763 .936 r
.68431 .44343 .68948 .44932 .70046 .44605 .69532 .44026 Mtetra
.639 .766 .94 r
.69532 .44026 .70046 .44605 .71148 .44282 .70639 .43715 Mtetra
.637 .771 .944 r
.70639 .43715 .71148 .44282 .72256 .43961 .71751 .43407 Mtetra
.634 .776 .948 r
.71751 .43407 .72256 .43961 .73368 .43644 .72867 .431 Mtetra
.634 .781 .952 r
.72867 .431 .73368 .43644 .74485 .43326 .73988 .4279 Mtetra
.637 .786 .953 r
.73988 .4279 .74485 .43326 .75606 .43005 .75112 .42469 Mtetra
.642 .789 .952 r
.75112 .42469 .75606 .43005 .76731 .42677 .76241 .42136 Mtetra
.65 .791 .949 r
.76241 .42136 .76731 .42677 .7786 .42338 .77373 .41782 Mtetra
.658 .789 .944 r
.77373 .41782 .7786 .42338 .78993 .41987 .78508 .41412 Mtetra
.665 .785 .938 r
.78508 .41412 .78993 .41987 .8013 .41621 .79646 .41024 Mtetra
.669 .779 .932 r
.79646 .41024 .8013 .41621 .81269 .41245 .80787 .40625 Mtetra
.671 .773 .926 r
.80787 .40625 .81269 .41245 .82413 .40859 .81933 .40221 Mtetra
.672 .767 .922 r
.81933 .40221 .82413 .40859 .8356 .40467 .83082 .39813 Mtetra
.671 .762 .919 r
.83082 .39813 .8356 .40467 .84712 .40073 .84237 .39408 Mtetra
.669 .759 .917 r
.84237 .39408 .84712 .40073 .85868 .39677 .85395 .39006 Mtetra
.668 .757 .917 r
.85395 .39006 .85868 .39677 .87028 .3928 .86559 .38605 Mtetra
.667 .756 .917 r
.86559 .38605 .87028 .3928 .88193 .38884 .87727 .38207 Mtetra
.647 .749 .924 r
.25164 .57089 .25789 .57635 .26727 .57369 .26105 .56812 Mtetra
.645 .745 .922 r
.26105 .56812 .26727 .57369 .27669 .57106 .27049 .56539 Mtetra
.643 .742 .921 r
.27049 .56539 .27669 .57106 .28613 .56845 .27996 .56271 Mtetra
.639 .739 .921 r
.27996 .56271 .28613 .56845 .29562 .56587 .28946 .5601 Mtetra
.634 .737 .923 r
.28946 .5601 .29562 .56587 .30513 .56332 .29899 .5576 Mtetra
.631 .739 .925 r
.29899 .5576 .30513 .56332 .31469 .56075 .30856 .55515 Mtetra
.628 .743 .93 r
.30856 .55515 .31469 .56075 .32428 .55812 .31816 .55274 Mtetra
.628 .752 .936 r
.31816 .55274 .32428 .55812 .33391 .55539 .3278 .55027 Mtetra
.632 .764 .942 r
.3278 .55027 .33391 .55539 .34359 .5525 .33748 .54768 Mtetra
.639 .778 .948 r
.33748 .54768 .34359 .5525 .35332 .54944 .34721 .54491 Mtetra
.648 .792 .951 r
.34721 .54491 .35332 .54944 .36309 .5462 .357 .54187 Mtetra
.657 .804 .953 r
.357 .54187 .36309 .5462 .3729 .54283 .36682 .53862 Mtetra
.666 .811 .953 r
.36682 .53862 .3729 .54283 .38274 .53937 .3767 .53515 Mtetra
.671 .813 .951 r
.3767 .53515 .38274 .53937 .39262 .53587 .38661 .53156 Mtetra
.674 .811 .949 r
.38661 .53156 .39262 .53587 .40254 .53238 .39656 .5279 Mtetra
.674 .805 .945 r
.39656 .5279 .40254 .53238 .41248 .52892 .40654 .52424 Mtetra
.672 .797 .941 r
.40654 .52424 .41248 .52892 .42246 .52552 .41655 .52063 Mtetra
.67 .789 .938 r
.41655 .52063 .42246 .52552 .43248 .52217 .4266 .51707 Mtetra
.667 .781 .935 r
.4266 .51707 .43248 .52217 .44253 .51886 .43667 .51359 Mtetra
.665 .775 .932 r
.43667 .51359 .44253 .51886 .45261 .51558 .44679 .51016 Mtetra
.662 .77 .929 r
.44679 .51016 .45261 .51558 .46273 .51232 .45693 .50678 Mtetra
.661 .765 .927 r
.45693 .50678 .46273 .51232 .47289 .50908 .46712 .50344 Mtetra
.659 .762 .926 r
.46712 .50344 .47289 .50908 .48308 .50584 .47734 .50012 Mtetra
.658 .76 .925 r
.47734 .50012 .48308 .50584 .49331 .5026 .4876 .49682 Mtetra
.657 .758 .924 r
.4876 .49682 .49331 .5026 .50358 .49936 .49789 .49352 Mtetra
.657 .757 .924 r
.49789 .49352 .50358 .49936 .51389 .49612 .50823 .49023 Mtetra
.656 .756 .923 r
.50823 .49023 .51389 .49612 .52424 .49286 .5186 .48694 Mtetra
.656 .755 .923 r
.5186 .48694 .52424 .49286 .53463 .4896 .52901 .48365 Mtetra
.52901 .48365 .53463 .4896 .54505 .48633 .53947 .48035 Mtetra
.53947 .48035 .54505 .48633 .55552 .48304 .54996 .47704 Mtetra
.655 .755 .923 r
.54996 .47704 .55552 .48304 .56602 .47975 .56049 .47373 Mtetra
.56049 .47373 .56602 .47975 .57657 .47645 .57106 .47042 Mtetra
.57106 .47042 .57657 .47645 .58715 .47314 .58167 .46709 Mtetra
.654 .755 .924 r
.58167 .46709 .58715 .47314 .59778 .46982 .59233 .46377 Mtetra
.653 .756 .925 r
.59233 .46377 .59778 .46982 .60845 .46649 .60302 .46045 Mtetra
.653 .757 .926 r
.60302 .46045 .60845 .46649 .61915 .46316 .61376 .45714 Mtetra
.651 .758 .927 r
.61376 .45714 .61915 .46316 .6299 .45983 .62454 .45385 Mtetra
.65 .759 .929 r
.62454 .45385 .6299 .45983 .6407 .45651 .63537 .45058 Mtetra
.647 .761 .932 r
.63537 .45058 .6407 .45651 .65153 .45319 .64623 .44734 Mtetra
.644 .764 .936 r
.64623 .44734 .65153 .45319 .66241 .4499 .65715 .44416 Mtetra
.641 .767 .94 r
.65715 .44416 .66241 .4499 .67334 .44664 .66811 .44103 Mtetra
.636 .772 .945 r
.66811 .44103 .67334 .44664 .68431 .44343 .67912 .43798 Mtetra
.631 .777 .951 r
.67912 .43798 .68431 .44343 .69532 .44026 .69018 .43498 Mtetra
.626 .783 .957 r
.69018 .43498 .69532 .44026 .70639 .43715 .70129 .43203 Mtetra
.624 .79 .961 r
.70129 .43203 .70639 .43715 .71751 .43407 .71245 .42908 Mtetra
.624 .796 .965 r
.71245 .42908 .71751 .43407 .72867 .431 .72365 .42607 Mtetra
.629 .801 .965 r
.72365 .42607 .72867 .431 .73988 .4279 .73489 .42292 Mtetra
.639 .804 .962 r
.73489 .42292 .73988 .4279 .75112 .42469 .74617 .41956 Mtetra
.651 .802 .956 r
.74617 .41956 .75112 .42469 .76241 .42136 .75747 .41596 Mtetra
.663 .798 .947 r
.75747 .41596 .76241 .42136 .77373 .41782 .7688 .41209 Mtetra
.672 .789 .936 r
.7688 .41209 .77373 .41782 .78508 .41412 .78016 .40802 Mtetra
.677 .778 .926 r
.78016 .40802 .78508 .41412 .79646 .41024 .79155 .40382 Mtetra
.679 .768 .918 r
.79155 .40382 .79646 .41024 .80787 .40625 .80298 .39956 Mtetra
.677 .759 .913 r
.80298 .39956 .80787 .40625 .81933 .40221 .81445 .39534 Mtetra
.674 .753 .91 r
.81445 .39534 .81933 .40221 .83082 .39813 .82598 .39117 Mtetra
.67 .749 .91 r
.82598 .39117 .83082 .39813 .84237 .39408 .83755 .3871 Mtetra
.667 .748 .911 r
.83755 .3871 .84237 .39408 .85395 .39006 .84918 .3831 Mtetra
.665 .749 .913 r
.84918 .3831 .85395 .39006 .86559 .38605 .86086 .37915 Mtetra
.663 .751 .916 r
.86086 .37915 .86559 .38605 .87727 .38207 .87259 .37524 Mtetra
.655 .751 .92 r
.24535 .5654 .25164 .57089 .26105 .56812 .25479 .56242 Mtetra
.654 .744 .916 r
.25479 .56242 .26105 .56812 .27049 .56539 .26427 .55948 Mtetra
.65 .737 .913 r
.26427 .55948 .27049 .56539 .27996 .56271 .27377 .55662 Mtetra
.645 .729 .91 r
.27377 .55662 .27996 .56271 .28946 .5601 .2833 .55387 Mtetra
.637 .723 .91 r
.2833 .55387 .28946 .5601 .29899 .5576 .29285 .5513 Mtetra
.63 .72 .911 r
.29285 .5513 .29899 .5576 .30856 .55515 .30243 .54889 Mtetra
.622 .719 .916 r
.30243 .54889 .30856 .55515 .31816 .55274 .31203 .54665 Mtetra
.617 .724 .923 r
.31203 .54665 .31816 .55274 .3278 .55027 .32167 .54449 Mtetra
.615 .735 .931 r
.32167 .54449 .3278 .55027 .33748 .54768 .33135 .54232 Mtetra
.619 .752 .942 r
.33135 .54232 .33748 .54768 .34721 .54491 .34108 .54 Mtetra
.628 .774 .95 r
.34108 .54 .34721 .54491 .357 .54187 .35086 .5374 Mtetra
.639 .795 .957 r
.35086 .5374 .357 .54187 .36682 .53862 .3607 .5345 Mtetra
.654 .813 .96 r
.3607 .5345 .36682 .53862 .3767 .53515 .37059 .53123 Mtetra
.664 .825 .961 r
.37059 .53123 .3767 .53515 .38661 .53156 .38053 .52769 Mtetra
.673 .83 .959 r
.38053 .52769 .38661 .53156 .39656 .5279 .39051 .52396 Mtetra
.677 .829 .956 r
.39051 .52396 .39656 .5279 .40654 .52424 .40052 .52013 Mtetra
.678 .823 .953 r
.40052 .52013 .40654 .52424 .41655 .52063 .41057 .51629 Mtetra
.677 .814 .949 r
.41057 .51629 .41655 .52063 .4266 .51707 .42066 .5125 Mtetra
.674 .805 .945 r
.42066 .5125 .4266 .51707 .43667 .51359 .43077 .50878 Mtetra
.671 .796 .941 r
.43077 .50878 .43667 .51359 .44679 .51016 .44091 .50514 Mtetra
.668 .788 .938 r
.44091 .50514 .44679 .51016 .45693 .50678 .45109 .50158 Mtetra
.665 .781 .935 r
.45109 .50158 .45693 .50678 .46712 .50344 .4613 .49809 Mtetra
.663 .776 .933 r
.4613 .49809 .46712 .50344 .47734 .50012 .47155 .49465 Mtetra
.661 .771 .931 r
.47155 .49465 .47734 .50012 .4876 .49682 .48184 .49125 Mtetra
.659 .768 .93 r
.48184 .49125 .4876 .49682 .49789 .49352 .49216 .48787 Mtetra
.658 .765 .929 r
.49216 .48787 .49789 .49352 .50823 .49023 .50252 .48452 Mtetra
.657 .764 .928 r
.50252 .48452 .50823 .49023 .5186 .48694 .51292 .48117 Mtetra
.656 .762 .928 r
.51292 .48117 .5186 .48694 .52901 .48365 .52336 .47784 Mtetra
.656 .761 .927 r
.52336 .47784 .52901 .48365 .53947 .48035 .53384 .47451 Mtetra
.655 .761 .927 r
.53384 .47451 .53947 .48035 .54996 .47704 .54436 .47118 Mtetra
.655 .761 .928 r
.54436 .47118 .54996 .47704 .56049 .47373 .55492 .46785 Mtetra
.654 .761 .928 r
.55492 .46785 .56049 .47373 .57106 .47042 .56552 .46453 Mtetra
.653 .761 .929 r
.56552 .46453 .57106 .47042 .58167 .46709 .57616 .46122 Mtetra
.652 .762 .93 r
.57616 .46122 .58167 .46709 .59233 .46377 .58684 .45791 Mtetra
.65 .763 .932 r
.58684 .45791 .59233 .46377 .60302 .46045 .59757 .45463 Mtetra
.649 .764 .934 r
.59757 .45463 .60302 .46045 .61376 .45714 .60834 .45138 Mtetra
.646 .767 .936 r
.60834 .45138 .61376 .45714 .62454 .45385 .61915 .44816 Mtetra
.643 .769 .94 r
.61915 .44816 .62454 .45385 .63537 .45058 .63001 .445 Mtetra
.638 .773 .944 r
.63001 .445 .63537 .45058 .64623 .44734 .64091 .4419 Mtetra
.633 .777 .95 r
.64091 .4419 .64623 .44734 .65715 .44416 .65187 .43888 Mtetra
.627 .782 .956 r
.65187 .43888 .65715 .44416 .66811 .44103 .66287 .43595 Mtetra
.62 .788 .963 r
.66287 .43595 .66811 .44103 .67912 .43798 .67392 .43309 Mtetra
.614 .795 .969 r
.67392 .43309 .67912 .43798 .69018 .43498 .68503 .43028 Mtetra
.61 .803 .974 r
.68503 .43028 .69018 .43498 .70129 .43203 .69618 .42746 Mtetra
.612 .81 .976 r
.69618 .42746 .70129 .43203 .71245 .42908 .70738 .42455 Mtetra
.621 .816 .975 r
.70738 .42455 .71245 .42908 .72365 .42607 .71861 .42143 Mtetra
.636 .817 .97 r
.71861 .42143 .72365 .42607 .73489 .42292 .72988 .41803 Mtetra
.655 .815 .96 r
.72988 .41803 .73489 .42292 .74617 .41956 .74116 .41426 Mtetra
.671 .805 .947 r
.74116 .41426 .74617 .41956 .75747 .41596 .75247 .41016 Mtetra
.684 .791 .931 r
.75247 .41016 .75747 .41596 .7688 .41209 .7638 .40578 Mtetra
.689 .775 .917 r
.7638 .40578 .7688 .41209 .78016 .40802 .77516 .40123 Mtetra
.688 .759 .906 r
.77516 .40123 .78016 .40802 .79155 .40382 .78655 .39667 Mtetra
.684 .747 .899 r
.78655 .39667 .79155 .40382 .80298 .39956 .798 .39218 Mtetra
.678 .738 .896 r
.798 .39218 .80298 .39956 .81445 .39534 .80949 .38786 Mtetra
.672 .734 .897 r
.80949 .38786 .81445 .39534 .82598 .39117 .82105 .38371 Mtetra
.666 .733 .9 r
.82105 .38371 .82598 .39117 .83755 .3871 .83267 .37974 Mtetra
.661 .735 .904 r
.83267 .37974 .83755 .3871 .84918 .3831 .84435 .37588 Mtetra
.658 .739 .91 r
.84435 .37588 .84918 .3831 .86086 .37915 .85608 .37211 Mtetra
.656 .745 .915 r
.85608 .37211 .86086 .37915 .87259 .37524 .86786 .36837 Mtetra
.666 .754 .916 r
.23902 .55988 .24535 .5654 .25479 .56242 .2485 .55663 Mtetra
.665 .745 .91 r
.2485 .55663 .25479 .56242 .26427 .55948 .25802 .55339 Mtetra
.662 .735 .904 r
.25802 .55339 .26427 .55948 .27377 .55662 .26756 .5502 Mtetra
.657 .724 .898 r
.26756 .5502 .27377 .55662 .2833 .55387 .27713 .54715 Mtetra
.649 .712 .894 r
.27713 .54715 .2833 .55387 .29285 .5513 .28672 .54428 Mtetra
.639 .701 .891 r
.28672 .54428 .29285 .5513 .30243 .54889 .29632 .54165 Mtetra
.626 .69 .89 r
.29632 .54165 .30243 .54889 .31203 .54665 .30595 .53933 Mtetra
.616 .685 .892 r
.30595 .53933 .31203 .54665 .32167 .54449 .3156 .53727 Mtetra
.605 .685 .898 r
.3156 .53727 .32167 .54449 .33135 .54232 .32527 .53544 Mtetra
.602 .695 .908 r
.32527 .53544 .33135 .54232 .34108 .54 .33499 .53364 Mtetra
.604 .714 .922 r
.33499 .53364 .34108 .54 .35086 .5374 .34475 .53174 Mtetra
.611 .742 .938 r
.34475 .53174 .35086 .5374 .3607 .5345 .35457 .52956 Mtetra
.627 .775 .952 r
.35457 .52956 .3607 .5345 .37059 .53123 .36445 .52695 Mtetra
.64 .806 .963 r
.36445 .52695 .37059 .53123 .38053 .52769 .37439 .52393 Mtetra
.655 .832 .968 r
.37439 .52393 .38053 .52769 .39051 .52396 .38439 .5205 Mtetra
.665 .847 .97 r
.38439 .5205 .39051 .52396 .40052 .52013 .39443 .51678 Mtetra
.672 .854 .969 r
.39443 .51678 .40052 .52013 .41057 .51629 .40452 .51288 Mtetra
.676 .853 .967 r
.40452 .51288 .41057 .51629 .42066 .5125 .41463 .5089 Mtetra
.676 .847 .964 r
.41463 .5089 .42066 .5125 .43077 .50878 .42478 .50495 Mtetra
.676 .837 .961 r
.42478 .50495 .43077 .50878 .44091 .50514 .43497 .50104 Mtetra
.673 .827 .957 r
.43497 .50104 .44091 .50514 .45109 .50158 .44518 .49722 Mtetra
.67 .816 .954 r
.44518 .49722 .45109 .50158 .4613 .49809 .45543 .49348 Mtetra
.667 .807 .95 r
.45543 .49348 .4613 .49809 .47155 .49465 .46571 .48983 Mtetra
.664 .799 .947 r
.46571 .48983 .47155 .49465 .48184 .49125 .47603 .48626 Mtetra
.662 .792 .944 r
.47603 .48626 .48184 .49125 .49216 .48787 .48638 .48274 Mtetra
.66 .787 .942 r
.48638 .48274 .49216 .48787 .50252 .48452 .49677 .47927 Mtetra
.658 .783 .94 r
.49677 .47927 .50252 .48452 .51292 .48117 .5072 .47584 Mtetra
.657 .78 .939 r
.5072 .47584 .51292 .48117 .52336 .47784 .51767 .47243 Mtetra
.655 .778 .939 r
.51767 .47243 .52336 .47784 .53384 .47451 .52817 .46906 Mtetra
.654 .777 .939 r
.52817 .46906 .53384 .47451 .54436 .47118 .53872 .46571 Mtetra
.652 .776 .939 r
.53872 .46571 .54436 .47118 .55492 .46785 .54931 .46238 Mtetra
.65 .776 .941 r
.54931 .46238 .55492 .46785 .56552 .46453 .55994 .45908 Mtetra
.648 .777 .942 r
.55994 .45908 .56552 .46453 .57616 .46122 .57061 .45581 Mtetra
.645 .779 .945 r
.57061 .45581 .57616 .46122 .58684 .45791 .58133 .45258 Mtetra
.642 .781 .948 r
.58133 .45258 .58684 .45791 .59757 .45463 .59209 .44939 Mtetra
.638 .785 .952 r
.59209 .44939 .59757 .45463 .60834 .45138 .60289 .44627 Mtetra
.632 .789 .957 r
.60289 .44627 .60834 .45138 .61915 .44816 .61374 .44322 Mtetra
.625 .794 .963 r
.61374 .44322 .61915 .44816 .63001 .445 .62464 .44025 Mtetra
.617 .8 .97 r
.62464 .44025 .63001 .445 .64091 .4419 .63558 .43738 Mtetra
.607 .807 .977 r
.63558 .43738 .64091 .4419 .65187 .43888 .64658 .43459 Mtetra
.599 .814 .983 r
.64658 .43459 .65187 .43888 .66287 .43595 .65763 .43186 Mtetra
.592 .821 .987 r
.65763 .43186 .66287 .43595 .67392 .43309 .66873 .42915 Mtetra
.591 .828 .989 r
.66873 .42915 .67392 .43309 .68503 .43028 .67987 .42636 Mtetra
.601 .833 .988 r
.67987 .42636 .68503 .43028 .69618 .42746 .69106 .42338 Mtetra
.619 .834 .983 r
.69106 .42338 .69618 .42746 .70738 .42455 .70227 .42011 Mtetra
.647 .83 .971 r
.70227 .42011 .70738 .42455 .71861 .42143 .71351 .41641 Mtetra
.671 .816 .953 r
.71351 .41641 .71861 .42143 .72988 .41803 .72477 .41229 Mtetra
.69 .795 .93 r
.72477 .41229 .72988 .41803 .74116 .41426 .73604 .40772 Mtetra
.699 .771 .907 r
.73604 .40772 .74116 .41426 .75247 .41016 .74733 .40286 Mtetra
.699 .747 .889 r
.74733 .40286 .75247 .41016 .7638 .40578 .75865 .39788 Mtetra
.695 .729 .876 r
.75865 .39788 .7638 .40578 .77516 .40123 .77001 .39293 Mtetra
.686 .715 .871 r
.77001 .39293 .77516 .40123 .78655 .39667 .78142 .38822 Mtetra
.678 .708 .871 r
.78142 .38822 .78655 .39667 .798 .39218 .79289 .38376 Mtetra
.668 .706 .875 r
.79289 .38376 .798 .39218 .80949 .38786 .80444 .37962 Mtetra
.661 .708 .883 r
.80444 .37962 .80949 .38786 .82105 .38371 .81605 .37573 Mtetra
.655 .714 .891 r
.81605 .37573 .82105 .38371 .83267 .37974 .82773 .37203 Mtetra
.651 .721 .9 r
.82773 .37203 .83267 .37974 .84435 .37588 .83946 .36846 Mtetra
.648 .73 .909 r
.83946 .36846 .84435 .37588 .85608 .37211 .85126 .36495 Mtetra
.647 .739 .916 r
.85126 .36495 .85608 .37211 .86786 .36837 .8631 .36144 Mtetra
.675 .756 .912 r
.23264 .55431 .23902 .55988 .2485 .55663 .24217 .55081 Mtetra
.676 .748 .905 r
.24217 .55081 .2485 .55663 .25802 .55339 .25173 .54725 Mtetra
.675 .738 .898 r
.25173 .54725 .25802 .55339 .26756 .5502 .26132 .54369 Mtetra
.671 .726 .89 r
.26132 .54369 .26756 .5502 .27713 .54715 .27093 .5402 Mtetra
.666 .712 .882 r
.27093 .5402 .27713 .54715 .28672 .54428 .28057 .53683 Mtetra
.655 .695 .875 r
.28057 .53683 .28672 .54428 .29632 .54165 .29023 .53372 Mtetra
.641 .677 .869 r
.29023 .53372 .29632 .54165 .30595 .53933 .29989 .53098 Mtetra
.625 .661 .865 r
.29989 .53098 .30595 .53933 .3156 .53727 .30957 .52868 Mtetra
.605 .647 .866 r
.30957 .52868 .3156 .53727 .32527 .53544 .31925 .5269 Mtetra
.591 .644 .871 r
.31925 .5269 .32527 .53544 .33499 .53364 .32895 .52547 Mtetra
.58 .649 .883 r
.32895 .52547 .33499 .53364 .34475 .53174 .33869 .52428 Mtetra
.579 .67 .902 r
.33869 .52428 .34475 .53174 .35457 .52956 .34848 .52301 Mtetra
.587 .704 .924 r
.34848 .52301 .35457 .52956 .36445 .52695 .35833 .52142 Mtetra
.601 .747 .946 r
.35833 .52142 .36445 .52695 .37439 .52393 .36825 .51936 Mtetra
.623 .792 .963 r
.36825 .51936 .37439 .52393 .38439 .5205 .37824 .51668 Mtetra
.64 .828 .973 r
.37824 .51668 .38439 .5205 .39443 .51678 .38829 .5135 Mtetra
.655 .854 .976 r
.38829 .5135 .39443 .51678 .40452 .51288 .39839 .50986 Mtetra
.665 .868 .976 r
.39839 .50986 .40452 .51288 .41463 .5089 .40854 .50595 Mtetra
.671 .873 .975 r
.40854 .50595 .41463 .5089 .42478 .50495 .41873 .50189 Mtetra
.674 .87 .973 r
.41873 .50189 .42478 .50495 .43497 .50104 .42895 .49779 Mtetra
.674 .863 .971 r
.42895 .49779 .43497 .50104 .44518 .49722 .4392 .49373 Mtetra
.672 .854 .969 r
.4392 .49373 .44518 .49722 .45543 .49348 .44949 .48974 Mtetra
.669 .844 .967 r
.44949 .48974 .45543 .49348 .46571 .48983 .45981 .48585 Mtetra
.667 .834 .964 r
.45981 .48585 .46571 .48983 .47603 .48626 .47016 .48206 Mtetra
.663 .826 .962 r
.47016 .48206 .47603 .48626 .48638 .48274 .48055 .47836 Mtetra
.66 .818 .959 r
.48055 .47836 .48638 .48274 .49677 .47927 .49097 .47474 Mtetra
.657 .813 .958 r
.49097 .47474 .49677 .47927 .5072 .47584 .50143 .47119 Mtetra
.655 .808 .957 r
.50143 .47119 .5072 .47584 .51767 .47243 .51193 .46771 Mtetra
.652 .805 .956 r
.51193 .46771 .51767 .47243 .52817 .46906 .52247 .46428 Mtetra
.649 .803 .957 r
.52247 .46428 .52817 .46906 .53872 .46571 .53304 .4609 Mtetra
.646 .802 .958 r
.53304 .4609 .53872 .46571 .54931 .46238 .54366 .45758 Mtetra
.642 .802 .96 r
.54366 .45758 .54931 .46238 .55994 .45908 .55433 .45432 Mtetra
.638 .803 .962 r
.55433 .45432 .55994 .45908 .57061 .45581 .56503 .45112 Mtetra
.632 .805 .966 r
.56503 .45112 .57061 .45581 .58133 .45258 .57578 .448 Mtetra
.626 .808 .97 r
.57578 .448 .58133 .45258 .59209 .44939 .58658 .44495 Mtetra
.617 .812 .975 r
.58658 .44495 .59209 .44939 .60289 .44627 .59742 .442 Mtetra
.608 .817 .98 r
.59742 .442 .60289 .44627 .61374 .44322 .60831 .43915 Mtetra
.596 .822 .986 r
.60831 .43915 .61374 .44322 .62464 .44025 .61925 .4364 Mtetra
.585 .827 .991 r
.61925 .4364 .62464 .44025 .63558 .43738 .63024 .43372 Mtetra
.574 .833 .994 r
.63024 .43372 .63558 .43738 .64658 .43459 .64128 .43109 Mtetra
.57 .839 .996 r
.64128 .43109 .64658 .43459 .65763 .43186 .65237 .42842 Mtetra
.577 .844 .995 r
.65237 .42842 .65763 .43186 .66873 .42915 .6635 .4256 Mtetra
.597 .848 .992 r
.6635 .4256 .66873 .42915 .67987 .42636 .67467 .4225 Mtetra
.631 .848 .983 r
.67467 .4225 .67987 .42636 .69106 .42338 .68587 .41893 Mtetra
.665 .836 .965 r
.68587 .41893 .69106 .42338 .70227 .42011 .69708 .41484 Mtetra
.696 .814 .938 r
.69708 .41484 .70227 .42011 .71351 .41641 .7083 .41011 Mtetra
.711 .782 .908 r
.7083 .41011 .71351 .41641 .72477 .41229 .71953 .40489 Mtetra
.715 .749 .879 r
.71953 .40489 .72477 .41229 .73604 .40772 .73076 .39932 Mtetra
.71 .721 .858 r
.73076 .39932 .73604 .40772 .74733 .40286 .74203 .39367 Mtetra
.699 .697 .845 r
.74203 .39367 .74733 .40286 .75865 .39788 .75334 .38826 Mtetra
.687 .683 .841 r
.75334 .38826 .75865 .39788 .77001 .39293 .76472 .3832 Mtetra
.673 .675 .844 r
.76472 .3832 .77001 .39293 .78142 .38822 .77617 .37868 Mtetra
.662 .675 .852 r
.77617 .37868 .78142 .38822 .79289 .38376 .7877 .37461 Mtetra
.652 .681 .864 r
.7877 .37461 .79289 .38376 .80444 .37962 .79931 .37092 Mtetra
.645 .69 .878 r
.79931 .37092 .80444 .37962 .81605 .37573 .811 .3675 Mtetra
.641 .702 .891 r
.811 .3675 .81605 .37573 .82773 .37203 .82274 .3642 Mtetra
.638 .714 .902 r
.82274 .3642 .82773 .37203 .83946 .36846 .83455 .36097 Mtetra
.637 .725 .911 r
.83455 .36097 .83946 .36846 .85126 .36495 .8464 .35775 Mtetra
.638 .735 .919 r
.8464 .35775 .85126 .36495 .8631 .36144 .85831 .35446 Mtetra
.677 .756 .911 r
.22623 .54871 .23264 .55431 .24217 .55081 .23578 .54514 Mtetra
.681 .755 .908 r
.23578 .54514 .24217 .55081 .25173 .54725 .24536 .54145 Mtetra
.683 .752 .904 r
.24536 .54145 .25173 .54725 .26132 .54369 .25499 .53768 Mtetra
.684 .746 .898 r
.25499 .53768 .26132 .54369 .27093 .5402 .26465 .53385 Mtetra
.685 .736 .89 r
.26465 .53385 .27093 .5402 .28057 .53683 .27435 .52995 Mtetra
.679 .719 .879 r
.27435 .52995 .28057 .53683 .29023 .53372 .28407 .52616 Mtetra
.669 .698 .868 r
.28407 .52616 .29023 .53372 .29989 .53098 .29381 .52258 Mtetra
.652 .671 .855 r
.29381 .52258 .29989 .53098 .30957 .52868 .30355 .51943 Mtetra
.63 .643 .844 r
.30355 .51943 .30957 .52868 .31925 .5269 .31329 .51689 Mtetra
.609 .618 .835 r
.31329 .51689 .31925 .5269 .32895 .52547 .32303 .51498 Mtetra
.585 .597 .831 r
.32303 .51498 .32895 .52547 .33869 .52428 .33277 .51376 Mtetra
.572 .591 .834 r
.33277 .51376 .33869 .52428 .34848 .52301 .34254 .51292 Mtetra
.564 .597 .845 r
.34254 .51292 .34848 .52301 .35833 .52142 .35234 .51226 Mtetra
.567 .621 .865 r
.35234 .51226 .35833 .52142 .36825 .51936 .36221 .51142 Mtetra
.581 .66 .892 r
.36221 .51142 .36825 .51936 .37824 .51668 .37215 .51011 Mtetra
.598 .711 .923 r
.37215 .51011 .37824 .51668 .38829 .5135 .38217 .50825 Mtetra
.62 .767 .95 r
.38217 .50825 .38829 .5135 .39839 .50986 .39225 .50572 Mtetra
.634 .816 .97 r
.39225 .50572 .39839 .50986 .40854 .50595 .4024 .50267 Mtetra
.644 .854 .98 r
.4024 .50267 .40854 .50595 .41873 .50189 .4126 .49916 Mtetra
.648 .878 .983 r
.4126 .49916 .41873 .50189 .42895 .49779 .42285 .49536 Mtetra
.648 .891 .983 r
.42285 .49536 .42895 .49779 .4392 .49373 .43314 .49141 Mtetra
.648 .896 .983 r
.43314 .49141 .4392 .49373 .44949 .48974 .44346 .48739 Mtetra
.646 .895 .984 r
.44346 .48739 .44949 .48974 .45981 .48585 .45382 .48338 Mtetra
.645 .891 .984 r
.45382 .48338 .45981 .48585 .47016 .48206 .46421 .47943 Mtetra
.643 .885 .985 r
.46421 .47943 .47016 .48206 .48055 .47836 .47464 .47557 Mtetra
.64 .879 .985 r
.47464 .47557 .48055 .47836 .49097 .47474 .4851 .47179 Mtetra
.637 .873 .986 r
.4851 .47179 .49097 .47474 .50143 .47119 .4956 .46812 Mtetra
.633 .867 .986 r
.4956 .46812 .50143 .47119 .51193 .46771 .50613 .46453 Mtetra
.628 .863 .987 r
.50613 .46453 .51193 .46771 .52247 .46428 .51671 .46104 Mtetra
.623 .86 .988 r
.51671 .46104 .52247 .46428 .53304 .4609 .52732 .45765 Mtetra
.616 .858 .989 r
.52732 .45765 .53304 .4609 .54366 .45758 .53798 .45435 Mtetra
.608 .857 .991 r
.53798 .45435 .54366 .45758 .55433 .45432 .54868 .45114 Mtetra
.599 .857 .993 r
.54868 .45114 .55433 .45432 .56503 .45112 .55942 .44803 Mtetra
.588 .857 .994 r
.55942 .44803 .56503 .45112 .57578 .448 .57021 .44501 Mtetra
.575 .858 .996 r
.57021 .44501 .57578 .448 .58658 .44495 .58105 .44209 Mtetra
.562 .859 .997 r
.58105 .44209 .58658 .44495 .59742 .442 .59193 .43926 Mtetra
.551 .86 .997 r
.59193 .43926 .59742 .442 .60831 .43915 .60286 .43648 Mtetra
.544 .861 .996 r
.60286 .43648 .60831 .43915 .61925 .4364 .61384 .43372 Mtetra
.548 .863 .996 r
.61384 .43372 .61925 .4364 .63024 .43372 .62487 .4309 Mtetra
.565 .864 .996 r
.62487 .4309 .63024 .43372 .64128 .43109 .63594 .42791 Mtetra
.597 .863 .993 r
.63594 .42791 .64128 .43109 .65237 .42842 .64705 .42464 Mtetra
.639 .854 .982 r
.64705 .42464 .65237 .42842 .6635 .4256 .65819 .4209 Mtetra
.676 .829 .957 r
.65819 .4209 .6635 .4256 .67467 .4225 .66934 .41662 Mtetra
.705 .794 .92 r
.66934 .41662 .67467 .4225 .68587 .41893 .6805 .41164 Mtetra
.716 .752 .881 r
.6805 .41164 .68587 .41893 .69708 .41484 .69167 .40609 Mtetra
.718 .714 .846 r
.69167 .40609 .69708 .41484 .7083 .41011 .70284 .40005 Mtetra
.711 .683 .821 r
.70284 .40005 .7083 .41011 .71953 .40489 .71403 .39382 Mtetra
.7 .659 .806 r
.71403 .39382 .71953 .40489 .73076 .39932 .72526 .38775 Mtetra
.688 .646 .802 r
.72526 .38775 .73076 .39932 .74203 .39367 .73654 .38207 Mtetra
.673 .638 .807 r
.73654 .38207 .74203 .39367 .75334 .38826 .74791 .37711 Mtetra
.661 .641 .819 r
.74791 .37711 .75334 .38826 .76472 .3832 .75935 .37278 Mtetra
.648 .65 .838 r
.75935 .37278 .76472 .3832 .77617 .37868 .77089 .36909 Mtetra
.638 .664 .859 r
.77089 .36909 .77617 .37868 .7877 .37461 .78252 .36583 Mtetra
.632 .683 .88 r
.78252 .36583 .7877 .37461 .79931 .37092 .79421 .3628 Mtetra
.628 .7 .897 r
.79421 .3628 .79931 .37092 .811 .3675 .80597 .35988 Mtetra
.629 .717 .91 r
.80597 .35988 .811 .3675 .82274 .3642 .81778 .3569 Mtetra
.63 .728 .918 r
.81778 .3569 .82274 .3642 .83455 .36097 .82963 .35384 Mtetra
.632 .736 .923 r
.82963 .35384 .83455 .36097 .8464 .35775 .84153 .3507 Mtetra
.636 .741 .924 r
.84153 .3507 .8464 .35775 .85831 .35446 .85348 .34743 Mtetra
.669 .755 .914 r
.21976 .54307 .22623 .54871 .23578 .54514 .22932 .53967 Mtetra
.675 .762 .917 r
.22932 .53967 .23578 .54514 .24536 .54145 .23892 .53613 Mtetra
.681 .77 .918 r
.23892 .53613 .24536 .54145 .25499 .53768 .24856 .5324 Mtetra
.689 .774 .916 r
.24856 .5324 .25499 .53768 .26465 .53385 .25825 .52846 Mtetra
.7 .772 .908 r
.25825 .52846 .26465 .53385 .27435 .52995 .268 .5242 Mtetra
.704 .762 .897 r
.268 .5242 .27435 .52995 .28407 .52616 .27779 .51977 Mtetra
.705 .742 .881 r
.27779 .51977 .28407 .52616 .29381 .52258 .28762 .51519 Mtetra
.693 .711 .862 r
.28762 .51519 .29381 .52258 .30355 .51943 .29746 .51079 Mtetra
.674 .674 .842 r
.29746 .51079 .30355 .51943 .31329 .51689 .3073 .50682 Mtetra
.647 .634 .823 r
.3073 .50682 .31329 .51689 .32303 .51498 .31713 .50358 Mtetra
.614 .595 .808 r
.31713 .50358 .32303 .51498 .33277 .51376 .32693 .50138 Mtetra
.586 .566 .798 r
.32693 .50138 .33277 .51376 .34254 .51292 .33672 .5001 Mtetra
.558 .545 .795 r
.33672 .5001 .34254 .51292 .35234 .51226 .34651 .49974 Mtetra
.544 .542 .803 r
.34651 .49974 .35234 .51226 .36221 .51142 .35633 .49981 Mtetra
.538 .556 .821 r
.35633 .49981 .36221 .51142 .37215 .51011 .3662 .49994 Mtetra
.544 .588 .849 r
.3662 .49994 .37215 .51011 .38217 .50825 .37615 .49975 Mtetra
.562 .639 .884 r
.37615 .49975 .38217 .50825 .39225 .50572 .38618 .49889 Mtetra
.582 .699 .922 r
.38618 .49889 .39225 .50572 .4024 .50267 .39629 .49733 Mtetra
.606 .762 .954 r
.39629 .49733 .4024 .50267 .4126 .49916 .40648 .49502 Mtetra
.621 .816 .975 r
.40648 .49502 .4126 .49916 .42285 .49536 .41672 .49213 Mtetra
.63 .856 .985 r
.41672 .49213 .42285 .49536 .43314 .49141 .42703 .48878 Mtetra
.631 .881 .987 r
.42703 .48878 .43314 .49141 .44346 .48739 .43738 .48513 Mtetra
.629 .894 .987 r
.43738 .48513 .44346 .48739 .45382 .48338 .44777 .48131 Mtetra
.625 .901 .986 r
.44777 .48131 .45382 .48338 .46421 .47943 .4582 .47742 Mtetra
.62 .902 .985 r
.4582 .47742 .46421 .47943 .47464 .47557 .46866 .47355 Mtetra
.615 .901 .986 r
.46866 .47355 .47464 .47557 .4851 .47179 .47917 .46972 Mtetra
.609 .898 .987 r
.47917 .46972 .4851 .47179 .4956 .46812 .4897 .46598 Mtetra
.603 .895 .988 r
.4897 .46598 .4956 .46812 .50613 .46453 .50028 .46234 Mtetra
.595 .891 .99 r
.50028 .46234 .50613 .46453 .51671 .46104 .51089 .45882 Mtetra
.586 .888 .991 r
.51089 .45882 .51671 .46104 .52732 .45765 .52155 .4554 Mtetra
.577 .884 .991 r
.52155 .4554 .52732 .45765 .53798 .45435 .53225 .4521 Mtetra
.566 .881 .992 r
.53225 .4521 .53798 .45435 .54868 .45114 .54299 .4489 Mtetra
.556 .878 .992 r
.54299 .4489 .54868 .45114 .55942 .44803 .55377 .44581 Mtetra
.546 .876 .991 r
.55377 .44581 .55942 .44803 .57021 .44501 .5646 .44281 Mtetra
.539 .874 .991 r
.5646 .44281 .57021 .44501 .58105 .44209 .57548 .43986 Mtetra
.537 .873 .991 r
.57548 .43986 .58105 .44209 .59193 .43926 .5864 .43692 Mtetra
.547 .874 .992 r
.5864 .43692 .59193 .43926 .60286 .43648 .59737 .43391 Mtetra
.569 .875 .994 r
.59737 .43391 .60286 .43648 .61384 .43372 .60838 .43073 Mtetra
.604 .873 .992 r
.60838 .43073 .61384 .43372 .62487 .4309 .61943 .42726 Mtetra
.648 .862 .98 r
.61943 .42726 .62487 .4309 .63594 .42791 .63051 .42331 Mtetra
.687 .835 .954 r
.63051 .42331 .63594 .42791 .64705 .42464 .64161 .41876 Mtetra
.717 .796 .914 r
.64161 .41876 .64705 .42464 .65819 .4209 .65272 .41343 Mtetra
.728 .75 .87 r
.65272 .41343 .65819 .4209 .66934 .41662 .66382 .40739 Mtetra
.729 .707 .829 r
.66382 .40739 .66934 .41662 .6805 .41164 .67493 .40065 Mtetra
.72 .669 .799 r
.67493 .40065 .6805 .41164 .69167 .40609 .68604 .39357 Mtetra
.707 .639 .778 r
.68604 .39357 .69167 .40609 .70284 .40005 .69717 .38653 Mtetra
.692 .619 .769 r
.69717 .38653 .70284 .40005 .71403 .39382 .70835 .37992 Mtetra
.673 .604 .77 r
.70835 .37992 .71403 .39382 .72526 .38775 .71962 .37425 Mtetra
.658 .602 .781 r
.71962 .37425 .72526 .38775 .73654 .38207 .73097 .36953 Mtetra
.639 .607 .801 r
.73097 .36953 .73654 .38207 .74791 .37711 .74244 .36588 Mtetra
.624 .623 .829 r
.74244 .36588 .74791 .37711 .75935 .37278 .75401 .36298 Mtetra
.613 .648 .861 r
.75401 .36298 .75935 .37278 .77089 .36909 .76567 .36053 Mtetra
.605 .677 .892 r
.76567 .36053 .77089 .36909 .78252 .36583 .7774 .35827 Mtetra
.607 .708 .916 r
.7774 .35827 .78252 .36583 .79421 .3628 .78918 .35586 Mtetra
.61 .731 .931 r
.78918 .35586 .79421 .3628 .80597 .35988 .801 .35326 Mtetra
.621 .748 .938 r
.801 .35326 .80597 .35988 .81778 .3569 .81285 .35034 Mtetra
.629 .756 .938 r
.81285 .35034 .81778 .3569 .82963 .35384 .82473 .34719 Mtetra
.637 .756 .935 r
.82473 .34719 .82963 .35384 .84153 .3507 .83665 .34384 Mtetra
.642 .753 .929 r
.83665 .34384 .84153 .3507 .85348 .34743 .84861 .34035 Mtetra
.651 .75 .922 r
.21326 .53739 .21976 .54307 .22932 .53967 .22279 .53442 Mtetra
.653 .767 .933 r
.22279 .53442 .22932 .53967 .23892 .53613 .23237 .53135 Mtetra
.66 .787 .942 r
.23237 .53135 .23892 .53613 .24856 .5324 .242 .52809 Mtetra
.67 .808 .949 r
.242 .52809 .24856 .5324 .25825 .52846 .25169 .52454 Mtetra
.687 .827 .95 r
.25169 .52454 .25825 .52846 .268 .5242 .26144 .52057 Mtetra
.704 .841 .948 r
.26144 .52057 .268 .5242 .27779 .51977 .27125 .51617 Mtetra
.725 .845 .938 r
.27125 .51617 .27779 .51977 .28762 .51519 .28113 .51125 Mtetra
.734 .834 .926 r
.28113 .51125 .28762 .51519 .29746 .51079 .29106 .50605 Mtetra
.737 .805 .906 r
.29106 .50605 .29746 .51079 .3073 .50682 .30102 .50068 Mtetra
.719 .757 .882 r
.30102 .50068 .3073 .50682 .31713 .50358 .31099 .49561 Mtetra
.689 .698 .853 r
.31099 .49561 .31713 .50358 .32693 .50138 .32093 .49122 Mtetra
.651 .636 .822 r
.32093 .49122 .32693 .50138 .33672 .5001 .33086 .48779 Mtetra
.61 .58 .795 r
.33086 .48779 .33672 .5001 .34651 .49974 .34074 .48563 Mtetra
.58 .539 .774 r
.34074 .48563 .34651 .49974 .35633 .49981 .35062 .48451 Mtetra
.555 .511 .762 r
.35062 .48451 .35633 .49981 .3662 .49994 .36049 .48433 Mtetra
.544 .502 .759 r
.36049 .48433 .3662 .49994 .37615 .49975 .37041 .48459 Mtetra
.542 .506 .766 r
.37041 .48459 .37615 .49975 .38618 .49889 .38038 .48489 Mtetra
.547 .525 .782 r
.38038 .48489 .38618 .49889 .39629 .49733 .39042 .48492 Mtetra
.562 .557 .806 r
.39042 .48492 .39629 .49733 .40648 .49502 .40054 .48438 Mtetra
.578 .598 .837 r
.40054 .48438 .40648 .49502 .41672 .49213 .41074 .48325 Mtetra
.598 .648 .871 r
.41074 .48325 .41672 .49213 .42703 .48878 .42101 .48147 Mtetra
.615 .7 .905 r
.42101 .48147 .42703 .48878 .43738 .48513 .43134 .47917 Mtetra
.628 .751 .935 r
.43134 .47917 .43738 .48513 .44777 .48131 .44173 .47643 Mtetra
.635 .794 .959 r
.44173 .47643 .44777 .48131 .4582 .47742 .45217 .47337 Mtetra
.634 .828 .975 r
.45217 .47337 .4582 .47742 .46866 .47355 .46266 .4701 Mtetra
.629 .852 .984 r
.46266 .4701 .46866 .47355 .47917 .46972 .47319 .4667 Mtetra
.621 .868 .989 r
.47319 .4667 .47917 .46972 .4897 .46598 .48376 .46325 Mtetra
.612 .877 .991 r
.48376 .46325 .4897 .46598 .50028 .46234 .49437 .45977 Mtetra
.603 .881 .992 r
.49437 .45977 .50028 .46234 .51089 .45882 .50502 .45631 Mtetra
.597 .882 .992 r
.50502 .45631 .51089 .45882 .52155 .4554 .51572 .45287 Mtetra
.594 .881 .992 r
.51572 .45287 .52155 .4554 .53225 .4521 .52646 .44946 Mtetra
.596 .878 .992 r
.52646 .44946 .53225 .4521 .54299 .4489 .53723 .44606 Mtetra
.603 .874 .992 r
.53723 .44606 .54299 .4489 .55377 .44581 .54805 .44264 Mtetra
.616 .866 .99 r
.54805 .44264 .55377 .44581 .5646 .44281 .55892 .43916 Mtetra
.634 .854 .983 r
.55892 .43916 .5646 .44281 .57548 .43986 .56982 .43555 Mtetra
.655 .834 .969 r
.56982 .43555 .57548 .43986 .5864 .43692 .58077 .43173 Mtetra
.676 .806 .945 r
.58077 .43173 .5864 .43692 .59737 .43391 .59175 .42759 Mtetra
.692 .771 .912 r
.59175 .42759 .59737 .43391 .60838 .43073 .60275 .42299 Mtetra
.702 .732 .873 r
.60275 .42299 .60838 .43073 .61943 .42726 .61378 .41786 Mtetra
.707 .693 .834 r
.61378 .41786 .61943 .42726 .63051 .42331 .62483 .41206 Mtetra
.706 .657 .799 r
.62483 .41206 .63051 .42331 .64161 .41876 .63588 .40565 Mtetra
.702 .627 .77 r
.63588 .40565 .64161 .41876 .65272 .41343 .64693 .39865 Mtetra
.695 .604 .75 r
.64693 .39865 .65272 .41343 .66382 .40739 .658 .39135 Mtetra
.687 .587 .738 r
.658 .39135 .66382 .40739 .67493 .40065 .66908 .38408 Mtetra
.677 .577 .735 r
.66908 .38408 .67493 .40065 .68604 .39357 .6802 .37725 Mtetra
.664 .572 .742 r
.6802 .37725 .68604 .39357 .69717 .38653 .6914 .37137 Mtetra
.651 .578 .759 r
.6914 .37137 .69717 .38653 .70835 .37992 .70269 .36655 Mtetra
.632 .591 .789 r
.70269 .36655 .70835 .37992 .71962 .37425 .71409 .36305 Mtetra
.614 .618 .831 r
.71409 .36305 .71962 .37425 .73097 .36953 .72561 .36053 Mtetra
.59 .657 .884 r
.72561 .36053 .73097 .36953 .74244 .36588 .73722 .35872 Mtetra
.565 .702 .933 r
.73722 .35872 .74244 .36588 .75401 .36298 .74893 .35722 Mtetra
.552 .749 .968 r
.74893 .35722 .75401 .36298 .76567 .36053 .76068 .35556 Mtetra
.55 .781 .984 r
.76068 .35556 .76567 .36053 .7774 .35827 .77247 .3536 Mtetra
.572 .804 .987 r
.77247 .3536 .7774 .35827 .78918 .35586 .78429 .35111 Mtetra
.597 .813 .982 r
.78429 .35111 .78918 .35586 .801 .35326 .79612 .34817 Mtetra
.624 .811 .972 r
.79612 .34817 .801 .35326 .81285 .35034 .80797 .34479 Mtetra
.643 .801 .959 r
.80797 .34479 .81285 .35034 .82473 .34719 .81985 .3411 Mtetra
.654 .786 .944 r
.81985 .3411 .82473 .34719 .83665 .34384 .83176 .3372 Mtetra
.659 .769 .931 r
.83176 .3372 .83665 .34384 .84861 .34035 .8437 .33321 Mtetra
.625 .743 .932 r
.20671 .53168 .21326 .53739 .22279 .53442 .21621 .52924 Mtetra
.62 .763 .947 r
.21621 .52924 .22279 .53442 .23237 .53135 .22575 .52682 Mtetra
.619 .788 .963 r
.22575 .52682 .23237 .53135 .242 .52809 .23534 .52428 Mtetra
.621 .818 .976 r
.23534 .52428 .242 .52809 .25169 .52454 .24499 .52152 Mtetra
.626 .852 .985 r
.24499 .52152 .25169 .52454 .26144 .52057 .2547 .51841 Mtetra
.64 .889 .985 r
.2547 .51841 .26144 .52057 .27125 .51617 .26449 .51475 Mtetra
.666 .92 .975 r
.26449 .51475 .27125 .51617 .28113 .51125 .27437 .51034 Mtetra
.699 .942 .961 r
.27437 .51034 .28113 .51125 .29106 .50605 .28433 .50515 Mtetra
.748 .947 .945 r
.28433 .50515 .29106 .50605 .30102 .50068 .29438 .49903 Mtetra
.778 .923 .932 r
.29438 .49903 .30102 .50068 .31099 .49561 .30449 .49239 Mtetra
.787 .865 .907 r
.30449 .49239 .31099 .49561 .32093 .49122 .31463 .48546 Mtetra
.758 .777 .869 r
.31463 .48546 .32093 .49122 .33086 .48779 .32476 .47898 Mtetra
.708 .687 .827 r
.32476 .47898 .33086 .48779 .34074 .48563 .33485 .47352 Mtetra
.657 .607 .787 r
.33485 .47352 .34074 .48563 .35062 .48451 .34489 .46942 Mtetra
.607 .543 .757 r
.34489 .46942 .35062 .48451 .36049 .48433 .35486 .46706 Mtetra
.573 .502 .737 r
.35486 .46706 .36049 .48433 .37041 .48459 .36482 .46606 Mtetra
.547 .476 .727 r
.36482 .46606 .37041 .48459 .38038 .48489 .37477 .46625 Mtetra
.534 .468 .728 r
.37477 .46625 .38038 .48489 .39042 .48492 .38476 .467 Mtetra
.531 .472 .735 r
.38476 .467 .39042 .48492 .40054 .48438 .39481 .46784 Mtetra
.535 .489 .751 r
.39481 .46784 .40054 .48438 .41074 .48325 .40493 .46844 Mtetra
.547 .516 .773 r
.40493 .46844 .41074 .48325 .42101 .48147 .41513 .46849 Mtetra
.561 .55 .799 r
.41513 .46849 .42101 .48147 .43134 .47917 .42542 .46794 Mtetra
.579 .59 .827 r
.42542 .46794 .43134 .47917 .44173 .47643 .43577 .46674 Mtetra
.596 .631 .856 r
.43577 .46674 .44173 .47643 .45217 .47337 .4462 .46499 Mtetra
.612 .671 .882 r
.4462 .46499 .45217 .47337 .46266 .4701 .45668 .46276 Mtetra
.625 .707 .905 r
.45668 .46276 .46266 .4701 .47319 .4667 .46722 .46016 Mtetra
.634 .737 .922 r
.46722 .46016 .47319 .4667 .48376 .46325 .47781 .45726 Mtetra
.641 .759 .934 r
.47781 .45726 .48376 .46325 .49437 .45977 .48844 .45413 Mtetra
.647 .775 .941 r
.48844 .45413 .49437 .45977 .50502 .45631 .49912 .45083 Mtetra
.652 .783 .944 r
.49912 .45083 .50502 .45631 .51572 .45287 .50985 .44736 Mtetra
.658 .785 .942 r
.50985 .44736 .51572 .45287 .52646 .44946 .52061 .44375 Mtetra
.666 .781 .935 r
.52061 .44375 .52646 .44946 .53723 .44606 .53142 .43995 Mtetra
.674 .77 .922 r
.53142 .43995 .53723 .44606 .54805 .44264 .54227 .43592 Mtetra
.684 .753 .904 r
.54227 .43592 .54805 .44264 .55892 .43916 .55315 .43159 Mtetra
.692 .731 .881 r
.55315 .43159 .55892 .43916 .56982 .43555 .56407 .42688 Mtetra
.699 .705 .852 r
.56407 .42688 .56982 .43555 .58077 .43173 .57501 .42168 Mtetra
.702 .676 .822 r
.57501 .42168 .58077 .43173 .59175 .42759 .58598 .41591 Mtetra
.703 .648 .792 r
.58598 .41591 .59175 .42759 .60275 .42299 .59696 .40948 Mtetra
.7 .621 .765 r
.59696 .40948 .60275 .42299 .61378 .41786 .60795 .40243 Mtetra
.696 .597 .742 r
.60795 .40243 .61378 .41786 .62483 .41206 .61894 .3948 Mtetra
.688 .576 .724 r
.61894 .3948 .62483 .41206 .63588 .40565 .62995 .38691 Mtetra
.679 .56 .713 r
.62995 .38691 .63588 .40565 .64693 .39865 .64096 .3791 Mtetra
.667 .548 .709 r
.64096 .3791 .64693 .39865 .658 .39135 .65202 .37185 Mtetra
.651 .539 .714 r
.65202 .37185 .658 .39135 .66908 .38408 .66315 .36579 Mtetra
.635 .539 .728 r
.66315 .36579 .66908 .38408 .6802 .37725 .67437 .36113 Mtetra
.611 .545 .756 r
.67437 .36113 .6802 .37725 .6914 .37137 .68572 .35826 Mtetra
.584 .569 .803 r
.68572 .35826 .6914 .37137 .70269 .36655 .69721 .35679 Mtetra
.542 .613 .874 r
.69721 .35679 .70269 .36655 .71409 .36305 .70881 .35638 Mtetra
.477 .676 .952 r
.70881 .35638 .71409 .36305 .72561 .36053 .72052 .35643 Mtetra
.396 .74 .992 r
.72052 .35643 .72561 .36053 .73722 .35872 .73228 .3562 Mtetra
.332 .767 .969 r
.73228 .3562 .73722 .35872 .74893 .35722 .74408 .35544 Mtetra
.358 .805 .95 r
.74408 .35544 .74893 .35722 .76068 .35556 .75588 .35373 Mtetra
.434 .847 .964 r
.75588 .35373 .76068 .35556 .77247 .3536 .76768 .3512 Mtetra
.533 .879 .987 r
.76768 .3512 .77247 .3536 .78429 .35111 .77948 .34789 Mtetra
.607 .881 .991 r
.77948 .34789 .78429 .35111 .79612 .34817 .79129 .344 Mtetra
.65 .86 .98 r
.79129 .344 .79612 .34817 .80797 .34479 .80311 .33975 Mtetra
.672 .834 .961 r
.80311 .33975 .80797 .34479 .81985 .3411 .81495 .33525 Mtetra
.68 .807 .943 r
.81495 .33525 .81985 .3411 .83176 .3372 .82683 .33063 Mtetra
.681 .782 .927 r
.82683 .33063 .83176 .3372 .8437 .33321 .83876 .32602 Mtetra
.611 .739 .937 r
.20012 .52592 .20671 .53168 .21621 .52924 .20961 .52374 Mtetra
.602 .747 .946 r
.20961 .52374 .21621 .52924 .22575 .52682 .21914 .52167 Mtetra
.596 .759 .957 r
.21914 .52167 .22575 .52682 .23534 .52428 .2287 .51964 Mtetra
.59 .778 .969 r
.2287 .51964 .23534 .52428 .24499 .52152 .23831 .51757 Mtetra
.579 .803 .985 r
.23831 .51757 .24499 .52152 .2547 .51841 .24796 .51543 Mtetra
.574 .841 .995 r
.24796 .51543 .2547 .51841 .26449 .51475 .25769 .51298 Mtetra
.565 .883 .991 r
.25769 .51298 .26449 .51475 .27437 .51034 .26749 .51002 Mtetra
.552 .916 .952 r
.26749 .51002 .27437 .51034 .28433 .50515 .27738 .50628 Mtetra
.546 .929 .881 r
.27738 .50628 .28433 .50515 .29438 .49903 .28739 .50146 Mtetra
.534 .919 .797 r
.28739 .50146 .29438 .49903 .30449 .49239 .2975 .49559 Mtetra
.571 .928 .758 r
.2975 .49559 .30449 .49239 .31463 .48546 .3077 .48859 Mtetra
.627 .953 .777 r
.3077 .48859 .31463 .48546 .32476 .47898 .31795 .48099 Mtetra
.719 .988 .85 r
.31795 .48099 .32476 .47898 .33485 .47352 .32823 .47318 Mtetra
.782 .967 .921 r
.32823 .47318 .33485 .47352 .34489 .46942 .33849 .46586 Mtetra
.765 .859 .92 r
.33849 .46586 .34489 .46942 .35486 .46706 .34871 .45962 Mtetra
.705 .722 .863 r
.34871 .45962 .35486 .46706 .36482 .46606 .35887 .45467 Mtetra
.643 .614 .806 r
.35887 .45467 .36482 .46606 .37477 .46625 .369 .45128 Mtetra
.602 .543 .761 r
.369 .45128 .37477 .46625 .38476 .467 .3791 .44912 Mtetra
.575 .499 .732 r
.3791 .44912 .38476 .467 .39481 .46784 .38921 .44799 Mtetra
.561 .476 .716 r
.38921 .44799 .39481 .46784 .40493 .46844 .39935 .44744 Mtetra
.557 .466 .707 r
.39935 .44744 .40493 .46844 .41513 .46849 .40954 .44713 Mtetra
.557 .464 .705 r
.40954 .44713 .41513 .46849 .42542 .46794 .41979 .44679 Mtetra
.562 .469 .707 r
.41979 .44679 .42542 .46794 .43577 .46674 .4301 .44617 Mtetra
.569 .477 .711 r
.4301 .44617 .43577 .46674 .4462 .46499 .44048 .44519 Mtetra
.578 .489 .717 r
.44048 .44519 .4462 .46499 .45668 .46276 .45092 .44377 Mtetra
.587 .5 .724 r
.45092 .44377 .45668 .46276 .46722 .46016 .46143 .44191 Mtetra
.597 .512 .73 r
.46143 .44191 .46722 .46016 .47781 .45726 .472 .4396 Mtetra
.605 .523 .735 r
.472 .4396 .47781 .45726 .48844 .45413 .48262 .43689 Mtetra
.614 .532 .738 r
.48262 .43689 .48844 .45413 .49912 .45083 .49329 .43378 Mtetra
.621 .538 .739 r
.49329 .43378 .49912 .45083 .50985 .44736 .504 .43028 Mtetra
.628 .542 .738 r
.504 .43028 .50985 .44736 .52061 .44375 .51476 .4264 Mtetra
.634 .543 .735 r
.51476 .4264 .52061 .44375 .53142 .43995 .52556 .42212 Mtetra
.639 .542 .729 r
.52556 .42212 .53142 .43995 .54227 .43592 .5364 .41742 Mtetra
.643 .54 .722 r
.5364 .41742 .54227 .43592 .55315 .43159 .54727 .41227 Mtetra
.646 .536 .715 r
.54727 .41227 .55315 .43159 .56407 .42688 .55816 .40667 Mtetra
.649 .532 .707 r
.55816 .40667 .56407 .42688 .57501 .42168 .56908 .40062 Mtetra
.65 .527 .7 r
.56908 .40062 .57501 .42168 .58598 .41591 .58002 .39419 Mtetra
.651 .524 .696 r
.58002 .39419 .58598 .41591 .59696 .40948 .59098 .38747 Mtetra
.651 .522 .694 r
.59098 .38747 .59696 .40948 .60795 .40243 .60196 .3807 Mtetra
.649 .523 .696 r
.60196 .3807 .60795 .40243 .61894 .3948 .61296 .37417 Mtetra
.645 .527 .705 r
.61296 .37417 .61894 .3948 .62995 .38691 .62401 .36821 Mtetra
.637 .536 .723 r
.62401 .36821 .62995 .38691 .64096 .3791 .63513 .36331 Mtetra
.627 .557 .756 r
.63513 .36331 .64096 .3791 .65202 .37185 .64633 .35966 Mtetra
.6 .592 .815 r
.64633 .35966 .65202 .37185 .66315 .36579 .65764 .35759 Mtetra
.541 .656 .91 r
.65764 .35759 .66315 .36579 .67437 .36113 .66907 .35686 Mtetra
.354 .709 .985 r
.66907 .35686 .67437 .36113 .68572 .35826 .68062 .35725 Mtetra
.008 .577 .779 r
.68062 .35725 .68572 .35826 .69721 .35679 .69228 .35816 Mtetra
.194 0 0 r
.69228 .35816 .69721 .35679 .70881 .35638 .70401 .35886 Mtetra
.224 0 0 r
.70401 .35886 .70881 .35638 .72052 .35643 .71578 .35897 Mtetra
.133 0 0 r
.71578 .35897 .72052 .35643 .73228 .3562 .72755 .35791 Mtetra
0 0 0 r
.72755 .35791 .73228 .3562 .74408 .35544 .73932 .35576 Mtetra
.298 .794 .804 r
.73932 .35576 .74408 .35544 .75588 .35373 .75107 .35249 Mtetra
.515 .902 .945 r
.75107 .35249 .75588 .35373 .76768 .3512 .76281 .34841 Mtetra
.634 .908 .983 r
.76281 .34841 .76768 .3512 .77948 .34789 .77456 .3438 Mtetra
.681 .875 .971 r
.77456 .3438 .77948 .34789 .79129 .344 .78633 .33885 Mtetra
.693 .838 .952 r
.78633 .33885 .79129 .344 .80311 .33975 .79813 .33382 Mtetra
.697 .81 .936 r
.79813 .33382 .80311 .33975 .81495 .33525 .80996 .32875 Mtetra
.695 .79 .924 r
.80996 .32875 .81495 .33525 .82683 .33063 .82185 .3237 Mtetra
.69 .775 .916 r
.82185 .3237 .82683 .33063 .83876 .32602 .83378 .31877 Mtetra
.617 .741 .935 r
.19348 .52013 .20012 .52592 .20961 .52374 .203 .51782 Mtetra
.609 .735 .935 r
.203 .51782 .20961 .52374 .21914 .52167 .21255 .51567 Mtetra
.599 .73 .936 r
.21255 .51567 .21914 .52167 .2287 .51964 .22212 .51371 Mtetra
.586 .729 .942 r
.22212 .51371 .2287 .51964 .23831 .51757 .23172 .51197 Mtetra
.563 .734 .956 r
.23172 .51197 .23831 .51757 .24796 .51543 .24133 .51053 Mtetra
.538 .753 .976 r
.24133 .51053 .24796 .51543 .25769 .51298 .25098 .50924 Mtetra
.491 .784 .997 r
.25098 .50924 .25769 .51298 .26749 .51002 .26067 .50806 Mtetra
.418 .818 .982 r
.26067 .50806 .26749 .51002 .27738 .50628 .27042 .50657 Mtetra
.279 .781 .841 r
.27042 .50657 .27738 .50628 .28739 .50146 .28027 .50451 Mtetra
0 0 0 r
.28027 .50451 .28739 .50146 .2975 .49559 .29024 .50138 Mtetra
.29024 .50138 .2975 .49559 .3077 .48859 .30034 .49669 Mtetra
.30034 .49669 .3077 .48859 .31795 .48099 .31059 .49037 Mtetra
.31059 .49037 .31795 .48099 .32823 .47318 .32096 .48222 Mtetra
.32096 .48222 .32823 .47318 .33849 .46586 .33141 .47293 Mtetra
.33141 .47293 .33849 .46586 .34871 .45962 .3419 .46298 Mtetra
.738 .985 .774 r
.3419 .46298 .34871 .45962 .35887 .45467 .35238 .45331 Mtetra
.831 .934 .897 r
.35238 .45331 .35887 .45467 .369 .45128 .3628 .44468 Mtetra
.765 .762 .849 r
.3628 .44468 .369 .45128 .3791 .44912 .37316 .43745 Mtetra
.687 .631 .788 r
.37316 .43745 .3791 .44912 .38921 .44799 .38346 .43196 Mtetra
.636 .552 .743 r
.38346 .43196 .38921 .44799 .39935 .44744 .39373 .42792 Mtetra
.602 .504 .715 r
.39373 .42792 .39935 .44744 .40954 .44713 .40398 .42517 Mtetra
.583 .477 .698 r
.40398 .42517 .40954 .44713 .41979 .44679 .41425 .42325 Mtetra
.573 .462 .689 r
.41425 .42325 .41979 .44679 .4301 .44617 .42455 .42181 Mtetra
.57 .456 .684 r
.42455 .42181 .4301 .44617 .44048 .44519 .4349 .42052 Mtetra
.572 .456 .683 r
.4349 .42052 .44048 .44519 .45092 .44377 .44531 .41912 Mtetra
.575 .459 .683 r
.44531 .41912 .45092 .44377 .46143 .44191 .45578 .41747 Mtetra
.582 .464 .684 r
.45578 .41747 .46143 .44191 .472 .4396 .46631 .41541 Mtetra
.588 .47 .685 r
.46631 .41541 .472 .4396 .48262 .43689 .47689 .41289 Mtetra
.596 .476 .686 r
.47689 .41289 .48262 .43689 .49329 .43378 .48753 .40987 Mtetra
.603 .481 .686 r
.48753 .40987 .49329 .43378 .504 .43028 .49821 .40634 Mtetra
.61 .486 .686 r
.49821 .40634 .504 .43028 .51476 .4264 .50894 .40228 Mtetra
.616 .489 .684 r
.50894 .40228 .51476 .4264 .52556 .42212 .51971 .39772 Mtetra
.621 .491 .682 r
.51971 .39772 .52556 .42212 .5364 .41742 .53052 .39269 Mtetra
.625 .492 .68 r
.53052 .39269 .5364 .41742 .54727 .41227 .54135 .38725 Mtetra
.628 .493 .678 r
.54135 .38725 .54727 .41227 .55816 .40667 .55222 .38155 Mtetra
.629 .493 .677 r
.55222 .38155 .55816 .40667 .56908 .40062 .56311 .37572 Mtetra
.628 .493 .679 r
.56311 .37572 .56908 .40062 .58002 .39419 .57403 .37005 Mtetra
.624 .494 .684 r
.57403 .37005 .58002 .39419 .59098 .38747 .58499 .36485 Mtetra
.617 .498 .695 r
.58499 .36485 .59098 .38747 .60196 .3807 .59601 .36049 Mtetra
.603 .504 .715 r
.59601 .36049 .60196 .3807 .61296 .37417 .60709 .35743 Mtetra
.582 .521 .752 r
.60709 .35743 .61296 .37417 .62401 .36821 .61827 .35586 Mtetra
.531 .553 .822 r
.61827 .35586 .62401 .36821 .63513 .36331 .62957 .35607 Mtetra
.39 .609 .937 r
.62957 .35607 .63513 .36331 .64633 .35966 .64099 .35772 Mtetra
0 .474 .764 r
.64099 .35772 .64633 .35966 .65764 .35759 .65254 .36046 Mtetra
.439 0 0 r
.65254 .36046 .65764 .35759 .66907 .35686 .6642 .36351 Mtetra
.484 0 .032 r
.6642 .36351 .66907 .35686 .68062 .35725 .67592 .3659 Mtetra
.465 .015 .096 r
.67592 .3659 .68062 .35725 .69228 .35816 .68768 .36714 Mtetra
.402 0 .078 r
.68768 .36714 .69228 .35816 .70401 .35886 .69942 .3665 Mtetra
.299 0 0 r
.69942 .3665 .70401 .35886 .71578 .35897 .71113 .36417 Mtetra
.094 0 0 r
.71113 .36417 .71578 .35897 .72755 .35791 .7228 .36025 Mtetra
0 0 0 r
.7228 .36025 .72755 .35791 .73932 .35576 .73444 .3552 Mtetra
.585 .942 .91 r
.73444 .3552 .73932 .35576 .75107 .35249 .74609 .34954 Mtetra
.708 .925 .964 r
.74609 .34954 .75107 .35249 .76281 .34841 .75774 .34357 Mtetra
.725 .858 .945 r
.75774 .34357 .76281 .34841 .77456 .3438 .76944 .33769 Mtetra
.719 .811 .922 r
.76944 .33769 .77456 .3438 .78633 .33885 .78118 .33196 Mtetra
.707 .781 .91 r
.78118 .33196 .78633 .33885 .79813 .33382 .79299 .32653 Mtetra
.698 .766 .904 r
.79299 .32653 .79813 .33382 .80996 .32875 .80486 .32133 Mtetra
.691 .76 .905 r
.80486 .32133 .80996 .32875 .82185 .3237 .81678 .31632 Mtetra
.686 .76 .908 r
.81678 .31632 .82185 .3237 .83378 .31877 .82876 .31146 Mtetra
.644 .748 .925 r
.18679 .51429 .19348 .52013 .203 .51782 .19639 .51139 Mtetra
.639 .728 .912 r
.19639 .51139 .203 .51782 .21255 .51567 .20602 .5086 Mtetra
.63 .705 .9 r
.20602 .5086 .21255 .51567 .22212 .51371 .21566 .50605 Mtetra
.616 .684 .891 r
.21566 .50605 .22212 .51371 .23172 .51197 .22531 .50382 Mtetra
.597 .664 .885 r
.22531 .50382 .23172 .51197 .24133 .51053 .23496 .50206 Mtetra
.578 .648 .883 r
.23496 .50206 .24133 .51053 .25098 .50924 .24462 .50076 Mtetra
.553 .638 .888 r
.24462 .50076 .25098 .50924 .26067 .50806 .25428 .49999 Mtetra
.534 .642 .903 r
.25428 .49999 .26067 .50806 .27042 .50657 .26397 .49953 Mtetra
.509 .665 .932 r
.26397 .49953 .27042 .50657 .28027 .50451 .27369 .49925 Mtetra
.491 .725 .975 r
.27369 .49925 .28027 .50451 .29024 .50138 .2835 .49864 Mtetra
.448 .808 .996 r
.2835 .49864 .29024 .50138 .30034 .49669 .29341 .49729 Mtetra
.314 .805 .836 r
.29341 .49729 .30034 .49669 .31059 .49037 .30345 .49468 Mtetra
0 0 0 r
.30345 .49468 .31059 .49037 .32096 .48222 .31365 .49033 Mtetra
.001 0 0 r
.31365 .49033 .32096 .48222 .33141 .47293 .32398 .48431 Mtetra
.054 0 0 r
.32398 .48431 .33141 .47293 .3419 .46298 .33443 .47655 Mtetra
.088 0 .028 r
.33443 .47655 .3419 .46298 .35238 .45331 .34495 .46774 Mtetra
.092 0 .049 r
.34495 .46774 .35238 .45331 .3628 .44468 .3555 .45836 Mtetra
.072 0 .025 r
.3555 .45836 .3628 .44468 .37316 .43745 .36606 .44909 Mtetra
.023 0 0 r
.36606 .44909 .37316 .43745 .38346 .43196 .37658 .44046 Mtetra
0 0 0 r
.37658 .44046 .38346 .43196 .39373 .42792 .38708 .4327 Mtetra
.38708 .4327 .39373 .42792 .40398 .42517 .39754 .42603 Mtetra
.605 .953 .887 r
.39754 .42603 .40398 .42517 .41425 .42325 .40799 .42031 Mtetra
.7 .888 .967 r
.40799 .42031 .41425 .42325 .42455 .42181 .41844 .41546 Mtetra
.685 .759 .908 r
.41844 .41546 .42455 .42181 .4349 .42052 .4289 .41123 Mtetra
.659 .669 .849 r
.4289 .41123 .4349 .42052 .44531 .41912 .43938 .40746 Mtetra
.641 .615 .808 r
.43938 .40746 .44531 .41912 .45578 .41747 .4499 .40394 Mtetra
.631 .582 .781 r
.4499 .40394 .45578 .41747 .46631 .41541 .46045 .40054 Mtetra
.626 .563 .763 r
.46045 .40054 .46631 .41541 .47689 .41289 .47104 .39714 Mtetra
.624 .552 .753 r
.47104 .39714 .47689 .41289 .48753 .40987 .48168 .39367 Mtetra
.624 .548 .748 r
.48168 .39367 .48753 .40987 .49821 .40634 .49236 .3901 Mtetra
.626 .549 .748 r
.49236 .3901 .49821 .40634 .50894 .40228 .50309 .38643 Mtetra
.629 .555 .752 r
.50309 .38643 .50894 .40228 .51971 .39772 .51385 .38268 Mtetra
.631 .566 .762 r
.51385 .38268 .51971 .39772 .53052 .39269 .52466 .37895 Mtetra
.634 .583 .78 r
.52466 .37895 .53052 .39269 .54135 .38725 .53551 .37532 Mtetra
.635 .611 .809 r
.53551 .37532 .54135 .38725 .55222 .38155 .5464 .37195 Mtetra
.629 .656 .858 r
.5464 .37195 .55222 .38155 .56311 .37572 .55735 .36904 Mtetra
.599 .729 .936 r
.55735 .36904 .56311 .37572 .57403 .37005 .56835 .36676 Mtetra
.452 .8 .998 r
.56835 .36676 .57403 .37005 .58499 .36485 .57942 .36537 Mtetra
.006 0 0 r
.57942 .36537 .58499 .36485 .59601 .36049 .59057 .36495 Mtetra
.361 0 0 r
.59057 .36495 .59601 .36049 .60709 .35743 .60182 .36565 Mtetra
.475 .02 .091 r
.60182 .36565 .60709 .35743 .61827 .35586 .61316 .36726 Mtetra
.515 .102 .196 r
.61316 .36726 .61827 .35586 .62957 .35607 .62461 .36954 Mtetra
.524 .131 .239 r
.62461 .36954 .62957 .35607 .64099 .35772 .63616 .37195 Mtetra
.513 .127 .246 r
.63616 .37195 .64099 .35772 .65254 .36046 .64777 .37379 Mtetra
.484 .091 .219 r
.64777 .37379 .65254 .36046 .6642 .36351 .65943 .37457 Mtetra
.416 .001 .141 r
.65943 .37457 .6642 .36351 .67592 .3659 .67109 .37358 Mtetra
.277 0 0 r
.67109 .37358 .67592 .3659 .68768 .36714 .68273 .37087 Mtetra
0 0 0 r
.68273 .37087 .68768 .36714 .69942 .3665 .69433 .36636 Mtetra
.574 .94 .891 r
.69433 .36636 .69942 .3665 .71113 .36417 .7059 .36055 Mtetra
.746 .906 .948 r
.7059 .36055 .71113 .36417 .7228 .36025 .71746 .35396 Mtetra
.755 .812 .898 r
.71746 .35396 .7228 .36025 .73444 .3552 .72902 .34701 Mtetra
.736 .75 .863 r
.72902 .34701 .73444 .3552 .74609 .34954 .74062 .34023 Mtetra
.72 .716 .846 r
.74062 .34023 .74609 .34954 .75774 .34357 .75227 .33377 Mtetra
.703 .699 .843 r
.75227 .33377 .75774 .34357 .76944 .33769 .764 .32785 Mtetra
.691 .694 .847 r
.764 .32785 .76944 .33769 .78118 .33196 .77579 .32239 Mtetra
.681 .696 .858 r
.77579 .32239 .78118 .33196 .79299 .32653 .78767 .31742 Mtetra
.673 .705 .871 r
.78767 .31742 .79299 .32653 .80486 .32133 .79962 .31279 Mtetra
.668 .719 .887 r
.79962 .31279 .80486 .32133 .81678 .31632 .81163 .30838 Mtetra
.665 .736 .903 r
.81163 .30838 .81678 .31632 .82876 .31146 .82371 .3041 Mtetra
.679 .757 .91 r
.18006 .50842 .18679 .51429 .19639 .51139 .18977 .50464 Mtetra
.675 .729 .89 r
.18977 .50464 .19639 .51139 .20602 .5086 .1995 .5009 Mtetra
.666 .699 .872 r
.1995 .5009 .20602 .5086 .21566 .50605 .20925 .49731 Mtetra
.652 .669 .853 r
.20925 .49731 .21566 .50605 .22531 .50382 .21901 .49399 Mtetra
.636 .639 .836 r
.21901 .49399 .22531 .50382 .23496 .50206 .22877 .49107 Mtetra
.616 .608 .82 r
.22877 .49107 .23496 .50206 .24462 .50076 .23852 .48869 Mtetra
.594 .579 .806 r
.23852 .48869 .24462 .50076 .25428 .49999 .24826 .487 Mtetra
.57 .552 .795 r
.24826 .487 .25428 .49999 .26397 .49953 .25798 .48607 Mtetra
.542 .531 .792 r
.25798 .48607 .26397 .49953 .27369 .49925 .26768 .48604 Mtetra
.515 .52 .8 r
.26768 .48604 .27369 .49925 .2835 .49864 .27738 .48676 Mtetra
.476 .524 .827 r
.27738 .48676 .2835 .49864 .29341 .49729 .28709 .4882 Mtetra
.426 .565 .89 r
.28709 .4882 .29341 .49729 .30345 .49468 .29685 .48982 Mtetra
.274 .639 .965 r
.29685 .48982 .30345 .49468 .31365 .49033 .3067 .49121 Mtetra
.136 0 0 r
.3067 .49121 .31365 .49033 .32398 .48431 .31667 .49158 Mtetra
.321 0 0 r
.31667 .49158 .32398 .48431 .33443 .47655 .32682 .49023 Mtetra
.352 0 .165 r
.32682 .49023 .33443 .47655 .34495 .46774 .33712 .48684 Mtetra
.341 .003 .238 r
.33712 .48684 .34495 .46774 .3555 .45836 .3476 .48106 Mtetra
.329 .012 .267 r
.3476 .48106 .3555 .45836 .36606 .44909 .35819 .47342 Mtetra
.308 .002 .272 r
.35819 .47342 .36606 .44909 .37658 .44046 .36887 .46427 Mtetra
.284 0 .259 r
.36887 .46427 .37658 .44046 .38708 .4327 .37959 .45441 Mtetra
.252 0 .228 r
.37959 .45441 .38708 .4327 .39754 .42603 .39031 .44446 Mtetra
.206 0 .172 r
.39031 .44446 .39754 .42603 .40799 .42031 .40101 .43488 Mtetra
.14 0 .08 r
.40101 .43488 .40799 .42031 .41844 .41546 .41169 .42605 Mtetra
.028 0 0 r
.41169 .42605 .41844 .41546 .4289 .41123 .42235 .41807 Mtetra
0 0 0 r
.42235 .41807 .4289 .41123 .43938 .40746 .43299 .41101 Mtetra
.378 .807 .633 r
.43299 .41101 .43938 .40746 .4499 .40394 .44363 .40478 Mtetra
.562 .936 .874 r
.44363 .40478 .4499 .40394 .46045 .40054 .45428 .39932 Mtetra
.636 .935 .966 r
.45428 .39932 .46045 .40054 .47104 .39714 .46495 .39454 Mtetra
.644 .895 .984 r
.46495 .39454 .47104 .39714 .48168 .39367 .47563 .39037 Mtetra
.626 .864 .987 r
.47563 .39037 .48168 .39367 .49236 .3901 .48635 .38678 Mtetra
.588 .852 .994 r
.48635 .38678 .49236 .3901 .50309 .38643 .49711 .38376 Mtetra
.512 .848 .997 r
.49711 .38376 .50309 .38643 .51385 .38268 .50791 .38136 Mtetra
.347 .806 .937 r
.50791 .38136 .51385 .38268 .52466 .37895 .51876 .37964 Mtetra
0 0 0 r
.51876 .37964 .52466 .37895 .53551 .37532 .52967 .37871 Mtetra
.26 0 0 r
.52967 .37871 .53551 .37532 .5464 .37195 .54064 .37862 Mtetra
.424 0 .004 r
.54064 .37862 .5464 .37195 .55735 .36904 .55169 .37949 Mtetra
.496 .073 .166 r
.55169 .37949 .55735 .36904 .56835 .36676 .56282 .38121 Mtetra
.528 .145 .257 r
.56282 .38121 .56835 .36676 .57942 .36537 .57405 .38373 Mtetra
.54 .182 .309 r
.57405 .38373 .57942 .36537 .59057 .36495 .58538 .38664 Mtetra
.539 .198 .338 r
.58538 .38664 .59057 .36495 .60182 .36565 .5968 .38948 Mtetra
.53 .198 .35 r
.5968 .38948 .60182 .36565 .61316 .36726 .60829 .39163 Mtetra
.509 .181 .346 r
.60829 .39163 .61316 .36726 .62461 .36954 .61982 .39224 Mtetra
.476 .144 .325 r
.61982 .39224 .62461 .36954 .63616 .37195 .63137 .39096 Mtetra
.411 .068 .27 r
.63137 .39096 .63616 .37195 .64777 .37379 .6429 .38724 Mtetra
.283 0 .139 r
.6429 .38724 .64777 .37379 .65943 .37457 .65439 .38141 Mtetra
0 0 0 r
.65439 .38141 .65943 .37457 .67109 .37358 .66584 .37382 Mtetra
.732 .991 .861 r
.66584 .37382 .67109 .37358 .68273 .37087 .67725 .36514 Mtetra
.807 .838 .874 r
.67725 .36514 .68273 .37087 .69433 .36636 .68866 .35621 Mtetra
.758 .711 .808 r
.68866 .35621 .69433 .36636 .7059 .36055 .7001 .34745 Mtetra
.718 .645 .775 r
.7001 .34745 .7059 .36055 .71746 .35396 .71159 .33941 Mtetra
.695 .615 .763 r
.71159 .33941 .71746 .35396 .72902 .34701 .72314 .33214 Mtetra
.677 .602 .764 r
.72314 .33214 .72902 .34701 .74062 .34023 .73478 .32579 Mtetra
.665 .602 .774 r
.73478 .32579 .74062 .34023 .75227 .33377 .74651 .32022 Mtetra
.656 .61 .79 r
.74651 .32022 .75227 .33377 .764 .32785 .75833 .31536 Mtetra
.649 .623 .81 r
.75833 .31536 .764 .32785 .77579 .32239 .77023 .31106 Mtetra
.644 .642 .833 r
.77023 .31106 .77579 .32239 .78767 .31742 .78222 .30716 Mtetra
.639 .663 .857 r
.78222 .30716 .78767 .31742 .79962 .31279 .79428 .30355 Mtetra
.636 .688 .881 r
.79428 .30355 .79962 .31279 .81163 .30838 .80642 .3001 Mtetra
.635 .714 .904 r
.80642 .3001 .81163 .30838 .82371 .3041 .81861 .29669 Mtetra
.703 .761 .898 r
.17328 .5025 .18006 .50842 .18977 .50464 .18308 .49801 Mtetra
.7 .739 .881 r
.18308 .49801 .18977 .50464 .1995 .5009 .19291 .49347 Mtetra
.695 .716 .865 r
.19291 .49347 .1995 .5009 .20925 .49731 .20277 .48895 Mtetra
.685 .69 .849 r
.20277 .48895 .20925 .49731 .21901 .49399 .21265 .48455 Mtetra
.674 .662 .831 r
.21265 .48455 .21901 .49399 .22877 .49107 .22253 .48034 Mtetra
.657 .631 .812 r
.22253 .48034 .22877 .49107 .23852 .48869 .23242 .47649 Mtetra
.637 .598 .794 r
.23242 .47649 .23852 .48869 .24826 .487 .24229 .47317 Mtetra
.613 .564 .775 r
.24229 .47317 .24826 .487 .25798 .48607 .25214 .47056 Mtetra
.587 .53 .758 r
.25214 .47056 .25798 .48607 .26768 .48604 .26196 .46888 Mtetra
.561 .498 .742 r
.26196 .46888 .26768 .48604 .27738 .48676 .27175 .46822 Mtetra
.533 .469 .73 r
.27175 .46822 .27738 .48676 .28709 .4882 .2815 .46873 Mtetra
.511 .448 .722 r
.2815 .46873 .28709 .4882 .29685 .48982 .29125 .47016 Mtetra
.492 .435 .721 r
.29125 .47016 .29685 .48982 .3067 .49121 .30101 .47238 Mtetra
.485 .438 .73 r
.30101 .47238 .3067 .49121 .31667 .49158 .31083 .47474 Mtetra
.487 .46 .753 r
.31083 .47474 .31667 .49158 .32682 .49023 .32075 .47674 Mtetra
.503 .514 .801 r
.32075 .47674 .32682 .49023 .33712 .48684 .3308 .47776 Mtetra
.537 .624 .886 r
.3308 .47776 .33712 .48684 .3476 .48106 .341 .47729 Mtetra
.542 .812 .996 r
.341 .47729 .3476 .48106 .35819 .47342 .35134 .47526 Mtetra
.299 .788 .74 r
.35134 .47526 .35819 .47342 .36887 .46427 .36181 .47157 Mtetra
.053 0 0 r
.36181 .47157 .36887 .46427 .37959 .45441 .37238 .46662 Mtetra
.205 0 .054 r
.37238 .46662 .37959 .45441 .39031 .44446 .38302 .4607 Mtetra
.278 0 .17 r
.38302 .4607 .39031 .44446 .40101 .43488 .39371 .45425 Mtetra
.322 0 .231 r
.39371 .45425 .40101 .43488 .41169 .42605 .40442 .44764 Mtetra
.35 .025 .266 r
.40442 .44764 .41169 .42605 .42235 .41807 .41516 .44112 Mtetra
.372 .052 .288 r
.41516 .44112 .42235 .41807 .43299 .41101 .4259 .43492 Mtetra
.388 .071 .302 r
.4259 .43492 .43299 .41101 .44363 .40478 .43666 .42914 Mtetra
.403 .086 .311 r
.43666 .42914 .44363 .40478 .45428 .39932 .44743 .42387 Mtetra
.415 .098 .317 r
.44743 .42387 .45428 .39932 .46495 .39454 .45823 .41914 Mtetra
.427 .109 .322 r
.45823 .41914 .46495 .39454 .47563 .39037 .46905 .41498 Mtetra
.438 .119 .326 r
.46905 .41498 .47563 .39037 .48635 .38678 .4799 .41139 Mtetra
.449 .128 .329 r
.4799 .41139 .48635 .38678 .49711 .38376 .49079 .40837 Mtetra
.459 .137 .333 r
.49079 .40837 .49711 .38376 .50791 .38136 .50172 .40591 Mtetra
.468 .145 .335 r
.50172 .40591 .50791 .38136 .51876 .37964 .5127 .40401 Mtetra
.476 .152 .337 r
.5127 .40401 .51876 .37964 .52967 .37871 .52373 .40262 Mtetra
.482 .155 .335 r
.52373 .40262 .52967 .37871 .54064 .37862 .53483 .40167 Mtetra
.486 .154 .33 r
.53483 .40167 .54064 .37862 .55169 .37949 .546 .40105 Mtetra
.484 .146 .317 r
.546 .40105 .55169 .37949 .56282 .38121 .55723 .40054 Mtetra
.474 .124 .293 r
.55723 .40054 .56282 .38121 .57405 .38373 .56852 .39986 Mtetra
.447 .079 .244 r
.56852 .39986 .57405 .38373 .58538 .38664 .57988 .39867 Mtetra
.381 0 .142 r
.57988 .39867 .58538 .38664 .5968 .38948 .59128 .39649 Mtetra
.194 0 0 r
.59128 .39649 .5968 .38948 .60829 .39163 .60271 .39303 Mtetra
.406 .853 .771 r
.60271 .39303 .60829 .39163 .61982 .39224 .61414 .38787 Mtetra
.758 .873 .931 r
.61414 .38787 .61982 .39224 .63137 .39096 .62555 .3811 Mtetra
.752 .712 .815 r
.62555 .3811 .63137 .39096 .6429 .38724 .63694 .37279 Mtetra
.727 .631 .751 r
.63694 .37279 .6429 .38724 .65439 .38141 .6483 .36346 Mtetra
.707 .587 .718 r
.6483 .36346 .65439 .38141 .66584 .37382 .65966 .35373 Mtetra
.693 .563 .704 r
.65966 .35373 .66584 .37382 .67725 .36514 .67102 .34413 Mtetra
.678 .548 .7 r
.67102 .34413 .67725 .36514 .68866 .35621 .68243 .33532 Mtetra
.667 .543 .704 r
.68243 .33532 .68866 .35621 .7001 .34745 .69391 .32745 Mtetra
.655 .542 .714 r
.69391 .32745 .7001 .34745 .71159 .33941 .70547 .32078 Mtetra
.646 .547 .729 r
.70547 .32078 .71159 .33941 .72314 .33214 .71712 .31514 Mtetra
.637 .557 .748 r
.71712 .31514 .72314 .33214 .73478 .32579 .72887 .31046 Mtetra
.629 .572 .771 r
.72887 .31046 .73478 .32579 .74651 .32022 .74072 .30653 Mtetra
.623 .591 .797 r
.74072 .30653 .74651 .32022 .75833 .31536 .75266 .30313 Mtetra
.618 .613 .823 r
.75266 .30313 .75833 .31536 .77023 .31106 .76468 .30012 Mtetra
.615 .637 .849 r
.76468 .30012 .77023 .31106 .78222 .30716 .77678 .2973 Mtetra
.611 .66 .873 r
.77678 .2973 .78222 .30716 .79428 .30355 .78895 .2946 Mtetra
.609 .684 .895 r
.78895 .2946 .79428 .30355 .80642 .3001 .80118 .29194 Mtetra
.609 .707 .914 r
.80118 .29194 .80642 .3001 .81861 .29669 .81347 .28921 Mtetra
.713 .763 .892 r
.16646 .49655 .17328 .5025 .18308 .49801 .17631 .49171 Mtetra
.714 .753 .883 r
.17631 .49171 .18308 .49801 .19291 .49347 .18621 .48673 Mtetra
.714 .741 .873 r
.18621 .48673 .19291 .49347 .20277 .48895 .19615 .48165 Mtetra
.712 .726 .861 r
.19615 .48165 .20277 .48895 .21265 .48455 .20611 .47649 Mtetra
.709 .706 .845 r
.20611 .47649 .21265 .48455 .22253 .48034 .21611 .47124 Mtetra
.7 .68 .828 r
.21611 .47124 .22253 .48034 .23242 .47649 .22613 .46605 Mtetra
.687 .65 .808 r
.22613 .46605 .23242 .47649 .24229 .47317 .23617 .46099 Mtetra
.669 .614 .785 r
.23617 .46099 .24229 .47317 .25214 .47056 .2462 .45623 Mtetra
.648 .576 .76 r
.2462 .45623 .25214 .47056 .26196 .46888 .25623 .45192 Mtetra
.625 .537 .735 r
.25623 .45192 .26196 .46888 .27175 .46822 .26624 .4482 Mtetra
.603 .5 .71 r
.26624 .4482 .27175 .46822 .2815 .46873 .27623 .44524 Mtetra
.58 .466 .687 r
.27623 .44524 .2815 .46873 .29125 .47016 .28619 .44318 Mtetra
.559 .436 .668 r
.28619 .44318 .29125 .47016 .30101 .47238 .29612 .44222 Mtetra
.54 .411 .654 r
.29612 .44222 .30101 .47238 .31083 .47474 .30602 .44248 Mtetra
.521 .392 .645 r
.30602 .44248 .31083 .47474 .32075 .47674 .3159 .44408 Mtetra
.505 .38 .643 r
.3159 .44408 .32075 .47674 .3308 .47776 .32578 .4468 Mtetra
.488 .374 .649 r
.32578 .4468 .3308 .47776 .341 .47729 .33568 .45047 Mtetra
.473 .38 .67 r
.33568 .45047 .341 .47729 .35134 .47526 .34565 .45444 Mtetra
.455 .405 .713 r
.34565 .45444 .35134 .47526 .36181 .47157 .35571 .45821 Mtetra
.419 .471 .808 r
.35571 .45821 .36181 .47157 .37238 .46662 .3659 .46125 Mtetra
.249 .609 .955 r
.3659 .46125 .37238 .46662 .38302 .4607 .37622 .46315 Mtetra
.276 0 0 r
.37622 .46315 .38302 .4607 .39371 .45425 .38666 .46385 Mtetra
.404 0 .092 r
.38666 .46385 .39371 .45425 .40442 .44764 .39722 .46329 Mtetra
.43 .058 .229 r
.39722 .46329 .40442 .44764 .41516 .44112 .40788 .46171 Mtetra
.439 .098 .29 r
.40788 .46171 .41516 .44112 .4259 .43492 .41863 .45928 Mtetra
.444 .121 .322 r
.41863 .45928 .4259 .43492 .43666 .42914 .42944 .45627 Mtetra
.448 .135 .34 r
.42944 .45627 .43666 .42914 .44743 .42387 .4403 .45291 Mtetra
.452 .144 .352 r
.4403 .45291 .44743 .42387 .45823 .41914 .45122 .44937 Mtetra
.454 .15 .358 r
.45122 .44937 .45823 .41914 .46905 .41498 .46218 .44577 Mtetra
.456 .153 .361 r
.46218 .44577 .46905 .41498 .4799 .41139 .47318 .44218 Mtetra
.457 .153 .361 r
.47318 .44218 .4799 .41139 .49079 .40837 .48423 .43861 Mtetra
.455 .15 .358 r
.48423 .43861 .49079 .40837 .50172 .40591 .49532 .43498 Mtetra
.449 .141 .351 r
.49532 .43498 .50172 .40591 .5127 .40401 .50646 .43117 Mtetra
.436 .124 .336 r
.50646 .43117 .5127 .40401 .52373 .40262 .51764 .427 Mtetra
.414 .094 .311 r
.51764 .427 .52373 .40262 .53483 .40167 .52887 .42224 Mtetra
.369 .036 .263 r
.52887 .42224 .53483 .40167 .546 .40105 .54013 .41662 Mtetra
.275 0 .162 r
.54013 .41662 .546 .40105 .55723 .40054 .55141 .40996 Mtetra
.014 0 0 r
.55141 .40996 .55723 .40054 .56852 .39986 .5627 .40201 Mtetra
.673 .968 .774 r
.5627 .40201 .56852 .39986 .57988 .39867 .574 .39281 Mtetra
.83 .826 .844 r
.574 .39281 .57988 .39867 .59128 .39649 .58527 .38243 Mtetra
.754 .647 .742 r
.58527 .38243 .59128 .39649 .60271 .39303 .59653 .37129 Mtetra
.703 .558 .688 r
.59653 .37129 .60271 .39303 .61414 .38787 .60778 .35992 Mtetra
.672 .511 .66 r
.60778 .35992 .61414 .38787 .62555 .3811 .61903 .34883 Mtetra
.649 .483 .645 r
.61903 .34883 .62555 .3811 .63694 .37279 .63031 .33868 Mtetra
.634 .468 .641 r
.63031 .33868 .63694 .37279 .6483 .36346 .64163 .32966 Mtetra
.622 .461 .643 r
.64163 .32966 .6483 .36346 .65966 .35373 .65301 .32201 Mtetra
.615 .462 .651 r
.65301 .32201 .65966 .35373 .67102 .34413 .66447 .31559 Mtetra
.61 .47 .666 r
.66447 .31559 .67102 .34413 .68243 .33532 .67601 .31029 Mtetra
.607 .483 .685 r
.67601 .31029 .68243 .33532 .69391 .32745 .68764 .30593 Mtetra
.604 .501 .71 r
.68764 .30593 .69391 .32745 .70547 .32078 .69936 .30234 Mtetra
.601 .523 .739 r
.69936 .30234 .70547 .32078 .71712 .31514 .71117 .29937 Mtetra
.598 .549 .771 r
.71117 .29937 .71712 .31514 .72887 .31046 .72306 .29685 Mtetra
.594 .577 .804 r
.72306 .29685 .72887 .31046 .74072 .30653 .73504 .29465 Mtetra
.592 .606 .835 r
.73504 .29465 .74072 .30653 .75266 .30313 .74709 .2926 Mtetra
.589 .633 .863 r
.74709 .2926 .75266 .30313 .76468 .30012 .75921 .2906 Mtetra
.59 .659 .886 r
.75921 .2906 .76468 .30012 .77678 .2973 .77139 .28852 Mtetra
.59 .68 .904 r
.77139 .28852 .77678 .2973 .78895 .2946 .78364 .28636 Mtetra
.591 .698 .917 r
.78364 .28636 .78895 .2946 .80118 .29194 .79594 .28409 Mtetra
.594 .712 .926 r
.79594 .28409 .80118 .29194 .81347 .28921 .8083 .28168 Mtetra
.703 .761 .897 r
.15958 .49055 .16646 .49655 .17631 .49171 .16943 .48599 Mtetra
.709 .772 .901 r
.16943 .48599 .17631 .49171 .18621 .48673 .17933 .48127 Mtetra
.717 .782 .904 r
.17933 .48127 .18621 .48673 .19615 .48165 .18927 .47635 Mtetra
.725 .79 .904 r
.18927 .47635 .19615 .48165 .20611 .47649 .19926 .47118 Mtetra
.734 .791 .899 r
.19926 .47118 .20611 .47649 .21611 .47124 .20931 .46571 Mtetra
.739 .785 .89 r
.20931 .46571 .21611 .47124 .22613 .46605 .2194 .46 Mtetra
.741 .77 .877 r
.2194 .46 .22613 .46605 .23617 .46099 .22954 .45405 Mtetra
.736 .745 .859 r
.22954 .45405 .23617 .46099 .2462 .45623 .23971 .44801 Mtetra
.725 .71 .836 r
.23971 .44801 .2462 .45623 .25623 .45192 .2499 .44197 Mtetra
.707 .669 .81 r
.2499 .44197 .25623 .45192 .26624 .4482 .26009 .43611 Mtetra
.684 .624 .783 r
.26009 .43611 .26624 .4482 .27623 .44524 .27028 .4306 Mtetra
.657 .579 .755 r
.27028 .4306 .27623 .44524 .28619 .44318 .28045 .42569 Mtetra
.629 .536 .73 r
.28045 .42569 .28619 .44318 .29612 .44222 .29059 .42164 Mtetra
.6 .495 .707 r
.29059 .42164 .29612 .44222 .30602 .44248 .30068 .41869 Mtetra
.571 .459 .686 r
.30068 .41869 .30602 .44248 .3159 .44408 .31073 .41708 Mtetra
.548 .429 .669 r
.31073 .41708 .3159 .44408 .32578 .4468 .32075 .41674 Mtetra
.529 .404 .654 r
.32075 .41674 .32578 .4468 .33568 .45047 .33075 .41765 Mtetra
.518 .388 .643 r
.33075 .41765 .33568 .45047 .34565 .45444 .34077 .41938 Mtetra
.513 .379 .635 r
.34077 .41938 .34565 .45444 .35571 .45821 .35084 .4216 Mtetra
.514 .376 .631 r
.35084 .4216 .35571 .45821 .3659 .46125 .36098 .42383 Mtetra
.519 .378 .629 r
.36098 .42383 .3659 .46125 .37622 .46315 .37121 .42569 Mtetra
.526 .383 .63 r
.37121 .42569 .37622 .46315 .38666 .46385 .38155 .427 Mtetra
.535 .391 .632 r
.38155 .427 .38666 .46385 .39722 .46329 .39199 .42754 Mtetra
.544 .401 .636 r
.39199 .42754 .39722 .46329 .40788 .46171 .40252 .42735 Mtetra
.553 .411 .642 r
.40252 .42735 .40788 .46171 .41863 .45928 .41315 .42642 Mtetra
.562 .421 .647 r
.41315 .42642 .41863 .45928 .42944 .45627 .42385 .42484 Mtetra
.57 .431 .653 r
.42385 .42484 .42944 .45627 .4403 .45291 .43463 .42266 Mtetra
.578 .441 .658 r
.43463 .42266 .4403 .45291 .45122 .44937 .44547 .41995 Mtetra
.585 .448 .661 r
.44547 .41995 .45122 .44937 .46218 .44577 .45638 .41677 Mtetra
.591 .454 .663 r
.45638 .41677 .46218 .44577 .47318 .44218 .46733 .41314 Mtetra
.596 .458 .663 r
.46733 .41314 .47318 .44218 .48423 .43861 .47834 .40905 Mtetra
.601 .459 .66 r
.47834 .40905 .48423 .43861 .49532 .43498 .48939 .40448 Mtetra
.605 .459 .656 r
.48939 .40448 .49532 .43498 .50646 .43117 .50049 .39939 Mtetra
.609 .457 .651 r
.50049 .39939 .50646 .43117 .51764 .427 .51162 .39368 Mtetra
.612 .455 .645 r
.51162 .39368 .51764 .427 .52887 .42224 .52279 .38731 Mtetra
.616 .454 .64 r
.52279 .38731 .52887 .42224 .54013 .41662 .53398 .38018 Mtetra
.619 .453 .635 r
.53398 .38018 .54013 .41662 .55141 .40996 .54519 .37229 Mtetra
.623 .453 .631 r
.54519 .37229 .55141 .40996 .5627 .40201 .55641 .36362 Mtetra
.626 .453 .629 r
.55641 .36362 .5627 .40201 .574 .39281 .56763 .35435 Mtetra
.629 .455 .628 r
.56763 .35435 .574 .39281 .58527 .38243 .57885 .3447 Mtetra
.63 .457 .63 r
.57885 .3447 .58527 .38243 .59653 .37129 .59007 .33504 Mtetra
.63 .46 .634 r
.59007 .33504 .59653 .37129 .60778 .35992 .60131 .32586 Mtetra
.628 .464 .641 r
.60131 .32586 .60778 .35992 .61903 .34883 .61259 .31749 Mtetra
.622 .468 .651 r
.61259 .31749 .61903 .34883 .63031 .33868 .62391 .31039 Mtetra
.616 .474 .665 r
.62391 .31039 .63031 .33868 .64163 .32966 .63531 .30458 Mtetra
.607 .482 .684 r
.63531 .30458 .64163 .32966 .65301 .32201 .64679 .30014 Mtetra
.599 .495 .707 r
.64679 .30014 .65301 .32201 .66447 .31559 .65836 .29683 Mtetra
.59 .513 .736 r
.65836 .29683 .66447 .31559 .67601 .31029 .67003 .2944 Mtetra
.582 .538 .771 r
.67003 .2944 .67601 .31029 .68764 .30593 .68179 .2926 Mtetra
.574 .57 .81 r
.68179 .2926 .68764 .30593 .69936 .30234 .69364 .29116 Mtetra
.566 .605 .852 r
.69364 .29116 .69936 .30234 .71117 .29937 .70557 .28992 Mtetra
.559 .644 .891 r
.70557 .28992 .71117 .29937 .72306 .29685 .71756 .28867 Mtetra
.553 .679 .922 r
.71756 .28867 .72306 .29685 .73504 .29465 .72963 .28734 Mtetra
.554 .708 .943 r
.72963 .28734 .73504 .29465 .74709 .2926 .74175 .28577 Mtetra
.559 .728 .954 r
.74175 .28577 .74709 .2926 .75921 .2906 .75392 .28396 Mtetra
.571 .742 .957 r
.75392 .28396 .75921 .2906 .77139 .28852 .76614 .28183 Mtetra
.582 .746 .955 r
.76614 .28183 .77139 .28852 .78364 .28636 .7784 .27945 Mtetra
.593 .744 .949 r
.7784 .27945 .78364 .28636 .79594 .28409 .79072 .27685 Mtetra
.603 .738 .94 r
.79072 .27685 .79594 .28409 .8083 .28168 .80308 .27409 Mtetra
.675 .756 .912 r
.15266 .48451 .15958 .49055 .16943 .48599 .16245 .48074 Mtetra
.681 .784 .928 r
.16245 .48074 .16943 .48599 .17933 .48127 .17228 .47682 Mtetra
.689 .815 .943 r
.17228 .47682 .17933 .48127 .18927 .47635 .18217 .47266 Mtetra
.7 .846 .952 r
.18217 .47266 .18927 .47635 .19926 .47118 .19213 .46817 Mtetra
.715 .874 .956 r
.19213 .46817 .19926 .47118 .20931 .46571 .20215 .46325 Mtetra
.729 .895 .955 r
.20215 .46325 .20931 .46571 .2194 .46 .21225 .45789 Mtetra
.746 .909 .949 r
.21225 .45789 .2194 .46 .22954 .45405 .22242 .45203 Mtetra
.76 .913 .942 r
.22242 .45203 .22954 .45405 .23971 .44801 .23264 .44579 Mtetra
.773 .906 .933 r
.23264 .44579 .23971 .44801 .2499 .44197 .24291 .4392 Mtetra
.778 .888 .924 r
.24291 .4392 .2499 .44197 .26009 .43611 .25322 .43247 Mtetra
.776 .858 .911 r
.25322 .43247 .26009 .43611 .27028 .4306 .26354 .42575 Mtetra
.765 .817 .894 r
.26354 .42575 .27028 .4306 .28045 .42569 .27387 .41918 Mtetra
.744 .763 .868 r
.27387 .41918 .28045 .42569 .29059 .42164 .28419 .41289 Mtetra
.72 .701 .832 r
.28419 .41289 .29059 .42164 .30068 .41869 .29452 .40685 Mtetra
.691 .633 .787 r
.29452 .40685 .30068 .41869 .31073 .41708 .30485 .40104 Mtetra
.661 .568 .739 r
.30485 .40104 .31073 .41708 .32075 .41674 .3152 .39543 Mtetra
.635 .513 .697 r
.3152 .39543 .32075 .41674 .33075 .41765 .32556 .39 Mtetra
.612 .469 .663 r
.32556 .39 .33075 .41765 .34077 .41938 .33593 .38493 Mtetra
.593 .436 .638 r
.33593 .38493 .34077 .41938 .35084 .4216 .3463 .38033 Mtetra
.578 .412 .62 r
.3463 .38033 .35084 .4216 .36098 .42383 .35667 .37636 Mtetra
.566 .394 .607 r
.35667 .37636 .36098 .42383 .37121 .42569 .36704 .37311 Mtetra
.558 .382 .598 r
.36704 .37311 .37121 .42569 .38155 .427 .37742 .37048 Mtetra
.553 .374 .593 r
.37742 .37048 .38155 .427 .39199 .42754 .38783 .36839 Mtetra
.55 .369 .589 r
.38783 .36839 .39199 .42754 .40252 .42735 .39828 .36659 Mtetra
.548 .367 .588 r
.39828 .36659 .40252 .42735 .41315 .42642 .40877 .36491 Mtetra
.549 .367 .587 r
.40877 .36491 .41315 .42642 .42385 .42484 .41933 .36312 Mtetra
.551 .368 .587 r
.41933 .36312 .42385 .42484 .43463 .42266 .42994 .36102 Mtetra
.554 .371 .587 r
.42994 .36102 .43463 .42266 .44547 .41995 .44062 .35848 Mtetra
.557 .373 .588 r
.44062 .35848 .44547 .41995 .45638 .41677 .45136 .35539 Mtetra
.561 .376 .588 r
.45136 .35539 .45638 .41677 .46733 .41314 .46217 .35168 Mtetra
.565 .379 .589 r
.46217 .35168 .46733 .41314 .47834 .40905 .47302 .34736 Mtetra
.568 .382 .589 r
.47302 .34736 .47834 .40905 .48939 .40448 .48392 .34248 Mtetra
.571 .383 .588 r
.48392 .34248 .48939 .40448 .50049 .39939 .49486 .33715 Mtetra
.572 .384 .588 r
.49486 .33715 .50049 .39939 .51162 .39368 .50584 .33151 Mtetra
.573 .385 .588 r
.50584 .33151 .51162 .39368 .52279 .38731 .51684 .32575 Mtetra
.572 .385 .589 r
.51684 .32575 .52279 .38731 .53398 .38018 .52788 .32009 Mtetra
.572 .385 .591 r
.52788 .32009 .53398 .38018 .54519 .37229 .53895 .31474 Mtetra
.57 .386 .594 r
.53895 .31474 .54519 .37229 .55641 .36362 .55006 .30992 Mtetra
.568 .389 .599 r
.55006 .30992 .55641 .36362 .56763 .35435 .56121 .30572 Mtetra
.566 .394 .607 r
.56121 .30572 .56763 .35435 .57885 .3447 .57242 .30225 Mtetra
.565 .403 .62 r
.57242 .30225 .57885 .3447 .59007 .33504 .58368 .29942 Mtetra
.566 .417 .639 r
.58368 .29942 .59007 .33504 .60131 .32586 .59502 .29708 Mtetra
.568 .44 .666 r
.59502 .29708 .60131 .32586 .61259 .31749 .60642 .29511 Mtetra
.573 .475 .705 r
.60642 .29511 .61259 .31749 .62391 .31039 .61788 .29333 Mtetra
.575 .52 .756 r
.61788 .29333 .62391 .31039 .63531 .30458 .62942 .29176 Mtetra
.571 .575 .818 r
.62942 .29176 .63531 .30458 .64679 .30014 .64103 .29043 Mtetra
.554 .633 .883 r
.64103 .29043 .64679 .30014 .65836 .29683 .65272 .28936 Mtetra
.519 .682 .94 r
.65272 .28936 .65836 .29683 .67003 .2944 .6645 .28859 Mtetra
.473 .722 .979 r
.6645 .28859 .67003 .2944 .68179 .2926 .67635 .28798 Mtetra
.426 .746 .994 r
.67635 .28798 .68179 .2926 .69364 .29116 .68828 .2874 Mtetra
.393 .763 .992 r
.68828 .2874 .69364 .29116 .70557 .28992 .70028 .28667 Mtetra
.389 .781 .988 r
.70028 .28667 .70557 .28992 .71756 .28867 .71234 .28559 Mtetra
.411 .8 .989 r
.71234 .28559 .71756 .28867 .72963 .28734 .72444 .28412 Mtetra
.458 .82 .995 r
.72444 .28412 .72963 .28734 .74175 .28577 .73659 .28214 Mtetra
.51 .832 .999 r
.73659 .28214 .74175 .28577 .75392 .28396 .74876 .2797 Mtetra
.56 .832 .996 r
.74876 .2797 .75392 .28396 .76614 .28183 .76097 .2768 Mtetra
.597 .819 .984 r
.76097 .2768 .76614 .28183 .7784 .27945 .77321 .27357 Mtetra
.621 .797 .966 r
.77321 .27357 .7784 .27945 .79072 .27685 .7855 .27008 Mtetra
.634 .771 .945 r
.7855 .27008 .79072 .27685 .80308 .27409 .79782 .26643 Mtetra
.629 .744 .931 r
.14569 .47843 .15266 .48451 .16245 .48074 .15538 .47573 Mtetra
.626 .783 .957 r
.15538 .47573 .16245 .48074 .17228 .47682 .16511 .47294 Mtetra
.622 .825 .979 r
.16511 .47294 .17228 .47682 .18217 .47266 .1749 .46997 Mtetra
.614 .868 .991 r
.1749 .46997 .18217 .47266 .19213 .46817 .18476 .46672 Mtetra
.598 .905 .984 r
.18476 .46672 .19213 .46817 .20215 .46325 .19469 .46309 Mtetra
.568 .925 .949 r
.19469 .46309 .20215 .46325 .21225 .45789 .20471 .45901 Mtetra
.528 .921 .885 r
.20471 .45901 .21225 .45789 .22242 .45203 .2148 .45439 Mtetra
.475 .891 .797 r
.2148 .45439 .22242 .45203 .23264 .44579 .22498 .44924 Mtetra
.429 .853 .71 r
.22498 .44924 .23264 .44579 .24291 .4392 .23523 .44354 Mtetra
.391 .815 .637 r
.23523 .44354 .24291 .4392 .25322 .43247 .24555 .43736 Mtetra
0 0 0 r
.24555 .43736 .25322 .43247 .26354 .42575 .25592 .43077 Mtetra
.397 .805 .595 r
.25592 .43077 .26354 .42575 .27387 .41918 .26634 .42383 Mtetra
.455 .847 .639 r
.26634 .42383 .27387 .41918 .28419 .41289 .2768 .41663 Mtetra
.558 .917 .73 r
.2768 .41663 .28419 .41289 .29452 .40685 .28729 .40918 Mtetra
.678 .977 .833 r
.28729 .40918 .29452 .40685 .30485 .40104 .2978 .40154 Mtetra
.766 .984 .904 r
.2978 .40154 .30485 .40104 .3152 .39543 .30834 .39382 Mtetra
.8 .935 .92 r
.30834 .39382 .3152 .39543 .32556 .39 .31889 .38616 Mtetra
.789 .86 .903 r
.31889 .38616 .32556 .39 .33593 .38493 .32943 .37881 Mtetra
.76 .784 .873 r
.32943 .37881 .33593 .38493 .3463 .38033 .33995 .37198 Mtetra
.726 .717 .842 r
.33995 .37198 .3463 .38033 .35667 .37636 .35046 .36579 Mtetra
.691 .659 .813 r
.35046 .36579 .35667 .37636 .36704 .37311 .36096 .36036 Mtetra
.663 .611 .786 r
.36096 .36036 .36704 .37311 .37742 .37048 .37145 .3556 Mtetra
.639 .571 .762 r
.37145 .3556 .37742 .37048 .38783 .36839 .38194 .35143 Mtetra
.622 .54 .741 r
.38194 .35143 .38783 .36839 .39828 .36659 .39246 .34768 Mtetra
.61 .517 .723 r
.39246 .34768 .39828 .36659 .40877 .36491 .403 .34422 Mtetra
.603 .499 .709 r
.403 .34422 .40877 .36491 .41933 .36312 .41359 .34089 Mtetra
.599 .487 .698 r
.41359 .34089 .41933 .36312 .42994 .36102 .42421 .33756 Mtetra
.597 .48 .69 r
.42421 .33756 .42994 .36102 .44062 .35848 .43488 .33415 Mtetra
.597 .476 .684 r
.43488 .33415 .44062 .35848 .45136 .35539 .44561 .33059 Mtetra
.599 .474 .682 r
.44561 .33059 .45136 .35539 .46217 .35168 .45637 .32684 Mtetra
.601 .476 .682 r
.45637 .32684 .46217 .35168 .47302 .34736 .46719 .32291 Mtetra
.604 .48 .684 r
.46719 .32291 .47302 .34736 .48392 .34248 .47805 .31882 Mtetra
.607 .486 .689 r
.47805 .31882 .48392 .34248 .49486 .33715 .48895 .31464 Mtetra
.61 .495 .697 r
.48895 .31464 .49486 .33715 .50584 .33151 .49989 .31047 Mtetra
.612 .505 .708 r
.49989 .31047 .50584 .33151 .51684 .32575 .51087 .30643 Mtetra
.613 .518 .723 r
.51087 .30643 .51684 .32575 .52788 .32009 .52189 .30267 Mtetra
.611 .534 .743 r
.52189 .30267 .52788 .32009 .53895 .31474 .53296 .29934 Mtetra
.604 .552 .769 r
.53296 .29934 .53895 .31474 .55006 .30992 .54409 .29662 Mtetra
.591 .575 .803 r
.54409 .29662 .55006 .30992 .56121 .30572 .55527 .29457 Mtetra
.568 .602 .847 r
.55527 .29457 .56121 .30572 .57242 .30225 .56652 .2933 Mtetra
.53 .638 .901 r
.56652 .2933 .57242 .30225 .58368 .29942 .57785 .29269 Mtetra
.466 .68 .958 r
.57785 .29269 .58368 .29942 .59502 .29708 .58926 .29262 Mtetra
.352 .71 .985 r
.58926 .29262 .59502 .29708 .60642 .29511 .60075 .29288 Mtetra
.179 .681 .91 r
.60075 .29288 .60642 .29511 .61788 .29333 .61232 .2932 Mtetra
.016 0 0 r
.61232 .2932 .61788 .29333 .62942 .29176 .62397 .29347 Mtetra
.152 0 0 r
.62397 .29347 .62942 .29176 .64103 .29043 .6357 .29354 Mtetra
.222 0 0 r
.6357 .29354 .64103 .29043 .65272 .28936 .64749 .29338 Mtetra
.25 0 0 r
.64749 .29338 .65272 .28936 .6645 .28859 .65935 .29295 Mtetra
.242 0 0 r
.65935 .29295 .6645 .28859 .67635 .28798 .67127 .29217 Mtetra
.206 0 0 r
.67127 .29217 .67635 .28798 .68828 .2874 .68325 .29098 Mtetra
.136 0 0 r
.68325 .29098 .68828 .2874 .70028 .28667 .69527 .2893 Mtetra
.022 0 0 r
.69527 .2893 .70028 .28667 .71234 .28559 .70733 .28704 Mtetra
0 0 0 r
.70733 .28704 .71234 .28559 .72444 .28412 .71942 .28424 Mtetra
.314 .804 .821 r
.71942 .28424 .72444 .28412 .73659 .28214 .73153 .28088 Mtetra
.472 .884 .936 r
.73153 .28088 .73659 .28214 .74876 .2797 .74367 .27704 Mtetra
.582 .901 .984 r
.74367 .27704 .74876 .2797 .76097 .2768 .75583 .27281 Mtetra
.641 .878 .985 r
.75583 .27281 .76097 .2768 .77321 .27357 .76803 .26828 Mtetra
.668 .839 .965 r
.76803 .26828 .77321 .27357 .7855 .27008 .78026 .26355 Mtetra
.678 .799 .939 r
.78026 .26355 .7855 .27008 .79782 .26643 .79252 .25872 Mtetra
.573 .727 .947 r
.13868 .4723 .14569 .47843 .15538 .47573 .14826 .47063 Mtetra
.557 .761 .973 r
.14826 .47063 .15538 .47573 .16511 .47294 .15789 .46896 Mtetra
.533 .797 .994 r
.15789 .46896 .16511 .47294 .1749 .46997 .16757 .46722 Mtetra
.496 .83 .999 r
.16757 .46722 .1749 .46997 .18476 .46672 .17731 .46535 Mtetra
.433 .844 .968 r
.17731 .46535 .18476 .46672 .19469 .46309 .18712 .46326 Mtetra
.339 .818 .876 r
.18712 .46326 .19469 .46309 .20471 .45901 .19701 .46087 Mtetra
.223 .738 .719 r
.19701 .46087 .20471 .45901 .2148 .45439 .20697 .45807 Mtetra
0 0 0 r
.20697 .45807 .2148 .45439 .22498 .44924 .21703 .45476 Mtetra
.21703 .45476 .22498 .44924 .23523 .44354 .22718 .45083 Mtetra
.032 0 0 r
.22718 .45083 .23523 .44354 .24555 .43736 .23743 .44622 Mtetra
.057 0 0 r
.23743 .44622 .24555 .43736 .25592 .43077 .24777 .44084 Mtetra
.066 0 0 r
.24777 .44084 .25592 .43077 .26634 .42383 .2582 .43477 Mtetra
.061 0 0 r
.2582 .43477 .26634 .42383 .2768 .41663 .2687 .42803 Mtetra
.059 0 0 r
.2687 .42803 .2768 .41663 .28729 .40918 .27925 .42092 Mtetra
.067 0 0 r
.27925 .42092 .28729 .40918 .2978 .40154 .28983 .41365 Mtetra
.097 0 0 r
.28983 .41365 .2978 .40154 .30834 .39382 .30041 .40656 Mtetra
.149 0 .017 r
.30041 .40656 .30834 .39382 .31889 .38616 .31099 .39989 Mtetra
.205 0 .07 r
.31099 .39989 .31889 .38616 .32943 .37881 .32155 .39366 Mtetra
.255 0 .119 r
.32155 .39366 .32943 .37881 .33995 .37198 .33211 .3879 Mtetra
.287 0 .154 r
.33211 .3879 .33995 .37198 .35046 .36579 .34268 .3824 Mtetra
.304 0 .174 r
.34268 .3824 .35046 .36579 .36096 .36036 .35327 .37702 Mtetra
.307 0 .176 r
.35327 .37702 .36096 .36036 .37145 .3556 .3639 .37165 Mtetra
.296 0 .162 r
.3639 .37165 .37145 .3556 .38194 .35143 .37455 .36622 Mtetra
.275 0 .132 r
.37455 .36622 .38194 .35143 .39246 .34768 .38524 .36079 Mtetra
.242 0 .083 r
.38524 .36079 .39246 .34768 .403 .34422 .39595 .3554 Mtetra
.198 0 .013 r
.39595 .3554 .403 .34422 .41359 .34089 .40669 .35016 Mtetra
.146 0 0 r
.40669 .35016 .41359 .34089 .42421 .33756 .41745 .34517 Mtetra
.096 0 0 r
.41745 .34517 .42421 .33756 .43488 .33415 .42823 .34053 Mtetra
.062 0 0 r
.42823 .34053 .43488 .33415 .44561 .33059 .43904 .3363 Mtetra
.43904 .3363 .44561 .33059 .45637 .32684 .44988 .33254 Mtetra
.103 0 0 r
.44988 .33254 .45637 .32684 .46719 .32291 .46075 .32923 Mtetra
.171 0 0 r
.46075 .32923 .46719 .32291 .47805 .31882 .47166 .32634 Mtetra
.246 0 0 r
.47166 .32634 .47805 .31882 .48895 .31464 .48262 .32381 Mtetra
.308 0 .014 r
.48262 .32381 .48895 .31464 .49989 .31047 .49363 .32153 Mtetra
.353 0 .093 r
.49363 .32153 .49989 .31047 .51087 .30643 .50469 .31941 Mtetra
.382 0 .151 r
.50469 .31941 .51087 .30643 .52189 .30267 .51581 .31733 Mtetra
.4 .016 .19 r
.51581 .31733 .52189 .30267 .53296 .29934 .52699 .31525 Mtetra
.41 .035 .214 r
.52699 .31525 .53296 .29934 .54409 .29662 .53822 .31312 Mtetra
.415 .044 .224 r
.53822 .31312 .54409 .29662 .55527 .29457 .54952 .31101 Mtetra
.418 .047 .224 r
.54952 .31101 .55527 .29457 .56652 .2933 .56087 .30903 Mtetra
.42 .042 .214 r
.56087 .30903 .56652 .2933 .57785 .29269 .57229 .30731 Mtetra
.424 .037 .197 r
.57229 .30731 .57785 .29269 .58926 .29262 .58378 .30608 Mtetra
.428 .029 .177 r
.58378 .30608 .58926 .29262 .60075 .29288 .59535 .3053 Mtetra
.432 .021 .157 r
.59535 .3053 .60075 .29288 .61232 .2932 .60701 .30497 Mtetra
.432 .013 .142 r
.60701 .30497 .61232 .2932 .62397 .29347 .61874 .30482 Mtetra
.423 0 .127 r
.61874 .30482 .62397 .29347 .6357 .29354 .63055 .30453 Mtetra
.407 0 .11 r
.63055 .30453 .6357 .29354 .64749 .29338 .64242 .30386 Mtetra
.376 0 .083 r
.64242 .30386 .64749 .29338 .65935 .29295 .65434 .30252 Mtetra
.333 0 .036 r
.65434 .30252 .65935 .29295 .67127 .29217 .6663 .30046 Mtetra
.267 0 0 r
.6663 .30046 .67127 .29217 .68325 .29098 .67829 .29761 Mtetra
.169 0 0 r
.67829 .29761 .68325 .29098 .69527 .2893 .6903 .29406 Mtetra
.022 0 0 r
.6903 .29406 .69527 .2893 .70733 .28704 .70233 .28986 Mtetra
0 0 0 r
.70233 .28986 .70733 .28704 .71942 .28424 .71437 .28513 Mtetra
.4 .851 .784 r
.71437 .28513 .71942 .28424 .73153 .28088 .72644 .27996 Mtetra
.57 .934 .922 r
.72644 .27996 .73153 .28088 .74367 .27704 .73853 .27447 Mtetra
.663 .934 .969 r
.73853 .27447 .74367 .27704 .75583 .27281 .75064 .26875 Mtetra
.703 .897 .967 r
.75064 .26875 .75583 .27281 .76803 .26828 .76279 .26287 Mtetra
.716 .853 .947 r
.76279 .26287 .76803 .26828 .78026 .26355 .77497 .25692 Mtetra
.716 .811 .924 r
.77497 .25692 .78026 .26355 .79252 .25872 .78718 .25095 Mtetra
.539 .716 .954 r
.13161 .46613 .13868 .4723 .14826 .47063 .14115 .46498 Mtetra
.524 .73 .968 r
.14115 .46498 .14826 .47063 .15789 .46896 .15072 .4639 Mtetra
.507 .747 .982 r
.15072 .4639 .15789 .46896 .16757 .46722 .16035 .46285 Mtetra
.484 .765 .993 r
.16035 .46285 .16757 .46722 .17731 .46535 .17002 .4618 Mtetra
.45 .783 .998 r
.17002 .4618 .17731 .46535 .18712 .46326 .17975 .46072 Mtetra
.403 .798 .987 r
.17975 .46072 .18712 .46326 .19701 .46087 .18954 .45953 Mtetra
.335 .795 .94 r
.18954 .45953 .19701 .46087 .20697 .45807 .1994 .45815 Mtetra
.243 .757 .839 r
.1994 .45815 .20697 .45807 .21703 .45476 .20934 .45646 Mtetra
0 0 0 r
.20934 .45646 .21703 .45476 .22718 .45083 .21937 .45435 Mtetra
.21937 .45435 .22718 .45083 .23743 .44622 .22949 .45172 Mtetra
.051 0 0 r
.22949 .45172 .23743 .44622 .24777 .44084 .23971 .44849 Mtetra
.124 0 0 r
.23971 .44849 .24777 .44084 .2582 .43477 .25001 .44468 Mtetra
.179 0 0 r
.25001 .44468 .2582 .43477 .2687 .42803 .2604 .4403 Mtetra
.231 0 .043 r
.2604 .4403 .2687 .42803 .27925 .42092 .27086 .43553 Mtetra
.273 0 .116 r
.27086 .43553 .27925 .42092 .28983 .41365 .28137 .4305 Mtetra
.307 0 .171 r
.28137 .4305 .28983 .41365 .30041 .40656 .29191 .42536 Mtetra
.334 0 .21 r
.29191 .42536 .30041 .40656 .31099 .39989 .30249 .42023 Mtetra
.349 .006 .234 r
.30249 .42023 .31099 .39989 .32155 .39366 .3131 .41503 Mtetra
.357 .019 .248 r
.3131 .41503 .32155 .39366 .33211 .3879 .32375 .40975 Mtetra
.357 .022 .253 r
.32375 .40975 .33211 .3879 .34268 .3824 .33444 .40429 Mtetra
.353 .018 .251 r
.33444 .40429 .34268 .3824 .35327 .37702 .34517 .39861 Mtetra
.346 .011 .246 r
.34517 .39861 .35327 .37702 .3639 .37165 .35593 .39276 Mtetra
.339 .002 .239 r
.35593 .39276 .3639 .37165 .37455 .36622 .36674 .38679 Mtetra
.335 0 .232 r
.36674 .38679 .37455 .36622 .38524 .36079 .37756 .38083 Mtetra
.333 0 .227 r
.37756 .38083 .38524 .36079 .39595 .3554 .38841 .375 Mtetra
.337 0 .224 r
.38841 .375 .39595 .3554 .40669 .35016 .39928 .36941 Mtetra
.344 0 .223 r
.39928 .36941 .40669 .35016 .41745 .34517 .41017 .36417 Mtetra
.355 .005 .226 r
.41017 .36417 .41745 .34517 .42823 .34053 .42107 .35936 Mtetra
.368 .016 .23 r
.42107 .35936 .42823 .34053 .43904 .3363 .432 .35506 Mtetra
.382 .029 .235 r
.432 .35506 .43904 .3363 .44988 .33254 .44295 .35129 Mtetra
.397 .042 .241 r
.44295 .35129 .44988 .33254 .46075 .32923 .45394 .34805 Mtetra
.41 .055 .247 r
.45394 .34805 .46075 .32923 .47166 .32634 .46496 .34531 Mtetra
.422 .066 .254 r
.46496 .34531 .47166 .32634 .48262 .32381 .47603 .34301 Mtetra
.432 .077 .26 r
.47603 .34301 .48262 .32381 .49363 .32153 .48715 .34107 Mtetra
.44 .085 .266 r
.48715 .34107 .49363 .32153 .50469 .31941 .49833 .33939 Mtetra
.445 .092 .272 r
.49833 .33939 .50469 .31941 .51581 .31733 .50957 .33783 Mtetra
.447 .097 .278 r
.50957 .33783 .51581 .31733 .52699 .31525 .52087 .3363 Mtetra
.447 .1 .283 r
.52087 .3363 .52699 .31525 .53822 .31312 .53223 .33464 Mtetra
.446 .101 .286 r
.53223 .33464 .53822 .31312 .54952 .31101 .54366 .33283 Mtetra
.443 .1 .287 r
.54366 .33283 .54952 .31101 .56087 .30903 .55515 .33079 Mtetra
.439 .096 .286 r
.55515 .33079 .56087 .30903 .57229 .30731 .5667 .32858 Mtetra
.436 .09 .28 r
.5667 .32858 .57229 .30731 .58378 .30608 .5783 .32629 Mtetra
.429 .079 .267 r
.5783 .32629 .58378 .30608 .59535 .3053 .58997 .32393 Mtetra
.421 .061 .247 r
.58997 .32393 .59535 .3053 .60701 .30497 .6017 .32158 Mtetra
.404 .032 .214 r
.6017 .32158 .60701 .30497 .61874 .30482 .61348 .31912 Mtetra
.376 0 .166 r
.61348 .31912 .61874 .30482 .63055 .30453 .62532 .31641 Mtetra
.33 0 .095 r
.62532 .31641 .63055 .30453 .64242 .30386 .63721 .31329 Mtetra
.252 0 0 r
.63721 .31329 .64242 .30386 .65434 .30252 .64913 .30958 Mtetra
.135 0 0 r
.64913 .30958 .65434 .30252 .6663 .30046 .66108 .30527 Mtetra
0 0 0 r
.66108 .30527 .6663 .30046 .67829 .29761 .67305 .30033 Mtetra
.67305 .30033 .67829 .29761 .6903 .29406 .68504 .29485 Mtetra
.48 .896 .812 r
.68504 .29485 .6903 .29406 .70233 .28986 .69704 .28893 Mtetra
.626 .955 .923 r
.69704 .28893 .70233 .28986 .71437 .28513 .70906 .28267 Mtetra
.699 .946 .958 r
.70906 .28267 .71437 .28513 .72644 .27996 .72111 .2762 Mtetra
.73 .914 .957 r
.72111 .2762 .72644 .27996 .73853 .27447 .73318 .2696 Mtetra
.739 .878 .945 r
.73318 .2696 .73853 .27447 .75064 .26875 .74528 .26296 Mtetra
.739 .847 .93 r
.74528 .26296 .75064 .26875 .76279 .26287 .75741 .25631 Mtetra
.736 .82 .917 r
.75741 .25631 .76279 .26287 .77497 .25692 .76959 .24968 Mtetra
.731 .798 .905 r
.76959 .24968 .77497 .25692 .78718 .25095 .7818 .24311 Mtetra
.541 .716 .954 r
.12449 .45992 .13161 .46613 .14115 .46498 .13405 .45872 Mtetra
.534 .713 .954 r
.13405 .45872 .14115 .46498 .15072 .4639 .14364 .45762 Mtetra
.526 .71 .956 r
.14364 .45762 .15072 .4639 .16035 .46285 .15327 .45664 Mtetra
.516 .709 .959 r
.15327 .45664 .16035 .46285 .17002 .4618 .16294 .45576 Mtetra
.502 .711 .965 r
.16294 .45576 .17002 .4618 .17975 .46072 .17264 .45503 Mtetra
.487 .718 .973 r
.17264 .45503 .17975 .46072 .18954 .45953 .18239 .45438 Mtetra
.467 .731 .984 r
.18239 .45438 .18954 .45953 .1994 .45815 .19219 .45377 Mtetra
.439 .75 .994 r
.19219 .45377 .1994 .45815 .20934 .45646 .20205 .45313 Mtetra
.393 .769 .992 r
.20205 .45313 .20934 .45646 .21937 .45435 .21197 .4524 Mtetra
.31 .768 .95 r
.21197 .4524 .21937 .45435 .22949 .45172 .22197 .45153 Mtetra
.17 .706 .817 r
.22197 .45153 .22949 .45172 .23971 .44849 .23203 .45049 Mtetra
.013 0 0 r
.23203 .45049 .23971 .44849 .25001 .44468 .24216 .44924 Mtetra
.17 0 0 r
.24216 .44924 .25001 .44468 .2604 .4403 .25237 .44777 Mtetra
.269 0 0 r
.25237 .44777 .2604 .4403 .27086 .43553 .26265 .44598 Mtetra
.321 0 .046 r
.26265 .44598 .27086 .43553 .28137 .4305 .27302 .44377 Mtetra
.343 0 .125 r
.27302 .44377 .28137 .4305 .29191 .42536 .28348 .44098 Mtetra
.347 0 .168 r
.28348 .44098 .29191 .42536 .30249 .42023 .29404 .43745 Mtetra
.341 0 .189 r
.29404 .43745 .30249 .42023 .3131 .41503 .30469 .43319 Mtetra
.329 0 .195 r
.30469 .43319 .3131 .41503 .32375 .40975 .31543 .4282 Mtetra
.318 0 .194 r
.31543 .4282 .32375 .40975 .33444 .40429 .32623 .42275 Mtetra
.31 0 .19 r
.32623 .42275 .33444 .40429 .34517 .39861 .33707 .41702 Mtetra
.309 0 .19 r
.33707 .41702 .34517 .39861 .35593 .39276 .34794 .41126 Mtetra
.317 0 .195 r
.34794 .41126 .35593 .39276 .36674 .38679 .35884 .40567 Mtetra
.33 0 .206 r
.35884 .40567 .36674 .38679 .37756 .38083 .36975 .40031 Mtetra
.347 0 .221 r
.36975 .40031 .37756 .38083 .38841 .375 .38068 .39528 Mtetra
.363 .017 .237 r
.38068 .39528 .38841 .375 .39928 .36941 .39164 .39053 Mtetra
.378 .036 .253 r
.39164 .39053 .39928 .36941 .41017 .36417 .40262 .38608 Mtetra
.391 .051 .265 r
.40262 .38608 .41017 .36417 .42107 .35936 .41363 .38187 Mtetra
.4 .063 .274 r
.41363 .38187 .42107 .35936 .432 .35506 .42467 .37789 Mtetra
.407 .071 .28 r
.42467 .37789 .432 .35506 .44295 .35129 .43575 .37412 Mtetra
.412 .075 .281 r
.43575 .37412 .44295 .35129 .45394 .34805 .44688 .37055 Mtetra
.415 .076 .28 r
.44688 .37055 .45394 .34805 .46496 .34531 .45804 .3672 Mtetra
.417 .075 .276 r
.45804 .3672 .46496 .34531 .47603 .34301 .46925 .36411 Mtetra
.42 .073 .269 r
.46925 .36411 .47603 .34301 .48715 .34107 .48051 .36131 Mtetra
.422 .07 .261 r
.48051 .36131 .48715 .34107 .49833 .33939 .49182 .35881 Mtetra
.425 .068 .254 r
.49182 .35881 .49833 .33939 .50957 .33783 .50318 .35663 Mtetra
.427 .066 .248 r
.50318 .35663 .50957 .33783 .52087 .3363 .5146 .3547 Mtetra
.429 .065 .244 r
.5146 .3547 .52087 .3363 .53223 .33464 .52609 .35295 Mtetra
.428 .064 .242 r
.52609 .35295 .53223 .33464 .54366 .33283 .53763 .35117 Mtetra
.422 .058 .239 r
.53763 .35117 .54366 .33283 .55515 .33079 .54924 .34911 Mtetra
.411 .048 .235 r
.54924 .34911 .55515 .33079 .5667 .32858 .56091 .34659 Mtetra
.391 .027 .223 r
.56091 .34659 .5667 .32858 .5783 .32629 .57262 .34333 Mtetra
.363 0 .2 r
.57262 .34333 .5783 .32629 .58997 .32393 .58438 .33931 Mtetra
.321 0 .158 r
.58438 .33931 .58997 .32393 .6017 .32158 .59617 .33454 Mtetra
.259 0 .085 r
.59617 .33454 .6017 .32158 .61348 .31912 .60799 .32916 Mtetra
.161 0 0 r
.60799 .32916 .61348 .31912 .62532 .31641 .61983 .32335 Mtetra
0 0 0 r
.61983 .32335 .62532 .31641 .63721 .31329 .63171 .3172 Mtetra
.63171 .3172 .63721 .31329 .64913 .30958 .6436 .3108 Mtetra
.51 .908 .795 r
.6436 .3108 .64913 .30958 .66108 .30527 .65553 .30419 Mtetra
.674 .966 .928 r
.65553 .30419 .66108 .30527 .67305 .30033 .66747 .29737 Mtetra
.736 .937 .952 r
.66747 .29737 .67305 .30033 .68504 .29485 .67944 .29041 Mtetra
.754 .892 .941 r
.67944 .29041 .68504 .29485 .69704 .28893 .69144 .28333 Mtetra
.755 .854 .924 r
.69144 .28333 .69704 .28893 .70906 .28267 .70346 .27622 Mtetra
.751 .825 .91 r
.70346 .27622 .70906 .28267 .72111 .2762 .71551 .26914 Mtetra
.745 .805 .9 r
.71551 .26914 .72111 .2762 .73318 .2696 .7276 .26212 Mtetra
.739 .792 .895 r
.7276 .26212 .73318 .2696 .74528 .26296 .73973 .25524 Mtetra
.734 .784 .893 r
.73973 .25524 .74528 .26296 .75741 .25631 .7519 .24846 Mtetra
.73 .78 .892 r
.7519 .24846 .75741 .25631 .76959 .24968 .76412 .24179 Mtetra
.727 .778 .894 r
.76412 .24179 .76959 .24968 .7818 .24311 .77637 .23521 Mtetra
.585 .731 .944 r
.11732 .45366 .12449 .45992 .13405 .45872 .12698 .45172 Mtetra
.584 .707 .927 r
.12698 .45172 .13405 .45872 .14364 .45762 .13667 .44989 Mtetra
.58 .683 .911 r
.13667 .44989 .14364 .45762 .15327 .45664 .14639 .4482 Mtetra
.574 .661 .897 r
.14639 .4482 .15327 .45664 .16294 .45576 .15614 .4467 Mtetra
.565 .641 .885 r
.15614 .4467 .16294 .45576 .17264 .45503 .16591 .44544 Mtetra
.557 .624 .875 r
.16591 .44544 .17264 .45503 .18239 .45438 .1757 .4444 Mtetra
.548 .611 .868 r
.1757 .4444 .18239 .45438 .19219 .45377 .18553 .44358 Mtetra
.54 .604 .866 r
.18553 .44358 .19219 .45377 .20205 .45313 .19539 .44295 Mtetra
.533 .601 .868 r
.19539 .44295 .20205 .45313 .21197 .4524 .20529 .44247 Mtetra
.527 .605 .875 r
.20529 .44247 .21197 .4524 .22197 .45153 .21524 .44209 Mtetra
.521 .616 .887 r
.21524 .44209 .22197 .45153 .23203 .45049 .22524 .44175 Mtetra
.516 .634 .905 r
.22524 .44175 .23203 .45049 .24216 .44924 .23531 .44135 Mtetra
.513 .659 .926 r
.23531 .44135 .24216 .44924 .25237 .44777 .24545 .44083 Mtetra
.516 .692 .948 r
.24545 .44083 .25237 .44777 .26265 .44598 .25567 .44003 Mtetra
.524 .732 .969 r
.25567 .44003 .26265 .44598 .27302 .44377 .26598 .43881 Mtetra
.538 .775 .985 r
.26598 .43881 .27302 .44377 .28348 .44098 .27639 .43706 Mtetra
.554 .82 .996 r
.27639 .43706 .28348 .44098 .29404 .43745 .28689 .4347 Mtetra
.552 .861 .997 r
.28689 .4347 .29404 .43745 .30469 .43319 .29749 .43183 Mtetra
.519 .889 .973 r
.29749 .43183 .30469 .43319 .31543 .4282 .30815 .42854 Mtetra
.415 .863 .882 r
.30815 .42854 .31543 .4282 .32623 .42275 .31888 .42504 Mtetra
.234 .74 .687 r
.31888 .42504 .32623 .42275 .33707 .41702 .32965 .42149 Mtetra
0 0 0 r
.32965 .42149 .33707 .41702 .34794 .41126 .34046 .41799 Mtetra
.124 0 0 r
.34046 .41799 .34794 .41126 .35884 .40567 .35131 .4146 Mtetra
.222 0 0 r
.35131 .4146 .35884 .40567 .36975 .40031 .3622 .41129 Mtetra
.282 0 .034 r
.3622 .41129 .36975 .40031 .38068 .39528 .37314 .40804 Mtetra
.318 0 .097 r
.37314 .40804 .38068 .39528 .39164 .39053 .38412 .40478 Mtetra
.339 0 .137 r
.38412 .40478 .39164 .39053 .40262 .38608 .39516 .40145 Mtetra
.349 0 .162 r
.39516 .40145 .40262 .38608 .41363 .38187 .40624 .398 Mtetra
.354 0 .176 r
.40624 .398 .41363 .38187 .42467 .37789 .41738 .39439 Mtetra
.353 0 .182 r
.41738 .39439 .42467 .37789 .43575 .37412 .42857 .39061 Mtetra
.348 0 .179 r
.42857 .39061 .43575 .37412 .44688 .37055 .43982 .38665 Mtetra
.339 0 .17 r
.43982 .38665 .44688 .37055 .45804 .3672 .45111 .38253 Mtetra
.325 0 .151 r
.45111 .38253 .45804 .3672 .46925 .36411 .46245 .37828 Mtetra
.306 0 .122 r
.46245 .37828 .46925 .36411 .48051 .36131 .47383 .37397 Mtetra
.279 0 .078 r
.47383 .37397 .48051 .36131 .49182 .35881 .48526 .36964 Mtetra
.24 0 .012 r
.48526 .36964 .49182 .35881 .50318 .35663 .49673 .36537 Mtetra
.18 0 0 r
.49673 .36537 .50318 .35663 .5146 .3547 .50825 .36118 Mtetra
.088 0 0 r
.50825 .36118 .5146 .3547 .52609 .35295 .51981 .3571 Mtetra
0 0 0 r
.51981 .3571 .52609 .35295 .53763 .35117 .53142 .35306 Mtetra
.261 .758 .699 r
.53142 .35306 .53763 .35117 .54924 .34911 .54308 .34897 Mtetra
.461 .887 .893 r
.54308 .34897 .54924 .34911 .56091 .34659 .55479 .34467 Mtetra
.603 .921 .972 r
.55479 .34467 .56091 .34659 .57262 .34333 .56654 .33994 Mtetra
.676 .901 .976 r
.56654 .33994 .57262 .34333 .58438 .33931 .57832 .33468 Mtetra
.717 .869 .953 r
.57832 .33468 .58438 .33931 .59617 .33454 .59013 .32878 Mtetra
.737 .835 .925 r
.59013 .32878 .59617 .33454 .60799 .32916 .60197 .32233 Mtetra
.745 .803 .899 r
.60197 .32233 .60799 .32916 .61983 .32335 .61383 .31544 Mtetra
.745 .773 .876 r
.61383 .31544 .61983 .32335 .63171 .3172 .6257 .30825 Mtetra
.74 .745 .856 r
.6257 .30825 .63171 .3172 .6436 .3108 .6376 .30092 Mtetra
.733 .721 .84 r
.6376 .30092 .6436 .3108 .65553 .30419 .64952 .29351 Mtetra
.725 .702 .828 r
.64952 .29351 .65553 .30419 .66747 .29737 .66147 .28614 Mtetra
.719 .689 .82 r
.66147 .28614 .66747 .29737 .67944 .29041 .67346 .27885 Mtetra
.713 .681 .817 r
.67346 .27885 .67944 .29041 .69144 .28333 .68548 .2717 Mtetra
.709 .678 .818 r
.68548 .2717 .69144 .28333 .70346 .27622 .69753 .26473 Mtetra
.705 .68 .823 r
.69753 .26473 .70346 .27622 .71551 .26914 .70964 .25799 Mtetra
.703 .687 .831 r
.70964 .25799 .71551 .26914 .7276 .26212 .72179 .25146 Mtetra
.701 .697 .843 r
.72179 .25146 .7276 .26212 .73973 .25524 .73399 .24518 Mtetra
.7 .711 .856 r
.73399 .24518 .73973 .25524 .7519 .24846 .74624 .23907 Mtetra
.701 .728 .871 r
.74624 .23907 .7519 .24846 .76412 .24179 .75855 .23311 Mtetra
.702 .748 .888 r
.75855 .23311 .76412 .24179 .77637 .23521 .7709 .22725 Mtetra
.642 .748 .926 r
.1101 .44736 .11732 .45366 .12698 .45172 .11992 .44425 Mtetra
.638 .711 .9 r
.11992 .44425 .12698 .45172 .13667 .44989 .12977 .44122 Mtetra
.631 .676 .875 r
.12977 .44122 .13667 .44989 .14639 .4482 .13964 .43834 Mtetra
.62 .644 .852 r
.13964 .43834 .14639 .4482 .15614 .4467 .14952 .43566 Mtetra
.608 .615 .832 r
.14952 .43566 .15614 .4467 .16591 .44544 .15942 .43326 Mtetra
.596 .589 .815 r
.15942 .43326 .16591 .44544 .1757 .4444 .16933 .43115 Mtetra
.584 .566 .799 r
.16933 .43115 .1757 .4444 .18553 .44358 .17925 .42938 Mtetra
.574 .547 .787 r
.17925 .42938 .18553 .44358 .19539 .44295 .18918 .42792 Mtetra
.564 .531 .776 r
.18918 .42792 .19539 .44295 .20529 .44247 .19914 .42674 Mtetra
.558 .519 .768 r
.19914 .42674 .20529 .44247 .21524 .44209 .20913 .42577 Mtetra
.554 .511 .761 r
.20913 .42577 .21524 .44209 .22524 .44175 .21917 .42492 Mtetra
.555 .505 .755 r
.21917 .42492 .22524 .44175 .23531 .44135 .22926 .42406 Mtetra
.558 .503 .75 r
.22926 .42406 .23531 .44135 .24545 .44083 .23943 .42306 Mtetra
.563 .501 .744 r
.23943 .42306 .24545 .44083 .25567 .44003 .24966 .42184 Mtetra
.569 .501 .74 r
.24966 .42184 .25567 .44003 .26598 .43881 .25998 .42034 Mtetra
.572 .501 .737 r
.25998 .42034 .26598 .43881 .27639 .43706 .27036 .41868 Mtetra
.574 .503 .738 r
.27036 .41868 .27639 .43706 .28689 .4347 .2808 .41695 Mtetra
.572 .509 .746 r
.2808 .41695 .28689 .4347 .29749 .43183 .29129 .41532 Mtetra
.567 .52 .762 r
.29129 .41532 .29749 .43183 .30815 .42854 .30182 .41395 Mtetra
.562 .542 .79 r
.30182 .41395 .30815 .42854 .31888 .42504 .31239 .4128 Mtetra
.554 .577 .831 r
.31239 .4128 .31888 .42504 .32965 .42149 .323 .41186 Mtetra
.543 .63 .888 r
.323 .41186 .32965 .42149 .34046 .41799 .33367 .41095 Mtetra
.522 .7 .95 r
.33367 .41095 .34046 .41799 .35131 .4146 .34442 .40994 Mtetra
.481 .77 .995 r
.34442 .40994 .35131 .4146 .3622 .41129 .35523 .40869 Mtetra
.413 .811 .985 r
.35523 .40869 .3622 .41129 .37314 .40804 .36613 .40708 Mtetra
.335 .806 .916 r
.36613 .40708 .37314 .40804 .38412 .40478 .3771 .40508 Mtetra
.274 .779 .828 r
.3771 .40508 .38412 .40478 .39516 .40145 .38815 .40262 Mtetra
.242 .755 .759 r
.38815 .40262 .39516 .40145 .40624 .398 .39927 .39972 Mtetra
.239 .749 .72 r
.39927 .39972 .40624 .398 .41738 .39439 .41046 .39636 Mtetra
.262 .762 .712 r
.41046 .39636 .41738 .39439 .42857 .39061 .42171 .39256 Mtetra
.31 .793 .732 r
.42171 .39256 .42857 .39061 .43982 .38665 .43302 .3883 Mtetra
.381 .84 .776 r
.43302 .3883 .43982 .38665 .45111 .38253 .44439 .38359 Mtetra
.473 .894 .839 r
.44439 .38359 .45111 .38253 .46245 .37828 .4558 .37842 Mtetra
.577 .94 .905 r
.4558 .37842 .46245 .37828 .47383 .37397 .46727 .37279 Mtetra
.67 .954 .951 r
.46727 .37279 .47383 .37397 .48526 .36964 .47877 .36676 Mtetra
.729 .921 .957 r
.47877 .36676 .48526 .36964 .49673 .36537 .49032 .36036 Mtetra
.748 .853 .928 r
.49032 .36036 .49673 .36537 .50825 .36118 .50189 .3537 Mtetra
.739 .775 .882 r
.50189 .3537 .50825 .36118 .51981 .3571 .5135 .34693 Mtetra
.717 .702 .835 r
.5135 .34693 .51981 .3571 .53142 .35306 .52513 .34018 Mtetra
.693 .643 .796 r
.52513 .34018 .53142 .35306 .54308 .34897 .53679 .33363 Mtetra
.672 .6 .766 r
.53679 .33363 .54308 .34897 .55479 .34467 .54849 .3273 Mtetra
.657 .57 .745 r
.54849 .3273 .55479 .34467 .56654 .33994 .56022 .32121 Mtetra
.648 .553 .733 r
.56022 .32121 .56654 .33994 .57832 .33468 .57198 .31523 Mtetra
.646 .546 .727 r
.57198 .31523 .57832 .33468 .59013 .32878 .58379 .30916 Mtetra
.648 .545 .725 r
.58379 .30916 .59013 .32878 .60197 .32233 .59562 .30292 Mtetra
.653 .551 .726 r
.59562 .30292 .60197 .32233 .61383 .31544 .60748 .29638 Mtetra
.658 .557 .729 r
.60748 .29638 .61383 .31544 .6257 .30825 .61936 .28961 Mtetra
.663 .563 .732 r
.61936 .28961 .6257 .30825 .6376 .30092 .63127 .28268 Mtetra
.665 .568 .736 r
.63127 .28268 .6376 .30092 .64952 .29351 .64322 .27572 Mtetra
.666 .573 .741 r
.64322 .27572 .64952 .29351 .66147 .28614 .65519 .26889 Mtetra
.665 .578 .748 r
.65519 .26889 .66147 .28614 .67346 .27885 .66721 .26224 Mtetra
.664 .585 .756 r
.66721 .26224 .67346 .27885 .68548 .2717 .67927 .25589 Mtetra
.663 .594 .767 r
.67927 .25589 .68548 .2717 .69753 .26473 .69139 .24984 Mtetra
.661 .605 .781 r
.69139 .24984 .69753 .26473 .70964 .25799 .70357 .24414 Mtetra
.661 .62 .798 r
.70357 .24414 .70964 .25799 .72179 .25146 .71581 .23873 Mtetra
.66 .639 .817 r
.71581 .23873 .72179 .25146 .73399 .24518 .72811 .23361 Mtetra
.661 .662 .84 r
.72811 .23361 .73399 .24518 .74624 .23907 .74047 .22869 Mtetra
.663 .689 .864 r
.74047 .22869 .74624 .23907 .75855 .23311 .7529 .22392 Mtetra
.665 .72 .89 r
.7529 .22392 .75855 .23311 .7709 .22725 .76539 .21923 Mtetra
.693 .759 .903 r
.10283 .44102 .1101 .44736 .11992 .44425 .11283 .43657 Mtetra
.685 .72 .876 r
.11283 .43657 .11992 .44425 .12977 .44122 .12286 .43218 Mtetra
.674 .683 .851 r
.12286 .43218 .12977 .44122 .13964 .43834 .13291 .42789 Mtetra
.661 .649 .827 r
.13291 .42789 .13964 .43834 .14952 .43566 .14297 .42376 Mtetra
.647 .617 .806 r
.14297 .42376 .14952 .43566 .15942 .43326 .15304 .41986 Mtetra
.633 .588 .786 r
.15304 .41986 .15942 .43326 .16933 .43115 .16312 .41623 Mtetra
.619 .561 .767 r
.16312 .41623 .16933 .43115 .17925 .42938 .17319 .41291 Mtetra
.607 .537 .75 r
.17319 .41291 .17925 .42938 .18918 .42792 .18328 .40989 Mtetra
.596 .516 .735 r
.18328 .40989 .18918 .42792 .19914 .42674 .19338 .40718 Mtetra
.586 .498 .721 r
.19338 .40718 .19914 .42674 .20913 .42577 .20349 .40473 Mtetra
.579 .483 .709 r
.20349 .40473 .20913 .42577 .21917 .42492 .21363 .40248 Mtetra
.574 .471 .699 r
.21363 .40248 .21917 .42492 .22926 .42406 .22381 .40036 Mtetra
.571 .461 .69 r
.22381 .40036 .22926 .42406 .23943 .42306 .23403 .39832 Mtetra
.568 .454 .684 r
.23403 .39832 .23943 .42306 .24966 .42184 .24429 .39633 Mtetra
.566 .449 .679 r
.24429 .39633 .24966 .42184 .25998 .42034 .2546 .39439 Mtetra
.563 .446 .677 r
.2546 .39439 .25998 .42034 .27036 .41868 .26496 .39259 Mtetra
.56 .443 .677 r
.26496 .39259 .27036 .41868 .2808 .41695 .27535 .39098 Mtetra
.556 .442 .678 r
.27535 .39098 .2808 .41695 .29129 .41532 .28577 .38957 Mtetra
.553 .441 .68 r
.28577 .38957 .29129 .41532 .30182 .41395 .29625 .38837 Mtetra
.552 .441 .681 r
.29625 .38837 .30182 .41395 .31239 .4128 .30677 .38723 Mtetra
.553 .442 .682 r
.30677 .38723 .31239 .4128 .323 .41186 .31736 .38604 Mtetra
.556 .443 .681 r
.31736 .38604 .323 .41186 .33367 .41095 .32802 .38466 Mtetra
.56 .444 .678 r
.32802 .38466 .33367 .41095 .34442 .40994 .33875 .38299 Mtetra
.564 .444 .674 r
.33875 .38299 .34442 .40994 .35523 .40869 .34956 .38099 Mtetra
.569 .444 .67 r
.34956 .38099 .35523 .40869 .36613 .40708 .36045 .37864 Mtetra
.572 .444 .667 r
.36045 .37864 .36613 .40708 .3771 .40508 .37141 .37594 Mtetra
.576 .443 .663 r
.37141 .37594 .3771 .40508 .38815 .40262 .38243 .37291 Mtetra
.579 .443 .661 r
.38243 .37291 .38815 .40262 .39927 .39972 .39351 .36959 Mtetra
.581 .444 .659 r
.39351 .36959 .39927 .39972 .41046 .39636 .40466 .366 Mtetra
.584 .445 .658 r
.40466 .366 .41046 .39636 .42171 .39256 .41586 .36214 Mtetra
.587 .447 .658 r
.41586 .36214 .42171 .39256 .43302 .3883 .42711 .35803 Mtetra
.591 .45 .658 r
.42711 .35803 .43302 .3883 .44439 .38359 .43842 .35363 Mtetra
.595 .454 .66 r
.43842 .35363 .44439 .38359 .4558 .37842 .44978 .34894 Mtetra
.6 .46 .662 r
.44978 .34894 .4558 .37842 .46727 .37279 .46119 .34391 Mtetra
.605 .466 .665 r
.46119 .34391 .46727 .37279 .47877 .36676 .47264 .33854 Mtetra
.611 .472 .668 r
.47264 .33854 .47877 .36676 .49032 .36036 .48413 .33279 Mtetra
.617 .479 .671 r
.48413 .33279 .49032 .36036 .50189 .3537 .49567 .32671 Mtetra
.622 .485 .673 r
.49567 .32671 .50189 .3537 .5135 .34693 .50723 .32032 Mtetra
.626 .489 .675 r
.50723 .32032 .5135 .34693 .52513 .34018 .51883 .31373 Mtetra
.627 .49 .676 r
.51883 .31373 .52513 .34018 .53679 .33363 .53046 .30709 Mtetra
.626 .489 .676 r
.53046 .30709 .53679 .33363 .54849 .3273 .54212 .30049 Mtetra
.623 .486 .675 r
.54212 .30049 .54849 .3273 .56022 .32121 .55381 .29409 Mtetra
.619 .482 .674 r
.55381 .29409 .56022 .32121 .57198 .31523 .56554 .28789 Mtetra
.616 .48 .673 r
.56554 .28789 .57198 .31523 .58379 .30916 .57731 .28188 Mtetra
.614 .479 .673 r
.57731 .28188 .58379 .30916 .59562 .30292 .58911 .276 Mtetra
.615 .481 .676 r
.58911 .276 .59562 .30292 .60748 .29638 .60095 .27016 Mtetra
.616 .485 .68 r
.60095 .27016 .60748 .29638 .61936 .28961 .61283 .26437 Mtetra
.618 .491 .686 r
.61283 .26437 .61936 .28961 .63127 .28268 .62475 .25865 Mtetra
.62 .499 .694 r
.62475 .25865 .63127 .28268 .64322 .27572 .63672 .25305 Mtetra
.621 .509 .704 r
.63672 .25305 .64322 .27572 .65519 .26889 .64874 .24766 Mtetra
.622 .52 .716 r
.64874 .24766 .65519 .26889 .66721 .26224 .66081 .24253 Mtetra
.623 .532 .731 r
.66081 .24253 .66721 .26224 .67927 .25589 .67294 .23771 Mtetra
.623 .546 .747 r
.67294 .23771 .67927 .25589 .69139 .24984 .68514 .2332 Mtetra
.622 .563 .767 r
.68514 .2332 .69139 .24984 .70357 .24414 .69741 .22901 Mtetra
.622 .582 .788 r
.69741 .22901 .70357 .24414 .71581 .23873 .70975 .22509 Mtetra
.622 .605 .812 r
.70975 .22509 .71581 .23873 .72811 .23361 .72216 .22141 Mtetra
.621 .631 .839 r
.72216 .22141 .72811 .23361 .74047 .22869 .73465 .2179 Mtetra
.621 .661 .868 r
.73465 .2179 .74047 .22869 .7529 .22392 .7472 .21449 Mtetra
.62 .696 .898 r
.7472 .21449 .7529 .22392 .76539 .21923 .75983 .21113 Mtetra
.728 .765 .882 r
.09551 .43462 .10283 .44102 .11283 .43657 .10569 .42897 Mtetra
.719 .731 .86 r
.10569 .42897 .11283 .43657 .12286 .43218 .11589 .42332 Mtetra
.708 .699 .839 r
.11589 .42332 .12286 .43218 .13291 .42789 .12611 .41772 Mtetra
.696 .668 .819 r
.12611 .41772 .13291 .42789 .14297 .42376 .13635 .41221 Mtetra
.683 .639 .799 r
.13635 .41221 .14297 .42376 .15304 .41986 .1466 .40684 Mtetra
.67 .611 .781 r
.1466 .40684 .15304 .41986 .16312 .41623 .15685 .40164 Mtetra
.656 .585 .763 r
.15685 .40164 .16312 .41623 .17319 .41291 .16711 .39667 Mtetra
.643 .56 .746 r
.16711 .39667 .17319 .41291 .18328 .40989 .17737 .39193 Mtetra
.63 .537 .73 r
.17737 .39193 .18328 .40989 .19338 .40718 .18764 .38745 Mtetra
.618 .516 .715 r
.18764 .38745 .19338 .40718 .20349 .40473 .19791 .38323 Mtetra
.608 .497 .702 r
.19791 .38323 .20349 .40473 .21363 .40248 .20819 .37929 Mtetra
.598 .481 .691 r
.20819 .37929 .21363 .40248 .22381 .40036 .21848 .37563 Mtetra
.589 .467 .682 r
.21848 .37563 .22381 .40036 .23403 .39832 .22878 .37229 Mtetra
.581 .456 .675 r
.22878 .37229 .23403 .39832 .24429 .39633 .23909 .36929 Mtetra
.574 .447 .669 r
.23909 .36929 .24429 .39633 .2546 .39439 .24942 .36665 Mtetra
.568 .44 .666 r
.24942 .36665 .2546 .39439 .26496 .39259 .25977 .3643 Mtetra
.564 .435 .664 r
.25977 .3643 .26496 .39259 .27535 .39098 .27015 .3622 Mtetra
.563 .433 .661 r
.27015 .3622 .27535 .39098 .28577 .38957 .28057 .36012 Mtetra
.564 .431 .658 r
.28057 .36012 .28577 .38957 .29625 .38837 .29106 .3579 Mtetra
.566 .43 .654 r
.29106 .3579 .29625 .38837 .30677 .38723 .30163 .35539 Mtetra
.57 .428 .648 r
.30163 .35539 .30677 .38723 .31736 .38604 .31227 .35247 Mtetra
.572 .424 .642 r
.31227 .35247 .31736 .38604 .32802 .38466 .32298 .34917 Mtetra
.573 .42 .635 r
.32298 .34917 .32802 .38466 .33875 .38299 .33376 .34553 Mtetra
.573 .415 .629 r
.33376 .34553 .33875 .38299 .34956 .38099 .3446 .34166 Mtetra
.572 .41 .624 r
.3446 .34166 .34956 .38099 .36045 .37864 .35549 .33764 Mtetra
.571 .406 .619 r
.35549 .33764 .36045 .37864 .37141 .37594 .36642 .33355 Mtetra
.569 .403 .616 r
.36642 .33355 .37141 .37594 .38243 .37291 .3774 .32947 Mtetra
.568 .4 .614 r
.3774 .32947 .38243 .37291 .39351 .36959 .38842 .32542 Mtetra
.566 .397 .612 r
.38842 .32542 .39351 .36959 .40466 .366 .39947 .32143 Mtetra
.565 .396 .611 r
.39947 .32143 .40466 .366 .41586 .36214 .41058 .31751 Mtetra
.564 .396 .611 r
.41058 .31751 .41586 .36214 .42711 .35803 .42172 .31367 Mtetra
.564 .396 .612 r
.42172 .31367 .42711 .35803 .43842 .35363 .43291 .30988 Mtetra
.564 .397 .613 r
.43291 .30988 .43842 .35363 .44978 .34894 .44414 .30614 Mtetra
.565 .399 .616 r
.44414 .30614 .44978 .34894 .46119 .34391 .45543 .30239 Mtetra
.567 .403 .619 r
.45543 .30239 .46119 .34391 .47264 .33854 .46676 .29858 Mtetra
.57 .409 .624 r
.46676 .29858 .47264 .33854 .48413 .33279 .47814 .29461 Mtetra
.574 .416 .629 r
.47814 .29461 .48413 .33279 .49567 .32671 .48958 .29042 Mtetra
.581 .425 .635 r
.48958 .29042 .49567 .32671 .50723 .32032 .50106 .28586 Mtetra
.587 .435 .641 r
.50106 .28586 .50723 .32032 .51883 .31373 .51259 .28093 Mtetra
.595 .445 .647 r
.51259 .28093 .51883 .31373 .53046 .30709 .52416 .27558 Mtetra
.601 .453 .653 r
.52416 .27558 .53046 .30709 .54212 .30049 .53577 .26992 Mtetra
.605 .459 .657 r
.53577 .26992 .54212 .30049 .55381 .29409 .54742 .26411 Mtetra
.606 .462 .659 r
.54742 .26411 .55381 .29409 .56554 .28789 .5591 .25832 Mtetra
.604 .462 .662 r
.5591 .25832 .56554 .28789 .57731 .28188 .57083 .25277 Mtetra
.601 .462 .664 r
.57083 .25277 .57731 .28188 .58911 .276 .5826 .24752 Mtetra
.598 .463 .668 r
.5826 .24752 .58911 .276 .60095 .27016 .59442 .24263 Mtetra
.596 .466 .674 r
.59442 .24263 .60095 .27016 .61283 .26437 .60629 .23808 Mtetra
.594 .471 .681 r
.60629 .23808 .61283 .26437 .62475 .25865 .61823 .23385 Mtetra
.593 .478 .692 r
.61823 .23385 .62475 .25865 .63672 .25305 .63022 .22992 Mtetra
.593 .488 .704 r
.63022 .22992 .63672 .25305 .64874 .24766 .64228 .22626 Mtetra
.593 .5 .719 r
.64228 .22626 .64874 .24766 .66081 .24253 .65441 .22288 Mtetra
.592 .514 .736 r
.65441 .22288 .66081 .24253 .67294 .23771 .66661 .21977 Mtetra
.591 .531 .756 r
.66661 .21977 .67294 .23771 .68514 .2332 .67889 .2169 Mtetra
.589 .549 .777 r
.67889 .2169 .68514 .2332 .69741 .22901 .69125 .21426 Mtetra
.588 .57 .801 r
.69125 .21426 .69741 .22901 .70975 .22509 .70369 .2118 Mtetra
.586 .593 .826 r
.70369 .2118 .70975 .22509 .72216 .22141 .7162 .2095 Mtetra
.583 .618 .853 r
.7162 .2095 .72216 .22141 .73465 .2179 .7288 .20729 Mtetra
.579 .646 .881 r
.7288 .20729 .73465 .2179 .7472 .21449 .74147 .20513 Mtetra
.575 .677 .909 r
.74147 .20513 .7472 .21449 .75983 .21113 .75422 .20298 Mtetra
.746 .767 .87 r
.08813 .42819 .09551 .43462 .10569 .42897 .09843 .42181 Mtetra
.74 .747 .858 r
.09843 .42181 .10569 .42897 .11589 .42332 .10875 .41539 Mtetra
.734 .728 .845 r
.10875 .41539 .11589 .42332 .12611 .41772 .1191 .40897 Mtetra
.726 .708 .833 r
.1191 .40897 .12611 .41772 .13635 .41221 .12946 .40258 Mtetra
.718 .687 .82 r
.12946 .40258 .13635 .41221 .1466 .40684 .13984 .39624 Mtetra
.708 .666 .807 r
.13984 .39624 .1466 .40684 .15685 .40164 .15023 .39 Mtetra
.697 .645 .794 r
.15023 .39 .15685 .40164 .16711 .39667 .16062 .38389 Mtetra
.685 .623 .78 r
.16062 .38389 .16711 .39667 .17737 .39193 .17101 .37797 Mtetra
.673 .602 .768 r
.17101 .37797 .17737 .39193 .18764 .38745 .18141 .37227 Mtetra
.661 .582 .755 r
.18141 .37227 .18764 .38745 .19791 .38323 .19181 .36681 Mtetra
.649 .562 .744 r
.19181 .36681 .19791 .38323 .20819 .37929 .20221 .36164 Mtetra
.638 .545 .733 r
.20221 .36164 .20819 .37929 .21848 .37563 .2126 .35676 Mtetra
.626 .528 .723 r
.2126 .35676 .21848 .37563 .22878 .37229 .223 .3522 Mtetra
.617 .513 .714 r
.223 .3522 .22878 .37229 .23909 .36929 .23341 .34794 Mtetra
.608 .499 .704 r
.23341 .34794 .23909 .36929 .24942 .36665 .24383 .34395 Mtetra
.601 .487 .695 r
.24383 .34395 .24942 .36665 .25977 .3643 .25427 .34011 Mtetra
.596 .475 .685 r
.25427 .34011 .25977 .3643 .27015 .3622 .26475 .33633 Mtetra
.593 .465 .675 r
.26475 .33633 .27015 .3622 .28057 .36012 .27528 .33246 Mtetra
.592 .457 .666 r
.27528 .33246 .28057 .36012 .29106 .3579 .28587 .3284 Mtetra
.59 .449 .657 r
.28587 .3284 .29106 .3579 .30163 .35539 .2965 .32412 Mtetra
.589 .442 .649 r
.2965 .32412 .30163 .35539 .31227 .35247 .30719 .31965 Mtetra
.587 .436 .643 r
.30719 .31965 .31227 .35247 .32298 .34917 .31793 .31506 Mtetra
.585 .431 .639 r
.31793 .31506 .32298 .34917 .33376 .34553 .3287 .31045 Mtetra
.583 .427 .635 r
.3287 .31045 .33376 .34553 .3446 .34166 .33951 .30589 Mtetra
.581 .424 .633 r
.33951 .30589 .3446 .34166 .35549 .33764 .35036 .30142 Mtetra
.579 .421 .632 r
.35036 .30142 .35549 .33764 .36642 .33355 .36123 .29706 Mtetra
.577 .42 .631 r
.36123 .29706 .36642 .33355 .3774 .32947 .37214 .29282 Mtetra
.576 .418 .631 r
.37214 .29282 .3774 .32947 .38842 .32542 .38309 .28868 Mtetra
.574 .417 .631 r
.38309 .28868 .38842 .32542 .39947 .32143 .39408 .28464 Mtetra
.573 .417 .631 r
.39408 .28464 .39947 .32143 .41058 .31751 .4051 .28066 Mtetra
.572 .416 .631 r
.4051 .28066 .41058 .31751 .42172 .31367 .41617 .27677 Mtetra
.571 .415 .631 r
.41617 .27677 .42172 .31367 .43291 .30988 .42728 .27297 Mtetra
.57 .414 .631 r
.42728 .27297 .43291 .30988 .44414 .30614 .43844 .26927 Mtetra
.569 .414 .631 r
.43844 .26927 .44414 .30614 .45543 .30239 .44964 .26569 Mtetra
.568 .413 .632 r
.44964 .26569 .45543 .30239 .46676 .29858 .46089 .26222 Mtetra
.567 .414 .633 r
.46089 .26222 .46676 .29858 .47814 .29461 .47219 .25885 Mtetra
.567 .416 .636 r
.47219 .25885 .47814 .29461 .48958 .29042 .48354 .25553 Mtetra
.568 .419 .639 r
.48354 .25553 .48958 .29042 .50106 .28586 .49494 .25218 Mtetra
.571 .425 .644 r
.49494 .25218 .50106 .28586 .51259 .28093 .5064 .24873 Mtetra
.576 .433 .65 r
.5064 .24873 .51259 .28093 .52416 .27558 .51791 .24506 Mtetra
.581 .442 .657 r
.51791 .24506 .52416 .27558 .53577 .26992 .52947 .24119 Mtetra
.587 .453 .666 r
.52947 .24119 .53577 .26992 .54742 .26411 .54108 .23711 Mtetra
.591 .464 .676 r
.54108 .23711 .54742 .26411 .5591 .25832 .55274 .23294 Mtetra
.594 .474 .686 r
.55274 .23294 .5591 .25832 .57083 .25277 .56445 .22883 Mtetra
.595 .483 .696 r
.56445 .22883 .57083 .25277 .5826 .24752 .57622 .22487 Mtetra
.594 .491 .706 r
.57622 .22487 .5826 .24752 .59442 .24263 .58804 .22119 Mtetra
.592 .498 .717 r
.58804 .22119 .59442 .24263 .60629 .23808 .59993 .21781 Mtetra
.589 .506 .729 r
.59993 .21781 .60629 .23808 .61823 .23385 .61188 .21476 Mtetra
.586 .515 .742 r
.61188 .21476 .61823 .23385 .63022 .22992 .6239 .21202 Mtetra
.582 .525 .756 r
.6239 .21202 .63022 .22992 .64228 .22626 .636 .20957 Mtetra
.578 .537 .772 r
.636 .20957 .64228 .22626 .65441 .22288 .64818 .20738 Mtetra
.574 .55 .79 r
.64818 .20738 .65441 .22288 .66661 .21977 .66044 .20541 Mtetra
.57 .565 .809 r
.66044 .20541 .66661 .21977 .67889 .2169 .67278 .20364 Mtetra
.565 .582 .829 r
.67278 .20364 .67889 .2169 .69125 .21426 .68521 .20202 Mtetra
.561 .599 .849 r
.68521 .20202 .69125 .21426 .70369 .2118 .69771 .20051 Mtetra
.556 .618 .869 r
.69771 .20051 .70369 .2118 .7162 .2095 .71031 .19905 Mtetra
.551 .637 .889 r
.71031 .19905 .7162 .2095 .7288 .20729 .72298 .19763 Mtetra
.547 .656 .907 r
.72298 .19763 .7288 .20729 .74147 .20513 .73574 .19621 Mtetra
.542 .675 .925 r
.73574 .19621 .74147 .20513 .75422 .20298 .74857 .19475 Mtetra
.749 .767 .868 r
.0807 .4217 .08813 .42819 .09843 .42181 .09105 .41513 Mtetra
.749 .763 .864 r
.09105 .41513 .09843 .42181 .10875 .41539 .10143 .40849 Mtetra
.748 .757 .86 r
.10143 .40849 .10875 .41539 .1191 .40897 .11183 .40181 Mtetra
.747 .751 .856 r
.11183 .40181 .1191 .40897 .12946 .40258 .12226 .39509 Mtetra
.744 .743 .85 r
.12226 .39509 .12946 .40258 .13984 .39624 .13271 .38834 Mtetra
.74 .733 .845 r
.13271 .38834 .13984 .39624 .15023 .39 .14318 .38163 Mtetra
.735 .721 .839 r
.14318 .38163 .15023 .39 .16062 .38389 .15365 .37497 Mtetra
.727 .708 .832 r
.15365 .37497 .16062 .38389 .17101 .37797 .16414 .36844 Mtetra
.719 .693 .825 r
.16414 .36844 .17101 .37797 .18141 .37227 .17462 .36207 Mtetra
.709 .677 .817 r
.17462 .36207 .18141 .37227 .19181 .36681 .18511 .35589 Mtetra
.698 .66 .809 r
.18511 .35589 .19181 .36681 .20221 .36164 .1956 .34996 Mtetra
.688 .644 .8 r
.1956 .34996 .20221 .36164 .2126 .35676 .20609 .34423 Mtetra
.678 .626 .79 r
.20609 .34423 .2126 .35676 .223 .3522 .21659 .33871 Mtetra
.669 .609 .778 r
.21659 .33871 .223 .3522 .23341 .34794 .22711 .3333 Mtetra
.661 .59 .765 r
.22711 .3333 .23341 .34794 .24383 .34395 .23765 .32794 Mtetra
.655 .572 .749 r
.23765 .32794 .24383 .34395 .25427 .34011 .24823 .32251 Mtetra
.649 .553 .733 r
.24823 .32251 .25427 .34011 .26475 .33633 .25885 .31694 Mtetra
.642 .535 .717 r
.25885 .31694 .26475 .33633 .27528 .33246 .26951 .31126 Mtetra
.636 .518 .703 r
.26951 .31126 .27528 .33246 .28587 .3284 .2802 .30549 Mtetra
.628 .503 .691 r
.2802 .30549 .28587 .3284 .2965 .32412 .29092 .29979 Mtetra
.62 .49 .683 r
.29092 .29979 .2965 .32412 .30719 .31965 .30165 .29428 Mtetra
.613 .481 .677 r
.30165 .29428 .30719 .31965 .31793 .31506 .3124 .28904 Mtetra
.606 .473 .674 r
.3124 .28904 .31793 .31506 .3287 .31045 .32315 .28414 Mtetra
.601 .469 .673 r
.32315 .28414 .3287 .31045 .33951 .30589 .33392 .27955 Mtetra
.597 .466 .673 r
.33392 .27955 .33951 .30589 .35036 .30142 .34472 .27523 Mtetra
.594 .465 .675 r
.34472 .27523 .35036 .30142 .36123 .29706 .35554 .2711 Mtetra
.593 .466 .676 r
.35554 .2711 .36123 .29706 .37214 .29282 .36641 .26709 Mtetra
.593 .467 .678 r
.36641 .26709 .37214 .29282 .38309 .28868 .37731 .26312 Mtetra
.593 .468 .679 r
.37731 .26312 .38309 .28868 .39408 .28464 .38825 .25914 Mtetra
.594 .469 .68 r
.38825 .25914 .39408 .28464 .4051 .28066 .39925 .25512 Mtetra
.39925 .25512 .4051 .28066 .41617 .27677 .41029 .25107 Mtetra
.593 .468 .679 r
.41029 .25107 .41617 .27677 .42728 .27297 .42137 .24702 Mtetra
.592 .467 .678 r
.42137 .24702 .42728 .27297 .43844 .26927 .4325 .243 Mtetra
.59 .464 .677 r
.4325 .243 .43844 .26927 .44964 .26569 .44367 .2391 Mtetra
.586 .46 .675 r
.44367 .2391 .44964 .26569 .46089 .26222 .45488 .23539 Mtetra
.581 .456 .674 r
.45488 .23539 .46089 .26222 .47219 .25885 .46613 .23196 Mtetra
.577 .453 .675 r
.46613 .23196 .47219 .25885 .48354 .25553 .47744 .22884 Mtetra
.572 .451 .676 r
.47744 .22884 .48354 .25553 .49494 .25218 .48879 .22606 Mtetra
.568 .452 .681 r
.48879 .22606 .49494 .25218 .5064 .24873 .5002 .22357 Mtetra
.567 .456 .687 r
.5002 .22357 .5064 .24873 .51791 .24506 .51167 .22126 Mtetra
.567 .465 .697 r
.51167 .22126 .51791 .24506 .52947 .24119 .5232 .21904 Mtetra
.571 .479 .711 r
.5232 .21904 .52947 .24119 .54108 .23711 .53479 .21673 Mtetra
.577 .496 .727 r
.53479 .21673 .54108 .23711 .55274 .23294 .54645 .2143 Mtetra
.583 .515 .744 r
.54645 .2143 .55274 .23294 .56445 .22883 .55817 .21174 Mtetra
.587 .535 .763 r
.55817 .21174 .56445 .22883 .57622 .22487 .56995 .20911 Mtetra
.589 .552 .781 r
.56995 .20911 .57622 .22487 .58804 .22119 .5818 .20653 Mtetra
.588 .567 .798 r
.5818 .20653 .58804 .22119 .59993 .21781 .59371 .20407 Mtetra
.584 .58 .815 r
.59371 .20407 .59993 .21781 .61188 .21476 .60569 .20182 Mtetra
.578 .591 .83 r
.60569 .20182 .61188 .21476 .6239 .21202 .61775 .19979 Mtetra
.57 .602 .846 r
.61775 .19979 .6239 .21202 .636 .20957 .62989 .19801 Mtetra
.561 .612 .861 r
.62989 .19801 .636 .20957 .64818 .20738 .64211 .19644 Mtetra
.553 .623 .875 r
.64211 .19644 .64818 .20738 .66044 .20541 .65442 .19504 Mtetra
.545 .633 .889 r
.65442 .19504 .66044 .20541 .67278 .20364 .6668 .19378 Mtetra
.539 .644 .902 r
.6668 .19378 .67278 .20364 .68521 .20202 .67928 .19258 Mtetra
.534 .654 .912 r
.67928 .19258 .68521 .20202 .69771 .20051 .69183 .19142 Mtetra
.531 .664 .921 r
.69183 .19142 .69771 .20051 .71031 .19905 .70447 .19024 Mtetra
.529 .672 .928 r
.70447 .19024 .71031 .19905 .72298 .19763 .71719 .18903 Mtetra
.528 .679 .934 r
.71719 .18903 .72298 .19763 .73574 .19621 .72999 .18778 Mtetra
.529 .686 .938 r
.72999 .18778 .73574 .19621 .74857 .19475 .74288 .18646 Mtetra
.736 .766 .877 r
.07322 .41517 .0807 .4217 .09105 .41513 .08352 .40911 Mtetra
.742 .782 .886 r
.08352 .40911 .09105 .41513 .10143 .40849 .09386 .40298 Mtetra
.747 .799 .894 r
.09386 .40298 .10143 .40849 .11183 .40181 .10423 .39677 Mtetra
.752 .815 .902 r
.10423 .39677 .11183 .40181 .12226 .39509 .11463 .39049 Mtetra
.756 .831 .909 r
.11463 .39049 .12226 .39509 .13271 .38834 .12507 .38413 Mtetra
.759 .844 .916 r
.12507 .38413 .13271 .38834 .14318 .38163 .13553 .37773 Mtetra
.76 .856 .921 r
.13553 .37773 .14318 .38163 .15365 .37497 .14602 .3713 Mtetra
.76 .865 .926 r
.14602 .3713 .15365 .37497 .16414 .36844 .15652 .3649 Mtetra
.757 .871 .93 r
.15652 .3649 .16414 .36844 .17462 .36207 .16704 .35856 Mtetra
.754 .873 .933 r
.16704 .35856 .17462 .36207 .18511 .35589 .17758 .3523 Mtetra
.75 .871 .935 r
.17758 .3523 .18511 .35589 .1956 .34996 .18813 .34614 Mtetra
.747 .864 .934 r
.18813 .34614 .1956 .34996 .20609 .34423 .19869 .34006 Mtetra
.744 .853 .931 r
.19869 .34006 .20609 .34423 .21659 .33871 .20927 .33405 Mtetra
.742 .838 .924 r
.20927 .33405 .21659 .33871 .22711 .3333 .21988 .32807 Mtetra
.74 .82 .914 r
.21988 .32807 .22711 .3333 .23765 .32794 .23051 .32208 Mtetra
.737 .8 .902 r
.23051 .32208 .23765 .32794 .24823 .32251 .24117 .31606 Mtetra
.734 .782 .892 r
.24117 .31606 .24823 .32251 .25885 .31694 .25186 .31002 Mtetra
.728 .768 .885 r
.25186 .31002 .25885 .31694 .26951 .31126 .26257 .30406 Mtetra
.722 .76 .882 r
.26257 .30406 .26951 .31126 .2802 .30549 .27329 .29824 Mtetra
.714 .758 .887 r
.27329 .29824 .2802 .30549 .29092 .29979 .28402 .29269 Mtetra
.705 .761 .896 r
.28402 .29269 .29092 .29979 .30165 .29428 .29476 .28749 Mtetra
.695 .768 .908 r
.29476 .28749 .30165 .29428 .3124 .28904 .30551 .28261 Mtetra
.684 .778 .922 r
.30551 .28261 .3124 .28904 .32315 .28414 .31627 .27806 Mtetra
.674 .788 .935 r
.31627 .27806 .32315 .28414 .33392 .27955 .32706 .27376 Mtetra
.665 .796 .945 r
.32706 .27376 .33392 .27955 .34472 .27523 .33787 .26964 Mtetra
.659 .803 .952 r
.33787 .26964 .34472 .27523 .35554 .2711 .34872 .26563 Mtetra
.655 .807 .956 r
.34872 .26563 .35554 .2711 .36641 .26709 .35961 .26167 Mtetra
.654 .81 .958 r
.35961 .26167 .36641 .26709 .37731 .26312 .37055 .25771 Mtetra
.655 .811 .958 r
.37055 .25771 .37731 .26312 .38825 .25914 .38153 .25371 Mtetra
.656 .812 .958 r
.38153 .25371 .38825 .25914 .39925 .25512 .39255 .24967 Mtetra
.658 .812 .958 r
.39255 .24967 .39925 .25512 .41029 .25107 .40363 .24558 Mtetra
.658 .812 .957 r
.40363 .24558 .41029 .25107 .42137 .24702 .41475 .24145 Mtetra
.658 .811 .957 r
.41475 .24145 .42137 .24702 .4325 .243 .42591 .23732 Mtetra
.656 .807 .956 r
.42591 .23732 .4325 .243 .44367 .2391 .43712 .23325 Mtetra
.651 .8 .955 r
.43712 .23325 .44367 .2391 .45488 .23539 .44838 .22927 Mtetra
.643 .79 .952 r
.44838 .22927 .45488 .23539 .46613 .23196 .45968 .22549 Mtetra
.632 .775 .949 r
.45968 .22549 .46613 .23196 .47744 .22884 .47102 .22196 Mtetra
.619 .757 .944 r
.47102 .22196 .47744 .22884 .48879 .22606 .48241 .21875 Mtetra
.605 .738 .939 r
.48241 .21875 .48879 .22606 .5002 .22357 .49385 .21589 Mtetra
.59 .722 .935 r
.49385 .21589 .5002 .22357 .51167 .22126 .50535 .21337 Mtetra
.579 .711 .933 r
.50535 .21337 .51167 .22126 .5232 .21904 .5169 .21113 Mtetra
.571 .707 .934 r
.5169 .21113 .5232 .21904 .53479 .21673 .52853 .20904 Mtetra
.564 .713 .941 r
.52853 .20904 .53479 .21673 .54645 .2143 .54021 .20704 Mtetra
.56 .726 .952 r
.54021 .20704 .54645 .2143 .55817 .21174 .55197 .20501 Mtetra
.553 .743 .965 r
.55197 .20501 .55817 .21174 .56995 .20911 .56379 .20297 Mtetra
.544 .76 .977 r
.56379 .20297 .56995 .20911 .5818 .20653 .57569 .20092 Mtetra
.53 .775 .987 r
.57569 .20092 .5818 .20653 .59371 .20407 .58765 .1989 Mtetra
.513 .784 .994 r
.58765 .1989 .59371 .20407 .60569 .20182 .59968 .19695 Mtetra
.496 .788 .997 r
.59968 .19695 .60569 .20182 .61775 .19979 .61179 .19509 Mtetra
.481 .788 .998 r
.61179 .19509 .61775 .19979 .62989 .19801 .62397 .19335 Mtetra
.472 .786 .999 r
.62397 .19335 .62989 .19801 .64211 .19644 .63624 .19169 Mtetra
.469 .782 .998 r
.63624 .19169 .64211 .19644 .65442 .19504 .64858 .1901 Mtetra
.473 .777 .997 r
.64858 .1901 .65442 .19504 .6668 .19378 .661 .18853 Mtetra
.482 .772 .995 r
.661 .18853 .6668 .19378 .67928 .19258 .6735 .18696 Mtetra
.495 .765 .991 r
.6735 .18696 .67928 .19258 .69183 .19142 .68607 .18534 Mtetra
.51 .756 .985 r
.68607 .18534 .69183 .19142 .70447 .19024 .69872 .18364 Mtetra
.524 .745 .976 r
.69872 .18364 .70447 .19024 .71719 .18903 .71145 .18187 Mtetra
.536 .733 .965 r
.71145 .18187 .71719 .18903 .72999 .18778 .72425 .18003 Mtetra
.547 .719 .953 r
.72425 .18003 .72999 .18778 .74288 .18646 .73713 .1781 Mtetra
.708 .762 .894 r
.06568 .40859 .07322 .41517 .08352 .40911 .07587 .40353 Mtetra
.715 .795 .914 r
.07587 .40353 .08352 .40911 .09386 .40298 .0861 .3984 Mtetra
.72 .829 .933 r
.0861 .3984 .09386 .40298 .10423 .39677 .09637 .39318 Mtetra
.722 .864 .948 r
.09637 .39318 .10423 .39677 .11463 .39049 .10668 .38785 Mtetra
.721 .896 .959 r
.10668 .38785 .11463 .39049 .12507 .38413 .11704 .3824 Mtetra
.713 .925 .963 r
.11704 .3824 .12507 .38413 .13553 .37773 .12744 .37686 Mtetra
.699 .946 .958 r
.12744 .37686 .13553 .37773 .14602 .3713 .13787 .37121 Mtetra
.676 .958 .945 r
.13787 .37121 .14602 .3713 .15652 .3649 .14834 .3655 Mtetra
.648 .961 .924 r
.14834 .3655 .15652 .3649 .16704 .35856 .15885 .35973 Mtetra
.619 .957 .9 r
.15885 .35973 .16704 .35856 .17758 .3523 .16939 .35391 Mtetra
.592 .948 .875 r
.16939 .35391 .17758 .3523 .18813 .34614 .17995 .34806 Mtetra
.571 .94 .854 r
.17995 .34806 .18813 .34614 .19869 .34006 .19055 .34216 Mtetra
.558 .934 .84 r
.19055 .34216 .19869 .34006 .20927 .33405 .20118 .33624 Mtetra
.549 .929 .832 r
.20118 .33624 .20927 .33405 .21988 .32807 .21184 .3303 Mtetra
.539 .925 .826 r
.21184 .3303 .21988 .32807 .23051 .32208 .22252 .32438 Mtetra
.519 .915 .814 r
.22252 .32438 .23051 .32208 .24117 .31606 .23322 .31857 Mtetra
.482 .894 .79 r
.23322 .31857 .24117 .31606 .25186 .31002 .24393 .31292 Mtetra
.414 .852 .741 r
.24393 .31292 .25186 .31002 .26257 .30406 .25465 .30756 Mtetra
.319 .784 .662 r
.25465 .30756 .26257 .30406 .27329 .29824 .26537 .30254 Mtetra
0 0 0 r
.26537 .30254 .27329 .29824 .28402 .29269 .2761 .29785 Mtetra
.2761 .29785 .28402 .29269 .29476 .28749 .28684 .29346 Mtetra
.28684 .29346 .29476 .28749 .30551 .28261 .29761 .28928 Mtetra
.036 0 0 r
.29761 .28928 .30551 .28261 .31627 .27806 .30841 .28523 Mtetra
.07 0 0 r
.30841 .28523 .31627 .27806 .32706 .27376 .31925 .28122 Mtetra
.087 0 0 r
.31925 .28122 .32706 .27376 .33787 .26964 .33013 .27722 Mtetra
.093 0 0 r
.33013 .27722 .33787 .26964 .34872 .26563 .34106 .2732 Mtetra
.34106 .2732 .34872 .26563 .35961 .26167 .35203 .26916 Mtetra
.091 0 0 r
.35203 .26916 .35961 .26167 .37055 .25771 .36305 .2651 Mtetra
.088 0 0 r
.36305 .2651 .37055 .25771 .38153 .25371 .37411 .26104 Mtetra
.087 0 0 r
.37411 .26104 .38153 .25371 .39255 .24967 .38522 .25698 Mtetra
.088 0 0 r
.38522 .25698 .39255 .24967 .40363 .24558 .39637 .25291 Mtetra
.091 0 0 r
.39637 .25291 .40363 .24558 .41475 .24145 .40757 .24884 Mtetra
.095 0 0 r
.40757 .24884 .41475 .24145 .42591 .23732 .41882 .24476 Mtetra
.097 0 0 r
.41882 .24476 .42591 .23732 .43712 .23325 .43011 .24065 Mtetra
.43011 .24065 .43712 .23325 .44838 .22927 .44146 .23652 Mtetra
.091 0 0 r
.44146 .23652 .44838 .22927 .45968 .22549 .45284 .2324 Mtetra
.081 0 0 r
.45284 .2324 .45968 .22549 .47102 .22196 .46428 .22832 Mtetra
.065 0 0 r
.46428 .22832 .47102 .22196 .48241 .21875 .47576 .22438 Mtetra
.042 0 0 r
.47576 .22438 .48241 .21875 .49385 .21589 .48729 .22063 Mtetra
.016 0 0 r
.48729 .22063 .49385 .21589 .50535 .21337 .49887 .2172 Mtetra
0 0 0 r
.49887 .2172 .50535 .21337 .5169 .21113 .51051 .2141 Mtetra
.51051 .2141 .5169 .21113 .52853 .20904 .5222 .21136 Mtetra
.5222 .21136 .52853 .20904 .54021 .20704 .53395 .2089 Mtetra
.53395 .2089 .54021 .20704 .55197 .20501 .54577 .20662 Mtetra
.54577 .20662 .55197 .20501 .56379 .20297 .55766 .20446 Mtetra
.55766 .20446 .56379 .20297 .57569 .20092 .56962 .20231 Mtetra
.56962 .20231 .57569 .20092 .58765 .1989 .58165 .20016 Mtetra
.58165 .20016 .58765 .1989 .59968 .19695 .59374 .19798 Mtetra
.132 .676 .702 r
.59374 .19798 .59968 .19695 .61179 .19509 .60591 .19576 Mtetra
.164 .702 .74 r
.60591 .19576 .61179 .19509 .62397 .19335 .61815 .1935 Mtetra
.21 .736 .79 r
.61815 .1935 .62397 .19335 .63624 .19169 .63045 .1912 Mtetra
.267 .773 .849 r
.63045 .1912 .63624 .19169 .64858 .1901 .64283 .18885 Mtetra
.332 .807 .907 r
.64283 .18885 .64858 .1901 .661 .18853 .65527 .18642 Mtetra
.4 .831 .956 r
.65527 .18642 .661 .18853 .6735 .18696 .66778 .1839 Mtetra
.461 .84 .987 r
.66778 .1839 .6735 .18696 .68607 .18534 .68036 .18127 Mtetra
.512 .834 .999 r
.68036 .18127 .68607 .18534 .69872 .18364 .69301 .17852 Mtetra
.55 .814 .995 r
.69301 .17852 .69872 .18364 .71145 .18187 .70572 .17566 Mtetra
.575 .787 .979 r
.70572 .17566 .71145 .18187 .72425 .18003 .7185 .17271 Mtetra
.591 .757 .957 r
.7185 .17271 .72425 .18003 .73713 .1781 .73134 .16968 Mtetra
.661 .753 .918 r
.05808 .40196 .06568 .40859 .07587 .40353 .06811 .39822 Mtetra
.663 .797 .946 r
.06811 .39822 .07587 .40353 .0861 .3984 .07818 .39441 Mtetra
.659 .843 .971 r
.07818 .39441 .0861 .3984 .09637 .39318 .08831 .39049 Mtetra
.645 .885 .984 r
.08831 .39049 .09637 .39318 .10668 .38785 .09848 .38646 Mtetra
.618 .916 .979 r
.09848 .38646 .10668 .38785 .11704 .3824 .10872 .38227 Mtetra
.572 .927 .948 r
.10872 .38227 .11704 .3824 .12744 .37686 .119 .37794 Mtetra
.506 .91 .887 r
.119 .37794 .12744 .37686 .13787 .37121 .12934 .37347 Mtetra
.426 .867 .801 r
.12934 .37347 .13787 .37121 .14834 .3655 .13973 .36887 Mtetra
.339 .804 .7 r
.13973 .36887 .14834 .3655 .15885 .35973 .15017 .36415 Mtetra
0 0 0 r
.15017 .36415 .15885 .35973 .16939 .35391 .16065 .35935 Mtetra
.16065 .35935 .16939 .35391 .17995 .34806 .17117 .35449 Mtetra
.17117 .35449 .17995 .34806 .19055 .34216 .18173 .34959 Mtetra
.18173 .34959 .19055 .34216 .20118 .33624 .19233 .34468 Mtetra
.033 0 0 r
.19233 .34468 .20118 .33624 .21184 .3303 .20295 .33983 Mtetra
.093 0 0 r
.20295 .33983 .21184 .3303 .22252 .32438 .2136 .33506 Mtetra
.15 0 0 r
.2136 .33506 .22252 .32438 .23322 .31857 .22427 .33045 Mtetra
.2 0 0 r
.22427 .33045 .23322 .31857 .24393 .31292 .23496 .32602 Mtetra
.241 0 .034 r
.23496 .32602 .24393 .31292 .25465 .30756 .24567 .32179 Mtetra
.273 0 .075 r
.24567 .32179 .25465 .30756 .26537 .30254 .2564 .31773 Mtetra
.293 0 .104 r
.2564 .31773 .26537 .30254 .2761 .29785 .26718 .31374 Mtetra
.303 0 .122 r
.26718 .31374 .2761 .29785 .28684 .29346 .27799 .30975 Mtetra
.306 0 .129 r
.27799 .30975 .28684 .29346 .29761 .28928 .28885 .30567 Mtetra
.303 0 .13 r
.28885 .30567 .29761 .28928 .30841 .28523 .29977 .30145 Mtetra
.297 0 .124 r
.29977 .30145 .30841 .28523 .31925 .28122 .31074 .29712 Mtetra
.29 0 .116 r
.31074 .29712 .31925 .28122 .33013 .27722 .32176 .29269 Mtetra
.283 0 .105 r
.32176 .29269 .33013 .27722 .34106 .2732 .33281 .28823 Mtetra
.278 0 .096 r
.33281 .28823 .34106 .2732 .35203 .26916 .34391 .2838 Mtetra
.276 0 .088 r
.34391 .2838 .35203 .26916 .36305 .2651 .35505 .27945 Mtetra
.278 0 .083 r
.35505 .27945 .36305 .2651 .37411 .26104 .36623 .27523 Mtetra
.282 0 .083 r
.36623 .27523 .37411 .26104 .38522 .25698 .37744 .27115 Mtetra
.288 0 .086 r
.37744 .27115 .38522 .25698 .39637 .25291 .38869 .26722 Mtetra
.296 0 .092 r
.38869 .26722 .39637 .25291 .40757 .24884 .39999 .26341 Mtetra
.304 0 .102 r
.39999 .26341 .40757 .24884 .41882 .24476 .41133 .25969 Mtetra
.311 0 .112 r
.41133 .25969 .41882 .24476 .43011 .24065 .42272 .25599 Mtetra
.317 0 .122 r
.42272 .25599 .43011 .24065 .44146 .23652 .43416 .25227 Mtetra
.319 0 .13 r
.43416 .25227 .44146 .23652 .45284 .2324 .44566 .24845 Mtetra
.32 0 .135 r
.44566 .24845 .45284 .2324 .46428 .22832 .45721 .24452 Mtetra
.318 0 .137 r
.45721 .24452 .46428 .22832 .47576 .22438 .46882 .24044 Mtetra
.314 0 .133 r
.46882 .24044 .47576 .22438 .48729 .22063 .48047 .23627 Mtetra
.309 0 .124 r
.48047 .23627 .48729 .22063 .49887 .2172 .49218 .2321 Mtetra
.302 0 .108 r
.49218 .2321 .49887 .2172 .51051 .2141 .50394 .22799 Mtetra
.294 0 .085 r
.50394 .22799 .51051 .2141 .5222 .21136 .51575 .22407 Mtetra
.282 0 .055 r
.51575 .22407 .5222 .21136 .53395 .2089 .52761 .22034 Mtetra
.266 0 .016 r
.52761 .22034 .53395 .2089 .54577 .20662 .53953 .2168 Mtetra
.246 0 0 r
.53953 .2168 .54577 .20662 .55766 .20446 .55151 .21341 Mtetra
.219 0 0 r
.55151 .21341 .55766 .20446 .56962 .20231 .56355 .21012 Mtetra
.186 0 0 r
.56355 .21012 .56962 .20231 .58165 .20016 .57565 .20688 Mtetra
.145 0 0 r
.57565 .20688 .58165 .20016 .59374 .19798 .58782 .20363 Mtetra
.095 0 0 r
.58782 .20363 .59374 .19798 .60591 .19576 .60005 .20035 Mtetra
.034 0 0 r
.60005 .20035 .60591 .19576 .61815 .1935 .61233 .197 Mtetra
0 0 0 r
.61233 .197 .61815 .1935 .63045 .1912 .62468 .19357 Mtetra
.62468 .19357 .63045 .1912 .64283 .18885 .63709 .19001 Mtetra
.245 .754 .732 r
.63709 .19001 .64283 .18885 .65527 .18642 .64956 .18632 Mtetra
.361 .833 .848 r
.64956 .18632 .65527 .18642 .66778 .1839 .66208 .18248 Mtetra
.467 .881 .936 r
.66208 .18248 .66778 .1839 .68036 .18127 .67466 .17849 Mtetra
.55 .893 .982 r
.67466 .17849 .68036 .18127 .69301 .17852 .68729 .17433 Mtetra
.604 .873 .992 r
.68729 .17433 .69301 .17852 .70572 .17566 .69997 .17005 Mtetra
.635 .836 .978 r
.69997 .17005 .70572 .17566 .7185 .17271 .71271 .16565 Mtetra
.649 .793 .952 r
.71271 .16565 .7185 .17271 .73134 .16968 .7255 .16118 Mtetra
.595 .735 .941 r
.05043 .39529 .05808 .40196 .06811 .39822 .06028 .39294 Mtetra
.586 .78 .972 r
.06028 .39294 .06811 .39822 .07818 .39441 .07017 .39053 Mtetra
.566 .825 .994 r
.07017 .39053 .07818 .39441 .08831 .39049 .08013 .38801 Mtetra
.53 .859 .996 r
.08013 .38801 .08831 .39049 .09848 .38646 .09015 .38536 Mtetra
.474 .871 .964 r
.09015 .38536 .09848 .38646 .10872 .38227 .10024 .38255 Mtetra
.395 .85 .892 r
.10024 .38255 .10872 .38227 .119 .37794 .11039 .37958 Mtetra
.301 .795 .784 r
.11039 .37958 .119 .37794 .12934 .37347 .12061 .37643 Mtetra
0 0 0 r
.12061 .37643 .12934 .37347 .13973 .36887 .1309 .37313 Mtetra
.1309 .37313 .13973 .36887 .15017 .36415 .14124 .36969 Mtetra
.14124 .36969 .15017 .36415 .16065 .35935 .15163 .36616 Mtetra
.048 0 0 r
.15163 .36616 .16065 .35935 .17117 .35449 .16208 .36257 Mtetra
.112 0 0 r
.16208 .36257 .17117 .35449 .18173 .34959 .17256 .35897 Mtetra
.169 0 0 r
.17256 .35897 .18173 .34959 .19233 .34468 .18309 .35543 Mtetra
.217 0 0 r
.18309 .35543 .19233 .34468 .20295 .33983 .19365 .35197 Mtetra
.259 0 .016 r
.19365 .35197 .20295 .33983 .2136 .33506 .20424 .34864 Mtetra
.292 0 .067 r
.20424 .34864 .2136 .33506 .22427 .33045 .21486 .34541 Mtetra
.318 0 .108 r
.21486 .34541 .22427 .33045 .23496 .32602 .22552 .34229 Mtetra
.334 0 .138 r
.22552 .34229 .23496 .32602 .24567 .32179 .23624 .33915 Mtetra
.343 0 .158 r
.23624 .33915 .24567 .32179 .2564 .31773 .24701 .3359 Mtetra
.344 0 .169 r
.24701 .3359 .2564 .31773 .26718 .31374 .25784 .33243 Mtetra
.338 0 .173 r
.25784 .33243 .26718 .31374 .27799 .30975 .26875 .32862 Mtetra
.33 0 .171 r
.26875 .32862 .27799 .30975 .28885 .30567 .27974 .32449 Mtetra
.32 0 .166 r
.27974 .32449 .28885 .30567 .29977 .30145 .29079 .32003 Mtetra
.311 0 .158 r
.29079 .32003 .29977 .30145 .31074 .29712 .30189 .31536 Mtetra
.304 0 .151 r
.30189 .31536 .31074 .29712 .32176 .29269 .31305 .31056 Mtetra
.3 0 .145 r
.31305 .31056 .32176 .29269 .33281 .28823 .32424 .30577 Mtetra
.3 0 .14 r
.32424 .30577 .33281 .28823 .34391 .2838 .33547 .30107 Mtetra
.303 0 .138 r
.33547 .30107 .34391 .2838 .35505 .27945 .34674 .29652 Mtetra
.309 0 .138 r
.34674 .29652 .35505 .27945 .36623 .27523 .35803 .29219 Mtetra
.316 0 .141 r
.35803 .29219 .36623 .27523 .37744 .27115 .36936 .2881 Mtetra
.325 0 .145 r
.36936 .2881 .37744 .27115 .38869 .26722 .38072 .28425 Mtetra
.333 0 .15 r
.38072 .28425 .38869 .26722 .39999 .26341 .39213 .28062 Mtetra
.341 0 .156 r
.39213 .28062 .39999 .26341 .41133 .25969 .40358 .27714 Mtetra
.347 0 .162 r
.40358 .27714 .41133 .25969 .42272 .25599 .41508 .27376 Mtetra
.35 0 .168 r
.41508 .27376 .42272 .25599 .43416 .25227 .42664 .27038 Mtetra
.35 0 .173 r
.42664 .27038 .43416 .25227 .44566 .24845 .43825 .26688 Mtetra
.348 0 .176 r
.43825 .26688 .44566 .24845 .45721 .24452 .44992 .26317 Mtetra
.341 0 .176 r
.44992 .26317 .45721 .24452 .46882 .24044 .46166 .25912 Mtetra
.332 0 .173 r
.46166 .25912 .46882 .24044 .48047 .23627 .47345 .25474 Mtetra
.321 0 .166 r
.47345 .25474 .48047 .23627 .49218 .2321 .4853 .25003 Mtetra
.309 0 .154 r
.4853 .25003 .49218 .2321 .50394 .22799 .4972 .24507 Mtetra
.296 0 .136 r
.4972 .24507 .50394 .22799 .51575 .22407 .50914 .24001 Mtetra
.28 0 .112 r
.50914 .24001 .51575 .22407 .52761 .22034 .52113 .23492 Mtetra
.263 0 .08 r
.52113 .23492 .52761 .22034 .53953 .2168 .53317 .22993 Mtetra
.241 0 .041 r
.53317 .22993 .53953 .2168 .55151 .21341 .54525 .22504 Mtetra
.215 0 0 r
.54525 .22504 .55151 .21341 .56355 .21012 .55739 .22029 Mtetra
.181 0 0 r
.55739 .22029 .56355 .21012 .57565 .20688 .56958 .21561 Mtetra
.138 0 0 r
.56958 .21561 .57565 .20688 .58782 .20363 .58182 .21098 Mtetra
.083 0 0 r
.58182 .21098 .58782 .20363 .60005 .20035 .59411 .20635 Mtetra
.013 0 0 r
.59411 .20635 .60005 .20035 .61233 .197 .60646 .20164 Mtetra
0 0 0 r
.60646 .20164 .61233 .197 .62468 .19357 .61886 .19684 Mtetra
.61886 .19684 .62468 .19357 .63709 .19001 .6313 .19189 Mtetra
.309 .787 .702 r
.6313 .19189 .63709 .19001 .64956 .18632 .64379 .18678 Mtetra
.437 .875 .829 r
.64379 .18678 .64956 .18632 .66208 .18248 .65632 .18147 Mtetra
.548 .925 .921 r
.65632 .18147 .66208 .18248 .67466 .17849 .6689 .176 Mtetra
.628 .932 .967 r
.6689 .176 .67466 .17849 .68729 .17433 .68152 .17034 Mtetra
.675 .906 .976 r
.68152 .17034 .68729 .17433 .69997 .17005 .69417 .16453 Mtetra
.697 .864 .961 r
.69417 .16453 .69997 .17005 .71271 .16565 .70687 .15861 Mtetra
.703 .816 .935 r
.70687 .15861 .71271 .16565 .7255 .16118 .71961 .15261 Mtetra
.52 .709 .957 r
.04273 .38856 .05043 .39529 .06028 .39294 .0524 .38743 Mtetra
.5 .745 .982 r
.0524 .38743 .06028 .39294 .07017 .39053 .06215 .38623 Mtetra
.471 .778 .997 r
.06215 .38623 .07017 .39053 .08013 .38801 .07195 .38495 Mtetra
.429 .801 .994 r
.07195 .38495 .08013 .38801 .09015 .38536 .08183 .38354 Mtetra
.372 .807 .961 r
.08183 .38354 .09015 .38536 .10024 .38255 .09178 .38197 Mtetra
.297 .786 .894 r
.09178 .38197 .10024 .38255 .11039 .37958 .10181 .38025 Mtetra
.213 .738 .794 r
.10181 .38025 .11039 .37958 .12061 .37643 .1119 .37836 Mtetra
0 0 0 r
.1119 .37836 .12061 .37643 .1309 .37313 .12207 .37632 Mtetra
.12207 .37632 .1309 .37313 .14124 .36969 .13231 .37412 Mtetra
.033 0 0 r
.13231 .37412 .14124 .36969 .15163 .36616 .14262 .37181 Mtetra
.094 0 0 r
.14262 .37181 .15163 .36616 .16208 .36257 .15299 .36938 Mtetra
.143 0 0 r
.15299 .36938 .16208 .36257 .17256 .35897 .16342 .36687 Mtetra
.182 0 0 r
.16342 .36687 .17256 .35897 .18309 .35543 .1739 .36428 Mtetra
.21 0 0 r
.1739 .36428 .18309 .35543 .19365 .35197 .18445 .36163 Mtetra
.23 0 0 r
.18445 .36163 .19365 .35197 .20424 .34864 .19505 .3589 Mtetra
.24 0 0 r
.19505 .3589 .20424 .34864 .21486 .34541 .20571 .35607 Mtetra
.243 0 0 r
.20571 .35607 .21486 .34541 .22552 .34229 .21644 .35311 Mtetra
.237 0 0 r
.21644 .35311 .22552 .34229 .23624 .33915 .22723 .34997 Mtetra
.225 0 0 r
.22723 .34997 .23624 .33915 .24701 .3359 .2381 .34659 Mtetra
.21 0 0 r
.2381 .34659 .24701 .3359 .25784 .33243 .24903 .343 Mtetra
.196 0 0 r
.24903 .343 .25784 .33243 .26875 .32862 .26002 .3392 Mtetra
.188 0 0 r
.26002 .3392 .26875 .32862 .27974 .32449 .27108 .33525 Mtetra
.189 0 0 r
.27108 .33525 .27974 .32449 .29079 .32003 .28218 .3312 Mtetra
.199 0 0 r
.28218 .3312 .29079 .32003 .30189 .31536 .29334 .3271 Mtetra
.214 0 0 r
.29334 .3271 .30189 .31536 .31305 .31056 .30454 .32298 Mtetra
.232 0 .004 r
.30454 .32298 .31305 .31056 .32424 .30577 .31579 .31886 Mtetra
.248 0 .029 r
.31579 .31886 .32424 .30577 .33547 .30107 .32708 .31475 Mtetra
.26 0 .049 r
.32708 .31475 .33547 .30107 .34674 .29652 .33842 .31065 Mtetra
.269 0 .062 r
.33842 .31065 .34674 .29652 .35803 .29219 .34981 .30655 Mtetra
.274 0 .07 r
.34981 .30655 .35803 .29219 .36936 .2881 .36125 .30244 Mtetra
.275 0 .07 r
.36125 .30244 .36936 .2881 .38072 .28425 .37273 .29834 Mtetra
.272 0 .063 r
.37273 .29834 .38072 .28425 .39213 .28062 .38426 .29423 Mtetra
.264 0 .051 r
.38426 .29423 .39213 .28062 .40358 .27714 .39585 .29013 Mtetra
.254 0 .032 r
.39585 .29013 .40358 .27714 .41508 .27376 .40748 .28604 Mtetra
.24 0 .009 r
.40748 .28604 .41508 .27376 .42664 .27038 .41916 .28194 Mtetra
.225 0 0 r
.41916 .28194 .42664 .27038 .43825 .26688 .43089 .27783 Mtetra
.208 0 0 r
.43089 .27783 .43825 .26688 .44992 .26317 .44268 .27367 Mtetra
.192 0 0 r
.44268 .27367 .44992 .26317 .46166 .25912 .45452 .26941 Mtetra
.179 0 0 r
.45452 .26941 .46166 .25912 .47345 .25474 .46642 .26499 Mtetra
.168 0 0 r
.46642 .26499 .47345 .25474 .4853 .25003 .47836 .26036 Mtetra
.16 0 0 r
.47836 .26036 .4853 .25003 .4972 .24507 .49037 .25549 Mtetra
.153 0 0 r
.49037 .25549 .4972 .24507 .50914 .24001 .50242 .2504 Mtetra
.144 0 0 r
.50242 .2504 .50914 .24001 .52113 .23492 .51452 .24511 Mtetra
.132 0 0 r
.51452 .24511 .52113 .23492 .53317 .22993 .52666 .23968 Mtetra
.113 0 0 r
.52666 .23968 .53317 .22993 .54525 .22504 .53885 .23413 Mtetra
.086 0 0 r
.53885 .23413 .54525 .22504 .55739 .22029 .55109 .22851 Mtetra
.047 0 0 r
.55109 .22851 .55739 .22029 .56958 .21561 .56336 .2228 Mtetra
0 0 0 r
.56336 .2228 .56958 .21561 .58182 .21098 .57568 .21702 Mtetra
.57568 .21702 .58182 .21098 .59411 .20635 .58805 .21114 Mtetra
.58805 .21114 .59411 .20635 .60646 .20164 .60045 .20514 Mtetra
.60045 .20514 .60646 .20164 .61886 .19684 .6129 .199 Mtetra
.388 .832 .709 r
.6129 .199 .61886 .19684 .6313 .19189 .62538 .19269 Mtetra
.502 .907 .818 r
.62538 .19269 .6313 .19189 .64379 .18678 .6379 .18622 Mtetra
.6 .95 .899 r
.6379 .18622 .64379 .18678 .65632 .18147 .65045 .17956 Mtetra
.671 .958 .944 r
.65045 .17956 .65632 .18147 .6689 .176 .66304 .17272 Mtetra
.715 .939 .959 r
.66304 .17272 .6689 .176 .68152 .17034 .67565 .16571 Mtetra
.737 .905 .953 r
.67565 .16571 .68152 .17034 .69417 .16453 .68829 .15856 Mtetra
.744 .865 .936 r
.68829 .15856 .69417 .16453 .70687 .15861 .70097 .15131 Mtetra
.743 .823 .914 r
.70097 .15131 .70687 .15861 .71961 .15261 .71368 .14397 Mtetra
.451 .681 .963 r
.03496 .38178 .04273 .38856 .0524 .38743 .04452 .38154 Mtetra
.432 .705 .979 r
.04452 .38154 .0524 .38743 .06215 .38623 .05414 .38123 Mtetra
.408 .727 .99 r
.05414 .38123 .06215 .38623 .07195 .38495 .06384 .38083 Mtetra
.378 .745 .991 r
.06384 .38083 .07195 .38495 .08183 .38354 .07361 .38033 Mtetra
.343 .757 .979 r
.07361 .38033 .08183 .38354 .09178 .38197 .08346 .37969 Mtetra
.298 .758 .951 r
.08346 .37969 .09178 .38197 .10181 .38025 .09338 .37891 Mtetra
.247 .745 .903 r
.09338 .37891 .10181 .38025 .1119 .37836 .10339 .37797 Mtetra
.187 .717 .835 r
.10339 .37797 .1119 .37836 .12207 .37632 .11347 .37689 Mtetra
.124 .674 .752 r
.11347 .37689 .12207 .37632 .13231 .37412 .12363 .37567 Mtetra
0 0 0 r
.12363 .37567 .13231 .37412 .14262 .37181 .13386 .37428 Mtetra
.13386 .37428 .14262 .37181 .15299 .36938 .14417 .37275 Mtetra
.031 0 0 r
.14417 .37275 .15299 .36938 .16342 .36687 .15456 .37103 Mtetra
.061 0 0 r
.15456 .37103 .16342 .36687 .1739 .36428 .16503 .36911 Mtetra
.075 0 0 r
.16503 .36911 .1739 .36428 .18445 .36163 .17558 .36694 Mtetra
.17558 .36694 .18445 .36163 .19505 .3589 .18621 .36449 Mtetra
.062 0 0 r
.18621 .36449 .19505 .3589 .20571 .35607 .19693 .36172 Mtetra
.035 0 0 r
.19693 .36172 .20571 .35607 .21644 .35311 .20773 .35862 Mtetra
0 0 0 r
.20773 .35862 .21644 .35311 .22723 .34997 .21861 .35523 Mtetra
.21861 .35523 .22723 .34997 .2381 .34659 .22957 .35157 Mtetra
.22957 .35157 .2381 .34659 .24903 .343 .24058 .34781 Mtetra
.24058 .34781 .24903 .343 .26002 .3392 .25164 .34404 Mtetra
.25164 .34404 .26002 .3392 .27108 .33525 .26273 .34037 Mtetra
.26273 .34037 .27108 .33525 .28218 .3312 .27386 .33689 Mtetra
.028 0 0 r
.27386 .33689 .28218 .3312 .29334 .3271 .28503 .33353 Mtetra
.077 0 0 r
.28503 .33353 .29334 .3271 .30454 .32298 .29625 .33026 Mtetra
.116 0 0 r
.29625 .33026 .30454 .32298 .31579 .31886 .30752 .32696 Mtetra
.144 0 0 r
.30752 .32696 .31579 .31886 .32708 .31475 .31885 .32357 Mtetra
.158 0 0 r
.31885 .32357 .32708 .31475 .33842 .31065 .33024 .31998 Mtetra
.162 0 0 r
.33024 .31998 .33842 .31065 .34981 .30655 .3417 .31614 Mtetra
.154 0 0 r
.3417 .31614 .34981 .30655 .36125 .30244 .35323 .31201 Mtetra
.138 0 0 r
.35323 .31201 .36125 .30244 .37273 .29834 .36482 .30761 Mtetra
.113 0 0 r
.36482 .30761 .37273 .29834 .38426 .29423 .37647 .30295 Mtetra
.08 0 0 r
.37647 .30295 .38426 .29423 .39585 .29013 .38818 .29809 Mtetra
.041 0 0 r
.38818 .29809 .39585 .29013 .40748 .28604 .39993 .29313 Mtetra
0 0 0 r
.39993 .29313 .40748 .28604 .41916 .28194 .41173 .28814 Mtetra
.41173 .28814 .41916 .28194 .43089 .27783 .42357 .28324 Mtetra
.42357 .28324 .43089 .27783 .44268 .27367 .43546 .27846 Mtetra
.43546 .27846 .44268 .27367 .45452 .26941 .44739 .27386 Mtetra
.44739 .27386 .45452 .26941 .46642 .26499 .45937 .26936 Mtetra
.45937 .26936 .46642 .26499 .47836 .26036 .47139 .26486 Mtetra
.47139 .26486 .47836 .26036 .49037 .25549 .48348 .26024 Mtetra
.48348 .26024 .49037 .25549 .50242 .2504 .49561 .25536 Mtetra
.49561 .25536 .50242 .2504 .51452 .24511 .5078 .25017 Mtetra
.5078 .25017 .51452 .24511 .52666 .23968 .52003 .24462 Mtetra
.52003 .24462 .52666 .23968 .53885 .23413 .53231 .23875 Mtetra
.53231 .23875 .53885 .23413 .55109 .22851 .54463 .23258 Mtetra
.54463 .23258 .55109 .22851 .56336 .2228 .55699 .22615 Mtetra
.34 .787 .63 r
.55699 .22615 .56336 .2228 .57568 .21702 .56939 .2195 Mtetra
.42 .848 .707 r
.56939 .2195 .57568 .21702 .58805 .21114 .58182 .21265 Mtetra
.503 .903 .783 r
.58182 .21265 .58805 .21114 .60045 .20514 .59428 .20562 Mtetra
.581 .944 .85 r
.59428 .20562 .60045 .20514 .6129 .199 .60678 .19843 Mtetra
.647 .966 .9 r
.60678 .19843 .6129 .199 .62538 .19269 .6193 .19107 Mtetra
.697 .969 .931 r
.6193 .19107 .62538 .19269 .6379 .18622 .63186 .18355 Mtetra
.732 .957 .944 r
.63186 .18355 .6379 .18622 .65045 .17956 .64444 .17585 Mtetra
.754 .935 .945 r
.64444 .17585 .65045 .17956 .66304 .17272 .65704 .16799 Mtetra
.766 .908 .937 r
.65704 .16799 .66304 .17272 .67565 .16571 .66967 .15998 Mtetra
.771 .879 .925 r
.66967 .15998 .67565 .16571 .68829 .15856 .68232 .15184 Mtetra
.77 .849 .91 r
.68232 .15184 .68829 .15856 .70097 .15131 .69499 .14359 Mtetra
.767 .819 .894 r
.69499 .14359 .70097 .15131 .71368 .14397 .70769 .13525 Mtetra
.416 .665 .963 r
.02714 .37496 .03496 .38178 .04452 .38154 .03665 .37511 Mtetra
.411 .677 .971 r
.03665 .37511 .04452 .38154 .05414 .38123 .04622 .37518 Mtetra
.407 .69 .977 r
.04622 .37518 .05414 .38123 .06384 .38083 .05588 .37515 Mtetra
.403 .702 .983 r
.05588 .37515 .06384 .38083 .07361 .38033 .06561 .37501 Mtetra
.401 .715 .987 r
.06561 .37501 .07361 .38033 .08346 .37969 .07542 .37476 Mtetra
.397 .728 .99 r
.07542 .37476 .08346 .37969 .09338 .37891 .08531 .37437 Mtetra
.393 .74 .992 r
.08531 .37437 .09338 .37891 .10339 .37797 .09527 .37385 Mtetra
.387 .752 .992 r
.09527 .37385 .10339 .37797 .11347 .37689 .10532 .37319 Mtetra
.38 .763 .99 r
.10532 .37319 .11347 .37689 .12363 .37567 .11545 .3724 Mtetra
.374 .774 .985 r
.11545 .3724 .12363 .37567 .13386 .37428 .12566 .37144 Mtetra
.368 .783 .979 r
.12566 .37144 .13386 .37428 .14417 .37275 .13595 .3703 Mtetra
.367 .794 .971 r
.13595 .3703 .14417 .37275 .15456 .37103 .14632 .36895 Mtetra
.371 .805 .964 r
.14632 .36895 .15456 .37103 .16503 .36911 .15679 .36734 Mtetra
.385 .819 .959 r
.15679 .36734 .16503 .36911 .17558 .36694 .16734 .36543 Mtetra
.407 .836 .957 r
.16734 .36543 .17558 .36694 .18621 .36449 .17799 .36315 Mtetra
.434 .852 .957 r
.17799 .36315 .18621 .36449 .19693 .36172 .18874 .36051 Mtetra
.463 .869 .958 r
.18874 .36051 .19693 .36172 .20773 .35862 .19958 .35748 Mtetra
.486 .881 .959 r
.19958 .35748 .20773 .35862 .21861 .35523 .21049 .35415 Mtetra
.501 .889 .958 r
.21049 .35415 .21861 .35523 .22957 .35157 .22148 .3506 Mtetra
.497 .889 .954 r
.22148 .3506 .22957 .35157 .24058 .34781 .23252 .347 Mtetra
.476 .883 .944 r
.23252 .347 .24058 .34781 .25164 .34404 .2436 .34349 Mtetra
.438 .868 .926 r
.2436 .34349 .25164 .34404 .26273 .34037 .25472 .34016 Mtetra
.386 .844 .898 r
.25472 .34016 .26273 .34037 .27386 .33689 .26586 .33707 Mtetra
.336 .817 .862 r
.26586 .33707 .27386 .33689 .28503 .33353 .27705 .33414 Mtetra
.291 .79 .821 r
.27705 .33414 .28503 .33353 .29625 .33026 .28829 .33129 Mtetra
.262 .77 .786 r
.28829 .33129 .29625 .33026 .30752 .32696 .29959 .32836 Mtetra
.249 .76 .758 r
.29959 .32836 .30752 .32696 .31885 .32357 .31095 .32526 Mtetra
.254 .761 .742 r
.31095 .32526 .31885 .32357 .33024 .31998 .3224 .32187 Mtetra
.273 .772 .737 r
.3224 .32187 .33024 .31998 .3417 .31614 .33391 .31813 Mtetra
.304 .792 .743 r
.33391 .31813 .3417 .31614 .35323 .31201 .3455 .31398 Mtetra
.343 .816 .758 r
.3455 .31398 .35323 .31201 .36482 .30761 .35717 .30943 Mtetra
.386 .843 .78 r
.35717 .30943 .36482 .30761 .37647 .30295 .3689 .30452 Mtetra
.429 .869 .806 r
.3689 .30452 .37647 .30295 .38818 .29809 .38068 .29932 Mtetra
.467 .891 .834 r
.38068 .29932 .38818 .29809 .39993 .29313 .39252 .29393 Mtetra
.499 .908 .861 r
.39252 .29393 .39993 .29313 .41173 .28814 .40441 .28847 Mtetra
.52 .917 .887 r
.40441 .28847 .41173 .28814 .42357 .28324 .41633 .28308 Mtetra
.535 .921 .909 r
.41633 .28308 .42357 .28324 .43546 .27846 .42829 .27784 Mtetra
.539 .919 .928 r
.42829 .27784 .43546 .27846 .44739 .27386 .44029 .27285 Mtetra
.544 .917 .942 r
.44029 .27285 .44739 .27386 .45937 .26936 .45234 .26803 Mtetra
.551 .916 .953 r
.45234 .26803 .45937 .26936 .47139 .26486 .46443 .2633 Mtetra
.562 .917 .959 r
.46443 .2633 .47139 .26486 .48348 .26024 .47657 .25853 Mtetra
.583 .923 .962 r
.47657 .25853 .48348 .26024 .49561 .25536 .48877 .25351 Mtetra
.607 .93 .964 r
.48877 .25351 .49561 .25536 .5078 .25017 .50102 .24819 Mtetra
.633 .937 .963 r
.50102 .24819 .5078 .25017 .52003 .24462 .51332 .24247 Mtetra
.659 .942 .962 r
.51332 .24247 .52003 .24462 .53231 .23875 .52566 .23636 Mtetra
.684 .944 .961 r
.52566 .23636 .53231 .23875 .54463 .23258 .53804 .22987 Mtetra
.705 .943 .959 r
.53804 .22987 .54463 .23258 .55699 .22615 .55046 .22305 Mtetra
.723 .938 .957 r
.55046 .22305 .55699 .22615 .56939 .2195 .56292 .21597 Mtetra
.738 .93 .953 r
.56292 .21597 .56939 .2195 .58182 .21265 .5754 .20864 Mtetra
.749 .92 .948 r
.5754 .20864 .58182 .21265 .59428 .20562 .58792 .20112 Mtetra
.757 .908 .942 r
.58792 .20112 .59428 .20562 .60678 .19843 .60046 .19342 Mtetra
.763 .894 .935 r
.60046 .19342 .60678 .19843 .6193 .19107 .61303 .18556 Mtetra
.768 .881 .928 r
.61303 .18556 .6193 .19107 .63186 .18355 .62563 .17754 Mtetra
.771 .867 .92 r
.62563 .17754 .63186 .18355 .64444 .17585 .63825 .16937 Mtetra
.773 .855 .911 r
.63825 .16937 .64444 .17585 .65704 .16799 .65089 .16105 Mtetra
.774 .842 .903 r
.65089 .16105 .65704 .16799 .66967 .15998 .66355 .15258 Mtetra
.775 .83 .895 r
.66355 .15258 .66967 .15998 .68232 .15184 .67623 .14399 Mtetra
.774 .818 .887 r
.67623 .14399 .68232 .15184 .69499 .14359 .68893 .13528 Mtetra
.773 .806 .879 r
.68893 .13528 .69499 .14359 .70769 .13525 .70165 .12647 Mtetra
.437 .674 .963 r
.01926 .36808 .02714 .37496 .03665 .37511 .02881 .36796 Mtetra
.453 .673 .958 r
.02881 .36796 .03665 .37511 .04622 .37518 .03844 .36772 Mtetra
.469 .67 .951 r
.03844 .36772 .04622 .37518 .05588 .37515 .04816 .36735 Mtetra
.483 .666 .943 r
.04816 .36735 .05588 .37515 .06561 .37501 .05795 .36686 Mtetra
.497 .661 .935 r
.05795 .36686 .06561 .37501 .07542 .37476 .06781 .36623 Mtetra
.509 .655 .925 r
.06781 .36623 .07542 .37476 .08531 .37437 .07776 .36547 Mtetra
.519 .65 .916 r
.07776 .36547 .08531 .37437 .09527 .37385 .08779 .36458 Mtetra
.529 .644 .907 r
.08779 .36458 .09527 .37385 .10532 .37319 .09789 .36355 Mtetra
.538 .639 .898 r
.09789 .36355 .10532 .37319 .11545 .3724 .10806 .36239 Mtetra
.545 .634 .889 r
.10806 .36239 .11545 .3724 .12566 .37144 .11832 .3611 Mtetra
.552 .629 .882 r
.11832 .3611 .12566 .37144 .13595 .3703 .12865 .35967 Mtetra
.559 .626 .875 r
.12865 .35967 .13595 .3703 .14632 .36895 .13905 .3581 Mtetra
.564 .624 .87 r
.13905 .3581 .14632 .36895 .15679 .36734 .14953 .35639 Mtetra
.57 .625 .867 r
.14953 .35639 .15679 .36734 .16734 .36543 .16009 .35455 Mtetra
.575 .63 .869 r
.16009 .35455 .16734 .36543 .17799 .36315 .17071 .35256 Mtetra
.58 .639 .874 r
.17071 .35256 .17799 .36315 .18874 .36051 .18141 .35044 Mtetra
.585 .655 .885 r
.18141 .35044 .18874 .36051 .19958 .35748 .19218 .34817 Mtetra
.589 .677 .901 r
.19218 .34817 .19958 .35748 .21049 .35415 .20302 .34576 Mtetra
.593 .704 .921 r
.20302 .34576 .21049 .35415 .22148 .3506 .21393 .3432 Mtetra
.595 .736 .943 r
.21393 .3432 .22148 .3506 .23252 .347 .22491 .3405 Mtetra
.595 .766 .961 r
.22491 .3405 .23252 .347 .2436 .34349 .23595 .33766 Mtetra
.595 .789 .973 r
.23595 .33766 .2436 .34349 .25472 .34016 .24707 .33466 Mtetra
.598 .803 .978 r
.24707 .33466 .25472 .34016 .26586 .33707 .25825 .33153 Mtetra
.606 .804 .976 r
.25825 .33153 .26586 .33707 .27705 .33414 .2695 .32824 Mtetra
.616 .797 .969 r
.2695 .32824 .27705 .33414 .28829 .33129 .28081 .32481 Mtetra
.626 .782 .956 r
.28081 .32481 .28829 .33129 .29959 .32836 .29218 .32123 Mtetra
.635 .765 .941 r
.29218 .32123 .29959 .32836 .31095 .32526 .30362 .3175 Mtetra
.641 .749 .927 r
.30362 .3175 .31095 .32526 .3224 .32187 .31512 .31361 Mtetra
.646 .737 .915 r
.31512 .31361 .3224 .32187 .33391 .31813 .32668 .30958 Mtetra
.65 .731 .908 r
.32668 .30958 .33391 .31813 .3455 .31398 .3383 .3054 Mtetra
.655 .733 .907 r
.3383 .3054 .3455 .31398 .35717 .30943 .34998 .30107 Mtetra
.66 .742 .91 r
.34998 .30107 .35717 .30943 .3689 .30452 .36171 .29658 Mtetra
.666 .757 .918 r
.36171 .29658 .3689 .30452 .38068 .29932 .3735 .29195 Mtetra
.671 .776 .929 r
.3735 .29195 .38068 .29932 .39252 .29393 .38535 .28716 Mtetra
.676 .797 .939 r
.38535 .28716 .39252 .29393 .40441 .28847 .39725 .28221 Mtetra
.681 .816 .948 r
.39725 .28221 .40441 .28847 .41633 .28308 .40921 .27712 Mtetra
.685 .828 .952 r
.40921 .27712 .41633 .28308 .42829 .27784 .42121 .27187 Mtetra
.69 .83 .95 r
.42121 .27187 .42829 .27784 .44029 .27285 .43327 .26647 Mtetra
.696 .819 .941 r
.43327 .26647 .44029 .27285 .45234 .26803 .44537 .26091 Mtetra
.7 .799 .926 r
.44537 .26091 .45234 .26803 .46443 .2633 .45752 .2552 Mtetra
.701 .771 .906 r
.45752 .2552 .46443 .2633 .47657 .25853 .46972 .24934 Mtetra
.7 .743 .885 r
.46972 .24934 .47657 .25853 .48877 .25351 .48196 .24332 Mtetra
.697 .718 .865 r
.48196 .24332 .48877 .25351 .50102 .24819 .49425 .23715 Mtetra
.695 .699 .85 r
.49425 .23715 .50102 .24819 .51332 .24247 .50658 .23082 Mtetra
.695 .687 .839 r
.50658 .23082 .51332 .24247 .52566 .23636 .51895 .22434 Mtetra
.695 .681 .832 r
.51895 .22434 .52566 .23636 .53804 .22987 .53135 .21771 Mtetra
.697 .68 .829 r
.53135 .21771 .53804 .22987 .55046 .22305 .5438 .21092 Mtetra
.701 .683 .829 r
.5438 .21092 .55046 .22305 .56292 .21597 .55628 .20398 Mtetra
.705 .688 .831 r
.55628 .20398 .56292 .21597 .5754 .20864 .5688 .19689 Mtetra
.71 .696 .834 r
.5688 .19689 .5754 .20864 .58792 .20112 .58135 .18964 Mtetra
.715 .704 .838 r
.58135 .18964 .58792 .20112 .60046 .19342 .59394 .18224 Mtetra
.721 .713 .842 r
.59394 .18224 .60046 .19342 .61303 .18556 .60655 .17469 Mtetra
.727 .723 .847 r
.60655 .17469 .61303 .18556 .62563 .17754 .61919 .16699 Mtetra
.733 .733 .851 r
.61919 .16699 .62563 .17754 .63825 .16937 .63186 .15913 Mtetra
.739 .743 .856 r
.63186 .15913 .63825 .16937 .65089 .16105 .64456 .15113 Mtetra
.745 .754 .86 r
.64456 .15113 .65089 .16105 .66355 .15258 .65728 .14297 Mtetra
.75 .765 .864 r
.65728 .14297 .66355 .15258 .67623 .14399 .67002 .13466 Mtetra
.756 .775 .868 r
.67002 .13466 .67623 .14399 .68893 .13528 .68278 .12621 Mtetra
.762 .784 .872 r
.68278 .12621 .68893 .13528 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Sooooo`03ol?8gol0003ooooo01Gooooo00?o
0000ooooooooool0DOooool0063ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`0Mooooo`?o00000_ooool00ol0003oooooooooo`1Oooooo`?o`lSO00?o
0000ol?8goooool05Oooool00ol0003oooooooooo`1@ooooo`00H?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol0000Looooo`;o0000IOooool00oo1a]ko`lSOol?8g`02ol?8g`03o`000?o5
c^7ooooo01Cooooo00?o0000ooooool00000DOooool0063ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0001[ooooo0ol0001Vooooo`?o`LKN0oo3b=l00ol0003oaLkQ
olG>h@0Fooooo`03o`000?oooooooooo04oooooo001Pooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool0000Hooooo`;o0000J?ooool5ol76gP03ol?8goo5c^7o000000?o
aLkQ5_ooool00ol0003oooooooooo`1>ooooo`00H?ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l000005Oooool3o`0000;ooooo00?o0000ooooooooool0Hoooool00ono`mgo
`LKNol76gP03ol76gP04olKAhoo5c^7oaLkQo`0000;oaLkQ00?oa=7Tooooooooool05?ooool00ol0
003oooooooooo`1>ooooo`00H?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4
A?l000004oooool2o`0006[ooooo0ono`md3ol76gP?oa]7S00?oaLkQo`000?o5c^400oo4dN@Foooo
o`03o`000?oooooooooo04gooooo001Pooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omg
MgOo0000ooooo`0?ooooo`?o0000Joooool5oko3g@03ol76g_o6dN?oa]7S00?oa]7S00?o0000olCA
i?o4dN@00oo4dN@Fooooo`03o`000?oooooooooo04cooooo0022ooooo`;o0000K?ooool00onn`Mco
_l?Moko3g@03oko3g@;oa]CU1?o6dN<00oo5fNSo0000olCAi003olCAi003okkBjOoooooooooo01Co
oooo00?o0000ooooooooool0C?ooool007oooooo0ol00002ooooo`03o`000?oooooooooo06Oooooo
1?nn`M`3oko3g@Coa]CU00Ooa]7SolGIj?o5fNSoaMWXo`000?o5fNSoa=7T00Co_];Y5?ooool3o`00
04gooooo001looooo`?o0000KOooool00onm_]_o_/7Lokk1g004okk1g003oko3gOo6e>Goa]CU00;o
a]CU00?oaN7/olGIj?o5fNP00_o5fNP00ol0003o_]g_okkBj@04okkBjAOooooo00?o0000oooooooo
ool0B_ooool007[ooooo0_l0001_ooooo`?o_KkK1?nn`M`2olKGi`?oa]CU0oo5hN`3olGIj003okkM
kol0003o_]g_00?o_];Y0_ncd>lFooooo`03o`000?oooooooooo04[ooooo001gooooo`?o0000L?oo
ool5okfnf`03okk1g?o6enOoa]OW00?oa]OW00?oa]CUolGQk?o5hN`00oo5hN`01_o5fNSo_]g_okkM
kol0003o_]g_okkBj@Go/m3_5_ooool00ol0003oooooooooo`19ooooo`00MOooool2o`0000;ooooo
00?o0000ooooooooool0K?ooool00onk^mWo_KkKokfnf`03okfnf`03olGJjOo6enOoa]OW00?oa]OW
0_o4j>l4olGQk0;o_>Oc0_nngNl00ol0003o/]gfok;MmP04ok?@k`03ojK;looooooooooo01Gooooo
00?o0000ooooooooool0B?ooool007;ooooo0ol00005ooooo`03o`000?oooooooooo06Wooooo1?nk
^mT3okfnf`?oaM[Y0oo6enL4olCXk`04olGQk?nlio?o_>OcokcWl`;o[>Oi00?o/]gfo`000?nbgOH0
0_nbgOH00oncd>ooY/_cojK;l`02ojK;laKooooo00?o0000ooooooooool0B?ooool0073ooooo0_l0
001booooo`03okZif?nk^mWo^k_I00Co^k_I00?o_KkKolGJjOo5f^T00oo5f^T00oo6enOoa>S_olCX
k`02olCXk`;o]o3e00?o_>OcojcWnOn/ioT00on/ioT00ol0003o/]gfoj;FnP02oj;FnPGoY/_c5_oo
ool00ol0003oooooooooo`17ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`Go00008?ooool3o`0007?ooooo0onj^MP4ok^kf@;oaMg[1?o5f^T3ol7_l@04olCXkong
l?Go]o3eokO`m@;oX>kg1?n/ioT00onJgogo0000oj;FnP04oj;FnP;oY/_c0_nG`O@Eooooo`?o0000
B?ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A401kooooo0_l00003ooooo`03o`000?oooooooooo06oooooo1?nj^MP3ok^kf@Co
aMg[00?oaM[Yol7_lOo1ko400_o1ko42oj_el@03okO`mOnPk_OoX>kg00?oX>kg00Ko[>Oioi[OoOnJ
gogoV]omo`000?nJgod2oj;FnP?oTlWj1?nG`O@Fooooo`03o`000?oooooooooo00Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo02Wooooo000h
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Looooo`?o0000MOoo
ool00onh]]Oo^[WHokZif004okZif003ok^kfOo5gN_oaMg[00;oaMg[0onkm?401?o1ko7oZoGaoj_e
lOn[mO43ohc/j`;oX>kg1?n<i?/2oi[Oo@03o`000?n<d?koS=3n00GoTlWj1?nG`O@Fooooo`03o`00
0?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003o
ooooooooo`0Zooooo`00>?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^
k^h06?ooool3o`0007Kooooo1?nh]]L4okZif0;oa>7]0oo5gN/3ok_dl@;oVO?V00CoZoGaohc/jon<
k>_oS>c[1?mghNl2ohcTn`?oPmGo00?oS=3no`000?n<d?h00_n<d?h2oi?9nP;oRK_g1On<^?<Foooo
o`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000:oooool0
03Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo01Gooooo0ol0001f
ooooo`03okNde_nh]]Oo^;KG00Co^;KG00?o^[WHolCQkOo4hNd00oo4hNd00oo5gN_o^oCaok_dl@03
oiWciP03ofoOe?mLeMWoG=GI00;oG=GI0_mghNl4ogKGo0CoPmGo00?o0000ohc@o_n6__T00_n6__T4
ohVkm`GoS;Sc5Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002ooo
ool01?m4A4CogMgMooooool0000/ooooo`00>?ooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool04Oooool3o`0000?ooooo00?o0000ooooooooool0LOooool4okNdePCo^;KG
0_o3i>l4olCQk@;o/_S^0_n0j=400onIlnKo?/6koeC>j003oeC>j0CoI]Cd0_mfeo`3ogk3o@?oP/7l
00?o0000ohJnnOn6__T00on6__T4ohVkm`;oS;Sc0_n7[o0Fooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002cooooo000hooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@017ooooo0_l0001h
ooooo`03okFbeOng]=Ko]kCF00?o]kCF0onh]]L4ol?Tk`03olCQkOnbn>ko/_S^00;oP>SA00CoClVc
odC5fOm4aMWoA<GI0_mDc^P3ogW6o`GoNlGn1?mn`od2oh;1o004o`000?n2`OcoQ[kiohJnn@;oQjc]
1?n7[Nl5ohN_l1Kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l00000;?ooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`03_ooool3o`0007Wooooo0one/]D5okNdeP03okRfeoo3i>oo`nC_
00;o`nC_0_nUmnH00omSe;Go0000ogS9o`02ogS9o`GoN<So1?mia_l2og_5oP;oRJCV1?n8YnT2ohNY
j`03o`000?n7ZN_oQjW[00CoQjc]1?n7[Nl5ohN_l1Cooooo0_l00004ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000/ooooo`00FOooool3o`0007[ooooo1?ne/]D4okNd
eP?o`NSa00?o`nC_ojGgi_nUmnH00_mSe;D2og_9o`CoN<Wo0_mhb?l2ohfOg`CoRj;S1On9Y>H4ohRW
j@03ohNYjol0003oQjW[00;oQjW[1?n7[>d4ohN]k`;oQjo`0_n:[>`Cooooo`04o`000?oooooooooo
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02_ooooo001F
ooooo`?o00000oooool00ol0003oooooooooo`1eooooo`03okB`e?ne/]Go]K;E00Co]K;E00?o]kCF
ol7XlOo1j?400_o1j?42oiCaf@04o`000?mnbOooNlWoog_9o`;oTI[H1?n?W=`5ohfOg`CoRj;S1On9
Y>H4ohRWj@04o`000?n7ZN_oSYkNohjNgPCoSJ?S1?n<YnP5ohZ/k1Kooooo00?o0000ooooooooool0
@?ooool005Cooooo0_l0001looooo`Co];3D1?ne/]D2oko[lP?o`NSa00?oU?7Ioi>Ge?nCUm@00_nC
Um@5oi6Jf0CoSicL1On=Wml4oh^Rh`;oRJCV0_n@U=@4ohnIf@04o`000?n>W]koSYkNohjNgPGoSJ?S
1?n<YnP4ohZ/k1Kooooo00?o0000ooooooooool0@?ooool0057ooooo0ol0001jooooo`03o`000?ln
003o/jkD00Ko];3D00?o]K;Eoko[l_nojo800onojo801?o1j?7oUIC@oiFDd?nEU=04oi>Ge0CoTI[H
1On?W=`2ohfOg`;oTXc:1?nAT<l4oi2De0CoSiWI00?o0000ohjNg_n>W]h00_n>W]h4ohfSh`;oS:OX
0_nDYN45oi>]j1Kooooo00?o0000ooooooooool0?oooool004kooooo1Ol0001gooooo`;o000000?o
A004och00?nc[]@00onc[]@4okB`e0;o_>kc1?nojo82oiJAc0?oUIC@1?nCUm@5oi6Jf0;oSicL0_nC
RLD5oi:<bPCoTI3?1?n@U=@3ohnIf@03o`000?n>W]koSYkN00;oSYkN0_n=Xn<2oiFNfPGoU:GQ1OnC
[NPFooooo`03o`000?oooooooooo03kooooo001<ooooo`;o00001Oooool00ol0003oooooooooo`1]
ooooo`03o`000?m;01GoB`0E00CoB00>0_m400@00onb[]Co/jkDok>^e003ok>^e0?o];3D1?nlk_<0
0onojo;oUY7<oiJAc002oiJAc0CoUIC@1?nCUm@2oi6Jf0;oU8K11OnCRLD4oi:<bPCoTI3?1?n@U=@2
ohnIf@03oiJAcOl0003oUYOC00?oUYOC1OnEW]X5oiBUh@;oTjgX0_nN/^DFooooo`03o`000?oooooo
oooo03kooooo0019ooooo`?o0000Loooool00ol4003oC@0Kodd06`04od/05@CoB00>1?nb[]@5ok>^
e003okB`e?nlk_?o_>kc00;o_>kc0_nFSLL5oiJAc0;oUIC@00?oUX6joiJ3_OnFPkd00_nFPkd5oiB6
`@CoThW51?nBS<X5oi6@c`;oT9CD00?oUXc6oiJAcOnFTLd00_nFTLd00ol0003oUYOCoiJGd`02oiJG
d`GoUIkJ0_nDYN42oijYgPGoW[;U5?ooool3o`0003oooooo000Rooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h08?ooool2o`0007;ooooo00?o2P00o`@00?m?01l01?m=01/3od/05@?oB00>00?o/JkDok:^
e?nb[]@00onb[]@4ok>^e0?o^O3d00?o_>kcoiJ=aonFSLL00onFSLL2oiJAc0;oUgng1?nFPKX4oiJ3
_@CoU8K11?nCRLD5oi:<bP;oTI3?0_nGQl44oiJ<aP?oUY7=00?o0000oiJGdonFUm<00_nFUm<4oiFN
fP03oijQe_nNZMkoWZWN00?oWZWN1OnN/^DEooooo`03o`000?oooooooooo03gooooo000Rooooo`05
ogMgMonHV9SooooooiRHV?mgMgL07Oooool3o`0000;ooooo00?o0000ooooooooool0K?ooool00ol:
003oD00Roe008P03odl07`?oC@0K1?m;01D00om800ko/JkDok6^e002ok6^e0Go/ZkD00?o/jkDokW`
m?nil?@00_nil?@2oiJ8``CoUXg700?oV7fdoiMo]onGOkL00_nGOkL4oiJ1^PCoUX>m1?nDQ/45oi>9
a@;oTXc:0_nGPk`5oiN7`@?oUXc60onFTLd00ol0003oUYOCoiJGd`03oiJGd`03oiFNf_nNXMKoWZ7F
00;oWZ7F1OnNZMh2oijbi@?oZ[SS5Oooool00ol0003oooooooooo`0looooo`008_ooool01Ol@413o
oooooooooooooooo410@01_ooooo0_l0001`ooooo`03oa@00?l@003oD@0S00CoD00R0_m?01l4odd0
6`;oB`0E00?oB`0Rok6_e_na[]@01?na[]@4ok:^e0?o]?7e00?o^O3doiF3__nFR<<00onFR<<01?nF
SLOoV7fdoiQm]?nHOK@5oiMo]`?oUX6j1?nFPkd5oiB6`@;oThW50_nGOkP5oiN3_0CoUhO10onFS<H3
oiJAc@04o`000?nFTLgoUYOCoiJGd`;oWi[?1OnNXMH4oijYgP03ojV`gOnZ^>?oZ[SS00CoZ[SS5Ooo
ool00ol0003oooooooooo`0kooooo`008_ooool01Ol0003ooooooooooooooooo000001Sooooo0ol0
001^ooooo`;o5`000_lD0003oe408`?oD00R0om?01l4odd06`03od/08_na[mKo/JoF00;o/JoF1Ona
[]@00onb[]Co]?7eokCam@02okCam@?oUH>n0_nFR<<2oiQk/PGoV7fd1?nGOkL4oiJ1^PCoUX>m0_nD
Q/42oiMl]0GoUgnh1?nGPk`4oiN7`@CoUXc60_nFTLd00ol0003oWiC9oinJc`04oinJc`GoWZ7F00?o
WZWNojV`gOnY/=d00_nY/=d4ojZhh`03ok>ohooooooooooo01?ooooo00?o0000ooooooooool0>ooo
ool002;ooooo00Go0000ooooooooooooooooo`00000Fooooo`?o0000KOooool01_lH003o5`00oaL0
0?lG003o5000oe408P?oD@0S1?m@0283odl07`04odd06om?02OoC`0Wok6bf@Go/JoF1?na[]@3ojoa
mP03okCamOnCO[[oTgjj00;oUH>n00?oV7V_oiQk/_nHNk800_nHNk85oiQm]0CoUgng1?nFPKX2oiJ3
_@;oUgZa1?nGO;@5oiMo^0CoUh>l1OnGQl42oiJ<aP04oin@a?nOU<WoWiC9o`0000;oWiC91OnOV/l2
oijQeP;oZJWG1_nY/=d00onZ^>?o/koSok>oh`02ok>ohaGooooo00?o0000ooooooooool0>_ooool0
02;ooooo00Go410@oooooooooooooooooa0@400Cooooo`?o00000_ooool00ol0003oooooooooo`1X
ooooo`?o600000?o5`00oe408OmA02400omA0283oe408`CoD00R00?oC`0Ooe80:_m?02L00_m?02L3
ok6bf@Go/JoF00?o/JkDojoam_n_lOH00_n_lOH2oi=n^P;oUgJ]0onHNJl5oiQk/PCoV7fd1OnGOkL2
oiJ1^P03oiQh[_nGN[7oUgZa00;oUgZa1OnGO;@4oiMo^0GoUh>l0onGQl400onORkooWi34oin@a002
oin@a004oinDbOl0003oWiC9oinDb@CoWi[?00?oZ:?AojVYeonYZML00onYZML4ojV`g@03ok>jg_nc
_n?o/koS00?o/koS5_ooool00ol0003oooooooooo`0iooooo`008_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg013ooooo0ol0001^ooooo`?o600000?oD@0Ooe408OmA02400_mA0242oe408PCoD@0S0_m@
02801?mD02coDP0Zoe80:_mB02X2odl09`Co/K;I1?na[mH3ojSamP03ojoam_nBN[KoUW>Z00CoUgJ]
1?nHNJl4oiQk/PGoV7fd1?nGOkL00onFPK[oV7R^oiQh[P05oiMj/@CoUgbd1OnGOkP4oiN3_003oiN7
`OnORkooWh^o00;oWh^o0onOT<@00onOU<Wo0000oinDb@02oinDb@03oinJconXXm7oZ:?A00;oZ:?A
1OnYZML00onY/=go/k[Nok>jgP02ok>jgP?o/koS0_njan@Dooooo`;o0000>oooool002;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0>ooooo`;o0000Koooool4oaP000;oD@0O0omA0243oe408P?oD@0S
00CoD00Roe@0;?mD02coE00/0_mB02X2ok:gg@Ko/K;I00?o/JoFojSam_nXlOH00_nXlOH01?nBN[Ko
UW>ZoiIcZ_nFLjX5oiMf[@?oV7V_1?nHNk85oiQm]0;oUgng0_nHMj`4oiQh[PCoUgZa1?nGO;@5oiMo
^0;oUh>l0_nOR;/5oin;_`?oWi3400GoWiC9o`000?nOU<WoWiC9ojVNc005ojRSd@CoZJWG00?o/kKK
ok>jg_nc^]h01?nc^]h00onc_n?o^/OTok[7i002ok[7i1Gooooo00?o0000ooooooooool0>?ooool0
03;ooooo1Ol0001[ooooo`;o5`000olH0002odl070;oD@0O1?mA0243oe408P03oe408omG02goE`0]
00?oE00/00?o/kkRok:ggOnb]md00onb]md4ok6bf@?oX^of00?oZ?7foi5g/_nDLJP01OnFLjX4oiMf
[@?oV7V_1OnHNk83oiQm]003oiUfZonHMjcoV7N/00;oV7N/1?nHN:h4oiMj/@GoUgbd0onGOkP00onO
QKOoWhRkoin8^`03oin8^`CoWh^o0onOT<@2o`0000CoZIk<1OnXXm400onYZMOo/kKKok>ff`02ok>f
f`Co/k[N1Onjan@00onkc>Ooooooooooo`0Dooooo`03o`000?oooooooooo03Oooooo000`ooooo`;o
0000KOooool01_lF003o5`00oaL00?lG003o6000odd06PCoC`0L0_mA01l4oe408@03oe408_mI02go
E`0]00?oE`0]00?oE00/ok>nh_nc_^800_nc_^85ok:gg@03ok6bfOnRkoKoX^of00;oX^of00CoTfjV
oiAaZ?nDLJSoU76X1OnFLjX4oiMf[@CoV7V_1?nHNk801?nHOKCoVGJ[oiUfZonIMZ/5oiQg[0?oV7R^
1?nGN[45oiMl]003oiMo^?nOQKOoWhFg00;oWhFg1?nOR;/4oin;_`?o000000?oZI[7o`000?nYW/`0
0onYW/`4ojRSd@03ok>beonc]]_o/kKK00Co/kKK00?o/k[Nok[7i?njan@00onjan@4ok_<iaGooooo
00?o0000ooooooooool0=oooool002gooooo0ol0001/ooooo`?o5P0000?o5`00od/05om;01L00om=
01X3odl070?oD@0O00?oD@0QoeT0;?mI02`00omI02d3oeL0;@03ok?5ionc_^;o/kkR00?o/kkR1?nb
]md3oi_^mP04oj;_m_nCKZKoTfjVoi=^YPCoU76X1?nFLjX4oiMf[@CoV7V_0_nHNk82oiUfZ@GoVGJ[
1?nHMj`3oiQh[PGoUgZa0onGO;@00onNP[CoWhFgoin5]`03oin5]`CoWhRk00KoWh^oo`000?l0003o
0000oin;_onOT<@3ojVJa`03o`000?nYW/coZIk<00;oZIk<00?oZ:?Aok>beonc/]L00_nc/]L4ok>f
f`03ok_8i?njanCo^/OT00;o^/OT00?o_=7Zok_<ionkc>L01?nkc>LEooooo`03o`000?oooooooooo
03Kooooo000/ooooo`;o0000K?ooool3oaH00003odT05_m;01OoB`0G00;oB`0G0_m=01X3odl07003
oe407omI02_oF@0[00CoF@0/0_mI02d2oeL0;@Co/lGW1Onc_^801?nb]mgoVnkfoi_^m_nKk_H2oi9/
Y0CoTfjV1?nDLJP4oiIcZPGoUgJ]0_nHNJl00onJMZWoVGJYoiUfZ@02oiUfZ@GoVGJ[1?nHMj`4oiQh
[PCoUgZa00CoUgbdoij2]?nNP[CoWX:d1OnOQKL2oin8^`?o00000_nORkl2ojVHa0CoZI[700GoZIk<
o`000?nYW/coZIk<ok>_e006ok>be`03ok>ffonkb>Co^lST00;o^lST0_njan@3okcAjPCo^lcW0_ng
cn`Eooooo`03o`000?oooooooooo03Gooooo000/ooooo`?o0000JOooool3oaH000?oB@0F0om;01L3
odd06P03odl07?mH02WoF@0[00?oF@0[0omI02`3oeT0;@;o/lc]1OncaNL2ok>nhP?oUNcf00?oTF^S
oi9/Y?nBK:@00onBK:@3oi=^YPCoU76X1?nFLjX5oiMf[@03oiQi[onJMZWoVWJY00GoVGJY1?nIMZ/4
oiQg[0CoV7R^0_nGN[42oiio/@GoWX:d0onOQKL3o`0000;oWhRk00?oZIG1ojVHa?nYV<@00_nYV<@5
ojVJa`03ojVNc?l0003o/joD00;o/joD1?nc/]L00onmb^Go^lSTok_8i003ok_8i003ok[7i?nldN[o
_=7Z00?o_=7Z00?o^lcWokO?k?ngcn`00ongcn`Dooooo`03o`000?oooooooooo03Gooooo000/oooo
o`04o`000?oooooo0000o`0006Cooooo00?o5`00oaH00?lF00000_lF00001?m801GoB@0FodT05_m9
01H3od/05`CoC@0J0_mH02T3oeT0:`CoF@0/00?oF@0]ok?<kOncc>d00oncc>d3ok?5i`CoSn[e00?o
UNcfoi5[XonAJj<01OnBK:@3oi=^YPCoU76X1OnFLjX3oiMf[@03oi]fZ?nJMZWoVWJY00;oVWJY1?nI
MZT4oiUfZ`GoV7N/0_nHN:h00onNOJooWWnaoiio/@02oiio/@GoWX:d0ol00002oin5]`03oin8^onY
UL7oZIG100;oZIG11?nYV<@3ojVJa`03okB^d_nc[mCo000000Co/joD00?o/k;Gokg:iOnmb^D00_nm
b^D3ok_8i0;o_MS^1?nldNX2okOJlPCo]lo/00?o[Lc`ooooooooool04Oooool00ol0003oooooo`00
0008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c00Iooooo`00;?ooool2o`0000;ooooo00?o0000ooooooooool0G_ooool3oaL00003oaH0
0?m701GoA`0E00?oB00E0om901H3od/05`03odd06_mG02OoE`0W00;oF00Y1?mI02/3oeT0;0?o/]7`
1Oncc>d01?ncaNOoSn[eohoZmOn?j_D2oi5ZXPCoTF^S1?nBK:@4oi=^YP?oU76X1OnFLjX01?nGMZgo
VgJXoi]fZ?nKMZP4oiYfZ@CoVGJY1?nIMZ/5oiQg[003oiQh[_nNOJooWWf_00GoWWna00CoWX:do`00
0?l0003o00001?nOQKL00onZTkooZIG1ojVE`@03ojVE`@CoZIS400?oZI[7okB^d_nd[]800_nd[]80
1Onc[mCo0000ok>_e?nc[mCo_/kV00Ko_L[U00?o^lSTokgHk_nmf>h00_nmf>h00onldN[o]m[bokOJ
lP03okOJlP03okO?k?n]c?3o[Lc`00;o[Lc`5Oooool00ol0003oooooooooo`05ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0Iooooo`00
:oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05cooooo0_lG00000om601KoA`0E
odL05@02odL05@;oB00E1?m901H00om;01OoE@0VoeL09`03oeL09`;oF00Y1?mI02/2oeT0;0Go/]7`
0_ncc>d3ohgZl`03oi5YX_nAJZ;oTFZR00?oTFZR0onAJj<4oi9/Y0CoTfjV1?nDLJP3oiIcZP03oiYe
Z?nKMZSoVgJX00?oVgJX0onJMZT4oiUfZ@GoVGJ[0onHMj`00onMO:koWWf_oiim[`02oiim[`?oWWna
0_l00004oij2]0;oWhFg0onZTkl4ojVE`@?oZIS400?o]JgAokB^d_nd[]800ond[]82ok>_e004o`00
0?nnc^Ko_/kVokk>iPCo_L[U00?o_N3aokgHk_nmf>h00_nmf>h3ok?Um`;o]m[b0_n[e_L5ojg<l1Go
oooo00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooo
ooooooooooooo`00000Iooooo`00:oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
05Sooooo1?lG0002odH05P?oA`0E0om801D00om901KoD`0Uoe<09@03oeD09P?oE`0W0omH02T3oeT0
:`03oeT0;?n`e??o/=Cc00Co/]7`0on;j_400on=j_?oTFVRoi5YXP02oi5YXPCoTFZR0onAJj<4oi9/
Y0CoTfjV1?nDLJP01?nFLj[oVWFXoiYeZ?nJMJP5oi]fZ0?oVWJY1?nIMZT5oiUfZ`04oiQg[?nMO:ko
WGb^oiel[PCoWWf_0ol000000onNOk7oWX:doij2]003oij2]003oin5]onZTkooZY>o00;oZY>o1OnY
UL401?nYV<Co]JgAokF]dOne[M45okB^dP03ok>_e?l0003o_/kV00?o_/kV00?o_L[UokgPlOnmh?40
0_nmh?400onmf>ko/nGgok?Um`02ok?Um`03ojCPo?n[e_OoZmKg00?oZmKg0_n]c?03oj;5lAGooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oo
ooooV9RHob4Q8@0Iooooo`00:oooool3o`0000Gooooo00?o0000ooooooooool0E?ooool01?lF003o
5`00oaL00?lG0002odL060;oAP0F0om701D2odP05@03oe009?mC02GoD`0U00;oD`0U0_mE02H3oeL0
9`?oF00Y0_mI02/00olm00;o/=Ccok3Dl`03ok3Dl`04ok;Al?n;j_7oRn[aoh_Zl@?oTFVQ1?nAJJ84
oi5ZXP?oTF^S1OnBK:@3oi=^YP?oU76X00?oVG>WoiYeZ?nJMJP00onJMJP4oi]fZ0?oVWJY1OnIMZT3
oiUfZ`03oiek[OnMO:koWGb^00?oWGb^0ol00005oiio/@?oWX:d00?oZY:mojZC_onZTkl00onZTkl4
ojVE`@03okJ^dOne[M7o]JgA00;o]JgA1?nd[]82ol3Cj004okk>i_l0003o_/kVokk>iP;o^^Wd0_nm
h?44ojW_n003ok?UmonTh?coY>3l00;oY>3l0_n[e_L3oik<m`GoX/Ga5Oooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<01Wo
oooo000[ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0D?ooool01OlA003o5P00
oaH00?lG003oB00J00CoA`0H0_m601H3odL05@?oD00T0omC02D3oeD09P?oE`0W00?oF00Yod402?m1
00P01?n_do<2ok3Dl`?oRN_]1_nAJJ44oi5YXPCoTFZR0onAJj<5oi9/Y0?oTfjV00CoU76XoiUcYonI
LjOoVG>W1OnJMJP4oi]fZ0CoVWJY1?nIMZT01?nIMZ_oWG^]oiek[OnMNjd2oiel[P?o00000onNOJl5
oiio/@03oij2]?nZT[goZY:m00;oZY:m1OnZTkl2ojVE`@?o]ZkA1?ne[M400ond[];o`=?Xol3Cj003
ol3Cj004okk>i_l0003o^^Wdok[Ym0?oTNo/0_nYkoP4oiCVn`;oY>3l0_nHdO/5oik<m`;oX/Ga0_nJ
_?0Eooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEE
EOn7QhOooooo01_ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0C?oo
ool01Ol9003o4@00oa400?lF003oBP0M00?oB00J0om701P3odH05P03odL05Om?02?oD00T00;oD00T
0omC02D4oeD09P03oeL09om300go@@0800;o[]3b1?n_do<3ohS[j003ohW[kOnAJJ7oTFVQ00KoTFVQ
1?nAJJ84oi5ZXPCoTF^S1?nBK:@2oi=^YP03oiQaYOnILjOoVG>W00?oVG>W1?nJMJP4oi]fZ0CoVWJY
0onIMZT01?nMNZcoWG^]oiek[OnMNjd3o`0000?oWGb^1?nNOJl3oiio/@03ojZA_?nZT[goZY:m00?o
ZY:m1OnZTkl00onYUL7o]ZkAokJ^d@02okJ^d@?o]JgA0_o1f^`4ol3Cj0?o/_;e00?o0000oi7_k?nA
kn`01?mhh^l2oiCVn`;oSmCn1OnHdO/2oik<m`?oUkkb1?nJ_?0Cooooo`?o00001?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P06oooool0013ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`19ooooo`;o2@0000?o4@00od`07om:01d00_m:01d2odP0
6P?oA`0H00?oAP0Fodd08om=02<00om?02<3oe0090?oD`0U00?oE@0VodD04?m501000_m300d5ojk@
lP03ojoClon8jnSoR>_X00;oR>_X2_nAJJ44oi5YXPGoTFZR0onAJj<3oi9/Y004oiI_Y?nHLJGoV76U
oiQaY@GoVG>W1?nJMJP5oi]fZ0?oVWJY00CoVGJYoiej[?nMNZcoWGZ/0ol00002oiek[@CoWGb^1?nN
OJl00onNOk7oZY6lojZA_002ojZA_0CoZY:m1?nZTkl00onh/=7o]ZkAokJ^d@04okJ^d@03okF]dOo1
f^co`M[/00;o`M[/00?o`=?Xok;bmOnbl_D00_nbl_D01?m@cM;o0000oe3=d_m@cM82ogSRk`?oP]Co
1?n?e?h2oiSAn`?oU;kd1OnG__84oiZll1Gooooo00Wo0000ooooooooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410Iooooo`004?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo0ol0000:ooooo`03o`000?oo
oooooooo04Kooooo00?o0000o`T00?l900000om<01l2odX07@?oB00J00?oA`0Hod`08om=02<00om=
02<2odl08`?oD00T0_mC02D01?m6017oA@0@odD04?m50104ojg<l0?o[]3b0on5j^<3oi9ZX@[oTFVQ
1?nAJJ85oi5ZXP?oTF^S00CoTVbToiI_Y?nFKjCoUVnT1?nHLJD4oiUcY`CoVWFX1OnKMZP2oiYfZ@;o
WGZ/0ol000000onMNZcoWG^]oiek[@02oiek[@GoWGb^0_nNOJl00onYT;_oZY6lojZA_003ojZA_0Go
ZY:m00?oZY>ookR`dOnh/=400_nh/=44okJ^d@03ol7Tl?o1f^co`M[/00;o`M[/0onPm>`00onbl_Go
JLcmofW<o@02ofW<o@03o`000?medOkoMM7n00;oP]Co0on?^_@4oi:mm0GoU;kd0_nG__82oiNbjPCo
V;K]5Oooool00ol0003oooooooooo`0_ooooo`002?ooool6o`0000;ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`Go00001Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04;o
oooo0ol000000ol9003oC@0Qod`07`02od`07`;oBP0M1?m801X2od`08`?oC@0S0om?02<3oe0090?o
AP0A0_n[a^d6ojg<l003ojk@l_n5j^?oQN[S00GoTVZQ2_nAJJ45oi5YXPCoTFZR0_nAJj<00onDK:;o
UVnToiI_Y002oiI_Y0CoV76U1?nILjL5oiYeZ0CoVgJX00CoVWJYoiej[?l0003o00001?nMNZ`4oiek
[@GoWGb^00CoWWf_ojV@^onYT;_oZI2k1?nZTK`4ojZB_@03okVcdonh/=7o^;3A00Co^;3A00?o]ZkA
ol7Tl?o1i?000_o1i?001?o1f^coX?C/oj3dk?nPm>`3of?7o0;oJLcm0_n=[N`01?n=]O7o0000ohfe
lOn=]O45ohnjm0CoT[gd0_nD__@2oiN^i`GoUk;Z1?nH]^dEooooo`03o`000?oooooooooo02kooooo
000@ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00006ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0?oooool2o`0000;oCP0Q0om=0243od`07`;o
BP0M00?oB00Jod`09Om<02D00_m<02<3odd08`CoC`0S00?oD00TodH04Om601400_m60144oj_6k@Co
[Lc`00?oOnSLoi9ZXOnBJZ401_nBJZ4;oi5YX@CoTFVR0onAJZ801?nBJZ7oU6bRoiA/X_nDK:85oiI_
Y0?oV76U1?nILjL5oiYeZ0?oVgJX0ol00006oiej[0GoWG^]0onMO:h00onXS[[oZI2kojV@^`02ojV@
^`GoZY6l00?oZY:mokVcdoni/m<00_ni/m<4okR`d@;o_>oc0oo1i?02og[Uc`;oT9[J1On?Y>@4ohf]
k004o`000?n=]O7oSKGaohfel@;oSk[d0_nFX]`4oiNXhPGoUjkW1?nG/^X2oiRfk@?oVkCY5Oooool0
0ol0003oooooooooo`0]ooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgM
oeEEEOoooooo00001_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03cooooo00?o
0000odd07om>02400om>0242odd08@?oC00O00?oBP0Modd09_m<02D00om<02D2od`08`?oC@0S00?o
C`0Sod@03om400l00om60143oj[1j`GoZlK]00?o[Lc`oi9ZXOnBJZ402OnBJZ4;oi5YX@CoTFVR00Co
TFZRoi9ZXOnBJZ7oTVZQ0onDK:85oiI_Y0?oV76U1OnILjL4oiYeZ0?o000000?oWW^/oiej[?nMNZ`0
1_nMNZ`5oiek[@03oiel[_nXS[[oZ8jj00;oZ8jj0onYT;/4ojZA_003ok^heoni/m?o^K?C00?o^K?C
0onh/=44okc_l`03ol7Tl?mjiLooT9[J00CoT9[J1On?Y>@3ohf]k004ohfelOl0003oUi_EoiNKe@Go
UZ;L1?nGZ>84oiN^i`;oUk;Z0onK[nD5oi^djACooooo00?o0000ooooooooool0;Oooool0013ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo0_l0000?ooooo`;o
0000>oooool00ol0003oC@0Oodd07`03odh08@;oC@0Q1?m<01l2odd09P?oC00U0om<02<00om=02?o
@P0<od@03`03od@03`03ojRmj?nZ`N_oZ/7[00CoZ/7[0_n[a^d00omgi=GoTVZQoi9ZX@0;oi9ZX@_o
TFVQ0_nAJJ82oi5XW`CoTVZQ1?nDK:84oiI_Y0?oV76U1OnILjL01?nJMJSo0000o`000?l00005oiik
[0SoWGZ/0onMNjd00onWSKWoZ8jjojR>^P03ojR>^PCoZI2k0_nZTK`3ok^he`Go^K?C00?o^;3Aokc_
lonlko<00_nlko<4oi:Ac`GoT9[J0_n?Y>@2oiV<a@?oV9?=0_nGVmD00ol0003oUi_EoiNKe@05oiJR
g0CoUjSR0_nG[^L00onLZ=ooVjoUoi^_i@04oi^_i@;oVkCY0_nR]^LEooooo`03o`000?oooooooooo
02cooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000006oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0=_ooool2od/06P;oC@0O0om>0243odd0
8@03od`07om?02SoC`0X00;oC@0V0om<02D3od`08`03odd08om200co@P0<00;oA00?1?nX_NP4oj[1
j`;oKMk>3onBJZ4:oi5YX@03oi5WW_nAJ9ooTFRO00;oTFRO1?nBJZ44oiA/XPCoUVnT1?nHLJD2oiUc
Y`?o00000onOO:`5oiik[0SoWGZ/00?oWG^]ojN=^OnWSKT00_nWSKT4ojR>^PCoZI2k00?oZY6lok^h
eonk^=L00_nk^=L4okVcd`?o[?O]00?o_>ocoiB9aOnDRLD01OnBTLl2oi2JfP;oVHFm1?nIS<D4oiRC
c@;oUi_E00?o0000oiNKeOnGVmD00_nFX]`2oijLdPCoWJ?I1?nLZ=l4oi^_i@03oj:`hOnR]^OoX[KW
00?oX[KW4oooool2o`0002kooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omg
MgOo0000ooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<_ooool00om5
01?oB`0Jod/06P02od/06P;oC@0O0om>02400om=027oD@0Zodl0:003odl0:0;oC@0V0om<02D00om<
02?o?`07ocl01`02od803004od@03onW^nSoYk_XojNkj0CoZ;gX00?oZ/7[ofgNc_nCJj400_nCJj4@
oi9ZX@GoTFVQ0_n@IYd3oi5WWPCoTFRO1?nBJZ44oiA/XPCoUVnT0onHLJD3o`000003oiUcYonPOJgo
Wgb/00CoWgb/1?nNNj`7oiej[003ojF;^OnWSKWoYhfi00?oYhfi1OnXS[X2ojV@^`03okfnfonk^=Oo
^kSG00Co^kSG00Co^K?CojcgkOn/mngo[?O]0_nGPk`4oiB9a@;oTY7?0_nJP;D5oiV5_@CoVHc50onH
Tld2oiNKe@03o`000?nGVmGoWiO<00GoWYcB1?nMXmT4oibXg`03oi^_iOnR/>7oX[3Q00;oX[3Q1?nR
]^LEooooo`03o`000?oooooooooo02_ooooo000Yooooo`;o00005?ooool00ol0003oooooooooo`0`
ooooo`;oA@0C0om;01X2odd07`;oCP0Q00CoE00[oe40:_mA02[oD@0Z0om?02P3odd09P03od`09Olk
007o?`0700;o?`070_nV^nP6ojNkj0;oZ;gX00?oH]O7oi=[XOnCJj401?nCJj4?oi9ZX@;oTFVQ00?o
T6FLoi1VWOn@IYd00_n@IYd3oi5WWPGoTFRO0onBJZ44oiA/XPCoUVnT0ol000000onHLJGoVG>Woj1m
[@02oj1m[@GoWgb/1?nNNj`5oiej[0?oYH^i1OnWSKT5ojR>^P04ojV@^onm_]_o_KkKokfnf`Co^kSG
00?oP^S;oiUn]?nIO[@01?nGPk`3oiB9a@03oi]k[onJP;GoVX2e00?oVX2e1?nIQKd4oiV<a@CoV9?=
00?oUi_EoinGc?l000000_nOUl`4oijLdPCoWJ?I0_nLZ=l3oj>Yf`GoX[3Q0_nR]^L2ojZliaGooooo
00?o0000ooooooooool0:_ooool002Wooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0]ooooo`03ocd02?m501?oA@0C00?oB`0J0om=01l3oe@0:`;oD@0Z0om?02P3odd09P04od`09Olk
007o>`01ojFljPGoY[_X1?nW^nP00omGd<;oU6^Qoi=[X@07oi=[X@ooTVZQ00?oTFVQoi1UW?n@II`0
1?n@IYd4oi5WWPCoTFRO1?nBJZ43oiA/XP;oUVnT0_l000000onFKjCoV76UoiQaY@06oj1m[@CoWgb/
1OnNNj`2oiej[003ojF;^_nURkWoYH^i00?oYH^i1OnWSKT3ojR>^P03okk5h?nm_]_o_KkK00?o_KkK
00?o^kSGoi]k[onIO[@01?nIO[@4oiN3_003oiB9aOnKNjooVg^_00GoVX2e1?nIQKd4oiV<a@;oV9?=
0_nQT/D3oinGc003o`000?nOUlcoWYcB00CoWYcB0_nMXmT00onTY=GoXjWKoj>Yf`04oj>Yf`;oX[3Q
0_n[^><5ojZliaCooooo00?o0000ooooooooool0:_ooool002Wooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0[ooooo`;o?@080_m501<3od/06P03odd07omF02coE00[00;oE00[0omA
02X3odl0:004odd09_lf003o=P00oc/00@CoYKcZ1OnV^nP00onW^nSoU6bRoiA[X@02oiA[X@SoTf^Q
3OnBJZ45oi1UW0GoT6JM0onAIih4oi5XW`CoTVZQ0_nDK:83o`0000?oUVnT00?oV76Uoj1m[OnPOJd0
1OnPOJd4oiml[0GoWW^/00?oWGZ/ojF;^_nURkX01OnURkT5ojN=^@03ojR>^_nnaN3o_/GP00;o_/GP
0onm_]/3oi]k[`GoVGjd0_nGPk`2oiahZPCoVg^_1?nJP;D5oiV5_@;oVHc500?oXhjooj6BaOnQT/D0
0onQT/D3oinGc004o`000?nOUlcoWYcBoijLdP;oYYo?1?nTY=D4oj>Yf`03ojbdg_n[^>?oZkSS00?o
ZkSS0onZ_>L2ojo2j1Cooooo00?o0000ooooooooool0:Oooool002Wooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Wooooo`;o<`000_lm00P3odD04`03od/06_mH02_oEP0/00;oEP0/
0omD02/2oe40:P;oC`0X00Co<P00ocH00?lf003o=P000onT_nd4ojFljP;oY[_X0_m=b[h2oiA/XPCo
U6^Q1onCJj49oi9ZX@[oT6FL1?n@IYd3oi5WWPCoTFRO0onBJZ43o`0000;oU6bR0onFKj@00onPOJco
X7f]oj1m[@06oj1m[@GoWgb/0onNNj`00onUSK_oYH^jojF;^P02ojF;^PCoYH^i1?nWSKT00onncNKo
_/GPokk5h004okk5h003okfnfonMNJ[oVg^_00?oVg^_0onIO[@00onMMZKoW7RZoiahZP02oiahZPCo
Vg^_1OnJP;D3oiV5_@03ojF<^_nSS[ooXhjo00;oXhjo1?nQT/D3oinGc003o`000?nWW<[oYYo?00?o
YYo?1OnTY=D00onSZM_o[;CNojbdgP02ojbdgPCoZkSS00?oZ[cWojo2j?n_`^P00on_`^PDooooo`03
o`000?oooooooooo02Sooooo000Yooooo`?o00005oooool00ol0003oooooooooo`0Sooooo`03obH0
0?lc003o<`0000;o<`0000Co?@08odD04omG02SoE`0X0omH02/2oeH0;0?oE00[0omA02X2oc8000?o
X/?`1OnT_nd2ojFljP;oALFl0_nEKJ83oiA/XPCoU6^Q1onCJj46oi9ZX@goT6FL1?n@IYd3oi5WWPCo
TFRO0ol000000onBJZ7oU6bRoiA/XP02oiA/XP04oiI_Y?nPOJcoX7f/oj1m[0SoX7f]1OnOO:`00onN
NjcoYHfkojF=^`02ojF=^`?oYH^j1OnURkT2ojN=^@?o_/gV1?nnaN03oieiZPCoVg^_00CoVGjdoief
Y_nMMZKoWGJV1OnLN:X3oi]k[`GoVX2e00?oVHFmojF<^_nUS;X00_nUS;X3oj>>_`GoXI;500GoWiO<
ojNLb_nWW<[o0000ojNLbP04ojJOc`?oY:CE00?o[[;Kojbdg_n/]=h01?n/]=h2oj^hh`;o/<;W1?n_
`^P00on`a^[oooooooooo`0Aooooo`;o0000:_ooool002Wooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Qooooo`;o9P000olc00000omE02?oE`0XoeL0:002oeL0:0;oF00[0omF02`3
oe@0:`04oe40:_nPb?CoX<Sdoj38m0GoX/?`0_nT_nd2od72_@;oUFjS1?nEKJ83oiA/XPCoU6^Q1onC
Jj42oi9ZXA7oT6FL1?n@IYd3oi5WWP04oi5XWol0003o0000o`0000CoTVZQ0onDK:800onOO:coX7f/
oj1m[003oj1m[0SoX7f]0onOO:`00onXTKkoYHfkojF=^`03ojF=^`?oYH^j1OnURkT00onWSKWo_/gV
okk=iP03okk=iP03okk5h?nOMjKoWGVZ00?oWGVZ1?nKNjl5oiefYPCoW7RZ1?nKNjl3oiZ0]@03ojN:
]_nUS;[oYHbj00?oYHbj0onSS[l4oj6Ba@03ojZJa_nWW<[oYic:00;oYic:00?o0000ojJOconVWll0
0_nVWll00onTY=Go[[;Kojjbf`02ojjbf`Co[;CN00?o//CWok32ion``^L00on``^L00on_`^So/<KZ
ok36jP02ok36jQCooooo00?o0000ooooooooool09oooool000kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Nooooo`03oaL00?lV003o9P0000?o<`000_mE02<3oeL0:0?oF00[0_mF02`2oe@0:`?oWLch
1?nPb?@2oj;3l0?o?l;20_nFKj@3oiE^X`CoUFfR0onDK:84oiA[X@KoTf^Q00?oTFJMoi1UW?n@II`0
4On@II`4oi1VW@04oi5WW_l0003o0000o`0000CoTFRO0onBJZ401?nDK:;oWgb/oiml[?nOO:`5oj1m
[0SoX7f]00?oWgb/ojRA__nXTKh00_nXTKh4ojF=^`CoYH^j0onURkT2okcEk0Co_/gV0onOMjH5oiei
ZP;oVg^_00?oWgJToiefY_nMMZH00onMMZH4oiahZPCoVg^_00?oVX2eojN:]_nWR[H00_nWR[H4ojF<
^PCoXhjo00?oXI;5ojZJa_nZV/H00_nZV/H3ojNLbP05o`000?nWW<[oYYo?ojJOcon`/MP01_n^/]/0
0on/]=ko//CWok;4i`02ok;4i`?o/<;W00?o/L[/ok36j_n`a^X00on`a^XEooooo`03o`000?oooooo
oooo02Kooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06ooo
ool3oaL00004obH00?lc003oD@0Koe406`;oE@0S1?mG02P2oeP0:`04oeH0;?nKcOWoVlgioi_=n@Go
WLch0_nPb?@2od?5b@;oUW6V1?nFKj@3oiE^X`CoUFfR1?nDK:83oiA[X@GoTf^Q0_nAIYdCoi1UW0;o
T6JM0ol00002oi5WWPGoTFRO0_nBJZ400onMNZ_oWgb/oiml[003oiml[0CoX7f/1onPOJd00on/VLCo
Z96nojRA_P03ojRA_PGoYHfk0onURkX00onURkWo_=G/okcEk003okcEk003okk=i_nPMZCoX7JT00?o
WgNV1OnMNJX01?nKNjooWgJToimfY?nOMZ@4oiefYPCoW7RZ1?nKNjl5ojN:]PGoYHbj0_nSS[l00on]
V/?oZY[6ojZJaP03ojZJaPCoYic:00?o0000ok2af?n`/MP00_n`/MP4ojjbf`03okC7j?nba>Oo//CW
00?o//CW00?o/<;Wok7:k?nab^`00_nab^`2ok36jP?o[/S]5?ooool00ol0003oooooooooo`0Voooo
o`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^
00Kooooo0_l0000Mooooo`03o`000?oooooooooo01Sooooo00Go2000oaL00?lG003o5`00odX04@04
oe406`;oE@0S0omG02P01?mH02_oVLgjoiW=n_nIcOX4oi_=n@;oWLch0om:b]82oiMbZ0?oUW6V1?nF
Kj@3oiE^X`CoUFfR1?nDK:83oiA[X@;oTf^Q0_nAIid3oi5VWA?oT6FL0_l00002oi1VW@CoTFNN1?nA
J9l00onBJZ7oWGZ[oiejZ`05oiml[0CoX7f/1OnPOJd4ojbIa0CoZ96n1OnUSK/2ojF;^P?o]mkc0_nl
eN`5oj1fY0?oWgNV1?nMNJX00onRMjCoWgJToimfY002oimfY0CoWGJV1OnLN:X2oi]k[`;oZX^d1?nW
R[H5ojF<^P04oj>>_on]V/?o[I[3ojfJ``GoZY[600GoYic:ok>beonc/]Oo/k;Go`000004ok2af003
ojjbfondanSo]<OX00;o]<OX0_nba>L3ok;?k`?o/L[/0_n^c_45ojk8kACooooo00?o0000oooooooo
ool09Oooool000kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Go
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Fooooo`;o20000_lG0002odX04@?o
D@0K0_mE02<01?mG02SoV<WioiS9nOnHbOT5oiW=nP;oVlgi0_mFdM`3oiMdZP?oUg:X0onFLJH4oiI_
Y0?oUFjS1OnEKJ83oiA/XP;oU6^Q00?oTVNNoi5WWOnAIid00_nAIid3oi5VWA3oT6FL0ol00005oi1V
W@?oTFNN0onAJ9l00onLN:_oWGZ[oiejZ`02oiejZ`CoWgb/1OnPOJ`2oj1m[@03ok6Tbon/VLCo[9W4
00?o[9W41OnXTKh3ojF=^`;o[NKi0ongg_<4oj5eXPCoX7JT1?nOMjH2oieiZP;oXWNT1?nOMZ@4oief
YPGoW7RZ00CoVg^_ojZ;]?nZRkCoZX^d1OnWR[H3ojF<^P03ok6M`on]V/?o[I[300;o[I[31?nZV/H0
0onh]mSo/k;Gok>be`03ok>be`03o`000?n`/MSo^<o/00;o^<o/0ondanP2ok7Fl`Go//o_00?o/L[/
ojk>lOn^c_400_n^c_42ojk8k@;oZ<C^5Oooool00ol0003oooooooooo`0Tooooo`003_ooool01Ol0
003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`0N
ooooo`;o00005?ooool01Ol0003o2000o`P00?lG003o@P0400;oBP0A0omA01/01?mE02?oV<CfoiS4
m_nHa?H4oiS9n@;oVLgj0omRf>D2oiMg[0CoUgBZ0onGLZP4oiIaYP?oUVnT1?nEKZ<4oiE]XP;oU6bR
00CoTVROoi9WW_nBIikoTVNN1?nAIid4oi5VW@coT6FL0ol00004oi1UW0CoT6JM0onAIih01?nAJ9oo
W7R[oiahZonLN:/4oiejZ`CoWgb/1OnPOJ`01?nPOJgo/JC;ok6TbonaY</4ojbIa0GoZ96n00?oYHfk
ojgVnOn]i_T00on]i_T00ongg_?oXGFRoj5eXP03oj5eXPCoX7JT1?nOMjH01?nMNJ[oXWNToj9gY?nR
Mj@4oimfY0GoWGJV0onLN:X00on]S;?oZX^dojZ;]002ojZ;]0GoYhZf00CoYHbjok6M`onaWL?o/Ig3
1On]V/<00onZV/Ko^;OHokRgf002okRgf0?o/k;G00?o^M_ao`000?nhcn`01?nhcn`00ondanSo/MKc
ok7Fl`02ok7Fl`;o//o_0on/eOH2ojk>l@?oYlWa1?nXa>hCooooo`;o00002?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`02Oooool000ko
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00?ooooo0_l0000Qoooo
o`03o`000?oooooooooo013ooooo00?o0000o`P00?lg00000om200@00om:017oD@0KoiRll@02oiRl
l@GoV<Cf0_nHbOT2og3Nk@;oV7V_1?nGMj`4oiMdZP?oUg:X1?nFLJH4oiI_Y0?oUFjS1?nEKJ800onD
K:;oTVROoi9XW`03oi9WWPGoTFNM0onAIYd9oi1UW0?o00001on@II`4oi1VW@;oTFNN00?oVWNZoiah
ZonLN:/00onLN:/3oiejZ`GoWgb/0onPOJ`00ong/mGo/JC;ok6Tb`02ok6Tb`Go[9W40onXTKh3oi[[
n0;o[NKi0_n@Iih00onQM:7oXGFRoj5eXP03oj5eXPGoX7JT0onOMjH5oj9gY0?oWgJT1OnMMZH00onL
N:[o[Hbcojf</`02ojf</`CoZX^d0onWR[H00ongYLKo/Ig3ok6M``03ok6M``?o[I[300?o_;oLokRg
f?nh]mP01?nh]mP01Onc/]Oo^M_aokWKlOnifo7o000000;o^<o/0on^goP2ok7Fl`;oY]cj1?n/eOH2
ojC=m@GoYlWa0_nXa>h2ojC0kACooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B402Oooool000kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool2o`0002?o
oooo00?o0000ooooooooool03Oooool2o`0000?o=`000_m200@2oiNdj`GoV;ca0_nHa?H3ogWRl@;o
VGba1?nHNJl3oiMg[0CoUgBZ0onGLZP4oiIaYPCoUVnT0onEKZ<2oiE]XP;oTVZQ0onBJ9l4oi9WWPCo
TFNM0onAIYd6oi1UW0?o00002_n@II`3oi1VW@04oiUeZOnJMj[oVWNZoiYgZPGoW7R[0onMNZ/5oiml
[003oj1m[?ng/mGo]k?E00;o]k?E0onaY</5ojbIa004ojRA__nJjoSoV^_hoi[[n0CoT6BK00?oT6NN
oj5dXOnQM:401OnQMJ85oj1fY0;oWgNV00?oYW^Uoj9gY?nRMj@00onRMj@4oimfY0?oWGJV00?o/I2d
ojf</on]S;<00on]S;<4ojZ;]003ojN:]_ngYLKo]jG600;o]jG61?naWL<00on]V/?o_;oLokbog002
okbog0Co^;OH00?o]NcfokWKlOnifo400_nifo400onRj?_o0000ojkOn002ojkOn0;oVn7m1?nVg?X0
0on/eOKoY<geojC=m@03ojC=m@;oYlWa0_nS`Nl5ojC0kACooooo00?o0000ooooooooool01?ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000009ooooo`003_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool02_ooool2o`000003ob/00?lg003o=`0000;o
UZgV1OnG]>/2oiRll@GoOn?d00?oNN;aoiUl/OnIO;400_nIO;43oiQi[`CoUgN/0onGM:X4oiMbZ0?o
UW6V1?nFKj@2oiE^X`03oi9[X_nBJZ7oTVZQ00;oTVZQ1?nBJ9l3oi9WWPCoTFNM0onAIYd3oi1UW0?o
00003On@II`01?n@IYgoVGFYoiUeZOnIMJT4oiYgZPCoW7R[1?nMNZ/3oiml[003okg6hOng/mGo]k?E
00?o]k?E1?naY</2ojbIa0;oM^?T1?nAHiT3oi1TV`03oj5dX?nQM:7oXGBQ00;oXGBQ1?nQMJ85oj1f
Y003oimgY_nVNjGoYW^U00GoXWNT1?nOMZ@2oiefYP;o/I2d1On]S;<4ojZ;]0Go]jG61?naWL<6okbo
g003okRgf?nek?Ko]Ncf00;o]Ncf00?o^M_aoj;XnonRj?/00_nRj?/00ol0003oVn7moi_Qo@03oi_Q
o@;oY]cj0onOcoP2ojC=m@;oXL7`1OnS`Nl3ojC0k@03oj:mk?oooooooooo01;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P09ooooo`009oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Oooooo0_nDXml4
oiFWhPCoUZgV0onG]>/4oh3Sm@;oOn?d0onKOk@4oiUl/@?oV7V_1?nGMj`4oiMdZP?oUg:X0onFLJH2
oiI_Y0;oTVbT0onBJj84oi9ZX@CoTVRO0onBIih4oi5WW@?oTFJM0ol0000>oi1UW0;oV7BX1?nIMJT4
oiYgZPCoW7R[1?nMNZ/00onOO:co_LKQokg6h@02okg6h@Go]k?E0_naY</2od;2/P?oTF:H1?nAHiT2
oi1TV`;oXGBP1?nQM:45oj5eXP?oX7JT00?o[8:XojIkYOnVNjD00_nVNjD4oj9gY0CoWgJT00?oWGJV
ok6@]?naT;@00_naT;@5ojf</`;oZX^d0_o2]/h4okNUaP?o/Ig30_o1cnD4okbog0;oUO7X0_nek?H4
oh?Vl@;oX^Sk00?oR>7lo`000?n8hO`00_nKhOd3oiS@n`;oWloh0onN_o04oj71l0CoXl7_00?oY<3]
oj:mk?nR_N`00_nR_N`Dooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05olc<c?l0003o0000o`000?o<c<`02Oooool002Oooooo0_l0000Vooooo`03o`000?oo
oooooooo00?ooooo0_nCXMh4oiBSg`CoUJOR1?nF[NH00onG]>_oP>?eoh3Sm@02oh3Sm@?oWH>f0onK
Ok@4oiUl/@?oV7V_1?nGMj`4oiMdZP?oUg:X0_nFLJH00onAKJGoTVbToi9/Y002oi9/Y0?oTV^R1?nB
JZ44oi9XW`?oTVNN1?nAIid00onAIYgo0000o`00000>oi1UW003oiMcZ?nHM:SoV7BX00;oV7BX1?nI
MJT4oiYgZPCoW7R[1?nMNZ/5okg6h@Co]k?E00CoTV:Foi9RUonBHYOoTV:G1OnAHYP3oi5SV@04oi1T
VonQM:3oXGBPoj5dX0CoXGBQ1OnQMJ82oj1fY0;o[8:X1?nVNjD4oj9gY0CoWgJT1OnaT;@5ojf</`04
ojZ;]?o2]/ko`[K>ol:fcPGo]jG600?o/Ig3ol7?iOo1cnD00_o1cnD01Onl_mcoUO7XoiGaj?nElNSo
C<_=00?oFlkc0_m_f?H3ohc7n`;oT/gl00?o0000oi;=o?nBcO`00_nHd?/2oibkkPGoW[o`0onQ`O02
oj?1k`?oXKc/1?nR_N`Eooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41002Oooool002Oooooo00?o0000ooooooooool09?oo
ool2oi2OgP?oTIoM1OnCXMh3oiBSg`GoUJOR0_nF[NH2ogcQm@CoX8Ni0onMPkH4oi]o]0?oVGba1?nH
NJl3oiMg[0CoUgBZ0_nGLZP01?n@KZOoTFfUoi5]YOnAKJD4oi9/Y0CoTV^R0onBJZ44oi9XW`?oTVNN
0_nAIid3o`0000;oTFJM3On@II`2oiMcZ0GoV7BX0onIMJT4oiYgZPGoW7R[0_nMNZ/2okoJk@Go_LKQ
00Co]k?Eoi9RU_nBHYKoTV:F1?nBHYL4oi5RV0?oTF>I1OnQM:03oj5dX@GoXGFR00?oX7JTojb2Z?n/
PZP00_n/PZP3ojIkY@GoXWNT0onOMZ@5ok6@]0Co[Hbc00?oc]KOol:fc_o2]/h00_o2]/h4okNUaP03
okkWl_o1cnGo`LoU00;o`LoU00?o0000ofFmoOmDa?P00omDa?P2oe_>l`;oSKog1On<ao/2oi;=o003
o`000?nK]N[oW;_^00CoW;_^0_nN_o02oj6gj0CoXK[[1OnQ_>`2oj:mk0;oXkc[4_ooool3o`0000Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000002Oooool0
02Oooooo00?o0000ooooooooool07_ooool00on=XN7oSj3OohnPg`02ohnPg`CoT9oN0onAWmd5oi>Q
gP?oU:?O0_nEYn83ogKNm@CoXh^k0onPQkT3oif3]PCoVgnd1?nIO;43oiQi[`;oUgN/00?oT6jYoi1^
Z?n@KZP00_n@KZP3oi1^Y`?oTFfU1?nBK:@4oi9[XP?oTVZQ1?nBJ9l2oi9WWP?o00000_nAIid4oi5V
W@WoT6FL0_nFLZP4oiMcZ0CoV7BX1?nIMJT3oiYgZPGoW7R[00?oWGZ[okoJkOnof^d00_nof^d2okg6
h@KoTV:F1?nBHYL4oi5RV0;oTF>I00?oX7>Qoj5dX?nQM:000onQM:03oj5dX@GoXGFR1On/PZP3ojIk
Y@GoXWNT0_nOMZ@2okBF]`Go/I2d0_n]S;<3olkFg`Co`[K>00?o]jG6okkWl_nnio800_nnio800oo1
cnGoIKgmofFmo@03oiNXhPCoT;?^1?n=_oL2ohc7n`;oVZgT0_nK]NX00ol0003oVkGZoi^ejP02oibk
kP;oX;?U1OnQ]nP4oj6jj`;oXKc/0_nS^NT5oj>ljaCooooo00Wo0000ooooooooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Wooooo000Vooooo`?o0000
6?ooool2ohVSi@?oRj;S1?n=XN44ohnPg`?oT9oN1?nAWmd2oi>QgPCoJ=Kd0_m_f_@2ok:Xc`03ojJ?
__nSRk_oXh^k00?oXh^k0onPQkT4oif3]P?oVgnd1?nIO;42oiQi[`04oi1_ZOn@KZWoT6jYoi1^Z@Co
T6jX1?n@KZL3oi5]Y@?oTVbT1?nBJj84oi9ZX@;oTVRO0ol000000onBIikoTFNMoi5WW@03oi5WW@?o
TFJM1_n@II`00onELJSoUW:XoiIbZ002oiIbZ0CoUg>X1?nHM:P4oiUeZ@CoVWNZ0onLN:/3ok[[m0;o
_m[]2OnBHYH4oi9RU`CoTF:H00?oTF>Ioj1cXOnPLj401OnQM:04oj5dX@?oXGFR00?o/hj`ojb2Z?n/
PZP00on/PZP3ojIkY@GoXWNT00CoWgJTokBF]ondU[Oo]9Jg1OnaT;@00on]S;?oc]KOolkFg`02olkF
g`;o`[K>1?nBl>@2okkWlP?oWIkD1OnGZ>82oi2ckP03oinOe?nLYMcoW:GL00?oW:GL1?nJ[N@2oi^e
jP03o`000?nQ[^7oX;?U00CoX;?U1?nQ]nP2oj6jj`;oXkKV1OnS^NT2oj>lj`;oYKgZ5Oooool00ol0
003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0<ooooo`04ognYkon2YncoPZO/oh:W
k0?oQ:KZ1?n7Y>P4ohVSi@?oRj;S0on=XN45ohnPg`?oT9oN0_nAWmd4of;Am@;oJ=Kd0one[M401?nb
Z<ooYXnnojJ?__nVSkh4oj>;^`CoX8Ni0onMPkH3oi]o]0;oVGba0_nAL:X3oi1_Z@CoT6jY0on@KZP4
oi1^Y`?oTFfU1?nBK:@3oi9[XP?oTVZQ0ol000000onBJ9ooTVNNoi9WWP02oi9WWPCoTFNM0onAIYd3
oi1UW004oiAaZ?nELJSoUG6XoiEaZ0GoUW:X0onGLjP4oiQdZ0CoVGFY1?nJMjX00onLN:_o^^_dok[[
m002ok[[m0goTV:F0onBHYL3oi5RV003oimcXOnPLj7oX7>Q00;oX7>Q1?nQM:04oj5dX@;oXGFR0onc
S[04ojb2Z0CoYW^U0onRMj@00onjXL3o]9JgokBF]`02okBF]`Co/I2d0_nkoM`3olkFg`?o00000_nB
l>@3oj6Gb@GoWIkD0_nGZ>82oj>Kc@CoWioD1OnLYM`2oiZ]i006oj>YfonQ[^7oXJkQoj6^hOl0003o
XJkQ1?nP/nD2oj6gj0?oY;?T1?nS]^H2oj>ij@?oYK[X1?nU_NXDooooo`03o`000?oooooooooo01ko
oooo000Kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooofn/mP02ofn/mP?o
Ljce0omhZo<3og^Zl@?oOjW_0on2Yn`3ohBVjPCoQjCX1?n9XnD3oh^Rh`?oSJ7Q0_n?X=l4oeg;n0;o
G/kf00?o^[GDokRadonh/M<01?nh/M<2okF]d@03ojVD`OnVSkkoYXnn00;oYXnn1OnSRk/3oj27^@;o
WH>f00CoU7B/oi9bZonBLZ_oTW:[1?nAL:X4oi1_Z@?oT6jY0on@KZP4oi1^Y`?oTFfU1?nBK:@3oi9[
XP?o000000?oTVZQoi9XWonBJ9l00_nBJ9l3oi9WWPCoTFNM0onAIYd01?n@IIcoU76XoiAaZ?nDLJP4
oiEaZ0CoUW:X0onGLjP4oiQdZ0CoVGFY0onJMjX3oj_dl`03ok[[m?nBHYKoTV:F00goTV:F0onBHYL0
1?nAHYSoWg>QoimcXOnOLj44oj1cX@CoXGBP1?nQM:400onQMJ;o/hj`ok>>/002ok>>/0Co[8:X1?nV
NjD2oj9gY0?o^Z701?ndU[L2ok6@]0Co^ogL00?oc]KOoib;`OnLRl400_nETLd00onVTl;oXIO9oj6G
b@03oj6Gb@?oWIkD00?oZ9[7oj>KcOnSVld00_nSVld4oinOe0CoW:GL00?oYJKFoj>YfonSZM/00_nS
ZM/3oj6^h@04o`000?nQ[^7oX;?Uoj2ci@;oYK3P1OnT/n@2oj>fiP;oY[SV1OnU^^P2ojFmjP;oYkkZ
5?ooool00ol0003oooooooooo`0Mooooo`006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool00om_[?H3og>/m@?oN:_c0omkZ_43ognYk`?oPZO/0on4Y^X4ohNTj0;oRJ?U
0omQ`od4oeo6o0?oG/Sj0_mMboP00oo2fn_o`]g]okZee002okZee0Co^;7C00?o[9[4ojVD`OnYU<40
0_nYU<43ojJ?_PGoXh^k0_nPQkT01?nFMjkoU7B/oiAd[?nDM:`3oi9bZ`CoTG2Z1?n@KjT3oi1^Z@Co
T6jX0on@KZL3oi5]Y@CoTVbT0ol00004oi9ZX@CoTVRO0onBIih4oi5WW@;oTFJM00?oU76YoiAaZ?nD
LJP00_nDLJP4oiEaZ0CoUW:X0onGLjP5oiQdZ0?oVGFY00?oVWNZoj_dlon[m?<00_n[m?<00onAHIKo
TV:Foi9RUP0>oi9RUP?oTV:G1?nOLj44oj1cX@CoXGBP1?nQM:45ok>>/0Go[8:X0onVNjD00onRMjCo
^Z70okZQ`002okZQ`0Co]9Jg00Co/I2dok_mg?nkoMco^ogL1?nLRl400onYT[goYY?2ojJC`P02ojJC
`PCoXIO900?oWIkDojRJaonXV/L00_nXV/L4oj>Kc@CoWioD00?oW:GLojFVe_nUY]H00_nUY]H4oj>Y
f`;oXJkQ00?o0000ojJ^gOnU/>001?nU/>02ojBci0;oYkKT1OnV^>H2ojFjj0;oZ;gX1OnW_^XCoooo
o`;o00007_ooool001_ooooo00Go410@oooooooooooooooooa0@4006ooooo`;o00000_ooool3ofZZ
mP?oJJgh1?mX/?X3ofNcn`?oI[Ol1?mU^_d3ofBmo@?oHl3m0_mQ`od3oan/`003oh7Xhonbl_Go/_;e
00Co`]_[00?o_;SFokZee?nj]M@00onj]M@00onh/M?o[9[4ojbJa002ojbJa0?oZIC11?nVSkh3oj>;
^`04oiUk/?nFMjkoUWN^oiIg[PCoU7B/0onBLZ/3oi5`ZPCoT6nY0on@KZT4oi1^Z0?oT6jW0onAKJD0
1?nBK:Co0000o`000?l00004oi9[XP?oTVZQ1?nBJ9l3oi9WWP;oTFNM0_nCLJT3oiAaZ@CoU76X1?nE
LJP4oiIbZ0CoUg>X1?nHM:P2oiUeZ@;oTo3W0_n@HIH4oi5QUPooTV:F0_nBHYL00onNLj;oWg>Qoimc
X@03oimcX@?oX7>Q1OnQM:03oj5dX@Go/hj`1On/PZP2ojIkY@03ol2fd?njXL3o^Z7000?o^Z700ond
U[L2ojJ9]PCoXXVj00CoW8_1ojVB_OnYT[goZI:m1?nVTl83oj6Gb@03ojbJaOnXV/OoZ9[700?oZ9[7
1?nSVld2oinOe0;oZJCA1OnUY]H2oj>Yf`;oZJcJ0onV[]d00ol0003oYZkMojF`h002ojF`h003ojVe
h_nW]^CoYkKT00?oYkKT0onV^>H00onY_>OoZ;gXojRmj003ojRmj0?oYkkZ00?oZL3Zooooooooool0
4?ooool00ol0003oooooo`00000Nooooo`006oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00_ooool3ofZZmP?oJJgh1?mX/?X3ofNcn`?oI[Ol0_mU^_d4odc2l`;o?kkW
0_lf_</3oi;]lP;o]^cf1?o2f>X01?o2fn_o_;SFokbhe_nl^=H3okZee003ojnOaon/V/Co[9[400?o
[9[40onYU<44ojJ?_P04oj>;^onINk3oVG^`oiUk/0?oUWN^1?nDM:`3oi9bZ`CoTG2Z0on@KjT3oi1^
Z@CoT6jX1?n@KZL00onAKJGo0000o`000003oi9/Y0CoTV^R0onBJZ42oi9XW`;oTG6[0onBLJX4oi=a
Z@CoU76Y0onDLJP4oiEaZ0CoUW:X1?nGLjP3oiQdZ0;oNNCF00?oSf2Foi1QU_n@HIH00_n@HIH4oi5Q
UPooTV:F00?oTV:GoiicX_nNLj801OnOLj43oj1cX@GoXGBP0_nQM:42ol6U_@Co/hj`1On/PZP01?nV
NjGo`;K@ol2fd?o0]]05okZQ`004okBF]onVRKKoYXVfojJ9]P?oXXVj00?o[I>lojVB_OnYT[d00onY
T[d4ojJC`P04oj6GbOn/V/Go[9[5ojbJa@GoZ9[70_nSVld00on/XlkoZJCAojVTd@03ojVTd@?oYJKF
00?o[:cHojV/f_nY[=X00onY[=X3ojJ^g@03o`000?nU/>3oZKGR00?oZKGR1?nW]^@00onV^>KoZKcW
ojVli`02ojVli`CoZ;gX00?oYkkZojW0j_nY`>X00_nY`>XDooooo`03o`000?oooooooooo01_ooooo
000Kooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`CoLjkf
0om^]?X4ofRjo@?oH;km0_mG`OX4oeo>mP;oC<WT0_mUfN@2oi;]lP?o]^cf1?o2f>X00onm^mSo_;SF
okbheP03okbheP04okZee?n_WlOo[io7ojnOa`Co[9[41?nYU<42ojJ?_P03oi]o/onINk3oVG^`00;o
VG^`0onFMjh4oiAd[0?oTW:[1?nAL:X3oi1_Z@CoT6jY0on@KZP2oi1^Y`?o00000_nAKJD3oi9/Y0Co
TV^R0_nBJZ400on@LJcoTG6[oi5aZ`02oi5aZ`?oTW6Z1?nCLJT4oiAaZ@CoU76X0onELJP5oiIbZ0?o
Ug>X00?oV7BXogWTe_mii=H01?n?H9H3oi1QUPCoTF6F3_nBHYH00onMM:?oWW>RoiicXP02oiicXPCo
Wg>Q0onPLj45oj5dX004oj5dXOo1YKgo`JFmol6U_@Go/hj`0on/PZP00oo2gnko`;K@ol2fd002ol2f
d0Co^Z7000?oZXbeojJ9]_nVRKH00_nVRKH00onRRK[o[I>lojfC_002ojfC_0CoZI:m0onVTl800ona
W/Co[9[5ojbJa@02ojbJa@CoZ9[700?o/:G=ojbSc_n/Xlh00_n/Xlh5ojVTd@04ojFVe_n/[=So[:cH
ojb/f0GoZJcJ0_nV[]d00ol0003oZkCOojVehP04ojVehP;oYkKT0_nZ^nH5ojVli`;oZ;gX0_nZ_nT3
ojW0jP03oj[1j_oooooooooo01?ooooo00?o0000ooooooooool06_ooool001_ooooo00Go410@oooo
oooooooooooooa0@4005ooooo`03o`000?oooooooooo00Gooooo1?mc[_H3ofjdnP;oJ;[m1?mhaol3
ofg=oP;oGlkf0_mig_H3oikZnP?o^>Ge0oo1e>P00oo2f>[o_K_Hokfkf002okfkf0?o_;SF00?o/ZG;
ojnOaon_WlL00on_WlL4ojbJa0;oZIC100CoWXBgoi]o/onKOk?oVgnc1?nINk04oiIg[P?oU7B/0onB
LZ/4oi5`ZPCoT6nY0on@KZT2oi1^Z0?o00000_n@KZL3oi5]Y@;oTVbT00?oSW6^ohma[On?LJd00_n?
LJd3oi1a[0CoTG6[1?nBLJX3oi=aZ@CoU76Y1?nDLJP4oiEaZ0CoUW:X0_nGLjP2of7GaP;oSUnF1?n?
H9H3oi1QUPCoTF6F3?nBHYH3oiedX`CoWW>R1?nOLj44oj1cX@?oXGBP00?oe=?Hol6U_Oo1YKd00_o1
YKd5ok>>/003ojb2Z?o2gnko`]o^00;o`]o^1?o0]]000onjXL3oZXbeojZ<]@02ojZ<]@;oYXVf00?o
[iJlojfC_?n]Tk`00on]Tk`4ojVB_@03ojJC`_naW/Co/Ik400;o/Ik41?n/V/D00onXV/Oo/:G=ok2U
c@02ok2Uc@Co[:?>0_nYY=42ojn^e`Go[:cH0_nY[=X2ojfegP?oZkCO00Co0000oj^dgonY]N;oZKGR
0_n/^nD5ojZkiP;oZKcW1onZ_nT01?nY`>[oZ/7Zoj[1j_nZ`NXDooooo`03o`000?oooooooooo01[o
oooo000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000Oooooo0_mc[_H2ohFem0Go
Okkk0_mhaol3oi3CoP;oQm_n0onUh_/4okSMlP03okSUmOo1e>So`MCX00;o`MCX00?o_[kIokfkf?nm
^mP00onm^mP01?nl^=Ko/ZG;ok:UbonbYL/4ojnOa`?o[9[400CoXHVjoij4]onNQ;OoWXBg1?nKOk<4
oiUk/0?oUWN^0onDM:`4oi9bZ`?oTG2Z1?n@KjT2oi1^Z@?o00001On=L:h3ohea[P?oSW6^1?n?LJd4
oi1a[0?oTG6[1?nBLJX4oi=aZ@?oU76Y1?nDLJP4oiEaZ0?oUW:X00CoCl^koheNU_n=GYKoSEjF0on>
GiH4ohmPUP?oT66F1?nAHIH:oi9RUP03oiadYOnMM:?oWGBS00;oWGBS1?nNLj84oimcX@CoX7>Q0_nQ
M:03omCCf0Co`JFm0oncS[02ofOJa@Co`]o^0_o0]]02ojf?]PGoZXbe00CoYXVfojnF_?n_U[co[iJl
1?n]Tk`3ojVB_@03okBSaonaW/Co/Ik400?o/Ik40on/V/D00oncZ<ko/:G=ok2Uc@03ok2Uc@?o[:?>
00?o/[;Hojn^eon_[]L00on_[]L3ojb/f003ojngg_n]]Mko[KGN00?o[KGN0on[]=l00ol0003o[;_U
ojbki@03ojbki@;oZ[_V0_n[_nP7ojZoj@;oZl7Z1OnZ`NXDooooo`03o`000?oooooooooo01Wooooo
000Kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`07ooooo`CoQKGd
0_mo__/4oiK7n0;oT=?n1?nXeoP00onUh__o^=gbokSMlP02okSMlP;o`=3V0oo1e>P3okjnf@?o_K_H
00?o]J[>ok:UbonbYL/00_nbYL/5ojnOa`04ojbJa?nQRK[oXHVjoj69^P?oWXBg0onKOk<4oiUk/0?o
UWN^1?nDM:`3oi9bZ`?oTG2Z0_n@KjT01On?LJgo0000o`000?l0003oSW6]00OoSG2^0on=LJh4ohia
[P?oSg6]1?n@LJ`4oi5aZ`?oTW6Z1?nCLJT3oiAaZ@CoU76X1?nELJP00onFLZSoSEjFoheNUP04oheN
UP?oSUnF1?n?H9H3oi1QUPCoTF6F2OnBHYH2oiadY@GoWGBS0onNLj84oimcX@CoX7>Q00?oXGBPomCC
f?oDdmP00_oDdmP4ol6U_@03ok>>/?nVQK;oYXFb00;oYXFb00?oIm[5ol;Ok_o2gnh00_n`TkT4ojf?
]P?oZXbe00?o/IZoojnF_?n_U[`00_n_U[`5ojfC_004ojVB_OndXlOo]:?7okBSa`Go/Ik400Co[9[5
ok>Xc_ncZ<ko/jS>1On`YLd01?n/Xlko/[;Hok:bf?nb/]P4ojn^e`03ojb/f?n_]mko[kON00;o[kON
1?n]]Mh01On[]=oo[KcUojfliOn]_>Go000000?o[;_U00?o[<3Xoj^oj?n[_nP00on[_nP2ojZoj@?o
Zl;Z1?n[`NX2oj[1jP;oZ/7[5?ooool00ol0003oooooooooo`0Iooooo`009Oooool00ol0003ooooo
ooooo`08ooooo`;oQKGd0onH_?03oiK7n0?oZLcb0onXeoP3okSDkP03okSMl_o0d>Ko`=3V00?o`=3V
00?o`MCXokjnfOnn_]T00onn_]T01?nm^mSo]J[>okFZc_neZ/h4ok:Ub`;o[io70_nTSkh4oj69^P?o
WXBg0onKOk<4oiUk/0?oUWN^1?nDM:`2oi9bZ`CoT7:]0ol000001?n?LJgoSW6]ohia[On>LJd7ohe`
[PCoSG6^0on>LJh3ohma[@CoT76/1?nALJ/3oi9aZPCoTg6Y1?nDLJT3oiAaZ0;oUG6X0_n<GIH7oheN
UP?oSUnF1?n?H9H4oi1QUP?oTF6F1onBHYH01?nKM:KoW7BUoiadYOnLM:D5oiedX`?oWW>R1OnOLj43
oj1cX@03ojcga_oDdmSoe=?H00?oe=?H0_o1YKd2ojJ5/@CoYXFb00?o/YRmok2C^On`TkT00_n`TkT4
ojf?]P;oZXbe0onaV[l3ojnF_0Co[I>l00?o^:_<okBSaondXlL00_ndXlL4ok6Na003okJ^d_ncZ<ko
/jS>00;o/jS>1?n`YLd00one^=_o/[;Hok:bf003ok:bf0;o[jkG00?o/K[Pojngg_n_]mh01?n_]mh2
ojfegP;o[koV0on]_>D00ol0003o[KcUojbki@03ojc0j0?oZkoX0_n[`n/5oj_2jP;oZl7Z0_n[`^/4
oj[1ja;ooooo00?o0000ooooool000006_ooool002Gooooo00?o0000ooooooooool02_ooool4oiRl
l003oiK7n?nYc?;oZLcb00?oZLcb00CoZ=OhokSDk_nhe>ko^=C^0onoc>@3ol3@iP;o_l3K1?nn_]T0
0ong[m7o]J[>okFZcP02okFZcP?o/ZG;00?oYiG3ojB?__nTSkh00_nTSkh4oj69^P?oWXBg1?nKOk<3
oiUk/0?oUWN^0_nDM:`2oi5d[`?oT7:]0ol00004ohma[@CoSW6]1_n=L:h4ohea[P?oSW6^1?n?LJd3
oi1a[0CoTG6[0onBLJX4oi=aZ@CoU76Y0_nDLJP00olm_kSoS5fFohaMUP02ohaMUPOoSEjF0on>GiH4
ohmPUPCoT66F0onAHIH5oi9RUP?oVgBV1?nLM:D4oiedX`?oWW>R1OnOLj42oj1cX@?o[?O60_oDdmP3
ojJ6/PCoYXFa0_nVQK82ok:H_@Co/9>i1?n]SkH00onZS;Go/IZook6J_`02ok6J_`Co[iJl00?o[I>l
okR[c?nhZl`00_nhZl`4okBSa`04ok6Na?nf[];o]ZkBokJ^dPGo/jS>00?o/:G=okFhfone^=/00_ne
^=/3ok:bf003ok:ohona^^3o/K[P00;o/K[P1?n_]mh00on``^Oo[koVojnoiP03ojnoiP;o[KcU00?o
[L;Yo`000?n/`>P01?n/`>P00on[_nSoZl?[oj_3j`02oj_3j`;oZl;Z0_n[`n/5oj_2j`;oZ/7[0_nZ
`^/Dooooo`03o`000?oooooooooo01Oooooo000Uooooo`;o00003?ooool2oiRll0?oZL3[0_nYc?84
okO;j@03okSDk_noc>Co_lcT00?o_lcT00?o`=3Voko0fono`=/00_no`=/00onn_]Wo]joAokN_d@02
okN_d@Co]J[>00Co/ZG;ojNE`onWUL?oYiG31?nTSkh4oj69^P?oWXBg0onKOk<2oiUk/004oi9h/_nB
M[3oTWJ`oi9f/0CoTGB_00?oT7:]o`000?l000001?n@LZd3ohma[@CoSW6]1on=L:h3ohea[P?oSW6^
1?n?LJd3oi1a[0CoTG6[1?nBLJX3oi=aZ@;oU76Y0olm`L86ohaMUPOoSEjF1?n>GiH3ohmPUPCoT66F
0onAHIH3oi9RUP03oiYeYonKM:KoVgBV00;oVgBV1?nLM:D4oiedX`CoWW>R1?nOLj400onPLj7oYXRd
ojJ6/`03ojJ6/`CoYXJb1?nVQK401?nVQK;o/YRmok:H_OnbV;d5ok2C^@;o[Hnf00?o/j35ok6J_ona
V[l00onaV[l3ojnF_003okZde?nhZlco^:_<00?o^:_<0ondXlL00ong]]So]ZkBokJ^dP03okJ^dP?o
/jS>00?o]koQokFhfone^=/00one^=/00onb/]So/[oSok:oh`02ok:oh`Co/K[P00?o[kONok32ion`
`^L00_n``^L2ojnoiP;o[LC[1?n]`^T00ol0003o[<3Xojc0j002ojc4k0CoZl?[00?oZlC/oj_3jon[
`n/00on[`n/2oj_2j`OoZ/;[4oooool00ol0003oooooooooo`0Gooooo`009?ooool00ol0003ooooo
ooooo`0=ooooo`?oZL3[0one`n@3okO;j@;o_LSR1?noc>@2oko1g0?o_l3K00?o^KGEokN_dOng[m40
1?ng[m42okFZcP03oj^LaonWUL?oYiG300;oYiG31?nTSkh4oj69^P?oWXBg0_nKOk<01?nDNkGoTWRb
oi9h/_nBN;83oi9f/0;oTGB_0ol00006oi1b[@CoSg6]0on>LJd7ohe`[P?oSG6^0on>LJh4ohma[@Co
T76/0onALJ/4oi9aZP;oTg6Y0_m6am<4ohaNUPKoS5fF2?n=GYH3ohiOUP?oSf2F1?n@HIH3oi5QUP04
oi9RU_nJMJOoVWFWoiYeY`CoVgBV1?nLM:D4oiedX`CoWW>R0onOLj43ojJ8]0CoYXJc1OnVQ[82ojJ5
/@03ok>N`onbV;go/YRm00?o/YRm1?n`TkT01?n]SkKo/j35ok>PaOncX<D5ok6J_`04ojnF_?nj]=Co
^[CDokZde0Go^:_<00Co]:?7okNff?ng]]So]kKH1?nf[]800oncZ<ko]koQokNoh@02okNoh@?o]KSK
0_nbaNP4ok:oh`;o/K[P0on`a^X3ok32i`;o[LO]1?n]a>/2ojg2j@;oZlG]00?o0000ojc4k?n/a>`0
0_n/a>`00on[`n_oZlC/oj_4k002oj_4k0;oZl?[0onZ`n`6oj[2j`;oZL7[5?ooool00ol0003ooooo
ooooo`0Fooooo`009?ooool00ol0003oooooooooo`0>ooooo`03ojW0jone`nCo]L?T00?o]L?T00?o
]l_Yokg8h_nmb>800_nmb>800onoc>Co_l7Loko1g003oko1g004oko0foni]MGo^KGEokVee@Co]joA
00?o[Z?<oj^Laon[W<L00_n[W<L3ojNE``CoY8nn0_nQRKX2oiR4_0?oUWnh0onDNkD4oi9h/P04oi9f
/?l0003o0000o`0000;oTGB_1on@LZd4ohma[@?oSW6]1on=L:h4ohea[P?oSW6^0on?LJd4oi1a[0;o
TG6[1?mYco`2oeG>jP?oSEnG1?n<GYH6ohaMUPSoSEjF0on>GiH3ohmPUPCoT66F0_nAHIH00onIMJSo
VWFWoiYeY`03oiYeY`?oVgBV1?nLM:D5oiedX`?oWW>R00?oWg>QojF9]onVR;@01?nVR;@3ojJ6/`Go
YXJb00CoYXFaok>N`oncW/?o/ik31?nbV;d3ok2C^@03okBXc?ncX<Go/j3500;o/j351?naV[l00onj
_mko^[CDokZde002okZde0Co^:_<00?o]l3QokNff?ng]]P00ong]]P2okJ^dP;o]/SX1Ong_n400one
^=_o//GXok;5j002ok;5j0;o/[oS0_n_b^h5ok36jP03ok32ion]ango[LO]00;o[LO]0_n]a>/2oj_7
kP?oZlG]00Co0000oj_5kOn/a>co[<C/0_nZaNd3oj_4k0;oZLC]1OnZ`n`2oj[2j`;oZL;[1?nY`N/D
ooooo`03o`000?oooooooooo01Gooooo000Tooooo`?o00003oooool4okG3i0;o_<CP0onmb>83oko3
g@?o_l7L00?o^k[HokVeeOni]MD00oni]MD00ong[m7o[Z?<ojjSc002ojjSc0?oZic71?nWUL<2ojB?
_P03oi^9_onHQ;coV8Bl00;oV8Bl1?nFOkP3oiAk]@04oi9h/_l0003o0000o`0000;oTWJ`1?nAM:l6
oi1b[@CoSg6]1?n>LJd6ohe`[PCoSG6^0on>LJh2ohma[@?oQK?c1?mkaOh2ofW?o004oi1TVon>HIWo
SV6IohiQV@?oSEnG1?n<GYH7ohaMUPOoSEjF0on>GiH3ohmPUP;oT66F0_nHMJT3oiUeZ0GoVWFW1?nK
M:H3oiadY@GoWGBS0_nNLj800onPOZgoYHVgojF9]`05ojJ8]0CoYXJc0onVQ[800oncYL[o/ik3ok>N
``02ok>N``Co/YRm00?o/9>iokBXc?ndZ<`00_ndZ<`4ok>Pa@03ok6J_onj_mko^[oN00;o^[oN1?nj
]=@00onhZlco]l3QokO0h@02okO0h@?o]kKH0_nbd?04okK8j0;o]koQ0_n`bnh4ok;5j003oj_>l_n_
b^ko[l[^00?o[l[^0_n`a^X2ojc9k`Co[LO]00?oZ/S`oj_7k_n[anh00on[anh2oj_5k@03oj[6k_l0
003oZ/G]00CoZ/G]00?oZlC/ojW4kOnYa>d00_nYa>d2oj[3k0;oZL;/1OnY`^/4ojW1ja;ooooo0_l0
0009ooooo`Co000000?o410@ooooooooool01oooool002Cooooo00?o0000ooooooooool04?ooool0
0one`nCo_<CPokc4h003okc4h003okg8h_no`mgo_l?M00?o_l?M00Co_l7Lok^jf?nk^]So^k[H0oni
]MD00onbZm7o[Z?<ojjSc003ojjSc0CoZic70_nWUL<00onNSlCoVhVooi^9_`02oi^9_`?oV8Bl1?nF
OkP01?nDNkGo0000o`000?l00002oi9h/P?oTWJ`1?nAM:l7oi1b[@?oSg6]1?n>LJd5ohe`[P03ohn:
b_n=TmCoSI?D00;oSI?D1?n;XN<5ohFcl`;oNlGn00CoTfVNoi1TVon@I9_oT6BK0on>HIT4oheOU`?o
S5jF1on<GIH7oheNUP?oSUnF0_n?H9H00onGM:WoV7FYoiQeZ@02oiQeZ@CoVGFX1?nJMJL4oi]dYPCo
W7BU1?nMM:<00onNLj;oY8ZhojF9]`03ojF9]`CoYXRd1?nVQ[<01?nVQ[;o/jG:ok>Ub_ncYLX4ok>N
``?o/YRm00?o];7EokBXc?ndZ<`00ondZ<`3ok>Pa@03okO;jOnj_mko^[oN00Co^[oN0_nj]=@2okC;
j`Co]l3Q00?o]kKHok;@l?nbd?000onbd?02okK8j0;oZm3c1?n`bnh00onbaNSoZlkboj_>lP02oj_>
lP;o[l[^0onYc?84ojc9k`03ojg7kOnZb?3oZ/S`00;oZ/S`0_n[anh3ojW6k`?oZ/K^00?o0000oj[5
kOnZaNd01_nYa>d00onY`ncoZL;/ojW2k003ojW2k0;oZL;[1onY`N/Cooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02Oooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool04_ooool3okc4h0;o_lCN1?no`md00onm
_m_o^k[Hok^jf003ok^jf004okVeeOnbZm7o/Z_Aok:[d@Go[Z?<0_n[W<L00onRU/WoWXo4oij?a002
oij?a0?oVhVo1?nHQ;`01?nFOkSo0000o`000?l00002oiAk]@?oTWRb1?nBM[03oi5d[`OoT7:]0on?
LJd2ohia[@;oTX:n0onAQL<4ohn:bPCoSI?D1?n;XN<2ohFcl`;oUfnS0onCJIh3oi1TV`?oSV6I1?n=
GiL3ohaNUPOoS5fF1on=GYH2ohiOUP04oiEbZOnGM:WoUgBYoiMdZ@GoV7FY0onIMJP4oiYeY`CoVgBV
1?nLM:D3oiedX`CoY8Zh0onURKL5ojJ8]0;oYXJc00?o/jgBok>Ub_ncYLX00oncYLX4ok>N``04ok:H
_Ond/MGo];7EokBae@Go]:S<00Co/j35okO;jOngbnWo]l_Y1?nj_mh00on]e?Co]<_[okC;j`03okC;
j`;o]l3Q0_nZe_L4ok;@l003ojGDn?n[d??oZm3c00?oZm3c0_n`bnh3ojO@m@;oZlkb0_nVcO@5ojW<
lP;o[<W_0onXbO42oj[8l0;oZ<O`1OnYa^l2oj[6kP03o`000?nXaNkoZLC]00CoZLC]1?nY`n`2ojW2
k0;oZ<;/1onY`N/2ojS1jaCooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09oooo
o`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01_ooool00ol0003oooooooooo`0Cooooo`03okc4h?noa=ko_lCN00;o_lCN00?o_l?M
okfofonm_m/00_nm_m/3ok^jf003okFbe_nbZm7o/Z_A00?o/Z_A0on^Xl`00onUWLkoXYK9oj:Fb@02
oj:Fb@?oWXo40onKRKl2oiR4_0?o00000onFOkP3oiAk]@?oTWRb0onBM[03oi5d[`KoT7:]1?nBP;`5
oi:2_P?oTHG30on?R/X5ohfCe0;oRj7S00GoQ6>Toh=QX_n3HJ;oPf6RoiM_X`03oi=YWP?oT6BK0on>
HIT4oheOU`?oS5jF1on<GIH5oheNUP;oTg2X0onELZT4oiMdZ@CoV7FY0onIMJP4oiYeY`CoVgBV1?nL
M:D00onMM:?oXhZjojB:^004ojB:^0?oYHVg1OnVR;@01?nVQ[?o/jgBok>]d_nc[M84ok>UbP;o/ik3
0_nc^ml4okBae@Co]:S<00?o[mGdokO;jOngbnT00ongbnT00onj_mko[MCdojgDm002ojgDm0;o]<_[
0_nQfO/5oj[Fm`03ok;@l?nUe?SoYMCh00;oYMCh0_n[d?<3oj;An0;oYm3e0_nScOH5ojK=m0;oZLcb
0_nVb_84ojS9l@03ojK7lOnXao3oZ<O`00?oZ<O`0_nYa^l2ojS5k`?oZ<G^00Co0000ojS5k_nYa>go
ZLC]0_nX`nd3ojW3k0KoZ<;/0_nY`N/7ojS1ja?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`09ooooo`002Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h01_ooool00ol0003oooooooooo`0Eooooo`?o_lCN0onna=h4okfof`04ok^jf?ne/]Ko]K;FokFb
ePGo/Z_A00Co[Z?<ojFMc_nUWLkoYIg>0onRU/T3oij?a0?oVhVo0_l00002oiR4_0CoUWnh0onDNkD3
oi9h/P;oTWJ`00CoSX2ooi20__n@P;koT82n1?nAP;d7oi:0_0CoTX:n0onAQL<4ohn:bP;oSI?D0_n7
IjL3ohASY0CoPf6R0on3H:43oi1TV`?oSV6I1?n=GiL3ohaNUPOoS5fF0_n=GYH00onAKZOoTg2Xoi=`
Z002oi=`Z0CoUG:Y0onGM:T4oiQeZ@?oVGFX1OnJMJL3oi]dYP?oW7BU1?nSR[X4ojB:^0CoYHVg0onV
R;@00onb]=[o/jgBok>]dP02ok>]dP?o/jG:00?o/LGYok>kgonc^ml00onc^ml4okBae@03okBXc?n_
eOCo[mGd00;o[mGd0_ngbnT4oj?Jn`;o[MCd0_nHfOd4oj7In`;oZ]Kg1?nNeO/2ojGDn0?oW]3i0_nR
dOP2oj7=m`CoXlgf0_nVcO@3ojC9l`CoY/[b00?oZ<WaojK7lOnVao400_nVao42ojS7l0;oYlG_1OnX
aNl2ojS5kP03ojS3kOl0003oZ<?]00CoZ<?]00?oZL?/ojS2k?nX`^`01?nX`^`2ojS1k0OoZ<7[0_nX
`>/Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool000Wooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0ol0000Fooooo`03oko4g_nn
a=ko_/CN00?o_/CN0_nm_m/2okRkg0Co]K;F0_nbZm42ojVVd`CoYIg>0onRU/T3oij?a0?o000000Co
VhVooiR4_?nHQ;coV8Bl0_nFOkP2ohj4a0?oSH;20on>PL44ohj0_`?oT82n1?nAP;d6oi:0_0CoTX:n
1?nAQL<2ohn:bP03of[LhOn<KJ_oS6f[00?oQfNW0_n4Hj@4oh=QXP?oPf2Q0on4H:43ohIRX@CoSEnG
0on<GYH5ohaMUP;oSf^U0onAKZL4oi=`Z0CoUG:Y0onGM:T4oiQeZ@?oVGFX1OnJMJL3oi]dYP04oiad
YOnRRkcoXX^loj:;_0?oXhZj1OnTR[P3ojF9]`03ojJ8]?nb]=[o/[CJ00;o/[CJ1?nc[M801?ncYL[o
/LGYok75jOnaaNT5ok>kg`;o];7E0onUg?X2ojoEm0?oV=cn0_nSf_/3oi?HoPCoV=Wm0_nQfO/3oiWE
o0;oW]Gk0onLcoT2oik@n@;oWl_g1OnQcOL2oj?=mP;oXlWc1OnTbO<2ojK:lP?oYLOa0_nVao42ojK5
k`CoYlG_0_nXaNl3ojO3kP?oZ<?]00?o0000ojS3kOnX`nd00_nX`^d4ojS2k0KoZ<7/1?nX`N/5ojS0
ja7ooooo0ol00007ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo01Sooooo0onna=h00onj
`n7o^;_LokRkg003okRkg0;o]K;F0_n/[]T4ojVVd`?oYIg>0onRU/T3o`000004oiF@c?nBS<WoTXc9
oi:<b@?oT8O61On>Q<@3ohf2`P?oSX710on>P;l3oi20_PCoTH2m1_nBP;`5oi:2_P;oTHG30_n4hoT4
oha]Z`?oQfNW0on4Hj@3oh=QXP?oPf2Q0on4H:43ohIRX@CoR6BQ0on;IZ83oheYY0CoSf^U1?nAKZL3
oi=`Z0CoUG:Y0onGM:T4oiQeZ@CoVGFX1?nJMJL2oi]dYP03oj2:_?nRRkcoXX^l00;oXX^l0onSR[X5
ojB:^0;oYHVg0_na^n44ok:dfP;o/jgB0on]c_44ok75j@;o/k_O0onJgod2ojGLnPCoT=gn0_nHg?h3
oi7FoP;oTmSn0_nGd_`5oiOCo@;oVMGl0onLcOT2oic?n@;oWl[f1?nOboL2oj7=m`;oX/Oc1OnSbO<2
ojC9l`?oY<Ka0_nUao42ojG4k`GoY/G_0_nWaNl7ojO3kP;oZ<?]00?o0000ojO2kOnX`^d00onX`^d0
0onX`^coZ<7/ojS1k006ojS1k0GoZ<7[1?nX`>/>ooooo`Co000000?oooooo`000?ooool01_ooool0
0ol0003oooooooooo`09ooooo`002Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Iooooo`04okk4g_nj`n7o^/?Qok[3h@?o^;_L00?o
[kSPojb^fOn/[]T00on/[]T4ojVVd`;oYIg>0ol000000onHU]3oUI3<oiF@c002oiF@c0?oTXc90on@
QlH4ohj4a0?oSH;20on>PL43ohj0_`?oT82n1?nAP;d7oi:0_0;oTX:n1?n=g?l00on4hoWoTWF_oi9e
[`03oha]Z`?oQfNW0on4Hj@3oh=QXP?oPf2Q0on4H:43ohIRX@CoR6BQ0on;IZ83oheYY0CoSf^U1?nA
KZL3oi=`Z0CoUG:Y0onGM:T5oiQeZ@?oVGFX0_nJMJL00onNRKgoX8Zloj2:_002oj2:_0CoXX^l1?nS
R[X3ojB:^003ojo0iona^n7o/K_Q00?o/K_Q0_nb]=X2ojOEn0Go[Lka0_naaNT3oi7OoP;oV]om0on<
g?h2oi3MoP?oT]Gn0_nAe_h2oiW@n`GoUm;l0_nGdod3oig;n0;oW<gi0_nPb?@5oio:mP;oWl_g0_nR
a_84oj;7l`;oXlWc1?nTaO42ojC6l@;oYL?_1?nUa>l2ojK5k`;oY/?^1onW`nh5ojO2k@04o`000?nW
`^goZ<;]ojS2k@_oZ<7/0_nX`N/7ojS0j`[ooooo0ol00005ooooo`03o`000?oooooooooo00?ooooo
00?oEEEEofIVI_l000002oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001Oooool2o`0001_ooooo1?nj`n401?nh^mco[kSPojnhh?n_^>05ojb^
f@;oZJKC0ol000000onKWMCoV9K@oiRFd002oiRFd0?oUI3<0onBS<T3oi27aPCoSXC40on=P/83ohj1
`@CoSX2o0on@P;h4oi60_@GoTX2l1?n=dOh2ohgLo`04oiUn]?nBMJooTWF_oi9e[`?oS6f[0on7IjL3
ohASY0?oPf6R0on3H:44ohAPX@;oQV:Q1?n8I:43oh]VXPCoSFVT0on?JjD4oi5^Y`CoTg2X0onELZT4
oiMdZ@CoV7FY0_nIMJP00onMR;coWXVmoij9_@02oij9_@CoX8Zl1?nRRk`3oj>:^P03ojB:^?n_`>Oo
[l3W00;o[l3W0ona^n42oj;Jn`CoYmGh0_n]c_43ohcOo@;oTMon1?n;g?h2ohcLoP?oUM?m0_nBeOh3
oi_>nP?oVM3k0_nGd_`4oik9mP;oWL_h0_nQa_<4oj38m0;oWl[f0_nSaO45oj;6lP;oX/Oc0onTa?02
ojC5l@OoYL?_0_nUa>l2ojK2kPCoY/?^0_nW`nh9ojO2k@03ojO1k?l0003oZ<7/00_oZ<7/2?nX`>/2
ojO0j`Kooooo1?l00008ooooo`03o`000?oooooooooo017ooooo0009ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool06ooo
ool2ok[3h@;o/L;W1?n_^>02ojb^f@04oj6]gol0003o0000o`0000;oWZCJ0onKWM@3oiRFd0?oUI3<
0onBS<T3oi27aPGoSXC40on=P/83ohj1`@?oSX2o0on@P;h2oi60_@?oQ[_h1?n9a_`2ohgAoP;oXHVj
0onIO[@3oi9e[`CoS6f[0_n7IjL3ohASY0?oPf6R0on3H:44ohAPX@?oQV:Q0on8I:44oh]VXP?oSFVT
0on?JjD4oi5^Y`CoTg2X1?nELZT3oiMdZ@?oV7FY1OnMR;`3oij9_@CoX8Zl1?nRRk`2oj>:^P;o[<G/
1On_`>L00ona^n7oX][koj;Jn`02oj;Jn`;oYmGh0on9god2ohcOo@?oSMco0_n;g?h3oiSBo0;oUM?m
1?nMc?P2oi_>nP;oX/Kc1?nPb?@2oik9mP;oX/Ga1OnQa_<2oj38m0;oXlC`1?nSaO42oj;6lP?oY<?_
0onTa?02ojG2kPKoYL?_0_nV`^d5ojK2kP;oY/?^2?nW`^d5ojO1k004o`000?nW`NcoZ<7/ojS1k0;o
Yl7/1_nX`N`6ojS0j`KoYl3[0_ooool3o`0000cooooo00?o0000ooooooooool04Oooool002;ooooo
00?o0000ooooooooool07Oooool4ok72i`;o[kSP00CoXkKVo`000?l0003o00000_nQ[Ml3oijTfP?o
VigD1?nHU]03oiF@c0?oTXc90on@QlH2ohj4a0;oQY[O0on5WN<3ohBRi`CoPjS]1?n4/O84ohJkn0;o
RLKl0_nXU<43oj69^P?oVGjd0onBMJl4oha]Z`?oQfNW0_n4Hj@4oh=QXP;oPf2Q1?n4H:43ohIRX@?o
R6BQ1?n;IZ83oheYY0CoSf^U0onAKZL4oi=`Z0CoUG:Y0onGM:T01?nHMJWoVXFloiZ5_?nJQK`4oif8
_0?oWXVm1?nPR[`2oj:;_0?oZ/O_1?n/aN`2ojo0i`?oWMgm0_nRf_/2ohWOo@?oTm_n0_n?fol2oig?
n@GoVm7j0_nHd_`3oio;mP;oWLch0_nSaO45oj;6l`;oX<Sd0_nTa?04oj;5l@;oXLKc0_nT`nl5oj?4
l0;oXlGa0_nU`nl5ojC3k`03ojC4l?nU`^koYL;^00;oYL;^0_nU`nl2ojK1k@CoY/;]0_nV`^h2ojK1
k@OoYl;]2OnW`N`00ol0003oYl7/ojO1k003ojO1k0;oZ<7/0_nW`>/4ojS0j`[oYl3[00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0Nooooo`;o
/L;W0_nT_nd2o`0000;oXkKV1?nQ[Ml3oijTfP?oVigD0_nHU]001?n>WmooS9cNohbLg_n<W=h3ohZJ
g@?oR9WN1On6V]l3ohFMh`?oQ:;W1?n3Z>d4ohBalP;oQ[_h00?o[io8oiYo]OnDMjl00_nDMjl3ohm_
Z`?oRVVW0on5I:D3oh5QY004oha]Zon7IjOoQfNWohMWY`?oQ6>T0on3HJ83oh=PX@?oQ62Q0on6HZ44
ohQTX@?oRfJR0on=JJ@4ohm[Y@CoTFjW0onCL:P4oiEbZ@;oUgBY0_nHPkX3oiZ5_0CoWHRl1?nNRKd2
oj2:_0;oZ<Sa1OnZanl2ojc5k0?oV]om0_nMgOd2oh_Po@?oU]_n0_nCfoh2oj3>n0CoWLoi0_nKdOX4
oj79m0;oWl_f0_nTa?04oj?5l@;oX/Kc0_nT`nl5ojC4l0;oX/Ga0_nU`^h4ojC3k`;oXlC`0onU`^h4
ojG3k`;oY<?_0onU`^d2ojG2kPOoY/7]0_nV`^d2ojK1k0CoY/7]0_nW`^d>ojO1k004o`000?nW`Nco
Yl7/ojO1k0;oYl3/1?nW`>/00onX`>_oYl3[ojO0j`0;ojO0ja3ooooo00?o0000ooooooooool04?oo
ool002;ooooo0_l0000Pooooo`?o000000?oY;o]oj>fi_nS]^H00_nS]^H2oj6]g`04oiB^jOnBZNGo
TZWUoi:Yi@?oT:CR1?n>Wml3ohbLgP?oRY[M0on8VMh5ohJJg`?oQIgS0on4X^L2oh>Xk@;o^KGF0ond
Zll01?nORKcoVWneoiYo]OnJOkD3oiAg[`?oSfn[0on:JJL3ohETY@CoPF6T0omlGjH3ohASY0?oPf6R
0on3H:43ohAPX@?oQV:Q1?n8I:43oh]VXP?oSFVT1?n?JjD4oi5^Y`?oTg2X0_nELZT2oiIo^@CoV8>j
0onJQK`5oif8_0;oWXVm0_nVb?44ojS8l@;oZ/O_0onHh?d2oi[Oo@;oS^3m0onIfoh2oiKKoP?oXLkg
1?nPc_P2oig?n@?oXlSc0_nQbO@2ojG4k`GoY<C`0_nSaO42ojG2kPCoY<?_0_nTa?02ojK2k@GoYL;^
0_nT`nl2ojK1k@GoYL;^0_nU`nl3ojK1k@;oYL;]0_nV`N`6ojK1k@;oYl7/1OnV`N`2ojK1kA7oYl7/
00?oYl3/o`000?nW`>`01?nW`>`AojO0ja3ooooo00?o0000ooooooooool04?ooool002;ooooo00?o
0000ooooooooool07?ooool3o`000003oooooonT_ngoY;o]00;oY;o]0_nS]^H2oiFdk@?oU:kY0onB
ZND3oi2ThPCoSYoO0on<W=h3ohZJg@?oR9WN0_n6V]l4odo4l`;o:kCA0_nl_]/5okVeeP03okB[conO
RKcoWhVl00CoVWne0onDMjl3ohm_Z`?oRVVW0on5I:D3oh5QY0?oO5nV0omiHJ/3oh=QXP?oPf2Q0on4
H:43ohIRX@CoR6BQ0on;IZ84oheYY0?oSf^U1?nAKZL2oi=`Z0;oTgfg1?nFOkT3oiR3^PCoVXFl0_nM
R;`2ojG6l0GoY/Sa0_nXb?43oiSQo@;oV>3m0_n@hOd3oi_Ko@;oVM_n0_nScOH5oj7>m`;oX<kh0onT
ao82oj?8l`;oY/?_1?nUa>l2ojC4l0;oY/;]1OnU`^h2ojC3k`;oY/7]1?nV`^d2ojG2kPOoY/7]0_nU
`^h2ojK1k0CoY/7]00?oYl3/ojK1k?nV`N`00onV`N`2ojK1k@;oYl3/1?nW`N`2ojK1k0;oYl3/1onW
`N`2ojO0k0KoYl7/1OnW`>`01?l0003oYl3/ojO0k?nW`>`DojO0j`oooooo00?o0000ooooooooool0
4?ooool002;ooooo00?o0000ooooooooool06Oooool3o`0000Kooooo0onE^o44oiFdk@?oU:kY0onB
ZND3oi2ThP;oSYoO0_ml]oT3ogNkn`GoL;on0_mTa?d00ol0003o_^SbokkXlP02okg5h0Co_;kK0_ni
]MH2ojFC`P?oWhVl1?nJOkD3oiAg[`?oSfn[0on:JJL3ohETY@?oPF6T0omlGjH3ogUQZ`;oM6Nf00Co
Pf6Roh=PXOn3H:7oPf2Q1?n4H:43ohIRX@?oR6BQ1?n;IZ83oheYY0?oSf^U0_nAKZL3oi5j]P?oTgfg
1?nFOkT4oiR3^P;oVXFl0_nT`^l4ojG6l0;oY/Sa1_nHhOd00onCh_goWM_moigKo@02oigKo@;oVm_m
0_nTcOD4oj?=mP;oXLkg0_nUao44ojC7lP03ojK3k_nV`nooY/?_00?oY/?_0_nUa>l6ojK2k@;oYL;^
0onV`N`4ojK1k@;oY/;]0_nV`N`7ojK1k@;oYl7/1?nV`N`00onV`NgoYl3/ojO0k002ojO0k0;oY/7/
1onW`>`2ojO1k0KoYl3/0_nW`N`7ojO0k0;oYl7/2?nW`>`00onW`>_o0000ojO0j`0EojO0j`oooooo
00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool05_ooool3o`0000[ooooo0onE
^o42oiFdk@;oR;Kd0on6]O@3ohBem@CoP;Kg0oml]oT3ogNkn`;oL;on0oln`MH00on7jn;o_^SbokkX
lP04okg5h0;o_;kK00?oZig8ojFC`_nUTl800_nUTl84oin9_0?oVWne0onDMjl3ohm_Z`?oRVVW0on5
I:D3oh5QY0?oO5nV0omiHJ/3ogAW]P?oPf2Q1?n4H:43ohIRX@?oR6BQ1?n;IZ83oheYY0;oSf^U0on?
N;@3oi5j]PCoTgfg0onFOkT2oiR3^P?oX[c/1?nT`^l2ojG6l0?oV^7m0_nHhOd2oiKSo@?oWmcl0_nM
fod2ojG=m@GoY<ge0_nScOH2ojG6l@CoYLOa00?oY<ObojK3k_nV`nh00_nV`nh2ojK3k`?oYl7]1_nV
`^d2ojO1k0GoY/7/0_nV`Nd2ojO0k0CoY/7/0_nV`Nd2ojO0k0GoYl7/0_nV`N`NojO0k0;oYl3[1onW
`>`5ojO0j`03o`000?nW`>_oYl3[01CoYl3[3_ooool00ol0003oooooooooo`0@ooooo`008_ooool2
o`0001Cooooo0ol0000>ooooo`?oR[Od1?n8]_@3ohJem0?oQ;Ge0_n0]_L4og?8o`;oIlcl0_mFdN02
oi7/lP?o^^Gd0_nmb><3okg5h003ojnVc_n[WLSoZig800;oZig81?nUTl83oin9_0?oVWne0onDMjl3
ohm_Z`?oRVVW0on5I:D3oh5QY0?oO5nV1?miHJ/2ogAW]P?oJgS>1?n4H:43ohIRX@?oR6BQ1?n;IZ82
oheYY0;oSWJd1?n?N;@4oi5j]P?oTgfg0_nFOkT2oindi`GoX[c/0_nT`^l3oicPo@;oV^7m0onHi?d0
1?nFhogoWmcloioLo?nOg?`2ojK=m0CoYLge0_nTcOD3ojK6l0CoYLKa0_nUao45ojK3kP;oYl7/1OnW
`Nd2ojK2k@KoYl7/0_nV`N`7ojO0k0;oY/7/1_nW`>`2ojO1k0koYl3/0_nW`>/6ojO0k0;oYl3[1onW
`>`6ojO0j`;oYl3/2_nW`>/00ol0003oYl3[ojO0j`0DojO0j`gooooo00?o0000ooooooooool04?oo
ool0027ooooo0_l0000Booooo`?o00004_ooool3ohZgm0;oR;Kd0_n6^_L4oh6on`?oNl?n0_mcb?l3
ofkHm`;oVNOk1?nggo@00onjiOCo_LSSokg8h`02okg8h`04okg5h?n_Y/ko[jK>ojnVcP?oZig81?nU
Tl83oin9_0CoVWne0onDMjl2ohm_Z`?oRVVW0on5I:D4oh5QY0?oO5nV0omiHJ/3ogAW]PCoJgS>00Co
?i_doiZ;`_nJRl;oVX_20onCOk/4ohmi]`?oSWNd0on>M[@3ohmh]0CoTGZf0_nCOKL2oib[h@CoWkCW
0_nR_>`4oikNo@;oW>3m0onJiO`2oiSTo@?oX=cl00?oWmclojK=m?nVcO@00_nVcO@2ojG=m@OoY/K`
0_nUa_43ojO2k@;oY/?^1_nW`N`2ojO1k@;oYl3/1onW`N`8ojO0k0;oYl3[1onW`>`2ojO0j`KoYl3/
0onW`>/2ojO0k0OoYl3[0_nW`>`6ojO0j`;oYl3/5_nW`>/00ol0003oYl3[ojO0j`0EojO0j`cooooo
00?o0000ooooooooool04?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool03oooool2o`0001Kooooo
0on9]o@4ohJjm`;oPKok1?n8c?h2ogkDo`?oWMkm00?oVNOkokOOm?nggo@00_nggo@2ok_:iP?o_LSS
00?o/jkCojnVc_n_Y/h00_n_Y/h3oj^Mb0CoYI?20onORK`4oiYo]@?oU7N_0on?Kj/3ohYYY`?oQFBU
0on1HJ@3ogaOYP?oNF6[0omdIkH3of]hcP;oS7Vj0on8MkX3ohMh_0CoSgVg0on>Mk@3ohif]0;oSgRd
00?oU9OCoiRQfonHXM/00onHXM/4oib[h@;oWkCW0onQf_/2oikNo@?oVnGl0_nJiO`4oj;Mo0;oX=cl
0onVc_@2ojK=m0;oYlK`1_nVa_05ojO2k@WoYl7/1_nW`>`2ojO1k0;oYl3[1onW`>`6ojO0j`;oYl3/
1onW`>/2ojO0k33oYl3[00?o0000ojO0jonW`>/05?nW`>/=ooooo`03o`000?oooooooooo00oooooo
0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0<ooooo`?o00006Oooool3ohVgm0;oQ[[g1?n>`_T2ohS<oP?oWm?j
0_nMg_d3ok?Hl`03okOOm?nkb^Ko^l[V00?o^l[V00Co_LSSok>^donc[]?o/jkC1?n_Y/h3oj^Mb0;o
YI?200CoUXO2ohmo_On?OkgoSgnm1?n8N;X3oh9b^0?oOFnh0on:JJL3ohETY@?oPF6T0omlGjH4ogUQ
Z`?oM6Nf00?oJgS>oi:0_?n<NKX00_n<NKX3ohQg^P;oQgRl1?n8OL03ohb4a@?oShc<1?nDUm<5oiRQ
f`;oW:_Q0onRdoT2oj7Jn`?oWNKl0_nKiO`3oj?Oo0;oX]gl0onWc_@2ojK>m0?oYlO`1?nWa_02ojK6
l0GoYl;]2?nW`N`9ojO0k0KoYl3[0_nW`>a6ojO0j`03o`000?nW`>_oYl3[01CoYl3[3?ooool00ol0
003oooooooooo`0?ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00005oooo
o`;o00002_ooool3o`0001gooooo1OnB^_82ohk2n@;oX<Sd0onOdoX3ok3@l@;o/mSc1?nib^L2ok_:
iP03okFdf?nc[]?o/jkC00?o/jkC0_n_Y/h01?nSVL_oW936oib@a_nLT<H4oiJ7`P?oSgnm0on8N;X3
oh9b^0?oOFnh0omlL;X3ohETY@?oPF6T0omlGjH4ogUQZ`;oM6Nf0onBP;`3ohai^P?oR7Nj0on7N;`4
ohQm`0?oS8C50on?S<`4oiBGd`;oV:7K0onRboD3oj;Cn@?oW^Kl0_nMi_`3oj?Qo0;oXmol0onXd?D2
ojO>m0;oZ<O`1OnWao02ojO6l0OoYl;]1_nW`N`2ojO0j`OoYl3/DOnW`>/00ol0003oYl3[ojO0j`0E
ojO0j`_ooooo00?o0000ooooooooool03oooool000Oooooo00Go0000ooooooooooooooooo`00000;
ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000ooooooooool01_ooool3o`00027ooooo0_nB
^_83oj6nkPCoX<Sd00CoWm?jok3@lOn`d?7o/=3a0_ngb>L4okW:i`03okJig?ne]=So]KCH00;o]KCH
0onc[]<00onXXLooXiW;oj>Ib`02oj>Ib`?oW9360onFQl83ohmo_@?oR7Rj0on2L[P4oge_^0;oO72j
0omlML03oh23c@?oO5nV0_miHJ/2oh[?oP;oVh_10onBP;`3ohai^P?oR7Nj0on7N;`4ohQm`0?oS8C5
1?n?S<`2oiBGd`;oX<3_1OnRboD00onRdoWoW^KloikVo004ojCRo0;oXn7l0onXdOD2ojS@m@;oZ<S`
1?nXao02ojO7l0WoYl;]1OnW`N`6ojO0j`;oYl3/E_nW`>/00ol0003oYl3[ojO0j`0EojO0j`[ooooo
00?o0000ooooooooool03oooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgM
gOmEEEGoooooo`0000Kooooo00?o0000ooooooooool00oooool3o`0002Kooooo1?nQ_^h2oj38m0?o
[/S]00?o/=3aokO8iongb>L00_ngb>L00onib^Oo][WLokJig002okJig0Co]KCH00Co/jkCojRQconX
XLooZ:7?0onSVL/3oib@aP?oUXO20on?Okd4ohQh^P?oPW:h0ommKkP3oga`^P?oO7G00_n0Pld5ohVO
hP03oh[?o_nKRl7oVh_100;oVh_10onBP;`3ohai^P?oR7Nj0_n7N;`4ohQm`0CoS8C50_n?S<`2oifc
i`CoX<3_0_nRboD2oioVo0?oYNCk0_nTh_`4ojWCmP;oZ=7e0_nXbO44ojS8l0;oZ<O`0_nW`nd6ojO2
k@GoYl7/HonW`>/00ol0003oYl3[ojO0j`0DojO0j`[ooooo00?o0000ooooooooool03oooool000Oo
oooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Gooooo00Co0000oooo
oooooooooooo0ol0000Zooooo`;oXKk^0on/`NT2ojk8k@;o]LGV0ongb>L3okJmg`Co][WL0_ne]=P0
0on/ZMCoZ:7?ojRQc`02ojRQc`?oXiW;1?nLT<H3oiJ7`P?oSgnm0on8N;X3oh9b^0?oOFnh0omlL;X3
ogae`0?oP8?=0on9Wn82ojRKb@CoVh_10onBP;`3ohai^P?oR7Nj0on7N;`4ohQm`0;oS8C50_nIYMh4
oifci`;oX<3_0onQi?`01?nOi_coYNCkojGTnonUi?/2oj[EmPCoZM?f00?oZL[aojS9lOnXbO400onX
bO42ojS8l0;oZ<?]1?nW`nd2ojO2k@GoYl7/IonW`>/00ol0003oYl3[ojO0j`0DojO0j`Wooooo00?o
0000ooooooooool03oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000000Gooooo1?l0000^ooooo`?o[<7Y0_nc`^D4okG5iP03okO8ionf_Moo][gO00?o][gO0_nf
^M`00on_/=Wo[:WDojbYe002ojbYe0CoZ:7?0onSVL/2oib@aP04oi6=bon:Ql[oRXO:ohZ7bP?oPhG<
0on8N;X3oh9b^0CoOFnh0_mlL;X3ogae`0CoP8?=00CoRIoRoiB9a_nDRLKoU8W61?n>P/<3oh^0`P?o
RX740on<Q/P3ohn>cPCoTiWF1OnIYMh2oifci`?oXN7l0_nQi?`2ojGUn`;oZmSg1?nZeOH00onYdoKo
ZL[aojW:l@02ojW:l@;oZ<Wa1onX`nd2ojO3k@OoYl7/J?nW`>/00ol0003oYl3[ojO0j`0DojO0j`Wo
oooo00?o0000ooooooooool03oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03
ogMgMol0003ooooo00Cooooo0_l0000aooooo`03ojc1jOnc`^Go/l;U00;o/l;U0_neaNH2okK0hPCo
][gO00?o/KOMojn`fOn_/=T00_n_/=T4ojbYe0;oZ:7?00CoWI_AoiRDc_nHU<koV9C>1?nASL/3ohZ7
bP;oPhG<0omiQ]<3off@h`CoOFnh0omlL;X3ogae`0;oP8?=0onLU</3oiB9aP?oSX;31?n;P<83ohZ1
a0?oS8K80on?S/h4oi>IeP;oVJGN1?nQfo`2oj7Qo0CoYNGk1?n[f?L2oj[EmP?oZLcb0_nYb_42ojS4
kPKoZ<?]2OnW`Na[ojO0j`03o`000?nW`>_oYl3[01CoYl3[2?ooool00ol0003oooooooooo`0?oooo
o`008_ooool00ol0003oooooooooo`0_ooooo`?o/l;U0_nf`n@4okK0hP03okJmgona]mgo/KOM00;o
/KOM1?n_/=T2ojbYe003oj:Se_nMVm7oWI_A00;oWI_A0onHU<h3oi6=b`?oRXO:0on3QL`3ogV6d`Co
KI3S0_m6XoL01?o7k>kobMgXolWMj?n`/]X4ojJRdP?oW9C;0onDRLH4ohj2``?oRh320on:PL@3ohb6
b0CoShk>0_nCVMH3oik@n@;oXM_l1?nUi?/2ojGUn`?o[=[h0_n[f?L3oj[>l`;oZLcb0_nYaNh4ojS4
kP;oZ<?]0_nX`N`7ojO1k6ooYl3[00?o0000ojO0jonW`>/04onW`>/9ooooo`03o`000?oooooooooo
00kooooo000Sooooo`03o`000?oooooooooo02oooooo00?o/l;UokK3i?nf`n@00_nf`n@2okK0hP?o
/kgQ1?na]md2ojn`f@03ojJ[f_nRXmKoXZ?F00;oXZ?F0onMVm43oiRDcP?oTHg;0on:QlX4oh>5c0?o
NHKC0_m]T><2oe3>eP03olO/k_nh`N7o/;;J00?o/;;J0onVX]83oibDb`?oU8W61?n>P/<3oh^0`P?o
RX741?n<Q/P2ohn>cP;oVl?d0onNd?T3ojGPn`;oYNCk0on/g?P2ojcJn0CoZm3d0_nZc_<2ojW6kPCo
ZLG^0_nXa>h2ojS2k0CoZ<7/0_nW`NacojO0j`03o`000?nW`>_oYl3[01CoYl3[2?ooool00ol0003o
ooooooooo`0>ooooo`009?ooool00ol0003oooooooooo`0_ooooo`?o]/?T0_nc`^D5ok>mh@;o/KOM
00?oZ[;OojJ[f_nVZmX00_nVZmX3oj:SePCoWI_A0onHU<h3oi6=b`?oRXO:0_n3QL`3ogfin@;oL/kn
00?oR>_<olO/k_o7k>h00onh`N44ok2bfP?oYZ;B0onLU</3oiB9aP?oSX;31?n;P<83ohZ1a0;oS8K8
0_nD/^`4oi_3m004oik@nOnUh?_oYN3kojGPn`?o[=ki0_n/g?P3ojcCm0;oZm3d0_nZanl5ojW6kP;o
ZLG^1_nX`^`2ojS1k0;oYl7/MOnW`>/00ol0003oYl3[ojO0j`0DojO0j`Oooooo00?o0000oooooooo
ool03_ooool002Gooooo0_l0000`ooooo`03okK3i?nc`^Go/l;U00;o/l;U0_nc_N42ojbjh`CoZ[;O
1?nVZmX3oj:SeP;oWI_A00?oTjGRohfShon=Xn<00_n=Xn<3ohRTi`CoPZ[^0_mm^OT01?n;kN7o_o;a
okoblOnol_42okc>i`Co^<7Q0_n`/]X01?nMV<koUY3<oiJ@c?nFT<`3ohj;b`?oRh[=0on9S]84oh^F
f@CoSj?R1?nD/^`2oi_3m0;oY=[j0on[goT2ojcNn@?o[MKf0_n/do@2oj_9l0CoZ/O_0_nYa^h2ojS3
k@OoZ<;/1_nW`NaeojO0j`03o`000?nW`>_oYl3[01CoYl3[1_ooool00ol0003oooooooooo`0>oooo
o`009oooool00ol0003oooooooooo`0^ooooo`?o/l;U0on]`NP3ojbjh`CoZ[;O0_nVZmX00onM[nCo
V:WRoiRYhP02oiRYhP?oTjGR1?n=Xn<3ohRTi`;oPZ[^00?oAlOGok;am_nblOH00_nblOH00onol_7o
_<kWokc>i`02okc>i`;o^<7Q00?oYJ;BoifHc_nMV<h00_nMV<h3oiJ@c0?oSX_;0on;R/d3ohV>dPCo
RiKI1?n?Xn82oiBbk0?oX]3h00CoY=[joj_OnOn[goWoZmoi0_n]f?H3ojgFmP;oZl_`1?n[bO02oj[7
k`;oZL?]1?nX`nd2ojS2k0?oZ<7/1_nW`NagojO0j`03o`000?nW`>_oYl3[01?oYl3[1_ooool00ol0
003oooooooooo`0>ooooo`00:?ooool00ol0003oooooooooo`0^ooooo`03ok?2iOn]`NSo[L7X00?o
[L7X0on/^^<2ojZbg`;oXKCV0onM[n@4oiRYhP?oTjGR0_n=Xn<3ogg8o`;oJm7k00CoSN[cok;am_nb
lOKo/_7f1?nkeNd2okc>i`03ojb/eonUX];oYJ;B00;oYJ;B0onMV<h3oiJ@c0?oSX_;1?n;R/d3ohV>
dP;oRiKI0_nI]^`5oik4l`;oX]3h0onZg_T00on[goWo[MSfojgHmP02ojgHmP03ojgFm_n[bo3oZl_`
00;oZl_`0_n[bO02ojW5k@CoZL?]0_nX`nd7ojS1k0;oYl7/N_nW`>/00ol0003oYl3[ojO0j`0DojO0
j`Gooooo00?o0000ooooooooool03_ooool002Wooooo00?o0000ooooooooool0;oooool2ojg1j0;o
Y;o/1?nS^^T4oj6diP?oWJoT0_nHZN82oi2km0CoRL3i0_mmb?l2oi3Ro@;oZ^_i0_nif?04ok_Ek@03
ok6fg?n/[=Oo[:cG00;o[:cG0onUX]84oifHcP?oUY3<0on>Rl/2oh^:c@03oi6NgOnDZ>CoU:ST00;o
U:ST1?nI]^`2oik4l`CoYm[i0_nZg_T3ojgJm`;o[MSf0on/c_42oj_;l0;oZ/K^1?nYaNd2ojW3k@So
Z<7/OonW`>/00ol0003oYl3[ojO0j`0DojO0j`Cooooo00?o0000ooooooooool03_ooool002[ooooo
0_l0000aooooo`?oY;o/1?nS^^T2oj6diP;oVK[_1?nF^_43oi2km0;oRL3i0onBeoh00on@h_goZ^_i
oj[[n@04okWHl003ok_EkOna]]co/KKL00;o/KKL1?n/[=L3ojFRdP;oWIS>00CoUISDoi:GeOnBUmGo
TYOE0on@V=P4oi6Ng@CoU:ST0_nI]^`3oj?Cn@;oYm[i0on/f_P2ojgJm`Co[M3b0_n/c_42oj[7k`Co
Z/K^0_nYaNd2ojS2k0KoZ<7/PonW`>/00ol0003oYl3[ojO0j`0DojO0j`?ooooo00?o0000oooooooo
ool03_ooool002cooooo00?o0000ooooooooool0;oooool3ojBok0;oXk[Y0_nK_>l4oiVjk`;oU[[a
0_nGaoP4oiC=o0;oT]On0_nSho`3okCGlP;o^MS`0_nd_N45ok6fg0;o[:cG00CoXJCHoi^NeOnKW]Go
VikE1?nEV=@3oi:Ge@?oT9SH1?nAW]d2oiBXi0?oWl[f0_nSdoT3oj[Hn0;o[=[h0on]d_<2ojg@lP;o
ZlW`1OnZanl2oj[6kP;oZ<?/1?nX`^`2ojS1k0?oZ<7[Q?nW`>/00ol0003oYl3[ojO0j`0DojO0j`?o
oooo00?o0000ooooooooool03Oooool002gooooo00?o0000ooooooooool0;oooool4oifmk`?oVkc_
0_nI^^l2oiS2m0CoUlOh0_nDcO`2oj3Jo0;o[m?c0ondeo82okC3i@Co];gQ0_na]]`2ojJ[fPCoXJCH
0onKW]D3oiFHe0CoTYOE0on@V=P2oi6Ng@?oVKob0_nOb_H3ojODm`;oZ]Sh0_n]e?@3ojgBl`;o[<c`
1?n[bO02oj[7k`;oZL?]1OnX`n`2ojS2k0?oZ<7/0_nX`N^5ojO0j`03o`000?nW`>_oYl3[01CoYl3[
0oooool00ol0003oooooooooo`0=ooooo`00;_ooool00ol0003oooooooooo`0_ooooo`;oWKg_0_nL
_Nl4oiZolP?oV<;d0_nGaoP3oikAn@03oj3Jo?n_do?o[m?c00;o[m?c00?o]=ObokC3iOnd`nD00_nd
`nD2okBmh@03oj^bg_nVZm[oYZ_J00?oYZ_J1?nQY=P3oi^Ne@?oUISD0_nBUmD2oiB[iPCoU[C/0_nI
_o82oj?>mP?oYmCg0_n/e?D4ojgDm003ojgBlon/c?3o[<c`00;o[<c`0_n[bO02ojW5k@CoZL?]0_nX
`n`5ojS1k8[oYl3[00?o0000ojO0jonW`>/05?nW`>/2ooooo`03o`000?oooooooooo00gooooo000_
ooooo`03o`000?oooooooooo02oooooo1?nL_Nl2oiZolP;oW/?b1?nNbOH2oikAn@?oZlkb0_n_do<3
ok?5j0;o]<?U00?o[KSQoj^bg_n[/]h00_n[/]h4ojJ[fP;oXJCH0_nJYMd3oiNTgPCoU:KR1?nDZnH2
oiJdk0;oX<Kc1?nSc_H00onWe?Oo[=CeojcDm@02ojcDm@;o[MCd0on/c_42ojc<l0;oZ/K^1?nYaNd2
ojW3k@?oZ<;/0_nX`N`2ojS0jhcoYl3[00?o0000ojO0jonW`>/04onW`>/2ooooo`03o`000?oooooo
oooo00gooooo000`ooooo`;o0000<?ooool2oibmk`;oWkk^1?nN`o82oik9mP?oZ<Wa0_n[c_82ok36
jP?o/lGX00?o[kcSojfhhOn]^>400_n]^>44oj^bgP;oYZ_J00?oWjWMoiZUgOnJYMd00onJYMd3oiNT
gPCoU:KR0_nDZnH2oibml0CoX<Kc0_nSc_H3ojWCmP;o[=Ce0on/co82ojc>l@;oZlO^1?nZa^h2ojW5
k@GoZ<;/0_nX`N/4ojS0jh_oYl3[00?o0000ojO0jonW`>/05?nW`>/00ooooooo0000ooooo`0>oooo
o`00<_ooool00ol0003oooooooooo`0^ooooo`CoWkk^0_nN`o83ojO4kP;oZ<Wa0_n^aN/4ok36jP04
ok?5j?n__>?o[kcSojnlh`Co[KSQ0_n[/]h2ojB]gP?oWjWM1?nJYMd3oiNTgP;oU:KR0onJ]^`4oibm
l0;oX<Kc0onWd?D2ojWCmP?oZm3c0_n/co82oj_9k`CoZlO^0_nZa^h3ojW3k@;oZ<;/0_nX`N`4ojS1
j`;oZ<3[SOnW`>/00ol0003oYl3[ojO0j`0CojO0j`03ooooool0003ooooo00kooooo000cooooo`03
o`000?oooooooooo02kooooo0_nO_^h3ojJok0;oYlC^0_n/`nX4ojk5j`;o/<KZ0_n__^D4ojnlh`;o
[KSQ0_nW/Ml4ojB]gP?oWjWM0_nJYMd2oiZ_i@?oV[7X1OnJ]^`2oibml0?oXl_d0_nWd?D3oj[?l`;o
Zm3c0_n[b_04oj_9k`;oZlO^0onYa>d2ojW3k@KoZ<7/0_nX`N^AojO0j`03o`000?nW`>_oYl3[01?o
Yl3[00?o0000ooooooooool03Oooool003Cooooo00?o0000ooooooooool0;_ooool3ojJok0;oZl7Y
1?n/`nX2ojk5j`;o[/3W1?n__^D2ojnlh`;oZ[KQ1?nW/Ml2ojB]gP03oj2`honM[nCoWJoT00;oWJoT
1?nJ[nD3oiZaj0;oV[K/0onPa_<2oj?;m0CoZ<gc0_nZco<2oj_;l@CoZl[`0_n[bNl3oj[5kP;oZLC]
0_nX`^`6ojS1k0;oZ<3[TonW`>/00ol0003oYl3[ojO0j`0AojO0j`03ooooool0003ooooo00kooooo
000eooooo`;o0000;oooool00onV_ncoZl7Yoj_1j@02oj_1j@;o[<?Z0_n^`NP4ojk0i`;o[kkU0_n[
^N<4ojZfh@;oYk7O0_nS/n@3oj2`h`CoWJoT0_nJ[nD2oiflkPCoW/3a0_nPa_<2ojG:l`CoZ<gc00?o
Z/_aoj_;lOn[bo400on[bo42oj_:l0?oZ/K^0_nZaNh00onY`ncoZ<;/ojS2k003ojS2k0;oZ<7/0_nX
`N/4ojS0ji;oYl3[00?o0000ojO0jonW`>/03OnW`>/6ooooo`03o`000?oooooooooo00cooooo000g
ooooo`03o`000?oooooooooo02kooooo0_n[`NT2ojg1j@Co[/7X0_n^`>L2ojbli@CoZkWS0_nZ]^42
ojJfi0CoXk?T0onP/><2oif_i0;oWKW/1?nM_>h2oik0l@;oXlOb1?nUb_<00onXcO?oZ/_aoj[;l@02
oj[;l@;oZl_a0onZanl2oj[6kP;oZL?]1?nY`n`2ojS2k0;oZ<7/1OnX`N/2ojS0jiCoYl3[00?o0000
ojO0jonW`>/02OnW`>/9ooooo`03o`000?oooooooooo00cooooo000hooooo`03o`000?oooooooooo
02kooooo1?n]`NT2ojk1j0;o[KoW1?n/_>D2oj^ih`;oZ;WU1?nV]^@2oj>ci0;oXKSY0onO^>X4oifi
k0;oWKc^0_nQ`o44oj?7lP;oYL[c0onXbo82oj[;l@?oZ/S_0_nZanl2ojW4k@CoZL?]0_nY`n`6ojS1
k0;oZ<7[VOnW`>/00ol0003oYl3[ojO0j`05ojO0j`cooooo00?o0000ooooooooool03?ooool003Wo
oooo00?o0000ooooooooool0;_ooool2ojg1j@;o[<7Y1?n]_nL2ojbli@;oZKcW1?nX^ND2ojJfi0;o
XkWX1?nQ^>T3oinhjP;oWKW/0onP`>l3oj73l@;oXlOb0onVbO82ojS;lP?oZLS`0_nZb>l2ojW5kPCo
ZLC]0_nY`nd2ojS2k0KoZ<7/0_nX`>^KojO0j`03o`000?nW`>_oYl3[013ooooo00?o0000oooooooo
ool03?ooool003[ooooo0_l0000_ooooo`Co[<7Y0_n]_nL2ojZnj0CoZKcW0_nX^ND2ojFjj0CoXkWX
0_nQ^>T2oj6mk0CoX;k^0_nP`>l2oj?5l@CoYLOa0_nVbO83ojS8l0;oZLS`1_nYaNh2ojW4k@KoZ<;/
0_nX`N`2ojS1j`CoZ<3[V_nW`>/00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo
000looooo`03o`000?oooooooooo02gooooo0_n/`NT2oj[1jPCoZ[kX0_nY_>L2ojJlj@CoYK[X0_nS
^NP2oj:lk0CoXKg/0_nP_^h2oj;3l0CoXlGa0_nUao43ojO7l0;oZ<S`0_nXaNh6ojW5kP;oZL?]1_nX
`^`2ojS1k0CoZ<7[0_nX`>^GojO0j`Gooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0<ooooo`00?Oooool00ol0003oooooooooo`0]ooooo`CoZ/7Z0_nZ_^P2ojNnjPCoY[cY0_nU^^P2
oj>mj`CoX[c/0_nQ_N`2oj;1k`CoX/?`0_nSaO43ojK5l0;oYlO`0_nXaNl4ojS5kP;oZLG^0_nX`nd4
ojW3k@;oZ<;/1_nX`N`2ojS1jiOoYl3[2Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00cooooo000nooooo`03o`000?oooooooooo02gooooo0_nZ`NX3ojO0j`?oYkkZ0_nV_>T2ojBm
j`CoXkg[0_nR_>`2oj;0kPCoX/7_0_nR`o03ojG4k`;oY/G`0_nWaNl4ojS5k`;oZ<G^0_nXa>d4ojS3
k@;oZL?]2?nX`N`3ojS0ji3oYl3[4?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00cooooo000oooooo`;o0000;oooool2ojO0j`;oYKo/1?nU_^`3ojBmj`;oXkg[0onS_nd3oj;0kP;o
X/7_0onT`nl2ojG4k`;oY/C_1?nWaNl2ojS5k`KoZ<C]0_nX`nd3ojS2k0GoZ<7/0onX`N/2ojS0jhko
Yl3[5?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo0011ooooo`03o`00
0?oooooooooo02gooooo1?nU_n`2ojFnk0;oY;o]1_nS_nd6ojC1kP;oY<?_0_nU`nh4ojK4k`;oYlG_
0_nW`nh6ojS4k@GoZ<;/1_nX`N`2ojS1jhkoYl3[6?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00_ooooo0012ooooo`03o`000?oooooooooo02gooooo0_nU_n`2ojBok0CoY;o]0_nS
_nd2ojC0k@KoY<7^0_nU`^h4ojG3kP;oY/C_1_nW`nh2ojS4k@GoZ<;/2?nX`N`2ojS0jh_oYl3[7Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0013ooooo`03o`000?oooooo
oooo02gooooo1?nT_n`4ojBok@CoY<3]0_nT`Nh2ojG1kPCoYL;^0_nU`nh2ojK3kPKoYl?^0onX`^d2
ojS2k0SoZ<7/1_nX`>^7ojO0jb3ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`00A?ooool00ol0003oooooooooo`0]ooooo`;oY;o/1_nT_nd4ojC0k@CoYL7^0_nU`^h3ojK2
k@?oY/?^0_nW`nh3ojO2k@;oZ<;]2?nX`N`00onX`N_oZ<3[ojS0j`04ojS0jhKoYl3[9?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0015ooooo`;o0000;oooool5ojBok@Ko
Y<3]0_nU`Nh3ojG1k@;oY/;]0_nW`Nd6ojO2k@03ojO1k?nX`NcoZ<7/00KoZ<7/1?nX`N/2ojS0jhGo
Yl3[:Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo0017ooooo`03o`00
0?oooooooooo02gooooo1?nT_n`2ojC0k@;oYL3/1_nU`Nd2ojK1k@CoYl7]0_nW`^d5ojO1k0SoZ<7/
0_nX`N^5ojO0jbcooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`00B?oo
ool00ol0003oooooooooo`0]ooooo`;oY;o/0_nU_n`4ojG0k0;oYL7]0_nV`N`4ojK1k@;oYl7]2OnW
`N`6ojS1k8GoYl3[<?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo0019
ooooo`03o`000?oooooooooo02gooooo1?nU_n`2ojG0k0;oY/3/1?nV`N`2ojK1k@goYl7/0_nX`Nb5
ojO0jcCooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00B_ooool2o`00
02kooooo0_nU_n`2ojJok0CoY/3/0_nV`N`2ojO0k0[oYl7/1_nW`>b1ojO0jcWooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0:ooooo`00C?ooool00ol0003oooooooooo`0/ooooo`Co
Y[o/1OnV`>`3ojO0k0;oYl7/0_nW`>`2ojO1k0SoYl3/OonW`>/looooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02_ooool004gooooo00?o0000ooooooooool0;?ooool5ojJok0;oY/3/
3onW`>alojO0jd?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`00C_oo
ool00ol0003oooooooooo`0]ooooo`;oY[o/00?oYl3[ojO0k?nW`>`01?nW`>`2ojO0j`KoYl3/O?nW
`>]7ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool004oooooo0_l0000^
ooooo`?oYl3[0_nW`>`6ojO0j`;oYl3/NonW`>]<ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02_ooool0057ooooo00?o0000ooooooooool0;?oooon4ojO0jdoooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0:ooooo`00D_ooool00ol0003oooooooooo`0[oooooh7o
Yl3[Doooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo001Cooooo`03o`00
0?oooooooooo02_oooooOOnW`>]Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2Oooool005Cooooo0_l0000]ooooogSoYl3[F_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Wooooo001Fooooo`03o`000?oooooooooo02_oooooM?nW`>]Nooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02Oooool005Oooooo00?o0000ooooooooool0:ooooom/ojO0
jfKooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`00F?ooool00ol0003o
ooooooooo`0/ooooofOoYl3[J_ooool01Ol0003ooooooooooooooooo000000_ooooo001Iooooo`03
o`000?oooooooooo02coooooHonW`>]]ooooo`05o`000?ooooooooooooooool000002oooool005[o
oooo0_l0000]oooooeooYl3[LOooool01?l0003oooooooooool0000;ooooo`00G?ooool00ol0003o
ooooooooo`0[oooooe_oYl3[MOooool00ol0003oooooo`00000;ooooo`00GOooool00ol0003ooooo
ooooo`0[oooooeOoYl3[N?ooool01?l0003oooooooooool0000:ooooo`00G_ooool00ol0003ooooo
ooooo`0[oooooe?oYl3[O?ooool00ol0003oooooo`00000:ooooo`00Goooool2o`0002coooooC?nW
`>^3ooooo`;o00002_ooool0067ooooo00?o0000ooooooooool0:_oooom8ojO0jhGooooo0ol0000:
ooooo`00H_ooool00ol0003oooooooooo`0[oooood?oYl3[Q?ooool4o`0000gooooo001Sooooo`03
o`000?oooooooooo02_ooooo?onW`>^3ooooo`Co00004Oooool006Cooooo0_l0000/oooooc_oYl3[
Poooool3o`0001Gooooo001Vooooo`03o`000?oooooooooo02_ooooo<onW`>^5ooooo`Co00006?oo
ool006Oooooo00?o0000ooooooooool0:_ooool`ojO0jhCooooo1?l0000Looooo`00J?ooool00ol0
003oooooooooo`0ZooooobcoYl3[Poooool4o`00023ooooo001Yooooo`;o0000;?oooolWojO0jh;o
oooo1?l0000Tooooo`00Joooool00ol0003oooooooooo`0Zooooob?oYl3[P_ooool3o`0002Sooooo
001/ooooo`03o`000?oooooooooo02[ooooo7OnW`>^3ooooo`Co0000:oooool006gooooo00?o0000
ooooooooool0:ooooolHojO0jh;ooooo1?l0000_ooooo`00K_ooool00ol0003oooooooooo`0Zoooo
oaGoYl3[POooool4o`0003?ooooo001_ooooo`;o0000:ooooolAojO0jh3ooooo1?l0000gooooo`00
LOooool00ol0003oooooooooo`0Zooooo`WoYl3[P_ooool4o`0003_ooooo001booooo`03o`000?oo
oooooooo02[ooooo1OnW`>^2ooooo`?o0000?oooool007?ooooo00?o0000ooooooooool0:_ooool0
0onW`>_oooooooooo`1oooooo`Co0000@_ooool007Cooooo0_l0000Zooooo`03o`000?oooooooooo
07_ooooo1?l00016ooooo`00M_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07So
oooo1?l0001:ooooo`00Moooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07Cooooo
1?l0001>ooooo`00N?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo077ooooo0ol0
001Booooo`00NOooool2o`0002Cooooo00?o0000ooooooooool0KOooool4o`0005Gooooo001koooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0JOooool4o`0005Wooooo001looooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0IOooool4o`0005gooooo001mooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0HOooool4o`00067ooooo001nooooo`;o00007ooo
ool00ol0003oooooooooo`1Mooooo`Co0000IOooool0083ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`1Jooooo`?o0000JOooool0087ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`1Fooooo`Co0000K?ooool008;ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`1Booooo`Co0000L?ooool008?ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`1>ooooo`Co0000M?ooool008Cooooo0_l0000Iooooo`03o`000?oooooooooo04[ooooo1?l0
001hooooo`00Q_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Kooooo1?l0001l
ooooo`00Qoooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04?ooooo0ol00020oooo
o`00R?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03oooooo1?l00023ooooo`00
ROooool2o`0001Cooooo00?o0000ooooooooool0>oooool4o`0008Oooooo002;ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0=oooool4o`0008_ooooo002<ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0<oooool4o`0008oooooo002=ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0<?ooool3o`0009?ooooo002>ooooo`;o00003oooool00ol0003o
ooooooooo`0/ooooo`Co0000U_ooool0093ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Xooooo`Co0000V_ooool0097ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Tooooo`Co0000W_ooool009;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Q
ooooo`Co0000X_ooool009?ooooo0_l00009ooooo`03o`000?oooooooooo01gooooo1?l0002Voooo
o`00UOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo0ol0002Zooooo`00
U_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo1?l0002]ooooo`00Uooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo1?l0002aooooo`00V?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0002eooooo`00VOooool2o`00
00?ooooo00?o0000ooooooooool02_ooool4o`000;Wooooo002Kooooo`04o`000?ooooooooooo`00
00Wooooo0ol0002mooooo`00W?ooool00ol0003oooooo`000005ooooo`Co0000`?ooool009gooooo
0_l000000ooooooo0000o`000002o`000<Cooooo002Nooooo`;o0000b?ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00:[ooooo00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0
TOooool00:[ooooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`Ko00001?ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool0T_ooool00:[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0009?ooooo002Zooooo`03o`000?oooooooooo00Cooooo
1_l00004ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0009Cooooo002Zooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo0000U?ooool0
0:Sooooo00?o410@o`000?l000000ol0000=ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000009Cooooo002Zooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l00000U?ooool00:[ooooo00?o0000ooooooooool03?ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`2Cooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -20 0 ]
[.5 .82364 20 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11.2) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69467 Mtetra
.4053 .69467 .41061 .69934 .41957 .69681 .41427 .69213 Mtetra
.41427 .69213 .41957 .69681 .42855 .69428 .42327 .68958 Mtetra
.42327 .68958 .42855 .69428 .43756 .69174 .43231 .68703 Mtetra
.43231 .68703 .43756 .69174 .4466 .68919 .44137 .68446 Mtetra
.44137 .68446 .4466 .68919 .45567 .68663 .45046 .68189 Mtetra
.45046 .68189 .45567 .68663 .46478 .68407 .45958 .67931 Mtetra
.45958 .67931 .46478 .68407 .47391 .68149 .46873 .67671 Mtetra
.46873 .67671 .47391 .68149 .48307 .67891 .47792 .67412 Mtetra
.47792 .67412 .48307 .67891 .49227 .67632 .48713 .67151 Mtetra
.48713 .67151 .49227 .67632 .50149 .67371 .49638 .66889 Mtetra
.49638 .66889 .50149 .67371 .51075 .6711 .50565 .66626 Mtetra
.50565 .66626 .51075 .6711 .52004 .66849 .51496 .66363 Mtetra
.51496 .66363 .52004 .66849 .52936 .66586 .5243 .66098 Mtetra
.5243 .66098 .52936 .66586 .53871 .66322 .53367 .65833 Mtetra
.53367 .65833 .53871 .66322 .54809 .66058 .54308 .65567 Mtetra
.54308 .65567 .54809 .66058 .55751 .65792 .55251 .653 Mtetra
.55251 .653 .55751 .65792 .56695 .65526 .56198 .65032 Mtetra
.56198 .65032 .56695 .65526 .57643 .65259 .57148 .64763 Mtetra
.57148 .64763 .57643 .65259 .58595 .6499 .58102 .64493 Mtetra
.58102 .64493 .58595 .6499 .59549 .64721 .59058 .64222 Mtetra
.59058 .64222 .59549 .64721 .60507 .64451 .60018 .6395 Mtetra
.60018 .6395 .60507 .64451 .61468 .6418 .60982 .63678 Mtetra
.60982 .63678 .61468 .6418 .62432 .63908 .61948 .63404 Mtetra
.61948 .63404 .62432 .63908 .634 .63636 .62918 .63129 Mtetra
.62918 .63129 .634 .63636 .64371 .63362 .63892 .62854 Mtetra
.63892 .62854 .64371 .63362 .65345 .63087 .64868 .62577 Mtetra
.64868 .62577 .65345 .63087 .66323 .62811 .65848 .623 Mtetra
.65848 .623 .66323 .62811 .67304 .62535 .66832 .62021 Mtetra
.66832 .62021 .67304 .62535 .68289 .62257 .67819 .61742 Mtetra
.67819 .61742 .68289 .62257 .69277 .61979 .68809 .61462 Mtetra
.68809 .61462 .69277 .61979 .70269 .61699 .69803 .6118 Mtetra
.69803 .6118 .70269 .61699 .71264 .61418 .70801 .60898 Mtetra
.70801 .60898 .71264 .61418 .72262 .61137 .71802 .60615 Mtetra
.71802 .60615 .72262 .61137 .73264 .60854 .72806 .6033 Mtetra
.72806 .6033 .73264 .60854 .7427 .60571 .73814 .60045 Mtetra
.73814 .60045 .7427 .60571 .75279 .60286 .74826 .59759 Mtetra
.74826 .59759 .75279 .60286 .76291 .60001 .75841 .59471 Mtetra
.75841 .59471 .76291 .60001 .77308 .59714 .7686 .59183 Mtetra
.7686 .59183 .77308 .59714 .78328 .59427 .77882 .58893 Mtetra
.77882 .58893 .78328 .59427 .79351 .59138 .78908 .58603 Mtetra
.78908 .58603 .79351 .59138 .80378 .58849 .79938 .58311 Mtetra
.79938 .58311 .80378 .58849 .81409 .58558 .80971 .58019 Mtetra
.80971 .58019 .81409 .58558 .82443 .58267 .82008 .57725 Mtetra
.82008 .57725 .82443 .58267 .83482 .57974 .83049 .57431 Mtetra
.83049 .57431 .83482 .57974 .84523 .5768 .84094 .57135 Mtetra
.84094 .57135 .84523 .5768 .85569 .57385 .85142 .56838 Mtetra
.85142 .56838 .85569 .57385 .86618 .57089 .86194 .5654 Mtetra
.86194 .5654 .86618 .57089 .87672 .56792 .8725 .56241 Mtetra
.8725 .56241 .87672 .56792 .88729 .56494 .8831 .55941 Mtetra
.8831 .55941 .88729 .56494 .89789 .56195 .89374 .5564 Mtetra
.89374 .5564 .89789 .56195 .90854 .55895 .90441 .55338 Mtetra
.90441 .55338 .90854 .55895 .91923 .55594 .91512 .55035 Mtetra
.91512 .55035 .91923 .55594 .92995 .55292 .92588 .5473 Mtetra
.92588 .5473 .92995 .55292 .94071 .54988 .93667 .54425 Mtetra
.93667 .54425 .94071 .54988 .95152 .54684 .9475 .54118 Mtetra
.9475 .54118 .95152 .54684 .96236 .54378 .95837 .53811 Mtetra
.95837 .53811 .96236 .54378 .97324 .54071 .96928 .53502 Mtetra
.96928 .53502 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.391 .69252 .39636 .6972 .4053 .69467 .39996 .68998 Mtetra
.39996 .68998 .4053 .69467 .41427 .69213 .40895 .68742 Mtetra
.40895 .68742 .41427 .69213 .42327 .68958 .41797 .68486 Mtetra
.41797 .68486 .42327 .68958 .43231 .68703 .42702 .68228 Mtetra
.42702 .68228 .43231 .68703 .44137 .68446 .4361 .6797 Mtetra
.4361 .6797 .44137 .68446 .45046 .68189 .44521 .67711 Mtetra
.44521 .67711 .45046 .68189 .45958 .67931 .45435 .67452 Mtetra
.45435 .67452 .45958 .67931 .46873 .67671 .46352 .67191 Mtetra
.46352 .67191 .46873 .67671 .47792 .67412 .47273 .66929 Mtetra
.47273 .66929 .47792 .67412 .48713 .67151 .48196 .66667 Mtetra
.48196 .66667 .48713 .67151 .49638 .66889 .49123 .66403 Mtetra
.49123 .66403 .49638 .66889 .50565 .66626 .50053 .66139 Mtetra
.50053 .66139 .50565 .66626 .51496 .66363 .50985 .65874 Mtetra
.50985 .65874 .51496 .66363 .5243 .66098 .51922 .65608 Mtetra
.51922 .65608 .5243 .66098 .53367 .65833 .52861 .65341 Mtetra
.52861 .65341 .53367 .65833 .54308 .65567 .53803 .65073 Mtetra
.53803 .65073 .54308 .65567 .55251 .653 .54749 .64804 Mtetra
.54749 .64804 .55251 .653 .56198 .65032 .55698 .64534 Mtetra
.55698 .64534 .56198 .65032 .57148 .64763 .5665 .64264 Mtetra
.5665 .64264 .57148 .64763 .58102 .64493 .57606 .63992 Mtetra
.57606 .63992 .58102 .64493 .59058 .64222 .58565 .6372 Mtetra
.58565 .6372 .59058 .64222 .60018 .6395 .59527 .63446 Mtetra
.59527 .63446 .60018 .6395 .60982 .63678 .60493 .63172 Mtetra
.60493 .63172 .60982 .63678 .61948 .63404 .61461 .62896 Mtetra
.61461 .62896 .61948 .63404 .62918 .63129 .62434 .6262 Mtetra
.62434 .6262 .62918 .63129 .63892 .62854 .63409 .62343 Mtetra
.63409 .62343 .63892 .62854 .64868 .62577 .64388 .62064 Mtetra
.64388 .62064 .64868 .62577 .65848 .623 .65371 .61785 Mtetra
.65371 .61785 .65848 .623 .66832 .62021 .66357 .61505 Mtetra
.66357 .61505 .66832 .62021 .67819 .61742 .67346 .61224 Mtetra
.67346 .61224 .67819 .61742 .68809 .61462 .68339 .60942 Mtetra
.68339 .60942 .68809 .61462 .69803 .6118 .69335 .60658 Mtetra
.69335 .60658 .69803 .6118 .70801 .60898 .70335 .60374 Mtetra
.70335 .60374 .70801 .60898 .71802 .60615 .71338 .60089 Mtetra
.71338 .60089 .71802 .60615 .72806 .6033 .72345 .59803 Mtetra
.72345 .59803 .72806 .6033 .73814 .60045 .73356 .59516 Mtetra
.73356 .59516 .73814 .60045 .74826 .59759 .7437 .59227 Mtetra
.7437 .59227 .74826 .59759 .75841 .59471 .75387 .58938 Mtetra
.75387 .58938 .75841 .59471 .7686 .59183 .76409 .58648 Mtetra
.76409 .58648 .7686 .59183 .77882 .58893 .77434 .58356 Mtetra
.77434 .58356 .77882 .58893 .78908 .58603 .78462 .58064 Mtetra
.78462 .58064 .78908 .58603 .79938 .58311 .79495 .57771 Mtetra
.79495 .57771 .79938 .58311 .80971 .58019 .80531 .57476 Mtetra
.80531 .57476 .80971 .58019 .82008 .57725 .81571 .57181 Mtetra
.81571 .57181 .82008 .57725 .83049 .57431 .82614 .56884 Mtetra
.82614 .56884 .83049 .57431 .84094 .57135 .83661 .56586 Mtetra
.83661 .56586 .84094 .57135 .85142 .56838 .84712 .56288 Mtetra
.84712 .56288 .85142 .56838 .86194 .5654 .85767 .55988 Mtetra
.85767 .55988 .86194 .5654 .8725 .56241 .86826 .55687 Mtetra
.86826 .55687 .8725 .56241 .8831 .55941 .87889 .55385 Mtetra
.87889 .55385 .8831 .55941 .89374 .5564 .88955 .55082 Mtetra
.88955 .55082 .89374 .5564 .90441 .55338 .90025 .54777 Mtetra
.90025 .54777 .90441 .55338 .91512 .55035 .911 .54472 Mtetra
.911 .54472 .91512 .55035 .92588 .5473 .92178 .54166 Mtetra
.92178 .54166 .92588 .5473 .93667 .54425 .9326 .53858 Mtetra
.9326 .53858 .93667 .54425 .9475 .54118 .94346 .53549 Mtetra
.94346 .53549 .9475 .54118 .95837 .53811 .95436 .53239 Mtetra
.95436 .53239 .95837 .53811 .96928 .53502 .9653 .52928 Mtetra
.9653 .52928 .96928 .53502 .98024 .53192 .97628 .52616 Mtetra
.38561 .68781 .391 .69252 .39996 .68998 .39459 .68525 Mtetra
.39459 .68525 .39996 .68998 .40895 .68742 .40359 .68268 Mtetra
.40359 .68268 .40895 .68742 .41797 .68486 .41263 .6801 Mtetra
.41263 .6801 .41797 .68486 .42702 .68228 .4217 .67751 Mtetra
.4217 .67751 .42702 .68228 .4361 .6797 .4308 .67492 Mtetra
.4308 .67492 .4361 .6797 .44521 .67711 .43993 .67231 Mtetra
.43993 .67231 .44521 .67711 .45435 .67452 .44909 .6697 Mtetra
.44909 .6697 .45435 .67452 .46352 .67191 .45828 .66707 Mtetra
.45828 .66707 .46352 .67191 .47273 .66929 .46751 .66444 Mtetra
.46751 .66444 .47273 .66929 .48196 .66667 .47676 .6618 Mtetra
.47676 .6618 .48196 .66667 .49123 .66403 .48605 .65915 Mtetra
.48605 .65915 .49123 .66403 .50053 .66139 .49537 .65649 Mtetra
.49537 .65649 .50053 .66139 .50985 .65874 .50472 .65382 Mtetra
.50472 .65382 .50985 .65874 .51922 .65608 .5141 .65114 Mtetra
.5141 .65114 .51922 .65608 .52861 .65341 .52351 .64846 Mtetra
.52351 .64846 .52861 .65341 .53803 .65073 .53296 .64576 Mtetra
.53296 .64576 .53803 .65073 .54749 .64804 .54244 .64305 Mtetra
.54244 .64305 .54749 .64804 .55698 .64534 .55195 .64034 Mtetra
.55195 .64034 .55698 .64534 .5665 .64264 .56149 .63762 Mtetra
.56149 .63762 .5665 .64264 .57606 .63992 .57107 .63488 Mtetra
.57107 .63488 .57606 .63992 .58565 .6372 .58068 .63214 Mtetra
.58068 .63214 .58565 .6372 .59527 .63446 .59032 .62939 Mtetra
.59032 .62939 .59527 .63446 .60493 .63172 .6 .62663 Mtetra
.6 .62663 .60493 .63172 .61461 .62896 .60971 .62385 Mtetra
.60971 .62385 .61461 .62896 .62434 .6262 .61946 .62107 Mtetra
.61946 .62107 .62434 .6262 .63409 .62343 .62924 .61828 Mtetra
.62924 .61828 .63409 .62343 .64388 .62064 .63905 .61548 Mtetra
.63905 .61548 .64388 .62064 .65371 .61785 .6489 .61267 Mtetra
.6489 .61267 .65371 .61785 .66357 .61505 .65878 .60985 Mtetra
.65878 .60985 .66357 .61505 .67346 .61224 .6687 .60702 Mtetra
.6687 .60702 .67346 .61224 .68339 .60942 .67865 .60418 Mtetra
.67865 .60418 .68339 .60942 .69335 .60658 .68864 .60133 Mtetra
.68864 .60133 .69335 .60658 .70335 .60374 .69866 .59847 Mtetra
.69866 .59847 .70335 .60374 .71338 .60089 .70872 .5956 Mtetra
.70872 .5956 .71338 .60089 .72345 .59803 .71881 .59272 Mtetra
.71881 .59272 .72345 .59803 .73356 .59516 .72894 .58983 Mtetra
.72894 .58983 .73356 .59516 .7437 .59227 .73911 .58692 Mtetra
.73911 .58692 .7437 .59227 .75387 .58938 .74931 .58401 Mtetra
.74931 .58401 .75387 .58938 .76409 .58648 .75955 .58109 Mtetra
.75955 .58109 .76409 .58648 .77434 .58356 .76982 .57816 Mtetra
.76982 .57816 .77434 .58356 .78462 .58064 .78014 .57521 Mtetra
.78014 .57521 .78462 .58064 .79495 .57771 .79049 .57226 Mtetra
.79049 .57226 .79495 .57771 .80531 .57476 .80087 .5693 Mtetra
.80087 .5693 .80531 .57476 .81571 .57181 .8113 .56632 Mtetra
.8113 .56632 .81571 .57181 .82614 .56884 .82176 .56334 Mtetra
.82176 .56334 .82614 .56884 .83661 .56586 .83226 .56034 Mtetra
.83226 .56034 .83661 .56586 .84712 .56288 .8428 .55733 Mtetra
.8428 .55733 .84712 .56288 .85767 .55988 .85337 .55431 Mtetra
.85337 .55431 .85767 .55988 .86826 .55687 .86399 .55128 Mtetra
.86399 .55128 .86826 .55687 .87889 .55385 .87464 .54824 Mtetra
.87464 .54824 .87889 .55385 .88955 .55082 .88533 .54519 Mtetra
.88533 .54519 .88955 .55082 .90025 .54777 .89607 .54213 Mtetra
.89607 .54213 .90025 .54777 .911 .54472 .90684 .53905 Mtetra
.90684 .53905 .911 .54472 .92178 .54166 .91765 .53597 Mtetra
.91765 .53597 .92178 .54166 .9326 .53858 .9285 .53287 Mtetra
.9285 .53287 .9326 .53858 .94346 .53549 .93939 .52976 Mtetra
.93939 .52976 .94346 .53549 .95436 .53239 .95032 .52664 Mtetra
.95032 .52664 .95436 .53239 .9653 .52928 .96129 .52351 Mtetra
.96129 .52351 .9653 .52928 .97628 .52616 .9723 .52037 Mtetra
.38018 .68308 .38561 .68781 .39459 .68525 .38918 .6805 Mtetra
.38918 .6805 .39459 .68525 .40359 .68268 .3982 .67791 Mtetra
.3982 .67791 .40359 .68268 .41263 .6801 .40726 .67532 Mtetra
.40726 .67532 .41263 .6801 .4217 .67751 .41635 .67271 Mtetra
.41635 .67271 .4217 .67751 .4308 .67492 .42547 .6701 Mtetra
.42547 .6701 .4308 .67492 .43993 .67231 .43462 .66748 Mtetra
.43462 .66748 .43993 .67231 .44909 .6697 .4438 .66485 Mtetra
.4438 .66485 .44909 .6697 .45828 .66707 .45301 .66221 Mtetra
.45301 .66221 .45828 .66707 .46751 .66444 .46225 .65956 Mtetra
.46225 .65956 .46751 .66444 .47676 .6618 .47153 .6569 Mtetra
.47153 .6569 .47676 .6618 .48605 .65915 .48083 .65423 Mtetra
.48083 .65423 .48605 .65915 .49537 .65649 .49017 .65156 Mtetra
.49017 .65156 .49537 .65649 .50472 .65382 .49954 .64887 Mtetra
.49954 .64887 .50472 .65382 .5141 .65114 .50895 .64618 Mtetra
.50895 .64618 .5141 .65114 .52351 .64846 .51838 .64347 Mtetra
.51838 .64347 .52351 .64846 .53296 .64576 .52785 .64076 Mtetra
.52785 .64076 .53296 .64576 .54244 .64305 .53735 .63804 Mtetra
.53735 .63804 .54244 .64305 .55195 .64034 .54688 .6353 Mtetra
.54688 .6353 .55195 .64034 .56149 .63762 .55645 .63256 Mtetra
.55645 .63256 .56149 .63762 .57107 .63488 .56605 .62981 Mtetra
.56605 .62981 .57107 .63488 .58068 .63214 .57568 .62705 Mtetra
.57568 .62705 .58068 .63214 .59032 .62939 .58535 .62428 Mtetra
.58535 .62428 .59032 .62939 .6 .62663 .59505 .6215 Mtetra
.59505 .6215 .6 .62663 .60971 .62385 .60478 .61871 Mtetra
.60478 .61871 .60971 .62385 .61946 .62107 .61455 .61591 Mtetra
.61455 .61591 .61946 .62107 .62924 .61828 .62435 .6131 Mtetra
.62435 .6131 .62924 .61828 .63905 .61548 .63419 .61028 Mtetra
.63419 .61028 .63905 .61548 .6489 .61267 .64406 .60746 Mtetra
.64406 .60746 .6489 .61267 .65878 .60985 .65396 .60462 Mtetra
.65396 .60462 .65878 .60985 .6687 .60702 .66391 .60177 Mtetra
.66391 .60177 .6687 .60702 .67865 .60418 .67388 .59891 Mtetra
.67388 .59891 .67865 .60418 .68864 .60133 .68389 .59604 Mtetra
.68389 .59604 .68864 .60133 .69866 .59847 .69394 .59316 Mtetra
.69394 .59316 .69866 .59847 .70872 .5956 .70402 .59027 Mtetra
.70402 .59027 .70872 .5956 .71881 .59272 .71414 .58737 Mtetra
.71414 .58737 .71881 .59272 .72894 .58983 .7243 .58446 Mtetra
.7243 .58446 .72894 .58983 .73911 .58692 .73449 .58154 Mtetra
.73449 .58154 .73911 .58692 .74931 .58401 .74472 .57861 Mtetra
.74472 .57861 .74931 .58401 .75955 .58109 .75498 .57567 Mtetra
.75498 .57567 .75955 .58109 .76982 .57816 .76528 .57272 Mtetra
.76528 .57272 .76982 .57816 .78014 .57521 .77562 .56975 Mtetra
.77562 .56975 .78014 .57521 .79049 .57226 .786 .56678 Mtetra
.786 .56678 .79049 .57226 .80087 .5693 .79641 .5638 Mtetra
.79641 .5638 .80087 .5693 .8113 .56632 .80686 .5608 Mtetra
.80686 .5608 .8113 .56632 .82176 .56334 .81735 .55779 Mtetra
.81735 .55779 .82176 .56334 .83226 .56034 .82788 .55478 Mtetra
.82788 .55478 .83226 .56034 .8428 .55733 .83844 .55175 Mtetra
.83844 .55175 .8428 .55733 .85337 .55431 .84905 .54871 Mtetra
.84905 .54871 .85337 .55431 .86399 .55128 .85969 .54566 Mtetra
.85969 .54566 .86399 .55128 .87464 .54824 .87037 .5426 Mtetra
.87037 .5426 .87464 .54824 .88533 .54519 .88109 .53953 Mtetra
.88109 .53953 .88533 .54519 .89607 .54213 .89185 .53644 Mtetra
.89185 .53644 .89607 .54213 .90684 .53905 .90265 .53335 Mtetra
.90265 .53335 .90684 .53905 .91765 .53597 .91349 .53024 Mtetra
.91349 .53024 .91765 .53597 .9285 .53287 .92437 .52713 Mtetra
.92437 .52713 .9285 .53287 .93939 .52976 .93529 .524 Mtetra
.93529 .524 .93939 .52976 .95032 .52664 .94625 .52085 Mtetra
.94625 .52085 .95032 .52664 .96129 .52351 .95725 .5177 Mtetra
.95725 .5177 .96129 .52351 .9723 .52037 .96829 .51454 Mtetra
.37472 .67831 .38018 .68308 .38918 .6805 .38373 .67572 Mtetra
.38373 .67572 .38918 .6805 .3982 .67791 .39278 .67311 Mtetra
.39278 .67311 .3982 .67791 .40726 .67532 .40186 .6705 Mtetra
.40186 .6705 .40726 .67532 .41635 .67271 .41096 .66788 Mtetra
.41096 .66788 .41635 .67271 .42547 .6701 .4201 .66525 Mtetra
.4201 .66525 .42547 .6701 .43462 .66748 .42927 .66261 Mtetra
.42927 .66261 .43462 .66748 .4438 .66485 .43847 .65996 Mtetra
.43847 .65996 .4438 .66485 .45301 .66221 .4477 .65731 Mtetra
.4477 .65731 .45301 .66221 .46225 .65956 .45697 .65464 Mtetra
.45697 .65464 .46225 .65956 .47153 .6569 .46626 .65197 Mtetra
.46626 .65197 .47153 .6569 .48083 .65423 .47559 .64928 Mtetra
.47559 .64928 .48083 .65423 .49017 .65156 .48495 .64659 Mtetra
.48495 .64659 .49017 .65156 .49954 .64887 .49434 .64389 Mtetra
.49434 .64389 .49954 .64887 .50895 .64618 .50376 .64118 Mtetra
.50376 .64118 .50895 .64618 .51838 .64347 .51322 .63846 Mtetra
.51322 .63846 .51838 .64347 .52785 .64076 .52271 .63572 Mtetra
.52271 .63572 .52785 .64076 .53735 .63804 .53223 .63298 Mtetra
.53223 .63298 .53735 .63804 .54688 .6353 .54178 .63024 Mtetra
.54178 .63024 .54688 .6353 .55645 .63256 .55137 .62748 Mtetra
.55137 .62748 .55645 .63256 .56605 .62981 .56099 .62471 Mtetra
.56099 .62471 .56605 .62981 .57568 .62705 .57065 .62193 Mtetra
.57065 .62193 .57568 .62705 .58535 .62428 .58034 .61914 Mtetra
.58034 .61914 .58535 .62428 .59505 .6215 .59006 .61634 Mtetra
.59006 .61634 .59505 .6215 .60478 .61871 .59982 .61354 Mtetra
.59982 .61354 .60478 .61871 .61455 .61591 .60961 .61072 Mtetra
.60961 .61072 .61455 .61591 .62435 .6131 .61943 .60789 Mtetra
.61943 .60789 .62435 .6131 .63419 .61028 .62929 .60505 Mtetra
.62929 .60505 .63419 .61028 .64406 .60746 .63919 .60221 Mtetra
.63919 .60221 .64406 .60746 .65396 .60462 .64912 .59935 Mtetra
.64912 .59935 .65396 .60462 .66391 .60177 .65908 .59648 Mtetra
.65908 .59648 .66391 .60177 .67388 .59891 .66908 .5936 Mtetra
.66908 .5936 .67388 .59891 .68389 .59604 .67912 .59072 Mtetra
.67912 .59072 .68389 .59604 .69394 .59316 .68919 .58782 Mtetra
.68919 .58782 .69394 .59316 .70402 .59027 .6993 .58491 Mtetra
.6993 .58491 .70402 .59027 .71414 .58737 .70944 .58199 Mtetra
.70944 .58199 .71414 .58737 .7243 .58446 .71962 .57906 Mtetra
.71962 .57906 .7243 .58446 .73449 .58154 .72984 .57612 Mtetra
.72984 .57612 .73449 .58154 .74472 .57861 .74009 .57317 Mtetra
.74009 .57317 .74472 .57861 .75498 .57567 .75038 .57021 Mtetra
.75038 .57021 .75498 .57567 .76528 .57272 .76071 .56724 Mtetra
.76071 .56724 .76528 .57272 .77562 .56975 .77107 .56426 Mtetra
.77107 .56426 .77562 .56975 .786 .56678 .78148 .56126 Mtetra
.78148 .56126 .786 .56678 .79641 .5638 .79192 .55826 Mtetra
.79192 .55826 .79641 .5638 .80686 .5608 .80239 .55524 Mtetra
.80239 .55524 .80686 .5608 .81735 .55779 .81291 .55222 Mtetra
.81291 .55222 .81735 .55779 .82788 .55478 .82346 .54918 Mtetra
.82346 .54918 .82788 .55478 .83844 .55175 .83406 .54613 Mtetra
.83406 .54613 .83844 .55175 .84905 .54871 .84469 .54307 Mtetra
.84469 .54307 .84905 .54871 .85969 .54566 .85536 .54 Mtetra
.85536 .54 .85969 .54566 .87037 .5426 .86607 .53692 Mtetra
.86607 .53692 .87037 .5426 .88109 .53953 .87682 .53383 Mtetra
.87682 .53383 .88109 .53953 .89185 .53644 .88761 .53072 Mtetra
.88761 .53072 .89185 .53644 .90265 .53335 .89844 .52761 Mtetra
.89844 .52761 .90265 .53335 .91349 .53024 .90931 .52448 Mtetra
.90931 .52448 .91349 .53024 .92437 .52713 .92022 .52134 Mtetra
.92022 .52134 .92437 .52713 .93529 .524 .93116 .51819 Mtetra
.93116 .51819 .93529 .524 .94625 .52085 .94216 .51503 Mtetra
.94216 .51503 .94625 .52085 .95725 .5177 .95319 .51185 Mtetra
.95319 .51185 .95725 .5177 .96829 .51454 .96426 .50866 Mtetra
.36922 .67351 .37472 .67831 .38373 .67572 .37826 .6709 Mtetra
.37826 .6709 .38373 .67572 .39278 .67311 .38732 .66828 Mtetra
.38732 .66828 .39278 .67311 .40186 .6705 .39642 .66566 Mtetra
.39642 .66566 .40186 .6705 .41096 .66788 .40554 .66302 Mtetra
.40554 .66302 .41096 .66788 .4201 .66525 .4147 .66037 Mtetra
.4147 .66037 .4201 .66525 .42927 .66261 .42389 .65772 Mtetra
.42389 .65772 .42927 .66261 .43847 .65996 .43311 .65505 Mtetra
.43311 .65505 .43847 .65996 .4477 .65731 .44236 .65238 Mtetra
.44236 .65238 .4477 .65731 .45697 .65464 .45165 .6497 Mtetra
.45165 .6497 .45697 .65464 .46626 .65197 .46096 .64701 Mtetra
.46096 .64701 .46626 .65197 .47559 .64928 .47031 .6443 Mtetra
.47031 .6443 .47559 .64928 .48495 .64659 .47969 .64159 Mtetra
.47969 .64159 .48495 .64659 .49434 .64389 .4891 .63887 Mtetra
.4891 .63887 .49434 .64389 .50376 .64118 .49855 .63615 Mtetra
.49855 .63615 .50376 .64118 .51322 .63846 .50802 .63341 Mtetra
.50802 .63341 .51322 .63846 .52271 .63572 .51753 .63066 Mtetra
.51753 .63066 .52271 .63572 .53223 .63298 .52708 .6279 Mtetra
.52708 .6279 .53223 .63298 .54178 .63024 .53665 .62513 Mtetra
.53665 .62513 .54178 .63024 .55137 .62748 .54626 .62236 Mtetra
.54626 .62236 .55137 .62748 .56099 .62471 .55591 .61957 Mtetra
.55591 .61957 .56099 .62471 .57065 .62193 .56558 .61677 Mtetra
.56558 .61677 .57065 .62193 .58034 .61914 .57529 .61397 Mtetra
.57529 .61397 .58034 .61914 .59006 .61634 .58504 .61115 Mtetra
.58504 .61115 .59006 .61634 .59982 .61354 .59482 .60833 Mtetra
.59482 .60833 .59982 .61354 .60961 .61072 .60463 .60549 Mtetra
.60463 .60549 .60961 .61072 .61943 .60789 .61448 .60265 Mtetra
.61448 .60265 .61943 .60789 .62929 .60505 .62437 .59979 Mtetra
.62437 .59979 .62929 .60505 .63919 .60221 .63428 .59692 Mtetra
.63428 .59692 .63919 .60221 .64912 .59935 .64424 .59405 Mtetra
.64424 .59405 .64912 .59935 .65908 .59648 .65423 .59116 Mtetra
.65423 .59116 .65908 .59648 .66908 .5936 .66425 .58826 Mtetra
.66425 .58826 .66908 .5936 .67912 .59072 .67431 .58536 Mtetra
.67431 .58536 .67912 .59072 .68919 .58782 .68441 .58244 Mtetra
.68441 .58244 .68919 .58782 .6993 .58491 .69454 .57951 Mtetra
.69454 .57951 .6993 .58491 .70944 .58199 .70471 .57657 Mtetra
.70471 .57657 .70944 .58199 .71962 .57906 .71491 .57363 Mtetra
.71491 .57363 .71962 .57906 .72984 .57612 .72516 .57067 Mtetra
.72516 .57067 .72984 .57612 .74009 .57317 .73544 .5677 Mtetra
.73544 .5677 .74009 .57317 .75038 .57021 .74575 .56471 Mtetra
.74575 .56471 .75038 .57021 .76071 .56724 .75611 .56172 Mtetra
.75611 .56172 .76071 .56724 .77107 .56426 .7665 .55872 Mtetra
.7665 .55872 .77107 .56426 .78148 .56126 .77693 .55571 Mtetra
.77693 .55571 .78148 .56126 .79192 .55826 .78739 .55268 Mtetra
.78739 .55268 .79192 .55826 .80239 .55524 .7979 .54965 Mtetra
.7979 .54965 .80239 .55524 .81291 .55222 .80844 .5466 Mtetra
.80844 .5466 .81291 .55222 .82346 .54918 .81902 .54354 Mtetra
.81902 .54354 .82346 .54918 .83406 .54613 .82964 .54047 Mtetra
.82964 .54047 .83406 .54613 .84469 .54307 .8403 .53739 Mtetra
.8403 .53739 .84469 .54307 .85536 .54 .851 .5343 Mtetra
.851 .5343 .85536 .54 .86607 .53692 .86174 .5312 Mtetra
.86174 .5312 .86607 .53692 .87682 .53383 .87252 .52809 Mtetra
.87252 .52809 .87682 .53383 .88761 .53072 .88334 .52496 Mtetra
.88334 .52496 .88761 .53072 .89844 .52761 .89419 .52182 Mtetra
.89419 .52182 .89844 .52761 .90931 .52448 .90509 .51867 Mtetra
.90509 .51867 .90931 .52448 .92022 .52134 .91603 .51551 Mtetra
.91603 .51551 .92022 .52134 .93116 .51819 .92701 .51234 Mtetra
.92701 .51234 .93116 .51819 .94216 .51503 .93803 .50916 Mtetra
.93803 .50916 .94216 .51503 .95319 .51185 .94909 .50596 Mtetra
.94909 .50596 .95319 .51185 .96426 .50866 .9602 .50275 Mtetra
.36369 .66869 .36922 .67351 .37826 .6709 .37275 .66606 Mtetra
.37275 .66606 .37826 .6709 .38732 .66828 .38183 .66343 Mtetra
.38183 .66343 .38732 .66828 .39642 .66566 .39094 .66078 Mtetra
.39094 .66078 .39642 .66566 .40554 .66302 .40009 .65813 Mtetra
.40009 .65813 .40554 .66302 .4147 .66037 .40927 .65546 Mtetra
.40927 .65546 .4147 .66037 .42389 .65772 .41848 .65279 Mtetra
.41848 .65279 .42389 .65772 .43311 .65505 .42772 .65011 Mtetra
.42772 .65011 .43311 .65505 .44236 .65238 .43699 .64742 Mtetra
.43699 .64742 .44236 .65238 .45165 .6497 .44629 .64472 Mtetra
.44629 .64472 .45165 .6497 .46096 .64701 .45563 .64201 Mtetra
.45563 .64201 .46096 .64701 .47031 .6443 .465 .63929 Mtetra
.465 .63929 .47031 .6443 .47969 .64159 .4744 .63657 Mtetra
.4744 .63657 .47969 .64159 .4891 .63887 .48383 .63383 Mtetra
.48383 .63383 .4891 .63887 .49855 .63615 .4933 .63108 Mtetra
.4933 .63108 .49855 .63615 .50802 .63341 .50279 .62833 Mtetra
.50279 .62833 .50802 .63341 .51753 .63066 .51233 .62556 Mtetra
.51233 .62556 .51753 .63066 .52708 .6279 .52189 .62279 Mtetra
.52189 .62279 .52708 .6279 .53665 .62513 .53149 .62 Mtetra
.53149 .62 .53665 .62513 .54626 .62236 .54112 .61721 Mtetra
.54112 .61721 .54626 .62236 .55591 .61957 .55079 .6144 Mtetra
.55079 .6144 .55591 .61957 .56558 .61677 .56049 .61159 Mtetra
.56049 .61159 .56558 .61677 .57529 .61397 .57022 .60876 Mtetra
.57022 .60876 .57529 .61397 .58504 .61115 .57999 .60593 Mtetra
.57999 .60593 .58504 .61115 .59482 .60833 .58979 .60308 Mtetra
.58979 .60308 .59482 .60833 .60463 .60549 .59963 .60023 Mtetra
.59963 .60023 .60463 .60549 .61448 .60265 .6095 .59737 Mtetra
.6095 .59737 .61448 .60265 .62437 .59979 .61941 .59449 Mtetra
.61941 .59449 .62437 .59979 .63428 .59692 .62935 .59161 Mtetra
.62935 .59161 .63428 .59692 .64424 .59405 .63933 .58871 Mtetra
.63933 .58871 .64424 .59405 .65423 .59116 .64934 .58581 Mtetra
.64934 .58581 .65423 .59116 .66425 .58826 .65939 .58289 Mtetra
.65939 .58289 .66425 .58826 .67431 .58536 .66947 .57996 Mtetra
.66947 .57996 .67431 .58536 .68441 .58244 .67959 .57703 Mtetra
.67959 .57703 .68441 .58244 .69454 .57951 .68975 .57408 Mtetra
.68975 .57408 .69454 .57951 .70471 .57657 .69995 .57112 Mtetra
.69995 .57112 .70471 .57657 .71491 .57363 .71018 .56815 Mtetra
.71018 .56815 .71491 .57363 .72516 .57067 .72044 .56517 Mtetra
.72044 .56517 .72516 .57067 .73544 .5677 .73075 .56218 Mtetra
.73075 .56218 .73544 .5677 .74575 .56471 .74109 .55918 Mtetra
.74109 .55918 .74575 .56471 .75611 .56172 .75147 .55617 Mtetra
.75147 .55617 .75611 .56172 .7665 .55872 .76189 .55315 Mtetra
.76189 .55315 .7665 .55872 .77693 .55571 .77234 .55012 Mtetra
.77234 .55012 .77693 .55571 .78739 .55268 .78284 .54707 Mtetra
.78284 .54707 .78739 .55268 .7979 .54965 .79337 .54401 Mtetra
.79337 .54401 .7979 .54965 .80844 .5466 .80394 .54095 Mtetra
.80394 .54095 .80844 .5466 .81902 .54354 .81455 .53787 Mtetra
.81455 .53787 .81902 .54354 .82964 .54047 .8252 .53478 Mtetra
.8252 .53478 .82964 .54047 .8403 .53739 .83589 .53168 Mtetra
.83589 .53168 .8403 .53739 .851 .5343 .84661 .52857 Mtetra
.84661 .52857 .851 .5343 .86174 .5312 .85738 .52544 Mtetra
.85738 .52544 .86174 .5312 .87252 .52809 .86819 .52231 Mtetra
.86819 .52231 .87252 .52809 .88334 .52496 .87903 .51916 Mtetra
.87903 .51916 .88334 .52496 .89419 .52182 .88992 .516 Mtetra
.88992 .516 .89419 .52182 .90509 .51867 .90085 .51283 Mtetra
.90085 .51283 .90509 .51867 .91603 .51551 .91182 .50965 Mtetra
.91182 .50965 .91603 .51551 .92701 .51234 .92283 .50645 Mtetra
.92283 .50645 .92701 .51234 .93803 .50916 .93388 .50325 Mtetra
.93388 .50325 .93803 .50916 .94909 .50596 .94497 .50003 Mtetra
.94497 .50003 .94909 .50596 .9602 .50275 .9561 .4968 Mtetra
.35813 .66383 .36369 .66869 .37275 .66606 .3672 .66119 Mtetra
.3672 .66119 .37275 .66606 .38183 .66343 .3763 .65854 Mtetra
.3763 .65854 .38183 .66343 .39094 .66078 .38544 .65587 Mtetra
.38544 .65587 .39094 .66078 .40009 .65813 .3946 .6532 Mtetra
.3946 .6532 .40009 .65813 .40927 .65546 .4038 .65052 Mtetra
.4038 .65052 .40927 .65546 .41848 .65279 .41303 .64784 Mtetra
.41303 .64784 .41848 .65279 .42772 .65011 .42229 .64514 Mtetra
.42229 .64514 .42772 .65011 .43699 .64742 .43158 .64243 Mtetra
.43158 .64243 .43699 .64742 .44629 .64472 .4409 .63971 Mtetra
.4409 .63971 .44629 .64472 .45563 .64201 .45026 .63699 Mtetra
.45026 .63699 .45563 .64201 .465 .63929 .45965 .63425 Mtetra
.45965 .63425 .465 .63929 .4744 .63657 .46907 .63151 Mtetra
.46907 .63151 .4744 .63657 .48383 .63383 .47853 .62875 Mtetra
.47853 .62875 .48383 .63383 .4933 .63108 .48801 .62599 Mtetra
.48801 .62599 .4933 .63108 .50279 .62833 .49753 .62321 Mtetra
.49753 .62321 .50279 .62833 .51233 .62556 .50709 .62043 Mtetra
.50709 .62043 .51233 .62556 .52189 .62279 .51667 .61764 Mtetra
.51667 .61764 .52189 .62279 .53149 .62 .52629 .61483 Mtetra
.52629 .61483 .53149 .62 .54112 .61721 .53595 .61202 Mtetra
.53595 .61202 .54112 .61721 .55079 .6144 .54563 .6092 Mtetra
.54563 .6092 .55079 .6144 .56049 .61159 .55536 .60636 Mtetra
.55536 .60636 .56049 .61159 .57022 .60876 .56511 .60352 Mtetra
.56511 .60352 .57022 .60876 .57999 .60593 .5749 .60067 Mtetra
.5749 .60067 .57999 .60593 .58979 .60308 .58473 .59781 Mtetra
.58473 .59781 .58979 .60308 .59963 .60023 .59459 .59493 Mtetra
.59459 .59493 .59963 .60023 .6095 .59737 .60448 .59205 Mtetra
.60448 .59205 .6095 .59737 .61941 .59449 .61441 .58916 Mtetra
.61441 .58916 .61941 .59449 .62935 .59161 .62438 .58625 Mtetra
.62438 .58625 .62935 .59161 .63933 .58871 .63438 .58334 Mtetra
.63438 .58334 .63933 .58871 .64934 .58581 .64442 .58041 Mtetra
.64442 .58041 .64934 .58581 .65939 .58289 .65449 .57748 Mtetra
.65449 .57748 .65939 .58289 .66947 .57996 .6646 .57453 Mtetra
.6646 .57453 .66947 .57996 .67959 .57703 .67475 .57158 Mtetra
.67475 .57158 .67959 .57703 .68975 .57408 .68493 .56861 Mtetra
.68493 .56861 .68975 .57408 .69995 .57112 .69515 .56563 Mtetra
.69515 .56563 .69995 .57112 .71018 .56815 .70541 .56264 Mtetra
.70541 .56264 .71018 .56815 .72044 .56517 .7157 .55965 Mtetra
.7157 .55965 .72044 .56517 .73075 .56218 .72603 .55664 Mtetra
.72603 .55664 .73075 .56218 .74109 .55918 .7364 .55361 Mtetra
.7364 .55361 .74109 .55918 .75147 .55617 .7468 .55058 Mtetra
.7468 .55058 .75147 .55617 .76189 .55315 .75725 .54754 Mtetra
.75725 .54754 .76189 .55315 .77234 .55012 .76773 .54449 Mtetra
.76773 .54449 .77234 .55012 .78284 .54707 .77825 .54142 Mtetra
.77825 .54142 .78284 .54707 .79337 .54401 .78881 .53834 Mtetra
.78881 .53834 .79337 .54401 .80394 .54095 .79941 .53526 Mtetra
.79941 .53526 .80394 .54095 .81455 .53787 .81005 .53216 Mtetra
.81005 .53216 .81455 .53787 .8252 .53478 .82072 .52905 Mtetra
.82072 .52905 .8252 .53478 .83589 .53168 .83144 .52592 Mtetra
.83144 .52592 .83589 .53168 .84661 .52857 .84219 .52279 Mtetra
.84219 .52279 .84661 .52857 .85738 .52544 .85299 .51964 Mtetra
.85299 .51964 .85738 .52544 .86819 .52231 .86383 .51649 Mtetra
.86383 .51649 .86819 .52231 .87903 .51916 .8747 .51332 Mtetra
.8747 .51332 .87903 .51916 .88992 .516 .88562 .51014 Mtetra
.88562 .51014 .88992 .516 .90085 .51283 .89658 .50694 Mtetra
.89658 .50694 .90085 .51283 .91182 .50965 .90758 .50374 Mtetra
.90758 .50374 .91182 .50965 .92283 .50645 .91862 .50052 Mtetra
.91862 .50052 .92283 .50645 .93388 .50325 .9297 .49729 Mtetra
.9297 .49729 .93388 .50325 .94497 .50003 .94082 .49405 Mtetra
.94082 .49405 .94497 .50003 .9561 .4968 .95198 .4908 Mtetra
.35253 .65894 .35813 .66383 .3672 .66119 .36162 .65628 Mtetra
.36162 .65628 .3672 .66119 .3763 .65854 .37074 .65362 Mtetra
.37074 .65362 .3763 .65854 .38544 .65587 .3799 .65094 Mtetra
.3799 .65094 .38544 .65587 .3946 .6532 .38908 .64825 Mtetra
.38908 .64825 .3946 .6532 .4038 .65052 .3983 .64555 Mtetra
.3983 .64555 .4038 .65052 .41303 .64784 .40755 .64285 Mtetra
.40755 .64285 .41303 .64784 .42229 .64514 .41683 .64013 Mtetra
.41683 .64013 .42229 .64514 .43158 .64243 .42614 .63741 Mtetra
.42614 .63741 .43158 .64243 .4409 .63971 .43548 .63467 Mtetra
.43548 .63467 .4409 .63971 .45026 .63699 .44486 .63193 Mtetra
.44486 .63193 .45026 .63699 .45965 .63425 .45427 .62918 Mtetra
.45427 .62918 .45965 .63425 .46907 .63151 .46371 .62641 Mtetra
.46371 .62641 .46907 .63151 .47853 .62875 .47319 .62364 Mtetra
.47319 .62364 .47853 .62875 .48801 .62599 .48269 .62086 Mtetra
.48269 .62086 .48801 .62599 .49753 .62321 .49224 .61807 Mtetra
.49224 .61807 .49753 .62321 .50709 .62043 .50181 .61527 Mtetra
.50181 .61527 .50709 .62043 .51667 .61764 .51142 .61245 Mtetra
.51142 .61245 .51667 .61764 .52629 .61483 .52106 .60963 Mtetra
.52106 .60963 .52629 .61483 .53595 .61202 .53074 .6068 Mtetra
.53074 .6068 .53595 .61202 .54563 .6092 .54045 .60396 Mtetra
.54045 .60396 .54563 .6092 .55536 .60636 .55019 .60111 Mtetra
.55019 .60111 .55536 .60636 .56511 .60352 .55997 .59825 Mtetra
.55997 .59825 .56511 .60352 .5749 .60067 .56978 .59538 Mtetra
.56978 .59538 .5749 .60067 .58473 .59781 .57963 .59249 Mtetra
.57963 .59249 .58473 .59781 .59459 .59493 .58952 .5896 Mtetra
.58952 .5896 .59459 .59493 .60448 .59205 .59944 .5867 Mtetra
.59944 .5867 .60448 .59205 .61441 .58916 .60939 .58379 Mtetra
.60939 .58379 .61441 .58916 .62438 .58625 .61938 .58087 Mtetra
.61938 .58087 .62438 .58625 .63438 .58334 .62941 .57793 Mtetra
.62941 .57793 .63438 .58334 .64442 .58041 .63947 .57499 Mtetra
.63947 .57499 .64442 .58041 .65449 .57748 .64957 .57203 Mtetra
.64957 .57203 .65449 .57748 .6646 .57453 .6597 .56907 Mtetra
.6597 .56907 .6646 .57453 .67475 .57158 .66987 .56609 Mtetra
.66987 .56609 .67475 .57158 .68493 .56861 .68008 .56311 Mtetra
.68008 .56311 .68493 .56861 .69515 .56563 .69032 .56011 Mtetra
.69032 .56011 .69515 .56563 .70541 .56264 .7006 .5571 Mtetra
.7006 .5571 .70541 .56264 .7157 .55965 .71092 .55408 Mtetra
.71092 .55408 .7157 .55965 .72603 .55664 .72128 .55105 Mtetra
.72128 .55105 .72603 .55664 .7364 .55361 .73168 .54801 Mtetra
.73168 .54801 .7364 .55361 .7468 .55058 .74211 .54496 Mtetra
.74211 .54496 .7468 .55058 .75725 .54754 .75258 .54189 Mtetra
.75258 .54189 .75725 .54754 .76773 .54449 .76309 .53882 Mtetra
.76309 .53882 .76773 .54449 .77825 .54142 .77364 .53573 Mtetra
.77364 .53573 .77825 .54142 .78881 .53834 .78422 .53263 Mtetra
.78422 .53263 .78881 .53834 .79941 .53526 .79485 .52952 Mtetra
.79485 .52952 .79941 .53526 .81005 .53216 .80551 .5264 Mtetra
.80551 .5264 .81005 .53216 .82072 .52905 .81622 .52327 Mtetra
.81622 .52327 .82072 .52905 .83144 .52592 .82696 .52013 Mtetra
.82696 .52013 .83144 .52592 .84219 .52279 .83775 .51697 Mtetra
.83775 .51697 .84219 .52279 .85299 .51964 .84857 .51381 Mtetra
.84857 .51381 .85299 .51964 .86383 .51649 .85944 .51063 Mtetra
.85944 .51063 .86383 .51649 .8747 .51332 .87034 .50744 Mtetra
.87034 .50744 .8747 .51332 .88562 .51014 .88129 .50424 Mtetra
.88129 .50424 .88562 .51014 .89658 .50694 .89227 .50102 Mtetra
.89227 .50102 .89658 .50694 .90758 .50374 .9033 .49779 Mtetra
.9033 .49779 .90758 .50374 .91862 .50052 .91437 .49455 Mtetra
.91437 .49455 .91862 .50052 .9297 .49729 .92549 .4913 Mtetra
.92549 .4913 .9297 .49729 .94082 .49405 .93664 .48804 Mtetra
.93664 .48804 .94082 .49405 .95198 .4908 .94784 .48476 Mtetra
.34689 .65403 .35253 .65894 .36162 .65628 .356 .65135 Mtetra
.356 .65135 .36162 .65628 .37074 .65362 .36515 .64867 Mtetra
.36515 .64867 .37074 .65362 .3799 .65094 .37432 .64597 Mtetra
.37432 .64597 .3799 .65094 .38908 .64825 .38352 .64327 Mtetra
.38352 .64327 .38908 .64825 .3983 .64555 .39276 .64055 Mtetra
.39276 .64055 .3983 .64555 .40755 .64285 .40203 .63783 Mtetra
.40203 .63783 .40755 .64285 .41683 .64013 .41133 .6351 Mtetra
.41133 .6351 .41683 .64013 .42614 .63741 .42066 .63235 Mtetra
.42066 .63235 .42614 .63741 .43548 .63467 .43003 .6296 Mtetra
.43003 .6296 .43548 .63467 .44486 .63193 .43942 .62684 Mtetra
.43942 .62684 .44486 .63193 .45427 .62918 .44885 .62407 Mtetra
.44885 .62407 .45427 .62918 .46371 .62641 .45832 .62129 Mtetra
.45832 .62129 .46371 .62641 .47319 .62364 .46781 .6185 Mtetra
.46781 .6185 .47319 .62364 .48269 .62086 .47734 .6157 Mtetra
.47734 .6157 .48269 .62086 .49224 .61807 .4869 .61289 Mtetra
.4869 .61289 .49224 .61807 .50181 .61527 .4965 .61007 Mtetra
.4965 .61007 .50181 .61527 .51142 .61245 .50613 .60724 Mtetra
.50613 .60724 .51142 .61245 .52106 .60963 .5158 .6044 Mtetra
.5158 .6044 .52106 .60963 .53074 .6068 .52549 .60155 Mtetra
.52549 .60155 .53074 .6068 .54045 .60396 .53523 .59869 Mtetra
.53523 .59869 .54045 .60396 .55019 .60111 .54499 .59582 Mtetra
.54499 .59582 .55019 .60111 .55997 .59825 .5548 .59294 Mtetra
.5548 .59294 .55997 .59825 .56978 .59538 .56463 .59005 Mtetra
.56463 .59005 .56978 .59538 .57963 .59249 .5745 .58715 Mtetra
.5745 .58715 .57963 .59249 .58952 .5896 .58441 .58424 Mtetra
.58441 .58424 .58952 .5896 .59944 .5867 .59435 .58132 Mtetra
.59435 .58132 .59944 .5867 .60939 .58379 .60433 .57838 Mtetra
.60433 .57838 .60939 .58379 .61938 .58087 .61435 .57544 Mtetra
.61435 .57544 .61938 .58087 .62941 .57793 .6244 .57249 Mtetra
.6244 .57249 .62941 .57793 .63947 .57499 .63448 .56952 Mtetra
.63448 .56952 .63947 .57499 .64957 .57203 .6446 .56655 Mtetra
.6446 .56655 .64957 .57203 .6597 .56907 .65476 .56357 Mtetra
.65476 .56357 .6597 .56907 .66987 .56609 .66496 .56057 Mtetra
.66496 .56057 .66987 .56609 .68008 .56311 .67519 .55756 Mtetra
.67519 .55756 .68008 .56311 .69032 .56011 .68546 .55455 Mtetra
.68546 .55455 .69032 .56011 .7006 .5571 .69577 .55152 Mtetra
.69577 .55152 .7006 .5571 .71092 .55408 .70612 .54848 Mtetra
.70612 .54848 .71092 .55408 .72128 .55105 .7165 .54543 Mtetra
.7165 .54543 .72128 .55105 .73168 .54801 .72692 .54236 Mtetra
.72692 .54236 .73168 .54801 .74211 .54496 .73738 .53929 Mtetra
.73738 .53929 .74211 .54496 .75258 .54189 .74788 .53621 Mtetra
.74788 .53621 .75258 .54189 .76309 .53882 .75841 .53311 Mtetra
.75841 .53311 .76309 .53882 .77364 .53573 .76899 .53 Mtetra
.76899 .53 .77364 .53573 .78422 .53263 .7796 .52688 Mtetra
.7796 .52688 .78422 .53263 .79485 .52952 .79026 .52375 Mtetra
.79026 .52375 .79485 .52952 .80551 .5264 .80095 .52061 Mtetra
.80095 .52061 .80551 .5264 .81622 .52327 .81168 .51746 Mtetra
.81168 .51746 .81622 .52327 .82696 .52013 .82245 .51429 Mtetra
.82245 .51429 .82696 .52013 .83775 .51697 .83327 .51112 Mtetra
.83327 .51112 .83775 .51697 .84857 .51381 .84412 .50793 Mtetra
.84412 .50793 .84857 .51381 .85944 .51063 .85502 .50473 Mtetra
.85502 .50473 .85944 .51063 .87034 .50744 .86595 .50152 Mtetra
.86595 .50152 .87034 .50744 .88129 .50424 .87693 .49829 Mtetra
.87693 .49829 .88129 .50424 .89227 .50102 .88794 .49506 Mtetra
.88794 .49506 .89227 .50102 .9033 .49779 .899 .49181 Mtetra
.899 .49181 .9033 .49779 .91437 .49455 .9101 .48854 Mtetra
.9101 .48854 .91437 .49455 .92549 .4913 .92125 .48527 Mtetra
.92125 .48527 .92549 .4913 .93664 .48804 .93243 .48198 Mtetra
.93243 .48198 .93664 .48804 .94784 .48476 .94366 .47868 Mtetra
.34122 .64908 .34689 .65403 .356 .65135 .35035 .64639 Mtetra
.35035 .64639 .356 .65135 .36515 .64867 .35951 .64369 Mtetra
.35951 .64369 .36515 .64867 .37432 .64597 .36871 .64097 Mtetra
.656 .752 .92 r
.36871 .64097 .37432 .64597 .38352 .64327 .37793 .63825 Mtetra
.37793 .63825 .38352 .64327 .39276 .64055 .38719 .63552 Mtetra
.38719 .63552 .39276 .64055 .40203 .63783 .39647 .63278 Mtetra
.39647 .63278 .40203 .63783 .41133 .6351 .40579 .63003 Mtetra
.40579 .63003 .41133 .6351 .42066 .63235 .41515 .62727 Mtetra
.41515 .62727 .42066 .63235 .43003 .6296 .42453 .6245 Mtetra
.656 .751 .92 r
.42453 .6245 .43003 .6296 .43942 .62684 .43395 .62172 Mtetra
.43395 .62172 .43942 .62684 .44885 .62407 .4434 .61893 Mtetra
.4434 .61893 .44885 .62407 .45832 .62129 .45289 .61613 Mtetra
.45289 .61613 .45832 .62129 .46781 .6185 .4624 .61332 Mtetra
.4624 .61332 .46781 .6185 .47734 .6157 .47195 .6105 Mtetra
.47195 .6105 .47734 .6157 .4869 .61289 .48154 .60767 Mtetra
.48154 .60767 .4869 .61289 .4965 .61007 .49116 .60484 Mtetra
.49116 .60484 .4965 .61007 .50613 .60724 .50081 .60199 Mtetra
.50081 .60199 .50613 .60724 .5158 .6044 .5105 .59913 Mtetra
.5105 .59913 .5158 .6044 .52549 .60155 .52022 .59626 Mtetra
.52022 .59626 .52549 .60155 .53523 .59869 .52997 .59338 Mtetra
.52997 .59338 .53523 .59869 .54499 .59582 .53976 .59049 Mtetra
.53976 .59049 .54499 .59582 .5548 .59294 .54959 .58759 Mtetra
.54959 .58759 .5548 .59294 .56463 .59005 .55945 .58469 Mtetra
.55945 .58469 .56463 .59005 .5745 .58715 .56934 .58177 Mtetra
.56934 .58177 .5745 .58715 .58441 .58424 .57927 .57884 Mtetra
.57927 .57884 .58441 .58424 .59435 .58132 .58924 .57589 Mtetra
.58924 .57589 .59435 .58132 .60433 .57838 .59924 .57294 Mtetra
.59924 .57294 .60433 .57838 .61435 .57544 .60928 .56998 Mtetra
.60928 .56998 .61435 .57544 .6244 .57249 .61935 .56701 Mtetra
.61935 .56701 .6244 .57249 .63448 .56952 .62946 .56403 Mtetra
.62946 .56403 .63448 .56952 .6446 .56655 .63961 .56103 Mtetra
.63961 .56103 .6446 .56655 .65476 .56357 .64979 .55803 Mtetra
.64979 .55803 .65476 .56357 .66496 .56057 .66002 .55501 Mtetra
.66002 .55501 .66496 .56057 .67519 .55756 .67027 .55198 Mtetra
.67027 .55198 .67519 .55756 .68546 .55455 .68057 .54895 Mtetra
.68057 .54895 .68546 .55455 .69577 .55152 .6909 .5459 Mtetra
.6909 .5459 .69577 .55152 .70612 .54848 .70127 .54284 Mtetra
.70127 .54284 .70612 .54848 .7165 .54543 .71168 .53976 Mtetra
.71168 .53976 .7165 .54543 .72692 .54236 .72213 .53668 Mtetra
.72213 .53668 .72692 .54236 .73738 .53929 .73262 .53359 Mtetra
.73262 .53359 .73738 .53929 .74788 .53621 .74314 .53048 Mtetra
.74314 .53048 .74788 .53621 .75841 .53311 .75371 .52737 Mtetra
.75371 .52737 .75841 .53311 .76899 .53 .76431 .52424 Mtetra
.76431 .52424 .76899 .53 .7796 .52688 .77495 .5211 Mtetra
.77495 .5211 .7796 .52688 .79026 .52375 .78563 .51795 Mtetra
.78563 .51795 .79026 .52375 .80095 .52061 .79635 .51478 Mtetra
.79635 .51478 .80095 .52061 .81168 .51746 .80711 .51161 Mtetra
.80711 .51161 .81168 .51746 .82245 .51429 .81792 .50842 Mtetra
.81792 .50842 .82245 .51429 .83327 .51112 .82876 .50522 Mtetra
.82876 .50522 .83327 .51112 .84412 .50793 .83964 .50201 Mtetra
.83964 .50201 .84412 .50793 .85502 .50473 .85056 .49879 Mtetra
.85056 .49879 .85502 .50473 .86595 .50152 .86153 .49556 Mtetra
.656 .752 .92 r
.86153 .49556 .86595 .50152 .87693 .49829 .87253 .49231 Mtetra
.87253 .49231 .87693 .49829 .88794 .49506 .88358 .48905 Mtetra
.88358 .48905 .88794 .49506 .899 .49181 .89467 .48578 Mtetra
.89467 .48578 .899 .49181 .9101 .48854 .9058 .48249 Mtetra
.9058 .48249 .9101 .48854 .92125 .48527 .91698 .47919 Mtetra
.91698 .47919 .92125 .48527 .93243 .48198 .92819 .47588 Mtetra
.656 .751 .92 r
.92819 .47588 .93243 .48198 .94366 .47868 .93945 .47256 Mtetra
.33552 .6441 .34122 .64908 .35035 .64639 .34466 .64139 Mtetra
.34466 .64139 .35035 .64639 .35951 .64369 .35384 .63867 Mtetra
.656 .752 .92 r
.35384 .63867 .35951 .64369 .36871 .64097 .36306 .63595 Mtetra
.36306 .63595 .36871 .64097 .37793 .63825 .3723 .63321 Mtetra
.3723 .63321 .37793 .63825 .38719 .63552 .38158 .63046 Mtetra
.38158 .63046 .38719 .63552 .39647 .63278 .39089 .6277 Mtetra
.39089 .6277 .39647 .63278 .40579 .63003 .40023 .62493 Mtetra
.40023 .62493 .40579 .63003 .41515 .62727 .4096 .62215 Mtetra
.4096 .62215 .41515 .62727 .42453 .6245 .41901 .61937 Mtetra
.41901 .61937 .42453 .6245 .43395 .62172 .42844 .61657 Mtetra
.42844 .61657 .43395 .62172 .4434 .61893 .43792 .61376 Mtetra
.43792 .61376 .4434 .61893 .45289 .61613 .44742 .61094 Mtetra
.656 .751 .92 r
.44742 .61094 .45289 .61613 .4624 .61332 .45696 .60811 Mtetra
.45696 .60811 .4624 .61332 .47195 .6105 .46653 .60527 Mtetra
.46653 .60527 .47195 .6105 .48154 .60767 .47614 .60243 Mtetra
.47614 .60243 .48154 .60767 .49116 .60484 .48578 .59957 Mtetra
.48578 .59957 .49116 .60484 .50081 .60199 .49545 .5967 Mtetra
.49545 .5967 .50081 .60199 .5105 .59913 .50516 .59383 Mtetra
.50516 .59383 .5105 .59913 .52022 .59626 .5149 .59094 Mtetra
.5149 .59094 .52022 .59626 .52997 .59338 .52468 .58804 Mtetra
.52468 .58804 .52997 .59338 .53976 .59049 .5345 .58513 Mtetra
.5345 .58513 .53976 .59049 .54959 .58759 .54434 .58222 Mtetra
.54434 .58222 .54959 .58759 .55945 .58469 .55423 .57929 Mtetra
.55423 .57929 .55945 .58469 .56934 .58177 .56414 .57635 Mtetra
.56414 .57635 .56934 .58177 .57927 .57884 .5741 .5734 Mtetra
.5741 .5734 .57927 .57884 .58924 .57589 .58409 .57044 Mtetra
.58409 .57044 .58924 .57589 .59924 .57294 .59412 .56747 Mtetra
.59412 .56747 .59924 .57294 .60928 .56998 .60418 .56449 Mtetra
.60418 .56449 .60928 .56998 .61935 .56701 .61428 .56149 Mtetra
.61428 .56149 .61935 .56701 .62946 .56403 .62441 .55849 Mtetra
.62441 .55849 .62946 .56403 .63961 .56103 .63458 .55547 Mtetra
.63458 .55547 .63961 .56103 .64979 .55803 .64479 .55245 Mtetra
.64479 .55245 .64979 .55803 .66002 .55501 .65504 .54941 Mtetra
.65504 .54941 .66002 .55501 .67027 .55198 .66532 .54637 Mtetra
.66532 .54637 .67027 .55198 .68057 .54895 .67564 .54331 Mtetra
.67564 .54331 .68057 .54895 .6909 .5459 .686 .54024 Mtetra
.686 .54024 .6909 .5459 .70127 .54284 .6964 .53716 Mtetra
.6964 .53716 .70127 .54284 .71168 .53976 .70684 .53406 Mtetra
.70684 .53406 .71168 .53976 .72213 .53668 .71731 .53096 Mtetra
.71731 .53096 .72213 .53668 .73262 .53359 .72782 .52785 Mtetra
.72782 .52785 .73262 .53359 .74314 .53048 .73838 .52472 Mtetra
.73838 .52472 .74314 .53048 .75371 .52737 .74897 .52158 Mtetra
.74897 .52158 .75371 .52737 .76431 .52424 .7596 .51843 Mtetra
.7596 .51843 .76431 .52424 .77495 .5211 .77027 .51527 Mtetra
.77027 .51527 .77495 .5211 .78563 .51795 .78098 .5121 Mtetra
.78098 .5121 .78563 .51795 .79635 .51478 .79173 .50891 Mtetra
.79173 .50891 .79635 .51478 .80711 .51161 .80252 .50572 Mtetra
.80252 .50572 .80711 .51161 .81792 .50842 .81335 .50251 Mtetra
.81335 .50251 .81792 .50842 .82876 .50522 .82422 .49929 Mtetra
.82422 .49929 .82876 .50522 .83964 .50201 .83513 .49606 Mtetra
.656 .752 .92 r
.83513 .49606 .83964 .50201 .85056 .49879 .84608 .49281 Mtetra
.84608 .49281 .85056 .49879 .86153 .49556 .85708 .48956 Mtetra
.85708 .48956 .86153 .49556 .87253 .49231 .86811 .48629 Mtetra
.86811 .48629 .87253 .49231 .88358 .48905 .87919 .48301 Mtetra
.87919 .48301 .88358 .48905 .89467 .48578 .89031 .47971 Mtetra
.89031 .47971 .89467 .48578 .9058 .48249 .90147 .4764 Mtetra
.90147 .4764 .9058 .48249 .91698 .47919 .91268 .47308 Mtetra
.91268 .47308 .91698 .47919 .92819 .47588 .92392 .46974 Mtetra
.92392 .46974 .92819 .47588 .93945 .47256 .93521 .46639 Mtetra
.655 .751 .92 r
.32977 .63908 .33552 .6441 .34466 .64139 .33894 .63637 Mtetra
.655 .751 .921 r
.33894 .63637 .34466 .64139 .35384 .63867 .34814 .63364 Mtetra
.655 .752 .921 r
.34814 .63364 .35384 .63867 .36306 .63595 .35737 .63089 Mtetra
.656 .752 .921 r
.35737 .63089 .36306 .63595 .3723 .63321 .36664 .62814 Mtetra
.36664 .62814 .3723 .63321 .38158 .63046 .37593 .62538 Mtetra
.37593 .62538 .38158 .63046 .39089 .6277 .38526 .6226 Mtetra
.38526 .6226 .39089 .6277 .40023 .62493 .39462 .61981 Mtetra
.39462 .61981 .40023 .62493 .4096 .62215 .40401 .61701 Mtetra
.656 .752 .92 r
.40401 .61701 .4096 .62215 .41901 .61937 .41344 .6142 Mtetra
.41344 .6142 .41901 .61937 .42844 .61657 .4229 .61138 Mtetra
.4229 .61138 .42844 .61657 .43792 .61376 .43239 .60855 Mtetra
.43239 .60855 .43792 .61376 .44742 .61094 .44192 .60572 Mtetra
.44192 .60572 .44742 .61094 .45696 .60811 .45148 .60287 Mtetra
.656 .751 .92 r
.45148 .60287 .45696 .60811 .46653 .60527 .46108 .60001 Mtetra
.46108 .60001 .46653 .60527 .47614 .60243 .4707 .59715 Mtetra
.4707 .59715 .47614 .60243 .48578 .59957 .48037 .59427 Mtetra
.48037 .59427 .48578 .59957 .49545 .5967 .49006 .59138 Mtetra
.49006 .59138 .49545 .5967 .50516 .59383 .49979 .58849 Mtetra
.49979 .58849 .50516 .59383 .5149 .59094 .50956 .58558 Mtetra
.50956 .58558 .5149 .59094 .52468 .58804 .51936 .58267 Mtetra
.51936 .58267 .52468 .58804 .5345 .58513 .52919 .57974 Mtetra
.52919 .57974 .5345 .58513 .54434 .58222 .53907 .5768 Mtetra
.53907 .5768 .54434 .58222 .55423 .57929 .54897 .57385 Mtetra
.54897 .57385 .55423 .57929 .56414 .57635 .55891 .57089 Mtetra
.55891 .57089 .56414 .57635 .5741 .5734 .56889 .56792 Mtetra
.56889 .56792 .5741 .5734 .58409 .57044 .57891 .56494 Mtetra
.57891 .56494 .58409 .57044 .59412 .56747 .58896 .56195 Mtetra
.58896 .56195 .59412 .56747 .60418 .56449 .59904 .55895 Mtetra
.59904 .55895 .60418 .56449 .61428 .56149 .60917 .55594 Mtetra
.60917 .55594 .61428 .56149 .62441 .55849 .61933 .55292 Mtetra
.61933 .55292 .62441 .55849 .63458 .55547 .62952 .54988 Mtetra
.62952 .54988 .63458 .55547 .64479 .55245 .63976 .54684 Mtetra
.63976 .54684 .64479 .55245 .65504 .54941 .65003 .54378 Mtetra
.65003 .54378 .65504 .54941 .66532 .54637 .66034 .54071 Mtetra
.66034 .54071 .66532 .54637 .67564 .54331 .67069 .53763 Mtetra
.67069 .53763 .67564 .54331 .686 .54024 .68107 .53454 Mtetra
.68107 .53454 .686 .54024 .6964 .53716 .69149 .53144 Mtetra
.69149 .53144 .6964 .53716 .70684 .53406 .70196 .52833 Mtetra
.70196 .52833 .70684 .53406 .71731 .53096 .71246 .5252 Mtetra
.71246 .5252 .71731 .53096 .72782 .52785 .723 .52206 Mtetra
.723 .52206 .72782 .52785 .73838 .52472 .73358 .51892 Mtetra
.73358 .51892 .73838 .52472 .74897 .52158 .74419 .51576 Mtetra
.74419 .51576 .74897 .52158 .7596 .51843 .75485 .51259 Mtetra
.75485 .51259 .7596 .51843 .77027 .51527 .76555 .5094 Mtetra
.76555 .5094 .77027 .51527 .78098 .5121 .77629 .50621 Mtetra
.77629 .50621 .78098 .5121 .79173 .50891 .78707 .503 Mtetra
.78707 .503 .79173 .50891 .80252 .50572 .79788 .49978 Mtetra
.79788 .49978 .80252 .50572 .81335 .50251 .80874 .49656 Mtetra
.656 .752 .92 r
.80874 .49656 .81335 .50251 .82422 .49929 .81964 .49332 Mtetra
.81964 .49332 .82422 .49929 .83513 .49606 .83059 .49006 Mtetra
.656 .752 .921 r
.83059 .49006 .83513 .49606 .84608 .49281 .84157 .4868 Mtetra
.84157 .4868 .84608 .49281 .85708 .48956 .85259 .48352 Mtetra
.85259 .48352 .85708 .48956 .86811 .48629 .86366 .48023 Mtetra
.86366 .48023 .86811 .48629 .87919 .48301 .87477 .47693 Mtetra
.87477 .47693 .87919 .48301 .89031 .47971 .88592 .47361 Mtetra
.88592 .47361 .89031 .47971 .90147 .4764 .89711 .47027 Mtetra
.656 .752 .92 r
.89711 .47027 .90147 .4764 .91268 .47308 .90835 .46692 Mtetra
.90835 .46692 .91268 .47308 .92392 .46974 .91962 .46356 Mtetra
.91962 .46356 .92392 .46974 .93521 .46639 .93095 .46018 Mtetra
.655 .751 .921 r
.32399 .63404 .32977 .63908 .33894 .63637 .33318 .63131 Mtetra
.655 .752 .921 r
.33318 .63131 .33894 .63637 .34814 .63364 .3424 .62857 Mtetra
.3424 .62857 .34814 .63364 .35737 .63089 .35165 .62581 Mtetra
.35165 .62581 .35737 .63089 .36664 .62814 .36093 .62305 Mtetra
.656 .752 .921 r
.36093 .62305 .36664 .62814 .37593 .62538 .37025 .62027 Mtetra
.37025 .62027 .37593 .62538 .38526 .6226 .3796 .61747 Mtetra
.3796 .61747 .38526 .6226 .39462 .61981 .38898 .61466 Mtetra
.38898 .61466 .39462 .61981 .40401 .61701 .39839 .61184 Mtetra
.39839 .61184 .40401 .61701 .41344 .6142 .40784 .60901 Mtetra
.40784 .60901 .41344 .6142 .4229 .61138 .41732 .60617 Mtetra
.41732 .60617 .4229 .61138 .43239 .60855 .42684 .60332 Mtetra
.656 .752 .92 r
.42684 .60332 .43239 .60855 .44192 .60572 .43638 .60046 Mtetra
.43638 .60046 .44192 .60572 .45148 .60287 .44597 .59759 Mtetra
.44597 .59759 .45148 .60287 .46108 .60001 .45558 .59472 Mtetra
.45558 .59472 .46108 .60001 .4707 .59715 .46523 .59183 Mtetra
.656 .751 .92 r
.46523 .59183 .4707 .59715 .48037 .59427 .47492 .58894 Mtetra
.47492 .58894 .48037 .59427 .49006 .59138 .48463 .58603 Mtetra
.48463 .58603 .49006 .59138 .49979 .58849 .49439 .58312 Mtetra
.49439 .58312 .49979 .58849 .50956 .58558 .50418 .58019 Mtetra
.50418 .58019 .50956 .58558 .51936 .58267 .514 .57725 Mtetra
.514 .57725 .51936 .58267 .52919 .57974 .52386 .57431 Mtetra
.52386 .57431 .52919 .57974 .53907 .5768 .53375 .57135 Mtetra
.53375 .57135 .53907 .5768 .54897 .57385 .54368 .56838 Mtetra
.54368 .56838 .54897 .57385 .55891 .57089 .55365 .5654 Mtetra
.55365 .5654 .55891 .57089 .56889 .56792 .56365 .56241 Mtetra
.56365 .56241 .56889 .56792 .57891 .56494 .57369 .55941 Mtetra
.57369 .55941 .57891 .56494 .58896 .56195 .58376 .5564 Mtetra
.58376 .5564 .58896 .56195 .59904 .55895 .59387 .55338 Mtetra
.59387 .55338 .59904 .55895 .60917 .55594 .60402 .55035 Mtetra
.60402 .55035 .60917 .55594 .61933 .55292 .61421 .5473 Mtetra
.61421 .5473 .61933 .55292 .62952 .54988 .62443 .54425 Mtetra
.62443 .54425 .62952 .54988 .63976 .54684 .63469 .54118 Mtetra
.63469 .54118 .63976 .54684 .65003 .54378 .64498 .53811 Mtetra
.64498 .53811 .65003 .54378 .66034 .54071 .65532 .53502 Mtetra
.65532 .53502 .66034 .54071 .67069 .53763 .66569 .53192 Mtetra
.66569 .53192 .67069 .53763 .68107 .53454 .6761 .52881 Mtetra
.6761 .52881 .68107 .53454 .69149 .53144 .68655 .52568 Mtetra
.68655 .52568 .69149 .53144 .70196 .52833 .69704 .52255 Mtetra
.69704 .52255 .70196 .52833 .71246 .5252 .70757 .5194 Mtetra
.70757 .5194 .71246 .5252 .723 .52206 .71814 .51624 Mtetra
.71814 .51624 .723 .52206 .73358 .51892 .72874 .51307 Mtetra
.72874 .51307 .73358 .51892 .74419 .51576 .73939 .50989 Mtetra
.73939 .50989 .74419 .51576 .75485 .51259 .75008 .5067 Mtetra
.75008 .5067 .75485 .51259 .76555 .5094 .7608 .5035 Mtetra
.7608 .5035 .76555 .5094 .77629 .50621 .77157 .50028 Mtetra
.77157 .50028 .77629 .50621 .78707 .503 .78237 .49705 Mtetra
.78237 .49705 .78707 .503 .79788 .49978 .79322 .49382 Mtetra
.656 .752 .921 r
.79322 .49382 .79788 .49978 .80874 .49656 .80411 .49057 Mtetra
.655 .752 .921 r
.80411 .49057 .80874 .49656 .81964 .49332 .81504 .48731 Mtetra
.81504 .48731 .81964 .49332 .83059 .49006 .82601 .48404 Mtetra
.82601 .48404 .83059 .49006 .84157 .4868 .83703 .48075 Mtetra
.83703 .48075 .84157 .4868 .85259 .48352 .84808 .47746 Mtetra
.656 .752 .921 r
.84808 .47746 .85259 .48352 .86366 .48023 .85918 .47415 Mtetra
.85918 .47415 .86366 .48023 .87477 .47693 .87032 .47082 Mtetra
.87032 .47082 .87477 .47693 .88592 .47361 .8815 .46747 Mtetra
.8815 .46747 .88592 .47361 .89711 .47027 .89272 .46411 Mtetra
.89272 .46411 .89711 .47027 .90835 .46692 .90399 .46073 Mtetra
.656 .752 .92 r
.90399 .46073 .90835 .46692 .91962 .46356 .9153 .45734 Mtetra
.9153 .45734 .91962 .46356 .93095 .46018 .92665 .45393 Mtetra
.655 .751 .921 r
.31818 .62896 .32399 .63404 .33318 .63131 .32738 .62623 Mtetra
.655 .752 .921 r
.32738 .62623 .33318 .63131 .3424 .62857 .33662 .62348 Mtetra
.33662 .62348 .3424 .62857 .35165 .62581 .34589 .62071 Mtetra
.34589 .62071 .35165 .62581 .36093 .62305 .35519 .61794 Mtetra
.655 .753 .921 r
.35519 .61794 .36093 .62305 .37025 .62027 .36453 .61514 Mtetra
.656 .753 .921 r
.36453 .61514 .37025 .62027 .3796 .61747 .3739 .61233 Mtetra
.3739 .61233 .3796 .61747 .38898 .61466 .3833 .6095 Mtetra
.3833 .6095 .38898 .61466 .39839 .61184 .39274 .60666 Mtetra
.39274 .60666 .39839 .61184 .40784 .60901 .4022 .6038 Mtetra
.4022 .6038 .40784 .60901 .41732 .60617 .41171 .60094 Mtetra
.656 .752 .921 r
.41171 .60094 .41732 .60617 .42684 .60332 .42124 .59806 Mtetra
.42124 .59806 .42684 .60332 .43638 .60046 .43081 .59518 Mtetra
.656 .752 .92 r
.43081 .59518 .43638 .60046 .44597 .59759 .44042 .59229 Mtetra
.44042 .59229 .44597 .59759 .45558 .59472 .45005 .58939 Mtetra
.45005 .58939 .45558 .59472 .46523 .59183 .45972 .58648 Mtetra
.45972 .58648 .46523 .59183 .47492 .58894 .46943 .58357 Mtetra
.656 .751 .92 r
.46943 .58357 .47492 .58894 .48463 .58603 .47917 .58064 Mtetra
.47917 .58064 .48463 .58603 .49439 .58312 .48895 .57771 Mtetra
.48895 .57771 .49439 .58312 .50418 .58019 .49876 .57476 Mtetra
.49876 .57476 .50418 .58019 .514 .57725 .5086 .57181 Mtetra
.5086 .57181 .514 .57725 .52386 .57431 .51849 .56884 Mtetra
.51849 .56884 .52386 .57431 .53375 .57135 .5284 .56586 Mtetra
.5284 .56586 .53375 .57135 .54368 .56838 .53836 .56288 Mtetra
.53836 .56288 .54368 .56838 .55365 .5654 .54835 .55988 Mtetra
.54835 .55988 .55365 .5654 .56365 .56241 .55837 .55687 Mtetra
.55837 .55687 .56365 .56241 .57369 .55941 .56843 .55385 Mtetra
.56843 .55385 .57369 .55941 .58376 .5564 .57853 .55082 Mtetra
.57853 .55082 .58376 .5564 .59387 .55338 .58867 .54777 Mtetra
.58867 .54777 .59387 .55338 .60402 .55035 .59884 .54472 Mtetra
.59884 .54472 .60402 .55035 .61421 .5473 .60905 .54166 Mtetra
.60905 .54166 .61421 .5473 .62443 .54425 .6193 .53858 Mtetra
.6193 .53858 .62443 .54425 .63469 .54118 .62958 .53549 Mtetra
.62958 .53549 .63469 .54118 .64498 .53811 .63991 .53239 Mtetra
.63991 .53239 .64498 .53811 .65532 .53502 .65027 .52928 Mtetra
.65027 .52928 .65532 .53502 .66569 .53192 .66067 .52616 Mtetra
.66067 .52616 .66569 .53192 .6761 .52881 .6711 .52303 Mtetra
.6711 .52303 .6761 .52881 .68655 .52568 .68158 .51989 Mtetra
.68158 .51989 .68655 .52568 .69704 .52255 .6921 .51673 Mtetra
.6921 .51673 .69704 .52255 .70757 .5194 .70265 .51356 Mtetra
.70265 .51356 .70757 .5194 .71814 .51624 .71324 .51038 Mtetra
.71324 .51038 .71814 .51624 .72874 .51307 .72388 .50719 Mtetra
.72388 .50719 .72874 .51307 .73939 .50989 .73455 .50399 Mtetra
.73455 .50399 .73939 .50989 .75008 .5067 .74527 .50077 Mtetra
.74527 .50077 .75008 .5067 .7608 .5035 .75602 .49755 Mtetra
.75602 .49755 .7608 .5035 .77157 .50028 .76681 .49431 Mtetra
.76681 .49431 .77157 .50028 .78237 .49705 .77765 .49107 Mtetra
.655 .752 .921 r
.77765 .49107 .78237 .49705 .79322 .49382 .78853 .48781 Mtetra
.78853 .48781 .79322 .49382 .80411 .49057 .79945 .48454 Mtetra
.79945 .48454 .80411 .49057 .81504 .48731 .81041 .48127 Mtetra
.81041 .48127 .81504 .48731 .82601 .48404 .82141 .47798 Mtetra
.82141 .47798 .82601 .48404 .83703 .48075 .83245 .47468 Mtetra
.83245 .47468 .83703 .48075 .84808 .47746 .84354 .47136 Mtetra
.655 .753 .921 r
.84354 .47136 .84808 .47746 .85918 .47415 .85466 .46803 Mtetra
.656 .753 .921 r
.85466 .46803 .85918 .47415 .87032 .47082 .86583 .46468 Mtetra
.86583 .46468 .87032 .47082 .8815 .46747 .87705 .46131 Mtetra
.87705 .46131 .8815 .46747 .89272 .46411 .8883 .45791 Mtetra
.8883 .45791 .89272 .46411 .90399 .46073 .8996 .4545 Mtetra
.657 .753 .921 r
.8996 .4545 .90399 .46073 .9153 .45734 .91094 .45107 Mtetra
.657 .752 .92 r
.91094 .45107 .9153 .45734 .92665 .45393 .92232 .44763 Mtetra
.654 .751 .921 r
.31232 .62385 .31818 .62896 .32738 .62623 .32155 .62112 Mtetra
.654 .752 .921 r
.32155 .62112 .32738 .62623 .33662 .62348 .3308 .61837 Mtetra
.654 .752 .922 r
.3308 .61837 .33662 .62348 .34589 .62071 .34009 .6156 Mtetra
.655 .753 .922 r
.34009 .6156 .34589 .62071 .35519 .61794 .34941 .61281 Mtetra
.34941 .61281 .35519 .61794 .36453 .61514 .35877 .61 Mtetra
.655 .754 .922 r
.35877 .61 .36453 .61514 .3739 .61233 .36816 .60718 Mtetra
.656 .754 .922 r
.36816 .60718 .3739 .61233 .3833 .6095 .37758 .60433 Mtetra
.37758 .60433 .3833 .6095 .39274 .60666 .38704 .60146 Mtetra
.657 .754 .922 r
.38704 .60146 .39274 .60666 .4022 .6038 .39653 .59858 Mtetra
.657 .754 .921 r
.39653 .59858 .4022 .6038 .41171 .60094 .40605 .59569 Mtetra
.657 .753 .921 r
.40605 .59569 .41171 .60094 .42124 .59806 .41561 .59278 Mtetra
.41561 .59278 .42124 .59806 .43081 .59518 .4252 .58987 Mtetra
.656 .752 .921 r
.4252 .58987 .43081 .59518 .44042 .59229 .43483 .58696 Mtetra
.43483 .58696 .44042 .59229 .45005 .58939 .44449 .58403 Mtetra
.656 .752 .92 r
.44449 .58403 .45005 .58939 .45972 .58648 .45418 .5811 Mtetra
.45418 .5811 .45972 .58648 .46943 .58357 .46391 .57817 Mtetra
.46391 .57817 .46943 .58357 .47917 .58064 .47367 .57522 Mtetra
.47367 .57522 .47917 .58064 .48895 .57771 .48347 .57226 Mtetra
.656 .751 .92 r
.48347 .57226 .48895 .57771 .49876 .57476 .4933 .5693 Mtetra
.4933 .5693 .49876 .57476 .5086 .57181 .50317 .56632 Mtetra
.50317 .56632 .5086 .57181 .51849 .56884 .51308 .56334 Mtetra
.51308 .56334 .51849 .56884 .5284 .56586 .52302 .56034 Mtetra
.52302 .56034 .5284 .56586 .53836 .56288 .533 .55733 Mtetra
.533 .55733 .53836 .56288 .54835 .55988 .54301 .55431 Mtetra
.54301 .55431 .54835 .55988 .55837 .55687 .55306 .55128 Mtetra
.55306 .55128 .55837 .55687 .56843 .55385 .56314 .54824 Mtetra
.56314 .54824 .56843 .55385 .57853 .55082 .57327 .54519 Mtetra
.57327 .54519 .57853 .55082 .58867 .54777 .58343 .54213 Mtetra
.58343 .54213 .58867 .54777 .59884 .54472 .59363 .53905 Mtetra
.59363 .53905 .59884 .54472 .60905 .54166 .60386 .53597 Mtetra
.60386 .53597 .60905 .54166 .6193 .53858 .61413 .53287 Mtetra
.61413 .53287 .6193 .53858 .62958 .53549 .62444 .52976 Mtetra
.62444 .52976 .62958 .53549 .63991 .53239 .63479 .52664 Mtetra
.63479 .52664 .63991 .53239 .65027 .52928 .64518 .52351 Mtetra
.64518 .52351 .65027 .52928 .66067 .52616 .6556 .52037 Mtetra
.6556 .52037 .66067 .52616 .6711 .52303 .66607 .51722 Mtetra
.66607 .51722 .6711 .52303 .68158 .51989 .67657 .51405 Mtetra
.67657 .51405 .68158 .51989 .6921 .51673 .68711 .51087 Mtetra
.68711 .51087 .6921 .51673 .70265 .51356 .6977 .50768 Mtetra
.6977 .50768 .70265 .51356 .71324 .51038 .70832 .50448 Mtetra
.70832 .50448 .71324 .51038 .72388 .50719 .71898 .50127 Mtetra
.71898 .50127 .72388 .50719 .73455 .50399 .72968 .49804 Mtetra
.72968 .49804 .73455 .50399 .74527 .50077 .74042 .49481 Mtetra
.74042 .49481 .74527 .50077 .75602 .49755 .75121 .49156 Mtetra
.655 .752 .921 r
.75121 .49156 .75602 .49755 .76681 .49431 .76203 .48831 Mtetra
.76203 .48831 .76681 .49431 .77765 .49107 .77289 .48505 Mtetra
.77289 .48505 .77765 .49107 .78853 .48781 .7838 .48178 Mtetra
.7838 .48178 .78853 .48781 .79945 .48454 .79475 .4785 Mtetra
.79475 .4785 .79945 .48454 .81041 .48127 .80574 .47521 Mtetra
.655 .753 .922 r
.80574 .47521 .81041 .48127 .82141 .47798 .81677 .4719 Mtetra
.81677 .4719 .82141 .47798 .83245 .47468 .82785 .46859 Mtetra
.82785 .46859 .83245 .47468 .84354 .47136 .83896 .46526 Mtetra
.655 .754 .922 r
.83896 .46526 .84354 .47136 .85466 .46803 .85012 .4619 Mtetra
.656 .754 .922 r
.85012 .4619 .85466 .46803 .86583 .46468 .86132 .45852 Mtetra
.86132 .45852 .86583 .46468 .87705 .46131 .87257 .45512 Mtetra
.657 .754 .922 r
.87257 .45512 .87705 .46131 .8883 .45791 .88385 .45169 Mtetra
.657 .754 .921 r
.88385 .45169 .8883 .45791 .8996 .4545 .89518 .44824 Mtetra
.657 .753 .921 r
.89518 .44824 .8996 .4545 .91094 .45107 .90655 .44477 Mtetra
.657 .753 .92 r
.90655 .44477 .91094 .45107 .92232 .44763 .91796 .44128 Mtetra
.653 .751 .922 r
.30643 .61871 .31232 .62385 .32155 .62112 .31567 .61598 Mtetra
.653 .752 .922 r
.31567 .61598 .32155 .62112 .3308 .61837 .32495 .61324 Mtetra
.653 .753 .923 r
.32495 .61324 .3308 .61837 .34009 .6156 .33426 .61047 Mtetra
.654 .754 .923 r
.33426 .61047 .34009 .6156 .34941 .61281 .3436 .60769 Mtetra
.3436 .60769 .34941 .61281 .35877 .61 .35297 .60487 Mtetra
.655 .755 .923 r
.35297 .60487 .35877 .61 .36816 .60718 .36238 .60203 Mtetra
.656 .755 .923 r
.36238 .60203 .36816 .60718 .37758 .60433 .37183 .59916 Mtetra
.656 .756 .923 r
.37183 .59916 .37758 .60433 .38704 .60146 .3813 .59627 Mtetra
.657 .755 .923 r
.3813 .59627 .38704 .60146 .39653 .59858 .39082 .59336 Mtetra
.657 .755 .922 r
.39082 .59336 .39653 .59858 .40605 .59569 .40036 .59043 Mtetra
.40036 .59043 .40605 .59569 .41561 .59278 .40994 .5875 Mtetra
.657 .754 .921 r
.40994 .5875 .41561 .59278 .4252 .58987 .41955 .58455 Mtetra
.657 .753 .921 r
.41955 .58455 .4252 .58987 .43483 .58696 .4292 .5816 Mtetra
.4292 .5816 .43483 .58696 .44449 .58403 .43888 .57865 Mtetra
.656 .752 .921 r
.43888 .57865 .44449 .58403 .45418 .5811 .4486 .57569 Mtetra
.656 .752 .92 r
.4486 .57569 .45418 .5811 .46391 .57817 .45835 .57273 Mtetra
.45835 .57273 .46391 .57817 .47367 .57522 .46814 .56976 Mtetra
.46814 .56976 .47367 .57522 .48347 .57226 .47796 .56679 Mtetra
.47796 .56679 .48347 .57226 .4933 .5693 .48781 .5638 Mtetra
.656 .751 .92 r
.48781 .5638 .4933 .5693 .50317 .56632 .49771 .5608 Mtetra
.49771 .5608 .50317 .56632 .51308 .56334 .50763 .5578 Mtetra
.50763 .5578 .51308 .56334 .52302 .56034 .5176 .55478 Mtetra
.5176 .55478 .52302 .56034 .533 .55733 .5276 .55175 Mtetra
.5276 .55175 .533 .55733 .54301 .55431 .53764 .54871 Mtetra
.53764 .54871 .54301 .55431 .55306 .55128 .54771 .54566 Mtetra
.54771 .54566 .55306 .55128 .56314 .54824 .55782 .5426 Mtetra
.55782 .5426 .56314 .54824 .57327 .54519 .56797 .53953 Mtetra
.56797 .53953 .57327 .54519 .58343 .54213 .57815 .53644 Mtetra
.57815 .53644 .58343 .54213 .59363 .53905 .58837 .53335 Mtetra
.58837 .53335 .59363 .53905 .60386 .53597 .59864 .53024 Mtetra
.59864 .53024 .60386 .53597 .61413 .53287 .60893 .52713 Mtetra
.60893 .52713 .61413 .53287 .62444 .52976 .61927 .524 Mtetra
.61927 .524 .62444 .52976 .63479 .52664 .62964 .52085 Mtetra
.62964 .52085 .63479 .52664 .64518 .52351 .64006 .5177 Mtetra
.64006 .5177 .64518 .52351 .6556 .52037 .65051 .51454 Mtetra
.65051 .51454 .6556 .52037 .66607 .51722 .661 .51136 Mtetra
.661 .51136 .66607 .51722 .67657 .51405 .67153 .50817 Mtetra
.67153 .50817 .67657 .51405 .68711 .51087 .6821 .50497 Mtetra
.6821 .50497 .68711 .51087 .6977 .50768 .69271 .50176 Mtetra
.69271 .50176 .6977 .50768 .70832 .50448 .70336 .49854 Mtetra
.70336 .49854 .70832 .50448 .71898 .50127 .71405 .49531 Mtetra
.71405 .49531 .71898 .50127 .72968 .49804 .72478 .49206 Mtetra
.656 .751 .921 r
.72478 .49206 .72968 .49804 .74042 .49481 .73555 .48881 Mtetra
.655 .752 .921 r
.73555 .48881 .74042 .49481 .75121 .49156 .74636 .48555 Mtetra
.74636 .48555 .75121 .49156 .76203 .48831 .75721 .48228 Mtetra
.75721 .48228 .76203 .48831 .77289 .48505 .7681 .479 Mtetra
.7681 .479 .77289 .48505 .7838 .48178 .77904 .47572 Mtetra
.654 .752 .922 r
.77904 .47572 .7838 .48178 .79475 .4785 .79002 .47243 Mtetra
.654 .753 .922 r
.79002 .47243 .79475 .4785 .80574 .47521 .80104 .46913 Mtetra
.654 .754 .923 r
.80104 .46913 .80574 .47521 .81677 .4719 .81211 .46582 Mtetra
.81211 .46582 .81677 .4719 .82785 .46859 .82321 .4625 Mtetra
.655 .755 .923 r
.82321 .4625 .82785 .46859 .83896 .46526 .83436 .45915 Mtetra
.83436 .45915 .83896 .46526 .85012 .4619 .84555 .45577 Mtetra
.656 .755 .923 r
.84555 .45577 .85012 .4619 .86132 .45852 .85678 .45236 Mtetra
.656 .756 .923 r
.85678 .45236 .86132 .45852 .87257 .45512 .86806 .44892 Mtetra
.657 .755 .922 r
.86806 .44892 .87257 .45512 .88385 .45169 .87937 .44545 Mtetra
.658 .755 .922 r
.87937 .44545 .88385 .45169 .89518 .44824 .89073 .44195 Mtetra
.658 .754 .921 r
.89073 .44195 .89518 .44824 .90655 .44477 .90213 .43843 Mtetra
.658 .753 .92 r
.90213 .43843 .90655 .44477 .91796 .44128 .91357 .43489 Mtetra
.651 .75 .922 r
.3005 .61354 .30643 .61871 .31567 .61598 .30976 .61082 Mtetra
.651 .752 .923 r
.30976 .61082 .31567 .61598 .32495 .61324 .31905 .60809 Mtetra
.652 .753 .924 r
.31905 .60809 .32495 .61324 .33426 .61047 .32838 .60534 Mtetra
.652 .754 .924 r
.32838 .60534 .33426 .61047 .3436 .60769 .33774 .60256 Mtetra
.653 .756 .925 r
.33774 .60256 .3436 .60769 .35297 .60487 .34713 .59975 Mtetra
.654 .757 .925 r
.34713 .59975 .35297 .60487 .36238 .60203 .35656 .59691 Mtetra
.655 .758 .925 r
.35656 .59691 .36238 .60203 .37183 .59916 .36603 .59403 Mtetra
.656 .758 .925 r
.36603 .59403 .37183 .59916 .3813 .59627 .37553 .59111 Mtetra
.657 .758 .924 r
.37553 .59111 .3813 .59627 .39082 .59336 .38506 .58817 Mtetra
.658 .758 .924 r
.38506 .58817 .39082 .59336 .40036 .59043 .39463 .5852 Mtetra
.658 .757 .923 r
.39463 .5852 .40036 .59043 .40994 .5875 .40423 .58222 Mtetra
.658 .756 .922 r
.40423 .58222 .40994 .5875 .41955 .58455 .41387 .57924 Mtetra
.658 .755 .922 r
.41387 .57924 .41955 .58455 .4292 .5816 .42354 .57625 Mtetra
.657 .754 .921 r
.42354 .57625 .4292 .5816 .43888 .57865 .43324 .57326 Mtetra
.657 .753 .921 r
.43324 .57326 .43888 .57865 .4486 .57569 .44298 .57027 Mtetra
.44298 .57027 .4486 .57569 .45835 .57273 .45275 .56727 Mtetra
.656 .752 .921 r
.45275 .56727 .45835 .57273 .46814 .56976 .46256 .56428 Mtetra
.656 .752 .92 r
.46256 .56428 .46814 .56976 .47796 .56679 .47241 .56128 Mtetra
.47241 .56128 .47796 .56679 .48781 .5638 .48229 .55827 Mtetra
.48229 .55827 .48781 .5638 .49771 .5608 .4922 .55525 Mtetra
.4922 .55525 .49771 .5608 .50763 .5578 .50215 .55222 Mtetra
.656 .751 .92 r
.50215 .55222 .50763 .5578 .5176 .55478 .51214 .54918 Mtetra
.51214 .54918 .5176 .55478 .5276 .55175 .52217 .54613 Mtetra
.52217 .54613 .5276 .55175 .53764 .54871 .53223 .54307 Mtetra
.53223 .54307 .53764 .54871 .54771 .54566 .54232 .54 Mtetra
.54232 .54 .54771 .54566 .55782 .5426 .55246 .53692 Mtetra
.55246 .53692 .55782 .5426 .56797 .53953 .56263 .53383 Mtetra
.56263 .53383 .56797 .53953 .57815 .53644 .57284 .53072 Mtetra
.57284 .53072 .57815 .53644 .58837 .53335 .58309 .52761 Mtetra
.58309 .52761 .58837 .53335 .59864 .53024 .59337 .52448 Mtetra
.59337 .52448 .59864 .53024 .60893 .52713 .6037 .52134 Mtetra
.6037 .52134 .60893 .52713 .61927 .524 .61406 .51819 Mtetra
.61406 .51819 .61927 .524 .62964 .52085 .62446 .51503 Mtetra
.62446 .51503 .62964 .52085 .64006 .5177 .6349 .51185 Mtetra
.6349 .51185 .64006 .5177 .65051 .51454 .64538 .50867 Mtetra
.64538 .50867 .65051 .51454 .661 .51136 .65589 .50547 Mtetra
.65589 .50547 .661 .51136 .67153 .50817 .66645 .50226 Mtetra
.66645 .50226 .67153 .50817 .6821 .50497 .67705 .49904 Mtetra
.67705 .49904 .6821 .50497 .69271 .50176 .68768 .4958 Mtetra
.68768 .4958 .69271 .50176 .70336 .49854 .69836 .49256 Mtetra
.69836 .49256 .70336 .49854 .71405 .49531 .70908 .48931 Mtetra
.655 .752 .921 r
.70908 .48931 .71405 .49531 .72478 .49206 .71984 .48605 Mtetra
.71984 .48605 .72478 .49206 .73555 .48881 .73064 .48278 Mtetra
.73064 .48278 .73555 .48881 .74636 .48555 .74148 .4795 Mtetra
.74148 .4795 .74636 .48555 .75721 .48228 .75236 .47622 Mtetra
.654 .752 .922 r
.75236 .47622 .75721 .48228 .7681 .479 .76328 .47294 Mtetra
.654 .753 .923 r
.76328 .47294 .7681 .479 .77904 .47572 .77425 .46966 Mtetra
.653 .754 .923 r
.77425 .46966 .77904 .47572 .79002 .47243 .78526 .46637 Mtetra
.653 .754 .924 r
.78526 .46637 .79002 .47243 .80104 .46913 .79632 .46308 Mtetra
.653 .755 .925 r
.79632 .46308 .80104 .46913 .81211 .46582 .80741 .45977 Mtetra
.653 .756 .925 r
.80741 .45977 .81211 .46582 .82321 .4625 .81855 .45643 Mtetra
.654 .757 .925 r
.81855 .45643 .82321 .4625 .83436 .45915 .82973 .45306 Mtetra
.655 .758 .925 r
.82973 .45306 .83436 .45915 .84555 .45577 .84095 .44965 Mtetra
.656 .758 .925 r
.84095 .44965 .84555 .45577 .85678 .45236 .85222 .4462 Mtetra
.657 .758 .924 r
.85222 .4462 .85678 .45236 .86806 .44892 .86352 .44272 Mtetra
.658 .757 .923 r
.86352 .44272 .86806 .44892 .87937 .44545 .87486 .43919 Mtetra
.659 .757 .922 r
.87486 .43919 .87937 .44545 .89073 .44195 .88625 .43564 Mtetra
.659 .755 .921 r
.88625 .43564 .89073 .44195 .90213 .43843 .89768 .43206 Mtetra
.66 .754 .92 r
.89768 .43206 .90213 .43843 .91357 .43489 .90915 .42846 Mtetra
.649 .75 .923 r
.29453 .60833 .3005 .61354 .30976 .61082 .30381 .60564 Mtetra
.649 .751 .924 r
.30381 .60564 .30976 .61082 .31905 .60809 .31312 .60293 Mtetra
.65 .753 .925 r
.31312 .60293 .31905 .60809 .32838 .60534 .32246 .60021 Mtetra
.65 .755 .926 r
.32246 .60021 .32838 .60534 .33774 .60256 .33184 .59745 Mtetra
.652 .757 .927 r
.33184 .59745 .33774 .60256 .34713 .59975 .34125 .59466 Mtetra
.653 .759 .927 r
.34125 .59466 .34713 .59975 .35656 .59691 .3507 .59183 Mtetra
.655 .76 .927 r
.3507 .59183 .35656 .59691 .36603 .59403 .36019 .58894 Mtetra
.656 .761 .927 r
.36019 .58894 .36603 .59403 .37553 .59111 .36971 .58601 Mtetra
.658 .762 .926 r
.36971 .58601 .37553 .59111 .38506 .58817 .37927 .58303 Mtetra
.659 .761 .926 r
.37927 .58303 .38506 .58817 .39463 .5852 .38886 .58002 Mtetra
.659 .76 .925 r
.38886 .58002 .39463 .5852 .40423 .58222 .39848 .57699 Mtetra
.659 .759 .924 r
.39848 .57699 .40423 .58222 .41387 .57924 .40814 .57395 Mtetra
.659 .758 .923 r
.40814 .57395 .41387 .57924 .42354 .57625 .41784 .5709 Mtetra
.658 .756 .922 r
.41784 .5709 .42354 .57625 .43324 .57326 .42756 .56786 Mtetra
.658 .755 .922 r
.42756 .56786 .43324 .57326 .44298 .57027 .43732 .56483 Mtetra
.657 .754 .921 r
.43732 .56483 .44298 .57027 .45275 .56727 .44712 .5618 Mtetra
.657 .753 .921 r
.44712 .5618 .45275 .56727 .46256 .56428 .45695 .55877 Mtetra
.656 .753 .921 r
.45695 .55877 .46256 .56428 .47241 .56128 .46682 .55574 Mtetra
.656 .752 .921 r
.46682 .55574 .47241 .56128 .48229 .55827 .47672 .5527 Mtetra
.656 .752 .92 r
.47672 .5527 .48229 .55827 .4922 .55525 .48666 .54966 Mtetra
.48666 .54966 .4922 .55525 .50215 .55222 .49664 .54661 Mtetra
.49664 .54661 .50215 .55222 .51214 .54918 .50665 .54355 Mtetra
.50665 .54355 .51214 .54918 .52217 .54613 .5167 .54048 Mtetra
.656 .751 .92 r
.5167 .54048 .52217 .54613 .53223 .54307 .52678 .5374 Mtetra
.52678 .5374 .53223 .54307 .54232 .54 .5369 .5343 Mtetra
.5369 .5343 .54232 .54 .55246 .53692 .54706 .5312 Mtetra
.54706 .5312 .55246 .53692 .56263 .53383 .55726 .52809 Mtetra
.55726 .52809 .56263 .53383 .57284 .53072 .56749 .52496 Mtetra
.56749 .52496 .57284 .53072 .58309 .52761 .57777 .52182 Mtetra
.57777 .52182 .58309 .52761 .59337 .52448 .58808 .51867 Mtetra
.58808 .51867 .59337 .52448 .6037 .52134 .59843 .51551 Mtetra
.59843 .51551 .6037 .52134 .61406 .51819 .60881 .51234 Mtetra
.60881 .51234 .61406 .51819 .62446 .51503 .61924 .50916 Mtetra
.61924 .50916 .62446 .51503 .6349 .51185 .62971 .50596 Mtetra
.62971 .50596 .6349 .51185 .64538 .50867 .64021 .50275 Mtetra
.64021 .50275 .64538 .50867 .65589 .50547 .65075 .49953 Mtetra
.65075 .49953 .65589 .50547 .66645 .50226 .66134 .4963 Mtetra
.66134 .4963 .66645 .50226 .67705 .49904 .67196 .49306 Mtetra
.67196 .49306 .67705 .49904 .68768 .4958 .68263 .48981 Mtetra
.655 .752 .921 r
.68263 .48981 .68768 .4958 .69836 .49256 .69333 .48655 Mtetra
.69333 .48655 .69836 .49256 .70908 .48931 .70408 .48328 Mtetra
.70408 .48328 .70908 .48931 .71984 .48605 .71486 .48 Mtetra
.71486 .48 .71984 .48605 .73064 .48278 .72569 .47672 Mtetra
.654 .752 .922 r
.72569 .47672 .73064 .48278 .74148 .4795 .73656 .47344 Mtetra
.654 .753 .923 r
.73656 .47344 .74148 .4795 .75236 .47622 .74748 .47016 Mtetra
.653 .753 .923 r
.74748 .47016 .75236 .47622 .76328 .47294 .75843 .46689 Mtetra
.652 .754 .924 r
.75843 .46689 .76328 .47294 .77425 .46966 .76943 .46362 Mtetra
.652 .755 .926 r
.76943 .46362 .77425 .46966 .78526 .46637 .78048 .46035 Mtetra
.651 .757 .927 r
.78048 .46035 .78526 .46637 .79632 .46308 .79157 .45707 Mtetra
.652 .758 .927 r
.79157 .45707 .79632 .46308 .80741 .45977 .8027 .45376 Mtetra
.653 .759 .928 r
.8027 .45376 .80741 .45977 .81855 .45643 .81387 .45041 Mtetra
.654 .76 .928 r
.81387 .45041 .81855 .45643 .82973 .45306 .82508 .44701 Mtetra
.655 .761 .927 r
.82508 .44701 .82973 .45306 .84095 .44965 .83633 .44357 Mtetra
.657 .761 .926 r
.83633 .44357 .84095 .44965 .85222 .4462 .84762 .44006 Mtetra
.658 .76 .925 r
.84762 .44006 .85222 .4462 .86352 .44272 .85895 .43652 Mtetra
.66 .76 .924 r
.85895 .43652 .86352 .44272 .87486 .43919 .87033 .43292 Mtetra
.66 .758 .923 r
.87033 .43292 .87486 .43919 .88625 .43564 .88174 .4293 Mtetra
.661 .757 .921 r
.88174 .4293 .88625 .43564 .89768 .43206 .89319 .42564 Mtetra
.661 .755 .92 r
.89319 .42564 .89768 .43206 .90915 .42846 .90469 .42197 Mtetra
.647 .749 .924 r
.28853 .60308 .29453 .60833 .30381 .60564 .29782 .60042 Mtetra
.647 .751 .925 r
.29782 .60042 .30381 .60564 .31312 .60293 .30714 .59775 Mtetra
.647 .753 .926 r
.30714 .59775 .31312 .60293 .32246 .60021 .3165 .59506 Mtetra
.648 .755 .927 r
.3165 .59506 .32246 .60021 .33184 .59745 .3259 .59234 Mtetra
.649 .757 .929 r
.3259 .59234 .33184 .59745 .34125 .59466 .33533 .58959 Mtetra
.65 .76 .929 r
.33533 .58959 .34125 .59466 .3507 .59183 .3448 .58678 Mtetra
.653 .762 .93 r
.3448 .58678 .3507 .59183 .36019 .58894 .3543 .58392 Mtetra
.655 .764 .93 r
.3543 .58392 .36019 .58894 .36971 .58601 .36385 .58099 Mtetra
.657 .766 .93 r
.36385 .58099 .36971 .58601 .37927 .58303 .37342 .57799 Mtetra
.659 .766 .929 r
.37342 .57799 .37927 .58303 .38886 .58002 .38304 .57495 Mtetra
.661 .766 .928 r
.38304 .57495 .38886 .58002 .39848 .57699 .39269 .57185 Mtetra
.661 .765 .927 r
.39269 .57185 .39848 .57699 .40814 .57395 .40237 .56874 Mtetra
.661 .763 .925 r
.40237 .56874 .40814 .57395 .41784 .5709 .41209 .56562 Mtetra
.66 .761 .924 r
.41209 .56562 .41784 .5709 .42756 .56786 .42184 .56251 Mtetra
.659 .758 .923 r
.42184 .56251 .42756 .56786 .43732 .56483 .43163 .55941 Mtetra
.659 .757 .922 r
.43163 .55941 .43732 .56483 .44712 .5618 .44145 .55633 Mtetra
.658 .755 .922 r
.44145 .55633 .44712 .5618 .45695 .55877 .4513 .55325 Mtetra
.657 .754 .921 r
.4513 .55325 .45695 .55877 .46682 .55574 .46119 .55018 Mtetra
.657 .753 .921 r
.46119 .55018 .46682 .55574 .47672 .5527 .47112 .54711 Mtetra
.656 .752 .921 r
.47112 .54711 .47672 .5527 .48666 .54966 .48108 .54404 Mtetra
.48108 .54404 .48666 .54966 .49664 .54661 .49108 .54096 Mtetra
.656 .752 .92 r
.49108 .54096 .49664 .54661 .50665 .54355 .50112 .53788 Mtetra
.50112 .53788 .50665 .54355 .5167 .54048 .51119 .53479 Mtetra
.51119 .53479 .5167 .54048 .52678 .5374 .5213 .53168 Mtetra
.5213 .53168 .52678 .5374 .5369 .5343 .53144 .52857 Mtetra
.656 .751 .92 r
.53144 .52857 .5369 .5343 .54706 .5312 .54163 .52544 Mtetra
.54163 .52544 .54706 .5312 .55726 .52809 .55185 .52231 Mtetra
.55185 .52231 .55726 .52809 .56749 .52496 .56211 .51916 Mtetra
.56211 .51916 .56749 .52496 .57777 .52182 .57241 .516 Mtetra
.57241 .516 .57777 .52182 .58808 .51867 .58274 .51283 Mtetra
.58274 .51283 .58808 .51867 .59843 .51551 .59312 .50965 Mtetra
.59312 .50965 .59843 .51551 .60881 .51234 .60353 .50645 Mtetra
.60353 .50645 .60881 .51234 .61924 .50916 .61398 .50325 Mtetra
.61398 .50325 .61924 .50916 .62971 .50596 .62448 .50003 Mtetra
.62448 .50003 .62971 .50596 .64021 .50275 .63501 .4968 Mtetra
.63501 .4968 .64021 .50275 .65075 .49953 .64558 .49356 Mtetra
.656 .752 .92 r
.64558 .49356 .65075 .49953 .66134 .4963 .65619 .49031 Mtetra
.656 .752 .921 r
.65619 .49031 .66134 .4963 .67196 .49306 .66684 .48705 Mtetra
.655 .752 .921 r
.66684 .48705 .67196 .49306 .68263 .48981 .67753 .48378 Mtetra
.67753 .48378 .68263 .48981 .69333 .48655 .68827 .4805 Mtetra
.68827 .4805 .69333 .48655 .70408 .48328 .69904 .47722 Mtetra
.654 .752 .922 r
.69904 .47722 .70408 .48328 .71486 .48 .70986 .47394 Mtetra
.654 .753 .922 r
.70986 .47394 .71486 .48 .72569 .47672 .72072 .47066 Mtetra
.653 .753 .923 r
.72072 .47066 .72569 .47672 .73656 .47344 .73162 .4674 Mtetra
.652 .754 .925 r
.73162 .4674 .73656 .47344 .74748 .47016 .74256 .46414 Mtetra
.65 .755 .926 r
.74256 .46414 .74748 .47016 .75843 .46689 .75356 .4609 Mtetra
.65 .757 .928 r
.75356 .4609 .75843 .46689 .76943 .46362 .76459 .45767 Mtetra
.649 .759 .93 r
.76459 .45767 .76943 .46362 .78048 .46035 .77567 .45442 Mtetra
.649 .761 .931 r
.77567 .45442 .78048 .46035 .79157 .45707 .78679 .45115 Mtetra
.65 .763 .932 r
.78679 .45115 .79157 .45707 .8027 .45376 .79795 .44784 Mtetra
.652 .764 .932 r
.79795 .44784 .8027 .45376 .81387 .45041 .80916 .44447 Mtetra
.654 .765 .931 r
.80916 .44447 .81387 .45041 .82508 .44701 .8204 .44103 Mtetra
.657 .765 .93 r
.8204 .44103 .82508 .44701 .83633 .44357 .83168 .43751 Mtetra
.659 .765 .928 r
.83168 .43751 .83633 .44357 .84762 .44006 .843 .43393 Mtetra
.661 .763 .926 r
.843 .43393 .84762 .44006 .85895 .43652 .85436 .4303 Mtetra
.662 .762 .924 r
.85436 .4303 .85895 .43652 .87033 .43292 .86576 .42663 Mtetra
.662 .76 .922 r
.86576 .42663 .87033 .43292 .88174 .4293 .8772 .42292 Mtetra
.663 .758 .921 r
.8772 .42292 .88174 .4293 .89319 .42564 .88868 .41919 Mtetra
.663 .756 .919 r
.88868 .41919 .89319 .42564 .90469 .42197 .90021 .41544 Mtetra
.645 .749 .924 r
.28248 .59781 .28853 .60308 .29782 .60042 .29179 .59517 Mtetra
.645 .75 .926 r
.29179 .59517 .29782 .60042 .30714 .59775 .30113 .59252 Mtetra
.645 .752 .927 r
.30113 .59252 .30714 .59775 .3165 .59506 .31051 .58987 Mtetra
.645 .754 .929 r
.31051 .58987 .3165 .59506 .3259 .59234 .31992 .5872 Mtetra
.645 .757 .93 r
.31992 .5872 .3259 .59234 .33533 .58959 .32937 .58451 Mtetra
.647 .76 .932 r
.32937 .58451 .33533 .58959 .3448 .58678 .33885 .58176 Mtetra
.649 .764 .933 r
.33885 .58176 .3448 .58678 .3543 .58392 .34837 .57895 Mtetra
.652 .767 .934 r
.34837 .57895 .3543 .58392 .36385 .58099 .35794 .57606 Mtetra
.656 .77 .934 r
.35794 .57606 .36385 .58099 .37342 .57799 .36754 .57307 Mtetra
.659 .772 .933 r
.36754 .57307 .37342 .57799 .38304 .57495 .37717 .57 Mtetra
.662 .773 .932 r
.37717 .57 .38304 .57495 .39269 .57185 .38685 .56685 Mtetra
.663 .772 .93 r
.38685 .56685 .39269 .57185 .40237 .56874 .39656 .56366 Mtetra
.664 .77 .929 r
.39656 .56366 .40237 .56874 .41209 .56562 .4063 .56046 Mtetra
.663 .767 .927 r
.4063 .56046 .41209 .56562 .42184 .56251 .41608 .55725 Mtetra
.662 .764 .925 r
.41608 .55725 .42184 .56251 .43163 .55941 .42589 .55406 Mtetra
.661 .761 .924 r
.42589 .55406 .43163 .55941 .44145 .55633 .43574 .55089 Mtetra
.659 .758 .923 r
.43574 .55089 .44145 .55633 .4513 .55325 .44562 .54775 Mtetra
.658 .756 .922 r
.44562 .54775 .4513 .55325 .46119 .55018 .45553 .54463 Mtetra
.658 .755 .922 r
.45553 .54463 .46119 .55018 .47112 .54711 .46548 .54151 Mtetra
.657 .754 .921 r
.46548 .54151 .47112 .54711 .48108 .54404 .47547 .53841 Mtetra
.657 .753 .921 r
.47547 .53841 .48108 .54404 .49108 .54096 .48549 .5353 Mtetra
.656 .752 .921 r
.48549 .5353 .49108 .54096 .50112 .53788 .49555 .53218 Mtetra
.49555 .53218 .50112 .53788 .51119 .53479 .50564 .52906 Mtetra
.50564 .52906 .51119 .53479 .5213 .53168 .51578 .52594 Mtetra
.656 .752 .92 r
.51578 .52594 .5213 .53168 .53144 .52857 .52595 .5228 Mtetra
.52595 .5228 .53144 .52857 .54163 .52544 .53616 .51965 Mtetra
.53616 .51965 .54163 .52544 .55185 .52231 .5464 .51649 Mtetra
.5464 .51649 .55185 .52231 .56211 .51916 .55669 .51332 Mtetra
.55669 .51332 .56211 .51916 .57241 .516 .56701 .51014 Mtetra
.56701 .51014 .57241 .516 .58274 .51283 .57737 .50695 Mtetra
.57737 .50695 .58274 .51283 .59312 .50965 .58777 .50375 Mtetra
.58777 .50375 .59312 .50965 .60353 .50645 .59821 .50053 Mtetra
.59821 .50053 .60353 .50645 .61398 .50325 .60869 .4973 Mtetra
.60869 .4973 .61398 .50325 .62448 .50003 .61921 .49406 Mtetra
.656 .752 .921 r
.61921 .49406 .62448 .50003 .63501 .4968 .62977 .49081 Mtetra
.62977 .49081 .63501 .4968 .64558 .49356 .64037 .48755 Mtetra
.655 .752 .921 r
.64037 .48755 .64558 .49356 .65619 .49031 .65101 .48429 Mtetra
.65101 .48429 .65619 .49031 .66684 .48705 .66169 .48101 Mtetra
.66169 .48101 .66684 .48705 .67753 .48378 .67241 .47773 Mtetra
.654 .752 .922 r
.67241 .47773 .67753 .48378 .68827 .4805 .68317 .47444 Mtetra
.654 .753 .922 r
.68317 .47444 .68827 .4805 .69904 .47722 .69397 .47116 Mtetra
.653 .753 .923 r
.69397 .47116 .69904 .47722 .70986 .47394 .70482 .4679 Mtetra
.652 .754 .925 r
.70482 .4679 .70986 .47394 .72072 .47066 .71571 .46464 Mtetra
.65 .755 .926 r
.71571 .46464 .72072 .47066 .73162 .4674 .72664 .46142 Mtetra
.648 .757 .928 r
.72664 .46142 .73162 .4674 .74256 .46414 .73763 .45821 Mtetra
.647 .759 .931 r
.73763 .45821 .74256 .46414 .75356 .4609 .74865 .45502 Mtetra
.646 .761 .933 r
.74865 .45502 .75356 .4609 .76459 .45767 .75972 .45183 Mtetra
.646 .764 .935 r
.75972 .45183 .76459 .45767 .77567 .45442 .77084 .44863 Mtetra
.647 .767 .936 r
.77084 .44863 .77567 .45442 .78679 .45115 .78199 .44537 Mtetra
.65 .769 .936 r
.78199 .44537 .78679 .45115 .79795 .44784 .79319 .44204 Mtetra
.653 .77 .935 r
.79319 .44204 .79795 .44784 .80916 .44447 .80442 .43861 Mtetra
.656 .771 .934 r
.80442 .43861 .80916 .44447 .8204 .44103 .81569 .43509 Mtetra
.659 .77 .931 r
.81569 .43509 .8204 .44103 .83168 .43751 .827 .43147 Mtetra
.662 .768 .928 r
.827 .43147 .83168 .43751 .843 .43393 .83834 .42779 Mtetra
.663 .766 .926 r
.83834 .42779 .843 .43393 .85436 .4303 .84973 .42405 Mtetra
.664 .763 .924 r
.84973 .42405 .85436 .4303 .86576 .42663 .86115 .42028 Mtetra
.665 .761 .922 r
.86115 .42028 .86576 .42663 .8772 .42292 .87262 .41649 Mtetra
.665 .759 .92 r
.87262 .41649 .8772 .42292 .88868 .41919 .88413 .41268 Mtetra
.665 .757 .919 r
.88413 .41268 .88868 .41919 .90021 .41544 .89569 .40886 Mtetra
.645 .749 .925 r
.27639 .59249 .28248 .59781 .29179 .59517 .28572 .58985 Mtetra
.644 .749 .925 r
.28572 .58985 .29179 .59517 .30113 .59252 .29508 .58721 Mtetra
.643 .75 .926 r
.29508 .58721 .30113 .59252 .31051 .58987 .30447 .58458 Mtetra
.642 .751 .928 r
.30447 .58458 .31051 .58987 .31992 .5872 .3139 .58195 Mtetra
.642 .753 .93 r
.3139 .58195 .31992 .5872 .32937 .58451 .32336 .57933 Mtetra
.642 .756 .932 r
.32336 .57933 .32937 .58451 .33885 .58176 .33286 .57667 Mtetra
.644 .761 .934 r
.33286 .57667 .33885 .58176 .34837 .57895 .3424 .57396 Mtetra
.646 .766 .936 r
.3424 .57396 .34837 .57895 .35794 .57606 .35198 .57116 Mtetra
.651 .772 .937 r
.35198 .57116 .35794 .57606 .36754 .57307 .3616 .56825 Mtetra
.655 .777 .938 r
.3616 .56825 .36754 .57307 .37717 .57 .37126 .56522 Mtetra
.66 .78 .937 r
.37126 .56522 .37717 .57 .38685 .56685 .38096 .56206 Mtetra
.664 .781 .936 r
.38096 .56206 .38685 .56685 .39656 .56366 .39069 .55881 Mtetra
.666 .78 .934 r
.39069 .55881 .39656 .56366 .4063 .56046 .40046 .5555 Mtetra
.667 .777 .932 r
.40046 .5555 .4063 .56046 .41608 .55725 .41027 .55218 Mtetra
.666 .773 .93 r
.41027 .55218 .41608 .55725 .42589 .55406 .42011 .54887 Mtetra
.665 .769 .928 r
.42011 .54887 .42589 .55406 .43574 .55089 .42998 .54558 Mtetra
.663 .765 .926 r
.42998 .54558 .43574 .55089 .44562 .54775 .43988 .54234 Mtetra
.661 .761 .924 r
.43988 .54234 .44562 .54775 .45553 .54463 .44982 .53913 Mtetra
.659 .759 .923 r
.44982 .53913 .45553 .54463 .46548 .54151 .4598 .53594 Mtetra
.658 .756 .922 r
.4598 .53594 .46548 .54151 .47547 .53841 .46981 .53278 Mtetra
.657 .755 .922 r
.46981 .53278 .47547 .53841 .48549 .5353 .47986 .52962 Mtetra
.657 .754 .921 r
.47986 .52962 .48549 .5353 .49555 .53218 .48994 .52647 Mtetra
.657 .753 .921 r
.48994 .52647 .49555 .53218 .50564 .52906 .50006 .52332 Mtetra
.656 .753 .921 r
.50006 .52332 .50564 .52906 .51578 .52594 .51022 .52016 Mtetra
.656 .752 .921 r
.51022 .52016 .51578 .52594 .52595 .5228 .52041 .517 Mtetra
.52041 .517 .52595 .5228 .53616 .51965 .53065 .51383 Mtetra
.53065 .51383 .53616 .51965 .5464 .51649 .54092 .51064 Mtetra
.54092 .51064 .5464 .51649 .55669 .51332 .55123 .50745 Mtetra
.55123 .50745 .55669 .51332 .56701 .51014 .56158 .50425 Mtetra
.56158 .50425 .56701 .51014 .57737 .50695 .57197 .50103 Mtetra
.57197 .50103 .57737 .50695 .58777 .50375 .58239 .49781 Mtetra
.58239 .49781 .58777 .50375 .59821 .50053 .59286 .49457 Mtetra
.59286 .49457 .59821 .50053 .60869 .4973 .60336 .49132 Mtetra
.60336 .49132 .60869 .4973 .61921 .49406 .61391 .48806 Mtetra
.655 .752 .921 r
.61391 .48806 .61921 .49406 .62977 .49081 .62449 .4848 Mtetra
.62449 .4848 .62977 .49081 .64037 .48755 .63512 .48152 Mtetra
.63512 .48152 .64037 .48755 .65101 .48429 .64579 .47824 Mtetra
.655 .752 .922 r
.64579 .47824 .65101 .48429 .66169 .48101 .65649 .47496 Mtetra
.654 .753 .922 r
.65649 .47496 .66169 .48101 .67241 .47773 .66724 .47168 Mtetra
.653 .753 .923 r
.66724 .47168 .67241 .47773 .68317 .47444 .67804 .46841 Mtetra
.652 .754 .925 r
.67804 .46841 .68317 .47444 .69397 .47116 .68887 .46516 Mtetra
.65 .755 .927 r
.68887 .46516 .69397 .47116 .70482 .4679 .69975 .46193 Mtetra
.648 .757 .929 r
.69975 .46193 .70482 .4679 .71571 .46464 .71068 .45874 Mtetra
.645 .759 .932 r
.71068 .45874 .71571 .46464 .72664 .46142 .72165 .45559 Mtetra
.643 .762 .935 r
.72165 .45559 .72664 .46142 .73763 .45821 .73266 .45247 Mtetra
.641 .766 .938 r
.73266 .45247 .73763 .45821 .74865 .45502 .74373 .44936 Mtetra
.641 .769 .941 r
.74373 .44936 .74865 .45502 .75972 .45183 .75484 .44623 Mtetra
.643 .773 .943 r
.75484 .44623 .75972 .45183 .77084 .44863 .76599 .44303 Mtetra
.646 .776 .943 r
.76599 .44303 .77084 .44863 .78199 .44537 .77718 .43975 Mtetra
.651 .778 .941 r
.77718 .43975 .78199 .44537 .79319 .44204 .7884 .43633 Mtetra
.656 .777 .938 r
.7884 .43633 .79319 .44204 .80442 .43861 .79966 .43279 Mtetra
.661 .775 .934 r
.79966 .43279 .80442 .43861 .81569 .43509 .81095 .42912 Mtetra
.664 .772 .93 r
.81095 .42912 .81569 .43509 .827 .43147 .82228 .42535 Mtetra
.666 .768 .926 r
.82228 .42535 .827 .43147 .83834 .42779 .83365 .42153 Mtetra
.667 .765 .923 r
.83365 .42153 .83834 .42779 .84973 .42405 .84506 .41767 Mtetra
.667 .761 .921 r
.84506 .41767 .84973 .42405 .86115 .42028 .85651 .41381 Mtetra
.666 .759 .919 r
.85651 .41381 .86115 .42028 .87262 .41649 .86801 .40995 Mtetra
.666 .757 .918 r
.86801 .40995 .87262 .41649 .88413 .41268 .87955 .40609 Mtetra
.665 .756 .918 r
.87955 .40609 .88413 .41268 .89569 .40886 .89113 .40224 Mtetra
.646 .749 .924 r
.27027 .58715 .27639 .59249 .28572 .58985 .27961 .58445 Mtetra
.645 .748 .924 r
.27961 .58445 .28572 .58985 .29508 .58721 .289 .58178 Mtetra
.643 .746 .924 r
.289 .58178 .29508 .58721 .30447 .58458 .29841 .57913 Mtetra
.641 .746 .925 r
.29841 .57913 .30447 .58458 .3139 .58195 .30785 .57652 Mtetra
.639 .747 .927 r
.30785 .57652 .3139 .58195 .32336 .57933 .31733 .57395 Mtetra
.637 .749 .929 r
.31733 .57395 .32336 .57933 .33286 .57667 .32685 .5714 Mtetra
.637 .754 .933 r
.32685 .5714 .33286 .57667 .3424 .57396 .3364 .56884 Mtetra
.638 .76 .936 r
.3364 .56884 .3424 .57396 .35198 .57116 .34599 .5662 Mtetra
.643 .769 .94 r
.34599 .5662 .35198 .57116 .3616 .56825 .35562 .56345 Mtetra
.648 .777 .942 r
.35562 .56345 .3616 .56825 .37126 .56522 .36529 .56055 Mtetra
.656 .785 .943 r
.36529 .56055 .37126 .56522 .38096 .56206 .37501 .55745 Mtetra
.662 .79 .943 r
.37501 .55745 .38096 .56206 .39069 .55881 .38477 .5542 Mtetra
.667 .792 .941 r
.38477 .5542 .39069 .55881 .40046 .5555 .39457 .55082 Mtetra
.67 .79 .938 r
.39457 .55082 .40046 .5555 .41027 .55218 .40441 .54737 Mtetra
.67 .786 .936 r
.40441 .54737 .41027 .55218 .42011 .54887 .41427 .54391 Mtetra
.669 .781 .933 r
.41427 .54391 .42011 .54887 .42998 .54558 .42418 .54047 Mtetra
.667 .775 .93 r
.42418 .54047 .42998 .54558 .43988 .54234 .43411 .53709 Mtetra
.665 .77 .928 r
.43411 .53709 .43988 .54234 .44982 .53913 .44408 .53375 Mtetra
.662 .765 .926 r
.44408 .53375 .44982 .53913 .4598 .53594 .45408 .53046 Mtetra
.661 .762 .925 r
.45408 .53046 .4598 .53594 .46981 .53278 .46411 .52721 Mtetra
.659 .759 .924 r
.46411 .52721 .46981 .53278 .47986 .52962 .47419 .52399 Mtetra
.658 .757 .923 r
.47419 .52399 .47986 .52962 .48994 .52647 .48429 .52078 Mtetra
.657 .755 .922 r
.48429 .52078 .48994 .52647 .50006 .52332 .49444 .51758 Mtetra
.657 .754 .922 r
.49444 .51758 .50006 .52332 .51022 .52016 .50462 .51439 Mtetra
.656 .754 .922 r
.50462 .51439 .51022 .52016 .52041 .517 .51484 .51119 Mtetra
.656 .753 .921 r
.51484 .51119 .52041 .517 .53065 .51383 .5251 .50799 Mtetra
.5251 .50799 .53065 .51383 .54092 .51064 .5354 .50478 Mtetra
.5354 .50478 .54092 .51064 .55123 .50745 .54573 .50156 Mtetra
.54573 .50156 .55123 .50745 .56158 .50425 .55611 .49833 Mtetra
.656 .752 .921 r
.55611 .49833 .56158 .50425 .57197 .50103 .56652 .4951 Mtetra
.56652 .4951 .57197 .50103 .58239 .49781 .57697 .49185 Mtetra
.57697 .49185 .58239 .49781 .59286 .49457 .58747 .48859 Mtetra
.655 .752 .921 r
.58747 .48859 .59286 .49457 .60336 .49132 .598 .48533 Mtetra
.655 .753 .922 r
.598 .48533 .60336 .49132 .61391 .48806 .60857 .48205 Mtetra
.60857 .48205 .61391 .48806 .62449 .4848 .61918 .47878 Mtetra
.654 .753 .922 r
.61918 .47878 .62449 .4848 .63512 .48152 .62984 .47549 Mtetra
.654 .753 .923 r
.62984 .47549 .63512 .48152 .64579 .47824 .64053 .47222 Mtetra
.653 .754 .924 r
.64053 .47222 .64579 .47824 .65649 .47496 .65127 .46894 Mtetra
.652 .755 .925 r
.65127 .46894 .65649 .47496 .66724 .47168 .66205 .46569 Mtetra
.65 .756 .927 r
.66205 .46569 .66724 .47168 .67804 .46841 .67287 .46246 Mtetra
.648 .758 .929 r
.67287 .46246 .67804 .46841 .68887 .46516 .68374 .45927 Mtetra
.645 .76 .932 r
.68374 .45927 .68887 .46516 .69975 .46193 .69466 .45613 Mtetra
.642 .763 .936 r
.69466 .45613 .69975 .46193 .71068 .45874 .70562 .45304 Mtetra
.638 .766 .94 r
.70562 .45304 .71068 .45874 .72165 .45559 .71663 .45001 Mtetra
.636 .77 .944 r
.71663 .45001 .72165 .45559 .73266 .45247 .72769 .44699 Mtetra
.635 .775 .948 r
.72769 .44699 .73266 .45247 .74373 .44936 .73879 .44396 Mtetra
.636 .78 .95 r
.73879 .44396 .74373 .44936 .75484 .44623 .74994 .44086 Mtetra
.641 .784 .95 r
.74994 .44086 .75484 .44623 .76599 .44303 .76112 .43763 Mtetra
.648 .786 .948 r
.76112 .43763 .76599 .44303 .77718 .43975 .77233 .43423 Mtetra
.656 .785 .943 r
.77233 .43423 .77718 .43975 .7884 .43633 .78358 .43064 Mtetra
.663 .782 .937 r
.78358 .43064 .7884 .43633 .79966 .43279 .79486 .42688 Mtetra
.668 .777 .931 r
.79486 .42688 .79966 .43279 .81095 .42912 .80617 .423 Mtetra
.671 .771 .925 r
.80617 .423 .81095 .42912 .82228 .42535 .81752 .41904 Mtetra
.671 .765 .921 r
.81752 .41904 .82228 .42535 .83365 .42153 .8289 .41506 Mtetra
.67 .76 .918 r
.8289 .41506 .83365 .42153 .84506 .41767 .84034 .41109 Mtetra
.668 .756 .916 r
.84034 .41109 .84506 .41767 .85651 .41381 .85182 .40717 Mtetra
.667 .754 .916 r
.85182 .40717 .85651 .41381 .86801 .40995 .86335 .40328 Mtetra
.665 .753 .916 r
.86335 .40328 .86801 .40995 .87955 .40609 .87492 .39941 Mtetra
.664 .754 .917 r
.87492 .39941 .87955 .40609 .89113 .40224 .88655 .39556 Mtetra
.651 .75 .922 r
.2641 .58177 .27027 .58715 .27961 .58445 .27347 .57895 Mtetra
.649 .746 .92 r
.27347 .57895 .27961 .58445 .289 .58178 .28288 .57616 Mtetra
.647 .742 .919 r
.28288 .57616 .289 .58178 .29841 .57913 .29232 .57343 Mtetra
.644 .739 .918 r
.29232 .57343 .29841 .57913 .30785 .57652 .30179 .57076 Mtetra
.639 .736 .919 r
.30179 .57076 .30785 .57652 .31733 .57395 .31128 .56819 Mtetra
.635 .735 .921 r
.31128 .56819 .31733 .57395 .32685 .5714 .32081 .56569 Mtetra
.631 .737 .924 r
.32081 .56569 .32685 .5714 .3364 .56884 .33037 .56328 Mtetra
.63 .743 .929 r
.33037 .56328 .3364 .56884 .34599 .5662 .33997 .56086 Mtetra
.631 .752 .935 r
.33997 .56086 .34599 .5662 .35562 .56345 .34961 .55837 Mtetra
.636 .764 .94 r
.34961 .55837 .35562 .56345 .36529 .56055 .35929 .55574 Mtetra
.644 .778 .945 r
.35929 .55574 .36529 .56055 .37501 .55745 .36902 .55288 Mtetra
.653 .79 .948 r
.36902 .55288 .37501 .55745 .38477 .5542 .3788 .5498 Mtetra
.663 .8 .948 r
.3788 .5498 .38477 .5542 .39457 .55082 .38862 .54646 Mtetra
.669 .804 .947 r
.38862 .54646 .39457 .55082 .40441 .54737 .39848 .54297 Mtetra
.673 .804 .945 r
.39848 .54297 .40441 .54737 .41427 .54391 .40838 .53939 Mtetra
.674 .8 .942 r
.40838 .53939 .41427 .54391 .42418 .54047 .41832 .53577 Mtetra
.673 .794 .939 r
.41832 .53577 .42418 .54047 .43411 .53709 .42828 .53219 Mtetra
.671 .787 .936 r
.42828 .53219 .43411 .53709 .44408 .53375 .43828 .52866 Mtetra
.668 .779 .933 r
.43828 .52866 .44408 .53375 .45408 .53046 .44831 .52521 Mtetra
.665 .773 .93 r
.44831 .52521 .45408 .53046 .46411 .52721 .45837 .52182 Mtetra
.663 .768 .928 r
.45837 .52182 .46411 .52721 .47419 .52399 .46847 .51848 Mtetra
.661 .764 .926 r
.46847 .51848 .47419 .52399 .48429 .52078 .47861 .51518 Mtetra
.659 .761 .925 r
.47861 .51518 .48429 .52078 .49444 .51758 .48878 .51191 Mtetra
.658 .759 .924 r
.48878 .51191 .49444 .51758 .50462 .51439 .49899 .50865 Mtetra
.657 .757 .923 r
.49899 .50865 .50462 .51439 .51484 .51119 .50923 .50541 Mtetra
.657 .756 .923 r
.50923 .50541 .51484 .51119 .5251 .50799 .51952 .50217 Mtetra
.656 .755 .923 r
.51952 .50217 .5251 .50799 .5354 .50478 .52984 .49892 Mtetra
.656 .755 .922 r
.52984 .49892 .5354 .50478 .54573 .50156 .5402 .49567 Mtetra
.656 .754 .922 r
.5402 .49567 .54573 .50156 .55611 .49833 .5506 .49242 Mtetra
.5506 .49242 .55611 .49833 .56652 .4951 .56104 .48916 Mtetra
.655 .754 .922 r
.56104 .48916 .56652 .4951 .57697 .49185 .57152 .4859 Mtetra
.655 .754 .923 r
.57152 .4859 .57697 .49185 .58747 .48859 .58204 .48262 Mtetra
.58204 .48262 .58747 .48859 .598 .48533 .5926 .47935 Mtetra
.654 .754 .923 r
.5926 .47935 .598 .48533 .60857 .48205 .6032 .47607 Mtetra
.654 .755 .924 r
.6032 .47607 .60857 .48205 .61918 .47878 .61384 .4728 Mtetra
.653 .755 .925 r
.61384 .4728 .61918 .47878 .62984 .47549 .62452 .46953 Mtetra
.651 .756 .926 r
.62452 .46953 .62984 .47549 .64053 .47222 .63525 .46628 Mtetra
.65 .758 .928 r
.63525 .46628 .64053 .47222 .65127 .46894 .64601 .46306 Mtetra
.647 .76 .931 r
.64601 .46306 .65127 .46894 .66205 .46569 .65683 .45987 Mtetra
.644 .762 .934 r
.65683 .45987 .66205 .46569 .67287 .46246 .66768 .45674 Mtetra
.64 .765 .939 r
.66768 .45674 .67287 .46246 .68374 .45927 .67859 .45368 Mtetra
.635 .769 .944 r
.67859 .45368 .68374 .45927 .69466 .45613 .68954 .45069 Mtetra
.631 .774 .949 r
.68954 .45069 .69466 .45613 .70562 .45304 .70055 .44775 Mtetra
.627 .78 .954 r
.70055 .44775 .70562 .45304 .71663 .45001 .7116 .44485 Mtetra
.626 .786 .958 r
.7116 .44485 .71663 .45001 .72769 .44699 .7227 .44193 Mtetra
.629 .791 .96 r
.7227 .44193 .72769 .44699 .73879 .44396 .73384 .4389 Mtetra
.636 .795 .959 r
.73384 .4389 .73879 .44396 .74994 .44086 .74501 .4357 Mtetra
.648 .796 .954 r
.74501 .4357 .74994 .44086 .76112 .43763 .75622 .43226 Mtetra
.659 .793 .946 r
.75622 .43226 .76112 .43763 .77233 .43423 .76745 .42857 Mtetra
.669 .786 .936 r
.76745 .42857 .77233 .43423 .78358 .43064 .7787 .42465 Mtetra
.675 .777 .927 r
.7787 .42465 .78358 .43064 .79486 .42688 .78999 .42057 Mtetra
.677 .767 .918 r
.78999 .42057 .79486 .42688 .80617 .423 .80131 .41642 Mtetra
.677 .758 .912 r
.80131 .41642 .80617 .423 .81752 .41904 .81268 .41225 Mtetra
.674 .751 .909 r
.81268 .41225 .81752 .41904 .8289 .41506 .82409 .40817 Mtetra
.671 .747 .908 r
.82409 .40817 .8289 .41506 .84034 .41109 .83555 .40416 Mtetra
.667 .745 .909 r
.83555 .40416 .84034 .41109 .85182 .40717 .84707 .40025 Mtetra
.664 .745 .911 r
.84707 .40025 .85182 .40717 .86335 .40328 .85864 .39641 Mtetra
.662 .747 .913 r
.85864 .39641 .86335 .40328 .87492 .39941 .87026 .39261 Mtetra
.66 .75 .916 r
.87026 .39261 .87492 .39941 .88655 .39556 .88193 .38884 Mtetra
.658 .752 .919 r
.25789 .57635 .2641 .58177 .27347 .57895 .2673 .57335 Mtetra
.657 .746 .916 r
.2673 .57335 .27347 .57895 .28288 .57616 .27674 .57037 Mtetra
.654 .739 .912 r
.27674 .57037 .28288 .57616 .29232 .57343 .28621 .56745 Mtetra
.65 .732 .909 r
.28621 .56745 .29232 .57343 .30179 .57076 .2957 .56463 Mtetra
.644 .726 .908 r
.2957 .56463 .30179 .57076 .31128 .56819 .30522 .56195 Mtetra
.637 .721 .909 r
.30522 .56195 .31128 .56819 .32081 .56569 .31477 .55943 Mtetra
.628 .718 .911 r
.31477 .55943 .32081 .56569 .33037 .56328 .32434 .5571 Mtetra
.622 .72 .916 r
.32434 .5571 .33037 .56328 .33997 .56086 .33394 .55488 Mtetra
.618 .726 .923 r
.33394 .55488 .33997 .56086 .34961 .55837 .34358 .55273 Mtetra
.619 .739 .932 r
.34358 .55273 .34961 .55837 .35929 .55574 .35326 .5505 Mtetra
.625 .757 .941 r
.35326 .5505 .35929 .55574 .36902 .55288 .363 .54806 Mtetra
.635 .777 .949 r
.363 .54806 .36902 .55288 .3788 .5498 .37278 .54535 Mtetra
.65 .797 .953 r
.37278 .54535 .3788 .5498 .38862 .54646 .38262 .54226 Mtetra
.661 .81 .955 r
.38262 .54226 .38862 .54646 .39848 .54297 .3925 .53889 Mtetra
.672 .818 .954 r
.3925 .53889 .39848 .54297 .40838 .53939 .40243 .53527 Mtetra
.677 .819 .951 r
.40243 .53527 .40838 .53939 .41832 .53577 .4124 .53153 Mtetra
.678 .815 .948 r
.4124 .53153 .41832 .53577 .42828 .53219 .4224 .52775 Mtetra
.678 .808 .945 r
.4224 .52775 .42828 .53219 .43828 .52866 .43243 .524 Mtetra
.674 .799 .941 r
.43243 .524 .43828 .52866 .44831 .52521 .44249 .52033 Mtetra
.671 .79 .938 r
.44249 .52033 .44831 .52521 .45837 .52182 .45258 .51674 Mtetra
.668 .783 .935 r
.45258 .51674 .45837 .52182 .46847 .51848 .46271 .51323 Mtetra
.665 .776 .932 r
.46271 .51323 .46847 .51848 .47861 .51518 .47287 .50979 Mtetra
.662 .771 .93 r
.47287 .50979 .47861 .51518 .48878 .51191 .48307 .50641 Mtetra
.66 .767 .929 r
.48307 .50641 .48878 .51191 .49899 .50865 .49331 .50307 Mtetra
.659 .764 .928 r
.49331 .50307 .49899 .50865 .50923 .50541 .50358 .49975 Mtetra
.658 .762 .927 r
.50358 .49975 .50923 .50541 .51952 .50217 .51389 .49645 Mtetra
.657 .76 .926 r
.51389 .49645 .51952 .50217 .52984 .49892 .52424 .49315 Mtetra
.656 .759 .926 r
.52424 .49315 .52984 .49892 .5402 .49567 .53463 .48987 Mtetra
.656 .759 .925 r
.53463 .48987 .5402 .49567 .5506 .49242 .54505 .48658 Mtetra
.655 .758 .925 r
.54505 .48658 .5506 .49242 .56104 .48916 .55552 .4833 Mtetra
.655 .758 .926 r
.55552 .4833 .56104 .48916 .57152 .4859 .56603 .48002 Mtetra
.654 .758 .926 r
.56603 .48002 .57152 .4859 .58204 .48262 .57657 .47674 Mtetra
.653 .758 .927 r
.57657 .47674 .58204 .48262 .5926 .47935 .58716 .47347 Mtetra
.652 .759 .928 r
.58716 .47347 .5926 .47935 .6032 .47607 .59779 .4702 Mtetra
.651 .76 .929 r
.59779 .4702 .6032 .47607 .61384 .4728 .60846 .46696 Mtetra
.649 .761 .931 r
.60846 .46696 .61384 .4728 .62452 .46953 .61917 .46374 Mtetra
.647 .763 .933 r
.61917 .46374 .62452 .46953 .63525 .46628 .62993 .46056 Mtetra
.644 .765 .937 r
.62993 .46056 .63525 .46628 .64601 .46306 .64073 .45743 Mtetra
.639 .768 .941 r
.64073 .45743 .64601 .46306 .65683 .45987 .65158 .45437 Mtetra
.634 .772 .946 r
.65158 .45437 .65683 .45987 .66768 .45674 .66247 .4514 Mtetra
.628 .777 .952 r
.66247 .4514 .66768 .45674 .67859 .45368 .67342 .44851 Mtetra
.621 .782 .959 r
.67342 .44851 .67859 .45368 .68954 .45069 .68442 .44571 Mtetra
.617 .789 .964 r
.68442 .44571 .68954 .45069 .70055 .44775 .69546 .44293 Mtetra
.615 .796 .969 r
.69546 .44293 .70055 .44775 .7116 .44485 .70656 .44012 Mtetra
.619 .802 .97 r
.70656 .44012 .7116 .44485 .7227 .44193 .71769 .43718 Mtetra
.631 .807 .967 r
.71769 .43718 .7227 .44193 .73384 .4389 .72886 .43399 Mtetra
.647 .807 .96 r
.72886 .43399 .73384 .4389 .74501 .4357 .74005 .43049 Mtetra
.665 .802 .948 r
.74005 .43049 .74501 .4357 .75622 .43226 .75126 .42662 Mtetra
.678 .791 .934 r
.75126 .42662 .75622 .43226 .76745 .42857 .76249 .42245 Mtetra
.686 .777 .92 r
.76249 .42245 .76745 .42857 .7787 .42465 .77375 .41806 Mtetra
.688 .762 .908 r
.77375 .41806 .7787 .42465 .78999 .42057 .78504 .41359 Mtetra
.684 .749 .9 r
.78504 .41359 .78999 .42057 .80131 .41642 .79637 .40918 Mtetra
.68 .739 .896 r
.79637 .40918 .80131 .41642 .81268 .41225 .80775 .40488 Mtetra
.673 .733 .896 r
.80775 .40488 .81268 .41225 .82409 .40817 .8192 .40078 Mtetra
.667 .731 .898 r
.8192 .40078 .82409 .40817 .83555 .40416 .8307 .39683 Mtetra
.662 .732 .902 r
.8307 .39683 .83555 .40416 .84707 .40025 .84226 .39303 Mtetra
.658 .735 .906 r
.84226 .39303 .84707 .40025 .85864 .39641 .85388 .38934 Mtetra
.656 .739 .911 r
.85388 .38934 .85864 .39641 .87026 .39261 .86555 .38569 Mtetra
.654 .745 .916 r
.86555 .38569 .87026 .39261 .88193 .38884 .87727 .38207 Mtetra
.665 .754 .916 r
.25164 .57089 .25789 .57635 .2673 .57335 .26108 .5677 Mtetra
.665 .747 .911 r
.26108 .5677 .2673 .57335 .27674 .57037 .27056 .56449 Mtetra
.664 .74 .907 r
.27056 .56449 .27674 .57037 .28621 .56745 .28006 .56131 Mtetra
.66 .731 .902 r
.28006 .56131 .28621 .56745 .2957 .56463 .28959 .55822 Mtetra
.654 .721 .898 r
.28959 .55822 .2957 .56463 .30522 .56195 .29915 .55527 Mtetra
.646 .71 .894 r
.29915 .55527 .30522 .56195 .31477 .55943 .30873 .55251 Mtetra
.634 .7 .893 r
.30873 .55251 .31477 .55943 .32434 .5571 .31832 .55003 Mtetra
.624 .693 .893 r
.31832 .55003 .32434 .5571 .33394 .55488 .32794 .54781 Mtetra
.612 .689 .898 r
.32794 .54781 .33394 .55488 .34358 .55273 .33758 .54587 Mtetra
.606 .694 .905 r
.33758 .54587 .34358 .55273 .35326 .5505 .34726 .54403 Mtetra
.605 .707 .917 r
.34726 .54403 .35326 .5505 .363 .54806 .35698 .54217 Mtetra
.611 .73 .93 r
.35698 .54217 .363 .54806 .37278 .54535 .36676 .5401 Mtetra
.625 .759 .943 r
.36676 .5401 .37278 .54535 .38262 .54226 .37659 .53763 Mtetra
.639 .788 .954 r
.37659 .53763 .38262 .54226 .3925 .53889 .38648 .53476 Mtetra
.656 .814 .959 r
.38648 .53476 .3925 .53889 .40243 .53527 .39642 .53144 Mtetra
.667 .83 .962 r
.39642 .53144 .40243 .53527 .4124 .53153 .40641 .52782 Mtetra
.676 .838 .961 r
.40641 .52782 .4124 .53153 .4224 .52775 .41644 .52399 Mtetra
.679 .837 .959 r
.41644 .52399 .4224 .52775 .43243 .524 .42651 .52008 Mtetra
.679 .831 .956 r
.42651 .52008 .43243 .524 .44249 .52033 .43661 .51618 Mtetra
.678 .822 .953 r
.43661 .51618 .44249 .52033 .45258 .51674 .44674 .51233 Mtetra
.674 .812 .949 r
.44674 .51233 .45258 .51674 .46271 .51323 .4569 .50859 Mtetra
.671 .803 .946 r
.4569 .50859 .46271 .51323 .47287 .50979 .46709 .50493 Mtetra
.667 .794 .942 r
.46709 .50493 .47287 .50979 .48307 .50641 .47732 .50136 Mtetra
.664 .787 .939 r
.47732 .50136 .48307 .50641 .49331 .50307 .48759 .49786 Mtetra
.662 .781 .937 r
.48759 .49786 .49331 .50307 .50358 .49975 .49789 .49442 Mtetra
.66 .777 .935 r
.49789 .49442 .50358 .49975 .51389 .49645 .50822 .49102 Mtetra
.658 .773 .934 r
.50822 .49102 .51389 .49645 .52424 .49315 .5186 .48765 Mtetra
.657 .771 .933 r
.5186 .48765 .52424 .49315 .53463 .48987 .52901 .48431 Mtetra
.656 .769 .933 r
.52901 .48431 .53463 .48987 .54505 .48658 .53947 .48099 Mtetra
.654 .768 .933 r
.53947 .48099 .54505 .48658 .55552 .4833 .54996 .47768 Mtetra
.653 .768 .933 r
.54996 .47768 .55552 .4833 .56603 .48002 .5605 .4744 Mtetra
.652 .768 .934 r
.5605 .4744 .56603 .48002 .57657 .47674 .57107 .47113 Mtetra
.65 .769 .936 r
.57107 .47113 .57657 .47674 .58716 .47347 .58169 .46788 Mtetra
.648 .77 .938 r
.58169 .46788 .58716 .47347 .59779 .4702 .59235 .46467 Mtetra
.645 .772 .94 r
.59235 .46467 .59779 .4702 .60846 .46696 .60305 .46151 Mtetra
.641 .775 .944 r
.60305 .46151 .60846 .46696 .61917 .46374 .6138 .4584 Mtetra
.637 .778 .949 r
.6138 .4584 .61917 .46374 .62993 .46056 .62459 .45536 Mtetra
.63 .783 .954 r
.62459 .45536 .62993 .46056 .64073 .45743 .63543 .45241 Mtetra
.623 .788 .961 r
.63543 .45241 .64073 .45743 .65158 .45437 .64632 .44956 Mtetra
.614 .794 .968 r
.64632 .44956 .65158 .45437 .66247 .4514 .65726 .4468 Mtetra
.607 .801 .974 r
.65726 .4468 .66247 .4514 .67342 .44851 .66825 .4441 Mtetra
.601 .808 .979 r
.66825 .4441 .67342 .44851 .68442 .44571 .67928 .44142 Mtetra
.602 .815 .981 r
.67928 .44142 .68442 .44571 .69546 .44293 .69037 .43865 Mtetra
.613 .82 .98 r
.69037 .43865 .69546 .44293 .70656 .44012 .70149 .43567 Mtetra
.631 .82 .973 r
.70149 .43567 .70656 .44012 .71769 .43718 .71264 .43238 Mtetra
.657 .815 .96 r
.71264 .43238 .71769 .43718 .72886 .43399 .72381 .42862 Mtetra
.678 .801 .941 r
.72381 .42862 .72886 .43399 .74005 .43049 .73499 .42445 Mtetra
.693 .781 .919 r
.73499 .42445 .74005 .43049 .75126 .42662 .74619 .41986 Mtetra
.698 .76 .9 r
.74619 .41986 .75126 .42662 .76249 .42245 .75741 .41505 Mtetra
.696 .74 .885 r
.75741 .41505 .76249 .42245 .77375 .41806 .76866 .41021 Mtetra
.69 .725 .876 r
.76866 .41021 .77375 .41806 .78504 .41359 .77996 .40547 Mtetra
.681 .715 .874 r
.77996 .40547 .78504 .41359 .79637 .40918 .79132 .40101 Mtetra
.673 .711 .877 r
.79132 .40101 .79637 .40918 .80775 .40488 .80274 .39681 Mtetra
.664 .711 .882 r
.80274 .39681 .80775 .40488 .8192 .40078 .81424 .3929 Mtetra
.658 .714 .89 r
.81424 .3929 .8192 .40078 .8307 .39683 .82579 .3892 Mtetra
.653 .72 .898 r
.82579 .3892 .8307 .39683 .84226 .39303 .83741 .38563 Mtetra
.65 .727 .905 r
.83741 .38563 .84226 .39303 .85388 .38934 .84908 .38215 Mtetra
.648 .734 .912 r
.84908 .38215 .85388 .38934 .86555 .38569 .86081 .37871 Mtetra
.648 .741 .918 r
.86081 .37871 .86555 .38569 .87727 .38207 .87259 .37524 Mtetra
.671 .755 .914 r
.24535 .5654 .25164 .57089 .26108 .5677 .25483 .56204 Mtetra
.673 .75 .909 r
.25483 .56204 .26108 .5677 .27056 .56449 .26434 .55862 Mtetra
.673 .744 .904 r
.26434 .55862 .27056 .56449 .28006 .56131 .27388 .55517 Mtetra
.671 .735 .898 r
.27388 .55517 .28006 .56131 .28959 .55822 .28345 .55175 Mtetra
.668 .724 .891 r
.28345 .55175 .28959 .55822 .29915 .55527 .29305 .54838 Mtetra
.661 .71 .884 r
.29305 .54838 .29915 .55527 .30873 .55251 .30267 .54519 Mtetra
.649 .694 .878 r
.30267 .54519 .30873 .55251 .31832 .55003 .31231 .54228 Mtetra
.635 .678 .873 r
.31231 .54228 .31832 .55003 .32794 .54781 .32196 .53976 Mtetra
.616 .663 .873 r
.32196 .53976 .32794 .54781 .33758 .54587 .33162 .53774 Mtetra
.601 .656 .876 r
.33162 .53774 .33758 .54587 .34726 .54403 .3413 .53609 Mtetra
.587 .656 .885 r
.3413 .53609 .34726 .54403 .35698 .54217 .351 .53477 Mtetra
.583 .671 .9 r
.351 .53477 .35698 .54217 .36676 .5401 .36075 .53346 Mtetra
.589 .699 .918 r
.36075 .53346 .36676 .5401 .37659 .53763 .37056 .5319 Mtetra
.603 .736 .939 r
.37056 .5319 .37659 .53763 .38648 .53476 .38043 .52991 Mtetra
.625 .778 .954 r
.38043 .52991 .38648 .53476 .39642 .53144 .39037 .5273 Mtetra
.643 .813 .965 r
.39037 .5273 .39642 .53144 .40641 .52782 .40037 .52419 Mtetra
.661 .839 .968 r
.40037 .52419 .40641 .52782 .41644 .52399 .41043 .52059 Mtetra
.672 .852 .968 r
.41043 .52059 .41644 .52399 .42651 .52008 .42052 .51672 Mtetra
.678 .855 .967 r
.42052 .51672 .42651 .52008 .43661 .51618 .43066 .5127 Mtetra
.68 .852 .965 r
.43066 .5127 .43661 .51618 .44674 .51233 .44082 .50864 Mtetra
.678 .844 .962 r
.44082 .50864 .44674 .51233 .4569 .50859 .45102 .50465 Mtetra
.676 .834 .959 r
.45102 .50465 .4569 .50859 .46709 .50493 .46125 .50074 Mtetra
.672 .824 .956 r
.46125 .50074 .46709 .50493 .47732 .50136 .47152 .49694 Mtetra
.669 .815 .953 r
.47152 .49694 .47732 .50136 .48759 .49786 .48181 .49324 Mtetra
.665 .806 .951 r
.48181 .49324 .48759 .49786 .49789 .49442 .49214 .48963 Mtetra
.662 .8 .949 r
.49214 .48963 .49789 .49442 .50822 .49102 .50251 .4861 Mtetra
.659 .795 .947 r
.50251 .4861 .50822 .49102 .5186 .48765 .51292 .48263 Mtetra
.657 .791 .946 r
.51292 .48263 .5186 .48765 .52901 .48431 .52336 .47921 Mtetra
.654 .788 .946 r
.52336 .47921 .52901 .48431 .53947 .48099 .53384 .47584 Mtetra
.652 .786 .946 r
.53384 .47584 .53947 .48099 .54996 .47768 .54437 .47251 Mtetra
.65 .785 .947 r
.54437 .47251 .54996 .47768 .5605 .4744 .55493 .46923 Mtetra
.647 .786 .948 r
.55493 .46923 .5605 .4744 .57107 .47113 .56554 .46599 Mtetra
.643 .787 .95 r
.56554 .46599 .57107 .47113 .58169 .46788 .57618 .46281 Mtetra
.639 .788 .954 r
.57618 .46281 .58169 .46788 .59235 .46467 .58688 .45969 Mtetra
.634 .791 .958 r
.58688 .45969 .59235 .46467 .60305 .46151 .59761 .45665 Mtetra
.627 .795 .963 r
.59761 .45665 .60305 .46151 .6138 .4584 .6084 .4537 Mtetra
.619 .799 .969 r
.6084 .4537 .6138 .4584 .62459 .45536 .61923 .45085 Mtetra
.608 .805 .975 r
.61923 .45085 .62459 .45536 .63543 .45241 .63011 .44811 Mtetra
.598 .811 .981 r
.63011 .44811 .63543 .45241 .64632 .44956 .64104 .44546 Mtetra
.588 .817 .986 r
.64104 .44546 .64632 .44956 .65726 .4468 .65202 .44287 Mtetra
.585 .823 .99 r
.65202 .44287 .65726 .4468 .66825 .4441 .66305 .44025 Mtetra
.59 .83 .99 r
.66305 .44025 .66825 .4441 .67928 .44142 .67413 .43749 Mtetra
.608 .834 .986 r
.67413 .43749 .67928 .44142 .69037 .43865 .68523 .43444 Mtetra
.639 .834 .975 r
.68523 .43444 .69037 .43865 .70149 .43567 .69636 .4309 Mtetra
.67 .822 .956 r
.69636 .4309 .70149 .43567 .71264 .43238 .70751 .42683 Mtetra
.698 .801 .929 r
.70751 .42683 .71264 .43238 .72381 .42862 .71865 .42212 Mtetra
.71 .772 .901 r
.71865 .42212 .72381 .42862 .73499 .42445 .72981 .41696 Mtetra
.712 .743 .876 r
.72981 .41696 .73499 .42445 .74619 .41986 .74098 .41154 Mtetra
.706 .718 .859 r
.74098 .41154 .74619 .41986 .75741 .41505 .75219 .40612 Mtetra
.694 .699 .85 r
.75219 .40612 .75741 .41505 .76866 .41021 .76345 .40102 Mtetra
.682 .688 .849 r
.76345 .40102 .76866 .41021 .77996 .40547 .77478 .39631 Mtetra
.668 .684 .855 r
.77478 .39631 .77996 .40547 .79132 .40101 .78618 .39212 Mtetra
.658 .686 .865 r
.78618 .39212 .79132 .40101 .80274 .39681 .79767 .38832 Mtetra
.65 .694 .878 r
.79767 .38832 .80274 .39681 .81424 .3929 .80922 .38481 Mtetra
.644 .703 .89 r
.80922 .38481 .81424 .3929 .82579 .3892 .82085 .38149 Mtetra
.642 .715 .9 r
.82085 .38149 .82579 .3892 .83741 .38563 .83252 .37823 Mtetra
.64 .724 .909 r
.83252 .37823 .83741 .38563 .84908 .38215 .84426 .37498 Mtetra
.64 .733 .915 r
.84426 .37498 .84908 .38215 .86081 .37871 .85604 .37171 Mtetra
.642 .74 .92 r
.85604 .37171 .86081 .37871 .87259 .37524 .86786 .36837 Mtetra
.67 .755 .914 r
.23902 .55988 .24535 .5654 .25483 .56204 .24851 .55651 Mtetra
.674 .756 .913 r
.24851 .55651 .25483 .56204 .26434 .55862 .25804 .55305 Mtetra
.677 .756 .911 r
.25804 .55305 .26434 .55862 .27388 .55517 .26762 .54949 Mtetra
.68 .754 .907 r
.26762 .54949 .27388 .55517 .28345 .55175 .27722 .54585 Mtetra
.683 .747 .9 r
.27722 .54585 .28345 .55175 .29305 .54838 .28687 .5421 Mtetra
.68 .735 .892 r
.28687 .5421 .29305 .54838 .30267 .54519 .29655 .53837 Mtetra
.674 .718 .882 r
.29655 .53837 .30267 .54519 .31231 .54228 .30625 .53477 Mtetra
.66 .694 .871 r
.30625 .53477 .31231 .54228 .32196 .53976 .31596 .5315 Mtetra
.64 .668 .861 r
.31596 .5315 .32196 .53976 .33162 .53774 .32567 .52875 Mtetra
.619 .643 .852 r
.32567 .52875 .33162 .53774 .3413 .53609 .33538 .5266 Mtetra
.594 .621 .848 r
.33538 .5266 .3413 .53609 .351 .53477 .3451 .52516 Mtetra
.579 .611 .849 r
.3451 .52516 .351 .53477 .36075 .53346 .35485 .52415 Mtetra
.568 .614 .859 r
.35485 .52415 .36075 .53346 .37056 .5319 .36462 .52338 Mtetra
.57 .636 .877 r
.36462 .52338 .37056 .5319 .38043 .52991 .37446 .52246 Mtetra
.584 .673 .901 r
.37446 .52246 .38043 .52991 .39037 .5273 .38437 .52108 Mtetra
.602 .721 .928 r
.38437 .52108 .39037 .5273 .40037 .52419 .39434 .51913 Mtetra
.627 .774 .951 r
.39434 .51913 .40037 .52419 .41043 .52059 .40439 .51648 Mtetra
.644 .817 .966 r
.40439 .51648 .41043 .52059 .42052 .51672 .41449 .51329 Mtetra
.657 .849 .974 r
.41449 .51329 .42052 .51672 .43066 .5127 .42464 .50966 Mtetra
.664 .868 .976 r
.42464 .50966 .43066 .5127 .44082 .50864 .43484 .50576 Mtetra
.666 .875 .977 r
.43484 .50576 .44082 .50864 .45102 .50465 .44507 .50175 Mtetra
.667 .876 .977 r
.44507 .50175 .45102 .50465 .46125 .50074 .45534 .4977 Mtetra
.665 .871 .977 r
.45534 .4977 .46125 .50074 .47152 .49694 .46564 .49372 Mtetra
.663 .864 .976 r
.46564 .49372 .47152 .49694 .48181 .49324 .47597 .48982 Mtetra
.66 .855 .975 r
.47597 .48982 .48181 .49324 .49214 .48963 .48634 .48601 Mtetra
.657 .847 .973 r
.48634 .48601 .49214 .48963 .50251 .4861 .49674 .48231 Mtetra
.653 .84 .972 r
.49674 .48231 .50251 .4861 .51292 .48263 .50718 .4787 Mtetra
.649 .835 .972 r
.50718 .4787 .51292 .48263 .52336 .47921 .51766 .47519 Mtetra
.645 .83 .972 r
.51766 .47519 .52336 .47921 .53384 .47584 .52818 .47175 Mtetra
.641 .827 .972 r
.52818 .47175 .53384 .47584 .54437 .47251 .53873 .46841 Mtetra
.636 .826 .974 r
.53873 .46841 .54437 .47251 .55493 .46923 .54933 .46514 Mtetra
.63 .826 .976 r
.54933 .46514 .55493 .46923 .56554 .46599 .55997 .46196 Mtetra
.623 .827 .979 r
.55997 .46196 .56554 .46599 .57618 .46281 .57065 .45887 Mtetra
.614 .829 .983 r
.57065 .45887 .57618 .46281 .58688 .45969 .58138 .45588 Mtetra
.604 .831 .987 r
.58138 .45588 .58688 .45969 .59761 .45665 .59216 .45299 Mtetra
.592 .835 .991 r
.59216 .45299 .59761 .45665 .6084 .4537 .60298 .4502 Mtetra
.58 .838 .994 r
.60298 .4502 .6084 .4537 .61923 .45085 .61386 .4475 Mtetra
.57 .841 .996 r
.61386 .4475 .61923 .45085 .63011 .44811 .62478 .44485 Mtetra
.567 .844 .997 r
.62478 .44485 .63011 .44811 .64104 .44546 .63575 .44218 Mtetra
.574 .847 .996 r
.63575 .44218 .64104 .44546 .65202 .44287 .64676 .43939 Mtetra
.596 .848 .992 r
.64676 .43939 .65202 .44287 .66305 .44025 .65781 .43634 Mtetra
.633 .844 .981 r
.65781 .43634 .66305 .44025 .67413 .43749 .66889 .43283 Mtetra
.669 .825 .959 r
.66889 .43283 .67413 .43749 .68523 .43444 .67999 .42877 Mtetra
.701 .797 .925 r
.67999 .42877 .68523 .43444 .69636 .4309 .69109 .42398 Mtetra
.714 .759 .888 r
.69109 .42398 .69636 .4309 .70751 .42683 .70219 .4186 Mtetra
.718 .724 .855 r
.70219 .4186 .70751 .42683 .71865 .42212 .7133 .41273 Mtetra
.713 .695 .832 r
.7133 .41273 .71865 .42212 .72981 .41696 .72443 .40671 Mtetra
.7 .672 .819 r
.72443 .40671 .72981 .41696 .74098 .41154 .7356 .40093 Mtetra
.688 .661 .817 r
.7356 .40093 .74098 .41154 .75219 .40612 .74683 .39557 Mtetra
.672 .655 .825 r
.74683 .39557 .75219 .40612 .76345 .40102 .75815 .39095 Mtetra
.659 .659 .839 r
.75815 .39095 .76345 .40102 .77478 .39631 .76955 .38694 Mtetra
.647 .67 .858 r
.76955 .38694 .77478 .39631 .78618 .39212 .78104 .38347 Mtetra
.637 .685 .878 r
.78104 .38347 .78618 .39212 .79767 .38832 .79261 .38034 Mtetra
.633 .703 .896 r
.79261 .38034 .79767 .38832 .80922 .38481 .80424 .37734 Mtetra
.631 .718 .91 r
.80424 .37734 .80922 .38481 .82085 .38149 .81593 .37437 Mtetra
.633 .731 .918 r
.81593 .37437 .82085 .38149 .83252 .37823 .82765 .37128 Mtetra
.636 .739 .923 r
.82765 .37128 .83252 .37823 .84426 .37498 .83943 .3681 Mtetra
.639 .744 .925 r
.83943 .3681 .84426 .37498 .85604 .37171 .85124 .36483 Mtetra
.642 .746 .924 r
.85124 .36483 .85604 .37171 .86786 .36837 .8631 .36144 Mtetra
.662 .753 .918 r
.23264 .55431 .23902 .55988 .24851 .55651 .24214 .55113 Mtetra
.666 .761 .921 r
.24214 .55113 .24851 .55651 .25804 .55305 .25168 .54785 Mtetra
.672 .77 .924 r
.25168 .54785 .25804 .55305 .26762 .54949 .26126 .54441 Mtetra
.68 .776 .923 r
.26126 .54441 .26762 .54949 .27722 .54585 .27089 .54075 Mtetra
.691 .779 .918 r
.27089 .54075 .27722 .54585 .28687 .5421 .28058 .5368 Mtetra
.698 .774 .91 r
.28058 .5368 .28687 .5421 .29655 .53837 .29031 .53264 Mtetra
.703 .76 .896 r
.29031 .53264 .29655 .53837 .30625 .53477 .30008 .52826 Mtetra
.696 .735 .881 r
.30008 .52826 .30625 .53477 .31596 .5315 .30987 .52397 Mtetra
.682 .702 .863 r
.30987 .52397 .31596 .5315 .32567 .52875 .31967 .51997 Mtetra
.657 .663 .844 r
.31967 .51997 .32567 .52875 .33538 .5266 .32947 .5166 Mtetra
.624 .624 .83 r
.32947 .5166 .33538 .5266 .3451 .52516 .33925 .5142 Mtetra
.595 .592 .819 r
.33925 .5142 .3451 .52516 .35485 .52415 .34902 .51271 Mtetra
.564 .569 .816 r
.34902 .51271 .35485 .52415 .36462 .52338 .35879 .51216 Mtetra
.549 .566 .824 r
.35879 .51216 .36462 .52338 .37446 .52246 .36859 .51205 Mtetra
.543 .579 .841 r
.36859 .51205 .37446 .52246 .38437 .52108 .37844 .51199 Mtetra
.55 .614 .87 r
.37844 .51199 .38437 .52108 .39434 .51913 .38836 .51157 Mtetra
.572 .668 .903 r
.38836 .51157 .39434 .51913 .40439 .51648 .39837 .51042 Mtetra
.595 .727 .936 r
.39837 .51042 .40439 .51648 .41449 .51329 .40845 .50854 Mtetra
.621 .787 .961 r
.40845 .50854 .41449 .51329 .42464 .50966 .4186 .50588 Mtetra
.637 .832 .975 r
.4186 .50588 .42464 .50966 .43484 .50576 .42881 .50265 Mtetra
.647 .863 .981 r
.42881 .50265 .43484 .50576 .44507 .50175 .43907 .49901 Mtetra
.652 .88 .982 r
.43907 .49901 .44507 .50175 .45534 .4977 .44937 .49514 Mtetra
.652 .887 .983 r
.44937 .49514 .45534 .4977 .46564 .49372 .4597 .49117 Mtetra
.65 .889 .983 r
.4597 .49117 .46564 .49372 .47597 .48982 .47007 .4872 Mtetra
.647 .886 .984 r
.47007 .4872 .47597 .48982 .48634 .48601 .48048 .48328 Mtetra
.643 .881 .985 r
.48048 .48328 .48634 .48601 .49674 .48231 .49092 .47945 Mtetra
.638 .876 .985 r
.49092 .47945 .49674 .48231 .50718 .4787 .5014 .47574 Mtetra
.633 .871 .986 r
.5014 .47574 .50718 .4787 .51766 .47519 .51191 .47213 Mtetra
.627 .866 .987 r
.51191 .47213 .51766 .47519 .52818 .47175 .52246 .46865 Mtetra
.619 .863 .989 r
.52246 .46865 .52818 .47175 .53873 .46841 .53306 .46528 Mtetra
.611 .86 .99 r
.53306 .46528 .53873 .46841 .54933 .46514 .54369 .46202 Mtetra
.601 .859 .992 r
.54369 .46202 .54933 .46514 .55997 .46196 .55437 .45889 Mtetra
.591 .858 .994 r
.55437 .45889 .55997 .46196 .57065 .45887 .56509 .45587 Mtetra
.579 .857 .996 r
.56509 .45587 .57065 .45887 .58138 .45588 .57586 .45296 Mtetra
.568 .857 .997 r
.57586 .45296 .58138 .45588 .59216 .45299 .58667 .45014 Mtetra
.558 .857 .997 r
.58667 .45014 .59216 .45299 .60298 .4502 .59754 .44738 Mtetra
.556 .858 .997 r
.59754 .44738 .60298 .4502 .61386 .4475 .60845 .44462 Mtetra
.563 .859 .997 r
.60845 .44462 .61386 .4475 .62478 .44485 .6194 .44176 Mtetra
.587 .86 .995 r
.6194 .44176 .62478 .44485 .63575 .44218 .6304 .43867 Mtetra
.625 .857 .987 r
.6304 .43867 .63575 .44218 .64676 .43939 .64143 .43515 Mtetra
.667 .841 .967 r
.64143 .43515 .64676 .43939 .65781 .43634 .65247 .43106 Mtetra
.705 .812 .932 r
.65247 .43106 .65781 .43634 .66889 .43283 .66353 .42617 Mtetra
.724 .77 .89 r
.66353 .42617 .66889 .43283 .67999 .42877 .67458 .42052 Mtetra
.731 .728 .848 r
.67458 .42052 .67999 .42877 .69109 .42398 .68563 .41411 Mtetra
.725 .689 .816 r
.68563 .41411 .69109 .42398 .70219 .4186 .69668 .40732 Mtetra
.712 .658 .795 r
.69668 .40732 .70219 .4186 .7133 .41273 .70776 .40057 Mtetra
.697 .638 .786 r
.70776 .40057 .7133 .41273 .72443 .40671 .71888 .39425 Mtetra
.676 .624 .789 r
.71888 .39425 .72443 .40671 .7356 .40093 .7301 .38891 Mtetra
.66 .623 .802 r
.7301 .38891 .7356 .40093 .74683 .39557 .74141 .38449 Mtetra
.64 .63 .825 r
.74141 .38449 .74683 .39557 .75815 .39095 .75283 .38107 Mtetra
.625 .648 .853 r
.75283 .38107 .75815 .39095 .76955 .38694 .76435 .37831 Mtetra
.615 .676 .885 r
.76435 .37831 .76955 .38694 .78104 .38347 .77595 .37585 Mtetra
.608 .703 .911 r
.77595 .37585 .78104 .38347 .79261 .38034 .78761 .37348 Mtetra
.613 .731 .93 r
.78761 .37348 .79261 .38034 .80424 .37734 .79931 .37089 Mtetra
.618 .749 .939 r
.79931 .37089 .80424 .37734 .81593 .37437 .81105 .36808 Mtetra
.63 .761 .941 r
.81105 .36808 .81593 .37437 .82765 .37128 .82281 .36495 Mtetra
.638 .764 .939 r
.82281 .36495 .82765 .37128 .83943 .3681 .83461 .36161 Mtetra
.645 .762 .934 r
.83461 .36161 .83943 .3681 .85124 .36483 .84644 .35809 Mtetra
.65 .756 .927 r
.84644 .35809 .85124 .36483 .8631 .36144 .85831 .35446 Mtetra
.647 .749 .924 r
.22623 .54871 .23264 .55431 .24214 .55113 .23571 .54587 Mtetra
.647 .762 .933 r
.23571 .54587 .24214 .55113 .25168 .54785 .24524 .54298 Mtetra
.652 .779 .941 r
.24524 .54298 .25168 .54785 .26126 .54441 .25481 .53993 Mtetra
.661 .797 .948 r
.25481 .53993 .26126 .54441 .27089 .54075 .26444 .53664 Mtetra
.675 .815 .95 r
.26444 .53664 .27089 .54075 .28058 .5368 .27412 .533 Mtetra
.691 .831 .95 r
.27412 .533 .28058 .5368 .29031 .53264 .28387 .52895 Mtetra
.712 .839 .942 r
.28387 .52895 .29031 .53264 .30008 .52826 .29368 .52438 Mtetra
.725 .833 .932 r
.29368 .52438 .30008 .52826 .30987 .52397 .30355 .51949 Mtetra
.732 .812 .914 r
.30355 .51949 .30987 .52397 .31967 .51997 .31345 .51434 Mtetra
.719 .771 .893 r
.31345 .51434 .31967 .51997 .32947 .5166 .32336 .50942 Mtetra
.692 .718 .868 r
.32336 .50942 .32947 .5166 .33925 .5142 .33327 .50509 Mtetra
.655 .657 .84 r
.33327 .50509 .33925 .5142 .34902 .51271 .34315 .5017 Mtetra
.612 .601 .815 r
.34315 .5017 .34902 .51271 .35879 .51216 .353 .49961 Mtetra
.58 .559 .796 r
.353 .49961 .35879 .51216 .36859 .51205 .36284 .49858 Mtetra
.553 .532 .786 r
.36284 .49858 .36859 .51205 .37844 .51199 .37269 .49849 Mtetra
.542 .526 .787 r
.37269 .49849 .37844 .51199 .38836 .51157 .38258 .49875 Mtetra
.542 .537 .799 r
.38258 .49875 .38836 .51157 .39837 .51042 .39252 .49894 Mtetra
.552 .565 .821 r
.39252 .49894 .39837 .51042 .40845 .50854 .40255 .49871 Mtetra
.573 .61 .852 r
.40255 .49871 .40845 .50854 .4186 .50588 .41265 .49776 Mtetra
.594 .663 .887 r
.41265 .49776 .4186 .50588 .42881 .50265 .42283 .49613 Mtetra
.616 .722 .922 r
.42283 .49613 .42881 .50265 .43907 .49901 .43307 .4938 Mtetra
.631 .776 .95 r
.43307 .4938 .43907 .49901 .44937 .49514 .44337 .49096 Mtetra
.639 .82 .97 r
.44337 .49096 .44937 .49514 .4597 .49117 .45373 .48774 Mtetra
.639 .851 .981 r
.45373 .48774 .4597 .49117 .47007 .4872 .46412 .48428 Mtetra
.633 .871 .986 r
.46412 .48428 .47007 .4872 .48048 .48328 .47456 .48069 Mtetra
.625 .883 .989 r
.47456 .48069 .48048 .48328 .49092 .47945 .48504 .47706 Mtetra
.615 .888 .989 r
.48504 .47706 .49092 .47945 .5014 .47574 .49555 .47345 Mtetra
.605 .89 .99 r
.49555 .47345 .5014 .47574 .51191 .47213 .5061 .46989 Mtetra
.596 .889 .99 r
.5061 .46989 .51191 .47213 .52246 .46865 .51669 .46641 Mtetra
.587 .887 .991 r
.51669 .46641 .52246 .46865 .53306 .46528 .52733 .46302 Mtetra
.579 .884 .991 r
.52733 .46302 .53306 .46528 .54369 .46202 .538 .45972 Mtetra
.573 .881 .992 r
.538 .45972 .54369 .46202 .55437 .45889 .54872 .45649 Mtetra
.572 .878 .993 r
.54872 .45649 .55437 .45889 .56509 .45587 .55948 .45332 Mtetra
.575 .874 .994 r
.55948 .45332 .56509 .45587 .57586 .45296 .57028 .45018 Mtetra
.586 .87 .994 r
.57028 .45018 .57586 .45296 .58667 .45014 .58113 .44698 Mtetra
.606 .863 .992 r
.58113 .44698 .58667 .45014 .59754 .44738 .59202 .44367 Mtetra
.634 .85 .982 r
.59202 .44367 .59754 .44738 .60845 .44462 .60295 .44011 Mtetra
.665 .828 .962 r
.60295 .44011 .60845 .44462 .6194 .44176 .61391 .43616 Mtetra
.69 .794 .929 r
.61391 .43616 .6194 .44176 .6304 .43867 .6249 .43168 Mtetra
.709 .754 .887 r
.6249 .43168 .6304 .43867 .64143 .43515 .63589 .42649 Mtetra
.715 .711 .845 r
.63589 .42649 .64143 .43515 .65247 .43106 .6469 .4206 Mtetra
.717 .674 .807 r
.6469 .4206 .65247 .43106 .66353 .42617 .6579 .41396 Mtetra
.71 .643 .779 r
.6579 .41396 .66353 .42617 .67458 .42052 .66891 .40688 Mtetra
.701 .619 .762 r
.66891 .40688 .67458 .42052 .68563 .41411 .67993 .39971 Mtetra
.69 .605 .756 r
.67993 .39971 .68563 .41411 .69668 .40732 .69099 .39289 Mtetra
.674 .596 .761 r
.69099 .39289 .69668 .40732 .70776 .40057 .70212 .38703 Mtetra
.659 .6 .778 r
.70212 .38703 .70776 .40057 .71888 .39425 .71335 .38225 Mtetra
.637 .612 .808 r
.71335 .38225 .71888 .39425 .7301 .38891 .7247 .3788 Mtetra
.616 .639 .85 r
.7247 .3788 .7301 .38891 .74141 .38449 .73616 .37632 Mtetra
.592 .678 .901 r
.73616 .37632 .74141 .38449 .75283 .38107 .74772 .37446 Mtetra
.568 .719 .944 r
.74772 .37446 .75283 .38107 .76435 .37831 .75936 .37284 Mtetra
.562 .762 .972 r
.75936 .37284 .76435 .37831 .77595 .37585 .77104 .37096 Mtetra
.567 .789 .983 r
.77104 .37096 .77595 .37585 .78761 .37348 .78275 .36874 Mtetra
.592 .807 .982 r
.78275 .36874 .78761 .37348 .79931 .37089 .79448 .36599 Mtetra
.616 .811 .975 r
.79448 .36599 .79931 .37089 .81105 .36808 .80623 .36281 Mtetra
.638 .806 .964 r
.80623 .36281 .81105 .36808 .82281 .36495 .81799 .35926 Mtetra
.652 .795 .951 r
.81799 .35926 .82281 .36495 .83461 .36161 .82978 .35544 Mtetra
.66 .782 .939 r
.82978 .35544 .83461 .36161 .84644 .35809 .84161 .35147 Mtetra
.663 .768 .927 r
.84161 .35147 .84644 .35809 .85831 .35446 .85348 .34743 Mtetra
.628 .744 .931 r
.21976 .54307 .22623 .54871 .23571 .54587 .22924 .54061 Mtetra
.623 .757 .943 r
.22924 .54061 .23571 .54587 .24524 .54298 .23874 .53819 Mtetra
.622 .776 .955 r
.23874 .53819 .24524 .54298 .25481 .53993 .24829 .5357 Mtetra
.623 .8 .967 r
.24829 .5357 .25481 .53993 .26444 .53664 .25789 .53305 Mtetra
.627 .827 .977 r
.25789 .53305 .26444 .53664 .27412 .533 .26754 .53016 Mtetra
.64 .861 .983 r
.26754 .53016 .27412 .533 .28387 .52895 .27727 .5268 Mtetra
.665 .894 .979 r
.27727 .5268 .28387 .52895 .29368 .52438 .28708 .52278 Mtetra
.695 .919 .969 r
.28708 .52278 .29368 .52438 .30355 .51949 .29697 .51802 Mtetra
.74 .928 .952 r
.29697 .51802 .30355 .51949 .31345 .51434 .30694 .51233 Mtetra
.767 .91 .937 r
.30694 .51233 .31345 .51434 .32336 .50942 .31697 .50612 Mtetra
.778 .861 .911 r
.31697 .50612 .32336 .50942 .33327 .50509 .32704 .49957 Mtetra
.751 .782 .878 r
.32704 .49957 .33327 .50509 .34315 .5017 .3371 .49347 Mtetra
.703 .696 .84 r
.3371 .49347 .34315 .5017 .353 .49961 .34712 .48843 Mtetra
.651 .617 .802 r
.34712 .48843 .353 .49961 .36284 .49858 .35709 .48482 Mtetra
.598 .553 .775 r
.35709 .48482 .36284 .49858 .37269 .49849 .36701 .48302 Mtetra
.564 .514 .758 r
.36701 .48302 .37269 .49849 .38258 .49875 .37692 .48254 Mtetra
.537 .491 .752 r
.37692 .48254 .38258 .49875 .39252 .49894 .38684 .48312 Mtetra
.527 .49 .758 r
.38684 .48312 .39252 .49894 .40255 .49871 .3968 .48405 Mtetra
.529 .505 .774 r
.3968 .48405 .40255 .49871 .41265 .49776 .40684 .4848 Mtetra
.539 .535 .799 r
.40684 .4848 .41265 .49776 .42283 .49613 .41695 .48506 Mtetra
.559 .579 .831 r
.41695 .48506 .42283 .49613 .43307 .4938 .42715 .48455 Mtetra
.579 .629 .866 r
.42715 .48455 .43307 .4938 .44337 .49096 .43743 .48334 Mtetra
.601 .684 .9 r
.43743 .48334 .44337 .49096 .45373 .48774 .44777 .48143 Mtetra
.616 .734 .93 r
.44777 .48143 .45373 .48774 .46412 .48428 .45817 .47901 Mtetra
.627 .776 .952 r
.45817 .47901 .46412 .48428 .47456 .48069 .46862 .47619 Mtetra
.631 .809 .968 r
.46862 .47619 .47456 .48069 .48504 .47706 .47912 .47311 Mtetra
.631 .832 .978 r
.47912 .47311 .48504 .47706 .49555 .47345 .48966 .46986 Mtetra
.628 .847 .983 r
.48966 .46986 .49555 .47345 .5061 .46989 .50025 .46651 Mtetra
.625 .855 .986 r
.50025 .46651 .5061 .46989 .51669 .46641 .51088 .46312 Mtetra
.623 .859 .988 r
.51088 .46312 .51669 .46641 .52733 .46302 .52154 .45971 Mtetra
.623 .859 .987 r
.52154 .45971 .52733 .46302 .538 .45972 .53225 .45627 Mtetra
.628 .856 .986 r
.53225 .45627 .538 .45972 .54872 .45649 .54301 .45279 Mtetra
.638 .849 .981 r
.54301 .45279 .54872 .45649 .55948 .45332 .5538 .44922 Mtetra
.652 .838 .972 r
.5538 .44922 .55948 .45332 .57028 .45018 .56463 .44548 Mtetra
.67 .82 .956 r
.56463 .44548 .57028 .45018 .58113 .44698 .5755 .44146 Mtetra
.689 .795 .931 r
.5755 .44146 .58113 .44698 .59202 .44367 .5864 .43704 Mtetra
.704 .762 .897 r
.5864 .43704 .59202 .44367 .60295 .44011 .59733 .43209 Mtetra
.715 .726 .859 r
.59733 .43209 .60295 .44011 .61391 .43616 .60827 .42644 Mtetra
.718 .688 .821 r
.60827 .42644 .61391 .43616 .6249 .43168 .61922 .42006 Mtetra
.717 .654 .786 r
.61922 .42006 .6249 .43168 .63589 .42649 .63017 .41289 Mtetra
.71 .623 .759 r
.63017 .41289 .63589 .42649 .6469 .4206 .64112 .4052 Mtetra
.7 .599 .74 r
.64112 .4052 .6469 .4206 .6579 .41396 .65208 .39731 Mtetra
.687 .58 .73 r
.65208 .39731 .6579 .41396 .66891 .40688 .66307 .38977 Mtetra
.669 .567 .73 r
.66307 .38977 .66891 .40688 .67993 .39971 .67412 .38329 Mtetra
.651 .563 .742 r
.67412 .38329 .67993 .39971 .69099 .39289 .68527 .37816 Mtetra
.624 .567 .77 r
.68527 .37816 .69099 .39289 .70212 .38703 .69655 .37489 Mtetra
.595 .589 .815 r
.69655 .37489 .70212 .38703 .71335 .38225 .70796 .37309 Mtetra
.552 .631 .883 r
.70796 .37309 .71335 .38225 .7247 .3788 .7195 .37239 Mtetra
.491 .69 .956 r
.7195 .37239 .7247 .3788 .73616 .37632 .73114 .37216 Mtetra
.431 .753 .995 r
.73114 .37216 .73616 .37632 .74772 .37446 .74283 .3716 Mtetra
.396 .789 .988 r
.74283 .3716 .74772 .37446 .75936 .37284 .75455 .37049 Mtetra
.44 .832 .983 r
.75455 .37049 .75936 .37284 .77104 .37096 .76627 .36843 Mtetra
.512 .863 .991 r
.76627 .36843 .77104 .37096 .78275 .36874 .77798 .3656 Mtetra
.588 .874 .994 r
.77798 .3656 .78275 .36874 .79448 .36599 .78969 .36208 Mtetra
.637 .863 .984 r
.78969 .36208 .79448 .36599 .80623 .36281 .80142 .35807 Mtetra
.663 .839 .967 r
.80142 .35807 .80623 .36281 .81799 .35926 .81316 .3538 Mtetra
.675 .815 .95 r
.81316 .3538 .81799 .35926 .82978 .35544 .82493 .34935 Mtetra
.68 .794 .935 r
.82493 .34935 .82978 .35544 .84161 .35147 .83675 .34483 Mtetra
.678 .775 .924 r
.83675 .34483 .84161 .35147 .85348 .34743 .84861 .34035 Mtetra
.622 .743 .933 r
.21326 .53739 .21976 .54307 .22924 .54061 .22274 .53504 Mtetra
.615 .745 .939 r
.22274 .53504 .22924 .54061 .23874 .53819 .23225 .5328 Mtetra
.609 .751 .945 r
.23225 .5328 .23874 .53819 .24829 .5357 .24179 .53062 Mtetra
.604 .762 .955 r
.24179 .53062 .24829 .5357 .25789 .53305 .25137 .52847 Mtetra
.595 .78 .968 r
.25137 .52847 .25789 .53305 .26754 .53016 .26098 .52634 Mtetra
.594 .811 .983 r
.26098 .52634 .26754 .53016 .27727 .5268 .27066 .52398 Mtetra
.594 .852 .993 r
.27066 .52398 .27727 .5268 .28708 .52278 .2804 .52123 Mtetra
.6 .901 .986 r
.2804 .52123 .28708 .52278 .29697 .51802 .29024 .51777 Mtetra
.617 .94 .953 r
.29024 .51777 .29697 .51802 .30694 .51233 .30017 .51328 Mtetra
.627 .959 .901 r
.30017 .51328 .30694 .51233 .31697 .50612 .3102 .50774 Mtetra
.674 .977 .869 r
.3102 .50774 .31697 .50612 .32704 .49957 .32033 .50102 Mtetra
.722 .988 .877 r
.32033 .50102 .32704 .49957 .3371 .49347 .33051 .49373 Mtetra
.777 .979 .91 r
.33051 .49373 .3371 .49347 .34712 .48843 .34071 .48627 Mtetra
.785 .908 .926 r
.34071 .48627 .34712 .48843 .35709 .48482 .35088 .47946 Mtetra
.735 .789 .896 r
.35088 .47946 .35709 .48482 .36701 .48302 .36101 .47397 Mtetra
.671 .669 .839 r
.36101 .47397 .36701 .48302 .37692 .48254 .37109 .46997 Mtetra
.612 .578 .792 r
.37109 .46997 .37692 .48254 .38684 .48312 .38113 .46769 Mtetra
.577 .523 .758 r
.38113 .46769 .38684 .48312 .3968 .48405 .39116 .46664 Mtetra
.555 .491 .738 r
.39116 .46664 .3968 .48405 .40684 .4848 .40121 .4665 Mtetra
.547 .479 .73 r
.40121 .4665 .40684 .4848 .41695 .48506 .41131 .46673 Mtetra
.549 .48 .73 r
.41131 .46673 .41695 .48506 .42715 .48455 .42146 .4669 Mtetra
.555 .49 .737 r
.42146 .4669 .42715 .48455 .43743 .48334 .43169 .46677 Mtetra
.566 .507 .749 r
.43169 .46677 .43743 .48334 .44777 .48143 .44199 .46613 Mtetra
.579 .528 .763 r
.44199 .46613 .44777 .48143 .45817 .47901 .45236 .46498 Mtetra
.593 .552 .778 r
.45236 .46498 .45817 .47901 .46862 .47619 .46279 .4633 Mtetra
.605 .575 .793 r
.46279 .4633 .46862 .47619 .47912 .47311 .47328 .46116 Mtetra
.618 .597 .807 r
.47328 .46116 .47912 .47311 .48966 .46986 .48382 .45863 Mtetra
.628 .615 .818 r
.48382 .45863 .48966 .46986 .50025 .46651 .49441 .45575 Mtetra
.637 .628 .825 r
.49441 .45575 .50025 .46651 .51088 .46312 .50505 .45259 Mtetra
.645 .637 .827 r
.50505 .45259 .51088 .46312 .52154 .45971 .51573 .44915 Mtetra
.652 .64 .825 r
.51573 .44915 .52154 .45971 .53225 .45627 .52645 .44543 Mtetra
.658 .638 .818 r
.52645 .44543 .53225 .45627 .54301 .45279 .53722 .44142 Mtetra
.663 .631 .807 r
.53722 .44142 .54301 .45279 .5538 .44922 .54802 .43707 Mtetra
.667 .621 .793 r
.54802 .43707 .5538 .44922 .56463 .44548 .55885 .4323 Mtetra
.671 .608 .777 r
.55885 .4323 .56463 .44548 .5755 .44146 .56971 .42708 Mtetra
.673 .595 .759 r
.56971 .42708 .5755 .44146 .5864 .43704 .58059 .42131 Mtetra
.674 .581 .743 r
.58059 .42131 .5864 .43704 .59733 .43209 .59149 .41502 Mtetra
.675 .569 .728 r
.59149 .41502 .59733 .43209 .60827 .42644 .6024 .4082 Mtetra
.673 .559 .718 r
.6024 .4082 .60827 .42644 .61922 .42006 .61332 .40106 Mtetra
.67 .552 .712 r
.61332 .40106 .61922 .42006 .63017 .41289 .62426 .39385 Mtetra
.665 .549 .713 r
.62426 .39385 .63017 .41289 .64112 .4052 .63524 .387 Mtetra
.656 .55 .723 r
.63524 .387 .64112 .4052 .65208 .39731 .64627 .38106 Mtetra
.645 .561 .746 r
.64627 .38106 .65208 .39731 .66307 .38977 .65738 .37638 Mtetra
.62 .582 .789 r
.65738 .37638 .66307 .38977 .67412 .38329 .6686 .37345 Mtetra
.58 .628 .864 r
.6686 .37345 .67412 .38329 .68527 .37816 .67995 .37206 Mtetra
.47 .691 .963 r
.67995 .37206 .68527 .37816 .69655 .37489 .69144 .37203 Mtetra
.229 .688 .949 r
.69144 .37203 .69655 .37489 .70796 .37309 .70303 .37268 Mtetra
0 .569 .733 r
.70303 .37268 .70796 .37309 .7195 .37239 .71469 .37317 Mtetra
.072 0 0 r
.71469 .37317 .7195 .37239 .73114 .37216 .7264 .37309 Mtetra
0 0 0 r
.7264 .37309 .73114 .37216 .74283 .3716 .7381 .37178 Mtetra
.228 .748 .792 r
.7381 .37178 .74283 .3716 .75455 .37049 .74978 .3694 Mtetra
.459 .877 .935 r
.74978 .3694 .75455 .37049 .76627 .36843 .76145 .36594 Mtetra
.603 .904 .985 r
.76145 .36594 .76627 .36843 .77798 .3656 .77311 .36175 Mtetra
.666 .875 .977 r
.77311 .36175 .77798 .3656 .78969 .36208 .78478 .35714 Mtetra
.689 .84 .956 r
.78478 .35714 .78969 .36208 .80142 .35807 .79647 .35228 Mtetra
.691 .809 .938 r
.79647 .35228 .80142 .35807 .81316 .3538 .80821 .34744 Mtetra
.69 .789 .926 r
.80821 .34744 .81316 .3538 .82493 .34935 .81999 .34261 Mtetra
.687 .776 .919 r
.81999 .34261 .82493 .34935 .83675 .34483 .83182 .33785 Mtetra
.682 .767 .915 r
.83182 .33785 .83675 .34483 .84861 .34035 .8437 .33321 Mtetra
.632 .745 .929 r
.20671 .53168 .21326 .53739 .22274 .53504 .21623 .52909 Mtetra
.626 .736 .926 r
.21623 .52909 .22274 .53504 .23225 .5328 .22577 .52664 Mtetra
.618 .727 .924 r
.22577 .52664 .23225 .5328 .24179 .53062 .23533 .52438 Mtetra
.605 .721 .926 r
.23533 .52438 .24179 .53062 .25137 .52847 .24492 .52236 Mtetra
.586 .72 .936 r
.24492 .52236 .25137 .52847 .26098 .52634 .25451 .5207 Mtetra
.567 .732 .952 r
.25451 .5207 .26098 .52634 .27066 .52398 .26414 .51924 Mtetra
.536 .757 .978 r
.26414 .51924 .27066 .52398 .2804 .52123 .27379 .51798 Mtetra
.501 .806 .999 r
.27379 .51798 .2804 .52123 .29024 .51777 .28351 .51649 Mtetra
.43 .843 .967 r
.28351 .51649 .29024 .51777 .30017 .51328 .29331 .51448 Mtetra
.321 .808 .799 r
.29331 .51448 .30017 .51328 .3102 .50774 .30323 .5114 Mtetra
0 0 0 r
.30323 .5114 .3102 .50774 .32033 .50102 .31328 .5067 Mtetra
.31328 .5067 .32033 .50102 .33051 .49373 .32347 .50034 Mtetra
.32347 .50034 .33051 .49373 .34071 .48627 .33378 .49211 Mtetra
.501 .841 .561 r
.33378 .49211 .34071 .48627 .35088 .47946 .34415 .48292 Mtetra
.728 .982 .767 r
.34415 .48292 .35088 .47946 .36101 .47397 .35454 .47339 Mtetra
.834 .956 .893 r
.35454 .47339 .36101 .47397 .37109 .46997 .36489 .46459 Mtetra
.777 .796 .868 r
.36489 .46459 .37109 .46997 .38113 .46769 .37518 .45738 Mtetra
.696 .655 .805 r
.37518 .45738 .38113 .46769 .39116 .46664 .3854 .45194 Mtetra
.63 .561 .758 r
.3854 .45194 .39116 .46664 .40121 .4665 .39557 .44851 Mtetra
.592 .508 .729 r
.39557 .44851 .40121 .4665 .41131 .46673 .40573 .44654 Mtetra
.568 .478 .712 r
.40573 .44654 .41131 .46673 .42146 .4669 .4159 .44568 Mtetra
.558 .465 .705 r
.4159 .44568 .42146 .4669 .43169 .46677 .4261 .44535 Mtetra
.556 .463 .704 r
.4261 .44535 .43169 .46677 .44199 .46613 .43636 .44512 Mtetra
.559 .468 .708 r
.43636 .44512 .44199 .46613 .45236 .46498 .44668 .44471 Mtetra
.567 .478 .713 r
.44668 .44471 .45236 .46498 .46279 .4633 .45707 .44388 Mtetra
.577 .491 .72 r
.45707 .44388 .46279 .4633 .47328 .46116 .46753 .44258 Mtetra
.588 .504 .727 r
.46753 .44258 .47328 .46116 .48382 .45863 .47804 .44072 Mtetra
.6 .517 .732 r
.47804 .44072 .48382 .45863 .49441 .45575 .48862 .43832 Mtetra
.611 .528 .736 r
.48862 .43832 .49441 .45575 .50505 .45259 .49924 .43538 Mtetra
.621 .536 .737 r
.49924 .43538 .50505 .45259 .51573 .44915 .50992 .4319 Mtetra
.63 .541 .735 r
.50992 .4319 .51573 .44915 .52645 .44543 .52063 .42789 Mtetra
.638 .543 .731 r
.52063 .42789 .52645 .44543 .53722 .44142 .53139 .42333 Mtetra
.645 .543 .725 r
.53139 .42333 .53722 .44142 .54802 .43707 .54217 .41823 Mtetra
.65 .54 .717 r
.54217 .41823 .54802 .43707 .55885 .4323 .55299 .41256 Mtetra
.653 .536 .709 r
.55299 .41256 .55885 .4323 .56971 .42708 .56382 .4064 Mtetra
.655 .531 .701 r
.56382 .4064 .56971 .42708 .58059 .42131 .57468 .39981 Mtetra
.654 .526 .696 r
.57468 .39981 .58059 .42131 .59149 .41502 .58555 .39302 Mtetra
.65 .521 .693 r
.58555 .39302 .59149 .41502 .6024 .4082 .59644 .38633 Mtetra
.644 .518 .695 r
.59644 .38633 .6024 .4082 .61332 .40106 .60738 .38016 Mtetra
.632 .517 .704 r
.60738 .38016 .61332 .40106 .62426 .39385 .61837 .37512 Mtetra
.617 .523 .725 r
.61837 .37512 .62426 .39385 .63524 .387 .62944 .37155 Mtetra
.584 .535 .767 r
.62944 .37155 .63524 .387 .64627 .38106 .64064 .37004 Mtetra
.524 .573 .846 r
.64064 .37004 .64627 .38106 .65738 .37638 .65196 .37034 Mtetra
.327 .616 .954 r
.65196 .37034 .65738 .37638 .6686 .37345 .66343 .37229 Mtetra
.166 0 0 r
.66343 .37229 .6686 .37345 .67995 .37206 .67502 .375 Mtetra
.407 0 0 r
.67502 .375 .67995 .37206 .69144 .37203 .68669 .37739 Mtetra
.425 0 0 r
.68669 .37739 .69144 .37203 .70303 .37268 .6984 .37881 Mtetra
.352 0 0 r
.6984 .37881 .70303 .37268 .71469 .37317 .71008 .37832 Mtetra
.214 0 0 r
.71008 .37832 .71469 .37317 .7264 .37309 .72173 .3761 Mtetra
0 0 0 r
.72173 .3761 .7264 .37309 .7381 .37178 .73332 .37223 Mtetra
.453 .884 .832 r
.73332 .37223 .7381 .37178 .74978 .3694 .74489 .36722 Mtetra
.67 .937 .966 r
.74489 .36722 .74978 .3694 .76145 .36594 .75646 .36167 Mtetra
.722 .876 .953 r
.75646 .36167 .76145 .36594 .77311 .36175 .76804 .35588 Mtetra
.718 .815 .925 r
.76804 .35588 .77311 .36175 .78478 .35714 .77967 .35028 Mtetra
.708 .778 .907 r
.77967 .35028 .78478 .35714 .79647 .35228 .79136 .34489 Mtetra
.695 .757 .9 r
.79136 .34489 .79647 .35228 .80821 .34744 .80312 .33985 Mtetra
.686 .748 .899 r
.80312 .33985 .80821 .34744 .81999 .34261 .81494 .33506 Mtetra
.679 .748 .903 r
.81494 .33506 .81999 .34261 .83182 .33785 .82682 .33047 Mtetra
.675 .752 .909 r
.82682 .33047 .83182 .33785 .8437 .33321 .83876 .32602 Mtetra
.657 .752 .92 r
.20012 .52592 .20671 .53168 .21623 .52909 .2097 .52276 Mtetra
.653 .732 .907 r
.2097 .52276 .21623 .52909 .22577 .52664 .21932 .51968 Mtetra
.644 .71 .895 r
.21932 .51968 .22577 .52664 .23533 .52438 .22895 .51681 Mtetra
.631 .689 .885 r
.22895 .51681 .23533 .52438 .24492 .52236 .23859 .51425 Mtetra
.613 .668 .879 r
.23859 .51425 .24492 .52236 .25451 .5207 .24824 .51216 Mtetra
.594 .649 .875 r
.24824 .51216 .25451 .5207 .26414 .51924 .25788 .51056 Mtetra
.568 .635 .878 r
.25788 .51056 .26414 .51924 .27379 .51798 .26752 .50956 Mtetra
.549 .635 .889 r
.26752 .50956 .27379 .51798 .28351 .51649 .27719 .50894 Mtetra
.524 .651 .915 r
.27719 .50894 .28351 .51649 .29331 .51448 .28688 .50861 Mtetra
.515 .707 .958 r
.28688 .50861 .29331 .51448 .30323 .5114 .29665 .50796 Mtetra
.498 .8 .999 r
.29665 .50796 .30323 .5114 .31328 .5067 .30652 .50652 Mtetra
.424 .862 .918 r
.30652 .50652 .31328 .5067 .32347 .50034 .31653 .5037 Mtetra
0 0 0 r
.31653 .5037 .32347 .50034 .33378 .49211 .32669 .49891 Mtetra
.32669 .49891 .33378 .49211 .34415 .48292 .33699 .49231 Mtetra
.33699 .49231 .34415 .48292 .35454 .47339 .3474 .48392 Mtetra
.3474 .48392 .35454 .47339 .36489 .46459 .35786 .47466 Mtetra
.35786 .47466 .36489 .46459 .37518 .45738 .36834 .4652 Mtetra
.36834 .4652 .37518 .45738 .3854 .45194 .37878 .45632 Mtetra
.475 .852 .626 r
.37878 .45632 .3854 .45194 .39557 .44851 .38919 .44864 Mtetra
.706 .974 .922 r
.38919 .44864 .39557 .44851 .40573 .44654 .39955 .44225 Mtetra
.718 .834 .937 r
.39955 .44225 .40573 .44654 .4159 .44568 .40989 .43727 Mtetra
.669 .69 .86 r
.40989 .43727 .4159 .44568 .4261 .44535 .42022 .43334 Mtetra
.631 .601 .801 r
.42022 .43334 .4261 .44535 .43636 .44512 .43056 .43025 Mtetra
.611 .552 .763 r
.43056 .43025 .43636 .44512 .44668 .44471 .44093 .42765 Mtetra
.601 .524 .74 r
.44093 .42765 .44668 .44471 .45707 .44388 .45134 .42525 Mtetra
.598 .509 .725 r
.45134 .42525 .45707 .44388 .46753 .44258 .4618 .42286 Mtetra
.598 .501 .716 r
.4618 .42286 .46753 .44258 .47804 .44072 .47231 .4203 Mtetra
.601 .499 .71 r
.47231 .4203 .47804 .44072 .48862 .43832 .48287 .41747 Mtetra
.605 .499 .706 r
.48287 .41747 .48862 .43832 .49924 .43538 .49348 .41432 Mtetra
.61 .501 .704 r
.49348 .41432 .49924 .43538 .50992 .4319 .50413 .41081 Mtetra
.615 .504 .704 r
.50413 .41081 .50992 .4319 .52063 .42789 .51482 .40693 Mtetra
.621 .508 .704 r
.51482 .40693 .52063 .42789 .53139 .42333 .52556 .40273 Mtetra
.626 .514 .706 r
.52556 .40273 .53139 .42333 .54217 .41823 .53633 .39825 Mtetra
.63 .521 .711 r
.53633 .39825 .54217 .41823 .55299 .41256 .54714 .39361 Mtetra
.633 .53 .719 r
.54714 .39361 .55299 .41256 .56382 .4064 .55798 .38896 Mtetra
.636 .544 .733 r
.55798 .38896 .56382 .4064 .57468 .39981 .56886 .38452 Mtetra
.635 .565 .758 r
.56886 .38452 .57468 .39981 .58555 .39302 .57979 .38057 Mtetra
.627 .599 .802 r
.57979 .38057 .58555 .39302 .59644 .38633 .59077 .37746 Mtetra
.6 .661 .881 r
.59077 .37746 .59644 .38633 .60738 .38016 .60183 .37543 Mtetra
.46 .742 .989 r
.60183 .37543 .60738 .38016 .61837 .37512 .61298 .37483 Mtetra
.052 0 0 r
.61298 .37483 .61837 .37512 .62944 .37155 .62424 .37556 Mtetra
.422 0 0 r
.62424 .37556 .62944 .37155 .64064 .37004 .63562 .37753 Mtetra
.504 .04 .084 r
.63562 .37753 .64064 .37004 .65196 .37034 .64711 .38011 Mtetra
.513 .083 .159 r
.64711 .38011 .65196 .37034 .66343 .37229 .65868 .38251 Mtetra
.491 .066 .16 r
.65868 .38251 .66343 .37229 .67502 .375 .6703 .38405 Mtetra
.418 0 .092 r
.6703 .38405 .67502 .375 .68669 .37739 .68192 .38374 Mtetra
.266 0 0 r
.68192 .38374 .68669 .37739 .6984 .37881 .69351 .38158 Mtetra
0 0 0 r
.69351 .38158 .6984 .37881 .71008 .37832 .70505 .3774 Mtetra
.619 .949 .934 r
.70505 .3774 .71008 .37832 .72173 .3761 .71654 .37177 Mtetra
.748 .876 .939 r
.71654 .37177 .72173 .3761 .73332 .37223 .72802 .36532 Mtetra
.748 .786 .884 r
.72802 .36532 .73332 .37223 .74489 .36722 .73951 .35853 Mtetra
.726 .73 .853 r
.73951 .35853 .74489 .36722 .75646 .36167 .75104 .35202 Mtetra
.71 .701 .84 r
.75104 .35202 .75646 .36167 .76804 .35588 .76262 .34589 Mtetra
.693 .687 .84 r
.76262 .34589 .76804 .35588 .77967 .35028 .77429 .34038 Mtetra
.681 .685 .847 r
.77429 .34038 .77967 .35028 .79136 .34489 .78604 .33538 Mtetra
.67 .69 .86 r
.78604 .33538 .79136 .34489 .80312 .33985 .79787 .33085 Mtetra
.663 .7 .874 r
.79787 .33085 .80312 .33985 .81494 .33506 .80977 .32666 Mtetra
.657 .715 .89 r
.80977 .32666 .81494 .33506 .82682 .33047 .82175 .32267 Mtetra
.655 .732 .906 r
.82175 .32267 .82682 .33047 .83876 .32602 .83378 .31877 Mtetra
.685 .758 .907 r
.19348 .52013 .20012 .52592 .2097 .52276 .20315 .51623 Mtetra
.682 .735 .89 r
.20315 .51623 .2097 .52276 .21932 .51968 .21286 .51232 Mtetra
.675 .709 .873 r
.21286 .51232 .21932 .51968 .22895 .51681 .22259 .50852 Mtetra
.664 .682 .857 r
.22259 .50852 .22895 .51681 .23859 .51425 .23234 .50494 Mtetra
.649 .653 .84 r
.23234 .50494 .23859 .51425 .24824 .51216 .24208 .5017 Mtetra
.629 .621 .824 r
.24208 .5017 .24824 .51216 .25788 .51056 .25182 .49899 Mtetra
.605 .591 .81 r
.25182 .49899 .25788 .51056 .26752 .50956 .26154 .497 Mtetra
.578 .562 .799 r
.26154 .497 .26752 .50956 .27719 .50894 .27124 .49586 Mtetra
.546 .537 .796 r
.27124 .49586 .27719 .50894 .28688 .50861 .28091 .49575 Mtetra
.516 .525 .804 r
.28091 .49575 .28688 .50861 .29665 .50796 .29058 .49649 Mtetra
.472 .527 .833 r
.29058 .49649 .29665 .50796 .30652 .50652 .30025 .49804 Mtetra
.42 .576 .902 r
.30025 .49804 .30652 .50652 .31653 .5037 .30999 .49962 Mtetra
.266 .663 .967 r
.30999 .49962 .31653 .5037 .32669 .49891 .31982 .50067 Mtetra
.11 0 0 r
.31982 .50067 .32669 .49891 .33699 .49231 .32981 .50019 Mtetra
.248 0 0 r
.32981 .50019 .33699 .49231 .3474 .48392 .33999 .49733 Mtetra
.27 0 .124 r
.33999 .49733 .3474 .48392 .35786 .47466 .35034 .49198 Mtetra
.242 0 .176 r
.35034 .49198 .35786 .47466 .36834 .4652 .36085 .48395 Mtetra
.208 0 .179 r
.36085 .48395 .36834 .4652 .37878 .45632 .37145 .47423 Mtetra
.149 0 .141 r
.37145 .47423 .37878 .45632 .38919 .44864 .38209 .4635 Mtetra
.051 0 .045 r
.38209 .4635 .38919 .44864 .39955 .44225 .39272 .45277 Mtetra
0 0 0 r
.39272 .45277 .39955 .44225 .40989 .43727 .40332 .44279 Mtetra
.459 .816 .543 r
.40332 .44279 .40989 .43727 .42022 .43334 .41389 .43386 Mtetra
.75 .988 .896 r
.41389 .43386 .42022 .43334 .43056 .43025 .42442 .42625 Mtetra
.766 .855 .917 r
.42442 .42625 .43056 .43025 .44093 .42765 .43492 .41976 Mtetra
.714 .721 .856 r
.43492 .41976 .44093 .42765 .45134 .42525 .44543 .41428 Mtetra
.675 .641 .808 r
.44543 .41428 .45134 .42525 .4618 .42286 .45595 .40952 Mtetra
.65 .593 .777 r
.45595 .40952 .4618 .42286 .47231 .4203 .46649 .40528 Mtetra
.636 .566 .758 r
.46649 .40528 .47231 .4203 .48287 .41747 .47706 .40138 Mtetra
.628 .55 .747 r
.47706 .40138 .48287 .41747 .49348 .41432 .48767 .39769 Mtetra
.623 .542 .743 r
.48767 .39769 .49348 .41432 .50413 .41081 .49831 .39414 Mtetra
.62 .541 .743 r
.49831 .39414 .50413 .41081 .51482 .40693 .509 .39074 Mtetra
.617 .544 .749 r
.509 .39074 .51482 .40693 .52556 .40273 .51973 .38755 Mtetra
.613 .553 .763 r
.51973 .38755 .52556 .40273 .53633 .39825 .5305 .3847 Mtetra
.605 .57 .788 r
.5305 .3847 .53633 .39825 .54714 .39361 .54133 .38237 Mtetra
.587 .6 .832 r
.54133 .38237 .54714 .39361 .55798 .38896 .55221 .38078 Mtetra
.535 .65 .908 r
.55221 .38078 .55798 .38896 .56886 .38452 .56316 .38021 Mtetra
.337 .697 .982 r
.56316 .38021 .56886 .38452 .57979 .38057 .5742 .3808 Mtetra
.229 0 0 r
.5742 .3808 .57979 .38057 .59077 .37746 .58533 .38272 Mtetra
.498 0 0 r
.58533 .38272 .59077 .37746 .60183 .37543 .59657 .38574 Mtetra
.553 .131 .194 r
.59657 .38574 .60183 .37543 .61298 .37483 .60792 .38955 Mtetra
.557 .176 .275 r
.60792 .38955 .61298 .37483 .62424 .37556 .61937 .39338 Mtetra
.54 .181 .307 r
.61937 .39338 .62424 .37556 .63562 .37753 .63089 .39621 Mtetra
.511 .159 .306 r
.63089 .39621 .63562 .37753 .64711 .38011 .64244 .39732 Mtetra
.451 .095 .269 r
.64244 .39732 .64711 .38011 .65868 .38251 .65395 .39571 Mtetra
.342 0 .165 r
.65395 .39571 .65868 .38251 .6703 .38405 .66542 .39153 Mtetra
.038 0 0 r
.66542 .39153 .6703 .38405 .68192 .38374 .67682 .3849 Mtetra
.649 .965 .808 r
.67682 .3849 .68192 .38374 .69351 .38158 .68816 .37668 Mtetra
.811 .863 .887 r
.68816 .37668 .69351 .38158 .70505 .3774 .69949 .36789 Mtetra
.764 .723 .814 r
.69949 .36789 .70505 .3774 .71654 .37177 .71083 .35912 Mtetra
.721 .65 .778 r
.71083 .35912 .71654 .37177 .72802 .36532 .72223 .35116 Mtetra
.695 .618 .766 r
.72223 .35116 .72802 .36532 .73951 .35853 .73371 .34407 Mtetra
.675 .604 .769 r
.73371 .34407 .73951 .35853 .75104 .35202 .74529 .33805 Mtetra
.661 .604 .78 r
.74529 .33805 .75104 .35202 .76262 .34589 .75696 .33289 Mtetra
.651 .613 .798 r
.75696 .33289 .76262 .34589 .77429 .34038 .76873 .32848 Mtetra
.642 .627 .82 r
.76873 .32848 .77429 .34038 .78604 .33538 .78059 .32461 Mtetra
.637 .647 .843 r
.78059 .32461 .78604 .33538 .79787 .33085 .79253 .3211 Mtetra
.633 .668 .867 r
.79253 .3211 .79787 .33085 .80977 .32666 .80454 .31782 Mtetra
.63 .691 .889 r
.80454 .31782 .80977 .32666 .82175 .32267 .81663 .31465 Mtetra
.629 .716 .909 r
.81663 .31465 .82175 .32267 .83378 .31877 .82876 .31146 Mtetra
.7 .761 .899 r
.18679 .51429 .19348 .52013 .20315 .51623 .19653 .50994 Mtetra
.701 .747 .887 r
.19653 .50994 .20315 .51623 .21286 .51232 .20632 .50548 Mtetra
.698 .731 .875 r
.20632 .50548 .21286 .51232 .22259 .50852 .21613 .50098 Mtetra
.693 .711 .862 r
.21613 .50098 .22259 .50852 .23234 .50494 .22597 .49652 Mtetra
.685 .687 .846 r
.22597 .49652 .23234 .50494 .24208 .5017 .23583 .49214 Mtetra
.67 .657 .828 r
.23583 .49214 .24208 .5017 .25182 .49899 .24569 .48805 Mtetra
.651 .623 .809 r
.24569 .48805 .25182 .49899 .26154 .497 .25555 .48442 Mtetra
.626 .585 .789 r
.25555 .48442 .26154 .497 .27124 .49586 .26538 .48153 Mtetra
.596 .547 .77 r
.26538 .48153 .27124 .49586 .28091 .49575 .27517 .47966 Mtetra
.565 .509 .752 r
.27517 .47966 .28091 .49575 .29058 .49649 .28493 .47893 Mtetra
.531 .475 .739 r
.28493 .47893 .29058 .49649 .30025 .49804 .29464 .47959 Mtetra
.506 .452 .731 r
.29464 .47959 .30025 .49804 .30999 .49962 .30435 .48127 Mtetra
.482 .439 .733 r
.30435 .48127 .30999 .49962 .31982 .50067 .31406 .48379 Mtetra
.477 .451 .75 r
.31406 .48379 .31982 .50067 .32981 .50019 .32386 .48625 Mtetra
.486 .495 .792 r
.32386 .48625 .32981 .50019 .33999 .49733 .33377 .48793 Mtetra
.513 .6 .878 r
.33377 .48793 .33999 .49733 .35034 .49198 .34383 .48811 Mtetra
.546 .806 .994 r
.34383 .48811 .35034 .49198 .36085 .48395 .35407 .48614 Mtetra
.295 .781 .71 r
.35407 .48614 .36085 .48395 .37145 .47423 .36445 .4822 Mtetra
.021 0 0 r
.36445 .4822 .37145 .47423 .38209 .4635 .37495 .47631 Mtetra
.166 0 .055 r
.37495 .47631 .38209 .4635 .39272 .45277 .38553 .46918 Mtetra
.232 0 .157 r
.38553 .46918 .39272 .45277 .40332 .44279 .39616 .46132 Mtetra
.27 0 .205 r
.39616 .46132 .40332 .44279 .41389 .43386 .4068 .4533 Mtetra
.295 0 .228 r
.4068 .4533 .41389 .43386 .42442 .42625 .41745 .44557 Mtetra
.31 0 .234 r
.41745 .44557 .42442 .42625 .43492 .41976 .42809 .43831 Mtetra
.321 0 .231 r
.42809 .43831 .43492 .41976 .44543 .41428 .43874 .43173 Mtetra
.328 0 .22 r
.43874 .43173 .44543 .41428 .45595 .40952 .44939 .42579 Mtetra
.334 0 .208 r
.44939 .42579 .45595 .40952 .46649 .40528 .46005 .42052 Mtetra
.34 0 .195 r
.46005 .42052 .46649 .40528 .47706 .40138 .47073 .41585 Mtetra
.35 0 .187 r
.47073 .41585 .47706 .40138 .48767 .39769 .48144 .41174 Mtetra
.364 0 .186 r
.48144 .41174 .48767 .39769 .49831 .39414 .49218 .40819 Mtetra
.382 .006 .194 r
.49218 .40819 .49831 .39414 .509 .39074 .50296 .40518 Mtetra
.405 .031 .211 r
.50296 .40518 .509 .39074 .51973 .38755 .51379 .40275 Mtetra
.43 .06 .234 r
.51379 .40275 .51973 .38755 .5305 .3847 .52466 .40093 Mtetra
.454 .091 .258 r
.52466 .40093 .5305 .3847 .54133 .38237 .53559 .39977 Mtetra
.475 .119 .281 r
.53559 .39977 .54133 .38237 .55221 .38078 .54659 .39929 Mtetra
.493 .142 .299 r
.54659 .39929 .55221 .38078 .56316 .38021 .55766 .39949 Mtetra
.504 .156 .31 r
.55766 .39949 .56316 .38021 .5742 .3808 .56881 .40019 Mtetra
.51 .161 .312 r
.56881 .40019 .5742 .3808 .58533 .38272 .58003 .40119 Mtetra
.505 .151 .301 r
.58003 .40119 .58533 .38272 .59657 .38574 .59133 .40205 Mtetra
.483 .117 .267 r
.59133 .40205 .59657 .38574 .60792 .38955 .6027 .40217 Mtetra
.428 .032 .183 r
.6027 .40217 .60792 .38955 .61937 .39338 .6141 .40105 Mtetra
.25 0 0 r
.6141 .40105 .61937 .39338 .63089 .39621 .6255 .39795 Mtetra
.364 .823 .726 r
.6255 .39795 .63089 .39621 .64244 .39732 .63688 .39281 Mtetra
.777 .869 .916 r
.63688 .39281 .64244 .39732 .65395 .39571 .64822 .38547 Mtetra
.759 .705 .801 r
.64822 .38547 .65395 .39571 .66542 .39153 .65951 .37657 Mtetra
.728 .624 .742 r
.65951 .37657 .66542 .39153 .67682 .3849 .67078 .36685 Mtetra
.707 .585 .716 r
.67078 .36685 .67682 .3849 .68816 .37668 .68204 .35704 Mtetra
.688 .562 .708 r
.68204 .35704 .68816 .37668 .69949 .36789 .69336 .34807 Mtetra
.673 .553 .71 r
.69336 .34807 .69949 .36789 .71083 .35912 .70474 .34015 Mtetra
.658 .55 .721 r
.70474 .34015 .71083 .35912 .72223 .35116 .71623 .33364 Mtetra
.647 .556 .738 r
.71623 .33364 .72223 .35116 .73371 .34407 .72782 .32832 Mtetra
.636 .568 .762 r
.72782 .32832 .73371 .34407 .74529 .33805 .73952 .32404 Mtetra
.627 .586 .788 r
.73952 .32404 .74529 .33805 .75696 .33289 .75132 .32053 Mtetra
.62 .608 .817 r
.75132 .32053 .75696 .33289 .76873 .32848 .76321 .31749 Mtetra
.614 .632 .845 r
.76321 .31749 .76873 .32848 .78059 .32461 .77518 .31476 Mtetra
.613 .657 .87 r
.77518 .31476 .78059 .32461 .79253 .3211 .78722 .31211 Mtetra
.61 .679 .89 r
.78722 .31211 .79253 .3211 .80454 .31782 .79933 .3095 Mtetra
.609 .699 .907 r
.79933 .3095 .80454 .31782 .81663 .31465 .81149 .30686 Mtetra
.611 .717 .92 r
.81149 .30686 .81663 .31465 .82876 .31146 .82371 .3041 Mtetra
.701 .761 .899 r
.18006 .50842 .18679 .51429 .19653 .50994 .18983 .50401 Mtetra
.705 .761 .895 r
.18983 .50401 .19653 .50994 .20632 .50548 .19964 .49944 Mtetra
.71 .759 .89 r
.19964 .49944 .20632 .50548 .21613 .50098 .2095 .49469 Mtetra
.714 .752 .883 r
.2095 .49469 .21613 .50098 .22597 .49652 .2194 .48976 Mtetra
.717 .74 .87 r
.2194 .48976 .22597 .49652 .23583 .49214 .22935 .48461 Mtetra
.713 .719 .854 r
.22935 .48461 .23583 .49214 .24569 .48805 .23933 .47936 Mtetra
.705 .689 .832 r
.23933 .47936 .24569 .48805 .25555 .48442 .24934 .47407 Mtetra
.688 .65 .807 r
.24934 .47407 .25555 .48442 .26538 .48153 .25936 .46898 Mtetra
.667 .606 .778 r
.25936 .46898 .26538 .48153 .27517 .47966 .26937 .46426 Mtetra
.639 .559 .748 r
.26937 .46426 .27517 .47966 .28493 .47893 .27936 .46021 Mtetra
.61 .513 .719 r
.27936 .46021 .28493 .47893 .29464 .47959 .28932 .45712 Mtetra
.58 .47 .693 r
.28932 .45712 .29464 .47959 .30435 .48127 .29923 .45531 Mtetra
.55 .434 .674 r
.29923 .45531 .30435 .48127 .31406 .48379 .30907 .45512 Mtetra
.524 .405 .66 r
.30907 .45512 .31406 .48379 .32386 .48625 .31887 .4566 Mtetra
.495 .383 .655 r
.31887 .4566 .32386 .48625 .33377 .48793 .32863 .45988 Mtetra
.472 .373 .662 r
.32863 .45988 .33377 .48793 .34383 .48811 .3384 .46428 Mtetra
.443 .375 .686 r
.3384 .46428 .34383 .48811 .35407 .48614 .34823 .46929 Mtetra
.405 .409 .751 r
.34823 .46929 .35407 .48614 .36445 .4822 .35817 .47384 Mtetra
.289 .516 .9 r
.35817 .47384 .36445 .4822 .37495 .47631 .36826 .4771 Mtetra
.256 0 0 r
.36826 .4771 .37495 .47631 .38553 .46918 .37852 .4786 Mtetra
.404 0 .094 r
.37852 .4786 .38553 .46918 .39616 .46132 .38893 .47796 Mtetra
.419 .059 .245 r
.38893 .47796 .39616 .46132 .4068 .4533 .39946 .47555 Mtetra
.419 .092 .302 r
.39946 .47555 .4068 .4533 .41745 .44557 .4101 .4716 Mtetra
.421 .109 .33 r
.4101 .4716 .41745 .44557 .42809 .43831 .42081 .46672 Mtetra
.423 .12 .344 r
.42081 .46672 .42809 .43831 .43874 .43173 .43156 .46134 Mtetra
.427 .127 .352 r
.43156 .46134 .43874 .43173 .44939 .42579 .44235 .45587 Mtetra
.433 .134 .356 r
.44235 .45587 .44939 .42579 .46005 .42052 .45316 .45065 Mtetra
.441 .141 .359 r
.45316 .45065 .46005 .42052 .47073 .41585 .46399 .44587 Mtetra
.45 .149 .362 r
.46399 .44587 .47073 .41585 .48144 .41174 .47485 .44168 Mtetra
.459 .157 .364 r
.47485 .44168 .48144 .41174 .49218 .40819 .48574 .43813 Mtetra
.469 .165 .367 r
.48574 .43813 .49218 .40819 .50296 .40518 .49666 .43523 Mtetra
.477 .173 .37 r
.49666 .43523 .50296 .40518 .51379 .40275 .50764 .43292 Mtetra
.484 .179 .373 r
.50764 .43292 .51379 .40275 .52466 .40093 .51866 .43105 Mtetra
.487 .181 .373 r
.51866 .43105 .52466 .40093 .53559 .39977 .52974 .42944 Mtetra
.485 .178 .37 r
.52974 .42944 .53559 .39977 .54659 .39929 .54088 .42775 Mtetra
.476 .167 .362 r
.54088 .42775 .54659 .39929 .55766 .39949 .55207 .42557 Mtetra
.455 .14 .342 r
.55207 .42557 .55766 .39949 .56881 .40019 .56331 .42243 Mtetra
.409 .084 .3 r
.56331 .42243 .56881 .40019 .58003 .40119 .57457 .41775 Mtetra
.307 0 .199 r
.57457 .41775 .58003 .40119 .59133 .40205 .58584 .41125 Mtetra
0 0 0 r
.58584 .41125 .59133 .40205 .6027 .40217 .59709 .40256 Mtetra
.819 .998 .843 r
.59709 .40256 .6027 .40217 .6141 .40105 .6083 .39206 Mtetra
.815 .744 .786 r
.6083 .39206 .6141 .40105 .6255 .39795 .61947 .3802 Mtetra
.738 .603 .707 r
.61947 .3802 .6255 .39795 .63688 .39281 .63061 .36785 Mtetra
.69 .534 .67 r
.63061 .36785 .63688 .39281 .64822 .38547 .64176 .3561 Mtetra
.663 .5 .655 r
.64176 .3561 .64822 .38547 .65951 .37657 .65294 .34547 Mtetra
.641 .481 .651 r
.65294 .34547 .65951 .37657 .67078 .36685 .6642 .33666 Mtetra
.627 .474 .656 r
.6642 .33666 .67078 .36685 .68204 .35704 .67555 .32956 Mtetra
.616 .477 .67 r
.67555 .32956 .68204 .35704 .69336 .34807 .68701 .32411 Mtetra
.608 .488 .691 r
.68701 .32411 .69336 .34807 .70474 .34015 .69858 .31999 Mtetra
.602 .508 .721 r
.69858 .31999 .70474 .34015 .71623 .33364 .71026 .31685 Mtetra
.597 .535 .756 r
.71026 .31685 .71623 .33364 .72782 .32832 .72203 .3144 Mtetra
.593 .569 .796 r
.72203 .3144 .72782 .32832 .73952 .32404 .73389 .31235 Mtetra
.588 .604 .836 r
.73389 .31235 .73952 .32404 .75132 .32053 .74583 .3105 Mtetra
.588 .64 .87 r
.74583 .3105 .75132 .32053 .76321 .31749 .75783 .30862 Mtetra
.587 .671 .897 r
.75783 .30862 .76321 .31749 .77518 .31476 .76989 .30664 Mtetra
.592 .696 .915 r
.76989 .30664 .77518 .31476 .78722 .31211 .782 .30442 Mtetra
.597 .713 .925 r
.782 .30442 .78722 .31211 .79933 .3095 .79415 .30202 Mtetra
.602 .723 .93 r
.79415 .30202 .79933 .3095 .81149 .30686 .80636 .29944 Mtetra
.608 .729 .931 r
.80636 .29944 .81149 .30686 .82371 .3041 .81861 .29669 Mtetra
.682 .757 .908 r
.17328 .5025 .18006 .50842 .18983 .50401 .18302 .4986 Mtetra
.689 .777 .918 r
.18302 .4986 .18983 .50401 .19964 .49944 .19281 .49453 Mtetra
.698 .797 .926 r
.19281 .49453 .19964 .49944 .2095 .49469 .20265 .49023 Mtetra
.71 .815 .93 r
.20265 .49023 .2095 .49469 .2194 .48976 .21255 .48561 Mtetra
.725 .829 .929 r
.21255 .48561 .2194 .48976 .22935 .48461 .22251 .48057 Mtetra
.738 .835 .924 r
.22251 .48057 .22935 .48461 .23933 .47936 .23254 .47514 Mtetra
.751 .83 .912 r
.23254 .47514 .23933 .47936 .24934 .47407 .24263 .46929 Mtetra
.755 .811 .897 r
.24263 .46929 .24934 .47407 .25936 .46898 .25276 .46316 Mtetra
.753 .778 .874 r
.25276 .46316 .25936 .46898 .26937 .46426 .26293 .45683 Mtetra
.736 .731 .846 r
.26293 .45683 .26937 .46426 .27936 .46021 .2731 .4506 Mtetra
.711 .675 .813 r
.2731 .4506 .27936 .46021 .28932 .45712 .28328 .44469 Mtetra
.675 .614 .779 r
.28328 .44469 .28932 .45712 .29923 .45531 .29342 .43957 Mtetra
.635 .554 .746 r
.29342 .43957 .29923 .45531 .30907 .45512 .30351 .43563 Mtetra
.594 .499 .716 r
.30351 .43563 .30907 .45512 .31887 .4566 .31353 .43323 Mtetra
.555 .45 .689 r
.31353 .43323 .31887 .4566 .32863 .45988 .32348 .43271 Mtetra
.528 .414 .668 r
.32348 .43271 .32863 .45988 .3384 .46428 .33339 .43381 Mtetra
.506 .387 .652 r
.33339 .43381 .3384 .46428 .34823 .46929 .34328 .43642 Mtetra
.499 .375 .642 r
.34328 .43642 .34823 .46929 .35817 .47384 .35321 .43974 Mtetra
.498 .371 .638 r
.35321 .43974 .35817 .47384 .36826 .4771 .36322 .4432 Mtetra
.505 .377 .64 r
.36322 .4432 .36826 .4771 .37852 .4786 .37333 .44619 Mtetra
.518 .391 .647 r
.37333 .44619 .37852 .4786 .38893 .47796 .38356 .44821 Mtetra
.532 .409 .659 r
.38356 .44821 .38893 .47796 .39946 .47555 .39391 .44915 Mtetra
.549 .435 .676 r
.39391 .44915 .39946 .47555 .4101 .4716 .40437 .44891 Mtetra
.567 .466 .698 r
.40437 .44891 .4101 .4716 .42081 .46672 .41493 .4477 Mtetra
.587 .503 .727 r
.41493 .4477 .42081 .46672 .43156 .46134 .42557 .44567 Mtetra
.606 .546 .761 r
.42557 .44567 .43156 .46134 .44235 .45587 .43628 .44305 Mtetra
.623 .593 .799 r
.43628 .44305 .44235 .45587 .45316 .45065 .44705 .44002 Mtetra
.637 .639 .835 r
.44705 .44002 .45316 .45065 .46399 .44587 .45787 .43673 Mtetra
.646 .676 .865 r
.45787 .43673 .46399 .44587 .47485 .44168 .46873 .43327 Mtetra
.652 .698 .88 r
.46873 .43327 .47485 .44168 .48574 .43813 .47964 .4297 Mtetra
.655 .699 .879 r
.47964 .4297 .48574 .43813 .49666 .43523 .4906 .426 Mtetra
.657 .681 .861 r
.4906 .426 .49666 .43523 .50764 .43292 .5016 .42214 Mtetra
.657 .648 .829 r
.5016 .42214 .50764 .43292 .51866 .43105 .51264 .41801 Mtetra
.655 .609 .79 r
.51264 .41801 .51866 .43105 .52974 .42944 .52373 .41346 Mtetra
.652 .571 .751 r
.52373 .41346 .52974 .42944 .54088 .42775 .53485 .40832 Mtetra
.65 .54 .717 r
.53485 .40832 .54088 .42775 .55207 .42557 .546 .40234 Mtetra
.647 .516 .689 r
.546 .40234 .55207 .42557 .56331 .42243 .55717 .39537 Mtetra
.647 .499 .667 r
.55717 .39537 .56331 .42243 .57457 .41775 .56835 .38718 Mtetra
.647 .487 .652 r
.56835 .38718 .57457 .41775 .58584 .41125 .57953 .37789 Mtetra
.648 .479 .642 r
.57953 .37789 .58584 .41125 .59709 .40256 .59068 .36759 Mtetra
.647 .475 .637 r
.59068 .36759 .59709 .40256 .6083 .39206 .60183 .35678 Mtetra
.645 .473 .636 r
.60183 .35678 .6083 .39206 .61947 .3802 .61297 .34608 Mtetra
.642 .474 .64 r
.61297 .34608 .61947 .3802 .63061 .36785 .62414 .33611 Mtetra
.635 .475 .648 r
.62414 .33611 .63061 .36785 .64176 .3561 .63536 .32764 Mtetra
.628 .481 .663 r
.63536 .32764 .64176 .3561 .65294 .34547 .64665 .32083 Mtetra
.616 .489 .685 r
.64665 .32083 .65294 .34547 .6642 .33666 .65805 .31593 Mtetra
.603 .504 .715 r
.65805 .31593 .6642 .33666 .67555 .32956 .66957 .31262 Mtetra
.589 .528 .754 r
.66957 .31262 .67555 .32956 .68701 .32411 .6812 .31052 Mtetra
.573 .562 .803 r
.6812 .31052 .68701 .32411 .69858 .31999 .69293 .30923 Mtetra
.558 .607 .858 r
.69293 .30923 .69858 .31999 .71026 .31685 .70475 .30829 Mtetra
.54 .655 .91 r
.70475 .30829 .71026 .31685 .72203 .3144 .71665 .30746 Mtetra
.528 .703 .95 r
.71665 .30746 .72203 .3144 .73389 .31235 .72861 .30643 Mtetra
.522 .74 .974 r
.72861 .30643 .73389 .31235 .74583 .3105 .74062 .30512 Mtetra
.533 .767 .983 r
.74062 .30512 .74583 .3105 .75783 .30862 .75268 .30337 Mtetra
.552 .782 .984 r
.75268 .30337 .75783 .30862 .76989 .30664 .76477 .30122 Mtetra
.578 .788 .979 r
.76477 .30122 .76989 .30664 .782 .30442 .77689 .29863 Mtetra
.6 .784 .969 r
.77689 .29863 .782 .30442 .79415 .30202 .78904 .29572 Mtetra
.616 .773 .956 r
.78904 .29572 .79415 .30202 .80636 .29944 .80124 .29255 Mtetra
.627 .758 .941 r
.80124 .29255 .80636 .29944 .81861 .29669 .81347 .28921 Mtetra
.646 .749 .924 r
.16646 .49655 .17328 .5025 .18302 .4986 .17612 .49352 Mtetra
.648 .781 .945 r
.17612 .49352 .18302 .4986 .19281 .49453 .18584 .49039 Mtetra
.652 .818 .963 r
.18584 .49039 .19281 .49453 .20265 .49023 .19561 .48702 Mtetra
.658 .856 .976 r
.19561 .48702 .20265 .49023 .21255 .48561 .20545 .48333 Mtetra
.667 .893 .979 r
.20545 .48333 .21255 .48561 .22251 .48057 .21537 .47918 Mtetra
.676 .924 .972 r
.21537 .47918 .22251 .48057 .23254 .47514 .22536 .4745 Mtetra
.69 .948 .958 r
.22536 .4745 .23254 .47514 .24263 .46929 .23544 .4692 Mtetra
.705 .963 .942 r
.23544 .4692 .24263 .46929 .25276 .46316 .2456 .46333 Mtetra
.728 .972 .93 r
.2456 .46333 .25276 .46316 .26293 .45683 .25582 .45689 Mtetra
.752 .972 .926 r
.25582 .45689 .26293 .45683 .2731 .4506 .26609 .45004 Mtetra
.778 .959 .927 r
.26609 .45004 .2731 .4506 .28328 .44469 .2764 .4429 Mtetra
.794 .922 .922 r
.2764 .4429 .28328 .44469 .29342 .43957 .28674 .43563 Mtetra
.789 .847 .895 r
.28674 .43563 .29342 .43957 .30351 .43563 .29709 .42838 Mtetra
.757 .743 .84 r
.29709 .42838 .30351 .43563 .31353 .43323 .30745 .42123 Mtetra
.71 .637 .774 r
.30745 .42123 .31353 .43323 .32348 .43271 .3178 .41433 Mtetra
.662 .548 .715 r
.3178 .41433 .32348 .43271 .33339 .43381 .32814 .40797 Mtetra
.623 .483 .671 r
.32814 .40797 .33339 .43381 .34328 .43642 .33845 .40242 Mtetra
.593 .437 .64 r
.33845 .40242 .34328 .43642 .35321 .43974 .34873 .3981 Mtetra
.569 .405 .619 r
.34873 .3981 .35321 .43974 .36322 .4432 .35895 .39528 Mtetra
.553 .384 .606 r
.35895 .39528 .36322 .4432 .37333 .44619 .36916 .39392 Mtetra
.54 .369 .599 r
.36916 .39392 .37333 .44619 .38356 .44821 .37935 .39396 Mtetra
.533 .362 .595 r
.37935 .39396 .38356 .44821 .39391 .44915 .38956 .39489 Mtetra
.529 .359 .595 r
.38956 .39489 .39391 .44915 .40437 .44891 .39983 .39632 Mtetra
.529 .361 .598 r
.39983 .39632 .40437 .44891 .41493 .4477 .41016 .39776 Mtetra
.532 .367 .603 r
.41016 .39776 .41493 .4477 .42557 .44567 .42059 .39881 Mtetra
.538 .375 .609 r
.42059 .39881 .42557 .44567 .43628 .44305 .4311 .39921 Mtetra
.546 .386 .616 r
.4311 .39921 .43628 .44305 .44705 .44002 .4417 .39873 Mtetra
.556 .398 .622 r
.4417 .39873 .44705 .44002 .45787 .43673 .45239 .39727 Mtetra
.568 .41 .627 r
.45239 .39727 .45787 .43673 .46873 .43327 .46316 .39474 Mtetra
.579 .42 .629 r
.46316 .39474 .46873 .43327 .47964 .4297 .47399 .39111 Mtetra
.589 .427 .629 r
.47399 .39111 .47964 .4297 .4906 .426 .48488 .38638 Mtetra
.597 .43 .626 r
.48488 .38638 .4906 .426 .5016 .42214 .49581 .38056 Mtetra
.602 .431 .622 r
.49581 .38056 .5016 .42214 .51264 .41801 .50678 .37375 Mtetra
.605 .428 .616 r
.50678 .37375 .51264 .41801 .52373 .41346 .51778 .36605 Mtetra
.605 .424 .61 r
.51778 .36605 .52373 .41346 .53485 .40832 .52879 .35767 Mtetra
.604 .419 .605 r
.52879 .35767 .53485 .40832 .546 .40234 .53981 .34888 Mtetra
.6 .414 .601 r
.53981 .34888 .546 .40234 .55717 .39537 .55084 .34009 Mtetra
.595 .408 .598 r
.55084 .34009 .55717 .39537 .56835 .38718 .56188 .33179 Mtetra
.59 .404 .598 r
.56188 .33179 .56835 .38718 .57953 .37789 .57295 .32437 Mtetra
.582 .4 .6 r
.57295 .32437 .57953 .37789 .59068 .36759 .58407 .31837 Mtetra
.576 .401 .607 r
.58407 .31837 .59068 .36759 .60183 .35678 .59525 .31384 Mtetra
.568 .405 .619 r
.59525 .31384 .60183 .35678 .61297 .34608 .60651 .31085 Mtetra
.562 .416 .64 r
.60651 .31085 .61297 .34608 .62414 .33611 .61785 .3091 Mtetra
.557 .44 .676 r
.61785 .3091 .62414 .33611 .63536 .32764 .62929 .3082 Mtetra
.55 .482 .731 r
.62929 .3082 .63536 .32764 .64665 .32083 .64082 .30786 Mtetra
.536 .551 .817 r
.64082 .30786 .64665 .32083 .65805 .31593 .65243 .30777 Mtetra
.494 .643 .922 r
.65243 .30777 .65805 .31593 .66957 .31262 .66412 .30782 Mtetra
.393 .716 .988 r
.66412 .30782 .66957 .31262 .6812 .31052 .6759 .30788 Mtetra
.26 .722 .95 r
.6759 .30788 .6812 .31052 .69293 .30923 .68774 .30783 Mtetra
.176 .698 .876 r
.68774 .30783 .69293 .30923 .70475 .30829 .69965 .30748 Mtetra
.158 .694 .835 r
.69965 .30748 .70475 .30829 .71665 .30746 .71161 .30673 Mtetra
.209 .732 .849 r
.71161 .30673 .71665 .30746 .72861 .30643 .7236 .30539 Mtetra
.297 .785 .895 r
.7236 .30539 .72861 .30643 .74062 .30512 .73563 .30345 Mtetra
.408 .84 .95 r
.73563 .30345 .74062 .30512 .75268 .30337 .74768 .30087 Mtetra
.507 .869 .985 r
.74768 .30087 .75268 .30337 .76477 .30122 .75975 .29775 Mtetra
.582 .87 .995 r
.75975 .29775 .76477 .30122 .77689 .29863 .77184 .29415 Mtetra
.628 .849 .984 r
.77184 .29415 .77689 .29863 .78904 .29572 .78396 .29019 Mtetra
.653 .819 .963 r
.78396 .29019 .78904 .29572 .80124 .29255 .79611 .286 Mtetra
.663 .786 .94 r
.79611 .286 .80124 .29255 .81347 .28921 .8083 .28168 Mtetra
.602 .737 .94 r
.15958 .49055 .16646 .49655 .17612 .49352 .16917 .48843 Mtetra
.593 .768 .963 r
.16917 .48843 .17612 .49352 .18584 .49039 .1788 .48628 Mtetra
.583 .804 .984 r
.1788 .48628 .18584 .49039 .19561 .48702 .18849 .48401 Mtetra
.569 .843 .996 r
.18849 .48401 .19561 .48702 .20545 .48333 .19824 .48153 Mtetra
.544 .877 .991 r
.19824 .48153 .20545 .48333 .21537 .47918 .20806 .47873 Mtetra
.503 .894 .951 r
.20806 .47873 .21537 .47918 .22536 .4745 .21796 .47549 Mtetra
.446 .881 .867 r
.21796 .47549 .22536 .4745 .23544 .4692 .22795 .47169 Mtetra
.372 .831 .745 r
.22795 .47169 .23544 .4692 .2456 .46333 .23803 .46726 Mtetra
0 0 0 r
.23803 .46726 .2456 .46333 .25582 .45689 .2482 .46211 Mtetra
.2482 .46211 .25582 .45689 .26609 .45004 .25846 .45625 Mtetra
.25846 .45625 .26609 .45004 .2764 .4429 .26879 .44966 Mtetra
.26879 .44966 .2764 .4429 .28674 .43563 .2792 .44238 Mtetra
.2792 .44238 .28674 .43563 .29709 .42838 .28966 .43445 Mtetra
.28966 .43445 .29709 .42838 .30745 .42123 .30018 .426 Mtetra
.584 .911 .672 r
.30018 .426 .30745 .42123 .3178 .41433 .31073 .41715 Mtetra
.721 .986 .808 r
.31073 .41715 .3178 .41433 .32814 .40797 .32128 .40834 Mtetra
.801 .983 .895 r
.32128 .40834 .32814 .40797 .33845 .40242 .33181 .39991 Mtetra
.801 .904 .913 r
.33181 .39991 .33845 .40242 .34873 .3981 .34231 .39232 Mtetra
.752 .791 .885 r
.34231 .39232 .34873 .3981 .35895 .39528 .35275 .38595 Mtetra
.694 .682 .834 r
.35275 .38595 .35895 .39528 .36916 .39392 .36315 .38083 Mtetra
.641 .593 .785 r
.36315 .38083 .36916 .39392 .37935 .39396 .37352 .37701 Mtetra
.607 .53 .742 r
.37352 .37701 .37935 .39396 .38956 .39489 .38388 .37413 Mtetra
.585 .486 .709 r
.38388 .37413 .38956 .39489 .39983 .39632 .39426 .37197 Mtetra
.573 .459 .685 r
.39426 .37197 .39983 .39632 .41016 .39776 .40468 .37016 Mtetra
.569 .441 .667 r
.40468 .37016 .41016 .39776 .42059 .39881 .41514 .36841 Mtetra
.568 .431 .655 r
.41514 .36841 .42059 .39881 .4311 .39921 .42567 .36651 Mtetra
.569 .425 .646 r
.42567 .36651 .4311 .39921 .4417 .39873 .43625 .36428 Mtetra
.572 .423 .64 r
.43625 .36428 .4417 .39873 .45239 .39727 .4469 .36163 Mtetra
.576 .423 .636 r
.4469 .36163 .45239 .39727 .46316 .39474 .45761 .35847 Mtetra
.581 .425 .635 r
.45761 .35847 .46316 .39474 .47399 .39111 .46837 .35479 Mtetra
.586 .428 .634 r
.46837 .35479 .47399 .39111 .48488 .38638 .47918 .35058 Mtetra
.592 .434 .636 r
.47918 .35058 .48488 .38638 .49581 .38056 .49004 .34586 Mtetra
.598 .44 .639 r
.49004 .34586 .49581 .38056 .50678 .37375 .50093 .34071 Mtetra
.604 .449 .645 r
.50093 .34071 .50678 .37375 .51778 .36605 .51187 .33522 Mtetra
.61 .459 .652 r
.51187 .33522 .51778 .36605 .52879 .35767 .52283 .32958 Mtetra
.615 .472 .664 r
.52283 .32958 .52879 .35767 .53981 .34888 .53382 .32399 Mtetra
.619 .488 .681 r
.53382 .32399 .53981 .34888 .55084 .34009 .54485 .31876 Mtetra
.62 .508 .705 r
.54485 .31876 .55084 .34009 .56188 .33179 .55592 .31423 Mtetra
.616 .535 .74 r
.55592 .31423 .56188 .33179 .57295 .32437 .56704 .31067 Mtetra
.597 .57 .794 r
.56704 .31067 .57295 .32437 .58407 .31837 .57823 .30843 Mtetra
.555 .621 .873 r
.57823 .30843 .58407 .31837 .59525 .31384 .5895 .30746 Mtetra
.439 .675 .963 r
.5895 .30746 .59525 .31384 .60651 .31085 .60087 .30774 Mtetra
.173 .648 .931 r
.60087 .30774 .60651 .31085 .61785 .3091 .61235 .3089 Mtetra
.144 0 0 r
.61235 .3089 .61785 .3091 .62929 .3082 .62391 .31046 Mtetra
.315 0 0 r
.62391 .31046 .62929 .3082 .64082 .30786 .63557 .31208 Mtetra
.368 0 0 r
.63557 .31208 .64082 .30786 .65243 .30777 .6473 .3133 Mtetra
.377 0 0 r
.6473 .3133 .65243 .30777 .66412 .30782 .6591 .31401 Mtetra
.361 0 0 r
.6591 .31401 .66412 .30782 .6759 .30788 .67095 .31406 Mtetra
.324 0 0 r
.67095 .31406 .6759 .30788 .68774 .30783 .68284 .31341 Mtetra
.263 0 0 r
.68284 .31341 .68774 .30783 .69965 .30748 .69477 .31201 Mtetra
.166 0 0 r
.69477 .31201 .69965 .30748 .71161 .30673 .70673 .30988 Mtetra
.015 0 0 r
.70673 .30988 .71161 .30673 .7236 .30539 .7187 .307 Mtetra
0 0 0 r
.7187 .307 .7236 .30539 .73563 .30345 .73069 .30347 Mtetra
.395 .853 .849 r
.73069 .30347 .73563 .30345 .74768 .30087 .7427 .29935 Mtetra
.552 .916 .953 r
.7427 .29935 .74768 .30087 .75975 .29775 .75472 .29477 Mtetra
.64 .911 .981 r
.75472 .29477 .75975 .29775 .77184 .29415 .76676 .28985 Mtetra
.68 .877 .972 r
.76676 .28985 .77184 .29415 .78396 .29019 .77883 .2847 Mtetra
.695 .838 .951 r
.77883 .2847 .78396 .29019 .79611 .286 .79094 .27941 Mtetra
.698 .8 .929 r
.79094 .27941 .79611 .286 .8083 .28168 .80308 .27409 Mtetra
.563 .724 .949 r
.15266 .48451 .15958 .49055 .16917 .48843 .16219 .48305 Mtetra
.547 .744 .968 r
.16219 .48305 .16917 .48843 .1788 .48628 .17176 .48166 Mtetra
.527 .767 .985 r
.17176 .48166 .1788 .48628 .18849 .48401 .18138 .48029 Mtetra
.498 .792 .998 r
.18138 .48029 .18849 .48401 .19824 .48153 .19104 .47889 Mtetra
.449 .813 .995 r
.19104 .47889 .19824 .48153 .20806 .47873 .20076 .47744 Mtetra
.375 .817 .952 r
.20076 .47744 .20806 .47873 .21796 .47549 .21054 .47578 Mtetra
.265 .772 .837 r
.21054 .47578 .21796 .47549 .22795 .47169 .2204 .47383 Mtetra
0 0 0 r
.2204 .47383 .22795 .47169 .23803 .46726 .23035 .47139 Mtetra
.23035 .47139 .23803 .46726 .2482 .46211 .2404 .46832 Mtetra
.048 0 0 r
.2404 .46832 .2482 .46211 .25846 .45625 .25054 .4645 Mtetra
.089 0 0 r
.25054 .4645 .25846 .45625 .26879 .44966 .2608 .45977 Mtetra
.118 0 0 r
.2608 .45977 .26879 .44966 .2792 .44238 .27115 .45423 Mtetra
.138 0 0 r
.27115 .45423 .2792 .44238 .28966 .43445 .28159 .4479 Mtetra
.168 0 .047 r
.28159 .4479 .28966 .43445 .30018 .426 .29208 .44111 Mtetra
.205 0 .101 r
.29208 .44111 .30018 .426 .31073 .41715 .3026 .4341 Mtetra
.247 0 .153 r
.3026 .4341 .31073 .41715 .32128 .40834 .31314 .42705 Mtetra
.284 0 .196 r
.31314 .42705 .32128 .40834 .33181 .39991 .32369 .42015 Mtetra
.305 0 .224 r
.32369 .42015 .33181 .39991 .34231 .39232 .33426 .41318 Mtetra
.31 0 .233 r
.33426 .41318 .34231 .39232 .35275 .38595 .34486 .40608 Mtetra
.293 0 .218 r
.34486 .40608 .35275 .38595 .36315 .38083 .35549 .3987 Mtetra
.246 0 .17 r
.35549 .3987 .36315 .38083 .37352 .37701 .36616 .39098 Mtetra
.146 0 .057 r
.36616 .39098 .37352 .37701 .38388 .37413 .37684 .3831 Mtetra
0 0 0 r
.37684 .3831 .38388 .37413 .39426 .37197 .38754 .3752 Mtetra
.566 .921 .734 r
.38754 .3752 .39426 .37197 .40468 .37016 .39824 .36754 Mtetra
.786 .912 .926 r
.39824 .36754 .40468 .37016 .41514 .36841 .40894 .36029 Mtetra
.738 .73 .844 r
.40894 .36029 .41514 .36841 .42567 .36651 .41964 .3536 Mtetra
.686 .621 .778 r
.41964 .3536 .42567 .36651 .43625 .36428 .43034 .34759 Mtetra
.651 .56 .739 r
.43034 .34759 .43625 .36428 .4469 .36163 .44105 .34231 Mtetra
.627 .524 .718 r
.44105 .34231 .4469 .36163 .45761 .35847 .45177 .3378 Mtetra
.61 .504 .709 r
.45177 .3378 .45761 .35847 .46837 .35479 .46251 .33408 Mtetra
.596 .496 .711 r
.46251 .33408 .46837 .35479 .47918 .35058 .47329 .33114 Mtetra
.585 .499 .724 r
.47329 .33114 .47918 .35058 .49004 .34586 .4841 .32899 Mtetra
.573 .516 .752 r
.4841 .32899 .49004 .34586 .50093 .34071 .49495 .32757 Mtetra
.555 .555 .808 r
.49495 .32757 .50093 .34071 .51187 .33522 .50586 .32685 Mtetra
.506 .638 .914 r
.50586 .32685 .51187 .33522 .52283 .32958 .51684 .3267 Mtetra
.245 .703 .951 r
.51684 .3267 .52283 .32958 .53382 .32399 .52789 .32698 Mtetra
.277 0 0 r
.52789 .32698 .53382 .32399 .54485 .31876 .53901 .32751 Mtetra
.431 0 .072 r
.53901 .32751 .54485 .31876 .55592 .31423 .5502 .32804 Mtetra
.468 .074 .21 r
.5502 .32804 .55592 .31423 .56704 .31067 .56147 .32841 Mtetra
.477 .113 .269 r
.56147 .32841 .56704 .31067 .57823 .30843 .57282 .32846 Mtetra
.479 .128 .294 r
.57282 .32846 .57823 .30843 .5895 .30746 .58423 .32823 Mtetra
.478 .132 .3 r
.58423 .32823 .5895 .30746 .60087 .30774 .59571 .32786 Mtetra
.475 .125 .292 r
.59571 .32786 .60087 .30774 .61235 .3089 .60726 .32746 Mtetra
.473 .113 .275 r
.60726 .32746 .61235 .3089 .62391 .31046 .61889 .3272 Mtetra
.465 .094 .249 r
.61889 .3272 .62391 .31046 .63557 .31208 .6306 .32693 Mtetra
.45 .064 .215 r
.6306 .32693 .63557 .31208 .6473 .3133 .64238 .32643 Mtetra
.425 .024 .174 r
.64238 .32643 .6473 .3133 .6591 .31401 .65421 .32547 Mtetra
.381 0 .118 r
.65421 .32547 .6591 .31401 .67095 .31406 .66607 .3237 Mtetra
.318 0 .039 r
.66607 .3237 .67095 .31406 .68284 .31341 .67796 .32109 Mtetra
.219 0 0 r
.67796 .32109 .68284 .31341 .69477 .31201 .68987 .31756 Mtetra
.068 0 0 r
.68987 .31756 .69477 .31201 .70673 .30988 .70178 .31323 Mtetra
0 0 0 r
.70178 .31323 .70673 .30988 .7187 .307 .71371 .30824 Mtetra
.4 .847 .757 r
.71371 .30824 .7187 .307 .73069 .30347 .72564 .30275 Mtetra
.587 .943 .914 r
.72564 .30275 .73069 .30347 .7427 .29935 .73759 .29693 Mtetra
.681 .942 .963 r
.73759 .29693 .7427 .29935 .75472 .29477 .74957 .29089 Mtetra
.715 .904 .962 r
.74957 .29089 .75472 .29477 .76676 .28985 .76158 .28479 Mtetra
.725 .864 .947 r
.76158 .28479 .76676 .28985 .77883 .2847 .77362 .27864 Mtetra
.725 .829 .929 r
.77362 .27864 .77883 .2847 .79094 .27941 .7857 .2725 Mtetra
.72 .8 .914 r
.7857 .2725 .79094 .27941 .80308 .27409 .79782 .26643 Mtetra
.562 .724 .95 r
.14569 .47843 .15266 .48451 .16219 .48305 .15524 .47696 Mtetra
.553 .721 .952 r
.15524 .47696 .16219 .48305 .17176 .48166 .16482 .47562 Mtetra
.544 .72 .955 r
.16482 .47562 .17176 .48166 .18138 .48029 .17443 .4744 Mtetra
.532 .722 .961 r
.17443 .4744 .18138 .48029 .19104 .47889 .18408 .47331 Mtetra
.513 .727 .97 r
.18408 .47331 .19104 .47889 .20076 .47744 .19376 .47239 Mtetra
.493 .741 .982 r
.19376 .47239 .20076 .47744 .21054 .47578 .20349 .47152 Mtetra
.463 .761 .994 r
.20349 .47152 .21054 .47578 .2204 .47383 .21326 .47067 Mtetra
.422 .785 .995 r
.21326 .47067 .2204 .47383 .23035 .47139 .22311 .46968 Mtetra
.352 .796 .958 r
.22311 .46968 .23035 .47139 .2404 .46832 .23303 .46841 Mtetra
.238 .754 .835 r
.23303 .46841 .2404 .46832 .25054 .4645 .24303 .46673 Mtetra
0 0 0 r
.24303 .46673 .25054 .4645 .2608 .45977 .25313 .46449 Mtetra
.051 0 0 r
.25313 .46449 .2608 .45977 .27115 .45423 .26333 .46168 Mtetra
.156 0 0 r
.26333 .46168 .27115 .45423 .28159 .4479 .27361 .45826 Mtetra
.234 0 .002 r
.27361 .45826 .28159 .4479 .29208 .44111 .28397 .45434 Mtetra
.284 0 .103 r
.28397 .45434 .29208 .44111 .3026 .4341 .29439 .45 Mtetra
.314 0 .166 r
.29439 .45 .3026 .4341 .31314 .42705 .30488 .44521 Mtetra
.329 0 .206 r
.30488 .44521 .31314 .42705 .32369 .42015 .31543 .43994 Mtetra
.329 0 .225 r
.31543 .43994 .32369 .42015 .33426 .41318 .32606 .43405 Mtetra
.321 0 .233 r
.32606 .43405 .33426 .41318 .34486 .40608 .33674 .42745 Mtetra
.31 0 .233 r
.33674 .42745 .34486 .40608 .35549 .3987 .34748 .42024 Mtetra
.298 0 .23 r
.34748 .42024 .35549 .3987 .36616 .39098 .35827 .41251 Mtetra
.293 0 .228 r
.35827 .41251 .36616 .39098 .37684 .3831 .36908 .40456 Mtetra
.294 0 .229 r
.36908 .40456 .37684 .3831 .38754 .3752 .37991 .39664 Mtetra
.303 0 .234 r
.37991 .39664 .38754 .3752 .39824 .36754 .39073 .38899 Mtetra
.318 0 .241 r
.39073 .38899 .39824 .36754 .40894 .36029 .40156 .38181 Mtetra
.336 .007 .25 r
.40156 .38181 .40894 .36029 .41964 .3536 .41238 .37522 Mtetra
.355 .025 .26 r
.41238 .37522 .41964 .3536 .43034 .34759 .4232 .3693 Mtetra
.375 .043 .269 r
.4232 .3693 .43034 .34759 .44105 .34231 .43403 .36409 Mtetra
.393 .06 .277 r
.43403 .36409 .44105 .34231 .45177 .3378 .44488 .35961 Mtetra
.411 .076 .284 r
.44488 .35961 .45177 .3378 .46251 .33408 .45574 .35589 Mtetra
.428 .091 .291 r
.45574 .35589 .46251 .33408 .47329 .33114 .46664 .35291 Mtetra
.443 .105 .296 r
.46664 .35291 .47329 .33114 .4841 .32899 .47757 .35068 Mtetra
.457 .117 .3 r
.47757 .35068 .4841 .32899 .49495 .32757 .48855 .34917 Mtetra
.47 .128 .304 r
.48855 .34917 .49495 .32757 .50586 .32685 .49959 .34834 Mtetra
.481 .137 .306 r
.49959 .34834 .50586 .32685 .51684 .3267 .51068 .34811 Mtetra
.489 .144 .308 r
.51068 .34811 .51684 .3267 .52789 .32698 .52185 .34837 Mtetra
.494 .148 .309 r
.52185 .34837 .52789 .32698 .53901 .32751 .53309 .34891 Mtetra
.495 .148 .308 r
.53309 .34891 .53901 .32751 .5502 .32804 .54441 .3495 Mtetra
.491 .145 .307 r
.54441 .3495 .5502 .32804 .56147 .32841 .55581 .34989 Mtetra
.482 .136 .304 r
.55581 .34989 .56147 .32841 .57282 .32846 .56727 .34975 Mtetra
.47 .125 .298 r
.56727 .34975 .57282 .32846 .58423 .32823 .57881 .349 Mtetra
.455 .108 .287 r
.57881 .349 .58423 .32823 .59571 .32786 .59039 .34754 Mtetra
.437 .086 .27 r
.59039 .34754 .59571 .32786 .60726 .32746 .60203 .34545 Mtetra
.417 .057 .244 r
.60203 .34545 .60726 .32746 .61889 .3272 .61372 .34288 Mtetra
.387 .012 .201 r
.61372 .34288 .61889 .3272 .6306 .32693 .62545 .33984 Mtetra
.34 0 .131 r
.62545 .33984 .6306 .32693 .64238 .32643 .63722 .33636 Mtetra
.26 0 .018 r
.63722 .33636 .64238 .32643 .65421 .32547 .64903 .33238 Mtetra
.114 0 0 r
.64903 .33238 .65421 .32547 .66607 .3237 .66085 .32776 Mtetra
0 0 0 r
.66085 .32776 .66607 .3237 .67796 .32109 .6727 .32255 Mtetra
.419 .857 .754 r
.6727 .32255 .67796 .32109 .68987 .31756 .68456 .31675 Mtetra
.629 .956 .921 r
.68456 .31675 .68987 .31756 .70178 .31323 .69643 .3105 Mtetra
.717 .939 .958 r
.69643 .3105 .70178 .31323 .71371 .30824 .70832 .30397 Mtetra
.743 .893 .947 r
.70832 .30397 .71371 .30824 .72564 .30275 .72023 .29727 Mtetra
.745 .852 .929 r
.72023 .29727 .72564 .30275 .73759 .29693 .73218 .29058 Mtetra
.74 .821 .914 r
.73218 .29058 .73759 .29693 .74957 .29089 .74416 .28393 Mtetra
.733 .8 .906 r
.74416 .28393 .74957 .29089 .76158 .28479 .75618 .27745 Mtetra
.727 .787 .9 r
.75618 .27745 .76158 .28479 .77362 .27864 .76825 .27108 Mtetra
.722 .78 .899 r
.76825 .27108 .77362 .27864 .7857 .2725 .78036 .26484 Mtetra
.718 .777 .899 r
.78036 .26484 .7857 .2725 .79782 .26643 .79252 .25872 Mtetra
.595 .735 .941 r
.13868 .4723 .14569 .47843 .15524 .47696 .1483 .47024 Mtetra
.592 .714 .929 r
.1483 .47024 .15524 .47696 .16482 .47562 .15796 .46831 Mtetra
.586 .693 .916 r
.15796 .46831 .16482 .47562 .17443 .4744 .16764 .46655 Mtetra
.576 .674 .906 r
.16764 .46655 .17443 .4744 .18408 .47331 .17734 .46503 Mtetra
.564 .657 .899 r
.17734 .46503 .18408 .47331 .19376 .47239 .18706 .46381 Mtetra
.551 .644 .895 r
.18706 .46381 .19376 .47239 .20349 .47152 .19681 .46287 Mtetra
.537 .637 .897 r
.19681 .46287 .20349 .47152 .21326 .47067 .20657 .46223 Mtetra
.522 .637 .905 r
.20657 .46223 .21326 .47067 .22311 .46968 .21637 .46181 Mtetra
.504 .648 .922 r
.21637 .46181 .22311 .46968 .23303 .46841 .2262 .46159 Mtetra
.478 .672 .949 r
.2262 .46159 .23303 .46841 .24303 .46673 .23609 .46146 Mtetra
.429 .71 .982 r
.23609 .46146 .24303 .46673 .25313 .46449 .24603 .46135 Mtetra
.326 .741 .978 r
.24603 .46135 .25313 .46449 .26333 .46168 .25604 .46111 Mtetra
.13 .675 .817 r
.25604 .46111 .26333 .46168 .27361 .45826 .26613 .4606 Mtetra
.074 0 0 r
.26613 .4606 .27361 .45826 .28397 .45434 .27632 .45957 Mtetra
.184 0 0 r
.27632 .45957 .28397 .45434 .29439 .45 .28663 .45777 Mtetra
.224 0 0 r
.28663 .45777 .29439 .45 .30488 .44521 .29704 .45506 Mtetra
.227 0 0 r
.29704 .45506 .30488 .44521 .31543 .43994 .30757 .4513 Mtetra
.229 0 .024 r
.30757 .4513 .31543 .43994 .32606 .43405 .31819 .44677 Mtetra
.238 0 .063 r
.31819 .44677 .32606 .43405 .33674 .42745 .32888 .4417 Mtetra
.269 0 .112 r
.32888 .4417 .33674 .42745 .34748 .42024 .3396 .43653 Mtetra
.315 0 .17 r
.3396 .43653 .34748 .42024 .35827 .41251 .35035 .43159 Mtetra
.361 .011 .229 r
.35035 .43159 .35827 .41251 .36908 .40456 .36111 .42701 Mtetra
.4 .066 .279 r
.36111 .42701 .36908 .40456 .37991 .39664 .37188 .4229 Mtetra
.427 .106 .317 r
.37188 .4229 .37991 .39664 .39073 .38899 .38268 .41912 Mtetra
.445 .135 .345 r
.38268 .41912 .39073 .38899 .40156 .38181 .39351 .4156 Mtetra
.456 .155 .364 r
.39351 .4156 .40156 .38181 .41238 .37522 .40438 .41219 Mtetra
.463 .168 .378 r
.40438 .41219 .41238 .37522 .4232 .3693 .41529 .4088 Mtetra
.467 .176 .386 r
.41529 .4088 .4232 .3693 .43403 .36409 .42625 .40534 Mtetra
.468 .18 .391 r
.42625 .40534 .43403 .36409 .44488 .35961 .43726 .40177 Mtetra
.468 .181 .394 r
.43726 .40177 .44488 .35961 .45574 .35589 .44832 .39806 Mtetra
.467 .18 .393 r
.44832 .39806 .45574 .35589 .46664 .35291 .45943 .39421 Mtetra
.465 .177 .39 r
.45943 .39421 .46664 .35291 .47757 .35068 .47058 .39024 Mtetra
.461 .171 .385 r
.47058 .39024 .47757 .35068 .48855 .34917 .48178 .38621 Mtetra
.457 .162 .376 r
.48178 .38621 .48855 .34917 .49959 .34834 .49303 .38219 Mtetra
.451 .15 .363 r
.49303 .38219 .49959 .34834 .51068 .34811 .50431 .37828 Mtetra
.446 .136 .345 r
.50431 .37828 .51068 .34811 .52185 .34837 .51564 .37464 Mtetra
.439 .117 .321 r
.51564 .37464 .52185 .34837 .53309 .34891 .52702 .37133 Mtetra
.432 .094 .291 r
.52702 .37133 .53309 .34891 .54441 .3495 .53846 .3685 Mtetra
.422 .066 .254 r
.53846 .3685 .54441 .3495 .55581 .34989 .54995 .36603 Mtetra
.408 .033 .212 r
.54995 .36603 .55581 .34989 .56727 .34975 .5615 .3638 Mtetra
.386 0 .168 r
.5615 .3638 .56727 .34975 .57881 .349 .57311 .36148 Mtetra
.348 0 .119 r
.57311 .36148 .57881 .349 .59039 .34754 .58477 .3586 Mtetra
.293 0 .059 r
.58477 .3586 .59039 .34754 .60203 .34545 .59647 .35495 Mtetra
.202 0 0 r
.59647 .35495 .60203 .34545 .61372 .34288 .6082 .35021 Mtetra
.054 0 0 r
.6082 .35021 .61372 .34288 .62545 .33984 .61993 .34453 Mtetra
0 0 0 r
.61993 .34453 .62545 .33984 .63722 .33636 .63168 .33805 Mtetra
.513 .905 .765 r
.63168 .33805 .63722 .33636 .64903 .33238 .64344 .33102 Mtetra
.721 .971 .931 r
.64344 .33102 .64903 .33238 .66085 .32776 .65522 .3237 Mtetra
.77 .901 .933 r
.65522 .3237 .66085 .32776 .6727 .32255 .66701 .31623 Mtetra
.764 .824 .899 r
.66701 .31623 .6727 .32255 .68456 .31675 .67884 .30876 Mtetra
.75 .771 .87 r
.67884 .30876 .68456 .31675 .69643 .3105 .69068 .30138 Mtetra
.736 .737 .853 r
.69068 .30138 .69643 .3105 .70832 .30397 .70257 .29418 Mtetra
.725 .719 .844 r
.70257 .29418 .70832 .30397 .72023 .29727 .7145 .28721 Mtetra
.716 .71 .843 r
.7145 .28721 .72023 .29727 .73218 .29058 .72648 .28053 Mtetra
.709 .708 .847 r
.72648 .28053 .73218 .29058 .74416 .28393 .73851 .27414 Mtetra
.704 .712 .855 r
.73851 .27414 .74416 .28393 .75618 .27745 .75059 .26804 Mtetra
.7 .721 .866 r
.75059 .26804 .75618 .27745 .76825 .27108 .76273 .26218 Mtetra
.698 .734 .879 r
.76273 .26218 .76825 .27108 .78036 .26484 .77493 .2565 Mtetra
.697 .75 .893 r
.77493 .2565 .78036 .26484 .79252 .25872 .78718 .25095 Mtetra
.647 .749 .924 r
.13161 .46613 .13868 .4723 .1483 .47024 .14138 .46298 Mtetra
.642 .714 .9 r
.14138 .46298 .1483 .47024 .15796 .46831 .15117 .45993 Mtetra
.634 .681 .877 r
.15117 .45993 .15796 .46831 .16764 .46655 .16099 .45705 Mtetra
.622 .649 .856 r
.16099 .45705 .16764 .46655 .17734 .46503 .17082 .45442 Mtetra
.609 .62 .837 r
.17082 .45442 .17734 .46503 .18706 .46381 .18065 .45212 Mtetra
.595 .593 .82 r
.18065 .45212 .18706 .46381 .19681 .46287 .19049 .45018 Mtetra
.58 .569 .806 r
.19049 .45018 .19681 .46287 .20657 .46223 .20034 .44867 Mtetra
.567 .549 .794 r
.20034 .44867 .20657 .46223 .21637 .46181 .21019 .44756 Mtetra
.554 .533 .786 r
.21019 .44756 .21637 .46181 .2262 .46159 .22006 .44687 Mtetra
.544 .521 .781 r
.22006 .44687 .2262 .46159 .23609 .46146 .22996 .44652 Mtetra
.535 .514 .779 r
.22996 .44652 .23609 .46146 .24603 .46135 .23988 .44646 Mtetra
.531 .513 .781 r
.23988 .44646 .24603 .46135 .25604 .46111 .24986 .44651 Mtetra
.531 .518 .786 r
.24986 .44651 .25604 .46111 .26613 .4606 .2599 .44654 Mtetra
.538 .53 .794 r
.2599 .44654 .26613 .4606 .27632 .45957 .27002 .44631 Mtetra
.552 .551 .806 r
.27002 .44631 .27632 .45957 .28663 .45777 .28024 .44561 Mtetra
.568 .578 .824 r
.28024 .44561 .28663 .45777 .29704 .45506 .29055 .4444 Mtetra
.586 .618 .85 r
.29055 .4444 .29704 .45506 .30757 .4513 .30095 .44264 Mtetra
.595 .671 .893 r
.30095 .44264 .30757 .4513 .31819 .44677 .31143 .44058 Mtetra
.585 .746 .953 r
.31143 .44058 .31819 .44677 .32888 .4417 .32196 .43842 Mtetra
.51 .827 1 r
.32196 .43842 .32888 .4417 .3396 .43653 .33255 .43633 Mtetra
.267 .772 .857 r
.33255 .43633 .3396 .43653 .35035 .43159 .34317 .43445 Mtetra
.036 0 0 r
.34317 .43445 .35035 .43159 .36111 .42701 .35384 .43269 Mtetra
.216 0 0 r
.35384 .43269 .36111 .42701 .37188 .4229 .36456 .43098 Mtetra
.295 0 0 r
.36456 .43098 .37188 .4229 .38268 .41912 .37534 .42917 Mtetra
.331 0 .043 r
.37534 .42917 .38268 .41912 .39351 .4156 .38619 .42716 Mtetra
.345 0 .091 r
.38619 .42716 .39351 .4156 .40438 .41219 .3971 .42487 Mtetra
.349 0 .119 r
.3971 .42487 .40438 .41219 .41529 .4088 .40808 .42224 Mtetra
.347 0 .133 r
.40808 .42224 .41529 .4088 .42625 .40534 .41912 .41925 Mtetra
.341 0 .139 r
.41912 .41925 .42625 .40534 .43726 .40177 .43022 .4159 Mtetra
.331 0 .139 r
.43022 .4159 .43726 .40177 .44832 .39806 .44138 .41218 Mtetra
.318 0 .133 r
.44138 .41218 .44832 .39806 .45943 .39421 .45259 .40809 Mtetra
.301 0 .12 r
.45259 .40809 .45943 .39421 .47058 .39024 .46386 .40363 Mtetra
.278 0 .1 r
.46386 .40363 .47058 .39024 .48178 .38621 .47517 .39881 Mtetra
.248 0 .068 r
.47517 .39881 .48178 .38621 .49303 .38219 .48652 .39365 Mtetra
.206 0 .02 r
.48652 .39365 .49303 .38219 .50431 .37828 .49792 .38819 Mtetra
.145 0 0 r
.49792 .38819 .50431 .37828 .51564 .37464 .50935 .38252 Mtetra
.049 0 0 r
.50935 .38252 .51564 .37464 .52702 .37133 .52082 .37675 Mtetra
0 0 0 r
.52082 .37675 .52702 .37133 .53846 .3685 .53232 .37103 Mtetra
.354 .808 .685 r
.53232 .37103 .53846 .3685 .54995 .36603 .54385 .36541 Mtetra
.593 .941 .931 r
.54385 .36541 .54995 .36603 .5615 .3638 .55543 .36 Mtetra
.694 .886 .969 r
.55543 .36 .5615 .3638 .57311 .36148 .56704 .35465 Mtetra
.706 .785 .913 r
.56704 .35465 .57311 .36148 .58477 .3586 .57869 .34919 Mtetra
.7 .712 .857 r
.57869 .34919 .58477 .3586 .59647 .35495 .59037 .34343 Mtetra
.699 .668 .816 r
.59037 .34343 .59647 .35495 .6082 .35021 .60208 .33708 Mtetra
.697 .641 .789 r
.60208 .33708 .6082 .35021 .61993 .34453 .6138 .3302 Mtetra
.697 .624 .771 r
.6138 .3302 .61993 .34453 .63168 .33805 .62553 .32283 Mtetra
.696 .613 .76 r
.62553 .32283 .63168 .33805 .64344 .33102 .63728 .31518 Mtetra
.692 .604 .753 r
.63728 .31518 .64344 .33102 .65522 .3237 .64905 .30748 Mtetra
.688 .598 .75 r
.64905 .30748 .65522 .3237 .66701 .31623 .66085 .29989 Mtetra
.682 .594 .751 r
.66085 .29989 .66701 .31623 .67884 .30876 .67268 .29258 Mtetra
.678 .594 .754 r
.67268 .29258 .67884 .30876 .69068 .30138 .68456 .28561 Mtetra
.673 .596 .761 r
.68456 .28561 .69068 .30138 .70257 .29418 .69649 .27907 Mtetra
.669 .603 .772 r
.69649 .27907 .70257 .29418 .7145 .28721 .70848 .27293 Mtetra
.666 .612 .785 r
.70848 .27293 .7145 .28721 .72648 .28053 .72054 .26722 Mtetra
.664 .626 .802 r
.72054 .26722 .72648 .28053 .73851 .27414 .73266 .26189 Mtetra
.662 .644 .822 r
.73266 .26189 .73851 .27414 .75059 .26804 .74485 .2569 Mtetra
.661 .665 .843 r
.74485 .2569 .75059 .26804 .76273 .26218 .7571 .25215 Mtetra
.661 .691 .868 r
.7571 .25215 .76273 .26218 .77493 .2565 .76942 .24759 Mtetra
.662 .721 .893 r
.76942 .24759 .77493 .2565 .78718 .25095 .7818 .24311 Mtetra
.694 .76 .902 r
.12449 .45992 .13161 .46613 .14138 .46298 .13443 .45551 Mtetra
.687 .721 .876 r
.13443 .45551 .14138 .46298 .15117 .45993 .14439 .45113 Mtetra
.676 .685 .852 r
.14439 .45113 .15117 .45993 .16099 .45705 .15437 .44688 Mtetra
.662 .651 .829 r
.15437 .44688 .16099 .45705 .17082 .45442 .16437 .44282 Mtetra
.647 .619 .808 r
.16437 .44282 .17082 .45442 .18065 .45212 .17436 .43904 Mtetra
.632 .589 .788 r
.17436 .43904 .18065 .45212 .19049 .45018 .18436 .43559 Mtetra
.616 .561 .77 r
.18436 .43559 .19049 .45018 .20034 .44867 .19435 .43256 Mtetra
.602 .536 .753 r
.19435 .43256 .20034 .44867 .21019 .44756 .20434 .42994 Mtetra
.588 .513 .738 r
.20434 .42994 .21019 .44756 .22006 .44687 .21433 .42777 Mtetra
.577 .494 .725 r
.21433 .42777 .22006 .44687 .22996 .44652 .22433 .42598 Mtetra
.568 .478 .713 r
.22433 .42598 .22996 .44652 .23988 .44646 .23435 .42452 Mtetra
.561 .465 .702 r
.23435 .42452 .23988 .44646 .24986 .44651 .24441 .42328 Mtetra
.558 .455 .693 r
.24441 .42328 .24986 .44651 .2599 .44654 .2545 .42217 Mtetra
.554 .447 .686 r
.2545 .42217 .2599 .44654 .27002 .44631 .26464 .42119 Mtetra
.552 .441 .682 r
.26464 .42119 .27002 .44631 .28024 .44561 .27483 .42032 Mtetra
.547 .438 .681 r
.27483 .42032 .28024 .44561 .29055 .4444 .28505 .41973 Mtetra
.541 .437 .686 r
.28505 .41973 .29055 .4444 .30095 .44264 .29531 .4195 Mtetra
.534 .442 .697 r
.29531 .4195 .30095 .44264 .31143 .44058 .30561 .41961 Mtetra
.527 .453 .715 r
.30561 .41961 .31143 .44058 .32196 .43842 .31596 .42002 Mtetra
.525 .474 .742 r
.31596 .42002 .32196 .43842 .33255 .43633 .32637 .4204 Mtetra
.529 .504 .772 r
.32637 .4204 .33255 .43633 .34317 .43445 .33687 .42052 Mtetra
.541 .539 .801 r
.33687 .42052 .34317 .43445 .35384 .43269 .34746 .42013 Mtetra
.561 .573 .823 r
.34746 .42013 .35384 .43269 .36456 .43098 .35815 .41907 Mtetra
.581 .595 .832 r
.35815 .41907 .36456 .43098 .37534 .42917 .36893 .41737 Mtetra
.6 .607 .831 r
.36893 .41737 .37534 .42917 .38619 .42716 .3798 .41506 Mtetra
.613 .609 .823 r
.3798 .41506 .38619 .42716 .3971 .42487 .39073 .41227 Mtetra
.621 .605 .812 r
.39073 .41227 .3971 .42487 .40808 .42224 .40174 .40911 Mtetra
.626 .599 .803 r
.40174 .40911 .40808 .42224 .41912 .41925 .4128 .40569 Mtetra
.629 .594 .796 r
.4128 .40569 .41912 .41925 .43022 .4159 .42391 .40208 Mtetra
.631 .592 .792 r
.42391 .40208 .43022 .4159 .44138 .41218 .43508 .39833 Mtetra
.634 .594 .791 r
.43508 .39833 .44138 .41218 .45259 .40809 .44629 .39443 Mtetra
.639 .599 .793 r
.44629 .39443 .45259 .40809 .46386 .40363 .45756 .39033 Mtetra
.646 .609 .798 r
.45756 .39033 .46386 .40363 .47517 .39881 .46887 .38598 Mtetra
.657 .622 .803 r
.46887 .38598 .47517 .39881 .48652 .39365 .48023 .38125 Mtetra
.67 .635 .807 r
.48023 .38125 .48652 .39365 .49792 .38819 .49164 .37603 Mtetra
.685 .647 .806 r
.49164 .37603 .49792 .38819 .50935 .38252 .50309 .37018 Mtetra
.696 .649 .799 r
.50309 .37018 .50935 .38252 .52082 .37675 .51457 .36368 Mtetra
.704 .642 .785 r
.51457 .36368 .52082 .37675 .53232 .37103 .52609 .3565 Mtetra
.702 .622 .764 r
.52609 .3565 .53232 .37103 .54385 .36541 .53762 .34878 Mtetra
.692 .594 .741 r
.53762 .34878 .54385 .36541 .55543 .36 .54918 .34078 Mtetra
.677 .563 .719 r
.54918 .34078 .55543 .36 .56704 .35465 .56075 .33273 Mtetra
.659 .534 .7 r
.56075 .33273 .56704 .35465 .57869 .34919 .57235 .32498 Mtetra
.646 .513 .687 r
.57235 .32498 .57869 .34919 .59037 .34343 .58397 .31756 Mtetra
.635 .498 .678 r
.58397 .31756 .59037 .34343 .60208 .33708 .59563 .31049 Mtetra
.629 .491 .675 r
.59563 .31049 .60208 .33708 .6138 .3302 .60732 .30369 Mtetra
.628 .491 .676 r
.60732 .30369 .6138 .3302 .62553 .32283 .61904 .297 Mtetra
.629 .495 .68 r
.61904 .297 .62553 .32283 .63728 .31518 .6308 .29043 Mtetra
.631 .501 .686 r
.6308 .29043 .63728 .31518 .64905 .30748 .64259 .28399 Mtetra
.632 .509 .695 r
.64259 .28399 .64905 .30748 .66085 .29989 .65442 .27776 Mtetra
.632 .518 .705 r
.65442 .27776 .66085 .29989 .67268 .29258 .66631 .27187 Mtetra
.632 .527 .717 r
.66631 .27187 .67268 .29258 .68456 .28561 .67825 .26636 Mtetra
.63 .538 .732 r
.67825 .26636 .68456 .28561 .69649 .27907 .69026 .2613 Mtetra
.629 .551 .748 r
.69026 .2613 .69649 .27907 .70848 .27293 .70233 .25667 Mtetra
.626 .566 .768 r
.70233 .25667 .70848 .27293 .72054 .26722 .71449 .25247 Mtetra
.624 .585 .789 r
.71449 .25247 .72054 .26722 .73266 .26189 .72672 .24861 Mtetra
.623 .607 .814 r
.72672 .24861 .73266 .26189 .74485 .2569 .73902 .24504 Mtetra
.621 .633 .841 r
.73902 .24504 .74485 .2569 .7571 .25215 .7514 .24167 Mtetra
.62 .662 .87 r
.7514 .24167 .7571 .25215 .76942 .24759 .76385 .23842 Mtetra
.619 .696 .9 r
.76385 .23842 .76942 .24759 .7818 .24311 .77637 .23521 Mtetra
.725 .765 .884 r
.11732 .45366 .12449 .45992 .13443 .45551 .12741 .44822 Mtetra
.718 .735 .865 r
.12741 .44822 .13443 .45551 .14439 .45113 .13752 .44276 Mtetra
.709 .706 .845 r
.13752 .44276 .14439 .45113 .15437 .44688 .14765 .43733 Mtetra
.697 .677 .827 r
.14765 .43733 .15437 .44688 .16437 .44282 .15779 .432 Mtetra
.685 .649 .808 r
.15779 .432 .16437 .44282 .17436 .43904 .16795 .42682 Mtetra
.671 .621 .79 r
.16795 .42682 .17436 .43904 .18436 .43559 .17811 .42185 Mtetra
.656 .593 .772 r
.17811 .42185 .18436 .43559 .19435 .43256 .18827 .41717 Mtetra
.641 .566 .754 r
.18827 .41717 .19435 .43256 .20434 .42994 .19843 .4128 Mtetra
.626 .54 .737 r
.19843 .4128 .20434 .42994 .21433 .42777 .20858 .4088 Mtetra
.613 .517 .722 r
.20858 .4088 .21433 .42777 .22433 .42598 .21874 .40516 Mtetra
.6 .496 .707 r
.21874 .40516 .22433 .42598 .23435 .42452 .2289 .40188 Mtetra
.59 .478 .695 r
.2289 .40188 .23435 .42452 .24441 .42328 .23907 .39894 Mtetra
.581 .464 .684 r
.23907 .39894 .24441 .42328 .2545 .42217 .24926 .39634 Mtetra
.572 .451 .676 r
.24926 .39634 .2545 .42217 .26464 .42119 .25946 .39412 Mtetra
.564 .44 .669 r
.25946 .39412 .26464 .42119 .27483 .42032 .26967 .3923 Mtetra
.557 .431 .665 r
.26967 .3923 .27483 .42032 .28505 .41973 .27991 .3909 Mtetra
.55 .424 .661 r
.27991 .3909 .28505 .41973 .29531 .4195 .29017 .38993 Mtetra
.546 .419 .658 r
.29017 .38993 .29531 .4195 .30561 .41961 .30047 .38915 Mtetra
.545 .415 .654 r
.30047 .38915 .30561 .41961 .31596 .42002 .31083 .3884 Mtetra
.548 .414 .649 r
.31083 .3884 .31596 .42002 .32637 .4204 .32126 .38739 Mtetra
.553 .413 .644 r
.32126 .38739 .32637 .4204 .33687 .42052 .33179 .38592 Mtetra
.558 .412 .639 r
.33179 .38592 .33687 .42052 .34746 .42013 .3424 .38395 Mtetra
.563 .412 .634 r
.3424 .38395 .34746 .42013 .35815 .41907 .35309 .38144 Mtetra
.566 .411 .63 r
.35309 .38144 .35815 .41907 .36893 .41737 .36385 .37853 Mtetra
.568 .41 .626 r
.36385 .37853 .36893 .41737 .3798 .41506 .37468 .37529 Mtetra
.569 .409 .624 r
.37468 .37529 .3798 .41506 .39073 .41227 .38556 .37183 Mtetra
.57 .408 .622 r
.38556 .37183 .39073 .41227 .40174 .40911 .39649 .36823 Mtetra
.57 .407 .621 r
.39649 .36823 .40174 .40911 .4128 .40569 .40747 .36454 Mtetra
.571 .407 .621 r
.40747 .36454 .4128 .40569 .42391 .40208 .4185 .36078 Mtetra
.4185 .36078 .42391 .40208 .43508 .39833 .42958 .35696 Mtetra
.42958 .35696 .43508 .39833 .44629 .39443 .44071 .35309 Mtetra
.572 .408 .621 r
.44071 .35309 .44629 .39443 .45756 .39033 .45188 .34916 Mtetra
.573 .409 .621 r
.45188 .34916 .45756 .39033 .46887 .38598 .46309 .34513 Mtetra
.574 .411 .622 r
.46309 .34513 .46887 .38598 .48023 .38125 .47436 .34096 Mtetra
.577 .414 .624 r
.47436 .34096 .48023 .38125 .49164 .37603 .48567 .33656 Mtetra
.581 .419 .626 r
.48567 .33656 .49164 .37603 .50309 .37018 .49703 .33184 Mtetra
.586 .425 .629 r
.49703 .33184 .50309 .37018 .51457 .36368 .50843 .32669 Mtetra
.594 .433 .633 r
.50843 .32669 .51457 .36368 .52609 .3565 .51987 .321 Mtetra
.601 .442 .638 r
.51987 .321 .52609 .3565 .53762 .34878 .53135 .31479 Mtetra
.609 .451 .643 r
.53135 .31479 .53762 .34878 .54918 .34078 .54285 .3081 Mtetra
.614 .459 .647 r
.54285 .3081 .54918 .34078 .56075 .33273 .55438 .30114 Mtetra
.617 .463 .651 r
.55438 .30114 .56075 .33273 .57235 .32498 .56594 .29419 Mtetra
.617 .466 .655 r
.56594 .29419 .57235 .32498 .58397 .31756 .57752 .28744 Mtetra
.614 .466 .658 r
.57752 .28744 .58397 .31756 .59563 .31049 .58915 .2811 Mtetra
.611 .467 .662 r
.58915 .2811 .59563 .31049 .60732 .30369 .60081 .27519 Mtetra
.608 .469 .667 r
.60081 .27519 .60732 .30369 .61904 .297 .61253 .26969 Mtetra
.606 .473 .673 r
.61253 .26969 .61904 .297 .6308 .29043 .6243 .26457 Mtetra
.605 .479 .682 r
.6243 .26457 .6308 .29043 .64259 .28399 .63612 .25978 Mtetra
.605 .488 .693 r
.63612 .25978 .64259 .28399 .65442 .27776 .648 .25535 Mtetra
.604 .498 .707 r
.648 .25535 .65442 .27776 .66631 .27187 .65994 .25129 Mtetra
.603 .511 .723 r
.65994 .25129 .66631 .27187 .67825 .26636 .67196 .24759 Mtetra
.601 .525 .742 r
.67196 .24759 .67825 .26636 .69026 .2613 .68405 .24428 Mtetra
.599 .542 .763 r
.68405 .24428 .69026 .2613 .70233 .25667 .69622 .24129 Mtetra
.596 .561 .786 r
.69622 .24129 .70233 .25667 .71449 .25247 .70847 .2386 Mtetra
.593 .582 .81 r
.70847 .2386 .71449 .25247 .72672 .24861 .7208 .23613 Mtetra
.59 .605 .835 r
.7208 .23613 .72672 .24861 .73902 .24504 .73321 .23382 Mtetra
.587 .63 .861 r
.73321 .23382 .73902 .24504 .7514 .24167 .7457 .2316 Mtetra
.583 .656 .887 r
.7457 .2316 .7514 .24167 .76385 .23842 .75827 .22944 Mtetra
.579 .684 .913 r
.75827 .22944 .76385 .23842 .77637 .23521 .7709 .22725 Mtetra
.74 .766 .874 r
.1101 .44736 .11732 .45366 .12741 .44822 .12029 .4413 Mtetra
.737 .749 .862 r
.12029 .4413 .12741 .44822 .13752 .44276 .1305 .43517 Mtetra
.732 .732 .85 r
.1305 .43517 .13752 .44276 .14765 .43733 .14074 .42899 Mtetra
.726 .713 .838 r
.14074 .42899 .14765 .43733 .15779 .432 .151 .42279 Mtetra
.719 .693 .824 r
.151 .42279 .15779 .432 .16795 .42682 .16129 .41659 Mtetra
.709 .67 .809 r
.16129 .41659 .16795 .42682 .17811 .42185 .17159 .41043 Mtetra
.698 .646 .794 r
.17159 .41043 .17811 .42185 .18827 .41717 .1819 .40438 Mtetra
.685 .62 .777 r
.1819 .40438 .18827 .41717 .19843 .4128 .19222 .3985 Mtetra
.671 .594 .761 r
.19222 .3985 .19843 .4128 .20858 .4088 .20254 .39283 Mtetra
.656 .569 .744 r
.20254 .39283 .20858 .4088 .21874 .40516 .21286 .38746 Mtetra
.641 .544 .729 r
.21286 .38746 .21874 .40516 .2289 .40188 .22317 .38245 Mtetra
.627 .522 .716 r
.22317 .38245 .2289 .40188 .23907 .39894 .23347 .37785 Mtetra
.613 .503 .704 r
.23347 .37785 .23907 .39894 .24926 .39634 .24376 .37373 Mtetra
.601 .486 .694 r
.24376 .37373 .24926 .39634 .25946 .39412 .25405 .37007 Mtetra
.59 .471 .685 r
.25405 .37007 .25946 .39412 .26967 .3923 .26435 .36684 Mtetra
.584 .46 .677 r
.26435 .36684 .26967 .3923 .27991 .3909 .27467 .36382 Mtetra
.58 .451 .669 r
.27467 .36382 .27991 .3909 .29017 .38993 .28503 .36085 Mtetra
.58 .443 .659 r
.28503 .36085 .29017 .38993 .30047 .38915 .29545 .35765 Mtetra
.582 .436 .648 r
.29545 .35765 .30047 .38915 .31083 .3884 .30595 .35402 Mtetra
.582 .428 .638 r
.30595 .35402 .31083 .3884 .32126 .38739 .31651 .34999 Mtetra
.581 .42 .628 r
.31651 .34999 .32126 .38739 .33179 .38592 .32714 .34559 Mtetra
.578 .412 .621 r
.32714 .34559 .33179 .38592 .3424 .38395 .33781 .34106 Mtetra
.575 .405 .614 r
.33781 .34106 .3424 .38395 .35309 .38144 .34851 .33656 Mtetra
.571 .4 .61 r
.34851 .33656 .35309 .38144 .36385 .37853 .35925 .3322 Mtetra
.568 .395 .607 r
.35925 .3322 .36385 .37853 .37468 .37529 .37001 .32806 Mtetra
.566 .392 .605 r
.37001 .32806 .37468 .37529 .38556 .37183 .38081 .32409 Mtetra
.564 .39 .604 r
.38081 .32409 .38556 .37183 .39649 .36823 .39164 .32025 Mtetra
.563 .39 .604 r
.39164 .32025 .39649 .36823 .40747 .36454 .40251 .31645 Mtetra
.40251 .31645 .40747 .36454 .4185 .36078 .41343 .31263 Mtetra
.564 .39 .604 r
.41343 .31263 .4185 .36078 .42958 .35696 .4244 .30876 Mtetra
.4244 .30876 .42958 .35696 .44071 .35309 .43541 .30482 Mtetra
.43541 .30482 .44071 .35309 .45188 .34916 .44646 .30087 Mtetra
.44646 .30087 .45188 .34916 .46309 .34513 .45756 .29695 Mtetra
.563 .389 .604 r
.45756 .29695 .46309 .34513 .47436 .34096 .4687 .29317 Mtetra
.561 .389 .605 r
.4687 .29317 .47436 .34096 .48567 .33656 .47989 .28956 Mtetra
.56 .389 .607 r
.47989 .28956 .48567 .33656 .49703 .33184 .49112 .28617 Mtetra
.56 .391 .61 r
.49112 .28617 .49703 .33184 .50843 .32669 .5024 .28292 Mtetra
.561 .396 .614 r
.5024 .28292 .50843 .32669 .51987 .321 .51374 .2797 Mtetra
.564 .403 .62 r
.51374 .2797 .51987 .321 .53135 .31479 .52512 .27636 Mtetra
.571 .413 .628 r
.52512 .27636 .53135 .31479 .54285 .3081 .53656 .27263 Mtetra
.579 .426 .638 r
.53656 .27263 .54285 .3081 .55438 .30114 .54805 .2685 Mtetra
.588 .44 .648 r
.54805 .2685 .55438 .30114 .56594 .29419 .55957 .26393 Mtetra
.595 .453 .658 r
.55957 .26393 .56594 .29419 .57752 .28744 .57114 .25912 Mtetra
.599 .463 .667 r
.57114 .25912 .57752 .28744 .58915 .2811 .58275 .25435 Mtetra
.6 .47 .676 r
.58275 .25435 .58915 .2811 .60081 .27519 .59442 .2498 Mtetra
.597 .475 .685 r
.59442 .2498 .60081 .27519 .61253 .26969 .60614 .24569 Mtetra
.593 .481 .695 r
.60614 .24569 .61253 .26969 .6243 .26457 .61792 .24205 Mtetra
.588 .487 .707 r
.61792 .24205 .6243 .26457 .63612 .25978 .62977 .23889 Mtetra
.585 .497 .722 r
.62977 .23889 .63612 .25978 .648 .25535 .6417 .23617 Mtetra
.581 .509 .739 r
.6417 .23617 .648 .25535 .65994 .25129 .65371 .23381 Mtetra
.577 .524 .759 r
.65371 .23381 .65994 .25129 .67196 .24759 .6658 .23176 Mtetra
.574 .542 .782 r
.6658 .23176 .67196 .24759 .68405 .24428 .67797 .22995 Mtetra
.57 .562 .805 r
.67797 .22995 .68405 .24428 .69622 .24129 .69022 .22831 Mtetra
.567 .583 .829 r
.69022 .22831 .69622 .24129 .70847 .2386 .70256 .22678 Mtetra
.563 .604 .852 r
.70256 .22678 .70847 .2386 .7208 .23613 .71497 .22531 Mtetra
.56 .626 .874 r
.71497 .22531 .7208 .23613 .73321 .23382 .72746 .22384 Mtetra
.557 .646 .893 r
.72746 .22384 .73321 .23382 .7457 .2316 .74003 .22235 Mtetra
.554 .665 .911 r
.74003 .22235 .7457 .2316 .75827 .22944 .75267 .22082 Mtetra
.551 .683 .926 r
.75267 .22082 .75827 .22944 .7709 .22725 .76539 .21923 Mtetra
.737 .766 .876 r
.10283 .44102 .1101 .44736 .12029 .4413 .11303 .43504 Mtetra
.74 .77 .877 r
.11303 .43504 .12029 .4413 .1305 .43517 .12326 .42897 Mtetra
.743 .773 .877 r
.12326 .42897 .1305 .43517 .14074 .42899 .13353 .42279 Mtetra
.746 .774 .876 r
.13353 .42279 .14074 .42899 .151 .42279 .14383 .41652 Mtetra
.748 .773 .873 r
.14383 .41652 .151 .42279 .16129 .41659 .15416 .41012 Mtetra
.748 .768 .87 r
.15416 .41012 .16129 .41659 .17159 .41043 .16452 .40366 Mtetra
.746 .76 .864 r
.16452 .40366 .17159 .41043 .1819 .40438 .17491 .39715 Mtetra
.741 .748 .857 r
.17491 .39715 .1819 .40438 .19222 .3985 .18531 .39068 Mtetra
.734 .732 .849 r
.18531 .39068 .19222 .3985 .20254 .39283 .19573 .38429 Mtetra
.725 .713 .839 r
.19573 .38429 .20254 .39283 .21286 .38746 .20615 .37806 Mtetra
.712 .691 .828 r
.20615 .37806 .21286 .38746 .22317 .38245 .21657 .37206 Mtetra
.699 .667 .816 r
.21657 .37206 .22317 .38245 .23347 .37785 .22699 .36633 Mtetra
.683 .642 .802 r
.22699 .36633 .23347 .37785 .24376 .37373 .2374 .36093 Mtetra
.669 .616 .786 r
.2374 .36093 .24376 .37373 .25405 .37007 .24783 .35578 Mtetra
.656 .59 .769 r
.24783 .35578 .25405 .37007 .26435 .36684 .25826 .35086 Mtetra
.646 .565 .749 r
.25826 .35086 .26435 .36684 .27467 .36382 .26872 .34597 Mtetra
.638 .543 .731 r
.26872 .34597 .27467 .36382 .28503 .36085 .27922 .34102 Mtetra
.632 .524 .713 r
.27922 .34102 .28503 .36085 .29545 .35765 .28977 .33592 Mtetra
.628 .509 .699 r
.28977 .33592 .29545 .35765 .30595 .35402 .30036 .33065 Mtetra
.622 .496 .688 r
.30036 .33065 .30595 .35402 .31651 .34999 .31097 .32538 Mtetra
.616 .486 .681 r
.31097 .32538 .31651 .34999 .32714 .34559 .32162 .32023 Mtetra
.61 .478 .677 r
.32162 .32023 .32714 .34559 .33781 .34106 .33227 .31535 Mtetra
.604 .473 .676 r
.33227 .31535 .33781 .34106 .34851 .33656 .34294 .31084 Mtetra
.599 .47 .676 r
.34294 .31084 .34851 .33656 .35925 .3322 .35363 .30666 Mtetra
.595 .468 .678 r
.35363 .30666 .35925 .3322 .37001 .32806 .36435 .30276 Mtetra
.593 .468 .68 r
.36435 .30276 .37001 .32806 .38081 .32409 .3751 .29903 Mtetra
.592 .469 .681 r
.3751 .29903 .38081 .32409 .39164 .32025 .38589 .29537 Mtetra
.593 .471 .683 r
.38589 .29537 .39164 .32025 .40251 .31645 .39672 .29169 Mtetra
.595 .473 .684 r
.39672 .29169 .40251 .31645 .41343 .31263 .4076 .2879 Mtetra
.597 .475 .684 r
.4076 .2879 .41343 .31263 .4244 .30876 .41854 .28398 Mtetra
.598 .476 .684 r
.41854 .28398 .4244 .30876 .43541 .30482 .42952 .27993 Mtetra
.599 .476 .683 r
.42952 .27993 .43541 .30482 .44646 .30087 .44054 .27577 Mtetra
.599 .475 .682 r
.44054 .27577 .44646 .30087 .45756 .29695 .45161 .27159 Mtetra
.597 .473 .681 r
.45161 .27159 .45756 .29695 .4687 .29317 .46273 .26748 Mtetra
.594 .469 .679 r
.46273 .26748 .4687 .29317 .47989 .28956 .47388 .26353 Mtetra
.589 .465 .678 r
.47388 .26353 .47989 .28956 .49112 .28617 .48508 .25988 Mtetra
.584 .46 .677 r
.48508 .25988 .49112 .28617 .5024 .28292 .49632 .25655 Mtetra
.578 .456 .678 r
.49632 .25655 .5024 .28292 .51374 .2797 .50761 .2536 Mtetra
.574 .455 .68 r
.50761 .2536 .51374 .2797 .52512 .27636 .51895 .25092 Mtetra
.573 .458 .684 r
.51895 .25092 .52512 .27636 .53656 .27263 .53036 .24837 Mtetra
.575 .466 .692 r
.53036 .24837 .53656 .27263 .54805 .2685 .54182 .24583 Mtetra
.581 .48 .704 r
.54182 .24583 .54805 .2685 .55957 .26393 .55334 .24311 Mtetra
.587 .497 .719 r
.55334 .24311 .55957 .26393 .57114 .25912 .56492 .24025 Mtetra
.593 .517 .738 r
.56492 .24025 .57114 .25912 .58275 .25435 .57655 .23731 Mtetra
.596 .538 .759 r
.57655 .23731 .58275 .25435 .59442 .2498 .58825 .23442 Mtetra
.595 .557 .782 r
.58825 .23442 .59442 .2498 .60614 .24569 .60001 .23176 Mtetra
.591 .577 .806 r
.60001 .23176 .60614 .24569 .61792 .24205 .61183 .22937 Mtetra
.583 .594 .829 r
.61183 .22937 .61792 .24205 .62977 .23889 .62374 .2273 Mtetra
.574 .611 .852 r
.62374 .2273 .62977 .23889 .6417 .23617 .63572 .22553 Mtetra
.563 .628 .874 r
.63572 .22553 .6417 .23617 .65371 .23381 .64778 .22399 Mtetra
.553 .644 .894 r
.64778 .22399 .65371 .23381 .6658 .23176 .65993 .22263 Mtetra
.544 .66 .912 r
.65993 .22263 .6658 .23176 .67797 .22995 .67215 .22137 Mtetra
.537 .673 .926 r
.67215 .22137 .67797 .22995 .69022 .22831 .68445 .22014 Mtetra
.534 .685 .936 r
.68445 .22014 .69022 .22831 .70256 .22678 .69683 .21887 Mtetra
.533 .694 .943 r
.69683 .21887 .70256 .22678 .71497 .22531 .70929 .21754 Mtetra
.536 .701 .946 r
.70929 .21754 .71497 .22531 .72746 .22384 .72182 .21609 Mtetra
.54 .705 .947 r
.72182 .21609 .72746 .22384 .74003 .22235 .73441 .21454 Mtetra
.545 .706 .946 r
.73441 .21454 .74003 .22235 .75267 .22082 .74708 .21289 Mtetra
.55 .706 .943 r
.74708 .21289 .75267 .22082 .76539 .21923 .75983 .21113 Mtetra
.719 .764 .888 r
.09551 .43462 .10283 .44102 .11303 .43504 .10564 .42931 Mtetra
.726 .786 .9 r
.10564 .42931 .11303 .43504 .12326 .42897 .11582 .42389 Mtetra
.733 .808 .911 r
.11582 .42389 .12326 .42897 .13353 .42279 .12604 .41834 Mtetra
.739 .831 .921 r
.12604 .41834 .13353 .42279 .14383 .41652 .1363 .41263 Mtetra
.746 .851 .928 r
.1363 .41263 .14383 .41652 .15416 .41012 .14661 .40674 Mtetra
.752 .87 .934 r
.14661 .40674 .15416 .41012 .16452 .40366 .15696 .40069 Mtetra
.756 .885 .937 r
.15696 .40069 .16452 .40366 .17491 .39715 .16735 .39449 Mtetra
.757 .896 .94 r
.16735 .39449 .17491 .39715 .18531 .39068 .17777 .3882 Mtetra
.758 .904 .941 r
.17777 .3882 .18531 .39068 .19573 .38429 .18822 .38187 Mtetra
.757 .907 .943 r
.18822 .38187 .19573 .38429 .20615 .37806 .19869 .37554 Mtetra
.754 .905 .943 r
.19869 .37554 .20615 .37806 .21657 .37206 .20918 .36926 Mtetra
.754 .896 .942 r
.20918 .36926 .21657 .37206 .22699 .36633 .21969 .36302 Mtetra
.753 .88 .937 r
.21969 .36302 .22699 .36633 .2374 .36093 .23021 .35683 Mtetra
.753 .854 .925 r
.23021 .35683 .2374 .36093 .24783 .35578 .24076 .35062 Mtetra
.75 .819 .906 r
.24076 .35062 .24783 .35578 .25826 .35086 .25134 .34435 Mtetra
.742 .777 .881 r
.25134 .34435 .25826 .35086 .26872 .34597 .26195 .33804 Mtetra
.731 .736 .855 r
.26195 .33804 .26872 .34597 .27922 .34102 .27259 .3317 Mtetra
.716 .7 .834 r
.27259 .3317 .27922 .34102 .28977 .33592 .28323 .32554 Mtetra
.7 .673 .82 r
.28323 .32554 .28977 .33592 .30036 .33065 .29387 .3197 Mtetra
.684 .657 .817 r
.29387 .3197 .30036 .33065 .31097 .32538 .30451 .31436 Mtetra
.669 .65 .822 r
.30451 .31436 .31097 .32538 .32162 .32023 .31514 .30963 Mtetra
.658 .654 .835 r
.31514 .30963 .32162 .32023 .33227 .31535 .32577 .30543 Mtetra
.648 .665 .853 r
.32577 .30543 .33227 .31535 .34294 .31084 .33641 .30168 Mtetra
.642 .682 .872 r
.33641 .30168 .34294 .31084 .35363 .30666 .34708 .29819 Mtetra
.639 .7 .89 r
.34708 .29819 .35363 .30666 .36435 .30276 .35778 .29482 Mtetra
.639 .716 .903 r
.35778 .29482 .36435 .30276 .3751 .29903 .36854 .29145 Mtetra
.643 .728 .911 r
.36854 .29145 .3751 .29903 .38589 .29537 .37934 .28797 Mtetra
.647 .737 .914 r
.37934 .28797 .38589 .29537 .39672 .29169 .3902 .28437 Mtetra
.653 .742 .915 r
.3902 .28437 .39672 .29169 .4076 .2879 .4011 .28059 Mtetra
.659 .745 .913 r
.4011 .28059 .4076 .2879 .41854 .28398 .41206 .27664 Mtetra
.665 .747 .911 r
.41206 .27664 .41854 .28398 .42952 .27993 .42307 .27252 Mtetra
.67 .748 .908 r
.42307 .27252 .42952 .27993 .44054 .27577 .43413 .26823 Mtetra
.674 .746 .904 r
.43413 .26823 .44054 .27577 .45161 .27159 .44524 .2638 Mtetra
.676 .74 .898 r
.44524 .2638 .45161 .27159 .46273 .26748 .45639 .25927 Mtetra
.675 .728 .89 r
.45639 .25927 .46273 .26748 .47388 .26353 .46758 .25473 Mtetra
.668 .711 .88 r
.46758 .25473 .47388 .26353 .48508 .25988 .47881 .25031 Mtetra
.657 .688 .867 r
.47881 .25031 .48508 .25988 .49632 .25655 .49008 .24615 Mtetra
.639 .661 .855 r
.49008 .24615 .49632 .25655 .50761 .2536 .50139 .24245 Mtetra
.621 .637 .846 r
.50139 .24245 .50761 .2536 .51895 .25092 .51276 .23928 Mtetra
.6 .618 .841 r
.51276 .23928 .51895 .25092 .53036 .24837 .52417 .23673 Mtetra
.583 .611 .845 r
.52417 .23673 .53036 .24837 .54182 .24583 .53565 .2347 Mtetra
.572 .616 .858 r
.53565 .2347 .54182 .24583 .55334 .24311 .54719 .23301 Mtetra
.562 .637 .883 r
.54719 .23301 .55334 .24311 .56492 .24025 .5588 .23149 Mtetra
.556 .671 .915 r
.5588 .23149 .56492 .24025 .57655 .23731 .57049 .22996 Mtetra
.544 .711 .949 r
.57049 .22996 .57655 .23731 .58825 .23442 .58224 .22838 Mtetra
.524 .749 .978 r
.58224 .22838 .58825 .23442 .60001 .23176 .59406 .22675 Mtetra
.497 .777 .994 r
.59406 .22675 .60001 .23176 .61183 .22937 .60595 .22511 Mtetra
.464 .791 .999 r
.60595 .22511 .61183 .22937 .62374 .2273 .61791 .22353 Mtetra
.438 .795 .997 r
.61791 .22353 .62374 .2273 .63572 .22553 .62995 .22199 Mtetra
.419 .795 .993 r
.62995 .22199 .63572 .22553 .64778 .22399 .64206 .2205 Mtetra
.414 .794 .992 r
.64206 .2205 .64778 .22399 .65993 .22263 .65425 .21903 Mtetra
.422 .795 .994 r
.65425 .21903 .65993 .22263 .67215 .22137 .66651 .21751 Mtetra
.44 .796 .997 r
.66651 .21751 .67215 .22137 .68445 .22014 .67884 .21591 Mtetra
.466 .797 .999 r
.67884 .21591 .68445 .22014 .69683 .21887 .69124 .21415 Mtetra
.494 .794 .998 r
.69124 .21415 .69683 .21887 .70929 .21754 .70371 .21224 Mtetra
.522 .786 .993 r
.70371 .21224 .70929 .21754 .72182 .21609 .71624 .21014 Mtetra
.545 .774 .983 r
.71624 .21014 .72182 .21609 .73441 .21454 .72884 .20788 Mtetra
.563 .757 .969 r
.72884 .20788 .73441 .21454 .74708 .21289 .7415 .20549 Mtetra
.576 .739 .953 r
.7415 .20549 .74708 .21289 .75983 .21113 .75422 .20298 Mtetra
.68 .757 .909 r
.08813 .42819 .09551 .43462 .10564 .42931 .09814 .42404 Mtetra
.685 .797 .934 r
.09814 .42404 .10564 .42931 .11582 .42389 .10819 .4198 Mtetra
.688 .839 .956 r
.10819 .4198 .11582 .42389 .12604 .41834 .11829 .41543 Mtetra
.685 .881 .971 r
.11829 .41543 .12604 .41834 .1363 .41263 .12844 .41088 Mtetra
.675 .917 .974 r
.12844 .41088 .1363 .41263 .14661 .40674 .13866 .40612 Mtetra
.653 .942 .962 r
.13866 .40612 .14661 .40674 .15696 .40069 .14892 .40116 Mtetra
.618 .95 .929 r
.14892 .40116 .15696 .40069 .16735 .39449 .15925 .39597 Mtetra
.569 .939 .879 r
.15925 .39597 .16735 .39449 .17777 .3882 .16962 .39059 Mtetra
.514 .912 .817 r
.16962 .39059 .17777 .3882 .18822 .38187 .18004 .38505 Mtetra
.458 .876 .752 r
.18004 .38505 .18822 .38187 .19869 .37554 .1905 .37937 Mtetra
.408 .838 .692 r
.1905 .37937 .19869 .37554 .20918 .36926 .201 .37358 Mtetra
.37 .806 .645 r
.201 .37358 .20918 .36926 .21969 .36302 .21153 .36769 Mtetra
0 0 0 r
.21153 .36769 .21969 .36302 .23021 .35683 .2221 .36172 Mtetra
.2221 .36172 .23021 .35683 .24076 .35062 .2327 .35568 Mtetra
.2327 .35568 .24076 .35062 .25134 .34435 .24333 .34959 Mtetra
.24333 .34959 .25134 .34435 .26195 .33804 .25398 .34356 Mtetra
.25398 .34356 .26195 .33804 .27259 .3317 .26464 .33768 Mtetra
.26464 .33768 .27259 .3317 .28323 .32554 .27531 .33209 Mtetra
.27531 .33209 .28323 .32554 .29387 .3197 .28598 .32692 Mtetra
.011 0 0 r
.28598 .32692 .29387 .3197 .30451 .31436 .29665 .32216 Mtetra
.079 0 0 r
.29665 .32216 .30451 .31436 .31514 .30963 .30732 .3178 Mtetra
.117 0 0 r
.30732 .3178 .31514 .30963 .32577 .30543 .31802 .31366 Mtetra
.13 0 0 r
.31802 .31366 .32577 .30543 .33641 .30168 .32875 .30964 Mtetra
.121 0 0 r
.32875 .30964 .33641 .30168 .34708 .29819 .33953 .30564 Mtetra
.095 0 0 r
.33953 .30564 .34708 .29819 .35778 .29482 .35035 .30158 Mtetra
.057 0 0 r
.35035 .30158 .35778 .29482 .36854 .29145 .36121 .29748 Mtetra
.015 0 0 r
.36121 .29748 .36854 .29145 .37934 .28797 .37212 .29335 Mtetra
0 0 0 r
.37212 .29335 .37934 .28797 .3902 .28437 .38306 .28925 Mtetra
.38306 .28925 .3902 .28437 .4011 .28059 .39405 .2852 Mtetra
.39405 .2852 .4011 .28059 .41206 .27664 .40508 .28123 Mtetra
.40508 .28123 .41206 .27664 .42307 .27252 .41615 .27734 Mtetra
.41615 .27734 .42307 .27252 .43413 .26823 .42727 .2735 Mtetra
.011 0 0 r
.42727 .2735 .43413 .26823 .44524 .2638 .43843 .26969 Mtetra
.049 0 0 r
.43843 .26969 .44524 .2638 .45639 .25927 .44964 .26585 Mtetra
.087 0 0 r
.44964 .26585 .45639 .25927 .46758 .25473 .4609 .26197 Mtetra
.118 0 0 r
.4609 .26197 .46758 .25473 .47881 .25031 .4722 .25804 Mtetra
.142 0 0 r
.4722 .25804 .47881 .25031 .49008 .24615 .48356 .25411 Mtetra
.161 0 0 r
.48356 .25411 .49008 .24615 .50139 .24245 .49496 .25031 Mtetra
.173 0 0 r
.49496 .25031 .50139 .24245 .51276 .23928 .50641 .24673 Mtetra
.184 0 0 r
.50641 .24673 .51276 .23928 .52417 .23673 .51791 .24356 Mtetra
.188 0 0 r
.51791 .24356 .52417 .23673 .53565 .2347 .52947 .24081 Mtetra
.187 0 0 r
.52947 .24081 .53565 .2347 .54719 .23301 .54109 .23848 Mtetra
.181 0 0 r
.54109 .23848 .54719 .23301 .5588 .23149 .55277 .23647 Mtetra
.169 0 0 r
.55277 .23647 .5588 .23149 .57049 .22996 .56453 .2346 Mtetra
.158 0 0 r
.56453 .2346 .57049 .22996 .58224 .22838 .57635 .2328 Mtetra
.144 0 0 r
.57635 .2328 .58224 .22838 .59406 .22675 .58824 .23096 Mtetra
.128 0 0 r
.58824 .23096 .59406 .22675 .60595 .22511 .6002 .22905 Mtetra
.108 0 0 r
.6002 .22905 .60595 .22511 .61791 .22353 .61223 .22706 Mtetra
.076 0 0 r
.61223 .22706 .61791 .22353 .62995 .22199 .62433 .22497 Mtetra
.032 0 0 r
.62433 .22497 .62995 .22199 .64206 .2205 .63649 .22277 Mtetra
0 0 0 r
.63649 .22277 .64206 .2205 .65425 .21903 .64871 .22044 Mtetra
.64871 .22044 .65425 .21903 .66651 .21751 .661 .21793 Mtetra
.22 .742 .773 r
.661 .21793 .66651 .21751 .67884 .21591 .67335 .21523 Mtetra
.334 .814 .878 r
.67335 .21523 .67884 .21591 .69124 .21415 .68575 .2123 Mtetra
.439 .857 .953 r
.68575 .2123 .69124 .21415 .70371 .21224 .69821 .20916 Mtetra
.522 .868 .991 r
.69821 .20916 .70371 .21224 .71624 .21014 .71072 .20579 Mtetra
.577 .85 .996 r
.71072 .20579 .71624 .21014 .72884 .20788 .72328 .20224 Mtetra
.61 .818 .98 r
.72328 .20224 .72884 .20788 .7415 .20549 .7359 .19855 Mtetra
.627 .78 .954 r
.7359 .19855 .7415 .20549 .75422 .20298 .74857 .19475 Mtetra
.622 .743 .933 r
.0807 .4217 .08813 .42819 .09814 .42404 .09054 .41893 Mtetra
.616 .789 .964 r
.09054 .41893 .09814 .42404 .10819 .4198 .10043 .41609 Mtetra
.602 .836 .988 r
.10043 .41609 .10819 .4198 .11829 .41543 .11038 .41313 Mtetra
.573 .876 .994 r
.11038 .41313 .11829 .41543 .12844 .41088 .12039 .41001 Mtetra
.523 .895 .966 r
.12039 .41001 .12844 .41088 .13866 .40612 .13047 .40669 Mtetra
.447 .879 .895 r
.13047 .40669 .13866 .40612 .14892 .40116 .14061 .40313 Mtetra
.355 .826 .785 r
.14061 .40313 .14892 .40116 .15925 .39597 .15083 .39933 Mtetra
0 0 0 r
.15083 .39933 .15925 .39597 .16962 .39059 .1611 .39527 Mtetra
.1611 .39527 .16962 .39059 .18004 .38505 .17145 .39095 Mtetra
.17145 .39095 .18004 .38505 .1905 .37937 .18185 .3864 Mtetra
.18185 .3864 .1905 .37937 .201 .37358 .19231 .38163 Mtetra
.013 0 0 r
.19231 .38163 .201 .37358 .21153 .36769 .20283 .37669 Mtetra
.056 0 0 r
.20283 .37669 .21153 .36769 .2221 .36172 .21338 .37163 Mtetra
.098 0 0 r
.21338 .37163 .2221 .36172 .2327 .35568 .22397 .36655 Mtetra
.143 0 0 r
.22397 .36655 .2327 .35568 .24333 .34959 .23459 .36154 Mtetra
.191 0 0 r
.23459 .36154 .24333 .34959 .25398 .34356 .24522 .35671 Mtetra
.238 0 .045 r
.24522 .35671 .25398 .34356 .26464 .33768 .25586 .35217 Mtetra
.279 0 .095 r
.25586 .35217 .26464 .33768 .27531 .33209 .26652 .3479 Mtetra
.311 0 .135 r
.26652 .3479 .27531 .33209 .28598 .32692 .2772 .34388 Mtetra
.329 0 .161 r
.2772 .34388 .28598 .32692 .29665 .32216 .28791 .3399 Mtetra
.335 0 .175 r
.28791 .3399 .29665 .32216 .30732 .3178 .29867 .33582 Mtetra
.331 0 .177 r
.29867 .33582 .30732 .3178 .31802 .31366 .3095 .3315 Mtetra
.318 0 .169 r
.3095 .3315 .31802 .31366 .32875 .30964 .32038 .32686 Mtetra
.303 0 .153 r
.32038 .32686 .32875 .30964 .33953 .30564 .33131 .32199 Mtetra
.285 0 .132 r
.33131 .32199 .33953 .30564 .35035 .30158 .34229 .31694 Mtetra
.271 0 .109 r
.34229 .31694 .35035 .30158 .36121 .29748 .35331 .3119 Mtetra
.26 0 .087 r
.35331 .3119 .36121 .29748 .37212 .29335 .36436 .30698 Mtetra
.256 0 .07 r
.36436 .30698 .37212 .29335 .38306 .28925 .37543 .3023 Mtetra
.26 0 .06 r
.37543 .3023 .38306 .28925 .39405 .2852 .38653 .29795 Mtetra
.272 0 .059 r
.38653 .29795 .39405 .2852 .40508 .28123 .39766 .29396 Mtetra
.289 0 .068 r
.39766 .29396 .40508 .28123 .41615 .27734 .40882 .29035 Mtetra
.308 0 .084 r
.40882 .29035 .41615 .27734 .42727 .2735 .42002 .28706 Mtetra
.327 0 .105 r
.42002 .28706 .42727 .2735 .43843 .26969 .43126 .28402 Mtetra
.342 0 .127 r
.43126 .28402 .43843 .26969 .44964 .26585 .44255 .2811 Mtetra
.354 0 .149 r
.44255 .2811 .44964 .26585 .4609 .26197 .4539 .27819 Mtetra
.359 0 .167 r
.4539 .27819 .4609 .26197 .4722 .25804 .4653 .27511 Mtetra
.361 0 .18 r
.4653 .27511 .4722 .25804 .48356 .25411 .47677 .2718 Mtetra
.358 0 .187 r
.47677 .2718 .48356 .25411 .49496 .25031 .48829 .26816 Mtetra
.353 0 .187 r
.48829 .26816 .49496 .25031 .50641 .24673 .49987 .26427 Mtetra
.348 0 .181 r
.49987 .26427 .50641 .24673 .51791 .24356 .5115 .26028 Mtetra
.341 0 .167 r
.5115 .26028 .51791 .24356 .52947 .24081 .52318 .25634 Mtetra
.336 0 .146 r
.52318 .25634 .52947 .24081 .54109 .23848 .53491 .25265 Mtetra
.328 0 .118 r
.53491 .25265 .54109 .23848 .55277 .23647 .5467 .24924 Mtetra
.318 0 .084 r
.5467 .24924 .55277 .23647 .56453 .2346 .55855 .24611 Mtetra
.305 0 .048 r
.55855 .24611 .56453 .2346 .57635 .2328 .57046 .24318 Mtetra
.286 0 .007 r
.57046 .24318 .57635 .2328 .58824 .23096 .58243 .24032 Mtetra
.263 0 0 r
.58243 .24032 .58824 .23096 .6002 .22905 .59447 .23744 Mtetra
.23 0 0 r
.59447 .23744 .6002 .22905 .61223 .22706 .60657 .23443 Mtetra
.188 0 0 r
.60657 .23443 .61223 .22706 .62433 .22497 .61872 .23125 Mtetra
.131 0 0 r
.61872 .23125 .62433 .22497 .63649 .22277 .63093 .22785 Mtetra
.053 0 0 r
.63093 .22785 .63649 .22277 .64871 .22044 .64319 .22421 Mtetra
0 0 0 r
.64319 .22421 .64871 .22044 .661 .21793 .6555 .22029 Mtetra
.6555 .22029 .661 .21793 .67335 .21523 .66786 .21611 Mtetra
.334 .813 .775 r
.66786 .21611 .67335 .21523 .68575 .2123 .68025 .21166 Mtetra
.475 .893 .899 r
.68025 .21166 .68575 .2123 .69821 .20916 .69269 .20697 Mtetra
.581 .919 .967 r
.69269 .20697 .69821 .20916 .71072 .20579 .70518 .20206 Mtetra
.643 .899 .984 r
.70518 .20206 .71072 .20579 .72328 .20224 .7177 .19697 Mtetra
.673 .858 .97 r
.7177 .19697 .72328 .20224 .7359 .19855 .73026 .19176 Mtetra
.683 .809 .942 r
.73026 .19176 .7359 .19855 .74857 .19475 .74288 .18646 Mtetra
.552 .72 .952 r
.07322 .41517 .0807 .4217 .09054 .41893 .0829 .41364 Mtetra
.534 .759 .98 r
.0829 .41364 .09054 .41893 .10043 .41609 .09265 .41207 Mtetra
.506 .796 .998 r
.09265 .41207 .10043 .41609 .11038 .41313 .10245 .41041 Mtetra
.464 .824 .995 r
.10245 .41041 .11038 .41313 .12039 .41001 .11232 .40861 Mtetra
.402 .831 .959 r
.11232 .40861 .12039 .41001 .13047 .40669 .12226 .40664 Mtetra
.321 .805 .88 r
.12226 .40664 .13047 .40669 .14061 .40313 .13228 .40446 Mtetra
.229 .748 .764 r
.13228 .40446 .14061 .40313 .15083 .39933 .14237 .40203 Mtetra
0 0 0 r
.14237 .40203 .15083 .39933 .1611 .39527 .15254 .39935 Mtetra
.15254 .39935 .1611 .39527 .17145 .39095 .16279 .39641 Mtetra
.021 0 0 r
.16279 .39641 .17145 .39095 .18185 .3864 .1731 .39324 Mtetra
.081 0 0 r
.1731 .39324 .18185 .3864 .19231 .38163 .18348 .38984 Mtetra
.135 0 0 r
.18348 .38984 .19231 .38163 .20283 .37669 .19392 .38629 Mtetra
.181 0 0 r
.19392 .38629 .20283 .37669 .21338 .37163 .20441 .38263 Mtetra
.224 0 0 r
.20441 .38263 .21338 .37163 .22397 .36655 .21495 .37894 Mtetra
.261 0 .034 r
.21495 .37894 .22397 .36655 .23459 .36154 .22553 .3753 Mtetra
.292 0 .082 r
.22553 .3753 .23459 .36154 .24522 .35671 .23614 .37174 Mtetra
.317 0 .119 r
.23614 .37174 .24522 .35671 .25586 .35217 .24678 .36829 Mtetra
.332 0 .145 r
.24678 .36829 .25586 .35217 .26652 .3479 .25747 .36485 Mtetra
.34 0 .161 r
.25747 .36485 .26652 .3479 .2772 .34388 .26821 .36133 Mtetra
.338 0 .167 r
.26821 .36133 .2772 .34388 .28791 .3399 .27901 .35757 Mtetra
.329 0 .166 r
.27901 .35757 .28791 .3399 .29867 .33582 .28988 .35347 Mtetra
.318 0 .16 r
.28988 .35347 .29867 .33582 .3095 .3315 .30082 .34904 Mtetra
.306 0 .153 r
.30082 .34904 .3095 .3315 .32038 .32686 .31182 .34429 Mtetra
.3 0 .149 r
.31182 .34429 .32038 .32686 .33131 .32199 .32287 .33936 Mtetra
.297 0 .147 r
.32287 .33936 .33131 .32199 .34229 .31694 .33396 .33436 Mtetra
.301 0 .15 r
.33396 .33436 .34229 .31694 .35331 .3119 .34508 .32943 Mtetra
.309 0 .156 r
.34508 .32943 .35331 .3119 .36436 .30698 .35624 .32465 Mtetra
.319 0 .163 r
.35624 .32465 .36436 .30698 .37543 .3023 .36742 .3201 Mtetra
.33 0 .17 r
.36742 .3201 .37543 .3023 .38653 .29795 .37863 .31581 Mtetra
.341 0 .176 r
.37863 .31581 .38653 .29795 .39766 .29396 .38988 .31182 Mtetra
.35 0 .18 r
.38988 .31182 .39766 .29396 .40882 .29035 .40116 .30811 Mtetra
.358 0 .183 r
.40116 .30811 .40882 .29035 .42002 .28706 .41248 .30468 Mtetra
.364 0 .183 r
.41248 .30468 .42002 .28706 .43126 .28402 .42384 .30147 Mtetra
.367 0 .182 r
.42384 .30147 .43126 .28402 .44255 .2811 .43525 .29843 Mtetra
.368 0 .181 r
.43525 .29843 .44255 .2811 .4539 .27819 .44672 .29545 Mtetra
.366 0 .179 r
.44672 .29545 .4539 .27819 .4653 .27511 .45824 .2924 Mtetra
.362 0 .178 r
.45824 .2924 .4653 .27511 .47677 .2718 .46983 .28918 Mtetra
.354 0 .175 r
.46983 .28918 .47677 .2718 .48829 .26816 .48147 .28563 Mtetra
.345 0 .173 r
.48147 .28563 .48829 .26816 .49987 .26427 .49318 .28175 Mtetra
.336 0 .169 r
.49318 .28175 .49987 .26427 .5115 .26028 .50493 .27751 Mtetra
.326 0 .162 r
.50493 .27751 .5115 .26028 .52318 .25634 .51674 .27303 Mtetra
.318 0 .152 r
.51674 .27303 .52318 .25634 .53491 .25265 .5286 .26848 Mtetra
.308 0 .134 r
.5286 .26848 .53491 .25265 .5467 .24924 .5405 .26392 Mtetra
.296 0 .109 r
.5405 .26392 .5467 .24924 .55855 .24611 .55246 .25948 Mtetra
.278 0 .075 r
.55246 .25948 .55855 .24611 .57046 .24318 .56446 .25511 Mtetra
.253 0 .03 r
.56446 .25511 .57046 .24318 .58243 .24032 .57652 .25079 Mtetra
.218 0 0 r
.57652 .25079 .58243 .24032 .59447 .23744 .58863 .24643 Mtetra
.169 0 0 r
.58863 .24643 .59447 .23744 .60657 .23443 .6008 .24197 Mtetra
.104 0 0 r
.6008 .24197 .60657 .23443 .61872 .23125 .61301 .23733 Mtetra
.018 0 0 r
.61301 .23733 .61872 .23125 .63093 .22785 .62526 .23247 Mtetra
0 0 0 r
.62526 .23247 .63093 .22785 .64319 .22421 .63755 .22735 Mtetra
.63755 .22735 .64319 .22421 .6555 .22029 .64989 .22196 Mtetra
.372 .828 .73 r
.64989 .22196 .6555 .22029 .66786 .21611 .66225 .2163 Mtetra
.509 .913 .855 r
.66225 .2163 .66786 .21611 .68025 .21166 .67465 .21037 Mtetra
.614 .948 .932 r
.67465 .21037 .68025 .21166 .69269 .20697 .68708 .20422 Mtetra
.681 .941 .963 r
.68708 .20422 .69269 .20697 .70518 .20206 .69955 .19787 Mtetra
.715 .908 .963 r
.69955 .19787 .70518 .20206 .7177 .19697 .71204 .19137 Mtetra
.727 .865 .946 r
.71204 .19137 .7177 .19697 .73026 .19176 .72457 .18476 Mtetra
.728 .82 .922 r
.72457 .18476 .73026 .19176 .74288 .18646 .73713 .1781 Mtetra
.486 .695 .961 r
.06568 .40859 .07322 .41517 .0829 .41364 .07525 .408 Mtetra
.463 .721 .98 r
.07525 .408 .0829 .41364 .09265 .41207 .08487 .40739 Mtetra
.435 .745 .993 r
.08487 .40739 .09265 .41207 .10245 .41041 .09456 .40672 Mtetra
.398 .764 .993 r
.09456 .40672 .10245 .41041 .11232 .40861 .10432 .40596 Mtetra
.351 .774 .975 r
.10432 .40596 .11232 .40861 .12226 .40664 .11416 .40507 Mtetra
.293 .768 .931 r
.11416 .40507 .12226 .40664 .13228 .40446 .12406 .404 Mtetra
.226 .742 .858 r
.12406 .404 .13228 .40446 .14237 .40203 .13405 .40273 Mtetra
.149 .693 .758 r
.13405 .40273 .14237 .40203 .15254 .39935 .14412 .40126 Mtetra
0 0 0 r
.14412 .40126 .15254 .39935 .16279 .39641 .15427 .39956 Mtetra
.004 0 0 r
.15427 .39956 .16279 .39641 .1731 .39324 .16449 .39768 Mtetra
.073 0 0 r
.16449 .39768 .1731 .39324 .18348 .38984 .17478 .39561 Mtetra
.136 0 0 r
.17478 .39561 .18348 .38984 .19392 .38629 .18514 .39343 Mtetra
.19 0 0 r
.18514 .39343 .19392 .38629 .20441 .38263 .19555 .39116 Mtetra
.234 0 0 r
.19555 .39116 .20441 .38263 .21495 .37894 .20603 .38882 Mtetra
.268 0 0 r
.20603 .38882 .21495 .37894 .22553 .3753 .21656 .38643 Mtetra
.29 0 .016 r
.21656 .38643 .22553 .3753 .23614 .37174 .22715 .38392 Mtetra
.302 0 .049 r
.22715 .38392 .23614 .37174 .24678 .36829 .23781 .38124 Mtetra
.302 0 .066 r
.23781 .38124 .24678 .36829 .25747 .36485 .24854 .37827 Mtetra
.293 0 .07 r
.24854 .37827 .25747 .36485 .26821 .36133 .25936 .37491 Mtetra
.279 0 .066 r
.25936 .37491 .26821 .36133 .27901 .35757 .27026 .37116 Mtetra
.262 0 .057 r
.27026 .37116 .27901 .35757 .28988 .35347 .28122 .36702 Mtetra
.253 0 .051 r
.28122 .36702 .28988 .35347 .30082 .34904 .29225 .36267 Mtetra
.25 0 .052 r
.29225 .36267 .30082 .34904 .31182 .34429 .30333 .35821 Mtetra
.258 0 .062 r
.30333 .35821 .31182 .34429 .32287 .33936 .31445 .35375 Mtetra
.272 0 .079 r
.31445 .35375 .32287 .33936 .33396 .33436 .3256 .34939 Mtetra
.287 0 .1 r
.3256 .34939 .33396 .33436 .34508 .32943 .33679 .34513 Mtetra
.302 0 .119 r
.33679 .34513 .34508 .32943 .35624 .32465 .34802 .34098 Mtetra
.314 0 .135 r
.34802 .34098 .35624 .32465 .36742 .3201 .35929 .33689 Mtetra
.323 0 .147 r
.35929 .33689 .36742 .3201 .37863 .31581 .3706 .33286 Mtetra
.327 0 .153 r
.3706 .33286 .37863 .31581 .38988 .31182 .38196 .32885 Mtetra
.329 0 .153 r
.38196 .32885 .38988 .31182 .40116 .30811 .39337 .32488 Mtetra
.328 0 .149 r
.39337 .32488 .40116 .30811 .41248 .30468 .40482 .32095 Mtetra
.325 0 .14 r
.40482 .32095 .41248 .30468 .42384 .30147 .41632 .3171 Mtetra
.321 0 .128 r
.41632 .3171 .42384 .30147 .43525 .29843 .42786 .31335 Mtetra
.316 0 .114 r
.42786 .31335 .43525 .29843 .44672 .29545 .43946 .3097 Mtetra
.311 0 .099 r
.43946 .3097 .44672 .29545 .45824 .2924 .4511 .30614 Mtetra
.304 0 .086 r
.4511 .30614 .45824 .2924 .46983 .28918 .4628 .3026 Mtetra
.296 0 .075 r
.4628 .3026 .46983 .28918 .48147 .28563 .47456 .29895 Mtetra
.286 0 .069 r
.47456 .29895 .48147 .28563 .49318 .28175 .48637 .29507 Mtetra
.272 0 .063 r
.48637 .29507 .49318 .28175 .50493 .27751 .49824 .29081 Mtetra
.256 0 .055 r
.49824 .29081 .50493 .27751 .51674 .27303 .51017 .28614 Mtetra
.238 0 .043 r
.51017 .28614 .51674 .27303 .5286 .26848 .52214 .28107 Mtetra
.215 0 .022 r
.52214 .28107 .5286 .26848 .5405 .26392 .53415 .2757 Mtetra
.187 0 0 r
.53415 .2757 .5405 .26392 .55246 .25948 .54621 .27015 Mtetra
.151 0 0 r
.54621 .27015 .55246 .25948 .56446 .25511 .55831 .26446 Mtetra
.103 0 0 r
.55831 .26446 .56446 .25511 .57652 .25079 .57045 .25872 Mtetra
.039 0 0 r
.57045 .25872 .57652 .25079 .58863 .24643 .58264 .25289 Mtetra
0 0 0 r
.58264 .25289 .58863 .24643 .6008 .24197 .59486 .24698 Mtetra
.59486 .24698 .6008 .24197 .61301 .23733 .60712 .24092 Mtetra
.60712 .24092 .61301 .23733 .62526 .23247 .61942 .23468 Mtetra
.399 .837 .705 r
.61942 .23468 .62526 .23247 .63755 .22735 .63175 .22823 Mtetra
.521 .916 .817 r
.63175 .22823 .63755 .22735 .64989 .22196 .64411 .22154 Mtetra
.618 .957 .894 r
.64411 .22154 .64989 .22196 .66225 .2163 .65649 .21462 Mtetra
.687 .965 .936 r
.65649 .21462 .66225 .2163 .67465 .21037 .6689 .20747 Mtetra
.729 .949 .95 r
.6689 .20747 .67465 .21037 .68708 .20422 .68134 .20014 Mtetra
.75 .92 .948 r
.68134 .20014 .68708 .20422 .69955 .19787 .6938 .19265 Mtetra
.759 .886 .936 r
.6938 .19265 .69955 .19787 .71204 .19137 .70629 .18505 Mtetra
.76 .852 .919 r
.70629 .18505 .71204 .19137 .72457 .18476 .7188 .17738 Mtetra
.755 .818 .902 r
.7188 .17738 .72457 .18476 .73713 .1781 .73134 .16968 Mtetra
.456 .683 .963 r
.05808 .40196 .06568 .40859 .07525 .408 .06761 .40172 Mtetra
.446 .692 .97 r
.06761 .40172 .07525 .408 .08487 .40739 .0772 .40149 Mtetra
.436 .702 .977 r
.0772 .40149 .08487 .40739 .09456 .40672 .08685 .40123 Mtetra
.427 .714 .984 r
.08685 .40123 .09456 .40672 .10432 .40596 .09656 .40092 Mtetra
.417 .726 .989 r
.09656 .40092 .10432 .40596 .11416 .40507 .10635 .40053 Mtetra
.406 .74 .993 r
.10635 .40053 .11416 .40507 .12406 .404 .1162 .40002 Mtetra
.394 .755 .993 r
.1162 .40002 .12406 .404 .13405 .40273 .12614 .39938 Mtetra
.376 .768 .988 r
.12614 .39938 .13405 .40273 .14412 .40126 .13615 .39858 Mtetra
.354 .777 .975 r
.13615 .39858 .14412 .40126 .15427 .39956 .14624 .3976 Mtetra
.323 .779 .95 r
.14624 .3976 .15427 .39956 .16449 .39768 .1564 .39646 Mtetra
.286 .771 .913 r
.1564 .39646 .16449 .39768 .17478 .39561 .16665 .39516 Mtetra
.243 .754 .864 r
.16665 .39516 .17478 .39561 .18514 .39343 .17696 .39368 Mtetra
.201 .729 .807 r
.17696 .39368 .18514 .39343 .19555 .39116 .18735 .39206 Mtetra
.168 .706 .755 r
.18735 .39206 .19555 .39116 .20603 .38882 .19782 .39023 Mtetra
.15 .689 .713 r
.19782 .39023 .20603 .38882 .21656 .38643 .20836 .3882 Mtetra
.153 .689 .694 r
.20836 .3882 .21656 .38643 .22715 .38392 .21898 .38588 Mtetra
.176 .704 .694 r
.21898 .38588 .22715 .38392 .23781 .38124 .22969 .38322 Mtetra
.215 .733 .712 r
.22969 .38322 .23781 .38124 .24854 .37827 .24048 .38021 Mtetra
.26 .764 .735 r
.24048 .38021 .24854 .37827 .25936 .37491 .25135 .37683 Mtetra
.288 .783 .748 r
.25135 .37683 .25936 .37491 .27026 .37116 .26229 .3732 Mtetra
.292 .784 .741 r
.26229 .3732 .27026 .37116 .28122 .36702 .27329 .36942 Mtetra
.256 .756 .703 r
.27329 .36942 .28122 .36702 .29225 .36267 .28433 .36565 Mtetra
0 0 0 r
.28433 .36565 .29225 .36267 .30333 .35821 .29541 .362 Mtetra
.29541 .362 .30333 .35821 .31445 .35375 .30653 .3585 Mtetra
.30653 .3585 .31445 .35375 .3256 .34939 .31768 .35513 Mtetra
.048 0 0 r
.31768 .35513 .3256 .34939 .33679 .34513 .32889 .35179 Mtetra
.095 0 0 r
.32889 .35179 .33679 .34513 .34802 .34098 .34015 .3484 Mtetra
.12 0 0 r
.34015 .3484 .34802 .34098 .35929 .33689 .35147 .34485 Mtetra
.129 0 0 r
.35147 .34485 .35929 .33689 .3706 .33286 .36285 .34109 Mtetra
.124 0 0 r
.36285 .34109 .3706 .33286 .38196 .32885 .3743 .33707 Mtetra
.107 0 0 r
.3743 .33707 .38196 .32885 .39337 .32488 .3858 .33278 Mtetra
.08 0 0 r
.3858 .33278 .39337 .32488 .40482 .32095 .39736 .32828 Mtetra
.043 0 0 r
.39736 .32828 .40482 .32095 .41632 .3171 .40897 .32362 Mtetra
0 0 0 r
.40897 .32362 .41632 .3171 .42786 .31335 .42063 .3189 Mtetra
.42063 .3189 .42786 .31335 .43946 .3097 .43234 .31421 Mtetra
.43234 .31421 .43946 .3097 .4511 .30614 .44408 .30965 Mtetra
.44408 .30965 .4511 .30614 .4628 .3026 .45587 .30524 Mtetra
.45587 .30524 .4628 .3026 .47456 .29895 .46771 .30094 Mtetra
.28 .772 .713 r
.46771 .30094 .47456 .29895 .48637 .29507 .4796 .29667 Mtetra
.325 .806 .754 r
.4796 .29667 .48637 .29507 .49824 .29081 .49154 .29223 Mtetra
.36 .828 .775 r
.49154 .29223 .49824 .29081 .51017 .28614 .50353 .28754 Mtetra
.393 .848 .784 r
.50353 .28754 .51017 .28614 .52214 .28107 .51557 .28246 Mtetra
.423 .864 .791 r
.51557 .28246 .52214 .28107 .53415 .2757 .52766 .27701 Mtetra
.454 .881 .801 r
.52766 .27701 .53415 .2757 .54621 .27015 .53979 .27121 Mtetra
.492 .903 .821 r
.53979 .27121 .54621 .27015 .55831 .26446 .55196 .26512 Mtetra
.536 .925 .849 r
.55196 .26512 .55831 .26446 .57045 .25872 .56417 .25879 Mtetra
.585 .945 .883 r
.56417 .25879 .57045 .25872 .58264 .25289 .57641 .25226 Mtetra
.632 .959 .914 r
.57641 .25226 .58264 .25289 .59486 .24698 .58869 .24555 Mtetra
.675 .962 .937 r
.58869 .24555 .59486 .24698 .60712 .24092 .601 .23866 Mtetra
.709 .955 .95 r
.601 .23866 .60712 .24092 .61942 .23468 .61334 .23159 Mtetra
.733 .941 .952 r
.61334 .23159 .61942 .23468 .63175 .22823 .6257 .22433 Mtetra
.75 .921 .948 r
.6257 .22433 .63175 .22823 .64411 .22154 .63809 .21688 Mtetra
.76 .901 .939 r
.63809 .21688 .64411 .22154 .65649 .21462 .65051 .20926 Mtetra
.765 .88 .929 r
.65051 .20926 .65649 .21462 .6689 .20747 .66295 .20147 Mtetra
.768 .861 .919 r
.66295 .20147 .6689 .20747 .68134 .20014 .67541 .19356 Mtetra
.768 .844 .909 r
.67541 .19356 .68134 .20014 .6938 .19265 .6879 .18554 Mtetra
.767 .829 .9 r
.6879 .18554 .6938 .19265 .70629 .18505 .70041 .17745 Mtetra
.764 .815 .893 r
.70041 .17745 .70629 .18505 .7188 .17738 .71294 .16932 Mtetra
.761 .802 .886 r
.71294 .16932 .7188 .17738 .73134 .16968 .7255 .16118 Mtetra
.469 .688 .962 r
.05043 .39529 .05808 .40196 .06761 .40172 .06 .39486 Mtetra
.471 .683 .959 r
.06 .39486 .06761 .40172 .0772 .40149 .06962 .39446 Mtetra
.474 .68 .955 r
.06962 .39446 .0772 .40149 .08685 .40123 .07929 .39406 Mtetra
.478 .677 .952 r
.07929 .39406 .08685 .40123 .09656 .40092 .08903 .39363 Mtetra
.482 .676 .95 r
.08903 .39363 .09656 .40092 .10635 .40053 .09883 .39318 Mtetra
.486 .676 .949 r
.09883 .39318 .10635 .40053 .1162 .40002 .1087 .39267 Mtetra
.491 .679 .949 r
.1087 .39267 .1162 .40002 .12614 .39938 .11864 .39207 Mtetra
.497 .684 .95 r
.11864 .39207 .12614 .39938 .13615 .39858 .12865 .39138 Mtetra
.503 .691 .952 r
.12865 .39138 .13615 .39858 .14624 .3976 .13873 .39056 Mtetra
.509 .699 .955 r
.13873 .39056 .14624 .3976 .1564 .39646 .14889 .38959 Mtetra
.516 .709 .958 r
.14889 .38959 .1564 .39646 .16665 .39516 .15913 .38846 Mtetra
.526 .719 .961 r
.15913 .38846 .16665 .39516 .17696 .39368 .16945 .38713 Mtetra
.537 .73 .963 r
.16945 .38713 .17696 .39368 .18735 .39206 .17985 .38558 Mtetra
.553 .739 .963 r
.17985 .38558 .18735 .39206 .19782 .39023 .19033 .38374 Mtetra
.571 .746 .959 r
.19033 .38374 .19782 .39023 .20836 .3882 .20091 .38157 Mtetra
.59 .749 .953 r
.20091 .38157 .20836 .3882 .21898 .38588 .21157 .37907 Mtetra
.608 .75 .945 r
.21157 .37907 .21898 .38588 .22969 .38322 .22232 .37621 Mtetra
.621 .748 .937 r
.22232 .37621 .22969 .38322 .24048 .38021 .23314 .37308 Mtetra
.629 .748 .933 r
.23314 .37308 .24048 .38021 .25135 .37683 .24403 .36976 Mtetra
.63 .751 .935 r
.24403 .36976 .25135 .37683 .26229 .3732 .25497 .36641 Mtetra
.623 .759 .943 r
.25497 .36641 .26229 .3732 .27329 .36942 .26595 .36317 Mtetra
.61 .773 .959 r
.26595 .36317 .27329 .36942 .28433 .36565 .27696 .36012 Mtetra
.588 .792 .977 r
.27696 .36012 .28433 .36565 .29541 .362 .28801 .35732 Mtetra
.562 .813 .992 r
.28801 .35732 .29541 .362 .30653 .3585 .2991 .35467 Mtetra
.533 .832 .999 r
.2991 .35467 .30653 .3585 .31768 .35513 .31024 .35209 Mtetra
.51 .848 .996 r
.31024 .35209 .31768 .35513 .32889 .35179 .32144 .34941 Mtetra
.495 .862 .986 r
.32144 .34941 .32889 .35179 .34015 .3484 .33272 .34653 Mtetra
.496 .875 .975 r
.33272 .34653 .34015 .3484 .35147 .34485 .34406 .34331 Mtetra
.51 .888 .967 r
.34406 .34331 .35147 .34485 .36285 .34109 .35549 .3397 Mtetra
.536 .903 .964 r
.35549 .3397 .36285 .34109 .3743 .33707 .36698 .33565 Mtetra
.57 .916 .965 r
.36698 .33565 .3743 .33707 .3858 .33278 .37855 .33116 Mtetra
.605 .925 .969 r
.37855 .33116 .3858 .33278 .39736 .32828 .39018 .32627 Mtetra
.639 .928 .973 r
.39018 .32627 .39736 .32828 .40897 .32362 .40186 .32105 Mtetra
.665 .921 .975 r
.40186 .32105 .40897 .32362 .42063 .3189 .4136 .3156 Mtetra
.684 .906 .974 r
.4136 .3156 .42063 .3189 .43234 .31421 .42538 .31006 Mtetra
.691 .881 .969 r
.42538 .31006 .43234 .31421 .44408 .30965 .43719 .30459 Mtetra
.691 .852 .96 r
.43719 .30459 .44408 .30965 .45587 .30524 .44905 .29926 Mtetra
.684 .821 .949 r
.44905 .29926 .45587 .30524 .46771 .30094 .46094 .29417 Mtetra
.677 .794 .937 r
.46094 .29417 .46771 .30094 .4796 .29667 .47287 .28927 Mtetra
.672 .774 .927 r
.47287 .28927 .4796 .29667 .49154 .29223 .48485 .28448 Mtetra
.672 .765 .92 r
.48485 .28448 .49154 .29223 .50353 .28754 .49688 .27967 Mtetra
.678 .764 .916 r
.49688 .27967 .50353 .28754 .51557 .28246 .50896 .27465 Mtetra
.687 .77 .914 r
.50896 .27465 .51557 .28246 .52766 .27701 .52109 .26934 Mtetra
.699 .779 .914 r
.52109 .26934 .52766 .27701 .53979 .27121 .53326 .26367 Mtetra
.71 .787 .912 r
.53326 .26367 .53979 .27121 .55196 .26512 .54547 .25764 Mtetra
.72 .793 .91 r
.54547 .25764 .55196 .26512 .56417 .25879 .55772 .25127 Mtetra
.728 .796 .906 r
.55772 .25127 .56417 .25879 .57641 .25226 .57 .2446 Mtetra
.734 .794 .901 r
.57 .2446 .57641 .25226 .58869 .24555 .58232 .23768 Mtetra
.738 .791 .895 r
.58232 .23768 .58869 .24555 .601 .23866 .59467 .23054 Mtetra
.741 .786 .889 r
.59467 .23054 .601 .23866 .61334 .23159 .60704 .22322 Mtetra
.743 .78 .883 r
.60704 .22322 .61334 .23159 .6257 .22433 .61944 .21574 Mtetra
.745 .776 .878 r
.61944 .21574 .6257 .22433 .63809 .21688 .63187 .20812 Mtetra
.746 .773 .875 r
.63187 .20812 .63809 .21688 .65051 .20926 .64433 .20038 Mtetra
.748 .771 .872 r
.64433 .20038 .65051 .20926 .66295 .20147 .65681 .19253 Mtetra
.749 .771 .871 r
.65681 .19253 .66295 .20147 .67541 .19356 .66931 .18461 Mtetra
.75 .773 .872 r
.66931 .18461 .67541 .19356 .6879 .18554 .68185 .17664 Mtetra
.751 .775 .873 r
.68185 .17664 .6879 .18554 .70041 .17745 .69441 .16864 Mtetra
.752 .779 .875 r
.69441 .16864 .70041 .17745 .71294 .16932 .707 .16062 Mtetra
.753 .784 .878 r
.707 .16062 .71294 .16932 .7255 .16118 .71961 .15261 Mtetra
.526 .711 .956 r
.04273 .38856 .05043 .39529 .06 .39486 .05242 .38734 Mtetra
.535 .688 .938 r
.05242 .38734 .06 .39486 .06962 .39446 .06216 .38613 Mtetra
.541 .667 .919 r
.06216 .38613 .06962 .39446 .07929 .39406 .07195 .38493 Mtetra
.546 .647 .9 r
.07195 .38493 .07929 .39406 .08903 .39363 .0818 .38373 Mtetra
.549 .628 .883 r
.0818 .38373 .08903 .39363 .09883 .39318 .09171 .38251 Mtetra
.553 .612 .866 r
.09171 .38251 .09883 .39318 .1087 .39267 .10167 .38126 Mtetra
.556 .598 .851 r
.10167 .38126 .1087 .39267 .11864 .39207 .1117 .37995 Mtetra
.56 .586 .837 r
.1117 .37995 .11864 .39207 .12865 .39138 .12179 .37856 Mtetra
.563 .575 .824 r
.12179 .37856 .12865 .39138 .13873 .39056 .13195 .37708 Mtetra
.566 .566 .812 r
.13195 .37708 .13873 .39056 .14889 .38959 .14218 .37548 Mtetra
.57 .558 .802 r
.14218 .37548 .14889 .38959 .15913 .38846 .15248 .37376 Mtetra
.573 .551 .792 r
.15248 .37376 .15913 .38846 .16945 .38713 .16285 .37189 Mtetra
.576 .546 .784 r
.16285 .37189 .16945 .38713 .17985 .38558 .17329 .36988 Mtetra
.579 .542 .778 r
.17329 .36988 .17985 .38558 .19033 .38374 .1838 .36772 Mtetra
.582 .54 .773 r
.1838 .36772 .19033 .38374 .20091 .38157 .19438 .36541 Mtetra
.585 .54 .772 r
.19438 .36541 .20091 .38157 .21157 .37907 .20502 .36298 Mtetra
.587 .543 .773 r
.20502 .36298 .21157 .37907 .22232 .37621 .21573 .36047 Mtetra
.588 .549 .778 r
.21573 .36047 .22232 .37621 .23314 .37308 .22649 .35792 Mtetra
.589 .558 .787 r
.22649 .35792 .23314 .37308 .24403 .36976 .2373 .3554 Mtetra
.589 .57 .8 r
.2373 .3554 .24403 .36976 .25497 .36641 .24816 .35293 Mtetra
.589 .584 .815 r
.24816 .35293 .25497 .36641 .26595 .36317 .25908 .35051 Mtetra
.591 .601 .83 r
.25908 .35051 .26595 .36317 .27696 .36012 .27005 .34806 Mtetra
.595 .614 .841 r
.27005 .34806 .27696 .36012 .28801 .35732 .28108 .34553 Mtetra
.601 .623 .846 r
.28108 .34553 .28801 .35732 .2991 .35467 .29218 .34281 Mtetra
.608 .626 .843 r
.29218 .34281 .2991 .35467 .31024 .35209 .30336 .33985 Mtetra
.614 .622 .835 r
.30336 .33985 .31024 .35209 .32144 .34941 .3146 .33666 Mtetra
.619 .615 .825 r
.3146 .33666 .32144 .34941 .33272 .34653 .32592 .33321 Mtetra
.623 .608 .815 r
.32592 .33321 .33272 .34653 .34406 .34331 .3373 .32953 Mtetra
.626 .603 .807 r
.3373 .32953 .34406 .34331 .35549 .3397 .34874 .32565 Mtetra
.63 .601 .802 r
.34874 .32565 .35549 .3397 .36698 .33565 .36025 .32156 Mtetra
.634 .603 .801 r
.36025 .32156 .36698 .33565 .37855 .33116 .37181 .31727 Mtetra
.64 .61 .804 r
.37181 .31727 .37855 .33116 .39018 .32627 .38343 .31276 Mtetra
.647 .62 .809 r
.38343 .31276 .39018 .32627 .40186 .32105 .3951 .30803 Mtetra
.655 .632 .815 r
.3951 .30803 .40186 .32105 .4136 .3156 .40683 .30304 Mtetra
.664 .645 .821 r
.40683 .30304 .4136 .3156 .42538 .31006 .41862 .2978 Mtetra
.671 .654 .825 r
.41862 .2978 .42538 .31006 .43719 .30459 .43045 .29232 Mtetra
.675 .656 .824 r
.43045 .29232 .43719 .30459 .44905 .29926 .44234 .28665 Mtetra
.675 .651 .818 r
.44234 .28665 .44905 .29926 .46094 .29417 .45426 .28088 Mtetra
.671 .638 .808 r
.45426 .28088 .46094 .29417 .47287 .28927 .46622 .27507 Mtetra
.664 .621 .796 r
.46622 .27507 .47287 .28927 .48485 .28448 .47823 .26932 Mtetra
.658 .605 .784 r
.47823 .26932 .48485 .28448 .49688 .27967 .49027 .26361 Mtetra
.652 .591 .773 r
.49027 .26361 .49688 .27967 .50896 .27465 .50236 .25791 Mtetra
.649 .581 .765 r
.50236 .25791 .50896 .27465 .52109 .26934 .51449 .25217 Mtetra
.648 .577 .76 r
.51449 .25217 .52109 .26934 .53326 .26367 .52666 .24634 Mtetra
.65 .576 .758 r
.52666 .24634 .53326 .26367 .54547 .25764 .53888 .24038 Mtetra
.653 .579 .759 r
.53888 .24038 .54547 .25764 .55772 .25127 .55113 .23426 Mtetra
.657 .584 .762 r
.55113 .23426 .55772 .25127 .57 .2446 .56343 .22798 Mtetra
.662 .592 .766 r
.56343 .22798 .57 .2446 .58232 .23768 .57576 .22153 Mtetra
.668 .601 .771 r
.57576 .22153 .58232 .23768 .59467 .23054 .58813 .21494 Mtetra
.674 .611 .778 r
.58813 .21494 .59467 .23054 .60704 .22322 .60053 .20819 Mtetra
.68 .623 .785 r
.60053 .20819 .60704 .22322 .61944 .21574 .61297 .20132 Mtetra
.686 .635 .793 r
.61297 .20132 .61944 .21574 .63187 .20812 .62544 .19434 Mtetra
.692 .648 .802 r
.62544 .19434 .63187 .20812 .64433 .20038 .63794 .18727 Mtetra
.698 .663 .811 r
.63794 .18727 .64433 .20038 .65681 .19253 .65048 .18012 Mtetra
.704 .679 .822 r
.65048 .18012 .65681 .19253 .66931 .18461 .66305 .17292 Mtetra
.711 .696 .834 r
.66305 .17292 .66931 .18461 .68185 .17664 .67565 .1657 Mtetra
.717 .715 .848 r
.67565 .1657 .68185 .17664 .69441 .16864 .68829 .15846 Mtetra
.722 .736 .862 r
.68829 .15846 .69441 .16864 .707 .16062 .70096 .15121 Mtetra
.728 .758 .876 r
.70096 .15121 .707 .16062 .71961 .15261 .71368 .14397 Mtetra
.597 .735 .941 r
.03496 .38178 .04273 .38856 .05242 .38734 .04484 .37937 Mtetra
.599 .7 .914 r
.04484 .37937 .05242 .38734 .06216 .38613 .05477 .37696 Mtetra
.6 .668 .887 r
.05477 .37696 .06216 .38613 .07195 .38493 .06474 .37457 Mtetra
.598 .639 .862 r
.06474 .37457 .07195 .38493 .0818 .38373 .07476 .37218 Mtetra
.596 .613 .839 r
.07476 .37218 .0818 .38373 .09171 .38251 .08482 .36979 Mtetra
.594 .591 .818 r
.08482 .36979 .09171 .38251 .10167 .38126 .09494 .36738 Mtetra
.592 .571 .799 r
.09494 .36738 .10167 .38126 .1117 .37995 .10511 .36492 Mtetra
.59 .554 .782 r
.10511 .36492 .1117 .37995 .12179 .37856 .11533 .36241 Mtetra
.589 .54 .767 r
.11533 .36241 .12179 .37856 .13195 .37708 .12562 .35983 Mtetra
.588 .527 .754 r
.12562 .35983 .13195 .37708 .14218 .37548 .13596 .35718 Mtetra
.586 .516 .742 r
.13596 .35718 .14218 .37548 .15248 .37376 .14635 .35445 Mtetra
.585 .506 .732 r
.14635 .35445 .15248 .37376 .16285 .37189 .15681 .35166 Mtetra
.583 .497 .723 r
.15681 .35166 .16285 .37189 .17329 .36988 .16731 .34885 Mtetra
.58 .489 .716 r
.16731 .34885 .17329 .36988 .1838 .36772 .17786 .34605 Mtetra
.577 .483 .711 r
.17786 .34605 .1838 .36772 .19438 .36541 .18846 .34333 Mtetra
.573 .478 .709 r
.18846 .34333 .19438 .36541 .20502 .36298 .19909 .34075 Mtetra
.569 .475 .708 r
.19909 .34075 .20502 .36298 .21573 .36047 .20975 .33836 Mtetra
.565 .474 .71 r
.20975 .33836 .21573 .36047 .22649 .35792 .22045 .33617 Mtetra
.562 .475 .714 r
.22045 .33617 .22649 .35792 .2373 .3554 .23119 .33416 Mtetra
.561 .479 .719 r
.23119 .33416 .2373 .3554 .24816 .35293 .24198 .33221 Mtetra
.563 .485 .724 r
.24198 .33221 .24816 .35293 .25908 .35051 .25283 .33019 Mtetra
.57 .493 .728 r
.25283 .33019 .25908 .35051 .27005 .34806 .26377 .32789 Mtetra
.58 .5 .729 r
.26377 .32789 .27005 .34806 .28108 .34553 .2748 .32515 Mtetra
.589 .504 .727 r
.2748 .32515 .28108 .34553 .29218 .34281 .28591 .32193 Mtetra
.596 .505 .721 r
.28591 .32193 .29218 .34281 .30336 .33985 .29712 .31822 Mtetra
.6 .502 .714 r
.29712 .31822 .30336 .33985 .3146 .33666 .3084 .31419 Mtetra
.601 .497 .708 r
.3084 .31419 .3146 .33666 .32592 .33321 .31974 .30995 Mtetra
.599 .491 .702 r
.31974 .30995 .32592 .33321 .3373 .32953 .33113 .30567 Mtetra
.596 .485 .698 r
.33113 .30567 .3373 .32953 .34874 .32565 .34256 .30143 Mtetra
.593 .482 .696 r
.34256 .30143 .34874 .32565 .36025 .32156 .35404 .29729 Mtetra
.591 .48 .696 r
.35404 .29729 .36025 .32156 .37181 .31727 .36555 .29326 Mtetra
.591 .482 .698 r
.36555 .29326 .37181 .31727 .38343 .31276 .37712 .28928 Mtetra
.593 .487 .702 r
.37712 .28928 .38343 .31276 .3951 .30803 .38874 .28525 Mtetra
.599 .495 .708 r
.38874 .28525 .3951 .30803 .40683 .30304 .40042 .28101 Mtetra
.606 .506 .714 r
.40042 .28101 .40683 .30304 .41862 .2978 .41216 .27643 Mtetra
.617 .517 .718 r
.41216 .27643 .41862 .2978 .43045 .29232 .42396 .27137 Mtetra
.627 .527 .721 r
.42396 .27137 .43045 .29232 .44234 .28665 .43582 .26582 Mtetra
.634 .532 .721 r
.43582 .26582 .44234 .28665 .45426 .28088 .44774 .25982 Mtetra
.638 .533 .719 r
.44774 .25982 .45426 .28088 .46622 .27507 .4597 .25352 Mtetra
.637 .529 .715 r
.4597 .25352 .46622 .27507 .47823 .26932 .4717 .24714 Mtetra
.633 .522 .71 r
.4717 .24714 .47823 .26932 .49027 .26361 .48374 .24082 Mtetra
.628 .515 .706 r
.48374 .24082 .49027 .26361 .50236 .25791 .49581 .23467 Mtetra
.623 .509 .704 r
.49581 .23467 .50236 .25791 .51449 .25217 .50792 .22872 Mtetra
.619 .506 .703 r
.50792 .22872 .51449 .25217 .52666 .24634 .52007 .22296 Mtetra
.617 .505 .704 r
.52007 .22296 .52666 .24634 .53888 .24038 .53226 .21733 Mtetra
.617 .508 .707 r
.53226 .21733 .53888 .24038 .55113 .23426 .5445 .21176 Mtetra
.619 .513 .712 r
.5445 .21176 .55113 .23426 .56343 .22798 .55678 .20622 Mtetra
.622 .52 .718 r
.55678 .20622 .56343 .22798 .57576 .22153 .56911 .20063 Mtetra
.626 .53 .726 r
.56911 .20063 .57576 .22153 .58813 .21494 .58149 .19499 Mtetra
.632 .542 .735 r
.58149 .19499 .58813 .21494 .60053 .20819 .59391 .18925 Mtetra
.637 .555 .745 r
.59391 .18925 .60053 .20819 .61297 .20132 .60637 .18344 Mtetra
.644 .57 .756 r
.60637 .18344 .61297 .20132 .62544 .19434 .61888 .17754 Mtetra
.651 .586 .769 r
.61888 .17754 .62544 .19434 .63794 .18727 .63143 .17158 Mtetra
.658 .605 .784 r
.63143 .17158 .63794 .18727 .65048 .18012 .64403 .16556 Mtetra
.665 .625 .8 r
.64403 .16556 .65048 .18012 .66305 .17292 .65667 .15951 Mtetra
.672 .648 .817 r
.65667 .15951 .66305 .17292 .67565 .1657 .66935 .15345 Mtetra
.679 .673 .837 r
.66935 .15345 .67565 .1657 .68829 .15846 .68208 .14738 Mtetra
.686 .702 .859 r
.68208 .14738 .68829 .15846 .70096 .15121 .69486 .14131 Mtetra
.693 .734 .882 r
.69486 .14131 .70096 .15121 .71368 .14397 .70769 .13525 Mtetra
.66 .752 .918 r
.02714 .37496 .03496 .38178 .04484 .37937 .03725 .37113 Mtetra
.655 .711 .889 r
.03725 .37113 .04484 .37937 .05477 .37696 .0474 .36731 Mtetra
.649 .675 .861 r
.0474 .36731 .05477 .37696 .06474 .37457 .05758 .36352 Mtetra
.642 .643 .836 r
.05758 .36352 .06474 .37457 .07476 .37218 .0678 .35974 Mtetra
.635 .614 .812 r
.0678 .35974 .07476 .37218 .08482 .36979 .07806 .35597 Mtetra
.628 .59 .792 r
.07806 .35597 .08482 .36979 .09494 .36738 .08835 .3522 Mtetra
.622 .569 .773 r
.08835 .3522 .09494 .36738 .10511 .36492 .09869 .34841 Mtetra
.617 .55 .757 r
.09869 .34841 .10511 .36492 .11533 .36241 .10908 .34461 Mtetra
.612 .534 .743 r
.10908 .34461 .11533 .36241 .12562 .35983 .1195 .34077 Mtetra
.607 .52 .73 r
.1195 .34077 .12562 .35983 .13596 .35718 .12997 .33691 Mtetra
.603 .508 .719 r
.12997 .33691 .13596 .35718 .14635 .35445 .14049 .33303 Mtetra
.599 .497 .71 r
.14049 .33303 .14635 .35445 .15681 .35166 .15104 .32917 Mtetra
.595 .487 .702 r
.15104 .32917 .15681 .35166 .16731 .34885 .16163 .32535 Mtetra
.589 .478 .695 r
.16163 .32535 .16731 .34885 .17786 .34605 .17225 .32166 Mtetra
.584 .469 .689 r
.17225 .32166 .17786 .34605 .18846 .34333 .18289 .31815 Mtetra
.578 .461 .684 r
.18289 .31815 .18846 .34333 .19909 .34075 .19356 .31488 Mtetra
.571 .453 .68 r
.19356 .31488 .19909 .34075 .20975 .33836 .20424 .3119 Mtetra
.566 .447 .677 r
.20424 .3119 .20975 .33836 .22045 .33617 .21494 .30918 Mtetra
.561 .441 .674 r
.21494 .30918 .22045 .33617 .23119 .33416 .22568 .30668 Mtetra
.559 .438 .671 r
.22568 .30668 .23119 .33416 .24198 .33221 .23647 .30422 Mtetra
.56 .437 .669 r
.23647 .30422 .24198 .33221 .25283 .33019 .24732 .30164 Mtetra
.564 .437 .666 r
.24732 .30164 .25283 .33019 .26377 .32789 .25826 .29873 Mtetra
.571 .439 .663 r
.25826 .29873 .26377 .32789 .2748 .32515 .26929 .29533 Mtetra
.576 .44 .659 r
.26929 .29533 .2748 .32515 .28591 .32193 .2804 .29145 Mtetra
.581 .441 .656 r
.2804 .29145 .28591 .32193 .29712 .31822 .2916 .28711 Mtetra
.583 .44 .653 r
.2916 .28711 .29712 .31822 .3084 .31419 .30287 .28251 Mtetra
.583 .439 .651 r
.30287 .28251 .3084 .31419 .31974 .30995 .31418 .27781 Mtetra
.581 .436 .649 r
.31418 .27781 .31974 .30995 .33113 .30567 .32553 .27319 Mtetra
.578 .433 .648 r
.32553 .27319 .33113 .30567 .34256 .30143 .33692 .26875 Mtetra
.574 .429 .647 r
.33692 .26875 .34256 .30143 .35404 .29729 .34833 .26456 Mtetra
.57 .427 .647 r
.34833 .26456 .35404 .29729 .36555 .29326 .35978 .26062 Mtetra
.568 .426 .648 r
.35978 .26062 .36555 .29326 .37712 .28928 .37127 .25687 Mtetra
.567 .427 .649 r
.37127 .25687 .37712 .28928 .38874 .28525 .38281 .2532 Mtetra
.569 .429 .651 r
.38281 .2532 .38874 .28525 .40042 .28101 .39441 .24942 Mtetra
.573 .434 .653 r
.39441 .24942 .40042 .28101 .41216 .27643 .40607 .24539 Mtetra
.58 .441 .656 r
.40607 .24539 .41216 .27643 .42396 .27137 .4178 .24089 Mtetra
.588 .448 .659 r
.4178 .24089 .42396 .27137 .43582 .26582 .4296 .2359 Mtetra
.595 .456 .661 r
.4296 .2359 .43582 .26582 .44774 .25982 .44145 .23041 Mtetra
.601 .462 .664 r
.44145 .23041 .44774 .25982 .4597 .25352 .45336 .22458 Mtetra
.604 .466 .666 r
.45336 .22458 .4597 .25352 .4717 .24714 .46531 .21863 Mtetra
.604 .468 .669 r
.46531 .21863 .4717 .24714 .48374 .24082 .47729 .2127 Mtetra
.603 .469 .671 r
.47729 .2127 .48374 .24082 .49581 .23467 .48932 .207 Mtetra
.6 .47 .675 r
.48932 .207 .49581 .23467 .50792 .22872 .50138 .20155 Mtetra
.597 .47 .678 r
.50138 .20155 .50792 .22872 .52007 .22296 .51349 .1964 Mtetra
.595 .473 .683 r
.51349 .1964 .52007 .22296 .53226 .21733 .52565 .19148 Mtetra
.595 .476 .688 r
.52565 .19148 .53226 .21733 .5445 .21176 .53786 .18675 Mtetra
.595 .481 .694 r
.53786 .18675 .5445 .21176 .55678 .20622 .55012 .18213 Mtetra
.597 .489 .701 r
.55012 .18213 .55678 .20622 .56911 .20063 .56244 .17757 Mtetra
.599 .497 .71 r
.56244 .17757 .56911 .20063 .58149 .19499 .57481 .17302 Mtetra
.603 .508 .719 r
.57481 .17302 .58149 .19499 .59391 .18925 .58724 .16844 Mtetra
.607 .52 .73 r
.58724 .16844 .59391 .18925 .60637 .18344 .59972 .16384 Mtetra
.612 .535 .743 r
.59972 .16384 .60637 .18344 .61888 .17754 .61226 .1592 Mtetra
.617 .551 .757 r
.61226 .1592 .61888 .17754 .63143 .17158 .62485 .15453 Mtetra
.623 .569 .773 r
.62485 .15453 .63143 .17158 .64403 .16556 .63751 .14985 Mtetra
.629 .59 .792 r
.63751 .14985 .64403 .16556 .65667 .15951 .65022 .14515 Mtetra
.634 .614 .812 r
.65022 .14515 .65667 .15951 .66935 .15345 .66298 .14046 Mtetra
.64 .642 .836 r
.66298 .14046 .66935 .15345 .68208 .14738 .67581 .13579 Mtetra
.645 .673 .862 r
.67581 .13579 .68208 .14738 .69486 .14131 .6887 .13112 Mtetra
.649 .709 .891 r
.6887 .13112 .69486 .14131 .70769 .13525 .70165 .12647 Mtetra
.71 .762 .893 r
.01926 .36808 .02714 .37496 .03725 .37113 .02962 .36278 Mtetra
.699 .722 .867 r
.02962 .36278 .03725 .37113 .0474 .36731 .04 .35752 Mtetra
.688 .686 .842 r
.04 .35752 .0474 .36731 .05758 .36352 .05041 .3523 Mtetra
.678 .654 .819 r
.05041 .3523 .05758 .36352 .0678 .35974 .06084 .34711 Mtetra
.667 .626 .799 r
.06084 .34711 .0678 .35974 .07806 .35597 .07129 .34196 Mtetra
.658 .602 .781 r
.07129 .34196 .07806 .35597 .08835 .3522 .08178 .33685 Mtetra
.649 .581 .765 r
.08178 .33685 .08835 .3522 .09869 .34841 .09228 .33177 Mtetra
.641 .562 .75 r
.09228 .33177 .09869 .34841 .10908 .34461 .10282 .32673 Mtetra
.634 .547 .738 r
.10282 .32673 .10908 .34461 .1195 .34077 .11339 .32173 Mtetra
.628 .533 .727 r
.11339 .32173 .1195 .34077 .12997 .33691 .12398 .31676 Mtetra
.623 .521 .718 r
.12398 .31676 .12997 .33691 .14049 .33303 .13461 .31183 Mtetra
.617 .51 .709 r
.13461 .31183 .14049 .33303 .15104 .32917 .14526 .30693 Mtetra
.613 .5 .701 r
.14526 .30693 .15104 .32917 .16163 .32535 .15595 .30208 Mtetra
.608 .491 .694 r
.15595 .30208 .16163 .32535 .17225 .32166 .16666 .29725 Mtetra
.604 .482 .686 r
.16666 .29725 .17225 .32166 .18289 .31815 .17741 .29247 Mtetra
.599 .472 .679 r
.17741 .29247 .18289 .31815 .19356 .31488 .1882 .28772 Mtetra
.594 .462 .67 r
.1882 .28772 .19356 .31488 .20424 .3119 .19902 .28301 Mtetra
.589 .451 .661 r
.19902 .28301 .20424 .3119 .21494 .30918 .20987 .27833 Mtetra
.584 .44 .651 r
.20987 .27833 .21494 .30918 .22568 .30668 .22076 .27369 Mtetra
.579 .429 .642 r
.22076 .27369 .22568 .30668 .23647 .30422 .23168 .26908 Mtetra
.574 .419 .634 r
.23168 .26908 .23647 .30422 .24732 .30164 .24264 .26452 Mtetra
.57 .411 .627 r
.24264 .26452 .24732 .30164 .25826 .29873 .25364 .25998 Mtetra
.567 .405 .622 r
.25364 .25998 .25826 .29873 .26929 .29533 .26468 .25549 Mtetra
.565 .401 .618 r
.26468 .25549 .26929 .29533 .2804 .29145 .27575 .25102 Mtetra
.564 .399 .617 r
.27575 .25102 .2804 .29145 .2916 .28711 .28687 .2466 Mtetra
.563 .399 .616 r
.28687 .2466 .2916 .28711 .30287 .28251 .29803 .24221 Mtetra
.563 .399 .617 r
.29803 .24221 .30287 .28251 .31418 .27781 .30923 .23786 Mtetra
.563 .4 .618 r
.30923 .23786 .31418 .27781 .32553 .27319 .32048 .23354 Mtetra
.563 .401 .62 r
.32048 .23354 .32553 .27319 .33692 .26875 .33176 .22926 Mtetra
.562 .401 .62 r
.33176 .22926 .33692 .26875 .34833 .26456 .34309 .22501 Mtetra
.34309 .22501 .34833 .26456 .35978 .26062 .35447 .2208 Mtetra
.561 .399 .62 r
.35447 .2208 .35978 .26062 .37127 .25687 .3659 .21663 Mtetra
.56 .398 .618 r
.3659 .21663 .37127 .25687 .38281 .2532 .37737 .21249 Mtetra
.559 .396 .617 r
.37737 .21249 .38281 .2532 .39441 .24942 .38889 .20838 Mtetra
.558 .395 .616 r
.38889 .20838 .39441 .24942 .40607 .24539 .40045 .20432 Mtetra
.557 .395 .616 r
.40045 .20432 .40607 .24539 .4178 .24089 .41207 .20029 Mtetra
.557 .396 .618 r
.41207 .20029 .4178 .24089 .4296 .2359 .42374 .19629 Mtetra
.558 .399 .621 r
.42374 .19629 .4296 .2359 .44145 .23041 .43546 .19233 Mtetra
.56 .404 .627 r
.43546 .19233 .44145 .23041 .45336 .22458 .44724 .18841 Mtetra
.562 .411 .634 r
.44724 .18841 .45336 .22458 .46531 .21863 .45907 .18452 Mtetra
.564 .419 .642 r
.45907 .18452 .46531 .21863 .47729 .2127 .47095 .18067 Mtetra
.567 .429 .652 r
.47095 .18067 .47729 .2127 .48932 .207 .48289 .17686 Mtetra
.57 .438 .662 r
.48289 .17686 .48932 .207 .50138 .20155 .49489 .17308 Mtetra
.573 .448 .671 r
.49489 .17308 .50138 .20155 .51349 .1964 .50695 .16934 Mtetra
.575 .456 .68 r
.50695 .16934 .51349 .1964 .52565 .19148 .51906 .16563 Mtetra
.577 .465 .689 r
.51906 .16563 .52565 .19148 .53786 .18675 .53124 .16196 Mtetra
.579 .472 .697 r
.53124 .16196 .53786 .18675 .55012 .18213 .54347 .15833 Mtetra
.581 .48 .705 r
.54347 .15833 .55012 .18213 .56244 .17757 .55577 .15473 Mtetra
.582 .488 .713 r
.55577 .15473 .56244 .17757 .57481 .17302 .56814 .15117 Mtetra
.584 .497 .723 r
.56814 .15117 .57481 .17302 .58724 .16844 .58057 .14765 Mtetra
.586 .508 .733 r
.58057 .14765 .58724 .16844 .59972 .16384 .59306 .14416 Mtetra
.588 .52 .746 r
.59306 .14416 .59972 .16384 .61226 .1592 .60562 .14071 Mtetra
.59 .534 .76 r
.60562 .14071 .61226 .1592 .62485 .15453 .61826 .1373 Mtetra
.593 .551 .776 r
.61826 .1373 .62485 .15453 .63751 .14985 .63096 .13392 Mtetra
.596 .57 .796 r
.63096 .13392 .63751 .14985 .65022 .14515 .64373 .13059 Mtetra
.598 .593 .817 r
.64373 .13059 .65022 .14515 .66298 .14046 .65658 .12728 Mtetra
.6 .619 .842 r
.65658 .12728 .66298 .14046 .67581 .13579 .6695 .12402 Mtetra
.6 .649 .87 r
.6695 .12402 .67581 .13579 .6887 .13112 .68249 .1208 Mtetra
.599 .684 .901 r
.68249 .1208 .6887 .13112 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Rooooo`;oVJoV00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`1Aooooo`00H?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B47ooooo`03o`000?oooooooooo01gooooo0ol00002ooooo`03o`000?oooooooooo05cooooo0_nI
Y]h4oiV_iP03o`000?nI[nKooooo01Gooooo00?o0000ooooooooool0D?ooool0063ooooo00Go410@
oooooooooooooooooa0@400;ooooo`Go00007?ooool2o`00063ooooo0_nIW]L5oiVVgP?oVJoV00?o
0000ojJei?ooool05?ooool00ol0003oooooo`00001Aooooo`00H?ooool01Ol0003ooooooooooooo
oooo000000_ooooo00CoA4A4omgMgOoooooo00006_ooool3o`0005gooooo0_nIUm46oiVNe`GoVJKN
00?oVJoVojJei?l000000_nV]N@Fooooo`03o`000?oooooooooo04oooooo001Pooooo`05o`000?oo
ooooooooooooool000002oooool01?oMgMgoEEEEooooool0000Hooooo`;o0000G?ooool2oiRAb`Go
VIOA1_nIW]L2oiVVgP;oYJcL0_nV]N@01?l0003oY[GTojJei?nV]N@Fooooo`03o`000?oooooooooo
04kooooo001Pooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Eoooo
o`?o00000_ooool00ol0003oooooooooo`1Eooooo`;oUhg61OnHTL/5oiVGd@CoVIkG00?oXjCFojF/
g?nU[=`00onU[=`01OnV]NCo0000ojJei?nV]NCo/K_Q01Kooooo00?o0000ooooooooool0C_ooool0
063ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000001?ooooo0_l0001I
ooooo`;oUhS21OnGSLH4oiRAb`KoVIOA00?oVIkGoj>Te_nSY=H00_nSY=H5ojF/g003o`000?na^n7o
/K_Q00;o/K_Q5_ooool00ol0003oooooooooo`1=ooooo`00H?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00gooooo00?oMgMgo`000?ooool03oooool3o`0005Oooooo0_nFQKh5oiN8`PCoUhg61OnHTL/3
oiVGd@;oXYg?1OnSY=H4ojF/g003ojncfol0003o/K_Q00Co/K_Q5_ooool00ol0003oooooooooo`1<
ooooo`00P_ooool2o`0005Kooooo0_nFP[/5oiJ5_PCoUhS21?nGSLH4oiRAb`03oj6Gb_nRWLooXYg?
00CoXYg?1OnSY=H01OnU[=co[k?Kojncfon_/m_o000000Co/K_Q00?o^/;Pooooooooool05?ooool0
0ol0003oooooooooo`1<ooooo`00Ooooool3o`0000;ooooo00?o0000ooooooooool0Coooool2oiEo
^@GoUX:k1?nFQKh4oiN8`PGoUhg600?oV97;oj6Gb_nQUlX00_nQUlX5oj:Mc`CoXjCF00?o[JcFojnc
fon_/m/00_n_/m/00ol0003o[k?Kok6kh@04ok[2h1Cooooo0ol0001=ooooo`00O?ooool3o`0005Co
oooo00?oU7bfoiEo^OnEOkT00_nEOkT5oiJ2^`CoUXFn1OnGR<82oiN=aP;oWi751_nQUlX5oj:Mc`03
oj>Te_n][=Ko[JcF00;o[JcF0on_/m/00ol0003o^;cLok[2h004ok[2h1Oooooo00?o0000oooooooo
ool0B_ooool007[ooooo0_l0001Dooooo`03oiAj]?nDO;KoU7bf00;oU7bf1?nEOkT4oiJ2^`GoUXFn
0onGR<800onMSL7oWi75oinAa@03oinAa@GoXIO:1?nRWLl00on/YM7o[JcFojf/eP03ojf/eP?o[k?K
00?o^;cLo`000?nh_=`00onj`^02ol38h1Kooooo00?o0000ooooooooool0B_ooool007Oooooo0ol0
001Dooooo`?oU7Zd1?nDO;H4oiEo^@GoUX:k1?nFQKh00onGR<;oWHg1oif=`@02oif=`@GoWi751OnQ
UlX00onRWLoo[:GAojbUd@02ojbUd@Go[JcF00Ko[k?KokRlg?nh_=co0000okRlg?nj`^05ol38h1Ko
oooo00?o0000ooooooooool0BOooool007Gooooo0_l00002ooooo`03o`000?oooooooooo04oooooo
0_nDN;85oiAj]0CoU7bf0onEOkT5oiJ2^`;oUXFn0_nLR;h5oif=`@GoWi751?nQUlX00onZWlco[:GA
ojbUd@03ojbUd@Co[JcF00Ko]kOIokRlg?nh_=co^;cLo`000?o0aml5ol38h003ol;=h_oooooooooo
01Gooooo00?o0000ooooooooool0B?ooool007;ooooo0ol00005ooooo`03o`000?oooooooooo04[o
oooo0_nCMk04oiAh/PGoU7Zd1?nDO;H4oiEo^@?oUX:k00?oVhFjoib8__nLR;h00onLR;h5oif=`@Go
Wi7500?oXIO:ojZOc?nZWl`00_nZWl`5ojbUd@03ojf/e_ng]mWo]kOI00;o]kOI0_nh_=`00ol0003o
`<OOol37g`03ol38h0?o`/gR5_ooool00ol0003oooooooooo`18ooooo`00L?ooool2o`00057ooooo
0_nCM:h4oi=g/0GoU7Rb1?nDN[@4oiAl]PCoUGni00?oUX:koi^5^_nKQKX00_nKQKX4oib8_PGoWHg1
1?nOTLD00onXV/SoZYo<ojZOc003ojZOc0Co[:GA00?o][;EokNgfOng]mT00ong]mT00onh_=co`<OO
o`000003ol37g`03ol38h?o2cN;o`/gR00?o`/gR5_ooool00ol0003oooooooooo`17ooooo`00>?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00008?ooool3o`0004oooooo
0_nBLZ/4oi=d[PGoTgN`1?nDN;84oiAj]0GoU7bf0_nEOkT00onJP[SoVhFjoi^5^P03oi^5^PGoW8Rn
1OnMSL400onOTLGoZ9[8ojRJb002ojRJb0GoZYo<00?o[:GAokJbeOnf/]D00_nf/]D3okNgf@04ol36
goo0amoo`<OOo`0000;o`<OO00?o`m3Tol;=h_o2cN800oo2cN800oo1dNKoooooooooo`0Cooooo`?o
0000B?ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A401kooooo0_l00003ooooo`03o`000?oooooooooo04Sooooo0_nAL:T4oi9b
Z`GoTgB^1?nCMk04oiAh/PGoU7Zd0onDO;H00onIOkGoVX:hoiZ2^002oiZ2^0GoVhFj1?nLR;h4oif=
`@03ojJFa?nXV/SoZ9[800?oZ9[81?nZWl`00ond[M;o][;EokJbe@03okJbe@03okNgfOo0a]oo`<KO
00;o`<KO00?o`<OOo`000?o0aml00oo3d>@3ol;=hP?o`M7V5_ooool00ol0003oooooooooo`06oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`0Y
ooooo`00>?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h07?ooool3
o`0004gooooo00?oTFfVoi5`ZOnAL:T00_nAL:T5oi9bZ`CoTgB^1?nCMk05oiAh/PCoU7Zd00CoU7bf
oiUo]OnIOkGoVGne1?nJP[P5oi^5^PGoW8Rn00?oWHg1ojJFa?nVU/@00_nVU/@5ojRJb003ojZOc?nd
[M;o]:gB00;o]:gB1?nf/]D6ol36g`03o`000?o3d>Co`m3T00?o`m3T00?o`/gRol7Ai_o1dNH00oo1
dNHFooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1oooool00ol0003oooooooooo`0Zooooo`00>?ooool01Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h06?ooool3o`0004oooooo0_nAKJH5oi5`Z@CoTW:[1?nCM:h4oi=g/0GoU7Rb
0_nDN[@2oiQm/`GoVGne1?nJP[P5oi^5^P;oW8Rn0_nTTL45ojJFa0CoZ9[800?o/ZW?okB]d_nd[M80
0ond[M83okJbe@;o_lGO1?o0a]l00oo4e>Ko0000ol?@i003ol?@i0;o`][[1?o1dNH2ok[Ak1Kooooo
00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000[ooooo`00
>?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool05Oooool3o`0004ko
oooo0_n@Jj@4oi5]YPCoTG2Y1?nBLZ/4oi=d[PGoTgN`0onDN;800onHNk7oV7fcoiQm/`02oiQm/`Go
VGne1?nJP[P4oi^5^P03oj>>__nTTL7oY97100?oY9711?nVU/@3ojRJb0?o/ZW?1Ond[M800onf/]Go
_lGOoko5g`02oko5g`07ol36goo4e>Koa=CVolCDi_l0003oa=CVol?@i005ol;Jj`03ol7Ai_njdNco
^]7/00?o^]7/5Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002ooo
ool01?m4A4CogMgMooooool0000/ooooo`00>?ooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool04Oooool3o`0000?ooooo00?o0000ooooooooool0Aoooool2ohmYXPCoT6^T
1?nAKJH4oi5`Z@CoTW:[1OnCM:h4oi=g/004oiAh/_nHNk7oV7^aoiQk/@GoV7fc1?nIOkD5oiZ2^003
oi^5^_nSS[koXhjn00;oXhjn1?nTTL45ojJFa003ojRJb?nbZLoo/ZW?00;o/ZW?1?nd[M800onoaMko
_lGOoko5g`02oko5g`;oa=SX0oo4e>H00ol0003o`^;_ol;Rk`04ol;Jj`;o^]gb1?njdN`00on^co7o
ooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`04omgMgOmEEEGoooooo`0002cooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[ZjoooooonHV9So410@017ooooo0_l0001<ooooo`;oSfNP1?n?JJ85oi1[Y0?oTFfV1?nA
L:T4oi9bZ`GoTgB^0_nCMk02oiQi/0GoV7^a1?nHOK<5oiUo]@?oVX:h00?oXHZloj>>__nSS[h00onS
S[h4ojBA`@CoYYK400?o/JG=ok:YconbZLl01?nbZLl00ond[M;o_lGNoko5gP02oko5gP;o_lGO1?o4
f>P00oo4e>Ko`^;_o`000003ol;Rk`03ol;JjonjgO;o^]gb00?o^]gb00?o^]7/ojk?lOn^co400_n^
co4Fooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMg
Moo<c<co000002cooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00kooooo0ol0001;ooooo`03ohiVW_n?Ij3oSfNP00;oSfNP1?n?JJ85oi1[Y0?o
TFfV1?nAL:T5oi9bZ`?oTgB^00?oV7V^oiQi/?nHNK000_nHNK05oiQk/@CoV7fc1OnIOkD00onJP[So
XHZloj6:_002oj6:_0CoXhjn1OnTTL400onVU/Co/JG=ok6Uc@02ok6Uc@Co/ZW?00?o_lGOoko5g_no
aMh00onoaMh00onoaMooa=SXolCHj002olCHj0;o_n_b00Co`^;_o`000?o2h^oo`^;_0_ngj?H4ok[M
lP;o[=_h1On^co4Dooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l00000;?ooool005Wooooo0ol0001<ooooo`;oSVJN1?n?Ij05ohmYXPCoT6^T0onAKJH5oi5`
Z@CoTW:[00CoTgB^oiQi[_nHNJkoV7V^1OnHNK04oiQk/@GoV7fc0onIOkD00onPQkWoXHZloj6:_003
oj6:_0GoXhjn0onTTL400on_X/_o/JG=ok6Uc@03ok6Uc@?o/ZW?0onoaMl3oko5gP;oa=c[0oo4f>P4
oko[lP03o`000?ngj?Ko]nSf00?o]nSf00?o^]gbojcKn?n/foP00on/foP2ojk?l@;oX<Od4oooool0
1?l0003oooooooooool00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000
ooooo`0[ooooo`00E_ooool3o`0000?ooooo00?o0000ooooooooool0A_ooool2ohiUWP?oSVJN1On?
Ij04ohmYXPCoT6^T1?nAKJH4oi5`Z@;oTW:[0_nHN:d5oiQi[PCoV7V`1?nHNk45oiQm/`03oiUo]OnP
QkWoX8Ni00;oX8Ni1?nQR[`5oj>>_P03ojBA`On_X/_o[j;;00;o[j;;1OnaYLd00onbZLoo_lGOoko5
g`03oko5g`03oko5g_o4g>_oa=c[00;oa=c[00?oa=SXoko[l_nojo800_nojo800on^l?Ko0000ojk`
mP02okOXmPCoY>Kk0_n/foP2oicAnPGoX<Od5_ooool00ol0003oooooooooo`10ooooo`00E?ooool2
o`0004_ooooo0_n>IId4ohiUWPCoSVJN1?n?Ij04ohmYXPCoT6^T1?nAKJH3oi5`Z@03oiUh[?nHN:go
V7R]00;oV7R]1OnHNJh4oiQi/0GoV7^a0onHOK<00onOQKOoX8Nioj27^@03oj27^@GoXHZl0onSS[h0
0on^WlSo[j;;ojnRb`03ojnRb`Co/JG=00?o_/GOoko5gonoaMl00onoaMl00oo3hNgoa=c[olCLj`02
olCLj`?o^_;c00Go_n_bojk`m_n^l?Ko[_3fo`000002oiC[m`CoY>Kk00?oTmWnoicAn_nLdOX00onL
dOX4oj37m1Kooooo00?o0000ooooooooool0@?ooool0057ooooo0ol0001:ooooo`GoSVFM1?n>IIh4
ohiVWPCoSfNP1?n?JJ85oi1[Y0?oTFfV00CoTG2YoiUh[?nIN:coVGR/1OnHN:d4oiQi[PGoV7V`1?nH
Nk401?nHOK?oWhFgoin5]onOQKL5oj27^@GoXHZl00?oXhjnojjOb?n^WlP00_n^WlP5ojnRb`03ok6U
cOnnaMoo_/GO00;o_/GO0onoaMl3ol?Qk@03olCLjonjl_?o^_;c00;o^_;c0onMl^h00on^l?KoU>_g
o`000003oiC[m`03ojCVnonCfOkoTmWn00;oTmWn0_nLdOX2oi31n0GoTkgc5_ooool00ol0003ooooo
ooooo`0oooooo`00C_ooool5o`0004Sooooo00?oSfFMohiUWOn>IId01On>IId4ohiUWPCoSVJN1?n?
Ij04ohmYXPGoT6^T0_nAKJH00onJN:_oVGR/oiUh[003oiUh[0CoV7R]1?nHNJh5oiQi/0;oV7^a0_nN
PkH5oin5]`GoX8Ni0onQR[`00on/W<Oo[Yo8ojjOb003ojjOb0Co[j;;00?o_/KPokk5gonnaMl01?nn
aMl01?noaMoo`n7]ol?QkOo3hNd3ojogk`04ok[blonMl^koWO;^oigbkPCoNNCV00?o0000oiC[mon5
g_d00_n5g_d2oi?IoP?oRlKk1?n@`OP5oi>mlaKooooo00?o0000ooooooooool0?_ooool004cooooo
0_l00005ooooo`03o`000?oooooooooo04?ooooo0on?IId8ohiUW@?oSVFN1?n>IYh4ohmWX0GoSfVR
1?n@Jj@00onAKJKoVWR[oiYhZ`05oiUh[0CoV7R]1OnHNJh3oiQi/003oif2]?nNPkKoWX>f00;oWX>f
1OnOQKL5oj27^@03oj6:_?n/W<Oo[9c700;o[9c71?n^WlP3ojnRb`?o_/KP1?nnaMl2ol;Vl003ol?Q
kOn_mnoo[oO_00;o[oO_0_n2jMX3oeG@aP;oNNCV0_m`fo<00ol0003oQMkmohGNo@03ohG9oPGoRlKk
1?n@`OP2oi>ml`;oS;Ca5_ooool00ol0003oooooooooo`0nooooo`00BOooool3o`0004[ooooo0_n?
IIh4ohmUW@SoSVFM0on>IIh4ohiVWPCoSfNP1On?JJ83oi1[Y003oiYgZonJN:_oVWR[00;oVWR[1?nI
N:`4oiQh[@GoV7V^00CoV7V`oif2]?nMP[CoWH:d1OnNPkH4oin5]`CoX8Ni00?oZiW5ojbLaon/W<L0
0on/W<L5ojjOb003ojnRbonna^3o_/KP00?o_/KP00?o_/GOol;Vl?o2i_000_o2i_02oikdi003ojog
kon2jM[oP^WJ00?oEM360_mEd>02ogO<o`?oO/_o00?o0000ogk;oon5bOh00on5bOh2oh_6n`;oR[Cb
1On;]?84ohbdlACooooo0ol0000oooooo`008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^023ooooo
0_l0001:ooooo`03ohmVW_n?IIkoSfFN00;oSfFN1?n?IId8ohiUW@CoSVFN0on>IYh5ohmWX0CoSfVR
00CoT6^ToiYgZonJMj_oVWN[1?nJN:/4oiUh[0GoV7R]0onHNJh00onMPKCoWH:doif2]003oif2]0Co
WX>f1OnOQKL2oj27^@?oZiW51?n/W<L4ojjOb0;o_/OR1?nna^02oko[lP?o`^K`0_nNm>@01?mOdk[o
K<_nofc;o_m/boh4og3;o`CoMlco0_mnbol00ol0003oR;7aohVclP04ohVclPCoR[Cb1On;]?84ohbd
lAGooooo00?o0000ooooooooool0?Oooool002;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Moooo
o`?o00000_ooool00ol0003oooooooooo`14ooooo`CoSfJN1?n?IIh4ohmUW@SoSVFM1?n>IIh4ohiV
WPCoSfNP0on?JJ800onJMj[oVWN[oiYgZ`03oiYgZ`?oVWR[1?nIN:`5oiQh[@04oiQi[_nMPKCoWH6d
oif1]0GoWH:d1?nNPkH5oin5]`03oj27^On[VLGoZiW500;oZiW51On/W<L00on^WlSo_/ORokk7hP03
okk7hP03okk6h?nojo;o_n_b00?o_n_b00?o`^K`oikdi?mYbod00_mYbod2ofc;oP03oh^XjOn9[>go
RJc]00;oRJc]1On8[nl01?n8/O7o0000ohRalOn8/O45ohVclPCoR[Cb0_n;]?82ohfZj@GoSJk]5Ooo
ool00ol0003oooooooooo`0looooo`008_ooool01Ol@413ooooooooooooooooo410@01_ooooo0_l0
001:ooooo`KoSfJN1On?IIh3ohmUW@SoSVFM1?n>IIh4ohiVWPCoSfNP00CoSfVRoiYgZ_nJMj[oVWNZ
1OnJMj/3oiYhZ`GoVGR/0onHN:d00onNPK?oWH6doif1]003oif1]0CoWH:d1OnNPkH3oin5]`03ojVG
a?n[VLGoZiW500?oZiW51?n/W<L00onmbN?o_/ORokk7hP03okk7hP;o^o3c1?nojo82oi2Pg`CoSJCT
1?n;Z>T4ohV/k@GoR:o_00Co0000ohRalOn8/O7oR;7a0_n9/o82ohnPg`CoSZGT1On=Z^T5ohf^kAGo
oooo00?o0000ooooooooool0>oooool002;ooooo00Go0000ooooooooooooooooo`00000Hooooo`?o
0000BOooool:ohmVWPCoSfFN1?n?IId7ohiUW@CoSVFN1?n>IYh2ohmWX0;oVGJY1OnJMjX4oiYgZ`?o
VWR[1OnIN:`01?nHN:goWX6coij1/onNPK<5oif1]0CoWH:d1OnNPkH00onOQKOoZIO4ojVGa002ojVG
a0GoZiW500?o[9c7okg9honmbN<00_nmbN<3okk7hPCo^o3c00?o_n_boi2Pgon@X=l00on@X=l4ohfT
i0CoRjSY1?n9[>d2ohR_k`;oTIGD00Co0000oi2Jf_n@V][oT9[J1On?X=l4ohjUi0GoSJ[Y0_n=[^d2
oiB_jAGooooo00?o0000ooooooooool0>oooool002;ooooo00Go0000ooooooooooooooooo`00000F
ooooo`?o0000B?ooool00on@IYkoSfJNohmVWP0:ohmVWPCoSfFN1?n?IId7ohiUW@CoSVFN0on>IYh0
0onHM:WoVGJYoiUfZ@02oiUfZ@GoVWNZ1?nJMj/4oiYhZ`?oVGR/00?oWh:doij1/onNPK<00onNPK<4
oif1]0GoWH:d0onNPkH00onXUL?oZIO4ojVGa003ojVGa0CoZiW500?o_<[Uokg9honmbN<01?nmbN<0
0onnan;o^o3cok_`l`02ok_`l`?oTYcJ1On@X=l3ohfTi0;oRjSY0_nBR/P4oi6?cPCoTIGD00?o0000
oi2Jf_n@V]X00_n@V]X5ohnPg`CoSZGT0_n=Z^T2oiFWh`GoU:oY5Oooool00ol0003oooooooooo`0j
ooooo`008_ooool01Ol@413ooooooooooooooooo410@01?ooooo0ol00002ooooo`03o`000?oooooo
oooo04?ooooo1?n@IYh<ohmVWPCoSfFN1?n?IId8ohiUW@?oSVFN00CoSVJNoiQdZOnHM:WoV7BY1OnI
MZT4oiYgZPCoVWN[1?nJN:/01?nIN:coWh:doin2]?nOP[@5oij1/`CoWH6d1OnMP[@00onNPkKoZ9G3
ojRE``02ojRE``CoZIO40on[VLD3okc:i@Co_LWS0onem?<00onkl??oUISDoi:LfP04oi:LfP;oT:3O
0_nDP[d3oi>6`PGoTX[81?nASlh3oi6Ee003o`000?n@V][oT9[J00?oT9[J0_n?X=l2oiNJe@CoUZ7L
1OnEYn<4oiB_jAKooooo00?o0000ooooooooool0>Oooool002;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0@ooooo`?o0000BOooool6oi1VWPcoSfJN1?n?IIh4ohmUW@SoSVFM0_n>IIh00onFLZSoV7BY
oiQdZ@03oiQdZ@CoVGJY1?nJMjX5oiYgZ`;oVWR[00?oX8>doin2]?nOP[@00onOP[@4oij1/`GoWH6d
0onMP[@00onWU<;oZ9G3ojRE``03ojRE``GoZIO400?oZiW5okc:iOnlb^D00onlb^D00onmbN?o]OCc
okGdl`02okGdl`CoUISD0_nBW=X2oiEo^0GoU8:m0onCQ/84oi::b0CoTHo>0onAUM@01?l0003oTIGD
oi2Jf_n@V]X2oiNDc`GoUi[E1?nFXM`4oiFWh`;oU:oY0onN/^HDooooo`;o0000>oooool002;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`;o0000B_ooool00on@IYgoT6JNoi1VWP06oi1VWP_o
SfJN1?n?IIh4ohmUW@SoSVFM00?oSVFNoiIbZ?nFLZP01OnHM:T4oiUfZ@CoVWNZ1OnJMj/01?nJN:_o
X8>doj23]?nPPk@4oin2]0GoWX6c1?nMPK@00onMP[CoYiC2ojND`P02ojND`PCoZ9G31?nYUl@2ok_;
iPCo_<[U0on/m^l00onem??oUi?>oiNCcP02oiFHe0;oUWbd1OnEOkP4oiB2_@?oThK21?nBR/P5oi6?
cP;oTIGD00?o0000oiR?bOnGU<l01?nGU<l4oiNJe@GoUZ7L0_nEYn<00onNZMkoW[;VoijbiP04oijb
iQGooooo00?o0000ooooooooool0>?ooool003;ooooo1Ol00016ooooo`GoT6JM2?n@IYh;ohmVWPCo
SfFN1?n?IId6ohiUW@;oU72W1?nFLZP4oiQdZ@CoVGJY1OnJMjX3oiYgZ`03oj:5]OnPPkCoX8>d00;o
X8>d1?nOP[@5oij1/`;oWH6d0_nVTl85ojND`PGoZ9G300?oZIO4ok_;i_nkbnH00onkbnH00onlb^Go
[?K_ojcfk`02ojcfk`;oUi?>0_nGNk44oiIl]0GoUGnh1?nDP[d3oi>6`PGoTX[80_nASlh2oiV:``03
oiR?bOl0003o000000;oV8o91?nGU<l5oiNJe@;oUZ7L0_nNX]L4oijYgPCoW[;V00?oZKSToooooooo
ool05?ooool00ol0003oooooooooo`0gooooo`00<?ooool2o`0004Sooooo2?n@IYd8oi1VWP_oSfJN
1On?IIh3ohmUW@;oSVFM0_nBKjL4oiA`Y`CoUW:X1?nHM:T4oiUfZ@GoVWNZ00CoVWN[oj:5]OnRQKGo
XXFe1OnPPk@4oin2]0?oWX6c00?oYI?2ojJC`_nVTl800onVTl84ojND`PCoZ9G30_njbnL4ok_;iP?o
XOGY00?o[?K_oiR>b?nHNJl01?nGNk45oiIl]0CoUGnh1OnDP[d3oi>6`P;oTX[80_nIQ[d2oiV:``?o
000000CoV8o9o`000?nHSlWoV8o91OnGU<l2oiNJe@;oWi_@1OnNX]L4oijYgP03oijbi_nY^>CoZKST
00;oZKST5Oooool00ol0003oooooooooo`0gooooo`00;Oooool3o`0004Wooooo2_n@IYd7oi1VWPco
SfJN1?n?IIh2ohmUW@03oi5]Y_nBKjOoTVnW00;oTVnW1OnDL:L3oiIbZ0CoV7BY1OnIMZT3oiYgZP03
oj>7]onRQKGoXXFe00?oXXFe1?nPPk@4oin2]003oij1/onUTl;oYI?200;oYI?21?nVTl85ojND`P03
ojRE`onjbnOo^/_W00?o^/_W00Co^l_Voj7ejOnQmNWoXOGY0_nHRL801?nHS/SoV7V_oiQi[onHNJl4
oiMk/@CoUWbd1OnEOkP4oiB2_@;oThK200CoVX:ioiV6_OnIQ[goVHJm0ol00003oiV:``;oV8o900?o
0000oiR?bOnHSlT00_nGU<l2oinEb@CoWi_@1OnNX]L2oijYgP;oZK3N1_nY^>@Eooooo`03o`000?oo
oooooooo03Kooooo000/ooooo`;o0000B?ooool2oi1VWP_oT6JM1on@IYh<ohmVWPCoSfFN00?oSfFM
oi5]Y_nAKJH01OnBKjL4oiA`Y`?oUW:X1OnHM:T4oiUfZ@04oiYgZ_nSQkOoXhNgoj>7]`GoXXFe1?nP
Pk@3oin2]003ojJD`onUTl;oYI?200?oYI?21?nVTl84ojND`P;o^<_X1?njbnL2oiGahP03oiN4_?nH
RL;oV8W200;oVGR]1?nHNJl4oiMk/@CoUWbd1OnEOkP2oiB2_@;oVWnd0onJP[T3o`0000;oVHJm1?nI
R/<3oiR?b@03o`000?nPT<CoWiG900CoWiG91?nOVm03oijRe`03ojVZeonY/=koZK3N00?oZK3N1?nY
^>@2ok:oi1Gooooo00?o0000ooooooooool0=Oooool002cooooo0ol00014ooooo`03oi5WWon@IYko
T6JN00;oT6JN2on@IYd7oi1VWPcoSfJN0_n?IIh6oi5]YPCoTVnW1?nDL:L3oiIbZ0GoV7BY0onIMZT0
0onSR;SoXhNgoj>7]`03oj>7]`CoXXFe1OnPPk@01?nOP[CoYYC3ojJD`onVU<<4ojFC`PGoYY?200?o
YiC2okS;j?nhbnP00onhbnP01?njbnOoUO7RoiGah_nGQ;`2oiUfZPCoVGR]1?nHNJl4oiMk/@GoUWbd
0onEOkP00onJO;7oVWndoiYo]002oiYo]0?o000000?oVX:ioiV6_OnIQ[d00_nIQ[d5oiV:``05oiR?
bOnPT<CoX934o`000?nPT<@01?nOULT4oinKd003oijReonYZ]OoZJ[G00;oZJ[G1OnY/=h00onY^>Co
/[oTok:oi003ok:oi1Cooooo00?o0000ooooooooool0=Oooool002cooooo00Co0000ooooool0003o
0000@_ooool2oi5WW`CoT6JN2on@IYd7oi1VWP[oSfJN0_nAKJD8oi5]YPCoTVnW1?nDL:L4oiIbZ0Co
V7BY00CoVGJYoj>8^?nSR;SoXhRh1OnSQkL5oj:5]@?oX8>d00?oYYO5ojJD`onVU<<00_nVU<<5ojFC
`P?oYY?20_nebNT4okS;j0;oRNcI00?oV7>XoiUfZ_nIMZX00_nIMZX5oiUh[@CoV7V_1?nGNk44oiIl
]005oiEo^?nJO;7oVWbaoiYl/OnJOk@00ol000001?nJOkCoVX:ioiZ2^OnJP[T5oiV6_@;oVH[30_nQ
SKl3oj2@a003o`000?nPT<CoWiG900CoWiG90_nOVm000onYY=;oZJ[GojVZe`04ojVZe`;oZK3N0onb
^n44ok:oi003okO6i_oooooooooo017ooooo00?o0000ooooool000002?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`06Oooool002cooooo
0_l00002ooooo`03o`000?oooooooooo03cooooo0_nAJJ03oi5WW`CoT6JN2on@IYd8oi1VWPKoSfJN
1OnAKJD8oi5]YPCoTVnW1?nDL:L4oiIbZ0?oV7BY00?oXXRhoj>8^?nSR;P00onSR;P4oj>7]`GoXXFe
00?oX8>dojJGaOnVUlD00_nVUlD4ojJD``CoYI?200?oYY?2okG9jOnebNT00onebNT01?nhbnSoRNcI
ohW/fOnFOkP2oiQcZ0GoVGJZ1?nIN:d4oiQi[`CoUg^a0_nFO;@2oiYj[P;oVWba0ol00004oiYo]0Co
VX:i0onIQ[d00onQRK_oXHfooj6=_`03oj6=_`?oX93400?o0000oinEbOnOULT00_nOULT00onYX<go
ZJCBojVTdP02ojVTdPCoZJ[G00?o/kSMok:khOnb^n401?nb^n400onb_nCo]lKVokO6iP02okO6iQGo
oooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oeEEEOmgMgOooooooiRHV?lQ8B406Oooool002_ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0hooooo`03oi9[X_nAJJ3oTFVP00;oTFVP1?nAIil3oi1VWP_oT6JM2?n@IYh3ohmV
WP03oi9]YOnAKJGoTFfU00KoTFfU1onAKJH4oi9_Y`GoU72W0onFLZP00onHM:WoXXRhoj:8^002oj:8
^0CoXhRh1OnSQkL3oj:5]@03ojRJb?nVUlGoYYO500?oYYO51?nVU<<3ojFC`P;o//OY1?nebNT2oggW
dP;oUW2U1?nHLjP4oiUfZPCoVGR]1?nHNJl3oiMk/@03oi]i[?nJNZkoVWZ^00;oVWZ^0_l00003oiYl
/@CoVWnd1?nJP[T00onIQ[goXHVkoj69^`02oj69^`CoXHfo1?nPT<@00ol0003oWiG9ojVPc@02ojVP
c@GoZJCB00?oZJ[Gok>hgOnc^=d00_nc^=d4ok:kh@03okS7i_nga^Ko]lKV00?o]lKV5Oooool00ol0
003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000001Wooooo000[ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=_ooool2
oi9[XPCoTFVP1?nAIil3oi1VWPcoT6JM1on@IYh01?n?IYkoTVfUoi9]YOnBKJD8oi5]Y@OoTFfV1OnB
KjL4oiA`Y`;oUW:X00?oX8Jhoj:8^?nRR;P00onRR;P4oj>8^0GoXhNg00?oXXFeojRJb?nXV/P00_nX
V/P4ojJGa@GoYYC300?oYI?2ok;7jOnbanT00_nbanT00onebNWoONOBoggWdP04oiI`Y@CoV7>X1?nI
MZX4oiUh[@GoV7V_00CoUg^aoi]i[?nKNJcoVWZ^0ol000000onJNZkoVWbaoiYl/@02oiYl/@GoVWnd
0_nJP[T00onQQ[OoXHVkoj69^`03oj69^`CoXHfo1?nPT<@00ol0003oZJ3=ojVPc@03ojVPc@?oZJCB
00?o];KJok>hgOnc^=d01?nc^=d00onb^n7o^<OVokS7iP02okS7iP?o]lKV0_nhc>TEooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRH
V?lQ8B406Oooool002_ooooo0ol00005ooooo`03o`000?oooooooooo03;ooooo0_nDKJ@3oi9[XPCo
TFVP1?nAIil4oi1VWP_oT6JM1On@IYh2oi=^Y@CoTVfU2?nAKJD8oi5]YPCoTVnW0onDL:L00onMQ;Oo
X8Jhoj26^002oj26^0CoXXRh1OnSR;P3oj>7]`03ojVNbonXV/SoZ9[800?oZ9[81OnVUlD2ojJD``?o
[lGY0onbanT2ogCQc@;oU6fS1OnFL:D3oiQcZ0CoVGJZ1OnIN:d3oiQi[`03oi]hZ_nKNJco000000;o
00001?nJNZh5oiYl/@CoVWnd00CoVX:ioj66]onQQ[OoXHJg1?nQRK/5oj6=_`05oj2@a?nZW<SoZYc8
ojZLb?l000001?nYX<d00onYY=;o];KJokBffP02okBffPCo/kSM00?o^/WVokS7i_nhanH00onhanH0
0onga^Ko^<cYokS<j@03okS<jAGooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Iooooo`00:oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02kooooo00?oUG2VoiA]Y?nDKJ@00_nDKJ@4oi9[XP?oTFVP1?nA
Iil4oi1VWP_oT6JM0_n@IYh00onDKjKoTfjUoi=^Y@02oi=^Y@GoTVfU1onAKJD8oi5]YPCoTVnW00Co
U72Woif4]onMQ;OoWHBg1?nPQ[P5oj:8^0CoXhRh00?oXhNgojVNbonYW//00_nYW//4ojRJb0CoYYO5
00?o[L?Zojo5jOn_aNT01?n_aNT00onbanWoM>7=ogCQc@03oiA]X`GoUW2U0onHLjP5oiUfZPCoVGR]
00?oV7V_oi]hZ_l000000_l00003oi]i[0CoVWZ^1OnJO;42oiYo]0;oXHBd1?nQQ[L5oj69^`?oXHfo
00?oZi[5ojZLb?nZW<P00onZW<P01?l0003oZJ3=ojVPcOne]MP6okBffP03ok>hgOnjbNKo^/WV00;o
^/WV0onhanH2okWDk@Co^<cY00?o//c]ooooooooool04oooool00ol0003oooooooooo`03ooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Kooooo`00:oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02cooooo0_nEL:H4oiA]Y0CoTV^R0onAJJ04oi5WW`Co
T6JN2_n@IYd01?nEL:KoU6nVoiA_Y_nDKjH5oi=^Y@CoTVfU1onAKJD8oi5]YP;oTVnW0_nKPKH5oif4
]`CoX8Jh1?nRR;P2oj>8^0;oZj?>1OnYW//5ojRJb003ojJGaOn]`n[o[L?Z00;o[L?Z1?n_aNT00om/
gL[oTVVPoi9YX005oiA]X`CoUW2U0onHLjP5oiUfZP;oVGR]00CoW7NYo`000?l0003o00000onKN:X3
oi]i[0GoVWZ^0onJO;400onQP[7oXHBdoj64]003oj64]0?oXHJg1OnQRK/00onQSKooZi[5oj^Ja@02
oj^Ja@GoZYc800Co0000okFef?ne]MSo]KGH1?nd]]X00onkc>Oo^/WVok[9iP04ok[9iP03okS7i_ni
e>go^MC]00;o^MC]00?o^<cYok;<kOnbc>d00_nbc>dCooooo`?o00001?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P06oooool0013ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Xooooo`;oUW>Y0onEL:H4oiA]Y0CoTV^R1?nAJJ03oi5WW`CoT6JN
2?n@IYd3oiE`YPCoU6nV1?nCKZD4oi9]Y@SoTFfU1_nAKJH00onIO[GoVh6foi^1]P02oi^1]PGoWHBg
1?nPQ[P3oj:8^003ojbVdOn[XlkoZj?>00?oZj?>1?nYW//4ojRJb0;o[<?[1On]`nX00on_aNWoT6NN
oi1WWP03oi9YX0GoU6fS1?nFL:D4oiQcZ0?oVGJZ00GoWGNXo`000?l0003o0000oiagZ@05oi]hZP?o
VgV/1OnJNZh01?nJO;7oXH:aoj62/OnQP[45oj64]0CoXHJg0onQRK/00on/V<;oZi[5oj^Ja@03oj^J
a@CoZYc800?o]kGGo`000?ne]MP00one]MP00ond]][o^lcWok_<i`02ok_<i`Co^/WV00?o^MgbokWD
kOnie>d00_nie>d2ok7Fl`Go//c]5Oooool02Ol0003oooooooooooooooook^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@41Wooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01?ooool3o`0000[ooooo00?o0000oooooooo
ool09?ooool00onHMZ_oUW>YoiIcZ@02oiIcZ@CoUG2V0onDKJ@4oi9[XPCoTFVP0onAIil4oi1VWPKo
T6JM00?oUG2WoiE`Y_nEL:H00_nEL:H4oiA_YPCoTfjU1?nBKJD8oi5]Y@GoTFfV0_nIO[D5oi^1]PCo
WHBg1OnPQ[P01?nRR;So[:KAojbVdOn/Y]44oj^ScPGoZIk;00?oZ9[8ojc3jon/`n/00on/`n/2ojg3
jP03ofCIb?n@IikoT6NN00;oT6NN1?nBJJ04oiA]X`CoUW2U1?nHLjP01?nIMZ[o0000o`000?l00005
oiagZ@CoVgRZ1?nKNJ`3oiYj[P03oj60[onQP[7oXH:a00?oXH:a1?nQQ;@4oj66]`03oj69^on/V<;o
[9S200;o[9S21On[V/D00onZW<So]kGGokNee`02okNee`04o`000?ne]MSo]KGHokgBj@Ko^lcW00?o
^/WVokWMl_nigO800_nigO800onie>go/MKcok7Fl`03ok7Fl`;o//c]0_nYbO0Eooooo`03o`000?oo
oooooooo02oooooo0008ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
0005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08_ooool2oiQfZ`CoUW>Y1?nE
L:H4oiA]Y0?oTV^R1?nAJJ04oi5WW`?oT6JN0on@IYd01?nDL:OoUG2WoiE`YonEL:L5oiE`YP?oU6nV
1?nCKZD4oi9]Y@SoTFfU0_nAKJH2oiMl/`CoVGje1?nKPKH5oif4]`?oX8Jh00?o[:OBojbVdOn/Y]40
0_n/Y]45oj^ScP;oZIk;0on/a^d4ojc3j`;oG=?60_n?IId5oi1WWP?oTVVP1?nDKJ<5oiI`Y@;oV7>X
0_l00004oiegZ0CoW7NY1?nKN:X4oi]i[004oiYj[_nQP:ooXH2_oj60[`GoXH:a1OnQQ;@2oj66]`03
ojfH`On/V<;o[9S200?o[9S21?n[V/D00oni^=So]kGGokNee`03okNee`03okFef?l0003o_M;Y00;o
_M;Y1?nkc>L2okOWmP;o^Mgb1?n^h?P2ok7Fl`;oYm7f1OnYbO0Eooooo`03o`000?oooooooooo02ko
oooo000@ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00006oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool07oooool00onIN:goV7J[oiQfZ`02oiQf
Z`?oUW>Y1?nEL:H4oiA]Y0?oTV^R1?nAJJ04oi5WW`?oT6JN00CoT6JMoiA`YonDL:OoU72W1?nEL:L4
oiE`YP?oU6nV1?nCKZD5oi9]Y@GoTFfU0_nGNk84oiMl/`CoVGje1?nKPKH5oif4]`03oj26^?n/Ym;o
[:OB00;o[:OB0on/Y]44oj^ScP;o[L__1On/a^d01?n/`n_oG=?6oecCa_n?I9`4ohmUW@CoT6NN0onB
JJ04oiA]X`CoUW2U0ol000000onMMjOoWGNXoiegZ003oiegZ0CoW7NY1OnKN:X2oi]i[003oj5n[_nQ
P:ooXH2_00?oXH2_1?nQP[45oj64]004oj66]on]V<7o[IS1ojfH`@Co[9S20on[V/D3okVhf0Co]kGG
00?o_][]o`000?nmd^T00onmd^T01?nkc>Oo]nOfokOWm_ngioH2oj?Yn`Co[^3h00?oX=WkojOAm_nW
dOH00onWdOH2ojW9l0?oX<;`5Oooool00ol0003oooooooooo`0]ooooo`004?ooool01Ol0003ooooo
oooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01_ooooo00CoVW^_oiUh[OnIN:goVGR]1?nHMZ/4oiIcZ@?oUG2V1?nDKJ@4
oi9[XP?oTFVP1?nAIil2oi1VWP03oi=`Z?nDL:OoU72W00;oU72W1?nEL:L4oiE`YP?oU6nV1OnCKZD4
oi9]Y@;oTFfU00?oUgZboiMk/_nGNk800_nGNk85oiMl/`?oVGje1OnKPKH3oif4]`03oj^Wdon/Ym;o
[:OB00?o[:OB1?n/Y]400on[Xlko[L__ojg;k`03ojg;k`;o[<K]0omCc/43ohmTW0CoSfFM1?n@Iih3
oi9YX0GoU6fS0ol000000onFL:GoV7>XoiegY`02oiegY`CoWGNX1?nLMjT5oi]hZP03oi]i[?nQOZko
XGj^00GoXH2_1OnQP[43oj64]003ojjH`?n]V<7o[IS100;o[IS11On/V<800on[V/Go^KSHokVhf002
okVhf0?o]kGG0onnf^d00ol0003o_M;YojkamP03ojkamP03okOWm_nSjO_oXnWk00;oXnWk00?o[^3h
oj3InonPfO/00_nPfO/2ojOAmP?oWLGd1OnP`_0Dooooo`03o`000?oooooooooo02gooooo000@oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`;o00003oooool2
o`0001Wooooo0onJNjl4oiUh[@?oV7J[1?nFLjT3oiE`YPCoU6fT1?nBJj83oi5YX0;oTFNO0_nBL:T3
oi=`Z0CoU72W1?nEL:L4oiE`YPCoU6nV1?nCKZD4oi9]Y@03oi5]YOnGN[;oUgZb00GoUg^b1?nGO;<4
oiUn]@CoVh6f00?oWHBgoj^Wdon[Ym<00_n[Ym<5ojbWdP;o[:KA0on_d_83ojg;k`;oAlFf0on?Hi/4
ohmTW0CoSfFM1?n@Iih3oi9YX0;oU6fS0ol00003oiI`Y@03oiefY_nMMjOoWGNW00;oWGNW1?nMMjP4
oiagZ@CoVgRZ00?oX7f]oj5n[_nQOZh00_nQOZh4oj60[`GoXH:a00?oXHBdojjH`?n^V<000_n^V<03
ojfH`@Co[9S200?o_;cJokVhf?ni^=P01?ni^=P01?ng]MOo_][]okkJkOnnf^d2oiKaj@03o`000?n^
lOKo[_7f00?oSN[c0_nSjO/4oiCNoP;oX=Wk0_nIb?P5oig5m0;oX<;`0_nK^^hEooooo`03o`000?oo
oooooooo02cooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00
0006ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05?ooool00onKOK7oVW^_oiYk
[`02oiYk[`CoVGR]0onHMZ/4oiIcZ@CoUG2V0onDKJ@4oi9[XP;oTFVP00?oT6nZoi9`ZOnBL:T00_nB
L:T4oi=`Z0?oU72W1?nEL:L4oiE`YPCoU6nV1?nCKZD2oi9]Y@;oUg^b1?nGN[84oiMk/PCoUgbc1?nI
O[D2oi^1]P;oZJGB1On[Ym<4ojbWdP;o/=[e1On_d_800on]bnooSf>JohmSVP05ohmSV`?oSfBL1?n?
IId4oi1WWP;oTVVP0ol00003oiA]X`04oiI`YOnMMZKoWGJVoiefYPCoWGNW1?nMMjP5oiagZ@;oVgRZ
0_nPOJd4oj5n[PCoXH2_1?nQP[400on`VKoo[YS0ojjH`003ojjH`0Co[IS100?o[9S2okblf_nl_=X0
0_nl_=X4okVhf0;o_^Cb00?o_][]oiKajOnFlNT00_nFlNT01?mUf]Wo0000ohgZlon=j_<4oh7No0;o
U=kn0_nCbOX5oiW8n0;oWLGd0_nJ^Nh5oi^jkQ?ooooo0_l0000^ooooo`004?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo013ooooo00CoW7ncoi]m/OnKOK7oVgfa1?nJNjl4oiUh[@?oV7J[1?nFLjT4oiE`
YP?oU6fT0_nBJj82ohm_Z`?oT6nZ1?nBL:T4oi=`Z0CoU72W0onEL:L5oiE`YP?oU6nV0_nCKZD2oiQl
/PCoUg^b1?nGN[84oiMk/PGoUgbc0_nIO[D00onWXM3oZJGBojVUdP03ojVUdPGoZjOC00?o[:OBok3J
mOn`f_D00on`f_D2ojoBlP;oT6>J1?n?HiX4ohmSV`?oSfBL1?n?IId3oi1WWP?o00000_nBJJ03oiA]
X`03oieeYOnMMZKoWGJV00?oWGJV0onMMjL5oiegZ0CoW7NY00?oVgRZoj1m[OnPOJd00_nPOJd3oj5n
[PGoXH2_0_nQP[43ok2I_`Co[YS00on]V<400onoaMko_;cJokblfP04okblfP04okVhf?nni?;o_^Cb
okkTlP?oI]S100GoU_7YofGJfOmUf]WoIM[Io`000002ofSGl`;oPMkl0_n=b?/5oi?9nP;oVLSh0onH
]^`4oiZikPCoVk[^5Oooool00ol0003oooooooooo`0[ooooo`00:Oooool2o`0001Cooooo00?o0000
ooooooooool03Oooool3oiao/`CoVgfa1?nJNjl3oiUh[@CoV7J[0onFLjT4oiE`YP;oU6fT00?oSg2[
ohm_Zon?Kj/00_n?Kj/4oi1_ZP?oTW2Y1?nCL:P4oiA`Y`CoUG2W1?nEL:H2oiA_YP03oiUm/onHO;;o
V7bb00;oV7bb1OnGNk83oiMj/PGoUg^b1?nGO;<01?nIO[GoYj7@ojNQd?nWXM04ojVUdPCoZjOC0on`
hOP2ok3Jm@OoT6>J0on?HiX4ohmSV`CoSfBL0on?IId3o`0000;oT6NN0onBJJ001?nDKJ?oWGFUoiee
YOnMMJD5oiefYP?oWGNW1OnMMjP3oiagZ@03oj5m[?nPOJgoX7f]00?oX7f]0onQOZh5oj60[`03oj62
/On`VKoo/9Vo00;o/9Vo1On^V<001?n]V<7o_lGNoko5g_noaMh4okblfP?o]o3e00?o_^CbofKH`OmV
f<400_n7/o<4ohFmn@03ohS4nol0003oR<Ck00;oR<Ck0on=b?/2oi?9nP?oUk;Z1OnH]^`4oiZikP;o
Vk[^0_nL]n/Eooooo`03o`000?oooooooooo02[ooooo000Yooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool02_ooool00onMP[GoW7ncoiao/`03oiao/`?oVgfa1?nJNjl4oiUh[@?oV7J[
0_nFLjT00on@LZgoSg2/ohm`[002ohm`[0?oSg2[1?n?Kj/4oi1_ZPCoTW2Y0onCL:P4oiA`Y`CoUG2W
1?nEL:H00onDKjKoVGfcoiUm/`05oiQl/PCoUg^b0onGN[85oiMk/P;oUgbc0_nUW/l4ojNQd0GoZJGB
00?oZjOCok3Qn?n`hOP00_n`hOP00ol0003oT6>Joi1SVP07oi1SVP?oSf>J1?n?Hi/4ohmTW003ohmU
WOl0003o000000GoT6NN0_nBJJ000onKLjCoWGFUoieeY@03oieeY@CoWGJV1?nMMjL4oiegZ004oiag
ZOnQOJcoXGf/oj5m[0GoX7f]1?nQOZh3oj60[`03ok6J`?n`VKoo/9Vo00?o/9Vo1?n^V<000oo3d^Ko
_lGNoko5gP03oko5gP03okblf_ngl?Go]o3e00;o]o3e0_n:YnP5ohNcl`CoQKgi00CoR<Cko`000?nF
XmkoUZ?N1?nFZnD5oiNbjP;oV;K/0_nL[N<4oi^bj0GoW;O[5?ooool00ol0003oooooooooo`0Zoooo
o`00:Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo00CoWhFgoif2]OnM
P[GoWH:e1OnLOk<3oi]m/@CoVW^_1?nIN:d2oiQfZ`04oi9c[_n@LZgoT7:]oi1b[@CoSg2/1?n?L:/3
ohm_Z`CoT6nZ1?nBL:T3oi=`Z0CoU72W1?nEL:L2oiE`YP;oVGne1?nIOK<4oiQl/PCoUg^b1?nGN[83
oiMk/P03oj>LcOnUW/ooYIk?00?oYIk?1?nWXM02ojVUdPCo[nOi00?o/>7ho`000?n@HiX02_n@HiX3
ohmSVPCoSf>K0_n?I9`3o`0000?oSfFM1?n@Iih00onBJJ3oVg>Toi]cY005oieeY@CoWGJV1?nMMjL3
oiegZ003oj9o[OnQOJcoXGf/00?oXGf/1?nPOJd4oj5n[P03oj60[onaV/3o/I[000;o/I[01On`VKl2
ojjH`0?o`m;V0onoaMh3oj7dj`03okO`mOn>Vm_oRZOX00?oRZOX0_n7/o<2oiNAb`CoUY[F0_nFXmh0
0ol0003oUZ?NoiJSgP04oiJ[i@;oUk;Z0_nLZ=h5oib]h`CoVk;X0_nL]n/3oj6gj1Cooooo00?o0000
ooooooooool0:Oooool002Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`04oooo
o`;oWhFg1?nMP[D4oiao/`CoVgfa0onJNjl2oiUh[@;oTgJ_0onBLjh4oi1b[@CoSg2/0on?L:/4ohm_
Z`?oT6nZ1?nBL:T4oi=`Z0?oU72W0_nEL:L2oiV0]PCoVGne1?nIOK<4oiQl/PGoUg^b0onGN[800onG
Nk;oXic=oj>Lc@02oj>Lc@CoYIk?0onWXM04oj[[n@;o[nOi3_n@HiX3ohmSVP?oSf>K0ol00002ohmT
W0CoSfFM0on@Iih00onILJ?oVg>Toi]cY002oi]cY0CoWGFU1?nMMZH4oiegY`04oiegZ?nROjgoXWn]
oj9o[@GoXGf/1?nPOJd4oj5n[PGo/I[01On`VKl00on^V<3o`m;Vol?BiP02ol?BiP04oko5g_nQm>_o
XOC[oj7dj`GoSY_K0_n:YnP00onHR<7oUi7;oiNAb`03oiNAb`CoUY[F00CoUZ?No`000?nFXmkoUZ?N
0_nFZnD2oifQf0GoW:SN1?nL[N<2oi^bj0;oXK3S1_nQ]nPDooooo`03o`000?oooooooooo02Sooooo
000Yooooo`?o00005oooool00ol0003oooooooooo`02oj28^PCoWhFg0onMP[D5oiao/`?oVgfa0_nJ
Njl00onEN;3oTgJ_oi=f[`02oi=f[`CoTW>^0on@LZd4ohm`[0?oSg2[1?n?Kj/3oi1_ZPCoTW2Y1?nC
L:P2oiA`Y`03oiR1^?nIP;KoVH2f00;oVH2f1OnIOkD3oiUm/`CoV7bb1OnGNk82oiMj/P03oj:JcOnS
W<goXic=00?oXic=1OnUW/l00onWXM3oZ^_ioj[[n@02oj[[nA7oT6>J0on?HiX3o`000003ohmSVon?
I9coSfBL00;oSfBL1?n?IId01?n@IikoVG6SoiUaXonILJ<4oi]cY0CoWGFU1OnMMZH2oiegY`03ojF3
[onROjgoXWn]00?oXWn]1?nQOJ`5oj1m[@;oXGj^0_nbW<84ok6J`0Co/9Vo0_o5i^h3ol?BiP03of_K
`OnBSlgoTXo=00?oTXo=0_n>Vm/2oiZ2^0CoV8S11?nGTL/5oiJJeP03oiJSg_l0003oWY_A00GoWJ7H
1OnLZ=h2oib]h`03oj:[gOnQ/>?oXK3S00?oXK3S1?nQ]nP00onW^nOoooooooooo`0Aooooo`;o0000
:_ooool002Wooooo00?o0000ooooooooool05oooool00onRS;coX8Rjoj28^P02oj28^PCoWhFg0onM
P[D5oiao/`;oVgfa00CoUWZaoiEh/?nEN;3oUGR`1?nCMZl4oi9c[P?oT7:]1?n?L:`3ohm`Z`CoSfn[
1?n@KjX3oi9`Z@;oTg2X0_nFPKX3oiR1^0GoVH2f1?nIOkD3oiUm/`GoV7bb0onGNk800onQVLgoXY[=
oj:Jc@02oj:Jc@CoXic=1?nUW/l3oj?]n@03oj[[nOn@Hi[oT6>J017oT6>J0ol00005ohmSV`?oSfBL
0on?IId00onHKZ;oVG6SoiUaX`02oiUaX`CoVg>T1?nMMJD5oiefYP03oiegYonUPjooYH>_00GoXWn]
1?nQOJ`5oj1m[@04oj5n[_nbW<;o/Yc2ok:L`PGo/I[000?o/9VoolGVk_o5i^h00oo5i^h01?o3d^Ko
UXO1oiJ7`OnFQl42oi:?c@;oVgb`1?nJP[P4oiR8`@GoUi7;0_nFV]H2oj2Fb@;oWY_A00?o0000oijK
dOnMXMP01?nMXMP2oibXgP;oXjGG1?nRZmd5oj6`h`03oj6gj?nW^nOoYk_W00;oYk_W5?ooool00ol0
003oooooooooo`0Wooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001Oooool00ol0003oooooooooo`0Gooooo`?oXXbl0onPR;X4oin5]`CoWH:e0onLOk<01?nH
O;?oUWZaoiIj/OnFN[44oiEh/0?oTgJ_1?nBLjh3oi1b[@CoSg2/0on?L:/4ohm_Z`CoT6nZ0_nBL:T0
0onDOk[oUX6joiJ1^P02oiJ1^PCoV86h1?nIP;H4oiUo]@CoVGfc1?nHO;800onGNk;oXIW=oj6Ic@02
oj6Ic@?oXY[=1OnSW<d01?nUW/ooXngioj?]nOnSkOTCoi1SVP?o00001?n?HiX4ohmSV`?oSfBL00Co
SfFMoiQ^X_nHKZ;oV6jR1OnILJ<3oi]cY0GoWGFU0onMMZH00onXR;?oYH>_ojF3[`02ojF3[`CoXWn]
1OnQOJ`3oj1m[@03ok:OaOnbW<;o/Yc200;o/Yc21?naV/03okShkP;oaNK^0_nJPKL3oiJ7`@03oiej
ZonKO;3oVgb`00?oVgb`1?nJP[P4oiR8`@;oUi7;0_nRTL<4oj2Fb@;oWY_A00?o0000oijKdOnNVm40
0_nMXMP2ojBPd@GoXjGG1?nRZmd2oj6`h`;oZ;OS1OnW^nLEooooo`03o`000?oooooooooo02Kooooo
000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A005ooooo`03o`000?oooooooooo01Gooooo00?oY8nooj:<_?nRS;`00_nRS;`4oj28^PCo
WhFg0onMP[D01?nLOk?oV7bcoiQl/onHO;<4oiIj/@?oUGR`1?nCMZl3oi9c[P?oT7:]1On?L:`3ohm`
Z`?oSfn[0_n@KjX2oi5n^P?oU7nj1OnFPKX3oiR1^0CoVH2f1OnIOkD3oiUm/`;oV7bb0_nPV/h5oj6I
c@CoXY[=0_nSW<d3oi[/n1?oT6>J0ol00004oi1SVP?oSf>J1?n?Hi/2ohmTW003oiI/XOnHKZ;oV6jR
00;oV6jR1OnILJ<3oi]cY0GoWGFU0_nMMZH2ojR8/`CoYH>_1?nROjd5oj5m[003oj1m[OnbWlGo/Yo5
00;o/Yo51?nbW<800onaV/3o^?S^okShkP02okShkP03oiem[onJPKOoVX6g00;oVX6g00CoUXO1oiej
ZonMNZ_oWGZ[1OnKO;04oiZ2^0?oV8S100?oYHjloj:A`onRTL<00onRTL<4oj2Fb@;oWY_A00?o0000
ojJLc?nTX=401?nTX=44oj>Ue`;oXZ_M0_nY/ml5ojRgh`;oYk_W0on/`>PDooooo`03o`000?oooooo
oooo02Kooooo0006ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RH
ob4Q8Oo^k^h01_ooool2o`0001Gooooo0onTSkl3oj:<_0CoX8Rj1?nOQKL2oif2]@03oiUo]OnHO;?o
V7bc00;oV7bc1?nFN[43oiEh/0CoTgJ_0onBLjh4oi1b[@CoSg2/0on?L:/2ohm_Z`03oi1l^OnAO[[o
TGjj00;oTGjj1?nDOkX4oiJ1^P?oV86h1OnIP;H4oiUo]@;oVGfc00?oWi_@oj2Jc_nPV/h00onPV/h4
oj6Ic@?oXY[=1?nAj_L00onJk?SoT6>Joi1SVP0@oi1SVP;o00001on@HiX3ohmSVPCoSf>K00?oSfBL
oiI/XOnFK:401OnHKZ84oiUaX`CoVg>T1?nMMJD00onMMZKoZ8RcojR8/`02ojR8/`?oYH>_1OnROjd3
oj5m[003ok:TbOnbWlGo/Yo500?o/Yo51?nbW<82oh?W``03okShk_nMOJooWGf_00;oWGf_0_nJPKL0
0onPNJOoWGZ[oiejZ`03oiejZ`CoVgb`1?nJP[P00onHR<7oYHjlojF>_002ojF>_0CoXY731?nPU/T0
1OnNVm7oYYc<ojJLc?l0003oYYc<00CoY:3A0onSYML00on[/=coZK?OojVcg`03ojVcg`?oZ;OS0_n]
_nL5ojc0j1Cooooo00?o0000ooooooooool09Oooool000kooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool04Oooool2ojJD``CoY8no1?nR
S;`3oj28^P;oWhFg0_nJP[P3oiUo]@CoV7bc1?nFN[43oiEh/0CoTgJ_1?nBLjh3oi1b[@;oSg2/0_n?
NKH3ohmj^0CoT7bi1?nAO[X3oiAo^PCoUX6j1?nHPKP4oiV0]P;oVGne0_nNWM<4oinKd0CoX9[>1OnQ
VLd01?nRV/goTN[goi7ZmonAj_LBoi1SVP?o00002On@HiX3ohmSVP;oSf>K0_nDJj03oiI/X@GoV6jR
1?nILJ<4oi]cY0?oWGFU00?o[I2hojR8/onXR;<00onXR;<3ojF3[`GoXWn]00?oXGf/ok:TbOnbY<T0
0_nbY<T4ok:Oa@?o/Yc200?oPnO3oj1kZOnPNjT01OnMOJl01?nJPKOoX7VWoj1iYonPNJL4oiejZ`Go
Vgb`0_nJP[P00onXS;SoYHjlojF>_003ojF>_0CoXY730onPU/T00onYV/OoYYc<ojJLc002ojJLc003
o`000?nTX=7oY:3A00?oY:3A00CoXjGGoj^`g?n[/=coZk3L1OnY/ml00onX]n?o[KoWojfoi`02ojfo
i`;o[<3X0_n^a>XEooooo`03o`000?oooooooooo02Cooooo000>ooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo00kooooo00?oZ9[7ojJD
`onVU<<00onVU<<3ojB?_`CoXXbl0_nPR;X00onKQK[oVX:hoiZ2^002oiZ2^0CoVGne1?nHO;<3oiIj
/@CoUGR`0onCMZl4oi9c[P;oT7:]00?oT7Veohmi]_n?NKH00_n?NKH4ohmj^0?oT7bi1?nAO[X3oiAo
^PGoUX6j0onHPKP2oiV0]P;oWIoE1OnNWM<3oinKd0GoX9[>0_nQVLd2ohWWmP03oi5UVon@I9[oT6BJ
00;oT6BJ3_n@HiX3o`0000coT6>J0_n?HiX00onCJIooU6^PoiA[X002oiA[X0CoUVbQ1?nHKZ84oiUa
X`CoVg>T00CoWGFUojf@^?n]T;So[I2h1OnXR;<4ojF3[`?oXWn]00?o/Z_@ok:TbOnbY<T00onbY<T5
ok:Oa@03ok:L`_nRNJGoX7^Y00;oX7^Y1?nMOJl00onTNjKoX7VWoj1iY`02oj1iY`CoWGZ[1OnKO;00
1?nJP[SoZ8bhojR<^?nXS;P4ojF>_0GoXY7300CoX9K9ojVJaonYV/OoZI[70onVW<`01?l0003oYYc<
ojBPdOnTX=42ojj_f0GoZk3L0_nY/ml2ojnoiPCo[KoW00?o[lK[ojk4j_n^a>X00on^a>XCooooo`;o
00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`02Oooool000kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooo
oooo00?ooooo0_l0000>ooooo`?oZ9[71?nVU<<4ojB?_`;oXXbl00CoW8Rnoi^5^_nKQK[oVhFj1OnJ
P[P3oiUo]@CoV7bc1?nFN[43oiEh/0;oTgJ_00?oTWZeoi5i]OnANKD00_nANKD3oi1i]@GoSgVf0on?
N[P3oi1l^@CoTGjj1?nDOkX4oiJ1^P;oV86h00?oVj3GoifOeOnMWmD00onMWmD4oijMd`CoWi_@0_nP
V/h3oh;Sm`CoTFFK1?n@I9X;oi1SVP?o00003_n@HiX01?nBJIooTfVOoi=YWonCJIl4oiA[X0CoUVbQ
1?nHKZ85oiUaX`?oVg>T1On]T;P4ojR8/`CoYH>_00?oXWn]ok:[d?nbZm000_nbZm04ok:Tb@Co/Yo5
0onRNJD4oj1kZ@;oWGf_0_nTNjH4oj1iY`CoWGZ[1?nKO;000on/SKGoZ8bhojR<^002ojR<^0GoYHjl
0_nRTL<2ojbJa0CoZI[71?nVW<`00ol0003o[ZoHojj_f003ojj_f0?oZk3L0_na`NH4ojnoiP03ojfo
ion_a^_o[lK[00;o[lK[0on^a>X2ojg6k1Cooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B402Oooool000ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool2
o`0000gooooo00?oZZ3<ojRJaonXV/L00_nXV/L4ojJD``CoY8no00CoXXbloib8__nLR;koW8Rn0onK
QKX4oiZ2^0?oVGne1?nHO;<4oiIj/@;oUGR`00CoTg^foi9j]OnBN[GoTWZe1?nANKD4oi1i]@CoSgVf
0on?N[P4oi1l^@CoTGjj0onDOkX2oiJ1^P;oVIoH1?nKX=L4oifOe@GoWYgC0_nOVm04ogkOn@03oh;S
monBIYcoTVJL00?oTFFK1?n@I9X8oi1SVP?o00003on@HiX3oi9YW`?oTfVO1OnDJj03oiI/X@CoV6jR
1OnILJ<2oi]cY0;o/IRm1?n]T;P5ojR8/`;oYH>_00?o/kKKok:[d?nbZm000onbZm05ok:Tb@03ok:O
aOnTNJ?oXWVU00?oXWVU1?nPNjT00onMOJooY7^VojAkYP02ojAkYPCoX7VW1?nMNZ/2oi]l/0?o[8fe
0onXS;P4ojF>_003ok6Na?n/V/Co[9[400;o[9[41OnYV/L01OnVW<co/JoGok6_eona[mOo000000Co
[ZoH00?oZk3Lok71i_na`NH00ona`NH2ojnoiP;o/<W]1On_a^/00on^a>[o[LK/ojg6k002ojg6k1Co
oooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooo
ooooooooooooo`000009ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`03o`000?oooooooooo00Wooooo00?o[JOAojZPc?nZX<`00_nZ
X<`3ojRJa`GoYYC30_nTSkl00onMS<7oW8Rnoib8_P02oib8_P?oVhFj1?nJP[P4oiUo]@?oV7bc0_nF
N[42oiAm]`?oTg^f1?nBN[D4oi5i]@?oT7Ve1?n?NKH4ohmj^0?oT7bi1?nAO[X2oiAo^P03oiRMeonI
WmSoVIoH00?oVIoH1?nKX=L4oifOe@;oWYgC1?mng?`2ogkOn@03oi=WWOnBIYcoTVJL00;oTVJL0onA
II/4oi1TVPGoT6>J0ol0000@oi1SVP03oi9XW_nBJIooTVVO00;oTVVO1?nCJIl4oiA[X0?oUVbQ1OnH
KZ84oiUaX`04oi]cY?naV;go/IRmok6H_@Co[I2h1OnXR;<01?nUPjoo/kKKok>ffonc]]/5ok:[d0;o
/ZC91?nTNJ<4oj9iY@CoX7^Y1OnTNjH4oj1iY`CoWGZ[00?oVgb`ojb=]On/SKD00_n/SKD4ojR<^0;o
YHjl0onaW/@4ojbJa0?oZI[700?o]K?Gok6_eona[mL00ona[mL00ol0003o[ZoHojj_f002okG7j0Co
/L7V00?o/<o`ok39kOn`bNd00on`bNd2ojo6j`;o[/__1?n]a^`00onYa>goooooooooo`0Booooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9Sooooo
oiRHV?lb<S802Oooool002Oooooo00?o0000ooooooooool01oooool4ojfWd@?oZZ3<1?nXV/L2ojJD
``;oWi751?nMS<43oib8_P?oVhFj1OnJP[P3oiUo]@;oV7bc00?oUGnioiAm]onDOKL00_nDOKL4oi=k
]P?oTWZe1?nANKD3oi1i]@GoSgVf0on?N[P2oi1l^@03oiJEd?nGVMCoUiWD00;oUiWD1?nHWML4oiVO
f0GoVj3G0_nMWmD4oh;IoP;oO]cl00CoTfVNoi=WWOnCIigoTfNM1?nBIY`4oi5UV`?oT6BJ0_n@HiX3
o`0000ooT6>J1OnBJ9h5oi9YW`?oTfVO1?nDJj03oiI/X@GoV6jR0onILJ<00oncWl?o/IRmok6H_@02
ok6H_@Go[I2h0onXR;<00ondb>Wo/kKKok>ff`02ok>ff`Co/Z_@00?oTFNNojEiX_nUNJ801?nTNJ<5
oj9iY@;oX7^Y00?oZGnWojAkY_nTNjH00onTNjH4oj1iY`CoWGZ[1On/SKD4ojR<^003ojF>_?naW/Co
/Ik400;o/Ik41?n/V/@00onYV/Oo]K?GokFce`02okFce`Co/JoG00?o0000okG7j?neanP00oneanP0
0ona`NKo/<o`ok3?l002ok3?l0;o/<W]0_n/d?<5ojk;k`03ojg6k?nYa>goZLC]00;oZLC]5?ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`00
0?l0003oc<c<00Wooooo000Wooooo`;o00001_ooool00on`[mOo[JOAojfWd@03ojfWd@CoZZ3<0_nX
V/L00onPUl[oWi75oinAa@03oinAa@?oWHc11?nLR;h3oi^5^PCoVX:h0_nIOkD01?nEPK_oUGnioiEo
^OnEOkT5oiAm]`?oTg^f0onBN[D4oi5i]@CoT7Ve1?n?NKH2ohmj^003oiJAc?nFUM3oUYG@00;oUYG@
1?nGVM@4oiRMe`CoVIoH0_nKX=L4ohSDo`;oP]Wn00?oU6^Poi=YW_nCJIh00_nCJIh3oi=WW@CoTVJL
1?nAII/3oi1TVP;o00003_n@HiX9oi9XWPGoTVVO0onCJIl4oiA[X0?oUVbQ1OnHKZ800onILJ?o/io3
ok>O``02ok>O``Co/IRm1?n]T;P00onXR;?o]<SYokC8j@02okC8j@Co/kKK00?o/Z_@oi=VVonAIih0
0onUNJ84ojAiX`GoXWVU00CoX7^YojUoYonYOjOoZGnW1?nTNjH5oj1iY`;oWGZ[0_n`SkD5ojb=]@;o
Z8bh00?o^:K7ok6Na?naW/@00onaW/@3ojbJa003okVjf_ne/mOo]K?G00Co]K?G00Go/JoGokO@k?ng
d>co]m3/o`000003okG7j003ok3Gm?n`co3o/<o`00;o/<o`0_nYe_L4ojc@l`;o[/__0onXb?04ojW4
kAGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@
okZj^_oooooo^[Zjoa0@4009ooooo`009oooool00ol0003oooooooooo`04ooooo`?o/:oG1On]Ym42
ojZPc003oj:MconPUl[oX9O:00;oX9O:1?nOTLD3oif<`@CoW8Rn0onKQKX2oiZ2^0;oUXBm1?nEPK/3
oiEo^@CoU7fg0onCNkH4oi9j]@CoTGVe0on@NKD2ohmi]P;oUXk91?nFTL`4oiJEd0CoUiWD1?nHWML2
oiVOf0?oSm3m0_n8e?l2oiA]X`?oU6^P1?nCJIh3oi=WW@CoTVJL1?nAII/3o`0000goT6>J3OnBJ9h4
oi9YW`?oTfVO1?nDJj04oiI/X@?oV6jR00?o]:C8ok>O`oncWl<00oncWl<4ok6H_@;o[I2h0onah_P5
okC8j@;o/kKK0onCIY/5ojEiXP?oY7VS1OnRNJD4ojUoY`CoY7^V1OnPNJL01?nMNZ_o/8neok2?]On`
SkD5ojb=]@04ojR<^?nhY/Oo^:K7okRVa`Go/Ik400Co[9[4okVjf_ni^][o^K[J1?ne/mL00onhh??o
]m3/okO@k003okO@k003o`000?n`eoCo/=Od00;o/=Od00?o/<o`ojWFmonYe_L00onYe_L2ojc@l`;o
Y/_c1OnXb?02ojW4k@;oY/7]4_ooool3o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooookZj^_l000002Oooool002Oooooo00?o0000ooooooooool00_ooool00onb
^=go/:oGok2_e`03ok2_e`?o[JOA00?oY:CFoj:MconRWLl00_nRWLl3oj2GbPCoWi751?nMS<42oib8
_P04oiJ:a?nFQ/7oUXK1oiJ6`@GoUXBm0onEPK/3oiEo^@CoU7fg1?nCNkH3oi9j]@CoTGVe0_n@NKD0
0onFS<OoUXk9oiJ>b@03oiJ>b@?oUY7<1OnFUM02oiNIe0;oW<Ge1OnFb_X2oho@o@03oiA_YOnDKJ?o
U6fS00;oU6fS0onDJj04oi=YWPCoTfNM0onBIY`01?nAII_o0000o`000?l00004oi1TVP_oT6>J3_nB
J9h4oi9YW`?oTfVO1?nDJj04oiI/X@;oV6jR0ondY<P4ok>O``?o/IRm0_nGl>h5ok7Rn0;o]<SY1?nD
IYT3oi=VV`GoYGVR1?nTNJ<3oj9iY@03ok28ZonYOjOoZGnW00;oZGnW1OnTNjH3oj1iY`03okBE]on`
SkGo/8ne00;o/8ne1?n/SKD00oo3^M3o^:K7okRVa`02okRVa`Co/Ik400?o_lWRokVjf_ni^]X00oni
^]X00one/mOo^>3cokSPl`02okSPl`;o]m3/0_nZgoX01?l0003oZ]ojok3Gm?n`eo@3oj?Ln`;oZMKg
0_nSc_H5ojK;l`;oZ<S`0_nU`nl5ojK1kACooooo00Wo0000ooooooooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Wooooo000Vooooo`?o000000?o]L?T
ok:hgOnb^=d00_nb^=d5ok2_e`04ojfWdOnTY=KoY:CFojBTeP?oXYg?0onPUlX5oinAa@;oWHc100?o
Uhg8oiJ:a?nFR/@00_nFR/@3oiJ6`@CoUXBm0onEPK/3oiEo^@GoU7fg0onCNkH2oi9j]@03oiF:aOnF
RlGoUX_500;oUX_51?nFS<L4oiJ>b@CoUY7<0_nFUM03oio2l@CoW<Ge0_nFb_X2oiAaZ0CoU6nU0onD
KJ<3oiA[X0CoTfVN1?nCIid01?nBIYco0000o`000?l00003oi5UV`CoT6BJ2?n@HiXAoi9XWPCoTVVO
0onCJIl5oiA[X0?oUVbQ00?oV6jRokBTb?ndY<P00_ndY<P5ok>O``03ok6H_OnGl>koUo3^00;oUo3^
0_nah_P3oiMWV@GoU6JI0_nCIY/00onUNJ?oYGVRojEiXP03ojEiXPCoY7VS0_nRNJD3ok28Z`?oZGnW
1OnTNjH2oj1iY`;o]9Fg1On`SkD2ojb=]@;o`kW@1OnhY/L00onaW/Co_lWRoko9hP02oko9hP?o^K[J
0on[koL2okSPl`?oV^Ol0_nZgoX00onFgoko0000oiKOoP02oj?Ln`;oWLoi1OnSc_H2ojK;l`;oXl?`
1OnU`nl2ojK1k@;oY;k/5Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003o]L?TokG3
i002okG3i0Co/[SM0_n`[mL2ojJ/g0CoY:CF0onRWLl4oj2GbP;oWi750_nGT/`4oiN=b0?oUX[40onF
Q/44oiJ4_@CoUH6k0onEOkT4oiAm]`;oTg^f00?oU8[5oiF:aOnER/D00_nER/D4oiJ;a@?oUXc71?nF
S/T3oiJAc003oj70konO`_7oWl;a00CoWl;a0_nLaOD00om1`K?oU7>[oiAaZ003oiAaZ0?oU6nU0onD
KJ<4oiA[X0?oTfVN0_nCIid3o`0000?oTVJL0onAII/4oi1TVPGoT6>J00?oTFRNoi9XW_nBJ9h04OnB
J9h4oi9YW`?oTfVO1OnDJj02oiI/X@03ok:Vc?ndY<So]:C800?o]:C81?ncWl<01?mJcZooVFVIoiUY
VOnIJIT4oiQXV@CoUfNI1?nDIYT01?nCIY_oYGVSojEiXonUNJ<4ojEiXPCoY7VS00?oXWVUok28Zon`
R:/00_n`R:/3ojUoY`GoY7^V00CoX7VWokBE]ondUKOo]9Fg1On`SkD00on/SKGo`kW@ol>id002ol>i
d0?o^:K70_noh?04oko9hP04okVjf_n[koOoZnogoj__m`?oMN3_0_nJio`3oh?Lo@;oU]on00?oUlkk
o`000?nGc_/01?nMcoT2oj?>mP?oXL;`1?nS`o02ojG3k`?oXkk/1?nT_^`Dooooo`03o`000?oooooo
oooo01kooooo000Kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooookG3i003
okG3i0;o/[SM0_nW]^<4ojJ/g0CoY:CF0onRWLl2oj2GbP03oiRGdOnGT/coUi;<00?oUi;<0onGSLP3
oiJ:a0?oUXK11OnFQ;d3oiF1^`?oUGni0_nDOKL2oiB:a`CoU8[50onER/D4oiJ;a@?oUXc71OnFS/T0
1?nFTLcoXL3_oj70konQ`>l4oio2l@;oB/Rm0onDLj/4oiAaZ0?oU6nU1?nDKJ<3oiA[X0;oTfVN0ol0
0002oi=WW@CoTVJL0onAII/4oi1TVP;oT6>J00CoTFROoi5XW_nAJ9koTFRN4onBJ9h4oi9YW`CoTfVO
1?nDJj001?nFK:7o/ZK<ok:Vc?nbY/`5okBTb003ok>O`onJJi[oVV^J00CoVFVI1?nHJ9T4oiMWV@?o
U6JI00?oYGZTojEiXonUNJ<00_nUNJ<4ojEiXPCoY7VS1On`R:/4ojUoY`?oY7^V00?o^YnmokBE]ond
UKL00ondUKL3ok2?]@03oloLhoo3^M3o`kW@00?o`kW@00?o^:K7okoPl?noh?000onoh?02oko9hP03
og?Re?lj_l[o>[o:00;o>[o:0_meh>l3og3Dn`;oPmcm0_nAbO/3oiO>n`04o`000?nGc__oWLoioig?
n@;oW[o`1OnQ`_02oj?3l0;oX[g/1OnS_^`2ojBnk0;oY;g[5?ooool00ol0003oooooooooo`0Moooo
o`006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool00_ne`n@00onX
`>_oYkKSojNfh`03ojNfh`CoYZcL0_nTY=H01?nIXmcoV9cFoiRLe_nHW=H4oiRGd@CoUi;<0onGSLP4
oiJ:a0?oUXK11?nFQ;d2oiF1^`04oi:=b_nCRlSoTh_8oi>;b0GoU8[70onDR/D3oiF:a@CoUX_51?nF
S<L2oiJ>b@?oXKo^1?nQ`>l00onO`_7oB/RmoiEe[@02oiEe[@?oU7>[1?nDLJP3oiA_Y@CoU6fS0_nD
Jj03o`0000;oTfVN0onCIid4oi9VW0?oTFFK0_n@I9X5oi5XW`?oTFRN4onBJ9h5oi9YW`?oTfVO0onD
Jj000on_YLko/ZK<ok:Vc002ok:Vc0Co]:C800CoVVbLoiY[V_nJJi[oVV^J1?nIJIT4oiQXV@CoUfNI
0_nDIYT2ojEjY0CoYGVS1OnUNJ83ojAiX`Go/8R[1?nYOjL2ojAkYP?o^Ynm1?ndUKL2ok2?]@?ocmcS
0oo3^M02oikbk`Co_n3`00?o0000ofk0o_m^`?h00_m^`?h4ofG9o0;oL=Ck0on?`oP4oi79n`;oUlkk
00?o0000oibkk_nN_o001?nN_o02oj72l0;oX[_[1OnR_N`2oj>nk0;oXk_Z1OnT_N/Cooooo`;o0000
7_ooool001_ooooo00Go410@oooooooooooooooooa0@4006ooooo`;o00000_ooool3ojS0j`GoYkKS
0_nV[=`00onIZn?oVJ?LoiVSg002oiVSg0?oV9cF1?nHUm43oiNBc0CoUhg80onFR/@2oiJ6`@03oi2@
conAS/goTHk=00;oTHk=1?nBSLX3oi>;b0CoU8[70onDR/D4oiF:a@CoUX_50_nFS<L3oijok`CoXKo^
0_nQ`>l3oiMh[`?oUGF]1?nDLj/3oiAaZ0?oU6nU0onDKJ<3o`000003oiA[X?nCJIkoTfVN00;oTfVN
0onCIid4oi9VW0;oTFFK00?oTFRPoi5XWonAJ9l01OnAJ9l4oi5XWQ;oTVRN1OnBJIl3oi=YW`03oiA[
X?n_YLko[jG>00;o[jG>1?nbY/`01?ndY<SoVVbLoiY/W?nJK9`3oiY[VPCoVFVI1?nHJ9T4oiMWV@04
oiAVVOnUNZCoYGZTojEjY0CoYGVS1OnUNJ82ojAiX`;o_9Zd1?n`R:/4ojUoY`03ojAkY_njWkgo^Ynm
00;o^Ynm1?ndUKL00on`SkGocmcSoloLh`03oloLh`03ol>id?nNl^ooW_;_00;oW_;_00?o_n3`ogf`
m?mm/?@00_mm/?@2ofk0oP;oUjgV1OnA^?42oho3n003oif]h_nK/nWoVk?Y00?oVk?Y0_nL^nh01?l0
003oW;_^oijol?nN_o03oj6gj0CoX[_[0_nR_N`3oj>ij0CoXk_Z0_nT_N/2ojFmja;ooooo00?o0000
ooooool000007_ooool001_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo00;ooooo0onX`>/2ojNfh`;oVK?Y1?nIZn<3oiVSg0?oV9cF1OnHUm43oiNBc0;oUhg800CoSiKF
oi2Cd_n@Tm;oT9?B1?n@T<l4oi6>c@?oTXg:0onCRlP4oiB:a`CoU8[50onER/D2oiJ;a@?oVkoa1OnN
_nl2oj6okP?oVGba0onGN:l3oiEe[@CoU7>[0onDLJP4oiA_Y@;o000000CoU6fSoiA[X?nDJj3oU6^P
1?nCJIh3oi=WW@;oTVJL0_n@JJ43oi5XX0SoTFRO0onAJ9hCoi9XWPCoTVVO0_nCJIl00on[X/ko[jG>
ojnUcP03ojnUcP?o/ZK<00?oVVfMoiY/W?nJK9`00_nJK9`3oiY[VPCoVFVI1OnHJ9T3oiMWV@GoYGZT
0onUNJ<5ojEiXP04ojAiXonlV[Co_9ZdokbJ]0Go/8R[0onYOjL5okZO_@?o]9Fg0onVmlh2oloLh`Co
V9K@0on=XN800onSW<koWJ?IoifSf@02oifSf@GoUjgV0_nA^?42oinUfPCoWJgR1OnK/nT2oibkkP03
o`000?nR/nGoXKOX00CoXKOX0_nR^n/00onT]nKoXkWXoj>ij004oj>ij0;oXk_Z00?oYK_YojFmjonU
_N/00onU_N/Dooooo`03o`000?oooooooooo01_ooooo000Kooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`03ooooo`CoV;c`0onI/nT4oiV[h`?oVJ?L0onHW=H2oiRGd@;o
SIcM0on>VMT4ohnFeP?oT9?B0on@T<l4oi6>c@?oTXg:0onCRlP5oiB:a`;oU8[50_nB__D4oiNol`Co
Vkoa0_nN_nl3oib0]0CoVGba0onGN:l3oiEe[@CoU7>[1?nDLJP3o`0000?oU6fS0onDJj04oi=YWP;o
TfNM00?oT6VRoi1YXOn@JJ400_n@JJ43oi5XX0SoTFRO0onAJ9hCoi9XWP?oTVVO00?oZ9o=oj^Rc_n[
X/h00_n[X/h5ojnUcP03ok:Vc?nJKIgoVVfM00CoVVbL0onJJiX5oiUYV@CoV6RI0_nGIiT00onUO:Ko
YGZTojEjY003ojEjY0?oYGVS1OnUNJ84okbJ]0Go/8R[0_nYOjL2ol:dc@Go^Ynm00Co]9FgojKgc_nV
mlkoY_O>0onOTLD4oiRFd003ohfQh_nSW<koXic>00;oXic>1?nMXmT2oiN]iP;oXj7C1OnOYMX4oif]
hP;oVk?Y0_nS[n02oj:ci@03o`000?nR/nGoX[?U00;oXKOX0_nT/n<4ojBgiPCoXkWX00?oY[[WojFk
jOnU^nT00_nU^nT3ojFmj`03ojNnj_oooooooooo01?ooooo00?o0000ooooooooool06_ooool001_o
oooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo00Gooooo1?nH_?03oiVc
j@;oVJ_S00CoRZ[[oh^Ui_n;YNKoRjGV1?n<X>84ohfLg@?oSYWI0on?U]H3oi2CdP?oT93?1OnAS/d3
oi:=bP?oTh_80_nDR/L3ohfmmPCoT[ke1?nG_o<2oi^ol@?oX8Fg1?nLP;@3oiUl/@?oUgR_1?nEMJd3
oiAcZ`04oiAaZ?l0003o0000o`0000?oU6nU0onDKJ<3oiA[X0;oTfVN0_n>JJ<3oi1YXPCoT6VQ1?nA
J:07oi5XW`?oTFRN4onBJ9h00onBJIooZ9o=ojROc@02ojROc@CoZj;>0_n_YLh2oiY^W`?oVVfM1?nJ
K9`3oiY[VPGoVFVI1?nHJ9T00onGIiWoYGbVojElYP05ojEjY0CoYGVS0onUNJ82om2nb@?o_9Zd1On`
R:/01?nYOjOo`[C=ol:dcOo2]<d4okZO_@GoYY2m1?nOTLD2oiRFd003ojRIaonSW<koXic>00?oXic>
0onMXmT00onXWlgoXj7Coj>Qd`03oj>Qd`CoWjGJ0_nM[N82ojF[f`GoXjoP0_nR/nD00ol0003oY[7P
ojBch`04ojBch`CoY;OV00?oXkWXojJjionV^^L00_nV^^L4ojFkj@04ojFmjonW_^[oYkkZojNnjQCo
oooo00?o0000ooooooooool06_ooool001_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
00001oooool2oiRll003ohJfm?n8/?3oR;3`00;oR;3`0on:Z^/3oh^UiPCoS:3R0on=W=d3ohjIf@Co
SiKF0on@Tm83oi2@c`;oTHk=0_n4]OD4ohJhmPCoRK[f1?n=_OH2oi:nm@?o9[2f1?nTRkX3oj25]`Co
W82d1?nIO;43oiMh[`?oUGF]00CoU7>[o`000?l0003o00000onDLJP2oiA_Y@04oh]ZYon<JJKoS6VV
ohaYYP?oSFVT1?n>JJ<3oi1YXPCoT6VQ1?nAJ:07oi5XW`?oTFRN4OnBJ9h2ojFKc0GoZ9o=0on[X/h5
oiY^W`?oVVfM1?nJK9`3oiY[VPGoVFVI0onHJ9T00onUOj[oYGbVojElYP02ojElYPCoYGZT1?nUNJ<2
ojEiXP?od;k91?nlV[@3ok28Z`03olKNj_o2]<go`[C=00?o`[C=00Co^Ynmoj^A^_n[TK[oZi6j1?nV
T;d3oinAa@03ojbH`_nXVLOoZ9W700;oZ9W71OnSW<h01?nMXmWoZ9o=ojROcOnXWld5oj>Qd`;oWjGJ
00?oZ:SFojF[fonUZm/00onUZm/3oj>_h006ojR_gOnV/N3oY[7PojJah?l0003oY[7P1?nT/n<2ojBg
iP;oYkSU1OnV^^L2ojFkj@;oYkgY1OnW_^XDooooo`03o`000?oooooooooo01Wooooo000Kooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`07ooooo`?oQ[Kd1?n8/?03ohZZ
j`?oRjGV1?n<X>83ohfLg@?oSYWI0_n?U]H00omo[o?oP;3coh2`l`03oh2`l`?oP[;d0on4]OD4ohJh
mPCoRK[f0_n=_OH2ok^kf@03okVfe_nWTKkoYi6n00;oYi6n0onTRkX3oj25]`CoW82d1?nIO;43oiMh
[`04oiEe[Ol0003o0000o`0000;oS6bY1?n;JjP3oh]ZY`?oS6VV0on=JJ@4ohiYX`CoT6VR0on@JJ44
oi5XX0OoTFRO0onAJ9h>oi9XWP03oj>IbonUVlcoYI_<00?oYI_<1OnXWld00on[X/koV6jPoiQ^X004
oiY^W`?oVVfM1?nJK9`4oiY[VPCoVFVI0_nHJ9T2ojEoZPCoYGbV1?nUNZ@4ojEiX`03ojEiX_o@_/Wo
d;k900;od;k91?nlV[@00on`R:_oa]kZolKNjP02olKNjP?o`[C=00?o[iBjoj^A^_n[TKX00_n[TKX4
ojJ@_@03oinAaOn/V<;o[9S200;o[9S21?nXVLL2oj>LcP;o[Io91?nXWld4oj>Qd`03ojbWdonXZ=Ko
Z:SF00;oZ:SF1OnUZm/01?nS[n3oZ:oMojR_gOnX[md3ojJah003o`000?nT/n?oY;?S00?oZ;KS1?nW
^>D2ojJji`?oZ;cW1?nW_NT2ojNnjP;oZ;oZ5?ooool00ol0003oooooooooo`0Iooooo`009Oooool0
0ol0003oooooooooo`08ooooo`?oQ[Kd0_n8/?02ogR^m@?oNJkd1?mj[O<3og^]l`?oO:gb0omm[O83
ogn_l`GoP;3c0on2/_@3ohBem@;oQ[Sf0oln`Md2okfof`?o^k_I00?oZiS2ojNA__nWTKh00onWTKh3
ojB;^PCoX8Fg0onLP;@2oiUl/@;oTW>]00CoT72[o`000?l0003o00000_n>KZX3oha/Z@CoRf^X0on;
JZL3ohaYYP?oSFVT1?n>JJ<4oi1YXP?oT6VQ1?nAJ:07oi5XW`?oTFRN2onBJ9h00onRV<[oXiW;oj>I
b`02oj>Ib`CoYI_<1?nXWld4oiQ^X0CoVVjO0onJKId4oiY/W0CoVV^J1?nIJIT01?nHJ9WoYGnZojEo
Z_nUOjX4ojElYPGoYGZT0onUNJ<00ooAomOod;k9om2nb@03om2nb@;o_9Zd0omMd[T4olKNjP03ol:d
cOn_U;[o[iBj00CoZi6j0onVT;d00on`V/7o[9S2ojbH`P03ojbH`P?oZ9W700?o/Z?9ojfObOn]WlT0
0on]WlT4ojROc@03oj>Qdon/Ym?o[:OC00;o[:OC1?nXZ=H2ojF[f`;oZjoJ1OnX[md2ojJah003o`00
0?nY]^7oZ;KS00CoZ;KS0_nW^>D2ojVkiPGoZ;cW0_nW_NT2ojVoj@CoZ;oZ4_ooool00ol0003ooooo
o`00000Jooooo`009Oooool00ol0003oooooooooo`0:ooooo`?oN;3f0omh[_D3ogV^m0CoNZgc0omk
[O<3ogb]lP?oOJgb0omo[o<2oh2`l`CoF/Ki0_mBao<4ol7Rk`03okk2gOnm_m_o_KoK00?o_KoK00Co
^k_Ioj^H`_n[V<;oZiS21?nWTKh4ojB;^P?oX8Fg0_nLP;@00onDMZooTW>]oi9c[@03o`0000;oT72[
1?n>KZX3oha/Z@?oRf^X0on;JZL4ohaYYP?oSFVT0on>JJ<4oi1YXPCoT6VQ0onAJ:07oi5XW`CoTFRN
2?nBJ9h4oj:HbP?oXiW;1OnUVl`01?nXWlgoUVfQoiI]XOnFKJ43oiQ^X0CoVVjO0onJKId5oiY/W0?o
VV^J0onIJIT00onUQ;3oYGnZojEoZP02ojEoZPCoYGbV1OnUNZ@2ojEiX`?odOoG0_o@_/T2oj^=]PCo
ZXbf1?nWS;T5ojnD^PCoZi6j00CoYY2mok2J`On`V/7o/9[11On/V<801?nXVLOo/Z?9ok:SbOnbXlT5
ojfOb@;oZ9o=00?o/:WAojbWdon/Ym<00on/Ym<2ojRXeP;o[[3I1On[[mX2ojR_g@;o[;KP0onY]^40
1?l0003oZKKQojRfhonX]^<2ojZki@GoZK_V0_nX_>L2ojVnj@GoZKoY0_nX_nX2ojW1jQCooooo00?o
0000ooooooooool05oooool002Gooooo0_l0000<ooooo`?oN;3f0omh[_D3ogV^m0;oNZgc0_m]]_/3
ofZio@GoIkgn0omT`Oh3of34o0;oF/Ki00GoW_?]ol3Nkoo0g^oo`=k_ol7Rk`04okk2g@?o_KoK00?o
[ik6oj^H`_n[V<800_n[V<85ojNA_P?oY8^j0_nPQKL01?nGN[7oU7J_oiAf[onDMZl2o`0000;oTW>]
0on@L:/4ohi^ZP?oS6bY0on;JjP3oh]ZY`CoS6VV0on=JJ@3ohiYX`CoT6VR1?n@JJ43oi5XX0SoTFRO
0onAJ9h6oi9XWP03oj6Gb_nRV<[oXYS:00?oXYS:1?nSVL/2ojFKc0;oU6^Q1?nFKJ43oiQ^X0CoVVjO
1?nJKId4oiY/W0?oVV^J00CoVFVIojF4/?nUQ;3oYHB`1?nUOjX4ojElYPGoYGZT00GoYGVSom7oeooA
omOoY8Baojb?]`04oj^=]PGoZXbf0_nWS;T2ok>I_@Co[iBj0on[TKX00oncW/?o/9[1ok2J`@02ok2J
`@Co[9S200?o]ZS;ok:SbOnbXlT00_nbXlT4ojfOb@03ok>/dOn`ZM7o/:WA00;o/:WA0on/Ym<00ona
/]Wo[[3Iojj`f@03ojj`f@?oZjoJ00?o[[OOojbfh?n/]^000on/]^03ojVfh@03o`000?nZ^nGoZ[_U
00?oZ[_U0_nY^nH2ojZnj0GoZKkY0_nY_nT2oj[0jPGoZL7Z4oooool00ol0003oooooooooo`0Goooo
o`009?ooool00ol0003oooooooooo`0=ooooo`?oM:kf1?mb/OP3ofncnP?oKKKk0omZ^Od2ofNmoPCo
BlC^0_li_M/2og;Qi@;oYo7f0oo0g^l3oko4gPCo_/;M00Co_KoKojnNa_n_W/Ko[ik60on[V<85ojNA
_P;oY8^j00CoVGjdoiMj/OnGN[7oUgZa0ol000001?nDMZooTW>]oi9c[OnBLjd3oi1`Z`CoSVjZ0on<
K:T4oh][Z0?oRfZW0on<JJH3oheYY0CoSVVS0on@JJ84oi1YX@?oTFRP2?nAJ9l3oi5XWP;oTVRN0_nQ
V</4oj6GbPCoXYS:0onSVL/2oi5XX0?oU6^Q1?nFKJ43oiQ^X0CoVVjO1?nJKId4oiY/W0;oVV^J00?o
YXZgojF4/?nUQ;000onUQ;04ojEoZPCoYGbV0onUNZ@2ojJ5/@;oY8Ba0_n/SkL4oj^=]PGoZXbf00Co
Yhbiok>I_OncVKgo/iVm1?n_U;X00on[TK[o/ik3ok>N``02ok>N``Co/9[100Co[9S2okJXbonfZ<_o
]ZS;1OnbXlT01?n]WlWo/jcAok>/dOnc[=45ok2Yd@04ojbWdona/]Wo/K;Iok6bf@Go[[3I00CoZjoJ
ojjggon^]moo[[OO1?n/]^001OnY]^7o[;_UojbkiOn/^nGo000000?oZ[_U00?oZkoXojZnj?nZ_^P0
0onZ_^P2ojVnj@?oZ/7Z1?nZ`>X2ojW1jP;oZ/7[5?ooool00ol0003oooooooooo`0Fooooo`009?oo
ool00ol0003oooooooooo`0>ooooo`?oM:kf0_mb/OP3ogJhnPCoKkkn0omU`oh2oeW6n@;oI]Ce0on5
iOL3ojcZn@?o_]W]00?o`=k_oko4g_noa=h00onoa=h2okk2g@03ok:Ubon_W/Ko[ik600;o[ik61?n[
V<82ojNA_P;oW8Bh0onIO[@3o`000004oiMj/OnDMZooU7J_oiAf[`CoTW>]0on@L:/3ohi^ZP?oS6bY
1?n;JjP3oh]ZY`?oS6VV0on=JJ@4ohiYX`?oT6VR1?n@JJ44oi5XX0OoTFRO0_nAJ9h00onPVLgoXIS;
oj6Hb`03oj6Hb`?oXIO:1OnRV<X01?nSVL_oTFRPoi5XX?nAJ:03oiA[X@CoUVfQ0onHKZ05oiY^W`?o
VVfM1?nJK9`00onJJi[oYXZgojJ:]`05ojF4/0CoYGnZ1?nUO:H2ojEjY0?oYXFa00?oY8Baojb?]on/
SkL00_n/SkL4oj^=]P?oZXbf00?o]Io2ok>I_OncVKd00_ncVKd4ojnD^PGo/ik31?n`V/45okJXb`?o
/Z?900?o][7Dok>/dOnc[=400onc[=43ok2Yd@03okBgfona/]Wo/K;I00?o/K;I0_n^/=T2ok2ih0Go
[[OO0_n/]^02ojjmi@?o[;_U00?o0000ojbkiOnZ^nD00on[_nP3ojZnj003oj_1j_nZ`N[oZ/7Z00Co
Z/7Z0_nZ`>X6oj[1jaCooooo00?o0000ooooooooool05Oooool002Cooooo0ol0000?ooooo`GoO;7f
0omf^?X2ofnnoP?oPL_o0_mfd_h4oi;PoP03ohGUmon/j_Wo[>[i00Co_]W]0_noaMl4oko4gP03okF[
conbYL_o/ZG;00;o/ZG;1?n_W/H2oj^H`P03oj2:_?nLQ;SoW8Bh00;oW8Bh0ol000001?nIO[CoUgZa
oiMj/OnGN[43oiAf[`CoTW>]0on@L:/3ohi^ZP?oS6bY1?n;JjP3oh]ZY`?oS6VV0on=JJ@4ohiYX`Co
T6VR0on@JJ44oi5XX0GoTFRO0_nNV/l4oj2Ic@CoXIS;1?nQUlX2oj:HbP;oSVFO1?nAJ:04oiA[X@?o
UVfQ0onHKZ05oiY^W`?oVVfM0_nJK9`2ojJB`0CoYXZg1?nUQ;04ojEoZPCoYGbV00GoYGZTojN6/_nV
QK7oYXFaojbA^P05ojb?]`CoZhff00CoZXbfokFO`_neWl;o]Io21OncVKd2ojnD^P;o]JC71?ncW/<3
ok2J`@;o^K3@1?nfZ</00onbXlWo][7DokJae002okJae0Co/jcA00?o/:WAokBgfond]m/00_nd]m/3
ok6bf@03ok:mh_n`^N3o/;WP00?o/;WP0_n^]ml2ojnoiPGo[[gU0_n/^nD00on/`>So0000oj^oj004
oj^oj004ojZnj?n[`N[oZl7Zoj_1jPCoZ/7Z00?oZ/;[oj[1jonZ`N/01onZ`N/Booooo`;o00002Ooo
ool4o`000003oa0@4?oooooooooo00Oooooo000Tooooo`03o`000?oooooooooo013ooooo0_ml/OH3
ohfhl`CoR<;j0_n1bol4oi[Fo0;oT^3n0_n_hOP4okgDj`03okkIkOnoaMoo_lGO00;o_lGO00?o_lCN
okF[coneZll00_neZll3ok:Ub`?o[ik600?oY931oj2:_?nPR[`00_nPR[`3o`0000CoVGjd0onGN[43
oiAf[`CoTW>]0on@L:/4ohi^ZP?oS6bY0on;JjP3oh]ZY`CoS6VV0on=JJ@3ohiYX`CoT6VR0on@JJ44
oi5XX0;oTFRO00?oW9_BoijJconNV/l00onNV/l3oj2Ic@GoXIS;0_nQUlX2oh]RW@?oSVFO1?nAJ:04
oiA[X@?oUVfQ1?nHKZ04oiY^W`;oVVfM00?oYi_:ojJB`?nVT/000onVT/03ojJ:]`CoYHB`1?nUOjX3
ojElYP?oYhJb00CoYXFaojbA^_n/TK[o[96j1?n/SkL4oj^=]PGo]Io21?ncVKd01?n_U;[o]JC7okFT
aoneY<L5ok>N``04ok2J`Oni/=3o^K3@okV`d0?o]ZS;00?o]kWJokJae?nf/M@00onf/M@3ok>/d@;o
][kP1?nd]m/00ona/]Wo/[gRok:mhP02ok:mhP?o/;WP00?o/<?Xojnoi_n__nH00on__nH2ojjmi@?o
[L;Y0on/`>P00ol0003oZkoXoj^oj002oj_2j`GoZl7Z00?oZ/7Zoj[2jonZ`^/00_nZ`^/2oj[1j`;o
Z/;[1OnZ`N/Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool000Wooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000oooooooo
ool04_ooool4ohfhl`;oR<;j1?nMbOH2oi[Fo0?o/=Kd00?o[n7hokgDjonme>/00_nme>/2okk6h0?o
_lGO00?o^;7BokF[coneZll00oneZll4ok:Ub`04ojnNa_nTT<7oY931ojB@`@?o00001?nLQ;P3oiUn
]0?oUgZa1?nDMZl3oi9c[@?oT72[1?n>KZX3oha/Z@?oRf^X0on;JZL4ohaYYP?oSFVT0on>JJ<4oi1Y
XP?oT6VQ0_nAJ:02oiVKe0CoW9_B1?nNV/l4oj2Ic@;oXIS;0on9Gi/3oh]RW@CoSVFO0onAJ:04oiA[
X@CoUVfQ0onHKZ04oiY^W`04oiY]WOnWVl[oYi_:ojNKbPCoYY;00onVR[L5ojF4/0?oYGnZ00?oYGbV
ojN7/onWQ[800_nWQ[800on/U;ko[96jojbA^P02ojbA^PGo[8ng0_n[SKH2okNWb@Co]Io20oncVKd0
0ong[<ko]JC7okFTa`02okFTa`Co/ik300?o^k[IokV`d?ni/=000oni/=001?nfZ<_o]kWJokNif_ng
^MX5okJae003ok>/dOnf_^3o][kP00;o][kP0_nd]m/2ok;2iPGo/[gR00Co/;WPok33j?n``nSo/<?X
0on__nH2ojg4j`Go[L;Y0_n/`>P00ol0003oZl?[oj_2j`03oj_2j`;oZl7Z1_nZ`^/00onZ`^coZ/;[
oj[2j`03oj[2j`;oZ/7[0_nY`N/Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2Oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Kooooo00?o0000ooooooooool04oooool2ohfhl`;oWkk^1?nMbOH2ojo<k`?o
/=Kd1?nkc^T00onme>_o_/KPokk6h002okk6h004oko5gonh/M;o^;7BokRadPGo]J_?0_nbYL/00onW
UlGoY931o`000002o`0000?oX8Zl1?nLQ;P4oiUn]0?oUgZa0onDMZl3oi9c[@?oT72[0_n>KZX2oha`
[P?oRVn_0on8LK83ohIc]`?oQWVm00CoS6VVoheYY?n=JJCoSFVT0on>JJ<2oi1YXP;oSi;B0onDV=@5
oiVKe0?oW9_B1OnNV/l2oj2Ic@;oR5fJ1?n9Gi/3oh]RW@CoSVFO0onAJ:04oiA[X@CoUVfQ0onHKZ02
oiY^W`;oZ:GD1?nWVlX4ojJB`0CoYXZg1?nUQ;02ojEoZP?oYhNc00?oYhJbojbD__n/U;h00_n/U;h3
ojbA^PGo[8ng00CoZhffokNWbOngYlWo]jO91?neWl800oncVKgo]jc>okN/cP02okN/cPCo]JC700?o
/ik3ok^jfOnk^]T00_nk^]T3okV`d003okK2hong^M[o]kWJ00?o]kWJ0_nf/M@2okG5iPCo][kP00?o
/LO[ok;2i_nb`^H00onb`^H2ok:mhP;o[lK[1On``nP00on__nKo[LC[ojg4j`02ojg4j`;o[L;Y0_n[
aN`3oj_3j`04o`000?n[`n_oZl;[oj_2j`;oZ/?/1OnZ`^/4oj[2k0;oZ/;[0onY`^/4ojW1ja?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`002Oooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0Eooooo`CoWkk^
00?oWLWfojo<kon_c>l00on_c>l00on`e_Co^lkYok_>j@02ok_>j@;o_/GP0onna^000oni]]Ko^;7B
okRadP03okRadP?o]J_?00?oZik:ojNGaOnWUlD00_l00003ojB@`@CoX8Zl0onLQ;P4oiUn]0?oUgZa
0_nDMZl01?n>M;7oSG:_oheb[on=LZl3ohe`[PCoS72^0on:Kjl3ohQa/PCoQW>g0on6NKd3ohN1a@?o
RXW=1On?T]83oiBHe0CoVI_D1?nLVm82oijJc`?oQebI1?n8GIX3ohUOV`?oRf:M1?n>IIl3oi5XX0Co
U6^Q1?nFKJ42oiQ^X003ojR^g?nXYMCoZ:GD00?oZ:GD0onWVlX5ojJB`0?oYXZg0_nUQ;04ojN9]@;o
YhNc00?o[9S2ojbD__n/U;h00on/U;h4ojbA^P?o[8ng00?o]k3BokNWbOngYlT00_ngYlT3okFO`P03
okNff?ng[<ko]jc>00Co]jc>0_neY<L2okW5h`Co^k[I00?o^K3@okK2honf`^<00_nf`^<3okNifP;o
//g]1?neaNH00onf_^3o/LO[ok77j`02ok77j`?o//;V0_n]b^l4ojo6j`;o/<?X0_n/a^d4ojg4j`03
oj_6k_n[aNcoZlG/00?oZlG/0_n[`n/00onZa>go0000oj[3k004oj[3k0;oZ/;[0_nY`n`3oj[2k0;o
ZL;/1OnY`^/4ojW1ja?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`00
2Oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`0001Ko
oooo0_nO_^h4ojk1j0;o[lc_0onibNH00onkc^Wo_/GPokk5h003okk5h004okk6h?ni]]Ko^KKFokVf
ePGo^;7B00?o]J_?oj^Nb_l000000_l00002ojNGa@CoY9310onPR[`2oib4^003oi=n^OnAN[KoTGZf
00;oTGZf0on?Mk<3ohid/@?oSG:_0on=L:h4oha`[PCoRVn_0on8LK83ohIc]`CoQWVm0on7PLD3ohZ9
c@CoSi;B1?nDV=@4oiVKe0;oW9_B0on7FiP3ohMLV@CoR5fJ0on9Gi/3oh]RW@CoSVFO1?nAJ:03oiA[
X@?oUVfQ00?oYk;QojR^g?nX[]`00_nX[]`4ojRUe0CoYi_:1?nVT/05ojJ:]`CoYhVe00CoYhNcojbH
`_n/V<;o[9S21?n/U;h4ojbA^P03ojb?]ong/=;o]k3B00;o]k3B1?ngYlT01?neWl;o]kKHokNff?ng
]]P4okN/cP03okC?k_niaN?o^LGS00?o^LGS0_nk^]T2ok?<k0Go]/;S00?o]kWJok;=kOnbcNd00_nb
cNd2okG5iP;o[Lg`1Onaan/00onb`^Ko[L[_ojg:k`02ojg:k`;o[lK[0_n[bNl4ojc6k@03ojg4jon[
a^koZlK^00;oZlK^0_n[aN`3ojW5kP?oZ/C]00?o0000oj[3k?nZ`n`00_nYa>d5ojW3k003oj[2k?nY
`^coZL;/00;oZL;/0_nY`^/7ojW1ja7ooooo0ol00007ooooo`03o`000?oooooooooo00Wooooo0009
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oo
oooooooo01Sooooo0on^`NP2okS3h`?o^LWV0onmaN03okk5h003ok^kfOni]]Ko^KKF00?o^KKF0_nh
/M801?n_Y/ko0000o`000?l00002oj^NbPCoYiO50onTT<42oj2:_004oiJ3_?nCO[WoTgjioi=n^@Co
TGZf0on?Mk<4ohid/@?oSG:_0on=L:h3oha`[PCoRVn_0on8LK83ohIc]`CoQWVm0on7PLD3ohZ9c@Go
Si;B0_nDV=@4ohYNV@?oR5bH0on7FiP3ohMLV@CoR5fJ0on9Gi/3oh]RW@CoSVFO1?nAJ:03oiA[X@03
oiI]XOnW/^7oYk;Q00;oYk;Q0onX[]`5ojRUe0;oYi_:0onSRk/3ojF;^@CoYXZg0_nWRKD2oj^KaPCo
[9S21On/U;h2ojbA^P03okNifong/=;o]k3B00?o]k3B0_ngYlT3okG1h`Co]kKH00?o]jc>okC?k_nd
cnh00_ndcnh3okW5h`;oZm?e1?ncc>`2okK2h`?oZm;d0_nbcNd2ojS@m@Go[Lg`0_naan/3oj[=lP;o
[L[_0_nXbo85oj_9k`;o[<K]0_nYb>l3oj_6kP;oZLK_1OnYaNh2oj[4k@03o`000?nYa>goZLC]00?o
ZLC]1?nY`n`4ojW2k003ojS2k?nY`N_oZL7[00GoZL7[0_nX`N/>ooooo`Co000000?oooooo`000?oo
ool01_ooool00ol0003oooooooooo`09ooooo`002Oooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03ojk1j?nh`n?o^<?S00;o
^<?S00?o^LWVokg5h?nmaN000onmaN001?nnaN3o^k_Iok^kfOnk^mT3okVfeP04ok:]dol0003o0000
o`0000;o[jK>1?n[W/X2ojNGa@04oif?aOnJRL3oVXW0oiZ9`0CoUX>l0onCO[T3oi5j]P?oSgNc1?n>
M;43oheb[`?oSG2^1?n<L:h3ohY_[`?oR76b1?n6LkL3ohIi_@CoQh750on:RLd2ohnBdP04oi5WW_n=
HY_oSF:KoheRV`CoRUjI0on8G9P3ohMKV0?oQebI1?n8GIX4ohUOV`?oRf:M0on>IIl4oi5XX0;oU6^Q
0_nV/^45ojNbh@?oZ:kL0_nXYM@3oj6:_0CoXh^k1?nURkT2ojJ:]`03ojZNbon[VlKoZi_600?oZi_6
0on/V<84ojbD_P03okC3iOng^M_o]kWK00;o]kWK0ong/=82ok3;k@Go]L7S0_ng]]P2oj[Gm`Co]<o^
00?o^LGSoj_CmOn[doD00on[doD2ok?<k0?oXmGi0_n[d_@2oj7An@CoZ=3e0_n]cO04ojG>m@;oZ/gb
0_nUbo@4ojS;lP;oZlW_0_nWb?45ojW8k`03oj_6k_nYa^ooZLK_00;oZLK_0_nYaNh2ojS5kP?oZLC]
00Co0000ojW4kOnYa>goZLC]0_nY`nd4ojW3k003ojW2k?nX`^coZ<;/00;oZ<;/0_nY`N/7ojS1j`[o
oooo0ol00005ooooo`03o`000?oooooooooo00?ooooo00?oEEEEofIVI_l000002oooool000Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool2o`00
01_ooooo0onh`n<2okc4h0Co_LGP00?o_;oLok^kfOnk^mT00onk^mT3o`000003ok:]don_Y/ko[jK>
00;o[jK>0on[W/X00onQU/WoWHo5oif?a@02oif?a@?oVXW00onFPk`3oi=n^@CoTGZf0on?Mk<3ohid
/@?oSG:_0on=L:h4oha`[P?oRVn_1?n8LK83ohIc]`CoQWVm0_n7PLD01?m4aM_oUfnSoiM_XonGKj<3
oi5WWPCoSF:K0on:GYT3ohQLV0?oQe^H1?n7G9T3ohQMVPCoREnK0on;HYd3ohiUW`;oTFRP0onU[Md4
ojJbh@;oYk;Q00?oVWndoib7_?nLQk`01?nNRK`3oj6:_0CoXh^k1?nURkT01?nVR[OoZYk;ojZNbonZ
W//4oj^KaPCo[9S200?o[9BnokC3iOnd`nD00_nd`nD4okNif`03okN`d_n`bngo/<_]00;o/<_]0_ne
`N<2oioKo0GoZ]Og0_ndcnh3oj;Hn`;oZm?e0onKeO`2oj?En@;oW=7j1OnQdOT2ojS@m@?oXLkg0_nU
c_D2oj;;m@GoYL_d0_nXbo82ojG9lPCoYlSa0_nYb>l3ojO6l0;oZLK_0_nWaNl5ojS5kP;oZLC]00?o
Z<?]o`000?nY`nd01?nY`nd2ojW3k0GoZ<;/0_nX`N`6ojS1j`;oZ<3[1_ooool4o`0000Sooooo00?o
0000ooooooooool04Oooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`0Kooooo`03okS3honla>3o_<CP00;o_<CP
00?o_LGPokbog?nl_m`00_nl_m`01?nk^mWo0000o`000?l00004ok:]d`Go[jK>00CoZik:oj6FbOnQ
U/WoXIK90onMSlD3oiZ9`0?oUX>l0onCO[T4oi5j]P?oSgNc0on>M;43oheb[`?oSG2^1?n<L:h4ohY_
[`?oR76b0_n6LkL4oiFnl`;oP]?o0_n1HjH3ogmOY0?oTFNN1?n=HY/3ohYNV@?oR5bH0on7FiP4ohML
V@?oR5fJ1?n9Gi/3oh]RW@;oSVFO00?oXj?EojF]gOnU[Md01?nU[Md2ojJbh@03oiUo]OnIQ;_oW8Nl
00?oW8Nl1?nNRK`3oj6:_0GoXh^k0_nURkT00onYXLkoZYk;ojZNb`02ojZNb`GoZi_60_n/V<82ok3;
kPCo]<?U0_ng^M/4oj[CmP;o/<_]0_nFg?h4oioKo0;oZ]Og1?nHfOd2oj;Hn`?oUmCm0_nKeO`2oi[@
n`CoW=7j0_nQdOT3oik=n0;oXLkg0onQb_D4oj;;m@;oYL_d0_nTb?<5ojG9lP;oYlSa0onVao02ojO6
l0KoYlG_0_nXaNh2ojS3kP?oZ<?]00Co0000ojS3kOnY`ngoZL?]2?nX`^`4ojS1k0CoZ<7[1?nX`>/2
ooooo`?o00003?ooool00ol0003oooooooooo`0Aooooo`008_ooool00ol0003oooooooooo`0Moooo
o`?o_<CP0onma=l01Onl_mco0000o`000?l0003o^k_I00?o]KCH1?nb[M<2ojnVcP;oYIk>1?nQU/T3
oif?a@?oVXW01?nFPk`3oi=n^@?oTGZf0on?Mk<4ohid/@?oSG:_0on=L:h3oha`[PCoRVn_0_n8LK82
oiR[i0CoUKkc0on7JJ/2oh5SYP?oOenT0omoGZ<4oheRV`?oRUjI0on8G9P3ohMKV0CoQebI0on8GIX4
ohUOV`;oRf:M00?oWiO<oj>SeOnSXmD00_nSXmD4ojF]g@03oiV0]onFPK[oVHBk00?oVHBk0onLQk`4
oij9_0CoXHZl0onSRk/00onXXm7oZJ7>ojVQcP02ojVQcP?oZYk;1?n[VlH2oj_Am0Co/<_^0_nd`nD3
oj;In`;oZ]?f0on@fol4oiKLoP;oWm_l0onBf?h2oiSIo@?oUM;m0_nGe?d2oiW>nPGoV]3k0_nLdOX3
oig;n0;oW/gh0_nPbOD5oj7:m@;oX/_e0_nRao<4ojC8l`;oYLWb0_nUa_44ojK7l003ojK4konWaNoo
YlG_00GoYlG_0_nW`nh4ojS3kP;oZ<?]00?oZ<;]o`000?nX`^d01_nX`^`7ojS1k0GoZ<7[1?nX`>/0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo
01kooooo00Co_<CPokg4gonma=oo_LCO0_l00002okbog0;o]kcM1?ne]=P2ok:]d`03ojVVe?nUW/ko
YIk>00?oYIk>0onQU/T4oif?a@?oVXW00onFPk`3oi=n^@?oTGZf0on?Mk<4ohid/@?oSG:_0on=L:h2
oha`[P03oi6Cd_nFW]WoUYkI00?oUYkI1?nHZn@00onE__?oSW>`ohMYZ`03ohMYZ`?oPF>V0_moGj@3
ogmNX`?oPF2S00CoSF:KohYNVOn:GYWoRUjI0on8G9P3ohMKV0CoQebI0on8GIX2ohUOV`;oVh_21?nO
Ul`4oj>Se@03ojF]gOnCOKSoUX6j00?oUX6j0onIQ;/4oib7_0CoWXVl0onQR[`01?nSRk_oZ:?AojRS
dOnXXm44ojVQcPCoZYk;00?oZi_6oj_Am?n[dO@00on[dO@2ok3;kP?oVmcm0_nRfO/3ohkKo`;oT=_o
0onAeoh4oi7Ho`;oT]Sn0onFdO`2oiGBo@;oVlgi1?nIc_X2oi[@n`?oWLWf0_nMboP3oj37m0CoX<We
0_nQb_D2oj;6lPGoX/Oc0_nTb?<2ojC5l@CoYLKa00?oY/O`ojK4konVa>l00_nVa>l2ojO5k`;oY/?^
1OnW`nh2ojS3kP;oYl;]0onX`^d00ol0003oZ<;]ojS2k003ojS2k0WoZ<7/0_nX`N/7ojS0ja3ooooo
00?o0000ooooooooool04?ooool002;ooooo0_l0000Pooooo`?o000000?o_LCOokW3h_ng_=d01?ng
_=d2okFdf003ojf_f_nYY]CoZJKD00;oZJKD1?nUW/h4oj6Fb@?oWHo50_nJRL001?nAS<_oSHS9ohf8
bOn=R<T3oh^5a`?oR8?70on7PlL4ohN4b@?oRHO;0on=SLh4oi6CdPGoUYkI0_nHZn@01?nHOkOoSW>`
ohic/?n>Lk03ohMYZ`?oPF>V0_moGj@3ogmNX`CoPF2S0on4I:D3ohQXZ0?oQe^H0_n7G9T2oi5g/P?o
UX2j1OnKRl84oinGc0;oXj?E0onCOKP4oiJ1^P?oVHBk1?nLQk`4oij9_0;oXHZl00?oYZ?CojRSdOnX
Xm400onXXm44ojVQcP;oZYk;0onVe_P2oj_Am0?oU]kn0_nKg?d5ohkKo`CoU=Kn0_nAeoh2oi_>n@Co
VLok0_nFdO`3oig;m`CoVlgi0_nIc_X3oik8m@;oWLWf0_nQa_85oj37m0;oX<We0_nRaO44oj;6lP;o
X/Oc0_nTa?05ojC5l@;oYLKa0onUa>l2ojK4k`KoY/?^0_nW`nh7ojO2k@;oZ<;]00?oYl;/o`000?nX
`^`01?nX`^`7ojS1k0;oZ<7[2?nX`>/@ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`00
0?oooooooooo01cooooo0ol000000ooooooo_LCOokW3hP03okW3hP?o]kcM00?o[kSPojf_f_n][mX0
0_n][mX4ojVVe0CoYIk>0_nQU/T01?nHUm7oU97>oiBAc_nDTLh4oi6<b`?oSHS90on;QLL3ohR3a`?o
Qh?71?n7Q<T3ohV7b`?oSHg>0onATm84oiJNf@04oj:=__nHOkOoV7ngoiQo]`?oSW>`0on7JJ/3oh5S
YP?oOenT0_moGZ<4oh5PX`?oQ6BU0on8J:P3oha_[@GoTGNb0onFP;X4oi^;`P?oWiO<0onAN[H3oi=m
^0CoUX6j1?nIQ;/3oib7_0;oWXVl0_nUXm<4ojJSd`CoZ:?A0_nYXLh4oj?In`;oY]Kh0onCgoh2oiKN
oP?oTM_o0_n>fol3oiOEo@;oU=Kn0_nNc?P5oi_>n@;oVLok0onObOH2oig;m`;oX/Gb1?nPa_<2oik8
m@?oX/Ca1?nQa_82oj37m0;oXlC`1OnRaO42oj;6lPKoY<C`0_nTaO43ojG3k`;oYLC_0_nV`^h7ojK3
kPSoYl;]1OnW`^`01?l0003oYl;/ojS2k?nX`^`2ojO1k0KoZ<7/1?nX`N/8ojS0j`oooooo00?o0000
ooooooooool04?ooool002;ooooo00?o0000ooooooooool06Oooool3o`0000Kooooo1?ni`n801?ng
_=go[kSPojnhh?n_^>04ojf_fP;oZJKD00?oWjKKoi^Ne_nKW]H00_nKW]H4oiRGd@?oU97>0onAS</3
ohf8b@?oRhG70on8PlL3ohN3a`CoQhC90on9Ql/4ohf=cP?oTI?B00CoUYkIoj:=__nRSKkoXXfn0onH
OkL3ohic/0?oQfV[0on1HjH3ogmOY0?oOejS0on1H:<4ohATY@;oR6RX0on<Kjd5oi5g/P?oUX2j1OnK
Rl800onOUlcoSgNeoi5j]P02oi5j]PCoTgfh1?nFPKX3oiV4^`;oW8Nl00?oXj3CojFSdonUXm<00onU
Xm<4ojJSd`;oZ:?A0onPfo`2oj?In`?oT^3n0_nCgoh4oiCKoP;oTM_o0onJe?`2oiOEo@;oX<_f1?nN
c?P2oi_>n@?oXLSd0_nObOH3oj?4l0CoX/Gb0_nPa_<2oj?3l0GoX/Ca0_nQa_82ojC3k`CoXlC`0_nR
aO42ojC3k`OoY<C`0onU`^h2ojG3k`KoY/;^0_nV`nh2ojK2k@OoYl;]0_nW`N`6ojO2k003ojO1k?l0
003oYl7/00CoYl7/1?nX`N`4ojS1j`03ojO0jonX`>_oZ<3[00GoZ<3[00?oYl3[ooooooooool03Ooo
ool00ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0Fooooo`?o00002_ooool2
okW3hP;o/L;V1?n_^>02ojf_fP03oj:^h?nOY]_oWjKK00;oWjKK1?nKW]H3oiRGd@?oU97>0onAS</3
ohf8b@?oRhG70on8PlL3ohN3a`GoQhC90on9Ql/2ohf=cP03okJ/d?nLPkSoU7Ra00;oU7Ra0on<Kj`3
ohIWZ0?oOV:W1?n7JJ/2oh5SYP?oOenT0omoGZ<3oh5PX`CoQ6BU0on8J:P3oha_[@CoTGNb0onFP;X4
oi^;`P?oSgNe1?nAN[H3oi=m^0CoUX6j0_nIQ;/00onPWM7oXj3Coj>Pd`02oj>Pd`GoYJ?C0_nVXm<3
oioKo0;oX=_l0onBhOd2oi;PoP?oUm_n0_nDfoh3oigDn`;oV]Cl0onRb_D4oj3;mP;oW/ch0onSao82
oj78m0;oY<?_1OnSa?02oj;5lP;oY<?_1?nS`o02oj;4l@;oYL;^1OnT`nl2oj?4l0;oYL;^1?nT`nl2
ojC4l0GoYL;^0_nV`Nd7ojK2kP;oY/7]1?nV`^d2ojO2k@OoYl7/0_nW`^`5ojO1k003o`000?nW`Nco
Yl7/00;oYl7/1OnX`N`00onX`N_oYl3[ojO0j`02ojO0j`;oZ<3[1_nW`>/>ooooo`03o`000?oooooo
oooo013ooooo000Rooooo`;o00005?ooool3o`0000kooooo1?na`^H2ojnhh003ojBfi_nR[^3oXZkP
00;oXZkP0onOY]/5oi^NeP?oV9OA0onDTLh3oi6<b`?oSHS90on;QLL3ohR3a`?oQh?70_n7Q<T3ob6/
d@;o_;_H00CoXhnooib3^?nLPkSoW8>h0onDN;43oha_[0?oQVNX0omnHZL2ogQOZ@;oQfV[0on1HjH2
ogmOY0?oOejS0on1H:<4ohATY@?oR6RX0on<Kjd5oi5g/P?oUX2j00?oVh_2ohif]?n>M[@01?n?MkD3
oi5j]P?oTgfh0_nFPKX2oijHcPCoX9gA1?nSX=<2ojFSd`GoWm_l1?nDh_d2oi;Qo@?oVM_m0_nGfoh3
oioCnP;oWMCk0_nSbO@5oj;:m@;oX<_f0onTa_42oj?7lP;oYL?^1?nT`nl2oj?4l0;oYL;^1OnT`nl2
oj?3l0;oYL;]1?nU`^h2ojC3k`;oYL7]1OnU`^h2ojC3k`?oYL7]0_nU`^h6ojK1k@;oY/;^1onV`Nd2
ojK2kA;oYl7/00?o0000ojO1k?nW`N`00_nW`N`2ojS1k13oYl3[3Oooool00ol0003oooooooooo`0@
ooooo`008Oooool2o`0001;ooooo0ol0000Booooo`;o/L;V0_nU_n`3ojBfiPCoXZkP0onOY]/2oi^N
eP;oT:SV0on=Y>D3ohVSi@CoQJ?W0on1YN`4ogZ/lPCoKKGk0_mC_OX3ol37g`04okbkf?nSSkooXhno
oj>?_`?oW8>h0onDN;43oha_[0?oQVNX0_mnHZL4ogQOZ@?oPF>V0_moGj@3ogmNX`CoPF2S0on4I:D3
ohQXZ0?oS6n]1OnAMk82oiJ0^P04ohig]?n>M[CoSWJdohif]0CoSgNe0_nAN[H01?nGSLOoVY?;oiZC
bonJTl/5oijHcPCoX9gA0_nSX=<3oioJo0;oWm_l0onFhod2oiCRo@?oW=cm0_nIfod4oj7Cn@;oWm?j
0_nTbO<4oj?9m0;oX/[e0onUaO02ojC6l@;oY/;^1OnU`nh2ojC3k`;oY/;]1?nU`^h2ojC3k`;oY/7]
1OnU`^d2ojG2kP;oY/7]1?nU`Nd2ojG2kP;oY/7]1?nU`Nd00onV`NcoY/7]ojK1k@05ojK1k@;oY/7/
1_nV`NdFojO1k004o`000?nW`NcoYl7/ojO1k1CoYl3[3?ooool00ol0003oooooooooo`0@ooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@oooooooo
ool00oooool00ol0003oooooooooo`0?ooooo`;o00005_ooool4ojFok0?oY;KV0_nR[^02oiJajPCo
TjcW0on@Z>H3ohfTi@?oRJ?U1?n5XnL3oh6Uk0;oNZcb0_ll`MD5ol7?i@;o`<OO00?oZY_7oj>?_onS
Skl00_nSSkl3oib3^0?oU7Ra0on<Kj`3ohIWZ0?oOV:W0omhGjT3og5O[`?oOenT0_moGZ<4oh5PX`?o
Q6BU0on8J:P4oha_[@?oTGNb00CoS7Zjohim_?n>OKcoSWfl0on@PKl4oiB7``CoUhg70onJTl/5oijH
cP;oX9gA0onPf?/2oioJo0?oV>?m0_nFhod3oikLo@;oW=cm0onRdoT2oj7Cn@;oYLWb1OnTbO<2oj?9
m0GoYLG`0_nV`^d4ojK2kP;oYL?^0_nV`Nd5ojK2k@;oYL;^0_nV`N`4ojK1k@;oYL;]0_nV`N`5ojK1
k@;oYL7]0_nV`N`4ojK1k@03ojG1kOnV`NcoY/7/00;oY/7/0_nV`Nd2ojO0k0GoY/7/0_nV`NdAojO1
k0;oYl3/1_nW`N`00onW`>_o0000ojO0j`0EojO0j`gooooo00?o0000ooooooooool03oooool000Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00cooooo0ol0000Iooooo`;oYKo/00?oV;c`oiNfkOnG]^d00onG]^d3oiJa
jPCoTjcW0on@Z>H3ohfTi@?oRJ?U0_n5XnL3ofc8oP;oF/_e00?o/?;eol3DjOo0e>T01?o1cnD00on`
Y/koZY_7ojZKa`02ojZKa`?oXhno0onLPkP3oiAh/@?oS6n/0on6IjP3ogiRY`?oN5nY0omaGjl2ofMX
`004ogmOY?moGZ?oOejSogmNX`?oPF2S1?n4I:D3ohQXZ0?oS6n]00?oTGNbohaj^_n<N[X00_n<N[X3
ohim_0?oT86o1?nDQl<3oiN=a`CoVY?;0_nNV<h3oj7DnP;oX=Sk1?nJhod2oiSSo@?oX=gl0_nNg?d3
ojCCn0;oX]?i0_nVb?84ojG9lP;oY<Wc0onVa>l2ojG5l0OoY/;]0_nV`^h2ojO1k0CoY/7]0_nV`^d2
ojO1k0GoY/7/0_nV`Nd2ojO0k0CoY/7/0_nV`Nd2ojO0k0GoY/7/0_nV`Nd3ojO0k0;oY/7/1_nW`>`2
ojK1k0;oYl3/1onW`N`2ojO0k0KoYl7/1onW`>`2ojO1k0GoYl3[00?o0000ojO0jonW`>/05?nW`>/<
ooooo`03o`000?oooooooooo00oooooo0007ooooo`05oa0@4?ooooooooooooooool@41002oooool5
o`0000Gooooo0_l0000:ooooo`?o00007Oooool3oiRll0GoUkK]0onF/NX2oi>/i`;oR;Sf0on3^_P4
ogjmn`?oM/;n0_m/b?h00ombhMgo/?;eok3bm@04ol3Dj@04ol7?iOn`Y/ko/:K>ok2VcPCoZY_71?nS
Skl3oib3^0;oU7Ra0on<Kj`3ohIWZ0?oOV:W0omhGjT4og5O[`;oIfS00omoGZ<3oh5PX`CoQ6BU0on8
J:P2oha_[@KoS7Zj0on>OK`3oi21_`CoU8O31?nGSLL2oiZCb`;oXLog0onQe?X3oigSo@;oV^?m0onR
g_`2oj3Mo0CoYMCh0_nTdoP2ojK9lPCoY/Sb0_nUbO85ojK4k`;oYl;]1onV`^d6ojO1k0;oY/7]0_nW
`>`4ojO1k0;oY/7/1onW`>`2ojK1k0KoYl3/0_nV`N`DojO0k0;oYl7/1onW`>`2ojO1k0SoYl3/2OnW
`>/00ol0003oYl3[ojO0j`0EojO0j`_ooooo00?o0000ooooooooool03oooool000Oooooo00Go0000
ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000ooooooooool0
1_ooool3o`00027ooooo0onH_?02oiNfk@?oSKSc0on;^?@4ohRhmP?oPk[h0_mn_O/2oeoAl`?oP>Cc
0_n]k?P3okcEk0;o`=CY00?o];3Dok2Vc_n`Y/h00on`Y/h4ojZKa`?oXhno0onLPkP3oiAh/@;oS6n/
0on6IjP3ogiRY`CoN5nY0omaGjl3ofMX`0;oBHCV0on1H:<4ohATY@;oR6RX0_n>OK`7ohaj^P?oSWfl
0on@PKl5oiB7``;oUhg70_nPa_<4oj7?m`04oj7Dn_nMhogoWN?moigSo@?oXn3l0_nRg_`3ojKEn0;o
YMCh0_nWbO85ojK9lP;oY/Sb0_nWa>h3ojK4k`KoYl;]0_nV`^d9ojO1k0KoYl3/0_nW`N`FojO0k0;o
Yl3[1_nW`>`2ojO0j`OoYl3/0_nW`>/6ojO0k0;oYl3[1onW`>`=ojO0j`03o`000?nW`>_oYl3[01Go
Yl3[2_ooool00ol0003oooooooooo`0?ooooo`001oooool01Ol0003ooooooooooooooooo000000_o
oooo00CogMgMoeEEEOoooooo00001_ooool00ol0003oooooooooo`03ooooo`?o00009_ooool4ohni
l`?oSKSc0on;^?@2ohRhmP?oOl[o0_mbd?h3oh_Po@?oZ^Cj00Go[NchokcEk?nleNco_=G/okJhfP04
okB`e0Co/:K>0_nZVlL2oiR<a@?oT8;00on7NKd3oh5c^`?oS6n/0on6IjP2ogiRY`CoN5nY0omaGjl4
ofMX`004odV4i_n[ZmKoZj_Foj^[eP;oW9?:1?nCQL83ohim_0OoS7Zj0on>OK`3oi21_`;oU8O30_nM
^nh5oj36l`;oXLog0_nOh_d3ojCQo0;oXn3l0onWeoP2ojKEn0;oZ<[b1?nWbO82ojK9lPOoYlC^00?o
Y/C_ojO2kOnW`^d01?nW`^d8ojO1k0WoYl3/0_nW`>/6ojO0k0;oYl3[1onW`>`2ojO0j`GoYl3/1?nW
`>/2ojO0k0KoYl3[0_nW`>`7ojO0j`;oYl3/1_nW`>/2ojO0k1;oYl3[00?o0000ojO0jonW`>/05?nW
`>/:ooooo`03o`000?oooooooooo00oooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00omgMgOoc<c<o`000005ooooo`04o`000?ooooooooooooooo`?o0000:_ooool2ohnil`;oT;Wb
0on<__L4ohK4o0;oOl[o0onAeoh00on;h?goZ^Cjoj[TnP02oj[TnP?o^MC]00Co_=G/okJhf_nf^=[o
][SJ1?nd/=@2ok2VcP03oj2EbOnHS<GoV8c500;oV8c50on@P/03ohMi_@?oPG>k0omkL;/3ohIWZ0?o
OV:W0omhGjT4og5O[`;oIfS000?oBlNeoiV=a_n@Pl800_n@Pl83ohUm`0?oThG20on>OK`7ohaj^P?o
SWfl0_n@PKl2oiV_iPCoWK_^0_nPa_<4oj;No003oioRoOnThOcoY>7l00CoZ=Si0_nWeoP2ojS;lPCo
Z<[b0_nWbO88ojO4kPKoYl;]2?nW`N`8ojO0k0OoYl3[0_nW`>`6ojO0j`;oYl3/1onW`>/2ojO0k3Co
Yl3[00?o0000ojO0jonW`>/05?nW`>/9ooooo`03o`000?oooooooooo00oooooo0007ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000005ooooo`Co0000;_ooool4oi2ilP?o
S;kg0_n6a?`3oiG=n`;oTMOn0onXfoT2okG@kP?o^MC]0_ng_Mh4okJhfP;o];3D00?oYYo?oj2EbOnP
ULT00_nPULT3oiR<a@?oT8;00on7NKd4oh5c^`;oNg2k0omjLkl3oganbP?oN5nY0_maGjl3oh_>oP?o
VHg61?n@Pl82ohUm`0?oQWg20on7PLH3ohV8c0CoSiCD1?nDXMd4oiV_iP;oWK_^0onSfO/2oj;No0;o
YN;k0_nXf_T4ojSHn@03ojW<l_nXbo;oZ<_b00?oZ<_b0_nXb_82ojS5kPKoYlC^0onW`^`2ojO2k@Wo
Yl7/0_nW`>/6ojO0k57oYl3[00?o0000ojO0jonW`>/05?nW`>/9ooooo`03o`000?oooooooooo00oo
oooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`04ooooo`;o
0000<Oooool2oi2ilP;oV[c`1?nGa?H2oiG=n`CoY]7f00?oZ=_iokG@k_ned>h00_ned>h00onie>go
]kgNokNmgP02okNmgP;o][SJ00?oZjSCojJOconVWll00_nVWll3oj2Eb@CoV8c50on@P/03ohMi_@?o
PG>k0omkL;/3ogYc_`;oO7k:1On3VN000on;c_koYYg=ojJMc@04oiV=aP?oT8?20on9OL03ohIm`P?o
Qh760on9R<`4ohnDe0CoU:7M0_nI[nH3oj?An0;oXmWk0onVho/00onUh__oZ=[iojSJn@02ojSJn@03
ojSHnOnYc?;oZLcb00;oZLcb0_nXbo83ojS5k`CoZ<G^0_nWa>h5ojO2k0SoYl7/1onW`>/2ojO0k5Go
Yl3[00?o0000ojO0jonW`>/05?nW`>/8ooooo`03o`000?oooooooooo00oooooo000Rooooo`03o`00
0?oooooooooo02oooooo1?nJ_?02oiO4mP?oYLOa0_nVdOH4ok;<k@;o]M3^0_nf`>83okNmgP03ojn_
f?n[Z=?oZjSC00;oZjSC0onVWll3oj2Eb@CoV8c50on@P/03ohMi_@?oPG>k0omkL;/3ogYc_`?oO7k:
0on3VN000onc/]OoYYg=ojJMc@02ojJMc@?oVHg60on@Pl83ohUm`0?oQWg20on7PLH3ohV8c0GoSiCD
0_nDXMd3oj76l`;oXm7h1OnVho/3ojWMn@;oZ=[i0onZc_<2ojW<lP;oZ<K_1OnXaNl2ojS5kP?oYl;]
0_nW`^`8ojO1k6;oYl3[00?o0000ojO0jonW`>/04onW`>/9ooooo`03o`000?oooooooooo00kooooo
000Sooooo`03o`000?oooooooooo02oooooo0_nJ_?03ojFok0;oYLOa0on`a^/3ok;<k@;o]L;S1?nf
`>801?ng_Mko[joHojn_f?n_[mP3oj^Xd`CoYYo?0onPULT3oiR<a@?oT8;00on7NKd4oh5c^`;oNg2k
0omjLkl4oganbP03oh>Ih?nc/]Oo/k;G00CoYYg=0onISLH4oi23`P;oRGg01?n6OL83ohN1aP?oRHS<
0_n?U=@3oifhk0?oXLKc0onVhO/2ojKSn`?oZ]kj0_nYgOT3oj_@l`;oZ/kc0_nYanl4ojS6k`;oZ<G_
0_nX`^d4ojO2k@SoYl7/IOnW`>/00ol0003oYl3[ojO0j`0DojO0j`Sooooo00?o0000ooooooooool0
3_ooool002Cooooo00?o0000ooooooooool0;oooool3ojFok0;o[/7X1On`a^/00onbc>go]L;SokG2
h`02okG2h`;o]/3R0_na]]`4ojn_f0?oZjSC0_nVWll01?nJUlooTho<oi>?c?nCSl`3oh^9b`?oQ8K=
0omhQ]D3of^CiP04oh5c^omkL;_oNg2kog]`^`?oNW>o0_mlO/X2ol38h0?o/k;G0_nVWLd01?nDSl_o
SHS9ohf8bOn=R<T4ohZ6b@?oRXW<0_n6OL801?n=T=;oTYcJoi:Lf_nBW=X4oiRYh`GoWKS/00?oXLKc
ojKQnonVhO/01?nZh?X2oj[NnP?o[=;d0_n[d?<2ojW9l0CoZLO_0_nXa^l2ojS3k@CoZ<;]00?oYl;]
ojO1k?nW`N`01?nW`NaZojO0j`03o`000?nW`>_oYl3[01CoYl3[1oooool00ol0003oooooooooo`0>
ooooo`009Oooool2o`00033ooooo00?oYKo/ojk1j?n^`NP00_n^`NP2ok36j`?o]<;U0one`^<00onb
^moo/KKLok6fg003ok6fg0;o[joH00CoYZOGoj6Nd_nQW];oXIkB1?nJUll3oi>?c0?oRhW;0on4Q/d3
ogR6e@GoJi?V0_m4ZOL3olOLj@;o`<SP00CoYjSGoibId?nLVM3oW9W@1?nDSl/3ohf8b@?oRXK90on:
RL`4ohf@dP?oTYcJ1?nHZN<2oifhk0;oYMck0onZgoX2oj[PnP?o[MGe0_n/d_@2oj[;l@GoZLW`0_nY
anl6ojS3k@;oZ<;]1OnW`Na^ojO0j`03o`000?nW`>_oYl3[01CoYl3[1_ooool00ol0003ooooooooo
o`0>ooooo`009oooool00ol0003oooooooooo`0^ooooo`?o[/7X0onc`^H4okC2i@04okG2honb^moo
/[_Ook:kg`?o/KKL00?oZJkKojJWeonVYmL00_nVYmL3oj6NdP?oVYO?0onCSl`3oh^9b`CoQ8K=0omh
Q]D2of^CiP;oK=c[00Go[?[NolOLjOo7g>WoamcYok6ggP04ojNXe`?oW9W@0onDSl/3ohf8b@CoRXK9
0on:RL`3ohf@dPCoTYcJ0_nHZN<3oj?Dn@04ojGLnonZgo[oZ]ojoj[OnP;o[MSf0on]eOD2oj_=lPCo
Z/_a0_nYbO03ojS4k@KoZ<?]0onX`N`2ojO1k7;oYl3[00?o0000ojO0jonW`>/04onW`>/6ooooo`03
o`000?oooooooooo00kooooo000Xooooo`03o`000?oooooooooo02kooooo00?o[/7Xok?2i_nc`^H0
0onc`^H2okC2i@;o/koS1?nb^ml01?na]]coZJkKojV^fonY[]/3ojJWe`CoXIkB0onJUll3oi>?c0?o
RhW;0_n4Q/d3oh>dm@;oOlco0_nPmNH3olCXk`04olOLjOna]mko/KONok6ggP?oYjSG0onLVM03oiB?
b`?oSHS91?n:Q/T4ohZ9c0?oSI3B0_nBW=X3oik9mP;oXmCi0onYg_T00onZgo[o[MSfojgHmP02ojgH
mP03ojgEmOn[cO;oZlgb00;oZlgb0_nZbo42ojW5kPGoZ<C]0_nX`nd5ojS1k7GoYl3[00?o0000ojO0
jonW`>/05?nW`>/5ooooo`03o`000?oooooooooo00kooooo000Yooooo`03o`000?oooooooooo02oo
oooo1Onc`^H4ok>oh`;o/[_O0_n/]Ml4ojV^f`?oYZOG0_nQW]801?nHY]ooTJ;Poi6Rh?nAX^04ohbR
h`CoQZKZ0_n3]?D01?mBc/coX?GVoj3ei_nPmNH3olCXk`;o^<GT1?na]mh3ojNXe`?oW9W@0onDSl/3
ohf8b@?oRXK90_n:RL`3oi:[i`CoV;[_0_nNbOH3ojSIn@;oZMki0on^f_L2ojgHmP?o[<ob0_n[cO82
oj[6kPCoZLG^0_nXa>d3ojS2k0;oZ<7/0_nW`NahojO0j`03o`000?nW`>_oYl3[01CoYl3[1?ooool0
0ol0003oooooooooo`0>ooooo`00:_ooool2o`00037ooooo1?nc`^H2ok>oh`;o[[cS1?n/]Ml2ojV^
f`03oj6`h_nLZn7oW:_Q00;oW:_Q0onHY]l3oi6Rh0CoS:;S0_n6Y^X2ofkGm`?oWO3c0_nmkO<2ok_?
j@Co^<GT0_na]mh01?nOWmCoV9OAoiRGdOnHUm43oi2Ad0?oS93B0on;U=L4ohbMgPGoTZ_W0_nH^^l3
ojCAm`;oZ=Wi0on]f_L2ojkJm`?o[M;c0_n/co82oj_8k`CoZ/K^0_nYaNh5ojS2k0;oZ<7/1?nW`Nah
ojO0j`03o`000?nW`>_oYl3[01CoYl3[0oooool00ol0003oooooooooo`0>ooooo`00;?ooool00ol0
003oooooooooo`0_ooooo`;o/l;V0_n_`^P4ojjlh`;o[;GO00?oY;GUoj6`h_nQ/>800_nQ/>84oib[
h@?oV:KO0onAX^02ohbRh`;oP<ko0onIi_`01?nMl??o_Ngcokg]lonmkO<4ok_?j@;o^<GT00?oZ:WH
oinOe?nOWm@00_nOWm@3oiRGd@?oT97@0on<T=83oh^De`CoS9gN0_nBZnL3oj36l`;oY=7g1?n/f_L2
ojgJm`?o[MCd0_n]d_<2oj_:l0CoZlS_0_nZa^h3ojW3k@;oZ<;/1_nX`N`2ojO1k7[oYl3[00?o0000
ojO0jonW`>/05?nW`>/3ooooo`03o`000?oooooooooo00gooooo000]ooooo`03o`000?oooooooooo
02oooooo1?n_`^P2ojjlh`;oYk_X0onT]ND4oj6`hP;oW:_Q0_nF^>l4oi6kl`?oRL7j00CoP<kooiWV
o?nIi_coVNKl0onajoP3okWEkP;o^loY00?o[[?LojRYf?nXZMP00_nXZMP3oinOe0?oV9OA1?n@TM03
ohb@dP?oRiCG0_n<WMh2oiZhk@?oX<Kc0onYe_L2ojcJm`?o[MKe0_n]e?@2ojc<l0GoZl[`0_n[b>l3
ojW4k@;oZL?]2?nX`NamojO0j`03o`000?nW`>_oYl3[01CoYl3[0oooool00ol0003oooooooooo`0=
ooooo`00;_ooool00ol0003oooooooooo`0_ooooo`;o[l;X0_nX`>/4ojNkj0?oY;GU0_nQ/>82oiZh
k@CoU[S_0_nA^o<3oiS?n`;oV=[n0onZi?X00onajoSo^MG^okWEkP02okWEkP03ok:lhOn^/mco[[?L
00;o[[?L1?nXZMP3oinOe0?oV9OA0_n@TM000onAWM_oTJ;Poi6Rh002oi6Rh0?oUJcV1?nJ^>d01?nP
a_?oZMKgojWFmonYe_L2ojgFmP?o[MKe0_n]c_44ojc<l0;oZl[`0onZaNh2ojW4k@;oZ<;/1onX`N`2
ojS0jgooYl3[00?o0000ojO0jonW`>/05?nW`>/2ooooo`03o`000?oooooooooo00gooooo000_oooo
o`03o`000?oooooooooo02oooooo1?nX`>/2ojNkj0;oX;c]0onN^^`4oiZhk@;oU[S_0onHaoL2oiS?
n`?oXmck0_nZi?X3okKFl@03okWEk_nb_>7o/[cQ00;o/[cQ1?n^/m`2ojRYf004oijTf_nHW]WoV9kI
oiRNf@CoU9cI0onAWM/4oi6Rh0?oUJcV0_nJ^>d3ojC@m`03ojWFmon]e_Ko[MKf00;o[MKf00?o[MKe
ojg>lOn]c_400_n]c_42ojc<l0;oZlO^0onZaNh2ojW3k0CoZ<;/0_nX`N`2ojS1j`GoZ<3[OonW`>/0
0ol0003oYl3[ojO0j`0CojO0j`;ooooo00?o0000ooooooooool03Oooool0033ooooo0_l0000`oooo
o`;oZ<3[0_nQ_^d4oj2lk@?oW[[/0_nJ^>d3oi[3m0;oV<Og0onPdoX2oj?Ln`?o/=Cc0_nfe_42ok?2
i@Co/[cQ0_n^/m`2oj>[g0CoWZCJ0onHW]T4oiBLf@?oTIgK0_nAX^02oiZll0CoWlOd0_nTd?L3oj[D
mP;o[MKf0on]d?82ojg>l@;oZlW_1?n[anh00onZaNkoZL?/ojW3k002ojW3k0;oZ<;/0_nX`N`4ojS1
j`;oZ<3[POnW`>/00ol0003oYl3[ojO0j`0DojO0j`03ooooool0003ooooo00kooooo000booooo`03
o`000?oooooooooo02kooooo1?nQ_^d2oj2lk@;oWKk`1?nK`?42oi[3m0?oWlcg0_nPdoX2ojc@l`?o
/=Cc0_nba^P4ok?2i@;o/[cQ0_nX/Mh4oj>[g0?oWZCJ1?nHW]T2oiBLf@03oiF[i_nF/^_oU[;[00;o
U[;[1?nJ_?02oio7m0?oYm3e0_nZe?H3ojgAl`;o[M3b0_n/bo04oj_9k`;oZlO^0onY`nd2ojW3k0Ko
Z<7/0_nX`N^5ojO0j`03o`000?nW`>_oYl3[01?oYl3[00?oooooo`000?ooool03_ooool003?ooooo
00?o0000ooooooooool0;_ooool2oj6nk@;oWkk^1?nM__02oi_0l@;oWlKd0onOc?L2ojW<lPCo[=3c
00?o/=Ccok;6j?nba^P00_nba^P2ok?2i@;o[;OQ1?nX/Mh3oj>[g0;oWZCJ00?oVJOPoiJWh_nFYn80
0_nFYn84oiF[iPCoU[;[0_nJ_?03oj?9m0;oYm3e0on/dO@2ojgAl`;o[<ca1?n/bo02oj_9k`?oZ/G]
0_nY`nd2ojS2k0KoZ<7/0_nX`>^7ojO0j`03o`000?nW`>_oYl3[01?oYl3[00?o0000ooooooooool0
3Oooool003Cooooo00?o0000ooooooooool0;_ooool4oinnkP;oWKk`0onO`O43oio6m003oio<monY
c?;oZLcb00;oZLcb0_n/d?<3ok37j`;o//KX0_n^_>@4ojbgh@;oZ;7N00?oXZgOoifYgonMZMl00_nM
ZMl3oiVWh0CoUZOR1?nEZnH2oiJbj`?oWl;a0_nSbO@3ojW?m0;o[=7d0_n/cO44ojc<l@;o[<_`0onZ
a^h2oj[5k@;oZL;/1?nX`^`2ojS1k0;oZ<7[1?nX`>^7ojO0j`03o`000?nW`>_oYl3[017oYl3[00?o
ooooo`000?ooool03_ooool003Gooooo0_l0000_ooooo`;oWkk^0onP_^h2oio1l@;oYL?^1?nVao02
ojW<lP?o[/K/0_n`an/2ojjoiPCo[[cT0_n/]n400onV/N3oXZgOoj:]g`02oj:]g`CoWJWO0onIYn02
oiJWhP;oV[CZ1?nL^^h2oio2l@?oY/cc0onYco@2oj_=lPCo[<ga0_n/c?43oj_7kP;oZ/K^0_nY`nd4
ojW2k0;oZ<;/0_nX`N`4ojS1j`;oZ<3[R?nW`>/00ol0003oYl3[ojO0j`0=ojO0j`Kooooo00?o0000
ooooooooool03?ooool003Oooooo00?o0000ooooooooool0;_ooool2oj2nkP;oYKo/1?nU`nh2ojK7
l0;o[<G/0on^a^`2ojk1j0Co[[oV0_n^_>@00onY]N;oY[7PojJah002ojJah0CoXZgO0_nMZMl00onL
/>GoVk7Woi^ai`02oi^ai`CoV[CZ0_nL^^h2oj;6lPGoY/cc00?oZLodoj_=l_n[cO800_n[cO82ojc=
l@;oZlW_0_n[anh2oj[4k@GoZL?]0_nY`^`6ojS1k0;oZ<7[S?nW`>/00ol0003oYl3[ojO0j`09ojO0
j`Wooooo00?o0000ooooooooool03?ooool003Sooooo00?o0000ooooooooool0;_ooool4ojFok0;o
YL?^0_nZ`^/4ojc5k003ojk6k?n^`NSo[/7X00;o[/7X0_n^_nH2oj^ii0?oZKGR1?nV/N02oj:]g`;o
Wk7T0onL/>D4oi^ai`;oV[CZ0_nO`O04oj;6lP;oY/cc0onYc?82oj_=lP?oZl[`0_n[bNl2oj[5kPCo
Z/C]0_nY`nd2ojS2k0OoZ<7/00?oZ<3[ojO0jonW`>/0SOnW`>/00ol0003oYl3[ojO0j`05ojO0j`co
oooo00?o0000ooooooooool03?ooool003Wooooo00?o0000ooooooooool0;_ooool2ojFok0;oZL3[
1?nZ`^/2ojc5k0?o[L7Y0_n^`NP2oj^li@CoZkWT0onY]N82ojJah0;oX[?T1?nO/N@3oib`i@;oVk7W
0_nN_Nh4oio1l0;oX/Kb0onWb_82ojW<lP?oZ/[`0_n[b_02oj[6kPCoZ/G^0_nZa>d2ojW2k0CoZ<;/
0_nX`N`2ojS1j`CoZ<3[SonW`>/00ol0003oYl3[ojO0j`0@ooooo`03o`000?oooooooooo00cooooo
000jooooo`;o0000;oooool4ojW0j`;oZ/;[0on/`NT2ojg1j@;o[;kW1?n[_>D2oj^ii003ojNhiOnU
]NCoYKGT00;oYKGT1?nR/n@2oinai0;oWkSZ1?nN^N`3oijmkP;oWl7`0onTao42ojO:lP;oZL[a0onZ
b_02oj[7k`CoZ/K^0_nZaNh2ojW3k0CoZL;/0_nX`^`3ojS1k0?oZ<7[0_nX`>^@ojO0j`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool03?ooool003cooooo00?o0000ooooooooool0;Oooool2
ojW0j`;oZl7Y0on/`NT2ojboj0Co[;kW0_n[_>D2ojRkiP?oYkSU1?nU]N@2oj:ci0;oX;OY1?nO^>X2
oijik0;oXL3_1?nR`o02ojC7l@;oYlSa1?nYb_400onZb_3oZ/O_oj[7k`02oj[7k`;oZ/K^0_nYa>d4
ojW3k0;oZL;/1OnX`N`2ojS0ji3oYl3[1Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00cooooo000mooooo`03o`000?oooooooooo02gooooo1?n[`NT00on/`NWo[;oXojboj002ojbo
j0;o[;kW0_nY_NP4ojRkiP?oYkSU0_nU]N@2oj>hj0CoX;OY0_nO^>X2oj6nk@CoXL3_0_nR`o02ojG6
l@CoYlSa0_nYb_43ojW7k`;oZ/O_0_nYaNd4ojW4k@;oZL?/0onX`^`2ojS1k0;oZ<7[1?nX`>^<ojO0
j`Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`00?_ooool00ol0003o
ooooooooo`0]ooooo`GoZl7Y0_n/_nP2ojZoj@CoZKgX0_nX^nH2ojJkj0CoY;WX0onS^>P2oj2gj@;o
XKc/1?nQ_^d2oj70k`;oY<C`1?nUa_42ojO8l@?oZ<O_0_nYanl2ojW5kPCoZLG]0_nYa>d5ojS2k0;o
Z<7/1?nX`N/2ojS0jhKoYl3[4?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00co
oooo000oooooo`;o0000;oooool2oj_1j@;oZ/7Z1?nZ_nT2ojVmj0;oYkgY1?nV^nP2ojBij0;oXkc[
0onR_>/4oj6lk0;oXKk]0onS`^l3ojC4l0;oYLKa0onWa_02ojS7k`KoZLG^0_nYaNd3ojW3k0;oZ<;/
1_nX`N`2ojS1j`;oZ<3[Q?nW`>/Dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
2oooool0047ooooo00?o0000ooooooooool0;Oooool4oj[1jP;oZ[oY0_nX_^X4ojNmj@;oY[_X0_nT
_N/4oj>lj`?oX[c[0_nQ_>`3oj?1kP;oXl;_0_nUa>l4ojK5k`;oYlK`0_nXaNh6ojW5kP?oZL?]0_nY
`n`2ojS2k0KoZ<7/1_nX`>^0ojO0jaSooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0;ooooo`00@_ooool00ol0003oooooooooo`0]ooooo`;oZ/7Z0_nX`>/4ojRnjP;oYkgY0_nU_N/4
ojBmj`;oXkc[1_nS_nd2oj?1kP;oY<;_1?nUa>l2ojK5k`;oYlG_1?nXaNh2ojW5kP?oZLC]0_nY`nd6
ojS2k0;oZ<7/00?oZ<7[ojS0jonX`>/01OnX`>]mojO0jagooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`00@oooool00ol0003oooooooooo`0]ooooo`CoZ<3[0_nX_^X2ojJn
j`CoYKg[0_nT_N/2ojBnk0KoXko]0_nT`Nh4ojC2k`;oYLC_0_nVa>l4ojO5k`;oZ<G^0onXa>d2ojW4
k@SoZ<;/00?oZ<7/ojS1jonX`N/00_nX`N/2ojS0jgkoYl3[8?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo0014ooooo`03o`000?oooooooooo02gooooo0_nX`>/2ojJok0Co
Y[k[0_nU_N/6ojBnk0;oXko]0_nT`>h4ojC1kP;oY<;_0onV`nh3ojK4k`;oYlG_0onXa>h2ojS4k@03
ojS2kOnX`^coZ<;/00CoZ<;/1_nX`N`2ojS1j`;oZ<3[O?nW`>/Tooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02oooool004Gooooo0_l0000_ooooo`?oY[o/0_nV_^/2ojFok0KoY;k/
0_nT`>d4ojC0kP;oY<7^0onU`^h2ojK3kPKoYl?^0_nXa>h00onX`ngoZ<;]ojS2k@02ojS2k@;oZ<;/
2?nX`N`6ojS0jgOoYl3[:Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
0017ooooo`03o`000?oooooooooo02gooooo1onU_n`2ojBnk0?oY;o]0onT`>d2ojC0kP?oYL7^0_nU
`^h00onV`^goYl?^ojO3kP04ojO3kP;oYl;]1?nX`nd2ojS2k@;oZ<;/1_nX`N`3ojS1j`;oZ<3[N?nW
`>//ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool004Sooooo00?o0000
ooooooooool0;Oooool4ojFok0CoY;o/0_nT_nd2ojG0k@CoYL7]0_nU`Nh00onV`NgoY/;]ojK2k@02
ojK2k@;oYl?^1_nW`^d2ojS3k@KoZ<;/1OnX`N`2ojS1j`;oZ<3[M_nW`>/`ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02oooool004Wooooo00?o0000ooooooooool0;Oooool4ojFo
k0;oY;o/0_nU_nd4ojG0k@?oYL7]1?nV`Nd2ojK2k@SoYl;]0onW`^`2ojS2k0SoZ<7/1_nX`>]bojO0
jcCooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00B_ooool2o`0002ko
oooo1?nU_n`4ojFok@CoYL3]0onU`Nd5ojK1k@GoYl;]1OnW`^`2ojO1k0KoZ<7/0_nX`N/6ojS0jfoo
Yl3[>Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo001<ooooo`03o`00
0?oooooooooo02cooooo1?nU_n`2ojFok@;oYL3/1?nU`>d00onU`NgoY/7]ojK1k@03ojK1k@KoYl7/
0_nW`^`6ojO1k0CoZ<7/1?nX`N/2ojS0jfooYl3[??ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00[ooooo001=ooooo`03o`000?oooooooooo02cooooo1OnU_n`3ojG0k0;oYL3]0_nV
`>`2ojK1k@;oY/7/4?nW`N`4ojS1k0;oZ<7[K?nW`>]3ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02_ooool004kooooo00?o0000ooooooooool0;Oooool2ojFok003ojJok?nV`>co
Y/3/00KoY/3/1?nV`N`@ojO1k0;oZ<7/K?nW`>]7ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02_ooool004oooooo0_l0000^ooooo`?oY[o/2?nV`>`2ojK1k13oYl7/JonW`>]<oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool0057ooooo00?o0000oooooooo
ool0;?ooool3ojJok0KoY/3/0_nW`>`6ojO1k0?oYl3/0_nW`Na^ojO0jdoooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0:ooooo`00D_ooool00ol0003oooooooooo`0[ooooo`CoY[o/
0_nV`>`6ojO0k0;oYl7/1OnW`>a^ojO0je?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0:ooooo`00Doooool00ol0003oooooooooo`0[ooooo`;oY[o/1OnW`>`2ojO0j`KoYl3/K_nW
`>]Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool005Cooooo0_l0000]
ooooo`;oYl3/1_nW`>/2ojO0k6koYl3[F_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Wooooo001Fooooo`03o`000?oooooooooo02_oooooM?nW`>]Nooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02Oooool005Oooooo00?o0000ooooooooool0:ooooom/ojO0jfKo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`00F?ooool00ol0003ooooo
ooooo`0/ooooofOoYl3[J_ooool01Ol0003ooooooooooooooooo000000_ooooo001Iooooo`03o`00
0?oooooooooo02coooooHonW`>]]ooooo`05o`000?ooooooooooooooool000002oooool005[ooooo
0_l0000]oooooeooYl3[LOooool01?l0003oooooooooool0000;ooooo`00G?ooool00ol0003ooooo
ooooo`0[oooooe_oYl3[MOooool00ol0003oooooo`00000;ooooo`00GOooool00ol0003ooooooooo
o`0[oooooeOoYl3[N?ooool01?l0003oooooooooool0000:ooooo`00G_ooool00ol0003ooooooooo
o`0[oooooe?oYl3[O?ooool00ol0003oooooo`00000:ooooo`00Goooool2o`0002coooooC?nW`>^3
ooooo`;o00002_ooool0067ooooo00?o0000ooooooooool0:_oooom8ojO0jhGooooo0ol0000:oooo
o`00H_ooool00ol0003oooooooooo`0[oooood?oYl3[Q?ooool4o`0000gooooo001Sooooo`03o`00
0?oooooooooo02_ooooo?onW`>^3ooooo`Co00004Oooool006Cooooo0_l0000/oooooc_oYl3[Pooo
ool3o`0001Gooooo001Vooooo`03o`000?oooooooooo02_ooooo<onW`>^5ooooo`Co00006?ooool0
06Oooooo00?o0000ooooooooool0:_ooool`ojO0jhCooooo1?l0000Looooo`00J?ooool00ol0003o
ooooooooo`0ZooooobcoYl3[Poooool4o`00023ooooo001Yooooo`;o0000;?oooolWojO0jh;ooooo
1?l0000Tooooo`00Joooool00ol0003oooooooooo`0Zooooob?oYl3[P_ooool3o`0002Sooooo001/
ooooo`03o`000?oooooooooo02[ooooo7OnW`>^3ooooo`Co0000:oooool006gooooo00?o0000oooo
ooooool0:ooooolHojO0jh;ooooo1?l0000_ooooo`00K_ooool00ol0003oooooooooo`0ZoooooaGo
Yl3[POooool4o`0003?ooooo001_ooooo`;o0000:ooooolAojO0jh3ooooo1?l0000gooooo`00LOoo
ool00ol0003oooooooooo`0Zooooo`WoYl3[P_ooool4o`0003_ooooo001booooo`03o`000?oooooo
oooo02[ooooo1OnW`>^2ooooo`?o0000?oooool007?ooooo00?o0000ooooooooool0:_ooool00onW
`>_oooooooooo`1oooooo`Co0000@_ooool007Cooooo0_l0000Zooooo`03o`000?oooooooooo07_o
oooo1?l00016ooooo`00M_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07Sooooo
1?l0001:ooooo`00Moooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07Cooooo1?l0
001>ooooo`00N?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo077ooooo0ol0001B
ooooo`00NOooool2o`0002Cooooo00?o0000ooooooooool0KOooool4o`0005Gooooo001kooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0JOooool4o`0005Wooooo001looooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool0IOooool4o`0005gooooo001mooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0HOooool4o`00067ooooo001nooooo`;o00007oooool0
0ol0003oooooooooo`1Mooooo`Co0000IOooool0083ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`1Jooooo`?o0000JOooool0087ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`1Fooooo`Co0000K?ooool008;ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`1Booooo`Co0000L?ooool008?ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`1>ooooo`Co0000M?ooool008Cooooo0_l0000Iooooo`03o`000?oooooooooo04[ooooo1?l0001h
ooooo`00Q_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Kooooo1?l0001loooo
o`00Qoooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04?ooooo0ol00020ooooo`00
R?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03oooooo1?l00023ooooo`00ROoo
ool2o`0001Cooooo00?o0000ooooooooool0>oooool4o`0008Oooooo002;ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0=oooool4o`0008_ooooo002<ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0<oooool4o`0008oooooo002=ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0<?ooool3o`0009?ooooo002>ooooo`;o00003oooool00ol0003ooooo
ooooo`0/ooooo`Co0000U_ooool0093ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Xooooo`Co0000V_ooool0097ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0T
ooooo`Co0000W_ooool009;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qoooo
o`Co0000X_ooool009?ooooo0_l00009ooooo`03o`000?oooooooooo01gooooo1?l0002Vooooo`00
UOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo0ol0002Zooooo`00U_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo1?l0002]ooooo`00Uoooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo1?l0002aooooo`00V?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0002eooooo`00VOooool2o`0000?o
oooo00?o0000ooooooooool02_ooool4o`000;Wooooo002Kooooo`04o`000?ooooooooooo`0000Wo
oooo0ol0002mooooo`00W?ooool00ol0003oooooo`000005ooooo`Co0000`?ooool009gooooo0_l0
00000ooooooo0000o`000002o`000<Cooooo002Nooooo`;o0000b?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00:[ooooo00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`Co000000Co410@oooooooo
oooooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0009?ooooo002Zooooo`05
oa0@4?nj^[[ok^k^ogMgMol@41000_ooool6o`0000Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A409?ooooo002Zoooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;oooo
o`03oiRHV?lQ8B7ok^k^09Cooooo002Zooooo`03o`000?oooooooooo00Cooooo1_l00004ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP2Cooooo`00
Z_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
3Oooool00omgMgOoIVIVooooo`2Booooo`00Z?ooool00ol@413o0000o`000003o`0000gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo097ooooo002Z
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:
ooooo`05o`000?nj^[[ooooooiRHV?l@4100Toooool00:[ooooo00?o0000ooooooooool03?ooool0
0omEEEGoIVIVo`000005ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c02Cooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -17 0 ]
[.5 .82364 17 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12.) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69467 Mtetra
.4053 .69467 .41061 .69934 .41957 .69681 .41427 .69213 Mtetra
.41427 .69213 .41957 .69681 .42855 .69428 .42327 .68958 Mtetra
.42327 .68958 .42855 .69428 .43756 .69174 .43231 .68703 Mtetra
.43231 .68703 .43756 .69174 .4466 .68919 .44137 .68446 Mtetra
.44137 .68446 .4466 .68919 .45567 .68663 .45046 .68189 Mtetra
.45046 .68189 .45567 .68663 .46478 .68407 .45958 .67931 Mtetra
.45958 .67931 .46478 .68407 .47391 .68149 .46873 .67671 Mtetra
.46873 .67671 .47391 .68149 .48307 .67891 .47792 .67412 Mtetra
.47792 .67412 .48307 .67891 .49227 .67632 .48713 .67151 Mtetra
.48713 .67151 .49227 .67632 .50149 .67371 .49638 .66889 Mtetra
.49638 .66889 .50149 .67371 .51075 .6711 .50565 .66626 Mtetra
.50565 .66626 .51075 .6711 .52004 .66849 .51496 .66363 Mtetra
.51496 .66363 .52004 .66849 .52936 .66586 .5243 .66098 Mtetra
.5243 .66098 .52936 .66586 .53871 .66322 .53367 .65833 Mtetra
.53367 .65833 .53871 .66322 .54809 .66058 .54308 .65567 Mtetra
.54308 .65567 .54809 .66058 .55751 .65792 .55251 .653 Mtetra
.55251 .653 .55751 .65792 .56695 .65526 .56198 .65032 Mtetra
.56198 .65032 .56695 .65526 .57643 .65259 .57148 .64763 Mtetra
.57148 .64763 .57643 .65259 .58595 .6499 .58102 .64493 Mtetra
.58102 .64493 .58595 .6499 .59549 .64721 .59058 .64222 Mtetra
.59058 .64222 .59549 .64721 .60507 .64451 .60018 .6395 Mtetra
.60018 .6395 .60507 .64451 .61468 .6418 .60982 .63678 Mtetra
.60982 .63678 .61468 .6418 .62432 .63908 .61948 .63404 Mtetra
.61948 .63404 .62432 .63908 .634 .63636 .62918 .63129 Mtetra
.62918 .63129 .634 .63636 .64371 .63362 .63892 .62854 Mtetra
.63892 .62854 .64371 .63362 .65345 .63087 .64868 .62577 Mtetra
.64868 .62577 .65345 .63087 .66323 .62811 .65848 .623 Mtetra
.65848 .623 .66323 .62811 .67304 .62535 .66832 .62021 Mtetra
.66832 .62021 .67304 .62535 .68289 .62257 .67819 .61742 Mtetra
.67819 .61742 .68289 .62257 .69277 .61979 .68809 .61462 Mtetra
.68809 .61462 .69277 .61979 .70269 .61699 .69803 .6118 Mtetra
.69803 .6118 .70269 .61699 .71264 .61418 .70801 .60898 Mtetra
.70801 .60898 .71264 .61418 .72262 .61137 .71802 .60615 Mtetra
.71802 .60615 .72262 .61137 .73264 .60854 .72806 .6033 Mtetra
.72806 .6033 .73264 .60854 .7427 .60571 .73814 .60045 Mtetra
.73814 .60045 .7427 .60571 .75279 .60286 .74826 .59759 Mtetra
.74826 .59759 .75279 .60286 .76291 .60001 .75841 .59471 Mtetra
.75841 .59471 .76291 .60001 .77308 .59714 .7686 .59183 Mtetra
.7686 .59183 .77308 .59714 .78328 .59427 .77882 .58893 Mtetra
.77882 .58893 .78328 .59427 .79351 .59138 .78908 .58603 Mtetra
.78908 .58603 .79351 .59138 .80378 .58849 .79938 .58311 Mtetra
.79938 .58311 .80378 .58849 .81409 .58558 .80971 .58019 Mtetra
.80971 .58019 .81409 .58558 .82443 .58267 .82008 .57725 Mtetra
.82008 .57725 .82443 .58267 .83482 .57974 .83049 .57431 Mtetra
.83049 .57431 .83482 .57974 .84523 .5768 .84094 .57135 Mtetra
.84094 .57135 .84523 .5768 .85569 .57385 .85142 .56838 Mtetra
.85142 .56838 .85569 .57385 .86618 .57089 .86194 .5654 Mtetra
.86194 .5654 .86618 .57089 .87672 .56792 .8725 .56241 Mtetra
.8725 .56241 .87672 .56792 .88729 .56494 .8831 .55941 Mtetra
.8831 .55941 .88729 .56494 .89789 .56195 .89374 .5564 Mtetra
.89374 .5564 .89789 .56195 .90854 .55895 .90441 .55338 Mtetra
.90441 .55338 .90854 .55895 .91923 .55594 .91512 .55035 Mtetra
.91512 .55035 .91923 .55594 .92995 .55292 .92588 .54731 Mtetra
.92588 .54731 .92995 .55292 .94071 .54988 .93667 .54425 Mtetra
.93667 .54425 .94071 .54988 .95152 .54684 .9475 .54118 Mtetra
.9475 .54118 .95152 .54684 .96236 .54378 .95837 .53811 Mtetra
.95837 .53811 .96236 .54378 .97324 .54071 .96928 .53502 Mtetra
.96928 .53502 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.391 .69252 .39636 .6972 .4053 .69467 .39996 .68998 Mtetra
.39996 .68998 .4053 .69467 .41427 .69213 .40895 .68742 Mtetra
.40895 .68742 .41427 .69213 .42327 .68958 .41797 .68486 Mtetra
.41797 .68486 .42327 .68958 .43231 .68703 .42702 .68228 Mtetra
.42702 .68228 .43231 .68703 .44137 .68446 .4361 .6797 Mtetra
.4361 .6797 .44137 .68446 .45046 .68189 .44521 .67711 Mtetra
.44521 .67711 .45046 .68189 .45958 .67931 .45435 .67452 Mtetra
.45435 .67452 .45958 .67931 .46873 .67671 .46352 .67191 Mtetra
.46352 .67191 .46873 .67671 .47792 .67412 .47273 .66929 Mtetra
.47273 .66929 .47792 .67412 .48713 .67151 .48196 .66667 Mtetra
.48196 .66667 .48713 .67151 .49638 .66889 .49123 .66403 Mtetra
.49123 .66403 .49638 .66889 .50565 .66626 .50053 .66139 Mtetra
.50053 .66139 .50565 .66626 .51496 .66363 .50985 .65874 Mtetra
.50985 .65874 .51496 .66363 .5243 .66098 .51922 .65608 Mtetra
.51922 .65608 .5243 .66098 .53367 .65833 .52861 .65341 Mtetra
.52861 .65341 .53367 .65833 .54308 .65567 .53803 .65073 Mtetra
.53803 .65073 .54308 .65567 .55251 .653 .54749 .64804 Mtetra
.54749 .64804 .55251 .653 .56198 .65032 .55698 .64534 Mtetra
.55698 .64534 .56198 .65032 .57148 .64763 .5665 .64264 Mtetra
.5665 .64264 .57148 .64763 .58102 .64493 .57606 .63992 Mtetra
.57606 .63992 .58102 .64493 .59058 .64222 .58565 .6372 Mtetra
.58565 .6372 .59058 .64222 .60018 .6395 .59527 .63446 Mtetra
.59527 .63446 .60018 .6395 .60982 .63678 .60493 .63172 Mtetra
.60493 .63172 .60982 .63678 .61948 .63404 .61461 .62896 Mtetra
.61461 .62896 .61948 .63404 .62918 .63129 .62434 .6262 Mtetra
.62434 .6262 .62918 .63129 .63892 .62854 .63409 .62343 Mtetra
.63409 .62343 .63892 .62854 .64868 .62577 .64388 .62064 Mtetra
.64388 .62064 .64868 .62577 .65848 .623 .65371 .61785 Mtetra
.65371 .61785 .65848 .623 .66832 .62021 .66357 .61505 Mtetra
.66357 .61505 .66832 .62021 .67819 .61742 .67346 .61224 Mtetra
.67346 .61224 .67819 .61742 .68809 .61462 .68339 .60942 Mtetra
.68339 .60942 .68809 .61462 .69803 .6118 .69335 .60658 Mtetra
.69335 .60658 .69803 .6118 .70801 .60898 .70335 .60374 Mtetra
.70335 .60374 .70801 .60898 .71802 .60615 .71338 .60089 Mtetra
.71338 .60089 .71802 .60615 .72806 .6033 .72345 .59803 Mtetra
.72345 .59803 .72806 .6033 .73814 .60045 .73356 .59516 Mtetra
.73356 .59516 .73814 .60045 .74826 .59759 .7437 .59227 Mtetra
.7437 .59227 .74826 .59759 .75841 .59471 .75387 .58938 Mtetra
.75387 .58938 .75841 .59471 .7686 .59183 .76409 .58648 Mtetra
.76409 .58648 .7686 .59183 .77882 .58893 .77434 .58356 Mtetra
.77434 .58356 .77882 .58893 .78908 .58603 .78462 .58064 Mtetra
.78462 .58064 .78908 .58603 .79938 .58311 .79495 .57771 Mtetra
.79495 .57771 .79938 .58311 .80971 .58019 .80531 .57476 Mtetra
.80531 .57476 .80971 .58019 .82008 .57725 .81571 .57181 Mtetra
.81571 .57181 .82008 .57725 .83049 .57431 .82614 .56884 Mtetra
.82614 .56884 .83049 .57431 .84094 .57135 .83661 .56586 Mtetra
.83661 .56586 .84094 .57135 .85142 .56838 .84712 .56288 Mtetra
.84712 .56288 .85142 .56838 .86194 .5654 .85767 .55988 Mtetra
.85767 .55988 .86194 .5654 .8725 .56241 .86826 .55687 Mtetra
.86826 .55687 .8725 .56241 .8831 .55941 .87889 .55385 Mtetra
.87889 .55385 .8831 .55941 .89374 .5564 .88955 .55082 Mtetra
.88955 .55082 .89374 .5564 .90441 .55338 .90025 .54777 Mtetra
.90025 .54777 .90441 .55338 .91512 .55035 .911 .54472 Mtetra
.911 .54472 .91512 .55035 .92588 .54731 .92178 .54166 Mtetra
.92178 .54166 .92588 .54731 .93667 .54425 .9326 .53858 Mtetra
.9326 .53858 .93667 .54425 .9475 .54118 .94346 .53549 Mtetra
.94346 .53549 .9475 .54118 .95837 .53811 .95436 .53239 Mtetra
.95436 .53239 .95837 .53811 .96928 .53502 .9653 .52928 Mtetra
.9653 .52928 .96928 .53502 .98024 .53192 .97628 .52616 Mtetra
.38561 .68781 .391 .69252 .39996 .68998 .39459 .68525 Mtetra
.39459 .68525 .39996 .68998 .40895 .68742 .40359 .68268 Mtetra
.40359 .68268 .40895 .68742 .41797 .68486 .41263 .6801 Mtetra
.41263 .6801 .41797 .68486 .42702 .68228 .4217 .67751 Mtetra
.4217 .67751 .42702 .68228 .4361 .6797 .4308 .67492 Mtetra
.4308 .67492 .4361 .6797 .44521 .67711 .43993 .67231 Mtetra
.43993 .67231 .44521 .67711 .45435 .67452 .44909 .6697 Mtetra
.44909 .6697 .45435 .67452 .46352 .67191 .45828 .66707 Mtetra
.45828 .66707 .46352 .67191 .47273 .66929 .46751 .66444 Mtetra
.46751 .66444 .47273 .66929 .48196 .66667 .47676 .6618 Mtetra
.47676 .6618 .48196 .66667 .49123 .66403 .48605 .65915 Mtetra
.48605 .65915 .49123 .66403 .50053 .66139 .49537 .65649 Mtetra
.49537 .65649 .50053 .66139 .50985 .65874 .50472 .65382 Mtetra
.50472 .65382 .50985 .65874 .51922 .65608 .5141 .65114 Mtetra
.5141 .65114 .51922 .65608 .52861 .65341 .52351 .64846 Mtetra
.52351 .64846 .52861 .65341 .53803 .65073 .53296 .64576 Mtetra
.53296 .64576 .53803 .65073 .54749 .64804 .54244 .64305 Mtetra
.54244 .64305 .54749 .64804 .55698 .64534 .55195 .64034 Mtetra
.55195 .64034 .55698 .64534 .5665 .64264 .56149 .63762 Mtetra
.56149 .63762 .5665 .64264 .57606 .63992 .57107 .63488 Mtetra
.57107 .63488 .57606 .63992 .58565 .6372 .58068 .63214 Mtetra
.58068 .63214 .58565 .6372 .59527 .63446 .59032 .62939 Mtetra
.59032 .62939 .59527 .63446 .60493 .63172 .6 .62663 Mtetra
.6 .62663 .60493 .63172 .61461 .62896 .60971 .62385 Mtetra
.60971 .62385 .61461 .62896 .62434 .6262 .61946 .62107 Mtetra
.61946 .62107 .62434 .6262 .63409 .62343 .62924 .61828 Mtetra
.62924 .61828 .63409 .62343 .64388 .62064 .63905 .61548 Mtetra
.63905 .61548 .64388 .62064 .65371 .61785 .6489 .61267 Mtetra
.6489 .61267 .65371 .61785 .66357 .61505 .65878 .60985 Mtetra
.65878 .60985 .66357 .61505 .67346 .61224 .6687 .60702 Mtetra
.6687 .60702 .67346 .61224 .68339 .60942 .67865 .60418 Mtetra
.67865 .60418 .68339 .60942 .69335 .60658 .68864 .60133 Mtetra
.68864 .60133 .69335 .60658 .70335 .60374 .69866 .59847 Mtetra
.69866 .59847 .70335 .60374 .71338 .60089 .70872 .5956 Mtetra
.70872 .5956 .71338 .60089 .72345 .59803 .71881 .59272 Mtetra
.71881 .59272 .72345 .59803 .73356 .59516 .72894 .58983 Mtetra
.72894 .58983 .73356 .59516 .7437 .59227 .73911 .58692 Mtetra
.73911 .58692 .7437 .59227 .75387 .58938 .74931 .58401 Mtetra
.74931 .58401 .75387 .58938 .76409 .58648 .75955 .58109 Mtetra
.75955 .58109 .76409 .58648 .77434 .58356 .76982 .57816 Mtetra
.76982 .57816 .77434 .58356 .78462 .58064 .78014 .57521 Mtetra
.78014 .57521 .78462 .58064 .79495 .57771 .79049 .57226 Mtetra
.79049 .57226 .79495 .57771 .80531 .57476 .80087 .5693 Mtetra
.80087 .5693 .80531 .57476 .81571 .57181 .8113 .56632 Mtetra
.8113 .56632 .81571 .57181 .82614 .56884 .82176 .56334 Mtetra
.82176 .56334 .82614 .56884 .83661 .56586 .83226 .56034 Mtetra
.83226 .56034 .83661 .56586 .84712 .56288 .8428 .55733 Mtetra
.8428 .55733 .84712 .56288 .85767 .55988 .85337 .55431 Mtetra
.85337 .55431 .85767 .55988 .86826 .55687 .86399 .55128 Mtetra
.86399 .55128 .86826 .55687 .87889 .55385 .87464 .54824 Mtetra
.87464 .54824 .87889 .55385 .88955 .55082 .88533 .54519 Mtetra
.88533 .54519 .88955 .55082 .90025 .54777 .89607 .54213 Mtetra
.89607 .54213 .90025 .54777 .911 .54472 .90684 .53905 Mtetra
.90684 .53905 .911 .54472 .92178 .54166 .91765 .53597 Mtetra
.91765 .53597 .92178 .54166 .9326 .53858 .9285 .53287 Mtetra
.9285 .53287 .9326 .53858 .94346 .53549 .93939 .52976 Mtetra
.93939 .52976 .94346 .53549 .95436 .53239 .95032 .52664 Mtetra
.95032 .52664 .95436 .53239 .9653 .52928 .96129 .52351 Mtetra
.96129 .52351 .9653 .52928 .97628 .52616 .9723 .52037 Mtetra
.38018 .68308 .38561 .68781 .39459 .68525 .38918 .6805 Mtetra
.38918 .6805 .39459 .68525 .40359 .68268 .3982 .67791 Mtetra
.3982 .67791 .40359 .68268 .41263 .6801 .40726 .67532 Mtetra
.40726 .67532 .41263 .6801 .4217 .67751 .41635 .67271 Mtetra
.41635 .67271 .4217 .67751 .4308 .67492 .42547 .6701 Mtetra
.42547 .6701 .4308 .67492 .43993 .67231 .43462 .66748 Mtetra
.43462 .66748 .43993 .67231 .44909 .6697 .4438 .66485 Mtetra
.4438 .66485 .44909 .6697 .45828 .66707 .45301 .66221 Mtetra
.45301 .66221 .45828 .66707 .46751 .66444 .46225 .65956 Mtetra
.46225 .65956 .46751 .66444 .47676 .6618 .47153 .6569 Mtetra
.47153 .6569 .47676 .6618 .48605 .65915 .48083 .65423 Mtetra
.48083 .65423 .48605 .65915 .49537 .65649 .49017 .65156 Mtetra
.49017 .65156 .49537 .65649 .50472 .65382 .49954 .64887 Mtetra
.49954 .64887 .50472 .65382 .5141 .65114 .50895 .64618 Mtetra
.50895 .64618 .5141 .65114 .52351 .64846 .51838 .64347 Mtetra
.51838 .64347 .52351 .64846 .53296 .64576 .52785 .64076 Mtetra
.52785 .64076 .53296 .64576 .54244 .64305 .53735 .63804 Mtetra
.53735 .63804 .54244 .64305 .55195 .64034 .54688 .6353 Mtetra
.54688 .6353 .55195 .64034 .56149 .63762 .55645 .63256 Mtetra
.55645 .63256 .56149 .63762 .57107 .63488 .56605 .62981 Mtetra
.56605 .62981 .57107 .63488 .58068 .63214 .57568 .62705 Mtetra
.57568 .62705 .58068 .63214 .59032 .62939 .58535 .62428 Mtetra
.58535 .62428 .59032 .62939 .6 .62663 .59505 .6215 Mtetra
.59505 .6215 .6 .62663 .60971 .62385 .60478 .61871 Mtetra
.60478 .61871 .60971 .62385 .61946 .62107 .61455 .61591 Mtetra
.61455 .61591 .61946 .62107 .62924 .61828 .62435 .6131 Mtetra
.62435 .6131 .62924 .61828 .63905 .61548 .63419 .61028 Mtetra
.63419 .61028 .63905 .61548 .6489 .61267 .64406 .60746 Mtetra
.64406 .60746 .6489 .61267 .65878 .60985 .65396 .60462 Mtetra
.65396 .60462 .65878 .60985 .6687 .60702 .66391 .60177 Mtetra
.66391 .60177 .6687 .60702 .67865 .60418 .67388 .59891 Mtetra
.67388 .59891 .67865 .60418 .68864 .60133 .68389 .59604 Mtetra
.68389 .59604 .68864 .60133 .69866 .59847 .69394 .59316 Mtetra
.69394 .59316 .69866 .59847 .70872 .5956 .70402 .59027 Mtetra
.70402 .59027 .70872 .5956 .71881 .59272 .71414 .58737 Mtetra
.71414 .58737 .71881 .59272 .72894 .58983 .7243 .58446 Mtetra
.7243 .58446 .72894 .58983 .73911 .58692 .73449 .58154 Mtetra
.73449 .58154 .73911 .58692 .74931 .58401 .74472 .57861 Mtetra
.74472 .57861 .74931 .58401 .75955 .58109 .75498 .57567 Mtetra
.75498 .57567 .75955 .58109 .76982 .57816 .76528 .57272 Mtetra
.76528 .57272 .76982 .57816 .78014 .57521 .77562 .56975 Mtetra
.77562 .56975 .78014 .57521 .79049 .57226 .786 .56678 Mtetra
.786 .56678 .79049 .57226 .80087 .5693 .79641 .5638 Mtetra
.79641 .5638 .80087 .5693 .8113 .56632 .80686 .5608 Mtetra
.80686 .5608 .8113 .56632 .82176 .56334 .81735 .55779 Mtetra
.81735 .55779 .82176 .56334 .83226 .56034 .82788 .55478 Mtetra
.82788 .55478 .83226 .56034 .8428 .55733 .83844 .55175 Mtetra
.83844 .55175 .8428 .55733 .85337 .55431 .84905 .54871 Mtetra
.84905 .54871 .85337 .55431 .86399 .55128 .85969 .54566 Mtetra
.85969 .54566 .86399 .55128 .87464 .54824 .87037 .5426 Mtetra
.87037 .5426 .87464 .54824 .88533 .54519 .88109 .53953 Mtetra
.88109 .53953 .88533 .54519 .89607 .54213 .89185 .53645 Mtetra
.89185 .53645 .89607 .54213 .90684 .53905 .90265 .53335 Mtetra
.90265 .53335 .90684 .53905 .91765 .53597 .91349 .53024 Mtetra
.91349 .53024 .91765 .53597 .9285 .53287 .92437 .52713 Mtetra
.92437 .52713 .9285 .53287 .93939 .52976 .93529 .524 Mtetra
.93529 .524 .93939 .52976 .95032 .52664 .94625 .52086 Mtetra
.94625 .52086 .95032 .52664 .96129 .52351 .95725 .5177 Mtetra
.95725 .5177 .96129 .52351 .9723 .52037 .96829 .51454 Mtetra
.37472 .67831 .38018 .68308 .38918 .6805 .38373 .67572 Mtetra
.38373 .67572 .38918 .6805 .3982 .67791 .39278 .67311 Mtetra
.39278 .67311 .3982 .67791 .40726 .67532 .40186 .6705 Mtetra
.40186 .6705 .40726 .67532 .41635 .67271 .41096 .66788 Mtetra
.41096 .66788 .41635 .67271 .42547 .6701 .4201 .66525 Mtetra
.4201 .66525 .42547 .6701 .43462 .66748 .42927 .66261 Mtetra
.42927 .66261 .43462 .66748 .4438 .66485 .43847 .65997 Mtetra
.43847 .65997 .4438 .66485 .45301 .66221 .4477 .65731 Mtetra
.4477 .65731 .45301 .66221 .46225 .65956 .45697 .65464 Mtetra
.45697 .65464 .46225 .65956 .47153 .6569 .46626 .65197 Mtetra
.46626 .65197 .47153 .6569 .48083 .65423 .47559 .64928 Mtetra
.47559 .64928 .48083 .65423 .49017 .65156 .48495 .64659 Mtetra
.48495 .64659 .49017 .65156 .49954 .64887 .49434 .64389 Mtetra
.49434 .64389 .49954 .64887 .50895 .64618 .50376 .64118 Mtetra
.50376 .64118 .50895 .64618 .51838 .64347 .51322 .63846 Mtetra
.51322 .63846 .51838 .64347 .52785 .64076 .52271 .63572 Mtetra
.52271 .63572 .52785 .64076 .53735 .63804 .53223 .63298 Mtetra
.53223 .63298 .53735 .63804 .54688 .6353 .54178 .63024 Mtetra
.54178 .63024 .54688 .6353 .55645 .63256 .55137 .62748 Mtetra
.55137 .62748 .55645 .63256 .56605 .62981 .56099 .62471 Mtetra
.56099 .62471 .56605 .62981 .57568 .62705 .57065 .62193 Mtetra
.57065 .62193 .57568 .62705 .58535 .62428 .58034 .61914 Mtetra
.58034 .61914 .58535 .62428 .59505 .6215 .59006 .61634 Mtetra
.59006 .61634 .59505 .6215 .60478 .61871 .59982 .61354 Mtetra
.59982 .61354 .60478 .61871 .61455 .61591 .60961 .61072 Mtetra
.60961 .61072 .61455 .61591 .62435 .6131 .61943 .60789 Mtetra
.61943 .60789 .62435 .6131 .63419 .61028 .62929 .60505 Mtetra
.62929 .60505 .63419 .61028 .64406 .60746 .63919 .60221 Mtetra
.63919 .60221 .64406 .60746 .65396 .60462 .64912 .59935 Mtetra
.64912 .59935 .65396 .60462 .66391 .60177 .65908 .59648 Mtetra
.65908 .59648 .66391 .60177 .67388 .59891 .66908 .5936 Mtetra
.66908 .5936 .67388 .59891 .68389 .59604 .67912 .59072 Mtetra
.67912 .59072 .68389 .59604 .69394 .59316 .68919 .58782 Mtetra
.68919 .58782 .69394 .59316 .70402 .59027 .6993 .58491 Mtetra
.6993 .58491 .70402 .59027 .71414 .58737 .70944 .58199 Mtetra
.70944 .58199 .71414 .58737 .7243 .58446 .71962 .57906 Mtetra
.71962 .57906 .7243 .58446 .73449 .58154 .72984 .57612 Mtetra
.72984 .57612 .73449 .58154 .74472 .57861 .74009 .57317 Mtetra
.74009 .57317 .74472 .57861 .75498 .57567 .75038 .57021 Mtetra
.75038 .57021 .75498 .57567 .76528 .57272 .76071 .56724 Mtetra
.76071 .56724 .76528 .57272 .77562 .56975 .77107 .56426 Mtetra
.77107 .56426 .77562 .56975 .786 .56678 .78148 .56126 Mtetra
.78148 .56126 .786 .56678 .79641 .5638 .79192 .55826 Mtetra
.79192 .55826 .79641 .5638 .80686 .5608 .80239 .55524 Mtetra
.80239 .55524 .80686 .5608 .81735 .55779 .81291 .55222 Mtetra
.81291 .55222 .81735 .55779 .82788 .55478 .82346 .54918 Mtetra
.82346 .54918 .82788 .55478 .83844 .55175 .83406 .54613 Mtetra
.83406 .54613 .83844 .55175 .84905 .54871 .84469 .54307 Mtetra
.84469 .54307 .84905 .54871 .85969 .54566 .85536 .54 Mtetra
.85536 .54 .85969 .54566 .87037 .5426 .86607 .53692 Mtetra
.86607 .53692 .87037 .5426 .88109 .53953 .87682 .53383 Mtetra
.87682 .53383 .88109 .53953 .89185 .53645 .88761 .53072 Mtetra
.88761 .53072 .89185 .53645 .90265 .53335 .89844 .52761 Mtetra
.89844 .52761 .90265 .53335 .91349 .53024 .90931 .52448 Mtetra
.90931 .52448 .91349 .53024 .92437 .52713 .92022 .52134 Mtetra
.92022 .52134 .92437 .52713 .93529 .524 .93116 .51819 Mtetra
.93116 .51819 .93529 .524 .94625 .52086 .94216 .51503 Mtetra
.94216 .51503 .94625 .52086 .95725 .5177 .95319 .51185 Mtetra
.95319 .51185 .95725 .5177 .96829 .51454 .96426 .50866 Mtetra
.36922 .67351 .37472 .67831 .38373 .67572 .37826 .6709 Mtetra
.37826 .6709 .38373 .67572 .39278 .67311 .38732 .66829 Mtetra
.38732 .66829 .39278 .67311 .40186 .6705 .39642 .66566 Mtetra
.39642 .66566 .40186 .6705 .41096 .66788 .40554 .66302 Mtetra
.40554 .66302 .41096 .66788 .4201 .66525 .4147 .66038 Mtetra
.4147 .66038 .4201 .66525 .42927 .66261 .42389 .65772 Mtetra
.42389 .65772 .42927 .66261 .43847 .65997 .43311 .65506 Mtetra
.43311 .65506 .43847 .65997 .4477 .65731 .44236 .65238 Mtetra
.44236 .65238 .4477 .65731 .45697 .65464 .45165 .6497 Mtetra
.45165 .6497 .45697 .65464 .46626 .65197 .46096 .64701 Mtetra
.46096 .64701 .46626 .65197 .47559 .64928 .47031 .64431 Mtetra
.47031 .64431 .47559 .64928 .48495 .64659 .47969 .64159 Mtetra
.47969 .64159 .48495 .64659 .49434 .64389 .4891 .63888 Mtetra
.4891 .63888 .49434 .64389 .50376 .64118 .49855 .63615 Mtetra
.49855 .63615 .50376 .64118 .51322 .63846 .50802 .63341 Mtetra
.50802 .63341 .51322 .63846 .52271 .63572 .51753 .63066 Mtetra
.51753 .63066 .52271 .63572 .53223 .63298 .52708 .6279 Mtetra
.52708 .6279 .53223 .63298 .54178 .63024 .53665 .62513 Mtetra
.53665 .62513 .54178 .63024 .55137 .62748 .54626 .62236 Mtetra
.54626 .62236 .55137 .62748 .56099 .62471 .55591 .61957 Mtetra
.55591 .61957 .56099 .62471 .57065 .62193 .56558 .61677 Mtetra
.56558 .61677 .57065 .62193 .58034 .61914 .57529 .61397 Mtetra
.57529 .61397 .58034 .61914 .59006 .61634 .58504 .61115 Mtetra
.58504 .61115 .59006 .61634 .59982 .61354 .59482 .60833 Mtetra
.59482 .60833 .59982 .61354 .60961 .61072 .60463 .60549 Mtetra
.60463 .60549 .60961 .61072 .61943 .60789 .61448 .60265 Mtetra
.61448 .60265 .61943 .60789 .62929 .60505 .62437 .59979 Mtetra
.62437 .59979 .62929 .60505 .63919 .60221 .63428 .59692 Mtetra
.63428 .59692 .63919 .60221 .64912 .59935 .64424 .59405 Mtetra
.64424 .59405 .64912 .59935 .65908 .59648 .65423 .59116 Mtetra
.65423 .59116 .65908 .59648 .66908 .5936 .66425 .58826 Mtetra
.66425 .58826 .66908 .5936 .67912 .59072 .67431 .58536 Mtetra
.67431 .58536 .67912 .59072 .68919 .58782 .68441 .58244 Mtetra
.68441 .58244 .68919 .58782 .6993 .58491 .69454 .57951 Mtetra
.69454 .57951 .6993 .58491 .70944 .58199 .70471 .57657 Mtetra
.70471 .57657 .70944 .58199 .71962 .57906 .71491 .57363 Mtetra
.71491 .57363 .71962 .57906 .72984 .57612 .72516 .57067 Mtetra
.72516 .57067 .72984 .57612 .74009 .57317 .73544 .5677 Mtetra
.73544 .5677 .74009 .57317 .75038 .57021 .74575 .56471 Mtetra
.74575 .56471 .75038 .57021 .76071 .56724 .75611 .56172 Mtetra
.75611 .56172 .76071 .56724 .77107 .56426 .7665 .55872 Mtetra
.7665 .55872 .77107 .56426 .78148 .56126 .77693 .55571 Mtetra
.77693 .55571 .78148 .56126 .79192 .55826 .78739 .55268 Mtetra
.78739 .55268 .79192 .55826 .80239 .55524 .7979 .54965 Mtetra
.7979 .54965 .80239 .55524 .81291 .55222 .80844 .5466 Mtetra
.80844 .5466 .81291 .55222 .82346 .54918 .81902 .54354 Mtetra
.81902 .54354 .82346 .54918 .83406 .54613 .82964 .54048 Mtetra
.82964 .54048 .83406 .54613 .84469 .54307 .8403 .5374 Mtetra
.8403 .5374 .84469 .54307 .85536 .54 .851 .5343 Mtetra
.851 .5343 .85536 .54 .86607 .53692 .86174 .5312 Mtetra
.86174 .5312 .86607 .53692 .87682 .53383 .87252 .52809 Mtetra
.87252 .52809 .87682 .53383 .88761 .53072 .88334 .52496 Mtetra
.88334 .52496 .88761 .53072 .89844 .52761 .89419 .52183 Mtetra
.89419 .52183 .89844 .52761 .90931 .52448 .90509 .51868 Mtetra
.90509 .51868 .90931 .52448 .92022 .52134 .91603 .51552 Mtetra
.91603 .51552 .92022 .52134 .93116 .51819 .92701 .51234 Mtetra
.92701 .51234 .93116 .51819 .94216 .51503 .93803 .50916 Mtetra
.93803 .50916 .94216 .51503 .95319 .51185 .94909 .50596 Mtetra
.94909 .50596 .95319 .51185 .96426 .50866 .9602 .50275 Mtetra
.36369 .66869 .36922 .67351 .37826 .6709 .37275 .66606 Mtetra
.37275 .66606 .37826 .6709 .38732 .66829 .38183 .66343 Mtetra
.38183 .66343 .38732 .66829 .39642 .66566 .39094 .66078 Mtetra
.39094 .66078 .39642 .66566 .40554 .66302 .40009 .65813 Mtetra
.40009 .65813 .40554 .66302 .4147 .66038 .40927 .65547 Mtetra
.40927 .65547 .4147 .66038 .42389 .65772 .41848 .6528 Mtetra
.41848 .6528 .42389 .65772 .43311 .65506 .42772 .65012 Mtetra
.42772 .65012 .43311 .65506 .44236 .65238 .43699 .64742 Mtetra
.43699 .64742 .44236 .65238 .45165 .6497 .44629 .64472 Mtetra
.44629 .64472 .45165 .6497 .46096 .64701 .45563 .64201 Mtetra
.45563 .64201 .46096 .64701 .47031 .64431 .465 .6393 Mtetra
.465 .6393 .47031 .64431 .47969 .64159 .4744 .63657 Mtetra
.4744 .63657 .47969 .64159 .4891 .63888 .48383 .63383 Mtetra
.48383 .63383 .4891 .63888 .49855 .63615 .4933 .63108 Mtetra
.4933 .63108 .49855 .63615 .50802 .63341 .50279 .62833 Mtetra
.50279 .62833 .50802 .63341 .51753 .63066 .51233 .62556 Mtetra
.51233 .62556 .51753 .63066 .52708 .6279 .52189 .62279 Mtetra
.52189 .62279 .52708 .6279 .53665 .62513 .53149 .62 Mtetra
.53149 .62 .53665 .62513 .54626 .62236 .54112 .61721 Mtetra
.54112 .61721 .54626 .62236 .55591 .61957 .55079 .6144 Mtetra
.55079 .6144 .55591 .61957 .56558 .61677 .56049 .61159 Mtetra
.56049 .61159 .56558 .61677 .57529 .61397 .57022 .60876 Mtetra
.57022 .60876 .57529 .61397 .58504 .61115 .57999 .60593 Mtetra
.57999 .60593 .58504 .61115 .59482 .60833 .58979 .60308 Mtetra
.58979 .60308 .59482 .60833 .60463 .60549 .59963 .60023 Mtetra
.59963 .60023 .60463 .60549 .61448 .60265 .6095 .59737 Mtetra
.6095 .59737 .61448 .60265 .62437 .59979 .61941 .59449 Mtetra
.61941 .59449 .62437 .59979 .63428 .59692 .62935 .59161 Mtetra
.62935 .59161 .63428 .59692 .64424 .59405 .63933 .58871 Mtetra
.63933 .58871 .64424 .59405 .65423 .59116 .64934 .58581 Mtetra
.64934 .58581 .65423 .59116 .66425 .58826 .65939 .58289 Mtetra
.65939 .58289 .66425 .58826 .67431 .58536 .66947 .57996 Mtetra
.66947 .57996 .67431 .58536 .68441 .58244 .67959 .57703 Mtetra
.67959 .57703 .68441 .58244 .69454 .57951 .68975 .57408 Mtetra
.68975 .57408 .69454 .57951 .70471 .57657 .69995 .57112 Mtetra
.69995 .57112 .70471 .57657 .71491 .57363 .71018 .56815 Mtetra
.71018 .56815 .71491 .57363 .72516 .57067 .72044 .56517 Mtetra
.72044 .56517 .72516 .57067 .73544 .5677 .73075 .56218 Mtetra
.73075 .56218 .73544 .5677 .74575 .56471 .74109 .55918 Mtetra
.74109 .55918 .74575 .56471 .75611 .56172 .75147 .55617 Mtetra
.75147 .55617 .75611 .56172 .7665 .55872 .76189 .55315 Mtetra
.76189 .55315 .7665 .55872 .77693 .55571 .77234 .55012 Mtetra
.77234 .55012 .77693 .55571 .78739 .55268 .78284 .54707 Mtetra
.78284 .54707 .78739 .55268 .7979 .54965 .79337 .54401 Mtetra
.79337 .54401 .7979 .54965 .80844 .5466 .80394 .54095 Mtetra
.80394 .54095 .80844 .5466 .81902 .54354 .81455 .53787 Mtetra
.81455 .53787 .81902 .54354 .82964 .54048 .8252 .53478 Mtetra
.8252 .53478 .82964 .54048 .8403 .5374 .83589 .53168 Mtetra
.83589 .53168 .8403 .5374 .851 .5343 .84661 .52857 Mtetra
.84661 .52857 .851 .5343 .86174 .5312 .85738 .52544 Mtetra
.85738 .52544 .86174 .5312 .87252 .52809 .86819 .52231 Mtetra
.86819 .52231 .87252 .52809 .88334 .52496 .87903 .51916 Mtetra
.87903 .51916 .88334 .52496 .89419 .52183 .88992 .516 Mtetra
.88992 .516 .89419 .52183 .90509 .51868 .90085 .51283 Mtetra
.90085 .51283 .90509 .51868 .91603 .51552 .91182 .50965 Mtetra
.91182 .50965 .91603 .51552 .92701 .51234 .92283 .50646 Mtetra
.92283 .50646 .92701 .51234 .93803 .50916 .93388 .50325 Mtetra
.93388 .50325 .93803 .50916 .94909 .50596 .94497 .50003 Mtetra
.94497 .50003 .94909 .50596 .9602 .50275 .9561 .4968 Mtetra
.35813 .66383 .36369 .66869 .37275 .66606 .3672 .66119 Mtetra
.3672 .66119 .37275 .66606 .38183 .66343 .3763 .65854 Mtetra
.3763 .65854 .38183 .66343 .39094 .66078 .38544 .65588 Mtetra
.656 .752 .92 r
.38544 .65588 .39094 .66078 .40009 .65813 .3946 .65321 Mtetra
.3946 .65321 .40009 .65813 .40927 .65547 .4038 .65053 Mtetra
.4038 .65053 .40927 .65547 .41848 .6528 .41303 .64784 Mtetra
.41303 .64784 .41848 .6528 .42772 .65012 .42229 .64515 Mtetra
.42229 .64515 .42772 .65012 .43699 .64742 .43158 .64244 Mtetra
.43158 .64244 .43699 .64742 .44629 .64472 .4409 .63972 Mtetra
.4409 .63972 .44629 .64472 .45563 .64201 .45026 .63699 Mtetra
.45026 .63699 .45563 .64201 .465 .6393 .45965 .63425 Mtetra
.656 .751 .92 r
.45965 .63425 .465 .6393 .4744 .63657 .46907 .63151 Mtetra
.46907 .63151 .4744 .63657 .48383 .63383 .47853 .62875 Mtetra
.47853 .62875 .48383 .63383 .4933 .63108 .48801 .62599 Mtetra
.48801 .62599 .4933 .63108 .50279 .62833 .49753 .62321 Mtetra
.49753 .62321 .50279 .62833 .51233 .62556 .50709 .62043 Mtetra
.50709 .62043 .51233 .62556 .52189 .62279 .51667 .61764 Mtetra
.51667 .61764 .52189 .62279 .53149 .62 .52629 .61483 Mtetra
.52629 .61483 .53149 .62 .54112 .61721 .53595 .61202 Mtetra
.53595 .61202 .54112 .61721 .55079 .6144 .54563 .6092 Mtetra
.54563 .6092 .55079 .6144 .56049 .61159 .55536 .60636 Mtetra
.55536 .60636 .56049 .61159 .57022 .60876 .56511 .60352 Mtetra
.56511 .60352 .57022 .60876 .57999 .60593 .5749 .60067 Mtetra
.5749 .60067 .57999 .60593 .58979 .60308 .58473 .59781 Mtetra
.58473 .59781 .58979 .60308 .59963 .60023 .59459 .59493 Mtetra
.59459 .59493 .59963 .60023 .6095 .59737 .60448 .59205 Mtetra
.60448 .59205 .6095 .59737 .61941 .59449 .61441 .58916 Mtetra
.61441 .58916 .61941 .59449 .62935 .59161 .62438 .58625 Mtetra
.62438 .58625 .62935 .59161 .63933 .58871 .63438 .58334 Mtetra
.63438 .58334 .63933 .58871 .64934 .58581 .64442 .58041 Mtetra
.64442 .58041 .64934 .58581 .65939 .58289 .65449 .57748 Mtetra
.65449 .57748 .65939 .58289 .66947 .57996 .6646 .57453 Mtetra
.6646 .57453 .66947 .57996 .67959 .57703 .67475 .57158 Mtetra
.67475 .57158 .67959 .57703 .68975 .57408 .68493 .56861 Mtetra
.68493 .56861 .68975 .57408 .69995 .57112 .69515 .56563 Mtetra
.69515 .56563 .69995 .57112 .71018 .56815 .70541 .56264 Mtetra
.70541 .56264 .71018 .56815 .72044 .56517 .7157 .55965 Mtetra
.7157 .55965 .72044 .56517 .73075 .56218 .72603 .55664 Mtetra
.72603 .55664 .73075 .56218 .74109 .55918 .7364 .55361 Mtetra
.7364 .55361 .74109 .55918 .75147 .55617 .7468 .55058 Mtetra
.7468 .55058 .75147 .55617 .76189 .55315 .75725 .54754 Mtetra
.75725 .54754 .76189 .55315 .77234 .55012 .76773 .54449 Mtetra
.76773 .54449 .77234 .55012 .78284 .54707 .77825 .54142 Mtetra
.77825 .54142 .78284 .54707 .79337 .54401 .78881 .53834 Mtetra
.78881 .53834 .79337 .54401 .80394 .54095 .79941 .53526 Mtetra
.79941 .53526 .80394 .54095 .81455 .53787 .81005 .53216 Mtetra
.81005 .53216 .81455 .53787 .8252 .53478 .82072 .52905 Mtetra
.82072 .52905 .8252 .53478 .83589 .53168 .83144 .52593 Mtetra
.83144 .52593 .83589 .53168 .84661 .52857 .8422 .52279 Mtetra
.8422 .52279 .84661 .52857 .85738 .52544 .85299 .51965 Mtetra
.85299 .51965 .85738 .52544 .86819 .52231 .86383 .51649 Mtetra
.656 .752 .92 r
.86383 .51649 .86819 .52231 .87903 .51916 .8747 .51333 Mtetra
.8747 .51333 .87903 .51916 .88992 .516 .88562 .51015 Mtetra
.88562 .51015 .88992 .516 .90085 .51283 .89658 .50695 Mtetra
.89658 .50695 .90085 .51283 .91182 .50965 .90758 .50375 Mtetra
.90758 .50375 .91182 .50965 .92283 .50646 .91862 .50053 Mtetra
.91862 .50053 .92283 .50646 .93388 .50325 .9297 .4973 Mtetra
.9297 .4973 .93388 .50325 .94497 .50003 .94082 .49406 Mtetra
.656 .751 .92 r
.94082 .49406 .94497 .50003 .9561 .4968 .95198 .4908 Mtetra
.35253 .65894 .35813 .66383 .3672 .66119 .36162 .65629 Mtetra
.36162 .65629 .3672 .66119 .3763 .65854 .37074 .65362 Mtetra
.656 .752 .92 r
.37074 .65362 .3763 .65854 .38544 .65588 .3799 .65095 Mtetra
.3799 .65095 .38544 .65588 .3946 .65321 .38908 .64827 Mtetra
.38908 .64827 .3946 .65321 .4038 .65053 .3983 .64557 Mtetra
.3983 .64557 .4038 .65053 .41303 .64784 .40755 .64286 Mtetra
.40755 .64286 .41303 .64784 .42229 .64515 .41683 .64015 Mtetra
.41683 .64015 .42229 .64515 .43158 .64244 .42614 .63742 Mtetra
.42614 .63742 .43158 .64244 .4409 .63972 .43548 .63468 Mtetra
.43548 .63468 .4409 .63972 .45026 .63699 .44486 .63194 Mtetra
.44486 .63194 .45026 .63699 .45965 .63425 .45427 .62918 Mtetra
.45427 .62918 .45965 .63425 .46907 .63151 .46371 .62642 Mtetra
.656 .751 .92 r
.46371 .62642 .46907 .63151 .47853 .62875 .47319 .62364 Mtetra
.47319 .62364 .47853 .62875 .48801 .62599 .48269 .62086 Mtetra
.48269 .62086 .48801 .62599 .49753 .62321 .49224 .61807 Mtetra
.49224 .61807 .49753 .62321 .50709 .62043 .50181 .61527 Mtetra
.50181 .61527 .50709 .62043 .51667 .61764 .51142 .61245 Mtetra
.51142 .61245 .51667 .61764 .52629 .61483 .52106 .60963 Mtetra
.52106 .60963 .52629 .61483 .53595 .61202 .53074 .6068 Mtetra
.53074 .6068 .53595 .61202 .54563 .6092 .54045 .60396 Mtetra
.54045 .60396 .54563 .6092 .55536 .60636 .55019 .60111 Mtetra
.55019 .60111 .55536 .60636 .56511 .60352 .55997 .59825 Mtetra
.55997 .59825 .56511 .60352 .5749 .60067 .56978 .59538 Mtetra
.56978 .59538 .5749 .60067 .58473 .59781 .57963 .59249 Mtetra
.57963 .59249 .58473 .59781 .59459 .59493 .58952 .5896 Mtetra
.58952 .5896 .59459 .59493 .60448 .59205 .59944 .5867 Mtetra
.59944 .5867 .60448 .59205 .61441 .58916 .60939 .58379 Mtetra
.60939 .58379 .61441 .58916 .62438 .58625 .61938 .58087 Mtetra
.61938 .58087 .62438 .58625 .63438 .58334 .62941 .57793 Mtetra
.62941 .57793 .63438 .58334 .64442 .58041 .63947 .57499 Mtetra
.63947 .57499 .64442 .58041 .65449 .57748 .64957 .57203 Mtetra
.64957 .57203 .65449 .57748 .6646 .57453 .6597 .56907 Mtetra
.6597 .56907 .6646 .57453 .67475 .57158 .66987 .56609 Mtetra
.66987 .56609 .67475 .57158 .68493 .56861 .68008 .56311 Mtetra
.68008 .56311 .68493 .56861 .69515 .56563 .69032 .56011 Mtetra
.69032 .56011 .69515 .56563 .70541 .56264 .7006 .5571 Mtetra
.7006 .5571 .70541 .56264 .7157 .55965 .71092 .55408 Mtetra
.71092 .55408 .7157 .55965 .72603 .55664 .72128 .55105 Mtetra
.72128 .55105 .72603 .55664 .7364 .55361 .73168 .54801 Mtetra
.73168 .54801 .7364 .55361 .7468 .55058 .74211 .54496 Mtetra
.74211 .54496 .7468 .55058 .75725 .54754 .75258 .54189 Mtetra
.75258 .54189 .75725 .54754 .76773 .54449 .76309 .53882 Mtetra
.76309 .53882 .76773 .54449 .77825 .54142 .77364 .53573 Mtetra
.77364 .53573 .77825 .54142 .78881 .53834 .78422 .53263 Mtetra
.78422 .53263 .78881 .53834 .79941 .53526 .79485 .52953 Mtetra
.79485 .52953 .79941 .53526 .81005 .53216 .80551 .52641 Mtetra
.80551 .52641 .81005 .53216 .82072 .52905 .81622 .52328 Mtetra
.81622 .52328 .82072 .52905 .83144 .52593 .82696 .52013 Mtetra
.82696 .52013 .83144 .52593 .8422 .52279 .83775 .51698 Mtetra
.656 .752 .92 r
.83775 .51698 .8422 .52279 .85299 .51965 .84857 .51382 Mtetra
.84857 .51382 .85299 .51965 .86383 .51649 .85944 .51064 Mtetra
.85944 .51064 .86383 .51649 .8747 .51333 .87034 .50745 Mtetra
.87034 .50745 .8747 .51333 .88562 .51015 .88129 .50425 Mtetra
.88129 .50425 .88562 .51015 .89658 .50695 .89228 .50104 Mtetra
.89228 .50104 .89658 .50695 .90758 .50375 .90331 .49781 Mtetra
.90331 .49781 .90758 .50375 .91862 .50053 .91438 .49457 Mtetra
.91438 .49457 .91862 .50053 .9297 .4973 .92549 .49131 Mtetra
.92549 .49131 .9297 .4973 .94082 .49406 .93664 .48804 Mtetra
.93664 .48804 .94082 .49406 .95198 .4908 .94784 .48476 Mtetra
.655 .751 .92 r
.34689 .65403 .35253 .65894 .36162 .65629 .356 .65136 Mtetra
.655 .751 .921 r
.356 .65136 .36162 .65629 .37074 .65362 .36514 .64868 Mtetra
.655 .752 .921 r
.36514 .64868 .37074 .65362 .3799 .65095 .37432 .64599 Mtetra
.656 .752 .921 r
.37432 .64599 .3799 .65095 .38908 .64827 .38352 .64329 Mtetra
.38352 .64329 .38908 .64827 .3983 .64557 .39276 .64058 Mtetra
.39276 .64058 .3983 .64557 .40755 .64286 .40203 .63786 Mtetra
.40203 .63786 .40755 .64286 .41683 .64015 .41133 .63512 Mtetra
.41133 .63512 .41683 .64015 .42614 .63742 .42066 .63238 Mtetra
.42066 .63238 .42614 .63742 .43548 .63468 .43002 .62962 Mtetra
.656 .752 .92 r
.43002 .62962 .43548 .63468 .44486 .63194 .43942 .62686 Mtetra
.43942 .62686 .44486 .63194 .45427 .62918 .44885 .62408 Mtetra
.44885 .62408 .45427 .62918 .46371 .62642 .45832 .6213 Mtetra
.45832 .6213 .46371 .62642 .47319 .62364 .46781 .6185 Mtetra
.46781 .6185 .47319 .62364 .48269 .62086 .47734 .6157 Mtetra
.656 .751 .92 r
.47734 .6157 .48269 .62086 .49224 .61807 .4869 .61289 Mtetra
.4869 .61289 .49224 .61807 .50181 .61527 .4965 .61007 Mtetra
.4965 .61007 .50181 .61527 .51142 .61245 .50613 .60724 Mtetra
.50613 .60724 .51142 .61245 .52106 .60963 .5158 .6044 Mtetra
.5158 .6044 .52106 .60963 .53074 .6068 .52549 .60155 Mtetra
.52549 .60155 .53074 .6068 .54045 .60396 .53523 .59869 Mtetra
.53523 .59869 .54045 .60396 .55019 .60111 .54499 .59582 Mtetra
.54499 .59582 .55019 .60111 .55997 .59825 .5548 .59294 Mtetra
.5548 .59294 .55997 .59825 .56978 .59538 .56463 .59005 Mtetra
.56463 .59005 .56978 .59538 .57963 .59249 .5745 .58715 Mtetra
.5745 .58715 .57963 .59249 .58952 .5896 .58441 .58424 Mtetra
.58441 .58424 .58952 .5896 .59944 .5867 .59435 .58132 Mtetra
.59435 .58132 .59944 .5867 .60939 .58379 .60433 .57838 Mtetra
.60433 .57838 .60939 .58379 .61938 .58087 .61435 .57544 Mtetra
.61435 .57544 .61938 .58087 .62941 .57793 .6244 .57249 Mtetra
.6244 .57249 .62941 .57793 .63947 .57499 .63448 .56952 Mtetra
.63448 .56952 .63947 .57499 .64957 .57203 .6446 .56655 Mtetra
.6446 .56655 .64957 .57203 .6597 .56907 .65476 .56357 Mtetra
.65476 .56357 .6597 .56907 .66987 .56609 .66496 .56057 Mtetra
.66496 .56057 .66987 .56609 .68008 .56311 .67519 .55756 Mtetra
.67519 .55756 .68008 .56311 .69032 .56011 .68546 .55455 Mtetra
.68546 .55455 .69032 .56011 .7006 .5571 .69577 .55152 Mtetra
.69577 .55152 .7006 .5571 .71092 .55408 .70612 .54848 Mtetra
.70612 .54848 .71092 .55408 .72128 .55105 .7165 .54543 Mtetra
.7165 .54543 .72128 .55105 .73168 .54801 .72692 .54236 Mtetra
.72692 .54236 .73168 .54801 .74211 .54496 .73738 .53929 Mtetra
.73738 .53929 .74211 .54496 .75258 .54189 .74788 .53621 Mtetra
.74788 .53621 .75258 .54189 .76309 .53882 .75841 .53311 Mtetra
.75841 .53311 .76309 .53882 .77364 .53573 .76899 .53 Mtetra
.76899 .53 .77364 .53573 .78422 .53263 .7796 .52689 Mtetra
.7796 .52689 .78422 .53263 .79485 .52953 .79026 .52376 Mtetra
.79026 .52376 .79485 .52953 .80551 .52641 .80095 .52062 Mtetra
.80095 .52062 .80551 .52641 .81622 .52328 .81168 .51747 Mtetra
.656 .752 .92 r
.81168 .51747 .81622 .52328 .82696 .52013 .82246 .51431 Mtetra
.82246 .51431 .82696 .52013 .83775 .51698 .83327 .51113 Mtetra
.656 .752 .921 r
.83327 .51113 .83775 .51698 .84857 .51382 .84412 .50795 Mtetra
.84412 .50795 .84857 .51382 .85944 .51064 .85502 .50475 Mtetra
.85502 .50475 .85944 .51064 .87034 .50745 .86595 .50154 Mtetra
.86595 .50154 .87034 .50745 .88129 .50425 .87693 .49832 Mtetra
.87693 .49832 .88129 .50425 .89228 .50104 .88795 .49508 Mtetra
.88795 .49508 .89228 .50104 .90331 .49781 .89901 .49183 Mtetra
.89901 .49183 .90331 .49781 .91438 .49457 .91011 .48856 Mtetra
.656 .752 .92 r
.91011 .48856 .91438 .49457 .92549 .49131 .92125 .48528 Mtetra
.92125 .48528 .92549 .49131 .93664 .48804 .93243 .48199 Mtetra
.93243 .48199 .93664 .48804 .94784 .48476 .94366 .47868 Mtetra
.655 .751 .921 r
.34122 .64908 .34689 .65403 .356 .65136 .35035 .6464 Mtetra
.35035 .6464 .356 .65136 .36514 .64868 .35951 .64371 Mtetra
.655 .752 .921 r
.35951 .64371 .36514 .64868 .37432 .64599 .3687 .64101 Mtetra
.3687 .64101 .37432 .64599 .38352 .64329 .37793 .63829 Mtetra
.656 .752 .921 r
.37793 .63829 .38352 .64329 .39276 .64058 .38718 .63556 Mtetra
.38718 .63556 .39276 .64058 .40203 .63786 .39647 .63282 Mtetra
.39647 .63282 .40203 .63786 .41133 .63512 .40579 .63007 Mtetra
.40579 .63007 .41133 .63512 .42066 .63238 .41515 .62731 Mtetra
.41515 .62731 .42066 .63238 .43002 .62962 .42453 .62453 Mtetra
.42453 .62453 .43002 .62962 .43942 .62686 .43395 .62174 Mtetra
.43395 .62174 .43942 .62686 .44885 .62408 .4434 .61895 Mtetra
.656 .752 .92 r
.4434 .61895 .44885 .62408 .45832 .6213 .45289 .61614 Mtetra
.45289 .61614 .45832 .6213 .46781 .6185 .4624 .61333 Mtetra
.4624 .61333 .46781 .6185 .47734 .6157 .47195 .61051 Mtetra
.47195 .61051 .47734 .6157 .4869 .61289 .48154 .60768 Mtetra
.656 .751 .92 r
.48154 .60768 .4869 .61289 .4965 .61007 .49116 .60484 Mtetra
.49116 .60484 .4965 .61007 .50613 .60724 .50081 .60199 Mtetra
.50081 .60199 .50613 .60724 .5158 .6044 .5105 .59913 Mtetra
.5105 .59913 .5158 .6044 .52549 .60155 .52022 .59626 Mtetra
.52022 .59626 .52549 .60155 .53523 .59869 .52997 .59338 Mtetra
.52997 .59338 .53523 .59869 .54499 .59582 .53976 .59049 Mtetra
.53976 .59049 .54499 .59582 .5548 .59294 .54959 .58759 Mtetra
.54959 .58759 .5548 .59294 .56463 .59005 .55945 .58469 Mtetra
.55945 .58469 .56463 .59005 .5745 .58715 .56934 .58177 Mtetra
.56934 .58177 .5745 .58715 .58441 .58424 .57927 .57884 Mtetra
.57927 .57884 .58441 .58424 .59435 .58132 .58924 .57589 Mtetra
.58924 .57589 .59435 .58132 .60433 .57838 .59924 .57294 Mtetra
.59924 .57294 .60433 .57838 .61435 .57544 .60928 .56998 Mtetra
.60928 .56998 .61435 .57544 .6244 .57249 .61935 .56701 Mtetra
.61935 .56701 .6244 .57249 .63448 .56952 .62946 .56403 Mtetra
.62946 .56403 .63448 .56952 .6446 .56655 .63961 .56103 Mtetra
.63961 .56103 .6446 .56655 .65476 .56357 .64979 .55803 Mtetra
.64979 .55803 .65476 .56357 .66496 .56057 .66002 .55501 Mtetra
.66002 .55501 .66496 .56057 .67519 .55756 .67027 .55198 Mtetra
.67027 .55198 .67519 .55756 .68546 .55455 .68057 .54895 Mtetra
.68057 .54895 .68546 .55455 .69577 .55152 .6909 .5459 Mtetra
.6909 .5459 .69577 .55152 .70612 .54848 .70127 .54284 Mtetra
.70127 .54284 .70612 .54848 .7165 .54543 .71168 .53976 Mtetra
.71168 .53976 .7165 .54543 .72692 .54236 .72213 .53668 Mtetra
.72213 .53668 .72692 .54236 .73738 .53929 .73262 .53359 Mtetra
.73262 .53359 .73738 .53929 .74788 .53621 .74314 .53048 Mtetra
.74314 .53048 .74788 .53621 .75841 .53311 .75371 .52737 Mtetra
.75371 .52737 .75841 .53311 .76899 .53 .76431 .52424 Mtetra
.76431 .52424 .76899 .53 .7796 .52689 .77495 .5211 Mtetra
.77495 .5211 .7796 .52689 .79026 .52376 .78563 .51795 Mtetra
.78563 .51795 .79026 .52376 .80095 .52062 .79635 .51479 Mtetra
.656 .752 .92 r
.79635 .51479 .80095 .52062 .81168 .51747 .80712 .51162 Mtetra
.656 .752 .921 r
.80712 .51162 .81168 .51747 .82246 .51431 .81792 .50844 Mtetra
.655 .752 .921 r
.81792 .50844 .82246 .51431 .83327 .51113 .82876 .50525 Mtetra
.82876 .50525 .83327 .51113 .84412 .50795 .83964 .50205 Mtetra
.83964 .50205 .84412 .50795 .85502 .50475 .85057 .49883 Mtetra
.656 .752 .921 r
.85057 .49883 .85502 .50475 .86595 .50154 .86153 .4956 Mtetra
.86153 .4956 .86595 .50154 .87693 .49832 .87254 .49236 Mtetra
.87254 .49236 .87693 .49832 .88795 .49508 .88359 .4891 Mtetra
.88359 .4891 .88795 .49508 .89901 .49183 .89468 .48582 Mtetra
.89468 .48582 .89901 .49183 .91011 .48856 .90581 .48253 Mtetra
.90581 .48253 .91011 .48856 .92125 .48528 .91698 .47922 Mtetra
.656 .752 .92 r
.91698 .47922 .92125 .48528 .93243 .48199 .92819 .4759 Mtetra
.92819 .4759 .93243 .48199 .94366 .47868 .93945 .47256 Mtetra
.655 .751 .921 r
.33552 .6441 .34122 .64908 .35035 .6464 .34466 .64141 Mtetra
.655 .752 .921 r
.34466 .64141 .35035 .6464 .35951 .64371 .35384 .63871 Mtetra
.35384 .63871 .35951 .64371 .3687 .64101 .36305 .636 Mtetra
.36305 .636 .3687 .64101 .37793 .63829 .3723 .63327 Mtetra
.3723 .63327 .37793 .63829 .38718 .63556 .38157 .63053 Mtetra
.656 .753 .921 r
.38157 .63053 .38718 .63556 .39647 .63282 .39088 .62778 Mtetra
.39088 .62778 .39647 .63282 .40579 .63007 .40022 .625 Mtetra
.40022 .625 .40579 .63007 .41515 .62731 .4096 .62222 Mtetra
.4096 .62222 .41515 .62731 .42453 .62453 .419 .61942 Mtetra
.419 .61942 .42453 .62453 .43395 .62174 .42844 .61661 Mtetra
.656 .752 .921 r
.42844 .61661 .43395 .62174 .4434 .61895 .43792 .61379 Mtetra
.43792 .61379 .4434 .61895 .45289 .61614 .44742 .61097 Mtetra
.44742 .61097 .45289 .61614 .4624 .61333 .45696 .60813 Mtetra
.656 .752 .92 r
.45696 .60813 .4624 .61333 .47195 .61051 .46653 .60529 Mtetra
.46653 .60529 .47195 .61051 .48154 .60768 .47614 .60244 Mtetra
.47614 .60244 .48154 .60768 .49116 .60484 .48578 .59958 Mtetra
.48578 .59958 .49116 .60484 .50081 .60199 .49545 .59671 Mtetra
.656 .751 .92 r
.49545 .59671 .50081 .60199 .5105 .59913 .50516 .59383 Mtetra
.50516 .59383 .5105 .59913 .52022 .59626 .5149 .59094 Mtetra
.5149 .59094 .52022 .59626 .52997 .59338 .52468 .58804 Mtetra
.52468 .58804 .52997 .59338 .53976 .59049 .5345 .58513 Mtetra
.5345 .58513 .53976 .59049 .54959 .58759 .54434 .58222 Mtetra
.54434 .58222 .54959 .58759 .55945 .58469 .55423 .57929 Mtetra
.55423 .57929 .55945 .58469 .56934 .58177 .56414 .57635 Mtetra
.56414 .57635 .56934 .58177 .57927 .57884 .5741 .5734 Mtetra
.5741 .5734 .57927 .57884 .58924 .57589 .58409 .57044 Mtetra
.58409 .57044 .58924 .57589 .59924 .57294 .59412 .56747 Mtetra
.59412 .56747 .59924 .57294 .60928 .56998 .60418 .56449 Mtetra
.60418 .56449 .60928 .56998 .61935 .56701 .61428 .56149 Mtetra
.61428 .56149 .61935 .56701 .62946 .56403 .62441 .55849 Mtetra
.62441 .55849 .62946 .56403 .63961 .56103 .63458 .55548 Mtetra
.63458 .55548 .63961 .56103 .64979 .55803 .64479 .55245 Mtetra
.64479 .55245 .64979 .55803 .66002 .55501 .65504 .54941 Mtetra
.65504 .54941 .66002 .55501 .67027 .55198 .66532 .54637 Mtetra
.66532 .54637 .67027 .55198 .68057 .54895 .67564 .54331 Mtetra
.67564 .54331 .68057 .54895 .6909 .5459 .686 .54024 Mtetra
.686 .54024 .6909 .5459 .70127 .54284 .6964 .53716 Mtetra
.6964 .53716 .70127 .54284 .71168 .53976 .70684 .53406 Mtetra
.70684 .53406 .71168 .53976 .72213 .53668 .71731 .53096 Mtetra
.71731 .53096 .72213 .53668 .73262 .53359 .72782 .52785 Mtetra
.72782 .52785 .73262 .53359 .74314 .53048 .73838 .52472 Mtetra
.73838 .52472 .74314 .53048 .75371 .52737 .74897 .52158 Mtetra
.74897 .52158 .75371 .52737 .76431 .52424 .7596 .51844 Mtetra
.7596 .51844 .76431 .52424 .77495 .5211 .77027 .51528 Mtetra
.77027 .51528 .77495 .5211 .78563 .51795 .78098 .51211 Mtetra
.655 .752 .921 r
.78098 .51211 .78563 .51795 .79635 .51479 .79173 .50893 Mtetra
.79173 .50893 .79635 .51479 .80712 .51162 .80252 .50574 Mtetra
.80252 .50574 .80712 .51162 .81792 .50844 .81335 .50255 Mtetra
.81335 .50255 .81792 .50844 .82876 .50525 .82422 .49934 Mtetra
.82422 .49934 .82876 .50525 .83964 .50205 .83513 .49612 Mtetra
.83513 .49612 .83964 .50205 .85057 .49883 .84609 .49288 Mtetra
.84609 .49288 .85057 .49883 .86153 .4956 .85708 .48963 Mtetra
.656 .753 .921 r
.85708 .48963 .86153 .4956 .87254 .49236 .86812 .48637 Mtetra
.86812 .48637 .87254 .49236 .88359 .4891 .8792 .48308 Mtetra
.8792 .48308 .88359 .4891 .89468 .48582 .89032 .47978 Mtetra
.89032 .47978 .89468 .48582 .90581 .48253 .90148 .47646 Mtetra
.90148 .47646 .90581 .48253 .91698 .47922 .91268 .47312 Mtetra
.657 .752 .921 r
.91268 .47312 .91698 .47922 .92819 .4759 .92393 .46976 Mtetra
.657 .752 .92 r
.92393 .46976 .92819 .4759 .93945 .47256 .93521 .46639 Mtetra
.654 .751 .921 r
.32977 .63908 .33552 .6441 .34466 .64141 .33894 .63639 Mtetra
.654 .752 .921 r
.33894 .63639 .34466 .64141 .35384 .63871 .34814 .63369 Mtetra
.654 .752 .922 r
.34814 .63369 .35384 .63871 .36305 .636 .35737 .63097 Mtetra
.655 .753 .922 r
.35737 .63097 .36305 .636 .3723 .63327 .36663 .62824 Mtetra
.36663 .62824 .3723 .63327 .38157 .63053 .37593 .62548 Mtetra
.37593 .62548 .38157 .63053 .39088 .62778 .38526 .62271 Mtetra
.656 .754 .922 r
.38526 .62271 .39088 .62778 .40022 .625 .39462 .61992 Mtetra
.39462 .61992 .40022 .625 .4096 .62222 .40401 .61712 Mtetra
.656 .754 .921 r
.40401 .61712 .4096 .62222 .419 .61942 .41344 .6143 Mtetra
.656 .753 .921 r
.41344 .6143 .419 .61942 .42844 .61661 .4229 .61146 Mtetra
.657 .753 .921 r
.4229 .61146 .42844 .61661 .43792 .61379 .43239 .60862 Mtetra
.656 .753 .921 r
.43239 .60862 .43792 .61379 .44742 .61097 .44192 .60576 Mtetra
.656 .752 .921 r
.44192 .60576 .44742 .61097 .45696 .60813 .45148 .6029 Mtetra
.45148 .6029 .45696 .60813 .46653 .60529 .46107 .60004 Mtetra
.656 .752 .92 r
.46107 .60004 .46653 .60529 .47614 .60244 .4707 .59716 Mtetra
.4707 .59716 .47614 .60244 .48578 .59958 .48037 .59428 Mtetra
.48037 .59428 .48578 .59958 .49545 .59671 .49006 .59139 Mtetra
.49006 .59139 .49545 .59671 .50516 .59383 .49979 .58849 Mtetra
.656 .751 .92 r
.49979 .58849 .50516 .59383 .5149 .59094 .50956 .58558 Mtetra
.50956 .58558 .5149 .59094 .52468 .58804 .51936 .58267 Mtetra
.51936 .58267 .52468 .58804 .5345 .58513 .52919 .57974 Mtetra
.52919 .57974 .5345 .58513 .54434 .58222 .53907 .5768 Mtetra
.53907 .5768 .54434 .58222 .55423 .57929 .54897 .57385 Mtetra
.54897 .57385 .55423 .57929 .56414 .57635 .55891 .57089 Mtetra
.55891 .57089 .56414 .57635 .5741 .5734 .56889 .56792 Mtetra
.56889 .56792 .5741 .5734 .58409 .57044 .57891 .56494 Mtetra
.57891 .56494 .58409 .57044 .59412 .56747 .58896 .56195 Mtetra
.58896 .56195 .59412 .56747 .60418 .56449 .59904 .55895 Mtetra
.59904 .55895 .60418 .56449 .61428 .56149 .60917 .55594 Mtetra
.60917 .55594 .61428 .56149 .62441 .55849 .61933 .55292 Mtetra
.61933 .55292 .62441 .55849 .63458 .55548 .62952 .54988 Mtetra
.62952 .54988 .63458 .55548 .64479 .55245 .63976 .54684 Mtetra
.63976 .54684 .64479 .55245 .65504 .54941 .65003 .54378 Mtetra
.65003 .54378 .65504 .54941 .66532 .54637 .66034 .54071 Mtetra
.66034 .54071 .66532 .54637 .67564 .54331 .67069 .53763 Mtetra
.67069 .53763 .67564 .54331 .686 .54024 .68107 .53454 Mtetra
.68107 .53454 .686 .54024 .6964 .53716 .69149 .53144 Mtetra
.69149 .53144 .6964 .53716 .70684 .53406 .70196 .52833 Mtetra
.70196 .52833 .70684 .53406 .71731 .53096 .71246 .5252 Mtetra
.71246 .5252 .71731 .53096 .72782 .52785 .723 .52207 Mtetra
.723 .52207 .72782 .52785 .73838 .52472 .73358 .51892 Mtetra
.73358 .51892 .73838 .52472 .74897 .52158 .74419 .51576 Mtetra
.74419 .51576 .74897 .52158 .7596 .51844 .75485 .51259 Mtetra
.75485 .51259 .7596 .51844 .77027 .51528 .76555 .50942 Mtetra
.655 .752 .921 r
.76555 .50942 .77027 .51528 .78098 .51211 .77629 .50623 Mtetra
.77629 .50623 .78098 .51211 .79173 .50893 .78707 .50304 Mtetra
.78707 .50304 .79173 .50893 .80252 .50574 .79789 .49983 Mtetra
.79789 .49983 .80252 .50574 .81335 .50255 .80875 .49662 Mtetra
.80875 .49662 .81335 .50255 .82422 .49934 .81965 .4934 Mtetra
.655 .753 .922 r
.81965 .4934 .82422 .49934 .83513 .49612 .83059 .49016 Mtetra
.83059 .49016 .83513 .49612 .84609 .49288 .84158 .48691 Mtetra
.84158 .48691 .84609 .49288 .85708 .48963 .85261 .48364 Mtetra
.85261 .48364 .85708 .48963 .86812 .48637 .86367 .48035 Mtetra
.656 .754 .922 r
.86367 .48035 .86812 .48637 .8792 .48308 .87478 .47704 Mtetra
.87478 .47704 .8792 .48308 .89032 .47978 .88593 .47371 Mtetra
.657 .753 .921 r
.88593 .47371 .89032 .47978 .90148 .47646 .89712 .47036 Mtetra
.89712 .47036 .90148 .47646 .91268 .47312 .90835 .46698 Mtetra
.90835 .46698 .91268 .47312 .92393 .46976 .91963 .46359 Mtetra
.657 .753 .92 r
.91963 .46359 .92393 .46976 .93521 .46639 .93095 .46018 Mtetra
.653 .751 .921 r
.32399 .63404 .32977 .63908 .33894 .63639 .33318 .63135 Mtetra
.653 .752 .922 r
.33318 .63135 .33894 .63639 .34814 .63369 .34239 .62865 Mtetra
.654 .752 .922 r
.34239 .62865 .34814 .63369 .35737 .63097 .35164 .62593 Mtetra
.654 .753 .922 r
.35164 .62593 .35737 .63097 .36663 .62824 .36093 .62319 Mtetra
.655 .754 .923 r
.36093 .62319 .36663 .62824 .37593 .62548 .37024 .62043 Mtetra
.37024 .62043 .37593 .62548 .38526 .62271 .37959 .61765 Mtetra
.656 .755 .923 r
.37959 .61765 .38526 .62271 .39462 .61992 .38897 .61484 Mtetra
.38897 .61484 .39462 .61992 .40401 .61712 .39839 .61201 Mtetra
.657 .755 .922 r
.39839 .61201 .40401 .61712 .41344 .6143 .40784 .60917 Mtetra
.40784 .60917 .41344 .6143 .4229 .61146 .41732 .6063 Mtetra
.657 .754 .922 r
.41732 .6063 .4229 .61146 .43239 .60862 .42683 .60343 Mtetra
.657 .754 .921 r
.42683 .60343 .43239 .60862 .44192 .60576 .43638 .60055 Mtetra
.657 .753 .921 r
.43638 .60055 .44192 .60576 .45148 .6029 .44597 .59766 Mtetra
.44597 .59766 .45148 .6029 .46107 .60004 .45558 .59476 Mtetra
.656 .752 .921 r
.45558 .59476 .46107 .60004 .4707 .59716 .46523 .59186 Mtetra
.46523 .59186 .4707 .59716 .48037 .59428 .47492 .58895 Mtetra
.656 .752 .92 r
.47492 .58895 .48037 .59428 .49006 .59139 .48463 .58604 Mtetra
.48463 .58604 .49006 .59139 .49979 .58849 .49439 .58312 Mtetra
.49439 .58312 .49979 .58849 .50956 .58558 .50418 .58019 Mtetra
.656 .751 .92 r
.50418 .58019 .50956 .58558 .51936 .58267 .514 .57726 Mtetra
.514 .57726 .51936 .58267 .52919 .57974 .52386 .57431 Mtetra
.52386 .57431 .52919 .57974 .53907 .5768 .53375 .57135 Mtetra
.53375 .57135 .53907 .5768 .54897 .57385 .54368 .56838 Mtetra
.54368 .56838 .54897 .57385 .55891 .57089 .55365 .5654 Mtetra
.55365 .5654 .55891 .57089 .56889 .56792 .56365 .56241 Mtetra
.56365 .56241 .56889 .56792 .57891 .56494 .57369 .55941 Mtetra
.57369 .55941 .57891 .56494 .58896 .56195 .58376 .5564 Mtetra
.58376 .5564 .58896 .56195 .59904 .55895 .59387 .55338 Mtetra
.59387 .55338 .59904 .55895 .60917 .55594 .60402 .55035 Mtetra
.60402 .55035 .60917 .55594 .61933 .55292 .61421 .54731 Mtetra
.61421 .54731 .61933 .55292 .62952 .54988 .62443 .54425 Mtetra
.62443 .54425 .62952 .54988 .63976 .54684 .63469 .54118 Mtetra
.63469 .54118 .63976 .54684 .65003 .54378 .64498 .53811 Mtetra
.64498 .53811 .65003 .54378 .66034 .54071 .65532 .53502 Mtetra
.65532 .53502 .66034 .54071 .67069 .53763 .66569 .53192 Mtetra
.66569 .53192 .67069 .53763 .68107 .53454 .6761 .52881 Mtetra
.6761 .52881 .68107 .53454 .69149 .53144 .68655 .52568 Mtetra
.68655 .52568 .69149 .53144 .70196 .52833 .69704 .52255 Mtetra
.69704 .52255 .70196 .52833 .71246 .5252 .70757 .5194 Mtetra
.70757 .5194 .71246 .5252 .723 .52207 .71814 .51625 Mtetra
.71814 .51625 .723 .52207 .73358 .51892 .72874 .51308 Mtetra
.72874 .51308 .73358 .51892 .74419 .51576 .73939 .5099 Mtetra
.655 .752 .921 r
.73939 .5099 .74419 .51576 .75485 .51259 .75008 .50672 Mtetra
.75008 .50672 .75485 .51259 .76555 .50942 .7608 .50352 Mtetra
.7608 .50352 .76555 .50942 .77629 .50623 .77157 .50032 Mtetra
.77157 .50032 .77629 .50623 .78707 .50304 .78238 .49712 Mtetra
.655 .752 .922 r
.78238 .49712 .78707 .50304 .79789 .49983 .79323 .4939 Mtetra
.654 .753 .922 r
.79323 .4939 .79789 .49983 .80875 .49662 .80412 .49068 Mtetra
.80412 .49068 .80875 .49662 .81965 .4934 .81505 .48745 Mtetra
.654 .753 .923 r
.81505 .48745 .81965 .4934 .83059 .49016 .82603 .4842 Mtetra
.655 .754 .923 r
.82603 .4842 .83059 .49016 .84158 .48691 .83704 .48093 Mtetra
.83704 .48093 .84158 .48691 .85261 .48364 .8481 .47764 Mtetra
.655 .755 .923 r
.8481 .47764 .85261 .48364 .86367 .48035 .8592 .47433 Mtetra
.656 .755 .923 r
.8592 .47433 .86367 .48035 .87478 .47704 .87033 .47099 Mtetra
.656 .755 .922 r
.87033 .47099 .87478 .47704 .88593 .47371 .88151 .46762 Mtetra
.657 .755 .922 r
.88151 .46762 .88593 .47371 .89712 .47036 .89273 .46423 Mtetra
.657 .754 .921 r
.89273 .46423 .89712 .47036 .90835 .46698 .904 .46081 Mtetra
.658 .754 .921 r
.904 .46081 .90835 .46698 .91963 .46359 .9153 .45738 Mtetra
.658 .753 .92 r
.9153 .45738 .91963 .46359 .93095 .46018 .92665 .45393 Mtetra
.652 .751 .922 r
.31818 .62896 .32399 .63404 .33318 .63135 .32738 .62628 Mtetra
.652 .752 .922 r
.32738 .62628 .33318 .63135 .34239 .62865 .33661 .62359 Mtetra
.653 .753 .923 r
.33661 .62359 .34239 .62865 .35164 .62593 .34588 .62087 Mtetra
.653 .754 .923 r
.34588 .62087 .35164 .62593 .36093 .62319 .35518 .61814 Mtetra
.654 .755 .924 r
.35518 .61814 .36093 .62319 .37024 .62043 .36452 .61538 Mtetra
.36452 .61538 .37024 .62043 .37959 .61765 .37389 .61259 Mtetra
.655 .756 .924 r
.37389 .61259 .37959 .61765 .38897 .61484 .38329 .60977 Mtetra
.656 .756 .924 r
.38329 .60977 .38897 .61484 .39839 .61201 .39273 .60692 Mtetra
.657 .757 .923 r
.39273 .60692 .39839 .61201 .40784 .60917 .4022 .60405 Mtetra
.657 .756 .923 r
.4022 .60405 .40784 .60917 .41732 .6063 .4117 .60115 Mtetra
.658 .756 .922 r
.4117 .60115 .41732 .6063 .42683 .60343 .42124 .59824 Mtetra
.658 .755 .922 r
.42124 .59824 .42683 .60343 .43638 .60055 .43081 .59532 Mtetra
.657 .755 .922 r
.43081 .59532 .43638 .60055 .44597 .59766 .44041 .5924 Mtetra
.657 .754 .921 r
.44041 .5924 .44597 .59766 .45558 .59476 .45005 .58947 Mtetra
.657 .753 .921 r
.45005 .58947 .45558 .59476 .46523 .59186 .45972 .58653 Mtetra
.45972 .58653 .46523 .59186 .47492 .58895 .46943 .5836 Mtetra
.656 .752 .921 r
.46943 .5836 .47492 .58895 .48463 .58604 .47917 .58066 Mtetra
.656 .752 .92 r
.47917 .58066 .48463 .58604 .49439 .58312 .48895 .57772 Mtetra
.48895 .57772 .49439 .58312 .50418 .58019 .49876 .57477 Mtetra
.49876 .57477 .50418 .58019 .514 .57726 .5086 .57181 Mtetra
.5086 .57181 .514 .57726 .52386 .57431 .51849 .56884 Mtetra
.656 .751 .92 r
.51849 .56884 .52386 .57431 .53375 .57135 .5284 .56586 Mtetra
.5284 .56586 .53375 .57135 .54368 .56838 .53836 .56288 Mtetra
.53836 .56288 .54368 .56838 .55365 .5654 .54835 .55988 Mtetra
.54835 .55988 .55365 .5654 .56365 .56241 .55837 .55687 Mtetra
.55837 .55687 .56365 .56241 .57369 .55941 .56843 .55385 Mtetra
.56843 .55385 .57369 .55941 .58376 .5564 .57853 .55082 Mtetra
.57853 .55082 .58376 .5564 .59387 .55338 .58867 .54777 Mtetra
.58867 .54777 .59387 .55338 .60402 .55035 .59884 .54472 Mtetra
.59884 .54472 .60402 .55035 .61421 .54731 .60905 .54166 Mtetra
.60905 .54166 .61421 .54731 .62443 .54425 .6193 .53858 Mtetra
.6193 .53858 .62443 .54425 .63469 .54118 .62958 .53549 Mtetra
.62958 .53549 .63469 .54118 .64498 .53811 .63991 .5324 Mtetra
.63991 .5324 .64498 .53811 .65532 .53502 .65027 .52929 Mtetra
.65027 .52929 .65532 .53502 .66569 .53192 .66067 .52616 Mtetra
.66067 .52616 .66569 .53192 .6761 .52881 .6711 .52303 Mtetra
.6711 .52303 .6761 .52881 .68655 .52568 .68158 .51989 Mtetra
.68158 .51989 .68655 .52568 .69704 .52255 .6921 .51673 Mtetra
.6921 .51673 .69704 .52255 .70757 .5194 .70265 .51357 Mtetra
.70265 .51357 .70757 .5194 .71814 .51625 .71325 .51039 Mtetra
.71325 .51039 .71814 .51625 .72874 .51308 .72388 .5072 Mtetra
.655 .752 .921 r
.72388 .5072 .72874 .51308 .73939 .5099 .73455 .50401 Mtetra
.73455 .50401 .73939 .5099 .75008 .50672 .74527 .50081 Mtetra
.74527 .50081 .75008 .50672 .7608 .50352 .75602 .4976 Mtetra
.75602 .4976 .7608 .50352 .77157 .50032 .76682 .49439 Mtetra
.654 .752 .922 r
.76682 .49439 .77157 .50032 .78238 .49712 .77766 .49118 Mtetra
.654 .753 .922 r
.77766 .49118 .78238 .49712 .79323 .4939 .78854 .48796 Mtetra
.654 .753 .923 r
.78854 .48796 .79323 .4939 .80412 .49068 .79946 .48473 Mtetra
.654 .754 .923 r
.79946 .48473 .80412 .49068 .81505 .48745 .81042 .48149 Mtetra
.654 .755 .924 r
.81042 .48149 .81505 .48745 .82603 .4842 .82143 .47823 Mtetra
.82143 .47823 .82603 .4842 .83704 .48093 .83248 .47495 Mtetra
.655 .756 .924 r
.83248 .47495 .83704 .48093 .8481 .47764 .84356 .47164 Mtetra
.84356 .47164 .8481 .47764 .8592 .47433 .85469 .4683 Mtetra
.656 .756 .924 r
.85469 .4683 .8592 .47433 .87033 .47099 .86586 .46493 Mtetra
.657 .756 .923 r
.86586 .46493 .87033 .47099 .88151 .46762 .87707 .46152 Mtetra
.658 .756 .922 r
.87707 .46152 .88151 .46762 .89273 .46423 .88832 .45808 Mtetra
.658 .755 .922 r
.88832 .45808 .89273 .46423 .904 .46081 .89961 .45462 Mtetra
.659 .755 .921 r
.89961 .45462 .904 .46081 .9153 .45738 .91094 .45113 Mtetra
.659 .754 .92 r
.91094 .45113 .9153 .45738 .92665 .45393 .92232 .44763 Mtetra
.651 .75 .922 r
.31232 .62385 .31818 .62896 .32738 .62628 .32154 .62119 Mtetra
.651 .751 .923 r
.32154 .62119 .32738 .62628 .33661 .62359 .3308 .6185 Mtetra
.651 .753 .924 r
.3308 .6185 .33661 .62359 .34588 .62087 .34008 .6158 Mtetra
.652 .754 .925 r
.34008 .6158 .34588 .62087 .35518 .61814 .3494 .61308 Mtetra
.652 .755 .925 r
.3494 .61308 .35518 .61814 .36452 .61538 .35875 .61033 Mtetra
.653 .757 .925 r
.35875 .61033 .36452 .61538 .37389 .61259 .36814 .60754 Mtetra
.655 .758 .926 r
.36814 .60754 .37389 .61259 .38329 .60977 .37757 .60472 Mtetra
.656 .759 .925 r
.37757 .60472 .38329 .60977 .39273 .60692 .38702 .60186 Mtetra
.657 .759 .925 r
.38702 .60186 .39273 .60692 .4022 .60405 .39652 .59896 Mtetra
.658 .759 .925 r
.39652 .59896 .4022 .60405 .4117 .60115 .40604 .59603 Mtetra
.658 .759 .924 r
.40604 .59603 .4117 .60115 .42124 .59824 .4156 .59308 Mtetra
.659 .758 .923 r
.4156 .59308 .42124 .59824 .43081 .59532 .4252 .59011 Mtetra
.658 .757 .923 r
.4252 .59011 .43081 .59532 .44041 .5924 .43482 .58714 Mtetra
.658 .756 .922 r
.43482 .58714 .44041 .5924 .45005 .58947 .44448 .58417 Mtetra
.658 .755 .921 r
.44448 .58417 .45005 .58947 .45972 .58653 .45418 .5812 Mtetra
.657 .754 .921 r
.45418 .5812 .45972 .58653 .46943 .5836 .46391 .57823 Mtetra
.657 .753 .921 r
.46391 .57823 .46943 .5836 .47917 .58066 .47367 .57526 Mtetra
.656 .752 .921 r
.47367 .57526 .47917 .58066 .48895 .57772 .48347 .57229 Mtetra
.656 .752 .92 r
.48347 .57229 .48895 .57772 .49876 .57477 .4933 .56931 Mtetra
.4933 .56931 .49876 .57477 .5086 .57181 .50317 .56633 Mtetra
.50317 .56633 .5086 .57181 .51849 .56884 .51308 .56334 Mtetra
.51308 .56334 .51849 .56884 .5284 .56586 .52302 .56034 Mtetra
.656 .751 .92 r
.52302 .56034 .5284 .56586 .53836 .56288 .533 .55733 Mtetra
.533 .55733 .53836 .56288 .54835 .55988 .54301 .55431 Mtetra
.54301 .55431 .54835 .55988 .55837 .55687 .55306 .55128 Mtetra
.55306 .55128 .55837 .55687 .56843 .55385 .56314 .54824 Mtetra
.56314 .54824 .56843 .55385 .57853 .55082 .57327 .54519 Mtetra
.57327 .54519 .57853 .55082 .58867 .54777 .58343 .54213 Mtetra
.58343 .54213 .58867 .54777 .59884 .54472 .59363 .53905 Mtetra
.59363 .53905 .59884 .54472 .60905 .54166 .60386 .53597 Mtetra
.60386 .53597 .60905 .54166 .6193 .53858 .61413 .53287 Mtetra
.61413 .53287 .6193 .53858 .62958 .53549 .62444 .52976 Mtetra
.62444 .52976 .62958 .53549 .63991 .5324 .63479 .52665 Mtetra
.63479 .52665 .63991 .5324 .65027 .52929 .64518 .52351 Mtetra
.64518 .52351 .65027 .52929 .66067 .52616 .6556 .52037 Mtetra
.6556 .52037 .66067 .52616 .6711 .52303 .66607 .51722 Mtetra
.66607 .51722 .6711 .52303 .68158 .51989 .67657 .51405 Mtetra
.67657 .51405 .68158 .51989 .6921 .51673 .68711 .51088 Mtetra
.68711 .51088 .6921 .51673 .70265 .51357 .6977 .50769 Mtetra
.655 .752 .921 r
.6977 .50769 .70265 .51357 .71325 .51039 .70832 .5045 Mtetra
.70832 .5045 .71325 .51039 .72388 .5072 .71898 .50129 Mtetra
.71898 .50129 .72388 .5072 .73455 .50401 .72968 .49809 Mtetra
.72968 .49809 .73455 .50401 .74527 .50081 .74043 .49487 Mtetra
.654 .752 .922 r
.74043 .49487 .74527 .50081 .75602 .4976 .75121 .49166 Mtetra
.654 .753 .922 r
.75121 .49166 .75602 .4976 .76682 .49439 .76204 .48845 Mtetra
.653 .753 .923 r
.76204 .48845 .76682 .49439 .77766 .49118 .77291 .48524 Mtetra
.653 .754 .924 r
.77291 .48524 .77766 .49118 .78854 .48796 .78382 .48202 Mtetra
.652 .755 .925 r
.78382 .48202 .78854 .48796 .79946 .48473 .79477 .4788 Mtetra
.652 .756 .925 r
.79477 .4788 .79946 .48473 .81042 .48149 .80577 .47556 Mtetra
.653 .757 .926 r
.80577 .47556 .81042 .48149 .82143 .47823 .81681 .4723 Mtetra
.654 .758 .926 r
.81681 .4723 .82143 .47823 .83248 .47495 .82788 .469 Mtetra
.655 .758 .926 r
.82788 .469 .83248 .47495 .84356 .47164 .839 .46566 Mtetra
.656 .759 .925 r
.839 .46566 .84356 .47164 .85469 .4683 .85016 .46228 Mtetra
.657 .759 .925 r
.85016 .46228 .85469 .4683 .86586 .46493 .86136 .45886 Mtetra
.658 .758 .924 r
.86136 .45886 .86586 .46493 .87707 .46152 .8726 .4554 Mtetra
.659 .757 .923 r
.8726 .4554 .87707 .46152 .88832 .45808 .88387 .45191 Mtetra
.659 .757 .922 r
.88387 .45191 .88832 .45808 .89961 .45462 .89519 .44839 Mtetra
.66 .756 .921 r
.89519 .44839 .89961 .45462 .91094 .45113 .90656 .44484 Mtetra
.66 .754 .92 r
.90656 .44484 .91094 .45113 .92232 .44763 .91796 .44128 Mtetra
.649 .75 .923 r
.30643 .61871 .31232 .62385 .32154 .62119 .31567 .61606 Mtetra
.649 .751 .924 r
.31567 .61606 .32154 .62119 .3308 .6185 .32494 .6134 Mtetra
.649 .753 .925 r
.32494 .6134 .3308 .6185 .34008 .6158 .33424 .61072 Mtetra
.65 .754 .926 r
.33424 .61072 .34008 .6158 .3494 .61308 .34358 .60802 Mtetra
.651 .756 .927 r
.34358 .60802 .3494 .61308 .35875 .61033 .35295 .60529 Mtetra
.652 .758 .927 r
.35295 .60529 .35875 .61033 .36814 .60754 .36236 .60252 Mtetra
.653 .759 .928 r
.36236 .60252 .36814 .60754 .37757 .60472 .3718 .5997 Mtetra
.655 .761 .928 r
.3718 .5997 .37757 .60472 .38702 .60186 .38128 .59684 Mtetra
.657 .762 .927 r
.38128 .59684 .38702 .60186 .39652 .59896 .39079 .59392 Mtetra
.658 .762 .927 r
.39079 .59392 .39652 .59896 .40604 .59603 .40034 .59096 Mtetra
.659 .762 .926 r
.40034 .59096 .40604 .59603 .4156 .59308 .40993 .58796 Mtetra
.66 .761 .925 r
.40993 .58796 .4156 .59308 .4252 .59011 .41954 .58494 Mtetra
.66 .76 .924 r
.41954 .58494 .4252 .59011 .43482 .58714 .42919 .58192 Mtetra
.66 .758 .923 r
.42919 .58192 .43482 .58714 .44448 .58417 .43888 .57889 Mtetra
.659 .757 .922 r
.43888 .57889 .44448 .58417 .45418 .5812 .4486 .57586 Mtetra
.658 .755 .922 r
.4486 .57586 .45418 .5812 .46391 .57823 .45835 .57285 Mtetra
.658 .754 .921 r
.45835 .57285 .46391 .57823 .47367 .57526 .46814 .56984 Mtetra
.657 .753 .921 r
.46814 .56984 .47367 .57526 .48347 .57229 .47796 .56683 Mtetra
.47796 .56683 .48347 .57229 .4933 .56931 .48781 .56383 Mtetra
.656 .752 .921 r
.48781 .56383 .4933 .56931 .50317 .56633 .49771 .56082 Mtetra
.656 .752 .92 r
.49771 .56082 .50317 .56633 .51308 .56334 .50763 .55781 Mtetra
.50763 .55781 .51308 .56334 .52302 .56034 .5176 .55479 Mtetra
.5176 .55479 .52302 .56034 .533 .55733 .5276 .55176 Mtetra
.5276 .55176 .533 .55733 .54301 .55431 .53764 .54871 Mtetra
.656 .751 .92 r
.53764 .54871 .54301 .55431 .55306 .55128 .54771 .54566 Mtetra
.54771 .54566 .55306 .55128 .56314 .54824 .55782 .5426 Mtetra
.55782 .5426 .56314 .54824 .57327 .54519 .56797 .53953 Mtetra
.56797 .53953 .57327 .54519 .58343 .54213 .57815 .53645 Mtetra
.57815 .53645 .58343 .54213 .59363 .53905 .58837 .53335 Mtetra
.58837 .53335 .59363 .53905 .60386 .53597 .59864 .53024 Mtetra
.59864 .53024 .60386 .53597 .61413 .53287 .60893 .52713 Mtetra
.60893 .52713 .61413 .53287 .62444 .52976 .61927 .524 Mtetra
.61927 .524 .62444 .52976 .63479 .52665 .62964 .52086 Mtetra
.62964 .52086 .63479 .52665 .64518 .52351 .64006 .5177 Mtetra
.64006 .5177 .64518 .52351 .6556 .52037 .65051 .51454 Mtetra
.65051 .51454 .6556 .52037 .66607 .51722 .661 .51137 Mtetra
.661 .51137 .66607 .51722 .67657 .51405 .67153 .50818 Mtetra
.67153 .50818 .67657 .51405 .68711 .51088 .6821 .50499 Mtetra
.655 .752 .921 r
.6821 .50499 .68711 .51088 .6977 .50769 .69271 .50178 Mtetra
.69271 .50178 .6977 .50769 .70832 .5045 .70336 .49857 Mtetra
.70336 .49857 .70832 .5045 .71898 .50129 .71405 .49536 Mtetra
.654 .752 .921 r
.71405 .49536 .71898 .50129 .72968 .49809 .72478 .49214 Mtetra
.654 .752 .922 r
.72478 .49214 .72968 .49809 .74043 .49487 .73555 .48893 Mtetra
.653 .753 .923 r
.73555 .48893 .74043 .49487 .75121 .49166 .74637 .48572 Mtetra
.652 .753 .924 r
.74637 .48572 .75121 .49166 .76204 .48845 .75723 .48252 Mtetra
.651 .754 .925 r
.75723 .48252 .76204 .48845 .77291 .48524 .76813 .47932 Mtetra
.651 .756 .926 r
.76813 .47932 .77291 .48524 .78382 .48202 .77907 .47612 Mtetra
.651 .757 .927 r
.77907 .47612 .78382 .48202 .79477 .4788 .79006 .47291 Mtetra
.651 .758 .928 r
.79006 .47291 .79477 .4788 .80577 .47556 .80109 .46968 Mtetra
.652 .76 .928 r
.80109 .46968 .80577 .47556 .81681 .4723 .81216 .4664 Mtetra
.653 .761 .928 r
.81216 .4664 .81681 .4723 .82788 .469 .82327 .46308 Mtetra
.655 .762 .928 r
.82327 .46308 .82788 .469 .839 .46566 .83441 .45971 Mtetra
.657 .762 .927 r
.83441 .45971 .839 .46566 .85016 .46228 .8456 .45627 Mtetra
.658 .761 .926 r
.8456 .45627 .85016 .46228 .86136 .45886 .85683 .45279 Mtetra
.659 .76 .925 r
.85683 .45279 .86136 .45886 .8726 .4554 .86809 .44927 Mtetra
.66 .759 .923 r
.86809 .44927 .8726 .4554 .88387 .45191 .8794 .44571 Mtetra
.661 .758 .922 r
.8794 .44571 .88387 .45191 .89519 .44839 .89075 .44212 Mtetra
.661 .757 .921 r
.89075 .44212 .89519 .44839 .90656 .44484 .90214 .43851 Mtetra
.661 .755 .92 r
.90214 .43851 .90656 .44484 .91796 .44128 .91357 .43489 Mtetra
.648 .749 .924 r
.3005 .61354 .30643 .61871 .31567 .61606 .30976 .6109 Mtetra
.648 .751 .925 r
.30976 .6109 .31567 .61606 .32494 .6134 .31904 .60825 Mtetra
.648 .752 .926 r
.31904 .60825 .32494 .6134 .33424 .61072 .32836 .6056 Mtetra
.648 .754 .927 r
.32836 .6056 .33424 .61072 .34358 .60802 .33772 .60293 Mtetra
.648 .755 .928 r
.33772 .60293 .34358 .60802 .35295 .60529 .34711 .60023 Mtetra
.649 .758 .929 r
.34711 .60023 .35295 .60529 .36236 .60252 .35654 .59749 Mtetra
.651 .76 .929 r
.35654 .59749 .36236 .60252 .3718 .5997 .366 .59471 Mtetra
.653 .763 .93 r
.366 .59471 .3718 .5997 .38128 .59684 .3755 .59186 Mtetra
.655 .765 .93 r
.3755 .59186 .38128 .59684 .39079 .59392 .38503 .58895 Mtetra
.658 .766 .93 r
.38503 .58895 .39079 .59392 .40034 .59096 .3946 .58597 Mtetra
.66 .767 .929 r
.3946 .58597 .40034 .59096 .40993 .58796 .40421 .58293 Mtetra
.661 .766 .928 r
.40421 .58293 .40993 .58796 .41954 .58494 .41385 .57986 Mtetra
.662 .765 .926 r
.41385 .57986 .41954 .58494 .42919 .58192 .42352 .57676 Mtetra
.662 .763 .925 r
.42352 .57676 .42919 .58192 .43888 .57889 .43323 .57366 Mtetra
.661 .761 .924 r
.43323 .57366 .43888 .57889 .4486 .57586 .44297 .57056 Mtetra
.66 .759 .923 r
.44297 .57056 .4486 .57586 .45835 .57285 .45275 .56748 Mtetra
.659 .757 .922 r
.45275 .56748 .45835 .57285 .46814 .56984 .46256 .56442 Mtetra
.658 .755 .922 r
.46256 .56442 .46814 .56984 .47796 .56683 .47241 .56137 Mtetra
.657 .754 .921 r
.47241 .56137 .47796 .56683 .48781 .56383 .48229 .55833 Mtetra
.657 .753 .921 r
.48229 .55833 .48781 .56383 .49771 .56082 .4922 .55529 Mtetra
.656 .752 .921 r
.4922 .55529 .49771 .56082 .50763 .55781 .50215 .55225 Mtetra
.50215 .55225 .50763 .55781 .5176 .55479 .51214 .5492 Mtetra
.656 .752 .92 r
.51214 .5492 .5176 .55479 .5276 .55176 .52217 .54614 Mtetra
.52217 .54614 .5276 .55176 .53764 .54871 .53223 .54308 Mtetra
.53223 .54308 .53764 .54871 .54771 .54566 .54232 .54001 Mtetra
.54232 .54001 .54771 .54566 .55782 .5426 .55246 .53692 Mtetra
.55246 .53692 .55782 .5426 .56797 .53953 .56263 .53383 Mtetra
.656 .751 .92 r
.56263 .53383 .56797 .53953 .57815 .53645 .57284 .53072 Mtetra
.57284 .53072 .57815 .53645 .58837 .53335 .58309 .52761 Mtetra
.58309 .52761 .58837 .53335 .59864 .53024 .59337 .52448 Mtetra
.59337 .52448 .59864 .53024 .60893 .52713 .6037 .52134 Mtetra
.6037 .52134 .60893 .52713 .61927 .524 .61406 .51819 Mtetra
.61406 .51819 .61927 .524 .62964 .52086 .62446 .51503 Mtetra
.62446 .51503 .62964 .52086 .64006 .5177 .6349 .51186 Mtetra
.6349 .51186 .64006 .5177 .65051 .51454 .64538 .50867 Mtetra
.656 .752 .92 r
.64538 .50867 .65051 .51454 .661 .51137 .6559 .50548 Mtetra
.656 .752 .921 r
.6559 .50548 .661 .51137 .67153 .50818 .66645 .50228 Mtetra
.655 .752 .921 r
.66645 .50228 .67153 .50818 .6821 .50499 .67705 .49906 Mtetra
.67705 .49906 .6821 .50499 .69271 .50178 .68769 .49585 Mtetra
.68769 .49585 .69271 .50178 .70336 .49857 .69836 .49262 Mtetra
.654 .752 .922 r
.69836 .49262 .70336 .49857 .71405 .49536 .70908 .48941 Mtetra
.653 .753 .923 r
.70908 .48941 .71405 .49536 .72478 .49214 .71985 .48619 Mtetra
.652 .753 .924 r
.71985 .48619 .72478 .49214 .73555 .48893 .73065 .48299 Mtetra
.651 .754 .925 r
.73065 .48299 .73555 .48893 .74637 .48572 .7415 .47981 Mtetra
.65 .755 .926 r
.7415 .47981 .74637 .48572 .75723 .48252 .75239 .47663 Mtetra
.649 .757 .928 r
.75239 .47663 .75723 .48252 .76813 .47932 .76332 .47347 Mtetra
.648 .759 .93 r
.76332 .47347 .76813 .47932 .77907 .47612 .7743 .4703 Mtetra
.649 .761 .931 r
.7743 .4703 .77907 .47612 .79006 .47291 .78532 .46711 Mtetra
.65 .763 .932 r
.78532 .46711 .79006 .47291 .80109 .46968 .79638 .46387 Mtetra
.652 .764 .932 r
.79638 .46387 .80109 .46968 .81216 .4664 .80748 .46057 Mtetra
.654 .765 .931 r
.80748 .46057 .81216 .4664 .82327 .46308 .81862 .45721 Mtetra
.656 .765 .93 r
.81862 .45721 .82327 .46308 .83441 .45971 .8298 .45377 Mtetra
.658 .765 .928 r
.8298 .45377 .83441 .45971 .8456 .45627 .84101 .45026 Mtetra
.66 .763 .926 r
.84101 .45026 .8456 .45627 .85683 .45279 .85227 .4467 Mtetra
.661 .762 .924 r
.85227 .4467 .85683 .45279 .86809 .44927 .86356 .44309 Mtetra
.662 .76 .923 r
.86356 .44309 .86809 .44927 .8794 .44571 .87489 .43946 Mtetra
.662 .758 .921 r
.87489 .43946 .8794 .44571 .89075 .44212 .88627 .43581 Mtetra
.663 .757 .92 r
.88627 .43581 .89075 .44212 .90214 .43851 .89769 .43214 Mtetra
.663 .755 .919 r
.89769 .43214 .90214 .43851 .91357 .43489 .90915 .42846 Mtetra
.647 .749 .924 r
.29453 .60833 .3005 .61354 .30976 .6109 .3038 .60569 Mtetra
.646 .75 .925 r
.3038 .60569 .30976 .6109 .31904 .60825 .31311 .60306 Mtetra
.646 .751 .926 r
.31311 .60306 .31904 .60825 .32836 .6056 .32245 .60042 Mtetra
.646 .752 .927 r
.32245 .60042 .32836 .6056 .33772 .60293 .33182 .59778 Mtetra
.645 .754 .928 r
.33182 .59778 .33772 .60293 .34711 .60023 .34123 .59512 Mtetra
.646 .757 .93 r
.34123 .59512 .34711 .60023 .35654 .59749 .35067 .59244 Mtetra
.647 .76 .931 r
.35067 .59244 .35654 .59749 .366 .59471 .36015 .58972 Mtetra
.649 .763 .932 r
.36015 .58972 .366 .59471 .3755 .59186 .36967 .58692 Mtetra
.653 .767 .933 r
.36967 .58692 .3755 .59186 .38503 .58895 .37922 .58405 Mtetra
.656 .77 .933 r
.37922 .58405 .38503 .58895 .3946 .58597 .38881 .58108 Mtetra
.659 .772 .932 r
.38881 .58108 .3946 .58597 .40421 .58293 .39844 .57802 Mtetra
.662 .772 .931 r
.39844 .57802 .40421 .58293 .41385 .57986 .40811 .57489 Mtetra
.664 .771 .93 r
.40811 .57489 .41385 .57986 .42352 .57676 .41781 .57171 Mtetra
.664 .769 .928 r
.41781 .57171 .42352 .57676 .43323 .57366 .42754 .56852 Mtetra
.663 .766 .926 r
.42754 .56852 .43323 .57366 .44297 .57056 .43731 .56534 Mtetra
.662 .763 .925 r
.43731 .56534 .44297 .57056 .45275 .56748 .44711 .56217 Mtetra
.661 .76 .924 r
.44711 .56217 .45275 .56748 .46256 .56442 .45695 .55903 Mtetra
.66 .758 .923 r
.45695 .55903 .46256 .56442 .47241 .56137 .46682 .55592 Mtetra
.658 .756 .922 r
.46682 .55592 .47241 .56137 .48229 .55833 .47672 .55282 Mtetra
.658 .755 .921 r
.47672 .55282 .48229 .55833 .4922 .55529 .48666 .54974 Mtetra
.657 .753 .921 r
.48666 .54974 .4922 .55529 .50215 .55225 .49664 .54666 Mtetra
.49664 .54666 .50215 .55225 .51214 .5492 .50665 .54358 Mtetra
.656 .752 .921 r
.50665 .54358 .51214 .5492 .52217 .54614 .5167 .5405 Mtetra
.5167 .5405 .52217 .54614 .53223 .54308 .52678 .53741 Mtetra
.656 .752 .92 r
.52678 .53741 .53223 .54308 .54232 .54001 .5369 .53432 Mtetra
.5369 .53432 .54232 .54001 .55246 .53692 .54706 .53121 Mtetra
.54706 .53121 .55246 .53692 .56263 .53383 .55726 .52809 Mtetra
.55726 .52809 .56263 .53383 .57284 .53072 .56749 .52497 Mtetra
.56749 .52497 .57284 .53072 .58309 .52761 .57777 .52183 Mtetra
.57777 .52183 .58309 .52761 .59337 .52448 .58808 .51868 Mtetra
.58808 .51868 .59337 .52448 .6037 .52134 .59843 .51552 Mtetra
.59843 .51552 .6037 .52134 .61406 .51819 .60881 .51235 Mtetra
.60881 .51235 .61406 .51819 .62446 .51503 .61924 .50917 Mtetra
.61924 .50917 .62446 .51503 .6349 .51186 .62971 .50597 Mtetra
.656 .752 .921 r
.62971 .50597 .6349 .51186 .64538 .50867 .64021 .50277 Mtetra
.655 .752 .921 r
.64021 .50277 .64538 .50867 .6559 .50548 .65076 .49956 Mtetra
.65076 .49956 .6559 .50548 .66645 .50228 .66134 .49634 Mtetra
.66134 .49634 .66645 .50228 .67705 .49906 .67197 .49311 Mtetra
.654 .752 .922 r
.67197 .49311 .67705 .49906 .68769 .49585 .68263 .48989 Mtetra
.68263 .48989 .68769 .49585 .69836 .49262 .69334 .48667 Mtetra
.653 .753 .923 r
.69334 .48667 .69836 .49262 .70908 .48941 .70409 .48346 Mtetra
.651 .754 .924 r
.70409 .48346 .70908 .48941 .71985 .48619 .71488 .48027 Mtetra
.65 .755 .926 r
.71488 .48027 .71985 .48619 .73065 .48299 .72572 .4771 Mtetra
.648 .756 .928 r
.72572 .4771 .73065 .48299 .7415 .47981 .7366 .47396 Mtetra
.647 .758 .93 r
.7366 .47396 .7415 .47981 .75239 .47663 .74752 .47084 Mtetra
.645 .76 .933 r
.74752 .47084 .75239 .47663 .76332 .47347 .75849 .46773 Mtetra
.645 .763 .935 r
.75849 .46773 .76332 .47347 .7743 .4703 .76951 .4646 Mtetra
.647 .766 .936 r
.76951 .4646 .7743 .4703 .78532 .46711 .78056 .46141 Mtetra
.649 .768 .936 r
.78056 .46141 .78532 .46711 .79638 .46387 .79165 .45816 Mtetra
.652 .77 .935 r
.79165 .45816 .79638 .46387 .80748 .46057 .80278 .45481 Mtetra
.656 .77 .933 r
.80278 .45481 .80748 .46057 .81862 .45721 .81395 .45136 Mtetra
.659 .769 .931 r
.81395 .45136 .81862 .45721 .8298 .45377 .82515 .44782 Mtetra
.661 .767 .928 r
.82515 .44782 .8298 .45377 .84101 .45026 .83639 .44421 Mtetra
.663 .765 .926 r
.83639 .44421 .84101 .45026 .85227 .4467 .84767 .44055 Mtetra
.664 .762 .923 r
.84767 .44055 .85227 .4467 .86356 .44309 .85899 .43685 Mtetra
.664 .76 .922 r
.85899 .43685 .86356 .44309 .87489 .43946 .87035 .43315 Mtetra
.664 .758 .92 r
.87035 .43315 .87489 .43946 .88627 .43581 .88175 .42943 Mtetra
.664 .757 .919 r
.88175 .42943 .88627 .43581 .89769 .43214 .8932 .4257 Mtetra
.663 .755 .919 r
.8932 .4257 .89769 .43214 .90915 .42846 .90469 .42197 Mtetra
.647 .749 .924 r
.28853 .60308 .29453 .60833 .3038 .60569 .29782 .60042 Mtetra
.646 .749 .924 r
.29782 .60042 .3038 .60569 .31311 .60306 .30714 .59777 Mtetra
.645 .749 .924 r
.30714 .59777 .31311 .60306 .32245 .60042 .3165 .59513 Mtetra
.644 .749 .925 r
.3165 .59513 .32245 .60042 .33182 .59778 .32589 .5925 Mtetra
.643 .75 .926 r
.32589 .5925 .33182 .59778 .34123 .59512 .33531 .58989 Mtetra
.643 .752 .928 r
.33531 .58989 .34123 .59512 .35067 .59244 .34477 .58727 Mtetra
.643 .755 .93 r
.34477 .58727 .35067 .59244 .36015 .58972 .35427 .58464 Mtetra
.644 .76 .933 r
.35427 .58464 .36015 .58972 .36967 .58692 .3638 .58194 Mtetra
.648 .765 .935 r
.3638 .58194 .36967 .58692 .37922 .58405 .37337 .57915 Mtetra
.652 .77 .936 r
.37337 .57915 .37922 .58405 .38881 .58108 .38298 .57626 Mtetra
.657 .775 .936 r
.38298 .57626 .38881 .58108 .39844 .57802 .39263 .57322 Mtetra
.661 .778 .936 r
.39263 .57322 .39844 .57802 .40811 .57489 .40232 .57008 Mtetra
.665 .779 .934 r
.40232 .57008 .40811 .57489 .41781 .57171 .41205 .56685 Mtetra
.667 .778 .933 r
.41205 .56685 .41781 .57171 .42754 .56852 .42181 .56356 Mtetra
.667 .775 .931 r
.42181 .56356 .42754 .56852 .43731 .56534 .4316 .56026 Mtetra
.666 .771 .928 r
.4316 .56026 .43731 .56534 .44711 .56217 .44143 .55698 Mtetra
.664 .767 .927 r
.44143 .55698 .44711 .56217 .45695 .55903 .45129 .55373 Mtetra
.662 .763 .925 r
.45129 .55373 .45695 .55903 .46682 .55592 .46119 .55052 Mtetra
.661 .76 .924 r
.46119 .55052 .46682 .55592 .47672 .55282 .47112 .54735 Mtetra
.659 .758 .923 r
.47112 .54735 .47672 .55282 .48666 .54974 .48108 .54421 Mtetra
.658 .756 .922 r
.48108 .54421 .48666 .54974 .49664 .54666 .49108 .54108 Mtetra
.657 .754 .922 r
.49108 .54108 .49664 .54666 .50665 .54358 .50112 .53796 Mtetra
.657 .753 .921 r
.50112 .53796 .50665 .54358 .5167 .5405 .51119 .53484 Mtetra
.656 .753 .921 r
.51119 .53484 .5167 .5405 .52678 .53741 .5213 .53172 Mtetra
.656 .752 .921 r
.5213 .53172 .52678 .53741 .5369 .53432 .53144 .5286 Mtetra
.53144 .5286 .5369 .53432 .54706 .53121 .54163 .52547 Mtetra
.54163 .52547 .54706 .53121 .55726 .52809 .55185 .52233 Mtetra
.55185 .52233 .55726 .52809 .56749 .52497 .56211 .51918 Mtetra
.56211 .51918 .56749 .52497 .57777 .52183 .57241 .51602 Mtetra
.57241 .51602 .57777 .52183 .58808 .51868 .58274 .51285 Mtetra
.58274 .51285 .58808 .51868 .59843 .51552 .59312 .50967 Mtetra
.59312 .50967 .59843 .51552 .60881 .51235 .60353 .50647 Mtetra
.60353 .50647 .60881 .51235 .61924 .50917 .61399 .50327 Mtetra
.655 .752 .921 r
.61399 .50327 .61924 .50917 .62971 .50597 .62448 .50006 Mtetra
.62448 .50006 .62971 .50597 .64021 .50277 .63501 .49684 Mtetra
.63501 .49684 .64021 .50277 .65076 .49956 .64558 .49362 Mtetra
.655 .752 .922 r
.64558 .49362 .65076 .49956 .66134 .49634 .65619 .49039 Mtetra
.654 .753 .922 r
.65619 .49039 .66134 .49634 .67197 .49311 .66685 .48716 Mtetra
.653 .753 .923 r
.66685 .48716 .67197 .49311 .68263 .48989 .67754 .48395 Mtetra
.652 .754 .924 r
.67754 .48395 .68263 .48989 .69334 .48667 .68828 .48075 Mtetra
.65 .755 .926 r
.68828 .48075 .69334 .48667 .70409 .48346 .69906 .47757 Mtetra
.648 .756 .928 r
.69906 .47757 .70409 .48346 .71488 .48027 .70989 .47443 Mtetra
.646 .758 .931 r
.70989 .47443 .71488 .48027 .72572 .4771 .72076 .47133 Mtetra
.643 .76 .934 r
.72076 .47133 .72572 .4771 .7366 .47396 .73167 .46827 Mtetra
.642 .764 .937 r
.73167 .46827 .7366 .47396 .74752 .47084 .74264 .46522 Mtetra
.641 .767 .94 r
.74264 .46522 .74752 .47084 .75849 .46773 .75364 .46216 Mtetra
.642 .77 .941 r
.75364 .46216 .75849 .46773 .76951 .4646 .76469 .45905 Mtetra
.646 .774 .941 r
.76469 .45905 .76951 .4646 .78056 .46141 .77578 .45584 Mtetra
.65 .775 .94 r
.77578 .45584 .78056 .46141 .79165 .45816 .7869 .45251 Mtetra
.655 .775 .937 r
.7869 .45251 .79165 .45816 .80278 .45481 .79805 .44904 Mtetra
.66 .773 .933 r
.79805 .44904 .80278 .45481 .81395 .45136 .80924 .44546 Mtetra
.664 .77 .929 r
.80924 .44546 .81395 .45136 .82515 .44782 .82047 .44177 Mtetra
.666 .767 .925 r
.82047 .44177 .82515 .44782 .83639 .44421 .83173 .43803 Mtetra
.666 .763 .922 r
.83173 .43803 .83639 .44421 .84767 .44055 .84303 .43425 Mtetra
.666 .76 .92 r
.84303 .43425 .84767 .44055 .85899 .43685 .85437 .43047 Mtetra
.665 .757 .919 r
.85437 .43047 .85899 .43685 .87035 .43315 .86576 .4267 Mtetra
.665 .755 .918 r
.86576 .4267 .87035 .43315 .88175 .42943 .8772 .42294 Mtetra
.664 .755 .918 r
.8772 .42294 .88175 .42943 .8932 .4257 .88868 .41919 Mtetra
.663 .754 .918 r
.88868 .41919 .8932 .4257 .90469 .42197 .90021 .41544 Mtetra
.649 .75 .923 r
.28248 .59781 .28853 .60308 .29782 .60042 .29179 .59508 Mtetra
.648 .748 .922 r
.29179 .59508 .29782 .60042 .30714 .59777 .30114 .59237 Mtetra
.647 .746 .922 r
.30114 .59237 .30714 .59777 .3165 .59513 .31052 .58969 Mtetra
.645 .745 .922 r
.31052 .58969 .3165 .59513 .32589 .5925 .31993 .58704 Mtetra
.642 .744 .923 r
.31993 .58704 .32589 .5925 .33531 .58989 .32937 .58445 Mtetra
.64 .745 .925 r
.32937 .58445 .33531 .58989 .34477 .58727 .33884 .5819 Mtetra
.638 .747 .928 r
.33884 .5819 .34477 .58727 .35427 .58464 .34835 .57937 Mtetra
.638 .752 .931 r
.34835 .57937 .35427 .58464 .3638 .58194 .3579 .57681 Mtetra
.64 .759 .935 r
.3579 .57681 .3638 .58194 .37337 .57915 .36748 .57419 Mtetra
.644 .767 .938 r
.36748 .57419 .37337 .57915 .38298 .57626 .37711 .57144 Mtetra
.651 .775 .94 r
.37711 .57144 .38298 .57626 .39263 .57322 .38678 .56852 Mtetra
.657 .782 .94 r
.38678 .56852 .39263 .57322 .40232 .57008 .39649 .56544 Mtetra
.664 .787 .94 r
.39649 .56544 .40232 .57008 .41205 .56685 .40624 .56218 Mtetra
.668 .788 .938 r
.40624 .56218 .41205 .56685 .42181 .56356 .41603 .55882 Mtetra
.67 .786 .936 r
.41603 .55882 .42181 .56356 .4316 .56026 .42585 .5554 Mtetra
.67 .782 .933 r
.42585 .5554 .4316 .56026 .44143 .55698 .43571 .55197 Mtetra
.669 .777 .931 r
.43571 .55197 .44143 .55698 .45129 .55373 .4456 .54859 Mtetra
.667 .772 .928 r
.4456 .54859 .45129 .55373 .46119 .55052 .45552 .54525 Mtetra
.664 .767 .926 r
.45552 .54525 .46119 .55052 .47112 .54735 .46547 .54196 Mtetra
.662 .763 .925 r
.46547 .54196 .47112 .54735 .48108 .54421 .47546 .53873 Mtetra
.66 .76 .924 r
.47546 .53873 .48108 .54421 .49108 .54108 .48549 .53552 Mtetra
.659 .757 .923 r
.48549 .53552 .49108 .54108 .50112 .53796 .49555 .53235 Mtetra
.658 .756 .922 r
.49555 .53235 .50112 .53796 .51119 .53484 .50564 .52918 Mtetra
.657 .755 .922 r
.50564 .52918 .51119 .53484 .5213 .53172 .51578 .52603 Mtetra
.657 .754 .922 r
.51578 .52603 .5213 .53172 .53144 .5286 .52595 .52287 Mtetra
.656 .753 .921 r
.52595 .52287 .53144 .5286 .54163 .52547 .53616 .51971 Mtetra
.53616 .51971 .54163 .52547 .55185 .52233 .5464 .51654 Mtetra
.5464 .51654 .55185 .52233 .56211 .51918 .55669 .51337 Mtetra
.656 .752 .921 r
.55669 .51337 .56211 .51918 .57241 .51602 .56701 .51018 Mtetra
.56701 .51018 .57241 .51602 .58274 .51285 .57737 .50699 Mtetra
.57737 .50699 .58274 .51285 .59312 .50967 .58777 .50379 Mtetra
.655 .752 .921 r
.58777 .50379 .59312 .50967 .60353 .50647 .59821 .50058 Mtetra
.59821 .50058 .60353 .50647 .61399 .50327 .60869 .49736 Mtetra
.655 .753 .922 r
.60869 .49736 .61399 .50327 .62448 .50006 .61921 .49413 Mtetra
.61921 .49413 .62448 .50006 .63501 .49684 .62977 .4909 Mtetra
.654 .753 .922 r
.62977 .4909 .63501 .49684 .64558 .49362 .64037 .48767 Mtetra
.653 .753 .923 r
.64037 .48767 .64558 .49362 .65619 .49039 .65101 .48445 Mtetra
.652 .754 .924 r
.65101 .48445 .65619 .49039 .66685 .48716 .6617 .48124 Mtetra
.651 .755 .926 r
.6617 .48124 .66685 .48716 .67754 .48395 .67242 .47805 Mtetra
.649 .756 .928 r
.67242 .47805 .67754 .48395 .68828 .48075 .68319 .4749 Mtetra
.646 .758 .93 r
.68319 .4749 .68828 .48075 .69906 .47757 .694 .4718 Mtetra
.643 .76 .934 r
.694 .4718 .69906 .47757 .70989 .47443 .70487 .46875 Mtetra
.64 .763 .938 r
.70487 .46875 .70989 .47443 .72076 .47133 .71577 .46575 Mtetra
.636 .767 .942 r
.71577 .46575 .72076 .47133 .73167 .46827 .72673 .46279 Mtetra
.635 .771 .945 r
.72673 .46279 .73167 .46827 .74264 .46522 .73773 .45982 Mtetra
.637 .776 .947 r
.73773 .45982 .74264 .46522 .75364 .46216 .74877 .4568 Mtetra
.64 .779 .948 r
.74877 .4568 .75364 .46216 .76469 .45905 .75985 .45366 Mtetra
.648 .782 .946 r
.75985 .45366 .76469 .45905 .77578 .45584 .77097 .45035 Mtetra
.655 .782 .942 r
.77097 .45035 .77578 .45584 .7869 .45251 .78211 .44686 Mtetra
.662 .779 .936 r
.78211 .44686 .7869 .45251 .79805 .44904 .79329 .4432 Mtetra
.667 .774 .93 r
.79329 .4432 .79805 .44904 .80924 .44546 .80449 .4394 Mtetra
.67 .768 .924 r
.80449 .4394 .80924 .44546 .82047 .44177 .81573 .43552 Mtetra
.671 .763 .919 r
.81573 .43552 .82047 .44177 .83173 .43803 .82701 .43162 Mtetra
.67 .758 .916 r
.82701 .43162 .83173 .43803 .84303 .43425 .83834 .42773 Mtetra
.668 .754 .915 r
.83834 .42773 .84303 .43425 .85437 .43047 .84971 .42388 Mtetra
.666 .752 .914 r
.84971 .42388 .85437 .43047 .86576 .4267 .86113 .42009 Mtetra
.664 .751 .915 r
.86113 .42009 .86576 .4267 .8772 .42294 .8726 .41633 Mtetra
.662 .751 .916 r
.8726 .41633 .8772 .42294 .88868 .41919 .88412 .41259 Mtetra
.661 .752 .917 r
.88412 .41259 .88868 .41919 .90021 .41544 .89569 .40886 Mtetra
.653 .751 .921 r
.27639 .59249 .28248 .59781 .29179 .59508 .28573 .58966 Mtetra
.652 .747 .919 r
.28573 .58966 .29179 .59508 .30114 .59237 .2951 .58684 Mtetra
.651 .743 .917 r
.2951 .58684 .30114 .59237 .31052 .58969 .30451 .58405 Mtetra
.648 .74 .916 r
.30451 .58405 .31052 .58969 .31993 .58704 .31394 .58133 Mtetra
.644 .736 .916 r
.31394 .58133 .31993 .58704 .32937 .58445 .3234 .57869 Mtetra
.64 .734 .917 r
.3234 .57869 .32937 .58445 .33884 .5819 .33289 .57614 Mtetra
.635 .734 .92 r
.33289 .57614 .33884 .5819 .34835 .57937 .34242 .57369 Mtetra
.632 .737 .923 r
.34242 .57369 .34835 .57937 .3579 .57681 .35197 .57129 Mtetra
.631 .742 .928 r
.35197 .57129 .3579 .57681 .36748 .57419 .36157 .56888 Mtetra
.633 .752 .934 r
.36157 .56888 .36748 .57419 .37711 .57144 .3712 .56638 Mtetra
.639 .764 .938 r
.3712 .56638 .37711 .57144 .38678 .56852 .38089 .56371 Mtetra
.647 .777 .942 r
.38089 .56371 .38678 .56852 .39649 .56544 .39061 .56083 Mtetra
.658 .788 .944 r
.39061 .56083 .39649 .56544 .40624 .56218 .40038 .55768 Mtetra
.665 .795 .944 r
.40038 .55768 .40624 .56218 .41603 .55882 .41019 .55435 Mtetra
.671 .799 .943 r
.41019 .55435 .41603 .55882 .42585 .5554 .42005 .55085 Mtetra
.674 .797 .94 r
.42005 .55085 .42585 .5554 .43571 .55197 .42993 .54729 Mtetra
.674 .792 .938 r
.42993 .54729 .43571 .55197 .4456 .54859 .43985 .54374 Mtetra
.672 .786 .935 r
.43985 .54374 .4456 .54859 .45552 .54525 .4498 .54022 Mtetra
.669 .779 .932 r
.4498 .54022 .45552 .54525 .46547 .54196 .45978 .53678 Mtetra
.666 .773 .929 r
.45978 .53678 .46547 .54196 .47546 .53873 .4698 .5334 Mtetra
.663 .768 .927 r
.4698 .5334 .47546 .53873 .48549 .53552 .47985 .53008 Mtetra
.661 .764 .926 r
.47985 .53008 .48549 .53552 .49555 .53235 .48994 .52681 Mtetra
.66 .761 .925 r
.48994 .52681 .49555 .53235 .50564 .52918 .50006 .52358 Mtetra
.658 .758 .924 r
.50006 .52358 .50564 .52918 .51578 .52603 .51022 .52036 Mtetra
.658 .757 .923 r
.51022 .52036 .51578 .52603 .52595 .52287 .52041 .51716 Mtetra
.657 .756 .923 r
.52041 .51716 .52595 .52287 .53616 .51971 .53065 .51396 Mtetra
.656 .755 .922 r
.53065 .51396 .53616 .51971 .5464 .51654 .54092 .51076 Mtetra
.656 .754 .922 r
.54092 .51076 .5464 .51654 .55669 .51337 .55123 .50755 Mtetra
.55123 .50755 .55669 .51337 .56701 .51018 .56158 .50434 Mtetra
.56158 .50434 .56701 .51018 .57737 .50699 .57197 .50113 Mtetra
.655 .754 .922 r
.57197 .50113 .57737 .50699 .58777 .50379 .58239 .49791 Mtetra
.58239 .49791 .58777 .50379 .59821 .50058 .59286 .49468 Mtetra
.655 .754 .923 r
.59286 .49468 .59821 .50058 .60869 .49736 .60337 .49145 Mtetra
.654 .754 .923 r
.60337 .49145 .60869 .49736 .61921 .49413 .61391 .48822 Mtetra
.654 .754 .924 r
.61391 .48822 .61921 .49413 .62977 .4909 .6245 .485 Mtetra
.653 .755 .925 r
.6245 .485 .62977 .4909 .64037 .48767 .63513 .48178 Mtetra
.651 .756 .926 r
.63513 .48178 .64037 .48767 .65101 .48445 .6458 .47859 Mtetra
.649 .757 .928 r
.6458 .47859 .65101 .48445 .6617 .48124 .65651 .47543 Mtetra
.646 .759 .931 r
.65651 .47543 .6617 .48124 .67242 .47805 .66727 .47231 Mtetra
.643 .761 .935 r
.66727 .47231 .67242 .47805 .68319 .4749 .67808 .46926 Mtetra
.639 .764 .939 r
.67808 .46926 .68319 .4749 .694 .4718 .68893 .46628 Mtetra
.634 .768 .944 r
.68893 .46628 .694 .4718 .70487 .46875 .69983 .46337 Mtetra
.63 .773 .949 r
.69983 .46337 .70487 .46875 .71577 .46575 .71077 .4605 Mtetra
.628 .778 .953 r
.71077 .4605 .71577 .46575 .72673 .46279 .72177 .45763 Mtetra
.629 .784 .955 r
.72177 .45763 .72673 .46279 .73773 .45982 .73281 .4547 Mtetra
.636 .788 .955 r
.73281 .4547 .73773 .45982 .74877 .4568 .74388 .4516 Mtetra
.645 .79 .952 r
.74388 .4516 .74877 .4568 .75985 .45366 .75498 .44831 Mtetra
.657 .789 .945 r
.75498 .44831 .75985 .45366 .77097 .45035 .76611 .44474 Mtetra
.666 .783 .936 r
.76611 .44474 .77097 .45035 .78211 .44686 .77727 .44096 Mtetra
.674 .775 .927 r
.77727 .44096 .78211 .44686 .79329 .4432 .78845 .43698 Mtetra
.677 .766 .918 r
.78845 .43698 .79329 .4432 .80449 .4394 .79967 .43291 Mtetra
.676 .757 .912 r
.79967 .43291 .80449 .4394 .81573 .43552 .81093 .42884 Mtetra
.674 .751 .908 r
.81093 .42884 .81573 .43552 .82701 .43162 .82223 .4248 Mtetra
.67 .746 .907 r
.82223 .4248 .82701 .43162 .83834 .42773 .83359 .42087 Mtetra
.667 .743 .907 r
.83359 .42087 .83834 .42773 .84971 .42388 .84499 .41702 Mtetra
.663 .743 .909 r
.84499 .41702 .84971 .42388 .86113 .42009 .85645 .41326 Mtetra
.661 .744 .911 r
.85645 .41326 .86113 .42009 .8726 .41633 .86796 .40956 Mtetra
.659 .746 .914 r
.86796 .40956 .8726 .41633 .88412 .41259 .87952 .40589 Mtetra
.658 .749 .917 r
.87952 .40589 .88412 .41259 .89569 .40886 .89113 .40224 Mtetra
.659 .752 .919 r
.27027 .58715 .27639 .59249 .28573 .58966 .27964 .58416 Mtetra
.659 .747 .916 r
.27964 .58416 .28573 .58966 .2951 .58684 .28904 .58118 Mtetra
.657 .742 .912 r
.28904 .58118 .2951 .58684 .30451 .58405 .29847 .57823 Mtetra
.654 .736 .91 r
.29847 .57823 .30451 .58405 .31394 .58133 .30793 .57535 Mtetra
.649 .73 .908 r
.30793 .57535 .31394 .58133 .3234 .57869 .31742 .57258 Mtetra
.643 .724 .907 r
.31742 .57258 .3234 .57869 .33289 .57614 .32693 .56995 Mtetra
.635 .72 .909 r
.32693 .56995 .33289 .57614 .34242 .57369 .33647 .5675 Mtetra
.628 .718 .912 r
.33647 .5675 .34242 .57369 .35197 .57129 .34604 .56519 Mtetra
.622 .72 .917 r
.34604 .56519 .35197 .57129 .36157 .56888 .35564 .56302 Mtetra
.62 .729 .924 r
.35564 .56302 .36157 .56888 .3712 .56638 .36528 .56085 Mtetra
.622 .742 .933 r
.36528 .56085 .3712 .56638 .38089 .56371 .37496 .55857 Mtetra
.63 .76 .941 r
.37496 .55857 .38089 .56371 .39061 .56083 .3847 .55606 Mtetra
.643 .779 .946 r
.3847 .55606 .39061 .56083 .40038 .55768 .39448 .55321 Mtetra
.655 .795 .949 r
.39448 .55321 .40038 .55768 .41019 .55435 .40431 .55006 Mtetra
.668 .806 .949 r
.40431 .55006 .41019 .55435 .42005 .55085 .41419 .5466 Mtetra
.675 .81 .948 r
.41419 .5466 .42005 .55085 .42993 .54729 .4241 .54297 Mtetra
.678 .809 .945 r
.4241 .54297 .42993 .54729 .43985 .54374 .43405 .53926 Mtetra
.678 .804 .942 r
.43405 .53926 .43985 .54374 .4498 .54022 .44403 .53555 Mtetra
.675 .796 .939 r
.44403 .53555 .4498 .54022 .45978 .53678 .45405 .5319 Mtetra
.672 .788 .936 r
.45405 .5319 .45978 .53678 .4698 .5334 .46409 .52833 Mtetra
.668 .781 .933 r
.46409 .52833 .4698 .5334 .47985 .53008 .47417 .52485 Mtetra
.665 .774 .931 r
.47417 .52485 .47985 .53008 .48994 .52681 .48429 .52145 Mtetra
.663 .769 .929 r
.48429 .52145 .48994 .52681 .50006 .52358 .49443 .5181 Mtetra
.661 .765 .927 r
.49443 .5181 .50006 .52358 .51022 .52036 .50462 .5148 Mtetra
.659 .762 .926 r
.50462 .5148 .51022 .52036 .52041 .51716 .51484 .51153 Mtetra
.658 .76 .925 r
.51484 .51153 .52041 .51716 .53065 .51396 .5251 .50827 Mtetra
.657 .759 .925 r
.5251 .50827 .53065 .51396 .54092 .51076 .5354 .50503 Mtetra
.656 .758 .925 r
.5354 .50503 .54092 .51076 .55123 .50755 .54573 .50179 Mtetra
.656 .757 .924 r
.54573 .50179 .55123 .50755 .56158 .50434 .55611 .49855 Mtetra
.655 .757 .924 r
.55611 .49855 .56158 .50434 .57197 .50113 .56652 .49531 Mtetra
.655 .757 .925 r
.56652 .49531 .57197 .50113 .58239 .49791 .57698 .49208 Mtetra
.654 .757 .925 r
.57698 .49208 .58239 .49791 .59286 .49468 .58747 .48884 Mtetra
.654 .757 .926 r
.58747 .48884 .59286 .49468 .60337 .49145 .598 .48561 Mtetra
.653 .757 .926 r
.598 .48561 .60337 .49145 .61391 .48822 .60858 .48239 Mtetra
.651 .758 .928 r
.60858 .48239 .61391 .48822 .6245 .485 .6192 .47919 Mtetra
.649 .759 .93 r
.6192 .47919 .6245 .485 .63513 .48178 .62985 .47602 Mtetra
.647 .761 .932 r
.62985 .47602 .63513 .48178 .6458 .47859 .64056 .47289 Mtetra
.643 .763 .936 r
.64056 .47289 .6458 .47859 .65651 .47543 .6513 .46983 Mtetra
.639 .766 .94 r
.6513 .46983 .65651 .47543 .66727 .47231 .6621 .46683 Mtetra
.633 .769 .945 r
.6621 .46683 .66727 .47231 .67808 .46926 .67294 .46393 Mtetra
.628 .774 .951 r
.67294 .46393 .67808 .46926 .68893 .46628 .68383 .46111 Mtetra
.622 .779 .957 r
.68383 .46111 .68893 .46628 .69983 .46337 .69477 .45836 Mtetra
.619 .786 .962 r
.69477 .45836 .69983 .46337 .71077 .4605 .70576 .4556 Mtetra
.621 .792 .964 r
.70576 .4556 .71077 .4605 .72177 .45763 .71679 .45277 Mtetra
.628 .797 .963 r
.71679 .45277 .72177 .45763 .73281 .4547 .72786 .44975 Mtetra
.643 .8 .958 r
.72786 .44975 .73281 .4547 .74388 .4516 .73895 .44642 Mtetra
.658 .797 .949 r
.73895 .44642 .74388 .4516 .75498 .44831 .75007 .44278 Mtetra
.674 .789 .936 r
.75007 .44278 .75498 .44831 .76611 .44474 .7612 .43878 Mtetra
.683 .777 .922 r
.7612 .43878 .76611 .44474 .77727 .44096 .77236 .43455 Mtetra
.686 .763 .91 r
.77236 .43455 .77727 .44096 .78845 .43698 .78355 .43019 Mtetra
.685 .751 .901 r
.78355 .43019 .78845 .43698 .79967 .43291 .79477 .42583 Mtetra
.68 .74 .897 r
.79477 .42583 .79967 .43291 .81093 .42884 .80605 .42161 Mtetra
.674 .734 .895 r
.80605 .42161 .81093 .42884 .82223 .4248 .81738 .41752 Mtetra
.668 .731 .897 r
.81738 .41752 .82223 .4248 .83359 .42087 .82877 .41362 Mtetra
.663 .731 .9 r
.82877 .41362 .83359 .42087 .84499 .41702 .84022 .40987 Mtetra
.659 .733 .904 r
.84022 .40987 .84499 .41702 .85645 .41326 .85172 .40622 Mtetra
.656 .736 .909 r
.85172 .40622 .85645 .41326 .86796 .40956 .86328 .40265 Mtetra
.654 .741 .913 r
.86328 .40265 .86796 .40956 .87952 .40589 .87489 .39911 Mtetra
.653 .746 .917 r
.87489 .39911 .87952 .40589 .89113 .40224 .88655 .39556 Mtetra
.664 .753 .917 r
.2641 .58177 .27027 .58715 .27964 .58416 .2735 .57864 Mtetra
.665 .749 .913 r
.2735 .57864 .27964 .58416 .28904 .58118 .28293 .57548 Mtetra
.664 .744 .909 r
.28293 .57548 .28904 .58118 .29847 .57823 .29239 .57234 Mtetra
.662 .737 .906 r
.29239 .57234 .29847 .57823 .30793 .57535 .30189 .56925 Mtetra
.658 .729 .902 r
.30189 .56925 .30793 .57535 .31742 .57258 .31141 .56623 Mtetra
.651 .72 .899 r
.31141 .56623 .31742 .57258 .32693 .56995 .32095 .56337 Mtetra
.642 .711 .897 r
.32095 .56337 .32693 .56995 .33647 .5675 .33052 .56073 Mtetra
.632 .702 .896 r
.33052 .56073 .33647 .5675 .34604 .56519 .34011 .55834 Mtetra
.62 .696 .898 r
.34011 .55834 .34604 .56519 .35564 .56302 .34972 .55624 Mtetra
.612 .696 .903 r
.34972 .55624 .35564 .56302 .36528 .56085 .35936 .55431 Mtetra
.607 .703 .912 r
.35936 .55431 .36528 .56085 .37496 .55857 .36904 .55247 Mtetra
.609 .72 .923 r
.36904 .55247 .37496 .55857 .3847 .55606 .37877 .5505 Mtetra
.62 .744 .935 r
.37877 .5505 .3847 .55606 .39448 .55321 .38855 .54823 Mtetra
.634 .77 .945 r
.38855 .54823 .39448 .55321 .40431 .55006 .39839 .54557 Mtetra
.652 .796 .952 r
.39839 .54557 .40431 .55006 .41419 .5466 .40828 .54245 Mtetra
.665 .814 .955 r
.40828 .54245 .41419 .5466 .4241 .54297 .41821 .53899 Mtetra
.675 .824 .955 r
.41821 .53899 .4241 .54297 .43405 .53926 .42819 .53527 Mtetra
.68 .825 .953 r
.42819 .53527 .43405 .53926 .44403 .53555 .43821 .53142 Mtetra
.68 .821 .951 r
.43821 .53142 .44403 .53555 .45405 .5319 .44826 .52758 Mtetra
.679 .813 .947 r
.44826 .52758 .45405 .5319 .46409 .52833 .45833 .52378 Mtetra
.675 .804 .944 r
.45833 .52378 .46409 .52833 .47417 .52485 .46844 .52008 Mtetra
.671 .795 .941 r
.46844 .52008 .47417 .52485 .48429 .52145 .47859 .51647 Mtetra
.667 .787 .938 r
.47859 .51647 .48429 .52145 .49443 .5181 .48877 .51296 Mtetra
.664 .78 .935 r
.48877 .51296 .49443 .5181 .50462 .5148 .49898 .50951 Mtetra
.662 .775 .933 r
.49898 .50951 .50462 .5148 .51484 .51153 .50923 .50613 Mtetra
.66 .771 .932 r
.50923 .50613 .51484 .51153 .5251 .50827 .51951 .50279 Mtetra
.658 .768 .931 r
.51951 .50279 .5251 .50827 .5354 .50503 .52984 .49947 Mtetra
.657 .766 .93 r
.52984 .49947 .5354 .50503 .54573 .50179 .5402 .49618 Mtetra
.656 .765 .93 r
.5402 .49618 .54573 .50179 .55611 .49855 .5506 .49291 Mtetra
.655 .764 .93 r
.5506 .49291 .55611 .49855 .56652 .49531 .56104 .48965 Mtetra
.654 .763 .93 r
.56104 .48965 .56652 .49531 .57698 .49208 .57153 .48641 Mtetra
.653 .764 .931 r
.57153 .48641 .57698 .49208 .58747 .48884 .58205 .48318 Mtetra
.651 .764 .932 r
.58205 .48318 .58747 .48884 .598 .48561 .59261 .47997 Mtetra
.649 .765 .934 r
.59261 .47997 .598 .48561 .60858 .48239 .60321 .4768 Mtetra
.646 .767 .936 r
.60321 .4768 .60858 .48239 .6192 .47919 .61386 .47366 Mtetra
.643 .769 .94 r
.61386 .47366 .6192 .47919 .62985 .47602 .62455 .47059 Mtetra
.638 .772 .944 r
.62455 .47059 .62985 .47602 .64056 .47289 .63529 .46759 Mtetra
.632 .776 .95 r
.63529 .46759 .64056 .47289 .6513 .46983 .64607 .46468 Mtetra
.625 .781 .956 r
.64607 .46468 .6513 .46983 .6621 .46683 .65691 .46187 Mtetra
.617 .786 .962 r
.65691 .46187 .6621 .46683 .67294 .46393 .66779 .45916 Mtetra
.611 .793 .969 r
.66779 .45916 .67294 .46393 .68383 .46111 .67872 .4565 Mtetra
.607 .799 .973 r
.67872 .4565 .68383 .46111 .69477 .45836 .6897 .45384 Mtetra
.611 .805 .974 r
.6897 .45384 .69477 .45836 .70576 .4556 .70072 .45105 Mtetra
.625 .81 .971 r
.70072 .45105 .70576 .4556 .71679 .45277 .71178 .448 Mtetra
.644 .808 .962 r
.71178 .448 .71679 .45277 .72786 .44975 .72286 .4446 Mtetra
.668 .802 .947 r
.72286 .4446 .72786 .44975 .73895 .44642 .73395 .44071 Mtetra
.684 .787 .928 r
.73395 .44071 .73895 .44642 .75007 .44278 .74506 .43643 Mtetra
.695 .768 .908 r
.74506 .43643 .75007 .44278 .7612 .43878 .75619 .43183 Mtetra
.697 .75 .893 r
.75619 .43183 .7612 .43878 .77236 .43455 .76734 .42709 Mtetra
.691 .733 .883 r
.76734 .42709 .77236 .43455 .78355 .43019 .77853 .42244 Mtetra
.685 .723 .878 r
.77853 .42244 .78355 .43019 .79477 .42583 .78978 .41795 Mtetra
.675 .716 .879 r
.78978 .41795 .79477 .42583 .80605 .42161 .80109 .41376 Mtetra
.667 .714 .884 r
.80109 .41376 .80605 .42161 .81738 .41752 .81246 .40983 Mtetra
.66 .717 .89 r
.81246 .40983 .81738 .41752 .82877 .41362 .8239 .40612 Mtetra
.655 .721 .897 r
.8239 .40612 .82877 .41362 .84022 .40987 .8354 .40258 Mtetra
.652 .727 .904 r
.8354 .40258 .84022 .40987 .85172 .40622 .84695 .39911 Mtetra
.649 .733 .91 r
.84695 .39911 .85172 .40622 .86328 .40265 .85856 .39569 Mtetra
.648 .738 .915 r
.85856 .39569 .86328 .40265 .87489 .39911 .87022 .39228 Mtetra
.648 .744 .919 r
.87022 .39228 .87489 .39911 .88655 .39556 .88193 .38884 Mtetra
.667 .754 .915 r
.25789 .57635 .2641 .58177 .2735 .57864 .26732 .57313 Mtetra
.669 .752 .912 r
.26732 .57313 .2735 .57864 .28293 .57548 .27678 .56984 Mtetra
.67 .748 .909 r
.27678 .56984 .28293 .57548 .29239 .57234 .28627 .56652 Mtetra
.67 .743 .905 r
.28627 .56652 .29239 .57234 .30189 .56925 .2958 .56319 Mtetra
.669 .735 .899 r
.2958 .56319 .30189 .56925 .31141 .56623 .30536 .55985 Mtetra
.665 .724 .893 r
.30536 .55985 .31141 .56623 .32095 .56337 .31494 .55661 Mtetra
.657 .711 .888 r
.31494 .55661 .32095 .56337 .33052 .56073 .32455 .55357 Mtetra
.645 .695 .882 r
.32455 .55357 .33052 .56073 .34011 .55834 .33417 .55084 Mtetra
.628 .68 .88 r
.33417 .55084 .34011 .55834 .34972 .55624 .34381 .54854 Mtetra
.613 .67 .881 r
.34381 .54854 .34972 .55624 .35936 .55431 .35346 .54664 Mtetra
.596 .664 .887 r
.35346 .54664 .35936 .55431 .36904 .55247 .36314 .54514 Mtetra
.589 .673 .898 r
.36314 .54514 .36904 .55247 .37877 .5505 .37285 .54375 Mtetra
.59 .692 .913 r
.37285 .54375 .37877 .5505 .38855 .54823 .38262 .54224 Mtetra
.601 .724 .931 r
.38262 .54224 .38855 .54823 .39839 .54557 .39244 .54039 Mtetra
.622 .761 .946 r
.39244 .54039 .39839 .54557 .40828 .54245 .40233 .53796 Mtetra
.641 .795 .956 r
.40233 .53796 .40828 .54245 .41821 .53899 .41228 .535 Mtetra
.662 .822 .96 r
.41228 .535 .41821 .53899 .42819 .53527 .42228 .53153 Mtetra
.674 .836 .961 r
.42228 .53153 .42819 .53527 .43821 .53142 .43232 .52775 Mtetra
.681 .841 .96 r
.43232 .52775 .43821 .53142 .44826 .52758 .4424 .5238 Mtetra
.683 .838 .958 r
.4424 .5238 .44826 .52758 .45833 .52378 .45252 .5198 Mtetra
.681 .83 .955 r
.45252 .5198 .45833 .52378 .46844 .52008 .46266 .51587 Mtetra
.678 .821 .952 r
.46266 .51587 .46844 .52008 .47859 .51647 .47284 .51202 Mtetra
.673 .811 .949 r
.47284 .51202 .47859 .51647 .48877 .51296 .48305 .50829 Mtetra
.669 .802 .946 r
.48305 .50829 .48877 .51296 .49898 .50951 .49329 .50466 Mtetra
.666 .794 .944 r
.49329 .50466 .49898 .50951 .50923 .50613 .50357 .50112 Mtetra
.662 .788 .942 r
.50357 .50112 .50923 .50613 .51951 .50279 .51389 .49766 Mtetra
.66 .784 .94 r
.51389 .49766 .51951 .50279 .52984 .49947 .52424 .49425 Mtetra
.658 .78 .939 r
.52424 .49425 .52984 .49947 .5402 .49618 .53463 .49089 Mtetra
.655 .778 .939 r
.53463 .49089 .5402 .49618 .5506 .49291 .54506 .48758 Mtetra
.653 .776 .939 r
.54506 .48758 .5506 .49291 .56104 .48965 .55553 .4843 Mtetra
.651 .776 .94 r
.55553 .4843 .56104 .48965 .57153 .48641 .56604 .48105 Mtetra
.649 .776 .941 r
.56604 .48105 .57153 .48641 .58205 .48318 .57659 .47785 Mtetra
.646 .777 .943 r
.57659 .47785 .58205 .48318 .59261 .47997 .58718 .47469 Mtetra
.642 .778 .946 r
.58718 .47469 .59261 .47997 .60321 .4768 .59782 .47159 Mtetra
.637 .781 .95 r
.59782 .47159 .60321 .4768 .61386 .47366 .6085 .46857 Mtetra
.631 .784 .955 r
.6085 .46857 .61386 .47366 .62455 .47059 .61923 .46564 Mtetra
.624 .788 .961 r
.61923 .46564 .62455 .47059 .63529 .46759 .63 .46281 Mtetra
.614 .793 .967 r
.63 .46281 .63529 .46759 .64607 .46468 .64082 .46011 Mtetra
.605 .799 .974 r
.64082 .46011 .64607 .46468 .65691 .46187 .6517 .45749 Mtetra
.597 .805 .979 r
.6517 .45749 .65691 .46187 .66779 .45916 .66262 .45494 Mtetra
.595 .812 .983 r
.66262 .45494 .66779 .45916 .67872 .4565 .67359 .45234 Mtetra
.602 .818 .983 r
.67359 .45234 .67872 .4565 .6897 .45384 .68461 .44958 Mtetra
.621 .821 .978 r
.68461 .44958 .6897 .45384 .70072 .45105 .69565 .44649 Mtetra
.651 .82 .964 r
.69565 .44649 .70072 .45105 .71178 .448 .70671 .44287 Mtetra
.678 .807 .944 r
.70671 .44287 .71178 .448 .72286 .4446 .71778 .43872 Mtetra
.701 .786 .917 r
.71778 .43872 .72286 .4446 .73395 .44071 .72885 .43397 Mtetra
.709 .76 .892 r
.72885 .43397 .73395 .44071 .74506 .43643 .73994 .42884 Mtetra
.707 .735 .872 r
.73994 .42884 .74506 .43643 .75619 .43183 .75105 .4236 Mtetra
.7 .715 .86 r
.75105 .4236 .75619 .43183 .76734 .42709 .7622 .41845 Mtetra
.687 .7 .857 r
.7622 .41845 .76734 .42709 .77853 .42244 .77341 .41372 Mtetra
.676 .694 .86 r
.77341 .41372 .77853 .42244 .78978 .41795 .7847 .40939 Mtetra
.663 .693 .868 r
.7847 .40939 .78978 .41795 .80109 .41376 .79606 .40551 Mtetra
.654 .698 .879 r
.79606 .40551 .80109 .41376 .81246 .40983 .8075 .40194 Mtetra
.648 .707 .89 r
.8075 .40194 .81246 .40983 .8239 .40612 .819 .39858 Mtetra
.644 .716 .9 r
.819 .39858 .8239 .40612 .8354 .40258 .83056 .39532 Mtetra
.644 .726 .909 r
.83056 .39532 .8354 .40258 .84695 .39911 .84217 .39206 Mtetra
.643 .734 .915 r
.84217 .39206 .84695 .39911 .85856 .39569 .85382 .38878 Mtetra
.644 .74 .919 r
.85382 .38878 .85856 .39569 .87022 .39228 .86553 .38546 Mtetra
.646 .744 .921 r
.86553 .38546 .87022 .39228 .88193 .38884 .87727 .38207 Mtetra
.665 .754 .916 r
.25164 .57089 .25789 .57635 .26732 .57313 .26108 .56771 Mtetra
.668 .756 .916 r
.26108 .56771 .26732 .57313 .27678 .56984 .27056 .56443 Mtetra
.671 .758 .916 r
.27056 .56443 .27678 .56984 .28627 .56652 .28008 .56107 Mtetra
.674 .758 .914 r
.28008 .56107 .28627 .56652 .2958 .56319 .28964 .55761 Mtetra
.679 .755 .909 r
.28964 .55761 .2958 .56319 .30536 .55985 .29923 .55402 Mtetra
.679 .747 .903 r
.29923 .55402 .30536 .55985 .31494 .55661 .30886 .5504 Mtetra
.677 .735 .894 r
.30886 .5504 .31494 .55661 .32455 .55357 .31852 .5468 Mtetra
.667 .715 .885 r
.31852 .5468 .32455 .55357 .33417 .55084 .3282 .54344 Mtetra
.651 .692 .875 r
.3282 .54344 .33417 .55084 .34381 .54854 .33788 .54048 Mtetra
.631 .668 .867 r
.33788 .54048 .34381 .54854 .35346 .54664 .34758 .53805 Mtetra
.606 .645 .863 r
.34758 .53805 .35346 .54664 .36314 .54514 .35727 .53632 Mtetra
.588 .632 .862 r
.35727 .53632 .36314 .54514 .37285 .54375 .36699 .53506 Mtetra
.573 .629 .869 r
.36699 .53506 .37285 .54375 .38262 .54224 .37674 .53415 Mtetra
.572 .646 .884 r
.37674 .53415 .38262 .54224 .39244 .54039 .38654 .53318 Mtetra
.584 .678 .905 r
.38654 .53318 .39244 .54039 .40233 .53796 .39641 .53182 Mtetra
.603 .721 .928 r
.39641 .53182 .40233 .53796 .41228 .535 .40634 .5299 Mtetra
.629 .77 .947 r
.40634 .5299 .41228 .535 .42228 .53153 .41634 .52726 Mtetra
.649 .809 .96 r
.41634 .52726 .42228 .53153 .43232 .52775 .42639 .52407 Mtetra
.665 .838 .966 r
.42639 .52407 .43232 .52775 .4424 .5238 .43649 .52041 Mtetra
.673 .853 .968 r
.43649 .52041 .4424 .5238 .45252 .5198 .44664 .5165 Mtetra
.676 .858 .969 r
.44664 .5165 .45252 .5198 .46266 .51587 .45682 .51248 Mtetra
.677 .856 .968 r
.45682 .51248 .46266 .51587 .47284 .51202 .46703 .50846 Mtetra
.674 .849 .967 r
.46703 .50846 .47284 .51202 .48305 .50829 .47728 .50452 Mtetra
.671 .84 .965 r
.47728 .50452 .48305 .50829 .49329 .50466 .48755 .50068 Mtetra
.667 .831 .963 r
.48755 .50068 .49329 .50466 .50357 .50112 .49786 .49695 Mtetra
.663 .823 .961 r
.49786 .49695 .50357 .50112 .51389 .49766 .50821 .49332 Mtetra
.659 .816 .959 r
.50821 .49332 .51389 .49766 .52424 .49425 .5186 .48978 Mtetra
.655 .811 .958 r
.5186 .48978 .52424 .49425 .53463 .49089 .52902 .48633 Mtetra
.652 .807 .958 r
.52902 .48633 .53463 .49089 .54506 .48758 .53948 .48295 Mtetra
.648 .805 .958 r
.53948 .48295 .54506 .48758 .55553 .4843 .54998 .47965 Mtetra
.644 .803 .96 r
.54998 .47965 .55553 .4843 .56604 .48105 .56052 .47642 Mtetra
.639 .803 .962 r
.56052 .47642 .56604 .48105 .57659 .47785 .5711 .47327 Mtetra
.633 .804 .965 r
.5711 .47327 .57659 .47785 .58718 .47469 .58173 .4702 Mtetra
.626 .807 .969 r
.58173 .4702 .58718 .47469 .59782 .47159 .5924 .46722 Mtetra
.618 .81 .974 r
.5924 .46722 .59782 .47159 .6085 .46857 .60312 .46435 Mtetra
.607 .814 .979 r
.60312 .46435 .6085 .46857 .61923 .46564 .61388 .4616 Mtetra
.597 .818 .984 r
.61388 .4616 .61923 .46564 .63 .46281 .6247 .45894 Mtetra
.586 .822 .989 r
.6247 .45894 .63 .46281 .64082 .46011 .63556 .45637 Mtetra
.581 .827 .991 r
.63556 .45637 .64082 .46011 .6517 .45749 .64647 .45379 Mtetra
.585 .831 .991 r
.64647 .45379 .6517 .45749 .66262 .45494 .65743 .45111 Mtetra
.603 .833 .987 r
.65743 .45111 .66262 .45494 .67359 .45234 .66842 .44818 Mtetra
.636 .831 .976 r
.66842 .44818 .67359 .45234 .68461 .44958 .67944 .44476 Mtetra
.669 .816 .954 r
.67944 .44476 .68461 .44958 .69565 .44649 .69048 .44078 Mtetra
.7 .792 .922 r
.69048 .44078 .69565 .44649 .70671 .44287 .70151 .43606 Mtetra
.714 .759 .888 r
.70151 .43606 .70671 .44287 .71778 .43872 .71255 .43076 Mtetra
.717 .728 .859 r
.71255 .43076 .71778 .43872 .72885 .43397 .72359 .42504 Mtetra
.711 .702 .84 r
.72359 .42504 .72885 .43397 .73994 .42884 .73466 .41924 Mtetra
.698 .682 .831 r
.73466 .41924 .73994 .42884 .75105 .4236 .74578 .41381 Mtetra
.686 .673 .832 r
.74578 .41381 .75105 .4236 .7622 .41845 .75696 .40885 Mtetra
.669 .671 .843 r
.75696 .40885 .7622 .41845 .77341 .41372 .76824 .40461 Mtetra
.656 .677 .858 r
.76824 .40461 .77341 .41372 .7847 .40939 .7796 .40092 Mtetra
.644 .689 .877 r
.7796 .40092 .7847 .40939 .79606 .40551 .79104 .39765 Mtetra
.636 .704 .895 r
.79104 .39765 .79606 .40551 .8075 .40194 .80255 .39462 Mtetra
.635 .72 .909 r
.80255 .39462 .8075 .40194 .819 .39858 .81412 .3916 Mtetra
.634 .732 .919 r
.81412 .3916 .819 .39858 .83056 .39532 .82573 .38856 Mtetra
.638 .742 .924 r
.82573 .38856 .83056 .39532 .84217 .39206 .83738 .38538 Mtetra
.641 .748 .926 r
.83738 .38538 .84217 .39206 .85382 .38878 .84908 .3821 Mtetra
.644 .75 .926 r
.84908 .3821 .85382 .38878 .86553 .38546 .86081 .37872 Mtetra
.647 .75 .924 r
.86081 .37872 .86553 .38546 .87727 .38207 .87259 .37524 Mtetra
.657 .752 .92 r
.24535 .5654 .25164 .57089 .26108 .56771 .2548 .56239 Mtetra
.659 .759 .924 r
.2548 .56239 .26108 .56771 .27056 .56443 .26428 .5593 Mtetra
.664 .768 .927 r
.26428 .5593 .27056 .56443 .28008 .56107 .27381 .55608 Mtetra
.671 .775 .928 r
.27381 .55608 .28008 .56107 .28964 .55761 .28338 .55267 Mtetra
.681 .78 .925 r
.28338 .55267 .28964 .55761 .29923 .55402 .29301 .54901 Mtetra
.69 .78 .92 r
.29301 .54901 .29923 .55402 .30886 .5504 .30268 .54512 Mtetra
.698 .772 .909 r
.30268 .54512 .30886 .5504 .31852 .5468 .31239 .54097 Mtetra
.696 .754 .896 r
.31239 .54097 .31852 .5468 .3282 .54344 .32214 .53682 Mtetra
.688 .727 .88 r
.32214 .53682 .3282 .54344 .33788 .54048 .3319 .5328 Mtetra
.667 .692 .864 r
.3319 .5328 .33788 .54048 .34758 .53805 .34167 .5293 Mtetra
.637 .654 .85 r
.34167 .5293 .34758 .53805 .35727 .53632 .35142 .52662 Mtetra
.608 .621 .839 r
.35142 .52662 .35727 .53632 .36699 .53506 .36118 .52481 Mtetra
.574 .595 .836 r
.36118 .52481 .36699 .53506 .37674 .53415 .37093 .52398 Mtetra
.556 .588 .841 r
.37093 .52398 .37674 .53415 .38654 .53318 .3807 .52362 Mtetra
.548 .598 .856 r
.3807 .52362 .38654 .53318 .39641 .53182 .39053 .5234 Mtetra
.555 .631 .882 r
.39053 .5234 .39641 .53182 .40634 .5299 .40042 .52283 Mtetra
.579 .683 .912 r
.40042 .52283 .40634 .5299 .41634 .52726 .41039 .52153 Mtetra
.603 .739 .94 r
.41039 .52153 .41634 .52726 .42639 .52407 .42044 .51948 Mtetra
.632 .794 .96 r
.42044 .51948 .42639 .52407 .43649 .52041 .43055 .51663 Mtetra
.65 .833 .971 r
.43055 .51663 .43649 .52041 .44664 .5165 .44071 .51323 Mtetra
.662 .858 .975 r
.44071 .51323 .44664 .5165 .45682 .51248 .45092 .50945 Mtetra
.667 .87 .976 r
.45092 .50945 .45682 .51248 .46703 .50846 .46116 .50548 Mtetra
.667 .873 .976 r
.46116 .50548 .46703 .50846 .47728 .50452 .47144 .50146 Mtetra
.666 .87 .976 r
.47144 .50146 .47728 .50452 .48755 .50068 .48176 .49747 Mtetra
.662 .864 .976 r
.48176 .49747 .48755 .50068 .49786 .49695 .4921 .49358 Mtetra
.658 .857 .976 r
.4921 .49358 .49786 .49695 .50821 .49332 .50249 .48979 Mtetra
.653 .85 .976 r
.50249 .48979 .50821 .49332 .5186 .48978 .5129 .48613 Mtetra
.648 .845 .976 r
.5129 .48613 .5186 .48978 .52902 .48633 .52336 .48258 Mtetra
.643 .84 .976 r
.52336 .48258 .52902 .48633 .53948 .48295 .53385 .47914 Mtetra
.636 .836 .977 r
.53385 .47914 .53948 .48295 .54998 .47965 .54439 .47582 Mtetra
.629 .834 .979 r
.54439 .47582 .54998 .47965 .56052 .47642 .55496 .4726 Mtetra
.621 .833 .982 r
.55496 .4726 .56052 .47642 .5711 .47327 .56558 .46951 Mtetra
.612 .834 .985 r
.56558 .46951 .5711 .47327 .58173 .4702 .57624 .46652 Mtetra
.601 .835 .988 r
.57624 .46652 .58173 .4702 .5924 .46722 .58695 .46367 Mtetra
.59 .836 .991 r
.58695 .46367 .5924 .46722 .60312 .46435 .59771 .46092 Mtetra
.578 .838 .994 r
.59771 .46092 .60312 .46435 .61388 .4616 .60851 .45827 Mtetra
.571 .84 .996 r
.60851 .45827 .61388 .4616 .6247 .45894 .61937 .45565 Mtetra
.571 .843 .996 r
.61937 .45565 .6247 .45894 .63556 .45637 .63027 .45299 Mtetra
.585 .846 .994 r
.63027 .45299 .63556 .45637 .64647 .45379 .64121 .45013 Mtetra
.616 .846 .987 r
.64121 .45013 .64647 .45379 .65743 .45111 .65218 .44688 Mtetra
.656 .836 .969 r
.65218 .44688 .65743 .45111 .66842 .44818 .66317 .44308 Mtetra
.697 .813 .937 r
.66317 .44308 .66842 .44818 .67944 .44476 .67417 .43845 Mtetra
.719 .777 .898 r
.67417 .43845 .67944 .44476 .69048 .44078 .68517 .43305 Mtetra
.73 .738 .858 r
.68517 .43305 .69048 .44078 .70151 .43606 .69615 .42689 Mtetra
.726 .702 .828 r
.69615 .42689 .70151 .43606 .71255 .43076 .70714 .42036 Mtetra
.713 .672 .809 r
.70714 .42036 .71255 .43076 .72359 .42504 .71817 .41396 Mtetra
.698 .654 .802 r
.71817 .41396 .72359 .42504 .73466 .41924 .72925 .40804 Mtetra
.676 .642 .808 r
.72925 .40804 .73466 .41924 .74578 .41381 .74042 .40312 Mtetra
.658 .643 .824 r
.74042 .40312 .74578 .41381 .75696 .40885 .75169 .39908 Mtetra
.639 .654 .849 r
.75169 .39908 .75696 .40885 .76824 .40461 .76307 .39591 Mtetra
.624 .674 .877 r
.76307 .39591 .76824 .40461 .7796 .40092 .77454 .39326 Mtetra
.617 .701 .905 r
.77454 .39326 .7796 .40092 .79104 .39765 .78607 .39076 Mtetra
.613 .726 .926 r
.78607 .39076 .79104 .39765 .80255 .39462 .79766 .38825 Mtetra
.62 .748 .938 r
.79766 .38825 .80255 .39462 .81412 .3916 .80928 .38547 Mtetra
.627 .761 .943 r
.80928 .38547 .81412 .3916 .82573 .38856 .82094 .38246 Mtetra
.638 .768 .942 r
.82094 .38246 .82573 .38856 .83738 .38538 .83261 .37917 Mtetra
.646 .768 .938 r
.83261 .37917 .83738 .38538 .84908 .3821 .84433 .37569 Mtetra
.651 .764 .932 r
.84433 .37569 .84908 .3821 .86081 .37872 .85607 .37207 Mtetra
.654 .758 .926 r
.85607 .37207 .86081 .37872 .87259 .37524 .86786 .36837 Mtetra
.645 .749 .925 r
.23902 .55988 .24535 .5654 .2548 .56239 .24846 .55711 Mtetra
.645 .759 .932 r
.24846 .55711 .2548 .56239 .26428 .5593 .25794 .55432 Mtetra
.648 .771 .939 r
.25794 .55432 .26428 .5593 .27381 .55608 .26747 .55142 Mtetra
.655 .786 .944 r
.26747 .55142 .27381 .55608 .28338 .55267 .27704 .54833 Mtetra
.666 .802 .948 r
.27704 .54833 .28338 .55267 .29301 .54901 .28667 .54496 Mtetra
.68 .817 .949 r
.28667 .54496 .29301 .54901 .30268 .54512 .29635 .54124 Mtetra
.7 .827 .943 r
.29635 .54124 .30268 .54512 .31239 .54097 .3061 .53703 Mtetra
.714 .828 .936 r
.3061 .53703 .31239 .54097 .32214 .53682 .31589 .53248 Mtetra
.725 .814 .92 r
.31589 .53248 .32214 .53682 .3319 .5328 .32574 .52759 Mtetra
.718 .782 .903 r
.32574 .52759 .3319 .5328 .34167 .5293 .3356 .52282 Mtetra
.697 .737 .882 r
.3356 .52282 .34167 .5293 .35142 .52662 .34546 .5185 Mtetra
.663 .681 .857 r
.34546 .5185 .35142 .52662 .36118 .52481 .35531 .51506 Mtetra
.618 .626 .836 r
.35531 .51506 .36118 .52481 .37093 .52398 .36513 .51287 Mtetra
.584 .584 .818 r
.36513 .51287 .37093 .52398 .3807 .52362 .37494 .51174 Mtetra
.553 .555 .81 r
.37494 .51174 .3807 .52362 .39053 .5234 .38476 .5116 Mtetra
.542 .551 .813 r
.38476 .5116 .39053 .5234 .40042 .52283 .39463 .51178 Mtetra
.544 .566 .828 r
.39463 .51178 .40042 .52283 .41039 .52153 .40455 .51181 Mtetra
.557 .602 .854 r
.40455 .51181 .41039 .52153 .42044 .51948 .41455 .51133 Mtetra
.583 .654 .886 r
.41455 .51133 .42044 .51948 .43055 .51663 .42463 .51003 Mtetra
.607 .712 .919 r
.42463 .51003 .43055 .51663 .44071 .51323 .43478 .50799 Mtetra
.631 .77 .947 r
.43478 .50799 .44071 .51323 .45092 .50945 .44499 .50523 Mtetra
.644 .816 .966 r
.44499 .50523 .45092 .50945 .46116 .50548 .45525 .50199 Mtetra
.65 .849 .976 r
.45525 .50199 .46116 .50548 .47144 .50146 .46556 .49843 Mtetra
.649 .868 .981 r
.46556 .49843 .47144 .50146 .48176 .49747 .4759 .4947 Mtetra
.644 .878 .984 r
.4759 .4947 .48176 .49747 .4921 .49358 .48628 .49092 Mtetra
.638 .882 .986 r
.48628 .49092 .4921 .49358 .50249 .48979 .4967 .48717 Mtetra
.631 .882 .987 r
.4967 .48717 .50249 .48979 .5129 .48613 .50716 .48349 Mtetra
.623 .88 .989 r
.50716 .48349 .5129 .48613 .52336 .48258 .51765 .47991 Mtetra
.615 .877 .99 r
.51765 .47991 .52336 .48258 .53385 .47914 .52818 .47644 Mtetra
.606 .874 .992 r
.52818 .47644 .53385 .47914 .54439 .47582 .53875 .4731 Mtetra
.597 .871 .993 r
.53875 .4731 .54439 .47582 .55496 .4726 .54937 .46987 Mtetra
.588 .868 .994 r
.54937 .46987 .55496 .4726 .56558 .46951 .56002 .46676 Mtetra
.579 .866 .995 r
.56002 .46676 .56558 .46951 .57624 .46652 .57072 .46375 Mtetra
.573 .863 .996 r
.57072 .46375 .57624 .46652 .58695 .46367 .58147 .46082 Mtetra
.573 .861 .996 r
.58147 .46082 .58695 .46367 .59771 .46092 .59226 .45792 Mtetra
.581 .858 .995 r
.59226 .45792 .59771 .46092 .60851 .45827 .6031 .45496 Mtetra
.601 .854 .992 r
.6031 .45496 .60851 .45827 .61937 .45565 .61397 .45184 Mtetra
.632 .844 .981 r
.61397 .45184 .61937 .45565 .63027 .45299 .62489 .44839 Mtetra
.667 .823 .959 r
.62489 .44839 .63027 .45299 .64121 .45013 .63582 .44445 Mtetra
.699 .791 .922 r
.63582 .44445 .64121 .45013 .65218 .44688 .64678 .43977 Mtetra
.716 .75 .879 r
.64678 .43977 .65218 .44688 .66317 .44308 .65773 .43434 Mtetra
.724 .71 .837 r
.65773 .43434 .66317 .44308 .67417 .43845 .66868 .42805 Mtetra
.721 .675 .805 r
.66868 .42805 .67417 .43845 .68517 .43305 .67963 .42123 Mtetra
.712 .647 .783 r
.67963 .42123 .68517 .43305 .69615 .42689 .69059 .41425 Mtetra
.7 .63 .775 r
.69059 .41425 .69615 .42689 .70714 .42036 .70159 .40758 Mtetra
.681 .619 .78 r
.70159 .40758 .70714 .42036 .71817 .41396 .71267 .40192 Mtetra
.664 .622 .798 r
.71267 .40192 .71817 .41396 .72925 .40804 .72385 .39733 Mtetra
.639 .634 .83 r
.72385 .39733 .72925 .40804 .74042 .40312 .73515 .39405 Mtetra
.615 .66 .871 r
.73515 .39405 .74042 .40312 .75169 .39908 .74656 .39166 Mtetra
.592 .698 .916 r
.74656 .39166 .75169 .39908 .76307 .39591 .75806 .38974 Mtetra
.574 .735 .952 r
.75806 .38974 .76307 .39591 .77454 .39326 .76963 .38795 Mtetra
.576 .771 .971 r
.76963 .38795 .77454 .39326 .78607 .39076 .78123 .38582 Mtetra
.587 .792 .978 r
.78123 .38582 .78607 .39076 .79766 .38825 .79286 .38333 Mtetra
.611 .804 .974 r
.79286 .38333 .79766 .38825 .80928 .38547 .8045 .38034 Mtetra
.632 .805 .966 r
.8045 .38034 .80928 .38547 .82094 .38246 .81616 .37697 Mtetra
.648 .798 .954 r
.81616 .37697 .82094 .38246 .83261 .37917 .82785 .37331 Mtetra
.658 .788 .944 r
.82785 .37331 .83261 .37917 .84433 .37569 .83956 .36944 Mtetra
.663 .777 .933 r
.83956 .36944 .84433 .37569 .85607 .37207 .85131 .36546 Mtetra
.665 .765 .925 r
.85131 .36546 .85607 .37207 .86786 .36837 .8631 .36144 Mtetra
.633 .746 .929 r
.23264 .55431 .23902 .55988 .24846 .55711 .24209 .55179 Mtetra
.628 .754 .937 r
.24209 .55179 .24846 .55711 .25794 .55432 .25156 .54932 Mtetra
.627 .766 .946 r
.25156 .54932 .25794 .55432 .26747 .55142 .26107 .54682 Mtetra
.628 .783 .956 r
.26107 .54682 .26747 .55142 .27704 .54833 .27063 .54423 Mtetra
.63 .804 .966 r
.27063 .54423 .27704 .54833 .28667 .54496 .28024 .54147 Mtetra
.641 .833 .974 r
.28024 .54147 .28667 .54496 .29635 .54124 .28991 .53836 Mtetra
.661 .863 .976 r
.28991 .53836 .29635 .54124 .3061 .53703 .29964 .5347 Mtetra
.689 .89 .971 r
.29964 .5347 .3061 .53703 .31589 .53248 .30946 .53037 Mtetra
.728 .903 .957 r
.30946 .53037 .31589 .53248 .32574 .52759 .31935 .52518 Mtetra
.753 .893 .941 r
.31935 .52518 .32574 .52759 .3356 .52282 .32931 .51943 Mtetra
.767 .856 .917 r
.32931 .51943 .3356 .52282 .34546 .5185 .3393 .51329 Mtetra
.745 .789 .888 r
.3393 .51329 .34546 .5185 .35531 .51506 .34929 .50754 Mtetra
.702 .711 .856 r
.34929 .50754 .35531 .51506 .36513 .51287 .35926 .50279 Mtetra
.65 .634 .821 r
.35926 .50279 .36513 .51287 .37494 .51174 .36918 .49945 Mtetra
.595 .57 .796 r
.36918 .49945 .37494 .51174 .38476 .5116 .37906 .49793 Mtetra
.559 .532 .781 r
.37906 .49793 .38476 .5116 .39463 .51178 .38893 .49768 Mtetra
.532 .511 .778 r
.38893 .49768 .39463 .51178 .40455 .51181 .39883 .49837 Mtetra
.524 .517 .79 r
.39883 .49837 .40455 .51181 .41455 .51133 .40877 .49923 Mtetra
.532 .543 .812 r
.40877 .49923 .41455 .51133 .42463 .51003 .4188 .49968 Mtetra
.548 .586 .844 r
.4188 .49968 .42463 .51003 .43478 .50799 .4289 .49946 Mtetra
.575 .643 .881 r
.4289 .49946 .43478 .50799 .44499 .50523 .43908 .49834 Mtetra
.599 .703 .916 r
.43908 .49834 .44499 .50523 .45525 .50199 .44934 .49647 Mtetra
.62 .76 .946 r
.44934 .49647 .45525 .50199 .46556 .49843 .45965 .49393 Mtetra
.631 .804 .966 r
.45965 .49393 .46556 .49843 .4759 .4947 .47001 .49094 Mtetra
.635 .836 .978 r
.47001 .49094 .4759 .4947 .48628 .49092 .48042 .48765 Mtetra
.633 .857 .984 r
.48042 .48765 .48628 .49092 .4967 .48717 .49087 .4842 Mtetra
.627 .869 .988 r
.49087 .4842 .4967 .48717 .50716 .48349 .50136 .48071 Mtetra
.62 .875 .99 r
.50136 .48071 .50716 .48349 .51765 .47991 .51189 .47722 Mtetra
.612 .877 .991 r
.51189 .47722 .51765 .47991 .52818 .47644 .52246 .47378 Mtetra
.604 .876 .992 r
.52246 .47378 .52818 .47644 .53875 .4731 .53307 .47042 Mtetra
.598 .874 .993 r
.53307 .47042 .53875 .4731 .54937 .46987 .54372 .46712 Mtetra
.596 .871 .993 r
.54372 .46712 .54937 .46987 .56002 .46676 .55441 .46388 Mtetra
.598 .868 .993 r
.55441 .46388 .56002 .46676 .57072 .46375 .56515 .46065 Mtetra
.608 .863 .991 r
.56515 .46065 .57072 .46375 .58147 .46082 .57593 .45736 Mtetra
.626 .855 .986 r
.57593 .45736 .58147 .46082 .59226 .45792 .58674 .45392 Mtetra
.652 .842 .973 r
.58674 .45392 .59226 .45792 .6031 .45496 .5976 .45017 Mtetra
.68 .819 .95 r
.5976 .45017 .6031 .45496 .61397 .45184 .60848 .44597 Mtetra
.706 .786 .914 r
.60848 .44597 .61397 .45184 .62489 .44839 .61938 .44108 Mtetra
.721 .745 .872 r
.61938 .44108 .62489 .44839 .63582 .44445 .63029 .43543 Mtetra
.728 .705 .828 r
.63029 .43543 .63582 .44445 .64678 .43977 .6412 .42883 Mtetra
.725 .667 .793 r
.6412 .42883 .64678 .43977 .65773 .43434 .6521 .42155 Mtetra
.716 .636 .766 r
.6521 .42155 .65773 .43434 .66868 .42805 .663 .41384 Mtetra
.703 .612 .752 r
.663 .41384 .66868 .42805 .67963 .42123 .67393 .40629 Mtetra
.684 .594 .749 r
.67393 .40629 .67963 .42123 .69059 .41425 .68491 .39969 Mtetra
.664 .588 .76 r
.68491 .39969 .69059 .41425 .70159 .40758 .69599 .39437 Mtetra
.634 .59 .787 r
.69599 .39437 .70159 .40758 .71267 .40192 .70721 .39092 Mtetra
.603 .611 .833 r
.70721 .39092 .71267 .40192 .72385 .39733 .71856 .38892 Mtetra
.56 .653 .898 r
.71856 .38892 .72385 .39733 .73515 .39405 .73004 .38797 Mtetra
.505 .706 .961 r
.73004 .38797 .73515 .39405 .74656 .39166 .74161 .38742 Mtetra
.469 .767 .995 r
.74161 .38742 .74656 .39166 .75806 .38974 .75322 .38647 Mtetra
.461 .805 .999 r
.75322 .38647 .75806 .38974 .76963 .38795 .76485 .38496 Mtetra
.513 .843 .998 r
.76485 .38496 .76963 .38795 .78123 .38582 .77648 .38255 Mtetra
.573 .859 .996 r
.77648 .38255 .78123 .38582 .79286 .38333 .7881 .37944 Mtetra
.624 .855 .986 r
.7881 .37944 .79286 .38333 .8045 .38034 .79973 .37577 Mtetra
.655 .839 .971 r
.79973 .37577 .8045 .38034 .81616 .37697 .81137 .37171 Mtetra
.668 .816 .954 r
.81137 .37171 .81616 .37697 .82785 .37331 .82305 .36749 Mtetra
.675 .798 .94 r
.82305 .36749 .82785 .37331 .83956 .36944 .83476 .36315 Mtetra
.677 .782 .929 r
.83476 .36315 .83956 .36944 .85131 .36546 .84651 .35878 Mtetra
.674 .768 .921 r
.84651 .35878 .85131 .36546 .8631 .36144 .85831 .35446 Mtetra
.632 .745 .93 r
.22623 .54871 .23264 .55431 .24209 .55179 .23568 .54619 Mtetra
.626 .745 .932 r
.23568 .54619 .24209 .55179 .25156 .54932 .24517 .54378 Mtetra
.621 .746 .936 r
.24517 .54378 .25156 .54932 .26107 .54682 .25469 .54145 Mtetra
.616 .752 .942 r
.25469 .54145 .26107 .54682 .27063 .54423 .26424 .53918 Mtetra
.608 .762 .953 r
.26424 .53918 .27063 .54423 .28024 .54147 .27383 .537 Mtetra
.608 .786 .966 r
.27383 .537 .28024 .54147 .28991 .53836 .28346 .53467 Mtetra
.61 .819 .981 r
.28346 .53467 .28991 .53836 .29964 .5347 .29315 .53207 Mtetra
.624 .867 .988 r
.29315 .53207 .29964 .5347 .30946 .53037 .30293 .52886 Mtetra
.651 .915 .979 r
.30293 .52886 .30946 .53037 .31935 .52518 .31279 .52473 Mtetra
.677 .951 .954 r
.31279 .52473 .31935 .52518 .32931 .51943 .32275 .5196 Mtetra
.727 .973 .928 r
.32275 .5196 .32931 .51943 .3393 .51329 .33279 .51328 Mtetra
.761 .973 .923 r
.33279 .51328 .3393 .51329 .34929 .50754 .34289 .50639 Mtetra
.789 .942 .926 r
.34289 .50639 .34929 .50754 .35926 .50279 .35301 .49935 Mtetra
.77 .858 .916 r
.35301 .49935 .35926 .50279 .36918 .49945 .36311 .49305 Mtetra
.71 .748 .882 r
.36311 .49305 .36918 .49945 .37906 .49793 .37316 .48824 Mtetra
.647 .643 .832 r
.37316 .48824 .37906 .49793 .38893 .49768 .38316 .48503 Mtetra
.59 .564 .793 r
.38316 .48503 .38893 .49768 .39883 .49837 .39313 .48363 Mtetra
.558 .519 .768 r
.39313 .48363 .39883 .49837 .40877 .49923 .40311 .48339 Mtetra
.541 .497 .756 r
.40311 .48339 .40877 .49923 .4188 .49968 .41312 .48386 Mtetra
.538 .496 .757 r
.41312 .48386 .4188 .49968 .4289 .49946 .42319 .48443 Mtetra
.547 .511 .767 r
.42319 .48443 .4289 .49946 .43908 .49834 .43333 .48462 Mtetra
.56 .535 .784 r
.43333 .48462 .43908 .49834 .44934 .49647 .44354 .48429 Mtetra
.578 .569 .807 r
.44354 .48429 .44934 .49647 .45965 .49393 .45382 .48325 Mtetra
.596 .605 .832 r
.45382 .48325 .45965 .49393 .47001 .49094 .46417 .48161 Mtetra
.613 .643 .856 r
.46417 .48161 .47001 .49094 .48042 .48765 .47458 .47944 Mtetra
.627 .678 .879 r
.47458 .47944 .48042 .48765 .49087 .4842 .48504 .47686 Mtetra
.638 .708 .897 r
.48504 .47686 .49087 .4842 .50136 .48071 .49555 .47398 Mtetra
.645 .731 .911 r
.49555 .47398 .50136 .48071 .51189 .47722 .5061 .47088 Mtetra
.65 .746 .92 r
.5061 .47088 .51189 .47722 .52246 .47378 .51669 .46762 Mtetra
.655 .755 .923 r
.51669 .46762 .52246 .47378 .53307 .47042 .52733 .46423 Mtetra
.659 .756 .922 r
.52733 .46423 .53307 .47042 .54372 .46712 .53801 .46071 Mtetra
.665 .751 .915 r
.53801 .46071 .54372 .46712 .55441 .46388 .54872 .45703 Mtetra
.672 .74 .901 r
.54872 .45703 .55441 .46388 .56515 .46065 .55948 .45313 Mtetra
.679 .723 .882 r
.55948 .45313 .56515 .46065 .57593 .45736 .57027 .44892 Mtetra
.686 .701 .858 r
.57027 .44892 .57593 .45736 .58674 .45392 .58109 .4443 Mtetra
.693 .677 .83 r
.58109 .4443 .58674 .45392 .5976 .45017 .59193 .43912 Mtetra
.696 .651 .802 r
.59193 .43912 .5976 .45017 .60848 .44597 .60279 .43334 Mtetra
.698 .628 .775 r
.60279 .43334 .60848 .44597 .61938 .44108 .61366 .42684 Mtetra
.696 .607 .753 r
.61366 .42684 .61938 .44108 .63029 .43543 .62453 .41978 Mtetra
.692 .591 .738 r
.62453 .41978 .63029 .43543 .6412 .42883 .63541 .41232 Mtetra
.686 .58 .731 r
.63541 .41232 .6412 .42883 .6521 .42155 .64631 .40496 Mtetra
.675 .573 .733 r
.64631 .40496 .6521 .42155 .663 .41384 .65726 .39831 Mtetra
.662 .577 .748 r
.65726 .39831 .663 .41384 .67393 .40629 .66828 .39283 Mtetra
.637 .588 .783 r
.66828 .39283 .67393 .40629 .68491 .39969 .67942 .38919 Mtetra
.602 .621 .843 r
.67942 .38919 .68491 .39969 .69599 .39437 .69069 .38721 Mtetra
.522 .674 .933 r
.69069 .38721 .69599 .39437 .70721 .39092 .70211 .38676 Mtetra
.365 .714 .987 r
.70211 .38676 .70721 .39092 .71856 .38892 .71364 .38708 Mtetra
.184 .69 .904 r
.71364 .38708 .71856 .38892 .73004 .38797 .72523 .38726 Mtetra
.122 .668 .818 r
.72523 .38726 .73004 .38797 .74161 .38742 .73686 .38686 Mtetra
.236 .751 .852 r
.73686 .38686 .74161 .38742 .75322 .38647 .74847 .38524 Mtetra
.407 .845 .937 r
.74847 .38524 .75322 .38647 .76485 .38496 .76007 .38258 Mtetra
.566 .89 .987 r
.76007 .38258 .76485 .38496 .77648 .38255 .77166 .37896 Mtetra
.647 .876 .983 r
.77166 .37896 .77648 .38255 .7881 .37944 .78323 .37471 Mtetra
.678 .84 .961 r
.78323 .37471 .7881 .37944 .79973 .37577 .79483 .37016 Mtetra
.688 .81 .94 r
.79483 .37016 .79973 .37577 .81137 .37171 .80646 .36547 Mtetra
.686 .787 .927 r
.80646 .36547 .81137 .37171 .82305 .36749 .81814 .36085 Mtetra
.683 .773 .919 r
.81814 .36085 .82305 .36749 .83476 .36315 .82987 .35628 Mtetra
.68 .765 .916 r
.82987 .35628 .83476 .36315 .84651 .35878 .84164 .3518 Mtetra
.675 .76 .915 r
.84164 .3518 .84651 .35878 .85831 .35446 .85348 .34743 Mtetra
.644 .748 .925 r
.21976 .54307 .22623 .54871 .23568 .54619 .22926 .54028 Mtetra
.639 .738 .921 r
.22926 .54028 .23568 .54619 .24517 .54378 .23879 .5376 Mtetra
.631 .728 .917 r
.23879 .5376 .24517 .54378 .25469 .54145 .24834 .5351 Mtetra
.62 .719 .917 r
.24834 .5351 .25469 .54145 .26424 .53918 .25791 .53283 Mtetra
.603 .714 .923 r
.25791 .53283 .26424 .53918 .27383 .537 .26749 .53092 Mtetra
.588 .72 .934 r
.26749 .53092 .27383 .537 .28346 .53467 .27709 .52924 Mtetra
.564 .737 .957 r
.27709 .52924 .28346 .53467 .29315 .53207 .28672 .52783 Mtetra
.549 .78 .984 r
.28672 .52783 .29315 .53207 .30293 .52886 .2964 .52625 Mtetra
.521 .837 .999 r
.2964 .52625 .30293 .52886 .31279 .52473 .30616 .52426 Mtetra
.484 .886 .947 r
.30616 .52426 .31279 .52473 .32275 .5196 .31602 .52124 Mtetra
.465 .889 .822 r
.31602 .52124 .32275 .5196 .33279 .51328 .32602 .51665 Mtetra
.462 .866 .7 r
.32602 .51665 .33279 .51328 .34289 .50639 .33613 .51044 Mtetra
.572 .913 .694 r
.33613 .51044 .34289 .50639 .35301 .49935 .34637 .50241 Mtetra
.71 .98 .786 r
.34637 .50241 .35301 .49935 .36311 .49305 .35664 .49364 Mtetra
.82 .984 .883 r
.35664 .49364 .36311 .49305 .37316 .48824 .36692 .48485 Mtetra
.805 .862 .891 r
.36692 .48485 .37316 .48824 .38316 .48503 .37716 .47717 Mtetra
.72 .713 .842 r
.37716 .47717 .38316 .48503 .39313 .48363 .38732 .47151 Mtetra
.648 .602 .789 r
.38732 .47151 .39313 .48363 .40311 .48339 .39743 .46782 Mtetra
.591 .529 .754 r
.39743 .46782 .40311 .48339 .41312 .48386 .4075 .4662 Mtetra
.561 .492 .735 r
.4075 .4662 .41312 .48386 .42319 .48443 .41758 .46584 Mtetra
.545 .475 .727 r
.41758 .46584 .42319 .48443 .43333 .48462 .42769 .46621 Mtetra
.542 .475 .73 r
.42769 .46621 .43333 .48462 .44354 .48429 .43786 .46674 Mtetra
.548 .487 .738 r
.43786 .46674 .44354 .48429 .45382 .48325 .4481 .46694 Mtetra
.559 .505 .752 r
.4481 .46694 .45382 .48325 .46417 .48161 .45842 .46666 Mtetra
.574 .529 .767 r
.45842 .46666 .46417 .48161 .47458 .47944 .4688 .46574 Mtetra
.589 .554 .783 r
.4688 .46574 .47458 .47944 .48504 .47686 .47924 .46423 Mtetra
.605 .578 .797 r
.47924 .46423 .48504 .47686 .49555 .47398 .48974 .46216 Mtetra
.619 .599 .808 r
.48974 .46216 .49555 .47398 .5061 .47088 .5003 .4596 Mtetra
.632 .615 .815 r
.5003 .4596 .5061 .47088 .51669 .46762 .5109 .4566 Mtetra
.643 .625 .817 r
.5109 .4566 .51669 .46762 .52733 .46423 .52155 .45318 Mtetra
.653 .63 .814 r
.52155 .45318 .52733 .46423 .53801 .46071 .53224 .44935 Mtetra
.662 .629 .806 r
.53224 .44935 .53801 .46071 .54872 .45703 .54296 .44506 Mtetra
.669 .623 .794 r
.54296 .44506 .54872 .45703 .55948 .45313 .55372 .44029 Mtetra
.676 .614 .778 r
.55372 .44029 .55948 .45313 .57027 .44892 .5645 .43494 Mtetra
.679 .601 .761 r
.5645 .43494 .57027 .44892 .58109 .4443 .57531 .42899 Mtetra
.682 .588 .744 r
.57531 .42899 .58109 .4443 .59193 .43912 .58613 .42238 Mtetra
.681 .574 .729 r
.58613 .42238 .59193 .43912 .60279 .43334 .59696 .41527 Mtetra
.678 .562 .717 r
.59696 .41527 .60279 .43334 .61366 .42684 .60779 .40783 Mtetra
.672 .552 .711 r
.60779 .40783 .61366 .42684 .62453 .41978 .61865 .40051 Mtetra
.661 .544 .711 r
.61865 .40051 .62453 .41978 .63541 .41232 .62955 .39394 Mtetra
.646 .542 .722 r
.62955 .39394 .63541 .41232 .64631 .40496 .64052 .38864 Mtetra
.618 .544 .749 r
.64052 .38864 .64631 .40496 .65726 .39831 .65161 .38545 Mtetra
.579 .566 .804 r
.65161 .38545 .65726 .39831 .66828 .39283 .66283 .38427 Mtetra
.476 .606 .902 r
.66283 .38427 .66828 .39283 .67942 .38919 .67421 .38516 Mtetra
.192 .615 .946 r
.67421 .38516 .67942 .38919 .69069 .38721 .68572 .38722 Mtetra
.209 0 0 r
.68572 .38722 .69069 .38721 .70211 .38676 .69732 .38928 Mtetra
.323 0 0 r
.69732 .38928 .70211 .38676 .71364 .38708 .70896 .39059 Mtetra
.244 0 0 r
.70896 .39059 .71364 .38708 .72523 .38726 .72058 .39004 Mtetra
.057 0 0 r
.72058 .39004 .72523 .38726 .73686 .38686 .73215 .38781 Mtetra
.294 .787 .75 r
.73215 .38781 .73686 .38686 .74847 .38524 .74367 .38396 Mtetra
.593 .933 .951 r
.74367 .38396 .74847 .38524 .76007 .38258 .75517 .37905 Mtetra
.7 .895 .967 r
.75517 .37905 .76007 .38258 .77166 .37896 .76666 .37368 Mtetra
.718 .832 .935 r
.76666 .37368 .77166 .37896 .78323 .37471 .77818 .36815 Mtetra
.707 .783 .911 r
.77818 .36815 .78323 .37471 .79483 .37016 .78976 .36287 Mtetra
.697 .756 .898 r
.78976 .36287 .79483 .37016 .80646 .36547 .8014 .35784 Mtetra
.684 .742 .895 r
.8014 .35784 .80646 .36547 .81814 .36085 .8131 .35316 Mtetra
.676 .738 .897 r
.8131 .35316 .81814 .36085 .82987 .35628 .82488 .34874 Mtetra
.67 .74 .903 r
.82488 .34874 .82987 .35628 .84164 .3518 .83671 .34448 Mtetra
.666 .747 .911 r
.83671 .34448 .84164 .3518 .85348 .34743 .84861 .34035 Mtetra
.664 .753 .917 r
.21326 .53739 .21976 .54307 .22926 .54028 .22282 .53411 Mtetra
.661 .737 .906 r
.22282 .53411 .22926 .54028 .23879 .5376 .23241 .53087 Mtetra
.654 .718 .895 r
.23241 .53087 .23879 .5376 .24834 .5351 .24202 .5278 Mtetra
.642 .698 .886 r
.24202 .5278 .24834 .5351 .25791 .53283 .25165 .52502 Mtetra
.626 .678 .879 r
.25165 .52502 .25791 .53283 .26749 .53092 .26127 .52264 Mtetra
.607 .659 .875 r
.26127 .52264 .26749 .53092 .27709 .52924 .2709 .52075 Mtetra
.582 .643 .877 r
.2709 .52075 .27709 .52924 .28672 .52783 .28053 .51948 Mtetra
.563 .64 .885 r
.28053 .51948 .28672 .52783 .2964 .52625 .29018 .51862 Mtetra
.539 .651 .908 r
.29018 .51862 .2964 .52625 .30616 .52426 .29985 .51811 Mtetra
.534 .701 .947 r
.29985 .51811 .30616 .52426 .31602 .52124 .30959 .51731 Mtetra
.534 .791 .992 r
.30959 .51731 .31602 .52124 .32602 .51665 .31943 .51573 Mtetra
.514 .89 .967 r
.31943 .51573 .32602 .51665 .33613 .51044 .3294 .51269 Mtetra
.457 .879 .776 r
.3294 .51269 .33613 .51044 .34637 .50241 .33952 .50754 Mtetra
0 0 0 r
.33952 .50754 .34637 .50241 .35664 .49364 .34977 .50056 Mtetra
.34977 .50056 .35664 .49364 .36692 .48485 .36012 .49183 Mtetra
.36012 .49183 .36692 .48485 .37716 .47717 .3705 .48254 Mtetra
.505 .848 .577 r
.3705 .48254 .37716 .47717 .38732 .47151 .38087 .47356 Mtetra
.702 .984 .833 r
.38087 .47356 .38732 .47151 .39743 .46782 .3912 .46569 Mtetra
.755 .916 .945 r
.3912 .46569 .39743 .46782 .4075 .4662 .40147 .45958 Mtetra
.698 .745 .888 r
.40147 .45958 .4075 .4662 .41758 .46584 .41171 .45506 Mtetra
.634 .621 .819 r
.41171 .45506 .41758 .46584 .42769 .46621 .42193 .45209 Mtetra
.6 .553 .773 r
.42193 .45209 .42769 .46621 .43786 .46674 .43216 .4501 Mtetra
.583 .516 .745 r
.43216 .4501 .43786 .46674 .4481 .46694 .44243 .44871 Mtetra
.577 .498 .73 r
.44243 .44871 .4481 .46694 .45842 .46666 .45274 .44752 Mtetra
.578 .492 .721 r
.45274 .44752 .45842 .46666 .4688 .46574 .46311 .44621 Mtetra
.583 .493 .718 r
.46311 .44621 .4688 .46574 .47924 .46423 .47354 .44463 Mtetra
.59 .497 .717 r
.47354 .44463 .47924 .46423 .48974 .46216 .48402 .44262 Mtetra
.598 .503 .717 r
.48402 .44262 .48974 .46216 .5003 .4596 .49455 .44015 Mtetra
.607 .509 .717 r
.49455 .44015 .5003 .4596 .5109 .4566 .50514 .4372 Mtetra
.615 .514 .716 r
.50514 .4372 .5109 .4566 .52155 .45318 .51577 .43374 Mtetra
.623 .519 .715 r
.51577 .43374 .52155 .45318 .53224 .44935 .52645 .42979 Mtetra
.63 .523 .713 r
.52645 .42979 .53224 .44935 .54296 .44506 .53716 .42534 Mtetra
.636 .525 .711 r
.53716 .42534 .54296 .44506 .55372 .44029 .5479 .42043 Mtetra
.641 .528 .709 r
.5479 .42043 .55372 .44029 .5645 .43494 .55867 .41508 Mtetra
.645 .53 .709 r
.55867 .41508 .5645 .43494 .57531 .42899 .56946 .40946 Mtetra
.648 .534 .711 r
.56946 .40946 .57531 .42899 .58613 .42238 .58029 .4037 Mtetra
.649 .541 .718 r
.58029 .4037 .58613 .42238 .59696 .41527 .59114 .39813 Mtetra
.646 .552 .734 r
.59114 .39813 .59696 .41527 .60779 .40783 .60204 .39316 Mtetra
.639 .573 .765 r
.60204 .39316 .60779 .40783 .61865 .40051 .613 .38919 Mtetra
.613 .61 .824 r
.613 .38919 .61865 .40051 .62955 .39394 .62405 .3868 Mtetra
.536 .682 .932 r
.62405 .3868 .62955 .39394 .64052 .38864 .6352 .38603 Mtetra
.163 .652 .92 r
.6352 .38603 .64052 .38864 .65161 .38545 .64649 .38706 Mtetra
.341 0 0 r
.64649 .38706 .65161 .38545 .66283 .38427 .65791 .38925 Mtetra
.473 0 0 r
.65791 .38925 .66283 .38427 .67421 .38516 .66943 .39177 Mtetra
.475 0 .036 r
.66943 .39177 .67421 .38516 .68572 .38722 .68101 .39374 Mtetra
.398 0 0 r
.68101 .39374 .68572 .38722 .69732 .38928 .69258 .39392 Mtetra
.224 0 0 r
.69258 .39392 .69732 .38928 .70896 .39059 .70412 .39223 Mtetra
0 0 0 r
.70412 .39223 .70896 .39059 .72058 .39004 .7156 .38838 Mtetra
.648 .942 .961 r
.7156 .38838 .72058 .39004 .73215 .38781 .72702 .383 Mtetra
.742 .854 .932 r
.72702 .383 .73215 .38781 .74367 .38396 .73843 .37679 Mtetra
.74 .773 .88 r
.73843 .37679 .74367 .38396 .75517 .37905 .74985 .37028 Mtetra
.718 .722 .852 r
.74985 .37028 .75517 .37905 .76666 .37368 .76131 .36412 Mtetra
.702 .697 .842 r
.76131 .36412 .76666 .37368 .77818 .36815 .77285 .35838 Mtetra
.685 .686 .845 r
.77285 .35838 .77818 .36815 .78976 .36287 .78446 .35327 Mtetra
.673 .685 .853 r
.78446 .35327 .78976 .36287 .8014 .35784 .79616 .34867 Mtetra
.663 .692 .866 r
.79616 .34867 .8014 .35784 .8131 .35316 .80795 .34449 Mtetra
.656 .702 .881 r
.80795 .34449 .8131 .35316 .82488 .34874 .8198 .3406 Mtetra
.651 .716 .896 r
.8198 .3406 .82488 .34874 .83671 .34448 .83172 .33688 Mtetra
.649 .732 .91 r
.83172 .33688 .83671 .34448 .84861 .34035 .8437 .33321 Mtetra
.685 .758 .907 r
.20671 .53168 .21326 .53739 .22282 .53411 .21634 .52783 Mtetra
.684 .74 .893 r
.21634 .52783 .22282 .53411 .23241 .53087 .22601 .52393 Mtetra
.679 .719 .879 r
.22601 .52393 .23241 .53087 .24202 .5278 .2357 .52009 Mtetra
.67 .696 .865 r
.2357 .52009 .24202 .5278 .25165 .52502 .24541 .51642 Mtetra
.658 .67 .85 r
.24541 .51642 .25165 .52502 .26127 .52264 .25514 .513 Mtetra
.64 .64 .835 r
.25514 .513 .26127 .52264 .2709 .52075 .26485 .51007 Mtetra
.616 .61 .822 r
.26485 .51007 .2709 .52075 .28053 .51948 .27456 .50783 Mtetra
.588 .579 .811 r
.27456 .50783 .28053 .51948 .29018 .51862 .28424 .50645 Mtetra
.553 .553 .808 r
.28424 .50645 .29018 .51862 .29985 .51811 .29389 .50616 Mtetra
.521 .541 .817 r
.29389 .50616 .29985 .51811 .30959 .51731 .30354 .50673 Mtetra
.475 .545 .848 r
.30354 .50673 .30959 .51731 .31943 .51573 .31319 .50809 Mtetra
.43 .605 .92 r
.31319 .50809 .31943 .51573 .3294 .51269 .32292 .5093 Mtetra
.309 .712 .977 r
.32292 .5093 .3294 .51269 .33952 .50754 .33277 .50961 Mtetra
0 0 0 r
.33277 .50961 .33952 .50754 .34977 .50056 .34278 .50796 Mtetra
.103 0 0 r
.34278 .50796 .34977 .50056 .36012 .49183 .35299 .50342 Mtetra
.122 0 .009 r
.35299 .50342 .36012 .49183 .3705 .48254 .36335 .49625 Mtetra
.06 0 .028 r
.36335 .49625 .3705 .48254 .38087 .47356 .37385 .48653 Mtetra
0 0 0 r
.37385 .48653 .38087 .47356 .3912 .46569 .38439 .47574 Mtetra
.38439 .47574 .3912 .46569 .40147 .45958 .39493 .46488 Mtetra
.577 .886 .603 r
.39493 .46488 .40147 .45958 .41171 .45506 .40542 .45493 Mtetra
.806 .977 .9 r
.40542 .45493 .41171 .45506 .42193 .45209 .41586 .44663 Mtetra
.765 .798 .88 r
.41586 .44663 .42193 .45209 .43216 .4501 .42626 .43991 Mtetra
.689 .657 .813 r
.42626 .43991 .43216 .4501 .44243 .44871 .43664 .43478 Mtetra
.645 .58 .767 r
.43664 .43478 .44243 .44871 .45274 .44752 .44702 .43075 Mtetra
.619 .536 .739 r
.44702 .43075 .45274 .44752 .46311 .44621 .45741 .42748 Mtetra
.607 .513 .722 r
.45741 .42748 .46311 .44621 .47354 .44463 .46784 .42459 Mtetra
.602 .501 .712 r
.46784 .42459 .47354 .44463 .48402 .44262 .47832 .42179 Mtetra
.603 .496 .706 r
.47832 .42179 .48402 .44262 .49455 .44015 .48883 .41886 Mtetra
.605 .496 .702 r
.48883 .41886 .49455 .44015 .50514 .4372 .4994 .41569 Mtetra
.61 .497 .701 r
.4994 .41569 .50514 .4372 .51577 .43374 .51001 .41219 Mtetra
.614 .5 .7 r
.51001 .41219 .51577 .43374 .52645 .42979 .52066 .40839 Mtetra
.618 .503 .701 r
.52066 .40839 .52645 .42979 .53716 .42534 .53135 .40432 Mtetra
.621 .508 .703 r
.53135 .40432 .53716 .42534 .5479 .42043 .54208 .40014 Mtetra
.621 .513 .709 r
.54208 .40014 .5479 .42043 .55867 .41508 .55284 .39603 Mtetra
.619 .52 .72 r
.55284 .39603 .55867 .41508 .56946 .40946 .56365 .3923 Mtetra
.611 .531 .74 r
.56365 .3923 .56946 .40946 .58029 .4037 .57451 .38935 Mtetra
.593 .552 .778 r
.57451 .38935 .58029 .4037 .59114 .39813 .58544 .38751 Mtetra
.542 .588 .85 r
.58544 .38751 .59114 .39813 .60204 .39316 .59647 .38729 Mtetra
.359 .64 .962 r
.59647 .38729 .60204 .39316 .613 .38919 .6076 .38869 Mtetra
.276 0 0 r
.6076 .38869 .613 .38919 .62405 .3868 .61886 .39178 Mtetra
.537 .032 .004 r
.61886 .39178 .62405 .3868 .6352 .38603 .63024 .39583 Mtetra
.559 .132 .187 r
.63024 .39583 .6352 .38603 .64649 .38706 .64172 .39984 Mtetra
.539 .144 .241 r
.64172 .39984 .64649 .38706 .65791 .38925 .65325 .40276 Mtetra
.481 .095 .231 r
.65325 .40276 .65791 .38925 .66943 .39177 .66477 .4031 Mtetra
.382 0 .145 r
.66477 .4031 .66943 .39177 .68101 .39374 .67623 .40075 Mtetra
.104 0 0 r
.67623 .40075 .68101 .39374 .69258 .39392 .6876 .39542 Mtetra
.563 .928 .774 r
.6876 .39542 .69258 .39392 .70412 .39223 .6989 .38805 Mtetra
.805 .886 .904 r
.6989 .38805 .70412 .39223 .7156 .38838 .71016 .37975 Mtetra
.769 .742 .828 r
.71016 .37975 .7156 .38838 .72702 .383 .72143 .37127 Mtetra
.724 .664 .79 r
.72143 .37127 .72702 .383 .73843 .37679 .73276 .36359 Mtetra
.697 .629 .777 r
.73276 .36359 .73843 .37679 .74985 .37028 .74417 .35679 Mtetra
.675 .615 .78 r
.74417 .35679 .74985 .37028 .76131 .36412 .75569 .35111 Mtetra
.66 .614 .793 r
.75569 .35111 .76131 .36412 .77285 .35838 .76731 .34632 Mtetra
.649 .624 .812 r
.76731 .34632 .77285 .35838 .78446 .35327 .77903 .34224 Mtetra
.64 .64 .834 r
.77903 .34224 .78446 .35327 .79616 .34867 .79084 .33866 Mtetra
.635 .66 .857 r
.79084 .33866 .79616 .34867 .80795 .34449 .80272 .33535 Mtetra
.631 .68 .878 r
.80272 .33535 .80795 .34449 .8198 .3406 .81468 .33222 Mtetra
.628 .701 .897 r
.81468 .33222 .8198 .3406 .83172 .33688 .82669 .32915 Mtetra
.629 .721 .913 r
.82669 .32915 .83172 .33688 .8437 .33321 .83876 .32602 Mtetra
.693 .759 .903 r
.20012 .52592 .20671 .53168 .21634 .52783 .20979 .52182 Mtetra
.696 .752 .895 r
.20979 .52182 .21634 .52783 .22601 .52393 .21951 .51758 Mtetra
.697 .743 .887 r
.21951 .51758 .22601 .52393 .2357 .52009 .22927 .51326 Mtetra
.695 .729 .876 r
.22927 .51326 .2357 .52009 .24541 .51642 .23905 .50891 Mtetra
.691 .709 .862 r
.23905 .50891 .24541 .51642 .25514 .513 .24887 .50454 Mtetra
.679 .682 .846 r
.24887 .50454 .25514 .513 .26485 .51007 .2587 .50039 Mtetra
.662 .65 .827 r
.2587 .50039 .26485 .51007 .27456 .50783 .26852 .49661 Mtetra
.636 .61 .807 r
.26852 .49661 .27456 .50783 .28424 .50645 .27833 .49355 Mtetra
.604 .568 .787 r
.27833 .49355 .28424 .50645 .29389 .50616 .2881 .49152 Mtetra
.569 .527 .769 r
.2881 .49152 .29389 .50616 .30354 .50673 .29783 .49072 Mtetra
.529 .489 .755 r
.29783 .49072 .30354 .50673 .31319 .50809 .30751 .49143 Mtetra
.502 .466 .749 r
.30751 .49143 .31319 .50809 .32292 .5093 .31719 .49316 Mtetra
.475 .456 .757 r
.31719 .49316 .32292 .5093 .33277 .50961 .32689 .49566 Mtetra
.474 .485 .789 r
.32689 .49566 .33277 .50961 .34278 .50796 .33668 .49776 Mtetra
.497 .569 .858 r
.33668 .49776 .34278 .50796 .35299 .50342 .34662 .49853 Mtetra
.532 .757 .979 r
.34662 .49853 .35299 .50342 .36335 .49625 .35672 .49723 Mtetra
.438 .877 .85 r
.35672 .49723 .36335 .49625 .37385 .48653 .367 .49321 Mtetra
0 0 0 r
.367 .49321 .37385 .48653 .38439 .47574 .37742 .48699 Mtetra
.05 0 0 r
.37742 .48699 .38439 .47574 .39493 .46488 .38793 .47888 Mtetra
.12 0 .066 r
.38793 .47888 .39493 .46488 .40542 .45493 .39849 .46994 Mtetra
.152 0 .103 r
.39849 .46994 .40542 .45493 .41586 .44663 .40905 .46091 Mtetra
.154 0 .092 r
.40905 .46091 .41586 .44663 .42626 .43991 .41961 .45233 Mtetra
.14 0 .046 r
.41961 .45233 .42626 .43991 .43664 .43478 .43014 .44465 Mtetra
.088 0 0 r
.43014 .44465 .43664 .43478 .44702 .43075 .44067 .43786 Mtetra
0 0 0 r
.44067 .43786 .44702 .43075 .45741 .42748 .45119 .432 Mtetra
.45119 .432 .45741 .42748 .46784 .42459 .46172 .42685 Mtetra
.324 .795 .698 r
.46172 .42685 .46784 .42459 .47832 .42179 .47228 .4223 Mtetra
.458 .887 .87 r
.47228 .4223 .47832 .42179 .48883 .41886 .48286 .41818 Mtetra
.525 .907 .947 r
.48286 .41818 .48883 .41886 .4994 .41569 .49348 .41439 Mtetra
.54 .9 .97 r
.49348 .41439 .4994 .41569 .51001 .41219 .50413 .41088 Mtetra
.513 .889 .969 r
.50413 .41088 .51001 .41219 .52066 .40839 .51482 .40764 Mtetra
.432 .863 .932 r
.51482 .40764 .52066 .40839 .53135 .40432 .52556 .40474 Mtetra
.26 .77 .806 r
.52556 .40474 .53135 .40432 .54208 .40014 .53634 .40227 Mtetra
.001 0 0 r
.53634 .40227 .54208 .40014 .55284 .39603 .54718 .4004 Mtetra
.239 0 0 r
.54718 .4004 .55284 .39603 .56365 .3923 .55809 .39927 Mtetra
.388 0 .005 r
.55809 .39927 .56365 .3923 .57451 .38935 .56906 .39908 Mtetra
.466 .038 .142 r
.56906 .39908 .57451 .38935 .58544 .38751 .58012 .3998 Mtetra
.508 .11 .221 r
.58012 .3998 .58544 .38751 .59647 .38729 .59126 .40145 Mtetra
.525 .143 .259 r
.59126 .40145 .59647 .38729 .6076 .38869 .60251 .40358 Mtetra
.524 .148 .269 r
.60251 .40358 .6076 .38869 .61886 .39178 .61383 .40564 Mtetra
.502 .118 .244 r
.61383 .40564 .61886 .39178 .63024 .39583 .62521 .40686 Mtetra
.43 .019 .155 r
.62521 .40686 .63024 .39583 .64172 .39984 .63661 .40617 Mtetra
.215 0 0 r
.63661 .40617 .64172 .39984 .65325 .40276 .64799 .40324 Mtetra
.541 .927 .858 r
.64799 .40324 .65325 .40276 .66477 .4031 .65931 .39751 Mtetra
.785 .831 .887 r
.65931 .39751 .66477 .4031 .67623 .40075 .67056 .38964 Mtetra
.756 .686 .785 r
.67056 .38964 .67623 .40075 .6876 .39542 .68176 .3804 Mtetra
.727 .621 .74 r
.68176 .3804 .6876 .39542 .6989 .38805 .69294 .37071 Mtetra
.701 .586 .724 r
.69294 .37071 .6989 .38805 .71016 .37975 .70417 .3618 Mtetra
.683 .571 .723 r
.70417 .3618 .71016 .37975 .72143 .37127 .71547 .35393 Mtetra
.664 .566 .734 r
.71547 .35393 .72143 .37127 .73276 .36359 .72689 .34761 Mtetra
.65 .572 .753 r
.72689 .34761 .73276 .36359 .74417 .35679 .73843 .34254 Mtetra
.637 .585 .779 r
.73843 .34254 .74417 .35679 .75569 .35111 .75008 .33854 Mtetra
.627 .605 .809 r
.75008 .33854 .75569 .35111 .76731 .34632 .76183 .33529 Mtetra
.62 .63 .839 r
.76183 .33529 .76731 .34632 .77903 .34224 .77366 .33243 Mtetra
.615 .655 .867 r
.77366 .33243 .77903 .34224 .79084 .33866 .78558 .3298 Mtetra
.615 .68 .889 r
.78558 .3298 .79084 .33866 .80272 .33535 .79755 .32714 Mtetra
.614 .699 .905 r
.79755 .32714 .80272 .33535 .81468 .33222 .80958 .32446 Mtetra
.615 .715 .916 r
.80958 .32446 .81468 .33222 .82669 .32915 .82166 .32168 Mtetra
.619 .727 .924 r
.82166 .32168 .82669 .32915 .83876 .32602 .83378 .31877 Mtetra
.687 .758 .906 r
.19348 .52013 .20012 .52592 .20979 .52182 .20316 .51616 Mtetra
.693 .765 .907 r
.20316 .51616 .20979 .52182 .21951 .51758 .21289 .51203 Mtetra
.7 .77 .906 r
.21289 .51203 .21951 .51758 .22927 .51326 .22267 .50769 Mtetra
.708 .772 .902 r
.22267 .50769 .22927 .51326 .23905 .50891 .2325 .5031 Mtetra
.717 .766 .891 r
.2325 .5031 .23905 .50891 .24887 .50454 .24238 .49819 Mtetra
.719 .75 .877 r
.24238 .49819 .24887 .50454 .2587 .50039 .25231 .49306 Mtetra
.717 .723 .855 r
.25231 .49306 .2587 .50039 .26852 .49661 .26228 .48776 Mtetra
.702 .683 .829 r
.26228 .48776 .26852 .49661 .27833 .49355 .27226 .48257 Mtetra
.68 .635 .797 r
.27226 .48257 .27833 .49355 .2881 .49152 .28224 .47769 Mtetra
.648 .579 .764 r
.28224 .47769 .2881 .49152 .29783 .49072 .2922 .47359 Mtetra
.612 .526 .733 r
.2922 .47359 .29783 .49072 .30751 .49143 .3021 .47067 Mtetra
.575 .477 .706 r
.3021 .47067 .30751 .49143 .31719 .49316 .31195 .46937 Mtetra
.535 .434 .686 r
.31195 .46937 .31719 .49316 .32689 .49566 .32171 .47015 Mtetra
.502 .404 .676 r
.32171 .47015 .32689 .49566 .33668 .49776 .33142 .47284 Mtetra
.463 .38 .678 r
.33142 .47284 .33668 .49776 .34662 .49853 .3411 .47737 Mtetra
.429 .382 .704 r
.3411 .47737 .34662 .49853 .35672 .49723 .35084 .48246 Mtetra
.377 .417 .776 r
.35084 .48246 .35672 .49723 .367 .49321 .36069 .48715 Mtetra
.194 .541 .927 r
.36069 .48715 .367 .49321 .37742 .48699 .37071 .49013 Mtetra
.286 0 0 r
.37071 .49013 .37742 .48699 .38793 .47888 .38092 .4904 Mtetra
.368 0 .135 r
.38092 .4904 .38793 .47888 .39849 .46994 .3913 .48801 Mtetra
.361 .019 .243 r
.3913 .48801 .39849 .46994 .40905 .46091 .40183 .48296 Mtetra
.356 .038 .281 r
.40183 .48296 .40905 .46091 .41961 .45233 .41244 .47621 Mtetra
.349 .04 .293 r
.41244 .47621 .41961 .45233 .43014 .44465 .42311 .46842 Mtetra
.343 .035 .29 r
.42311 .46842 .43014 .44465 .44067 .43786 .4338 .46037 Mtetra
.339 .026 .28 r
.4338 .46037 .44067 .43786 .45119 .432 .44449 .45265 Mtetra
.336 .014 .262 r
.44449 .45265 .45119 .432 .46172 .42685 .45518 .44552 Mtetra
.338 .003 .243 r
.45518 .44552 .46172 .42685 .47228 .4223 .46587 .43925 Mtetra
.344 0 .224 r
.46587 .43925 .47228 .4223 .48286 .41818 .47658 .43387 Mtetra
.358 0 .213 r
.47658 .43387 .48286 .41818 .49348 .41439 .4873 .42942 Mtetra
.38 .014 .212 r
.4873 .42942 .49348 .41439 .50413 .41088 .49805 .4259 Mtetra
.409 .041 .225 r
.49805 .4259 .50413 .41088 .51482 .40764 .50884 .42331 Mtetra
.44 .076 .248 r
.50884 .42331 .51482 .40764 .52556 .40474 .51968 .42167 Mtetra
.469 .112 .276 r
.51968 .42167 .52556 .40474 .53634 .40227 .53057 .42092 Mtetra
.494 .145 .304 r
.53057 .42092 .53634 .40227 .54718 .4004 .54153 .42104 Mtetra
.51 .17 .328 r
.54153 .42104 .54718 .4004 .55809 .39927 .55256 .42179 Mtetra
.518 .186 .344 r
.55256 .42179 .55809 .39927 .56906 .39908 .56367 .42287 Mtetra
.515 .189 .352 r
.56367 .42287 .56906 .39908 .58012 .3998 .57486 .4237 Mtetra
.5 .175 .347 r
.57486 .4237 .58012 .3998 .59126 .40145 .5861 .42351 Mtetra
.466 .137 .323 r
.5861 .42351 .59126 .40145 .60251 .40358 .59737 .42159 Mtetra
.385 .042 .256 r
.59737 .42159 .60251 .40358 .61383 .40564 .60863 .41696 Mtetra
.161 0 .041 r
.60863 .41696 .61383 .40564 .62521 .40686 .61985 .40961 Mtetra
.667 .952 .712 r
.61985 .40961 .62521 .40686 .63661 .40617 .631 .39947 Mtetra
.844 .801 .81 r
.631 .39947 .63661 .40617 .64799 .40324 .64208 .38757 Mtetra
.754 .628 .72 r
.64208 .38757 .64799 .40324 .65931 .39751 .65313 .37522 Mtetra
.704 .555 .682 r
.65313 .37522 .65931 .39751 .67056 .38964 .66419 .36341 Mtetra
.668 .515 .668 r
.66419 .36341 .67056 .38964 .68176 .3804 .67533 .35348 Mtetra
.646 .498 .668 r
.67533 .35348 .68176 .3804 .69294 .37071 .68657 .34548 Mtetra
.628 .494 .68 r
.68657 .34548 .69294 .37071 .70417 .3618 .69794 .33962 Mtetra
.614 .501 .702 r
.69794 .33962 .70417 .3618 .71547 .35393 .70945 .33543 Mtetra
.605 .522 .734 r
.70945 .33543 .71547 .35393 .72689 .34761 .72107 .33245 Mtetra
.596 .551 .775 r
.72107 .33245 .72689 .34761 .73843 .34254 .7328 .33028 Mtetra
.591 .592 .822 r
.7328 .33028 .73843 .34254 .75008 .33854 .74461 .32843 Mtetra
.585 .633 .866 r
.74461 .32843 .75008 .33854 .76183 .33529 .7565 .32671 Mtetra
.587 .675 .901 r
.7565 .32671 .76183 .33529 .77366 .33243 .76844 .32481 Mtetra
.589 .706 .924 r
.76844 .32481 .77366 .33243 .78558 .3298 .78043 .32269 Mtetra
.599 .729 .935 r
.78043 .32269 .78558 .3298 .79755 .32714 .79245 .32023 Mtetra
.608 .74 .939 r
.79245 .32023 .79755 .32714 .80958 .32446 .80452 .31751 Mtetra
.616 .744 .937 r
.80452 .31751 .80958 .32446 .82166 .32168 .81662 .31458 Mtetra
.623 .743 .932 r
.81662 .31458 .82166 .32168 .83378 .31877 .82876 .31146 Mtetra
.665 .753 .916 r
.18679 .51429 .19348 .52013 .20316 .51616 .19644 .5109 Mtetra
.67 .775 .929 r
.19644 .5109 .20316 .51616 .21289 .51203 .20613 .50737 Mtetra
.678 .8 .94 r
.20613 .50737 .21289 .51203 .22267 .50769 .21589 .5036 Mtetra
.691 .824 .947 r
.21589 .5036 .22267 .50769 .2325 .5031 .2257 .49949 Mtetra
.708 .846 .948 r
.2257 .49949 .2325 .5031 .24238 .49819 .23558 .49491 Mtetra
.727 .861 .945 r
.23558 .49491 .24238 .49819 .25231 .49306 .24554 .48984 Mtetra
.747 .865 .934 r
.24554 .48984 .25231 .49306 .26228 .48776 .25556 .48421 Mtetra
.76 .853 .92 r
.25556 .48421 .26228 .48776 .27226 .48257 .26564 .47817 Mtetra
.766 .823 .897 r
.26564 .47817 .27226 .48257 .28224 .47769 .27577 .47177 Mtetra
.752 .773 .87 r
.27577 .47177 .28224 .47769 .2922 .47359 .28591 .46543 Mtetra
.725 .708 .834 r
.28591 .46543 .2922 .47359 .3021 .47067 .29605 .45945 Mtetra
.68 .633 .795 r
.29605 .45945 .3021 .47067 .31195 .46937 .30613 .45448 Mtetra
.628 .558 .757 r
.30613 .45448 .31195 .46937 .32171 .47015 .31615 .45109 Mtetra
.578 .491 .72 r
.31615 .45109 .32171 .47015 .33142 .47284 .32608 .44966 Mtetra
.531 .435 .691 r
.32608 .44966 .33142 .47284 .3411 .47737 .33593 .45057 Mtetra
.503 .399 .669 r
.33593 .45057 .3411 .47737 .35084 .48246 .34574 .45325 Mtetra
.484 .376 .656 r
.34574 .45325 .35084 .48246 .36069 .48715 .35556 .45731 Mtetra
.482 .373 .654 r
.35556 .45731 .36069 .48715 .37071 .49013 .36545 .46157 Mtetra
.491 .385 .661 r
.36545 .46157 .37071 .49013 .38092 .4904 .37546 .46516 Mtetra
.508 .411 .681 r
.37546 .46516 .38092 .4904 .3913 .48801 .38561 .46745 Mtetra
.538 .459 .714 r
.38561 .46745 .3913 .48801 .40183 .48296 .3959 .46795 Mtetra
.573 .532 .771 r
.3959 .46795 .40183 .48296 .41244 .47621 .40631 .46686 Mtetra
.621 .654 .861 r
.40631 .46686 .41244 .47621 .42311 .46842 .41683 .4643 Mtetra
.643 .833 .973 r
.41683 .4643 .42311 .46842 .4338 .46037 .42743 .46077 Mtetra
.474 .895 .886 r
.42743 .46077 .4338 .46037 .44449 .45265 .43808 .45664 Mtetra
0 0 0 r
.43808 .45664 .44449 .45265 .45518 .44552 .44877 .45225 Mtetra
.094 0 0 r
.44877 .45225 .45518 .44552 .46587 .43925 .4595 .44787 Mtetra
.202 0 0 r
.4595 .44787 .46587 .43925 .47658 .43387 .47027 .44369 Mtetra
.263 0 .031 r
.47027 .44369 .47658 .43387 .4873 .42942 .48106 .43981 Mtetra
.297 0 .067 r
.48106 .43981 .4873 .42942 .49805 .4259 .4919 .43628 Mtetra
.314 0 .075 r
.4919 .43628 .49805 .4259 .50884 .42331 .50277 .4331 Mtetra
.315 0 .059 r
.50277 .4331 .50884 .42331 .51968 .42167 .51369 .43023 Mtetra
.293 0 .006 r
.51369 .43023 .51968 .42167 .53057 .42092 .52466 .42754 Mtetra
.227 0 0 r
.52466 .42754 .53057 .42092 .54153 .42104 .53568 .42489 Mtetra
.042 0 0 r
.53568 .42489 .54153 .42104 .55256 .42179 .54674 .42197 Mtetra
.391 .85 .864 r
.54674 .42197 .55256 .42179 .56367 .42287 .55785 .41844 Mtetra
.681 .844 .961 r
.55785 .41844 .56367 .42287 .57486 .4237 .56899 .41393 Mtetra
.708 .69 .83 r
.56899 .41393 .57486 .4237 .5861 .42351 .58015 .40792 Mtetra
.694 .598 .744 r
.58015 .40792 .5861 .42351 .59737 .42159 .5913 .40029 Mtetra
.685 .549 .694 r
.5913 .40029 .59737 .42159 .60863 .41696 .60242 .39081 Mtetra
.677 .521 .667 r
.60242 .39081 .60863 .41696 .61985 .40961 .61351 .38 Mtetra
.67 .504 .652 r
.61351 .38 .61985 .40961 .631 .39947 .62458 .36846 Mtetra
.664 .496 .648 r
.62458 .36846 .631 .39947 .64208 .38757 .63564 .35711 Mtetra
.653 .491 .651 r
.63564 .35711 .64208 .38757 .65313 .37522 .64675 .34715 Mtetra
.644 .492 .663 r
.64675 .34715 .65313 .37522 .66419 .36341 .65793 .33897 Mtetra
.629 .498 .684 r
.65793 .33897 .66419 .36341 .67533 .35348 .66924 .3332 Mtetra
.613 .512 .716 r
.66924 .3332 .67533 .35348 .68657 .34548 .68068 .32943 Mtetra
.593 .539 .763 r
.68068 .32943 .68657 .34548 .69794 .33962 .69225 .32728 Mtetra
.569 .578 .823 r
.69225 .32728 .69794 .33962 .70945 .33543 .70394 .32619 Mtetra
.544 .634 .89 r
.70394 .32619 .70945 .33543 .72107 .33245 .71573 .32547 Mtetra
.513 .69 .948 r
.71573 .32547 .72107 .33245 .7328 .33028 .72759 .32483 Mtetra
.498 .742 .982 r
.72759 .32483 .7328 .33028 .74461 .32843 .7395 .32382 Mtetra
.496 .777 .995 r
.7395 .32382 .74461 .32843 .7565 .32671 .75145 .3224 Mtetra
.523 .803 .997 r
.75145 .3224 .7565 .32671 .76844 .32481 .76343 .32038 Mtetra
.556 .815 .994 r
.76343 .32038 .76844 .32481 .78043 .32269 .77543 .31786 Mtetra
.593 .815 .985 r
.77543 .31786 .78043 .32269 .79245 .32023 .78745 .31486 Mtetra
.619 .806 .971 r
.78745 .31486 .79245 .32023 .80452 .31751 .7995 .31149 Mtetra
.637 .789 .955 r
.7995 .31149 .80452 .31751 .81662 .31458 .81158 .30787 Mtetra
.646 .769 .938 r
.81158 .30787 .81662 .31458 .82876 .31146 .82371 .3041 Mtetra
.628 .744 .931 r
.18006 .50842 .18679 .51429 .19644 .5109 .18965 .50584 Mtetra
.625 .774 .952 r
.18965 .50584 .19644 .5109 .20613 .50737 .19928 .5032 Mtetra
.625 .809 .971 r
.19928 .5032 .20613 .50737 .21589 .5036 .20896 .50038 Mtetra
.626 .847 .984 r
.20896 .50038 .21589 .5036 .2257 .49949 .21871 .49726 Mtetra
.628 .886 .988 r
.21871 .49726 .2257 .49949 .23558 .49491 .22854 .49373 Mtetra
.63 .92 .977 r
.22854 .49373 .23558 .49491 .24554 .48984 .23844 .48964 Mtetra
.636 .946 .952 r
.23844 .48964 .24554 .48984 .25556 .48421 .24844 .48487 Mtetra
.644 .961 .92 r
.24844 .48487 .25556 .48421 .26564 .47817 .25852 .47938 Mtetra
.669 .973 .895 r
.25852 .47938 .26564 .47817 .27577 .47177 .26868 .47311 Mtetra
.706 .983 .888 r
.26868 .47311 .27577 .47177 .28591 .46543 .27892 .46619 Mtetra
.763 .985 .902 r
.27892 .46619 .28591 .46543 .29605 .45945 .28921 .45867 Mtetra
.808 .951 .913 r
.28921 .45867 .29605 .45945 .30613 .45448 .29954 .45081 Mtetra
.808 .853 .882 r
.29954 .45081 .30613 .45448 .31615 .45109 .30989 .44279 Mtetra
.757 .716 .814 r
.30989 .44279 .31615 .45109 .32608 .44966 .32022 .43506 Mtetra
.694 .597 .743 r
.32022 .43506 .32608 .44966 .33593 .45057 .33054 .42801 Mtetra
.636 .506 .687 r
.33054 .42801 .33593 .45057 .34574 .45325 .34078 .42238 Mtetra
.591 .445 .651 r
.34078 .42238 .34574 .45325 .35556 .45731 .35094 .41876 Mtetra
.559 .403 .627 r
.35094 .41876 .35556 .45731 .36545 .46157 .36102 .41744 Mtetra
.532 .375 .613 r
.36102 .41744 .36545 .46157 .37546 .46516 .37104 .41865 Mtetra
.515 .359 .607 r
.37104 .41865 .37546 .46516 .38561 .46745 .38104 .42166 Mtetra
.502 .351 .608 r
.38104 .42166 .38561 .46745 .3959 .46795 .39107 .42595 Mtetra
.496 .353 .616 r
.39107 .42595 .3959 .46795 .40631 .46686 .40118 .43052 Mtetra
.495 .364 .632 r
.40118 .43052 .40631 .46686 .41683 .4643 .41139 .43463 Mtetra
.499 .387 .658 r
.41139 .43463 .41683 .4643 .42743 .46077 .42172 .43784 Mtetra
.51 .427 .698 r
.42172 .43784 .42743 .46077 .43808 .45664 .43218 .43978 Mtetra
.527 .486 .754 r
.43218 .43978 .43808 .45664 .44877 .45225 .44274 .44048 Mtetra
.552 .573 .829 r
.44274 .44048 .44877 .45225 .4595 .44787 .45339 .43995 Mtetra
.579 .679 .909 r
.45339 .43995 .4595 .44787 .47027 .44369 .46413 .43833 Mtetra
.605 .779 .964 r
.46413 .43833 .47027 .44369 .48106 .43981 .47494 .43572 Mtetra
.636 .839 .978 r
.47494 .43572 .48106 .43981 .4919 .43628 .48581 .43216 Mtetra
.682 .851 .964 r
.48581 .43216 .4919 .43628 .50277 .4331 .49673 .42767 Mtetra
.723 .812 .92 r
.49673 .42767 .50277 .4331 .51369 .43023 .50769 .42217 Mtetra
.736 .736 .851 r
.50769 .42217 .51369 .43023 .52466 .42754 .51869 .41557 Mtetra
.725 .655 .78 r
.51869 .41557 .52466 .42754 .53568 .42489 .52971 .4077 Mtetra
.705 .587 .722 r
.52971 .4077 .53568 .42489 .54674 .42197 .54074 .39858 Mtetra
.685 .537 .679 r
.54074 .39858 .54674 .42197 .55785 .41844 .55176 .38816 Mtetra
.667 .5 .65 r
.55176 .38816 .55785 .41844 .56899 .41393 .56277 .3768 Mtetra
.65 .472 .63 r
.56277 .3768 .56899 .41393 .58015 .40792 .57377 .36495 Mtetra
.635 .452 .618 r
.57377 .36495 .58015 .40792 .5913 .40029 .58475 .35335 Mtetra
.62 .436 .611 r
.58475 .35335 .5913 .40029 .60242 .39081 .59576 .34303 Mtetra
.607 .425 .61 r
.59576 .34303 .60242 .39081 .61351 .38 .60681 .33452 Mtetra
.591 .417 .615 r
.60681 .33452 .61351 .38 .62458 .36846 .61794 .32857 Mtetra
.578 .417 .627 r
.61794 .32857 .62458 .36846 .63564 .35711 .62919 .32497 Mtetra
.564 .426 .652 r
.62919 .32497 .63564 .35711 .64675 .34715 .64055 .32343 Mtetra
.548 .451 .696 r
.64055 .32343 .64675 .34715 .65793 .33897 .65204 .32335 Mtetra
.527 .505 .775 r
.65204 .32335 .65793 .33897 .66924 .3332 .66364 .32398 Mtetra
.471 .596 .896 r
.66364 .32398 .66924 .3332 .68068 .32943 .67533 .32493 Mtetra
.323 .686 .979 r
.67533 .32493 .68068 .32943 .69225 .32728 .68709 .32572 Mtetra
.112 .648 .858 r
.68709 .32572 .69225 .32728 .70394 .32619 .69892 .32617 Mtetra
.017 .591 .717 r
.69892 .32617 .70394 .32619 .71573 .32547 .7108 .32602 Mtetra
0 0 0 r
.7108 .32602 .71573 .32547 .72759 .32483 .72271 .3252 Mtetra
.126 .675 .738 r
.72271 .3252 .72759 .32483 .7395 .32382 .73464 .32357 Mtetra
.263 .771 .835 r
.73464 .32357 .7395 .32382 .75145 .3224 .74658 .32121 Mtetra
.417 .855 .93 r
.74658 .32121 .75145 .3224 .76343 .32038 .75853 .31813 Mtetra
.537 .889 .98 r
.75853 .31813 .76343 .32038 .77543 .31786 .7705 .31448 Mtetra
.613 .883 .99 r
.7705 .31448 .77543 .31786 .78745 .31486 .78249 .31038 Mtetra
.654 .857 .977 r
.78249 .31038 .78745 .31486 .7995 .31149 .79449 .30597 Mtetra
.673 .824 .956 r
.79449 .30597 .7995 .31149 .81158 .30787 .80653 .30136 Mtetra
.678 .79 .934 r
.80653 .30136 .81158 .30787 .82371 .3041 .81861 .29669 Mtetra
.594 .734 .942 r
.17328 .5025 .18006 .50842 .18965 .50584 .18282 .50057 Mtetra
.584 .756 .96 r
.18282 .50057 .18965 .50584 .19928 .5032 .19239 .49867 Mtetra
.573 .782 .978 r
.19239 .49867 .19928 .5032 .20896 .50038 .20202 .49672 Mtetra
.561 .813 .993 r
.20202 .49672 .20896 .50038 .21871 .49726 .21169 .49464 Mtetra
.539 .846 .999 r
.21169 .49464 .21871 .49726 .22854 .49373 .22143 .49236 Mtetra
.506 .875 .98 r
.22143 .49236 .22854 .49373 .23844 .48964 .23125 .48971 Mtetra
.454 .879 .918 r
.23125 .48971 .23844 .48964 .24844 .48487 .24115 .48654 Mtetra
.382 .843 .8 r
.24115 .48654 .24844 .48487 .25852 .47938 .25114 .48269 Mtetra
.313 .779 .658 r
.25114 .48269 .25852 .47938 .26868 .47311 .26123 .47799 Mtetra
0 0 0 r
.26123 .47799 .26868 .47311 .27892 .46619 .27143 .47237 Mtetra
.27143 .47237 .27892 .46619 .28921 .45867 .28172 .4657 Mtetra
.28172 .4657 .28921 .45867 .29954 .45081 .29211 .45803 Mtetra
.29211 .45803 .29954 .45081 .30989 .44279 .30257 .44935 Mtetra
.30257 .44935 .30989 .44279 .32022 .43506 .31309 .44005 Mtetra
.625 .925 .668 r
.31309 .44005 .32022 .43506 .33054 .42801 .32362 .43041 Mtetra
.765 .996 .827 r
.32362 .43041 .33054 .42801 .34078 .42238 .33413 .42126 Mtetra
.812 .946 .911 r
.33413 .42126 .34078 .42238 .35094 .41876 .34457 .41322 Mtetra
.755 .796 .886 r
.34457 .41322 .35094 .41876 .36102 .41744 .35494 .40685 Mtetra
.666 .643 .817 r
.35494 .40685 .36102 .41744 .37104 .41865 .36523 .40257 Mtetra
.603 .535 .75 r
.36523 .40257 .37104 .41865 .38104 .42166 .37546 .40008 Mtetra
.563 .466 .703 r
.37546 .40008 .38104 .42166 .39107 .42595 .38568 .39918 Mtetra
.545 .429 .671 r
.38568 .39918 .39107 .42595 .40118 .43052 .39591 .3992 Mtetra
.539 .408 .65 r
.39591 .3992 .40118 .43052 .41139 .43463 .40619 .39962 Mtetra
.54 .399 .638 r
.40619 .39962 .41139 .43463 .42172 .43784 .41654 .39998 Mtetra
.545 .396 .63 r
.41654 .39998 .42172 .43784 .43218 .43978 .42696 .39992 Mtetra
.55 .396 .625 r
.42696 .39992 .43218 .43978 .44274 .44048 .43747 .39928 Mtetra
.557 .398 .622 r
.43747 .39928 .44274 .44048 .45339 .43995 .44805 .39791 Mtetra
.563 .402 .62 r
.44805 .39791 .45339 .43995 .46413 .43833 .45871 .39581 Mtetra
.569 .405 .62 r
.45871 .39581 .46413 .43833 .47494 .43572 .46943 .39295 Mtetra
.576 .41 .619 r
.46943 .39295 .47494 .43572 .48581 .43216 .48021 .38934 Mtetra
.582 .414 .619 r
.48021 .38934 .48581 .43216 .49673 .42767 .49103 .38497 Mtetra
.588 .419 .62 r
.49103 .38497 .49673 .42767 .50769 .42217 .5019 .37984 Mtetra
.595 .424 .62 r
.5019 .37984 .50769 .42217 .51869 .41557 .51281 .37396 Mtetra
.601 .43 .622 r
.51281 .37396 .51869 .41557 .52971 .4077 .52375 .36735 Mtetra
.608 .437 .624 r
.52375 .36735 .52971 .4077 .54074 .39858 .5347 .36014 Mtetra
.615 .445 .629 r
.5347 .36014 .54074 .39858 .55176 .38816 .54568 .35249 Mtetra
.62 .454 .636 r
.54568 .35249 .55176 .38816 .56277 .3768 .55667 .34477 Mtetra
.625 .466 .647 r
.55667 .34477 .56277 .3768 .57377 .36495 .56768 .33744 Mtetra
.627 .482 .666 r
.56768 .33744 .57377 .36495 .58475 .35335 .57872 .33103 Mtetra
.622 .503 .697 r
.57872 .33103 .58475 .35335 .59576 .34303 .58983 .32623 Mtetra
.608 .537 .749 r
.58983 .32623 .59576 .34303 .60681 .33452 .60102 .32324 Mtetra
.558 .591 .842 r
.60102 .32324 .60681 .33452 .61794 .32857 .61232 .3224 Mtetra
.397 .658 .964 r
.61232 .3224 .61794 .32857 .62919 .32497 .62373 .32326 Mtetra
0 .52 .782 r
.62373 .32326 .62919 .32497 .64055 .32343 .63527 .32528 Mtetra
.363 0 0 r
.63527 .32528 .64055 .32343 .65204 .32335 .64692 .32782 Mtetra
.432 0 0 r
.64692 .32782 .65204 .32335 .66364 .32398 .65865 .33004 Mtetra
.435 0 0 r
.65865 .33004 .66364 .32398 .67533 .32493 .67045 .33163 Mtetra
.402 0 0 r
.67045 .33163 .67533 .32493 .68709 .32572 .68228 .3322 Mtetra
.349 0 0 r
.68228 .3322 .68709 .32572 .69892 .32617 .69414 .33174 Mtetra
.261 0 0 r
.69414 .33174 .69892 .32617 .7108 .32602 .70601 .33021 Mtetra
.126 0 0 r
.70601 .33021 .7108 .32602 .72271 .3252 .71789 .32773 Mtetra
0 0 0 r
.71789 .32773 .72271 .3252 .73464 .32357 .72978 .32436 Mtetra
.319 .804 .771 r
.72978 .32436 .73464 .32357 .74658 .32121 .74167 .32029 Mtetra
.521 .911 .925 r
.74167 .32029 .74658 .32121 .75853 .31813 .75357 .31568 Mtetra
.633 .923 .976 r
.75357 .31568 .75853 .31813 .7705 .31448 .76549 .31066 Mtetra
.681 .892 .974 r
.76549 .31066 .7705 .31448 .78249 .31038 .77744 .30543 Mtetra
.7 .855 .957 r
.77744 .30543 .78249 .31038 .79449 .30597 .78941 .30005 Mtetra
.704 .822 .938 r
.78941 .30005 .79449 .30597 .80653 .30136 .80142 .29462 Mtetra
.702 .793 .921 r
.80142 .29462 .80653 .30136 .81861 .29669 .81347 .28921 Mtetra
.577 .729 .946 r
.16646 .49655 .17328 .5025 .18282 .50057 .17598 .49489 Mtetra
.565 .736 .956 r
.17598 .49489 .18282 .50057 .19239 .49867 .18553 .49335 Mtetra
.551 .745 .967 r
.18553 .49335 .19239 .49867 .20202 .49672 .19512 .49192 Mtetra
.533 .76 .98 r
.19512 .49192 .20202 .49672 .21169 .49464 .20475 .49058 Mtetra
.501 .778 .994 r
.20475 .49058 .21169 .49464 .22143 .49236 .21442 .48933 Mtetra
.458 .802 .999 r
.21442 .48933 .22143 .49236 .23125 .48971 .22414 .48804 Mtetra
.382 .811 .966 r
.22414 .48804 .23125 .48971 .24115 .48654 .23392 .48659 Mtetra
.269 .774 .852 r
.23392 .48659 .24115 .48654 .25114 .48269 .24377 .48477 Mtetra
0 0 0 r
.24377 .48477 .25114 .48269 .26123 .47799 .25373 .48239 Mtetra
.25373 .48239 .26123 .47799 .27143 .47237 .26378 .47925 Mtetra
.076 0 0 r
.26378 .47925 .27143 .47237 .28172 .4657 .27395 .47515 Mtetra
.137 0 0 r
.27395 .47515 .28172 .4657 .29211 .45803 .28422 .47014 Mtetra
.18 0 .029 r
.28422 .47014 .29211 .45803 .30257 .44935 .29458 .46419 Mtetra
.221 0 .11 r
.29458 .46419 .30257 .44935 .31309 .44005 .30501 .4575 Mtetra
.254 0 .169 r
.30501 .4575 .31309 .44005 .32362 .43041 .31551 .45022 Mtetra
.272 0 .208 r
.31551 .45022 .32362 .43041 .33413 .42126 .32605 .44229 Mtetra
.272 0 .222 r
.32605 .44229 .33413 .42126 .34457 .41322 .33664 .43373 Mtetra
.24 0 .202 r
.33664 .43373 .34457 .41322 .35494 .40685 .34729 .42443 Mtetra
.15 0 .125 r
.34729 .42443 .35494 .40685 .36523 .40257 .35797 .41441 Mtetra
0 0 0 r
.35797 .41441 .36523 .40257 .37546 .40008 .36866 .40407 Mtetra
.715 .97 .728 r
.36866 .40407 .37546 .40008 .38568 .39918 .37936 .39374 Mtetra
.823 .807 .836 r
.37936 .39374 .38568 .39918 .39591 .3992 .39002 .38395 Mtetra
.715 .604 .732 r
.39002 .38395 .39591 .3992 .40619 .39962 .40065 .37507 Mtetra
.654 .509 .675 r
.40065 .37507 .40619 .39962 .41654 .39998 .41125 .36723 Mtetra
.618 .458 .643 r
.41125 .36723 .41654 .39998 .42696 .39992 .42183 .36049 Mtetra
.598 .43 .625 r
.42183 .36049 .42696 .39992 .43747 .39928 .4324 .35467 Mtetra
.585 .412 .614 r
.4324 .35467 .43747 .39928 .44805 .39791 .44297 .34962 Mtetra
.577 .401 .607 r
.44297 .34962 .44805 .39791 .45871 .39581 .45356 .34515 Mtetra
.572 .395 .603 r
.45356 .34515 .45871 .39581 .46943 .39295 .46418 .34111 Mtetra
.568 .391 .601 r
.46418 .34111 .46943 .39295 .48021 .38934 .47484 .33744 Mtetra
.566 .389 .601 r
.47484 .33744 .48021 .38934 .49103 .38497 .48553 .33412 Mtetra
.563 .388 .603 r
.48553 .33412 .49103 .38497 .5019 .37984 .49626 .33125 Mtetra
.56 .389 .607 r
.49626 .33125 .5019 .37984 .51281 .37396 .50704 .32895 Mtetra
.555 .391 .613 r
.50704 .32895 .51281 .37396 .52375 .36735 .51786 .32744 Mtetra
.548 .395 .625 r
.51786 .32744 .52375 .36735 .5347 .36014 .52875 .32686 Mtetra
.537 .403 .645 r
.52875 .32686 .5347 .36014 .54568 .35249 .53971 .32741 Mtetra
.518 .421 .685 r
.53971 .32741 .54568 .35249 .55667 .34477 .55075 .32901 Mtetra
.468 .467 .774 r
.55075 .32901 .55667 .34477 .56768 .33744 .56188 .33156 Mtetra
.19 .549 .93 r
.56188 .33156 .56768 .33744 .57872 .33103 .57311 .33468 Mtetra
.467 0 0 r
.57311 .33468 .57872 .33103 .58983 .32623 .58443 .33783 Mtetra
.525 .111 .197 r
.58443 .33783 .58983 .32623 .60102 .32324 .59585 .34068 Mtetra
.521 .155 .286 r
.59585 .34068 .60102 .32324 .61232 .3224 .60734 .34281 Mtetra
.512 .163 .312 r
.60734 .34281 .61232 .3224 .62373 .32326 .6189 .34421 Mtetra
.502 .156 .313 r
.6189 .34421 .62373 .32326 .63527 .32528 .63052 .34497 Mtetra
.488 .137 .297 r
.63052 .34497 .63527 .32528 .64692 .32782 .6422 .34509 Mtetra
.467 .103 .263 r
.6422 .34509 .64692 .32782 .65865 .33004 .65393 .34461 Mtetra
.434 .051 .211 r
.65393 .34461 .65865 .33004 .67045 .33163 .66571 .34338 Mtetra
.377 0 .131 r
.66571 .34338 .67045 .33163 .68228 .3322 .6775 .34118 Mtetra
.286 0 .01 r
.6775 .34118 .68228 .3322 .69414 .33174 .68931 .33804 Mtetra
.129 0 0 r
.68931 .33804 .69414 .33174 .70601 .33021 .70112 .3339 Mtetra
0 0 0 r
.70112 .3339 .70601 .33021 .71789 .32773 .71293 .32898 Mtetra
.405 .85 .757 r
.71293 .32898 .71789 .32773 .72978 .32436 .72475 .32347 Mtetra
.613 .95 .924 r
.72475 .32347 .72978 .32436 .74167 .32029 .73658 .31755 Mtetra
.699 .934 .964 r
.73658 .31755 .74167 .32029 .75357 .31568 .74843 .31147 Mtetra
.725 .89 .956 r
.74843 .31147 .75357 .31568 .76549 .31066 .76032 .30533 Mtetra
.726 .849 .94 r
.76032 .30533 .76549 .31066 .77744 .30543 .77225 .29927 Mtetra
.722 .819 .926 r
.77225 .29927 .77744 .30543 .78941 .30005 .78422 .2933 Mtetra
.717 .799 .915 r
.78422 .2933 .78941 .30005 .80142 .29462 .79623 .28743 Mtetra
.711 .783 .908 r
.79623 .28743 .80142 .29462 .81347 .28921 .8083 .28168 Mtetra
.598 .735 .941 r
.15958 .49055 .16646 .49655 .17598 .49489 .16916 .4885 Mtetra
.592 .721 .933 r
.16916 .4885 .17598 .49489 .18553 .49335 .17877 .4866 Mtetra
.584 .706 .927 r
.17877 .4866 .18553 .49335 .19512 .49192 .1884 .48488 Mtetra
.573 .694 .923 r
.1884 .48488 .19512 .49192 .20475 .49058 .19805 .48341 Mtetra
.557 .684 .924 r
.19805 .48341 .20475 .49058 .21442 .48933 .20772 .48225 Mtetra
.542 .682 .93 r
.20772 .48225 .21442 .48933 .22414 .48804 .21742 .48133 Mtetra
.522 .688 .943 r
.21742 .48133 .22414 .48804 .23392 .48659 .22715 .48064 Mtetra
.503 .708 .963 r
.22715 .48064 .23392 .48659 .24377 .48477 .23692 .48 Mtetra
.473 .742 .987 r
.23692 .48 .24377 .48477 .25373 .48239 .24675 .47931 Mtetra
.416 .784 .994 r
.24675 .47931 .25373 .48239 .26378 .47925 .25666 .47835 Mtetra
.297 .781 .91 r
.25666 .47835 .26378 .47925 .27395 .47515 .26665 .47696 Mtetra
0 0 0 r
.26665 .47696 .27395 .47515 .28422 .47014 .27674 .47502 Mtetra
.093 0 0 r
.27674 .47502 .28422 .47014 .29458 .46419 .28692 .47241 Mtetra
.205 0 0 r
.28692 .47241 .29458 .46419 .30501 .4575 .2972 .46905 Mtetra
.26 0 .057 r
.2972 .46905 .30501 .4575 .31551 .45022 .30757 .46483 Mtetra
.277 0 .133 r
.30757 .46483 .31551 .45022 .32605 .44229 .31805 .45952 Mtetra
.275 0 .173 r
.31805 .45952 .32605 .44229 .33664 .43373 .32864 .45292 Mtetra
.263 0 .193 r
.32864 .45292 .33664 .43373 .34729 .42443 .33931 .44503 Mtetra
.245 0 .202 r
.33931 .44503 .34729 .42443 .35797 .41441 .35007 .43591 Mtetra
.239 0 .209 r
.35007 .43591 .35797 .41441 .36866 .40407 .36086 .4261 Mtetra
.241 0 .216 r
.36086 .4261 .36866 .40407 .37936 .39374 .37167 .41603 Mtetra
.256 0 .226 r
.37167 .41603 .37936 .39374 .39002 .38395 .38247 .40624 Mtetra
.278 0 .237 r
.38247 .40624 .39002 .38395 .40065 .37507 .39323 .39714 Mtetra
.301 0 .246 r
.39323 .39714 .40065 .37507 .41125 .36723 .40397 .38889 Mtetra
.325 .002 .253 r
.40397 .38889 .41125 .36723 .42183 .36049 .41469 .38162 Mtetra
.344 .016 .257 r
.41469 .38162 .42183 .36049 .4324 .35467 .4254 .37521 Mtetra
.361 .028 .259 r
.4254 .37521 .4324 .35467 .44297 .34962 .43611 .36961 Mtetra
.375 .037 .259 r
.43611 .36961 .44297 .34962 .45356 .34515 .44683 .36472 Mtetra
.388 .047 .261 r
.44683 .36472 .45356 .34515 .46418 .34111 .45757 .36045 Mtetra
.402 .058 .264 r
.45757 .36045 .46418 .34111 .47484 .33744 .46833 .35677 Mtetra
.416 .071 .27 r
.46833 .35677 .47484 .33744 .48553 .33412 .47914 .35367 Mtetra
.433 .087 .278 r
.47914 .35367 .48553 .33412 .49626 .33125 .48998 .35121 Mtetra
.45 .106 .289 r
.48998 .35121 .49626 .33125 .50704 .32895 .50087 .34946 Mtetra
.469 .126 .301 r
.50087 .34946 .50704 .32895 .51786 .32744 .51181 .34853 Mtetra
.488 .145 .312 r
.51181 .34853 .51786 .32744 .52875 .32686 .52282 .34849 Mtetra
.506 .164 .322 r
.52282 .34849 .52875 .32686 .53971 .32741 .53389 .34944 Mtetra
.52 .179 .329 r
.53389 .34944 .53971 .32741 .55075 .32901 .54506 .35126 Mtetra
.531 .19 .334 r
.54506 .35126 .55075 .32901 .56188 .33156 .55631 .35381 Mtetra
.536 .193 .334 r
.55631 .35381 .56188 .33156 .57311 .33468 .56766 .35667 Mtetra
.531 .187 .33 r
.56766 .35667 .57311 .33468 .58443 .33783 .5791 .35928 Mtetra
.52 .174 .321 r
.5791 .35928 .58443 .33783 .59585 .34068 .59061 .36121 Mtetra
.498 .149 .305 r
.59061 .36121 .59585 .34068 .60734 .34281 .60219 .36189 Mtetra
.469 .115 .281 r
.60219 .36189 .60734 .34281 .6189 .34421 .61381 .36127 Mtetra
.431 .067 .244 r
.61381 .36127 .6189 .34421 .63052 .34497 .62546 .35935 Mtetra
.378 0 .183 r
.62546 .35935 .63052 .34497 .6422 .34509 .63713 .3563 Mtetra
.299 0 .08 r
.63713 .3563 .6422 .34509 .65393 .34461 .64883 .35237 Mtetra
.154 0 0 r
.64883 .35237 .65393 .34461 .66571 .34338 .66054 .34766 Mtetra
0 0 0 r
.66054 .34766 .66571 .34338 .6775 .34118 .67226 .34225 Mtetra
.476 .892 .796 r
.67226 .34225 .6775 .34118 .68931 .33804 .68399 .33628 Mtetra
.693 .957 .949 r
.68399 .33628 .68931 .33804 .70112 .3339 .69574 .32983 Mtetra
.748 .896 .945 r
.69574 .32983 .70112 .3339 .71293 .32898 .70749 .32311 Mtetra
.75 .833 .915 r
.70749 .32311 .71293 .32898 .72475 .32347 .71928 .3163 Mtetra
.741 .789 .892 r
.71928 .3163 .72475 .32347 .73658 .31755 .73109 .30955 Mtetra
.729 .762 .879 r
.73109 .30955 .73658 .31755 .74843 .31147 .74295 .30302 Mtetra
.72 .747 .873 r
.74295 .30302 .74843 .31147 .76032 .30533 .75486 .29673 Mtetra
.71 .74 .875 r
.75486 .29673 .76032 .30533 .77225 .29927 .76683 .29076 Mtetra
.704 .741 .88 r
.76683 .29076 .77225 .29927 .78422 .2933 .77886 .28503 Mtetra
.7 .747 .888 r
.77886 .28503 .78422 .2933 .79623 .28743 .79094 .27948 Mtetra
.697 .756 .898 r
.79094 .27948 .79623 .28743 .8083 .28168 .80308 .27409 Mtetra
.641 .748 .926 r
.15266 .48451 .15958 .49055 .16916 .4885 .16236 .48157 Mtetra
.636 .718 .907 r
.16236 .48157 .16916 .4885 .17877 .4866 .17208 .47874 Mtetra
.628 .689 .888 r
.17208 .47874 .17877 .4866 .1884 .48488 .18181 .47612 Mtetra
.615 .66 .871 r
.18181 .47612 .1884 .48488 .19805 .48341 .19156 .47379 Mtetra
.6 .634 .857 r
.19156 .47379 .19805 .48341 .20772 .48225 .20131 .47186 Mtetra
.584 .61 .845 r
.20131 .47186 .20772 .48225 .21742 .48133 .21106 .47036 Mtetra
.565 .59 .837 r
.21106 .47036 .21742 .48133 .22715 .48064 .22081 .46937 Mtetra
.548 .577 .835 r
.22081 .46937 .22715 .48064 .23692 .48 .23058 .46884 Mtetra
.529 .57 .841 r
.23058 .46884 .23692 .48 .24675 .47931 .24036 .46877 Mtetra
.511 .575 .857 r
.24036 .46877 .24675 .47931 .25666 .47835 .25017 .46902 Mtetra
.487 .595 .887 r
.25017 .46902 .25666 .47835 .26665 .47696 .26002 .46949 Mtetra
.459 .639 .934 r
.26002 .46949 .26665 .47696 .27674 .47502 .26994 .4699 Mtetra
.408 .704 .983 r
.26994 .4699 .27674 .47502 .28692 .47241 .27994 .47001 Mtetra
.311 .755 .963 r
.27994 .47001 .28692 .47241 .2972 .46905 .29005 .46947 Mtetra
.167 .706 .777 r
.29005 .46947 .2972 .46905 .30757 .46483 .30029 .46798 Mtetra
0 0 0 r
.30029 .46798 .30757 .46483 .31805 .45952 .31063 .46559 Mtetra
.107 0 0 r
.31063 .46559 .31805 .45952 .32864 .45292 .32107 .46232 Mtetra
.23 0 0 r
.32107 .46232 .32864 .45292 .33931 .44503 .33158 .45868 Mtetra
.329 0 .139 r
.33158 .45868 .33931 .44503 .35007 .43591 .34213 .45503 Mtetra
.398 .049 .252 r
.34213 .45503 .35007 .43591 .36086 .4261 .35271 .45159 Mtetra
.441 .12 .323 r
.35271 .45159 .36086 .4261 .37167 .41603 .36331 .44851 Mtetra
.464 .161 .367 r
.36331 .44851 .37167 .41603 .38247 .40624 .37396 .44554 Mtetra
.476 .186 .393 r
.37396 .44554 .38247 .40624 .39323 .39714 .38465 .44255 Mtetra
.481 .2 .41 r
.38465 .44255 .39323 .39714 .40397 .38889 .39539 .43936 Mtetra
.484 .209 .42 r
.39539 .43936 .40397 .38889 .41469 .38162 .40619 .43589 Mtetra
.486 .214 .426 r
.40619 .43589 .41469 .38162 .4254 .37521 .41704 .43219 Mtetra
.487 .217 .43 r
.41704 .43219 .4254 .37521 .43611 .36961 .42793 .42833 Mtetra
.488 .22 .433 r
.42793 .42833 .43611 .36961 .44683 .36472 .43887 .42447 Mtetra
.489 .222 .435 r
.43887 .42447 .44683 .36472 .45757 .36045 .44985 .42067 Mtetra
.491 .223 .436 r
.44985 .42067 .45757 .36045 .46833 .35677 .46087 .41702 Mtetra
.492 .224 .436 r
.46087 .41702 .46833 .35677 .47914 .35367 .47194 .41351 Mtetra
.492 .224 .435 r
.47194 .41351 .47914 .35367 .48998 .35121 .48305 .41008 Mtetra
.492 .223 .434 r
.48305 .41008 .48998 .35121 .50087 .34946 .4942 .40664 Mtetra
.489 .219 .431 r
.4942 .40664 .50087 .34946 .51181 .34853 .5054 .40303 Mtetra
.486 .214 .426 r
.5054 .40303 .51181 .34853 .52282 .34849 .51665 .39921 Mtetra
.48 .205 .419 r
.51665 .39921 .52282 .34849 .53389 .34944 .52795 .39509 Mtetra
.472 .193 .407 r
.52795 .39509 .53389 .34944 .54506 .35126 .53929 .39076 Mtetra
.463 .175 .39 r
.53929 .39076 .54506 .35126 .55631 .35381 .55067 .38641 Mtetra
.449 .149 .362 r
.55067 .38641 .55631 .35381 .56766 .35667 .5621 .38217 Mtetra
.432 .111 .32 r
.5621 .38217 .56766 .35667 .5791 .35928 .57357 .3783 Mtetra
.4 .051 .253 r
.57357 .3783 .5791 .35928 .59061 .36121 .5851 .37464 Mtetra
.341 0 .145 r
.5851 .37464 .59061 .36121 .60219 .36189 .59668 .37096 Mtetra
.23 0 0 r
.59668 .37096 .60219 .36189 .61381 .36127 .60829 .36692 Mtetra
.007 0 0 r
.60829 .36692 .61381 .36127 .62546 .35935 .61993 .36195 Mtetra
.338 .792 .652 r
.61993 .36195 .62546 .35935 .63713 .3563 .63158 .35606 Mtetra
.654 .968 .9 r
.63158 .35606 .63713 .3563 .64883 .35237 .64322 .34919 Mtetra
.773 .927 .936 r
.64322 .34919 .64883 .35237 .66054 .34766 .65487 .34163 Mtetra
.778 .83 .892 r
.65487 .34163 .66054 .34766 .67226 .34225 .66652 .33374 Mtetra
.759 .754 .848 r
.66652 .33374 .67226 .34225 .68399 .33628 .67819 .32577 Mtetra
.736 .702 .819 r
.67819 .32577 .68399 .33628 .69574 .32983 .68989 .31801 Mtetra
.718 .671 .803 r
.68989 .31801 .69574 .32983 .70749 .32311 .70163 .31058 Mtetra
.703 .653 .796 r
.70163 .31058 .70749 .32311 .71928 .3163 .71343 .30361 Mtetra
.693 .646 .798 r
.71343 .30361 .71928 .3163 .73109 .30955 .72528 .2971 Mtetra
.684 .646 .806 r
.72528 .2971 .73109 .30955 .74295 .30302 .7372 .29111 Mtetra
.678 .653 .818 r
.7372 .29111 .74295 .30302 .75486 .29673 .74919 .28556 Mtetra
.673 .665 .834 r
.74919 .28556 .75486 .29673 .76683 .29076 .76125 .28042 Mtetra
.67 .682 .853 r
.76125 .28042 .76683 .29076 .77886 .28503 .77338 .27558 Mtetra
.668 .703 .874 r
.77338 .27558 .77886 .28503 .79094 .27948 .78557 .27095 Mtetra
.667 .729 .896 r
.78557 .27095 .79094 .27948 .80308 .27409 .79782 .26643 Mtetra
.684 .758 .907 r
.14569 .47843 .15266 .48451 .16236 .48157 .15553 .47437 Mtetra
.678 .723 .883 r
.15553 .47437 .16236 .48157 .17208 .47874 .16539 .47037 Mtetra
.668 .689 .861 r
.16539 .47037 .17208 .47874 .18181 .47612 .17527 .46651 Mtetra
.655 .657 .84 r
.17527 .46651 .18181 .47612 .19156 .47379 .18516 .46289 Mtetra
.639 .625 .82 r
.18516 .46289 .19156 .47379 .20131 .47186 .19504 .45961 Mtetra
.622 .594 .801 r
.19504 .45961 .20131 .47186 .21106 .47036 .20493 .45676 Mtetra
.604 .565 .784 r
.20493 .45676 .21106 .47036 .22081 .46937 .2148 .45443 Mtetra
.586 .539 .768 r
.2148 .45443 .22081 .46937 .23058 .46884 .22467 .45266 Mtetra
.569 .515 .755 r
.22467 .45266 .23058 .46884 .24036 .46877 .23452 .45152 Mtetra
.554 .496 .745 r
.23452 .45152 .24036 .46877 .25017 .46902 .24439 .45093 Mtetra
.541 .48 .737 r
.24439 .45093 .25017 .46902 .26002 .46949 .25426 .45087 Mtetra
.533 .471 .732 r
.25426 .45087 .26002 .46949 .26994 .4699 .26417 .45111 Mtetra
.53 .468 .731 r
.26417 .45111 .26994 .4699 .27994 .47001 .27413 .4515 Mtetra
.532 .473 .735 r
.27413 .4515 .27994 .47001 .29005 .46947 .28415 .45179 Mtetra
.539 .485 .744 r
.28415 .45179 .29005 .46947 .30029 .46798 .29426 .4518 Mtetra
.542 .504 .762 r
.29426 .4518 .30029 .46798 .31063 .46559 .30445 .45162 Mtetra
.544 .534 .794 r
.30445 .45162 .31063 .46559 .32107 .46232 .31471 .45129 Mtetra
.533 .582 .849 r
.31471 .45129 .32107 .46232 .33158 .45868 .32502 .45102 Mtetra
.49 .653 .931 r
.32502 .45102 .33158 .45868 .34213 .45503 .33538 .45093 Mtetra
.368 .729 .989 r
.33538 .45093 .34213 .45503 .35271 .45159 .34581 .45086 Mtetra
.099 .651 .808 r
.34581 .45086 .35271 .45159 .36331 .44851 .35631 .45066 Mtetra
.113 0 0 r
.35631 .45066 .36331 .44851 .37396 .44554 .36689 .45004 Mtetra
.204 0 0 r
.36689 .45004 .37396 .44554 .38465 .44255 .37756 .4488 Mtetra
.234 0 0 r
.37756 .4488 .38465 .44255 .39539 .43936 .38831 .44691 Mtetra
.24 0 0 r
.38831 .44691 .39539 .43936 .40619 .43589 .39915 .44438 Mtetra
.244 0 0 r
.39915 .44438 .40619 .43589 .41704 .43219 .41005 .44137 Mtetra
.246 0 0 r
.41005 .44137 .41704 .43219 .42793 .42833 .42101 .438 Mtetra
.251 0 0 r
.42101 .438 .42793 .42833 .43887 .42447 .43202 .43445 Mtetra
.256 0 .007 r
.43202 .43445 .43887 .42447 .44985 .42067 .44309 .43081 Mtetra
.261 0 .014 r
.44309 .43081 .44985 .42067 .46087 .41702 .45419 .42715 Mtetra
.26 0 .014 r
.45419 .42715 .46087 .41702 .47194 .41351 .46534 .42346 Mtetra
.252 0 .005 r
.46534 .42346 .47194 .41351 .48305 .41008 .47654 .41969 Mtetra
.233 0 0 r
.47654 .41969 .48305 .41008 .4942 .40664 .48779 .41573 Mtetra
.197 0 0 r
.48779 .41573 .4942 .40664 .5054 .40303 .49908 .4114 Mtetra
.14 0 0 r
.49908 .4114 .5054 .40303 .51665 .39921 .51042 .4066 Mtetra
.048 0 0 r
.51042 .4066 .51665 .39921 .52795 .39509 .5218 .40113 Mtetra
0 0 0 r
.5218 .40113 .52795 .39509 .53929 .39076 .53321 .395 Mtetra
.53321 .395 .53929 .39076 .55067 .38641 .54465 .38823 Mtetra
.559 .928 .787 r
.54465 .38823 .55067 .38641 .5621 .38217 .55611 .38102 Mtetra
.736 .971 .93 r
.55611 .38102 .5621 .38217 .57357 .3783 .56759 .37368 Mtetra
.773 .869 .919 r
.56759 .37368 .57357 .3783 .5851 .37464 .5791 .36632 Mtetra
.743 .749 .857 r
.5791 .36632 .5851 .37464 .59668 .37096 .59063 .35914 Mtetra
.712 .665 .801 r
.59063 .35914 .59668 .37096 .60829 .36692 .60219 .35202 Mtetra
.693 .612 .761 r
.60219 .35202 .60829 .36692 .61993 .36195 .61377 .34472 Mtetra
.681 .581 .737 r
.61377 .34472 .61993 .36195 .63158 .35606 .62537 .33722 Mtetra
.676 .565 .722 r
.62537 .33722 .63158 .35606 .64322 .34919 .63697 .32941 Mtetra
.672 .556 .714 r
.63697 .32941 .64322 .34919 .65487 .34163 .6486 .32149 Mtetra
.669 .551 .712 r
.6486 .32149 .65487 .34163 .66652 .33374 .66025 .31369 Mtetra
.665 .55 .714 r
.66025 .31369 .66652 .33374 .67819 .32577 .67193 .3062 Mtetra
.66 .55 .72 r
.67193 .3062 .67819 .32577 .68989 .31801 .68367 .29924 Mtetra
.655 .554 .729 r
.68367 .29924 .68989 .31801 .70163 .31058 .69547 .29284 Mtetra
.65 .561 .741 r
.69547 .29284 .70163 .31058 .71343 .30361 .70733 .28709 Mtetra
.646 .571 .757 r
.70733 .28709 .71343 .30361 .72528 .2971 .71927 .2819 Mtetra
.641 .585 .775 r
.71927 .2819 .72528 .2971 .7372 .29111 .73129 .27726 Mtetra
.638 .602 .797 r
.73129 .27726 .7372 .29111 .74919 .28556 .74339 .27305 Mtetra
.635 .623 .821 r
.74339 .27305 .74919 .28556 .76125 .28042 .75556 .2692 Mtetra
.632 .647 .846 r
.75556 .2692 .76125 .28042 .77338 .27558 .76782 .26559 Mtetra
.63 .674 .873 r
.76782 .26559 .77338 .27558 .78557 .27095 .78014 .26213 Mtetra
.629 .705 .901 r
.78014 .26213 .78557 .27095 .79782 .26643 .79252 .25872 Mtetra
.717 .763 .889 r
.13868 .4723 .14569 .47843 .15553 .47437 .14865 .46722 Mtetra
.711 .733 .869 r
.14865 .46722 .15553 .47437 .16539 .47037 .15865 .46211 Mtetra
.702 .703 .848 r
.15865 .46211 .16539 .47037 .17527 .46651 .16867 .45705 Mtetra
.69 .673 .829 r
.16867 .45705 .17527 .46651 .18516 .46289 .17871 .4521 Mtetra
.677 .643 .809 r
.17871 .4521 .18516 .46289 .19504 .45961 .18876 .44733 Mtetra
.662 .613 .789 r
.18876 .44733 .19504 .45961 .20493 .45676 .19881 .44283 Mtetra
.645 .582 .77 r
.19881 .44283 .20493 .45676 .2148 .45443 .20885 .4387 Mtetra
.628 .553 .751 r
.20885 .4387 .2148 .45443 .22467 .45266 .21889 .43499 Mtetra
.611 .525 .733 r
.21889 .43499 .22467 .45266 .23452 .45152 .22891 .4318 Mtetra
.595 .499 .716 r
.22891 .4318 .23452 .45152 .24439 .45093 .23893 .42911 Mtetra
.581 .477 .7 r
.23893 .42911 .24439 .45093 .25426 .45087 .24895 .42696 Mtetra
.569 .457 .687 r
.24895 .42696 .25426 .45087 .26417 .45111 .25897 .42532 Mtetra
.558 .441 .676 r
.25897 .42532 .26417 .45111 .27413 .4515 .269 .4242 Mtetra
.548 .428 .668 r
.269 .4242 .27413 .4515 .28415 .45179 .27905 .42364 Mtetra
.538 .418 .664 r
.27905 .42364 .28415 .45179 .29426 .4518 .2891 .42371 Mtetra
.529 .412 .664 r
.2891 .42371 .29426 .4518 .30445 .45162 .29918 .42434 Mtetra
.52 .41 .669 r
.29918 .42434 .30445 .45162 .31471 .45129 .30929 .42547 Mtetra
.518 .416 .678 r
.30929 .42547 .31471 .45129 .32502 .45102 .31946 .42664 Mtetra
.523 .427 .688 r
.31946 .42664 .32502 .45102 .33538 .45093 .32973 .42748 Mtetra
.538 .443 .695 r
.32973 .42748 .33538 .45093 .34581 .45086 .34011 .42756 Mtetra
.557 .457 .696 r
.34011 .42756 .34581 .45086 .35631 .45066 .35062 .42657 Mtetra
.573 .462 .69 r
.35062 .42657 .35631 .45066 .36689 .45004 .36123 .42465 Mtetra
.584 .463 .681 r
.36123 .42465 .36689 .45004 .37756 .4488 .37193 .42186 Mtetra
.588 .46 .673 r
.37193 .42186 .37756 .4488 .38831 .44691 .3827 .41857 Mtetra
.589 .455 .666 r
.3827 .41857 .38831 .44691 .39915 .44438 .39353 .41498 Mtetra
.589 .451 .661 r
.39353 .41498 .39915 .44438 .41005 .44137 .40441 .41127 Mtetra
.588 .448 .658 r
.40441 .41127 .41005 .44137 .42101 .438 .41533 .40755 Mtetra
.587 .446 .657 r
.41533 .40755 .42101 .438 .43202 .43445 .4263 .40383 Mtetra
.587 .446 .656 r
.4263 .40383 .43202 .43445 .44309 .43081 .43731 .40012 Mtetra
.587 .445 .656 r
.43731 .40012 .44309 .43081 .45419 .42715 .44836 .39641 Mtetra
.586 .445 .656 r
.44836 .39641 .45419 .42715 .46534 .42346 .45946 .39269 Mtetra
.45946 .39269 .46534 .42346 .47654 .41969 .47061 .38899 Mtetra
.586 .446 .657 r
.47061 .38899 .47654 .41969 .48779 .41573 .4818 .38528 Mtetra
.587 .447 .658 r
.4818 .38528 .48779 .41573 .49908 .4114 .49303 .38157 Mtetra
.589 .451 .661 r
.49303 .38157 .49908 .4114 .51042 .4066 .50432 .37773 Mtetra
.594 .458 .665 r
.50432 .37773 .51042 .4066 .5218 .40113 .51565 .37359 Mtetra
.603 .469 .671 r
.51565 .37359 .5218 .40113 .53321 .395 .52702 .36894 Mtetra
.618 .485 .678 r
.52702 .36894 .53321 .395 .54465 .38823 .53844 .3634 Mtetra
.633 .501 .683 r
.53844 .3634 .54465 .38823 .55611 .38102 .54988 .35691 Mtetra
.649 .514 .686 r
.54988 .35691 .55611 .38102 .56759 .37368 .56133 .34932 Mtetra
.657 .518 .683 r
.56133 .34932 .56759 .37368 .5791 .36632 .5728 .34094 Mtetra
.657 .513 .676 r
.5728 .34094 .5791 .36632 .59063 .35914 .58427 .33221 Mtetra
.651 .503 .669 r
.58427 .33221 .59063 .35914 .60219 .35202 .59576 .32349 Mtetra
.64 .49 .663 r
.59576 .32349 .60219 .35202 .61377 .34472 .60728 .31527 Mtetra
.631 .48 .659 r
.60728 .31527 .61377 .34472 .62537 .33722 .61883 .30762 Mtetra
.624 .475 .66 r
.61883 .30762 .62537 .33722 .63697 .32941 .63042 .30058 Mtetra
.62 .475 .664 r
.63042 .30058 .63697 .32941 .6486 .32149 .64206 .29413 Mtetra
.618 .48 .672 r
.64206 .29413 .6486 .32149 .66025 .31369 .65375 .28819 Mtetra
.616 .488 .683 r
.65375 .28819 .66025 .31369 .67193 .3062 .6655 .28278 Mtetra
.615 .498 .697 r
.6655 .28278 .67193 .3062 .68367 .29924 .67732 .27791 Mtetra
.613 .51 .713 r
.67732 .27791 .68367 .29924 .69547 .29284 .68921 .27356 Mtetra
.611 .525 .733 r
.68921 .27356 .69547 .29284 .70733 .28709 .70118 .26974 Mtetra
.608 .542 .754 r
.70118 .26974 .70733 .28709 .71927 .2819 .71323 .26636 Mtetra
.605 .561 .778 r
.71323 .26636 .71927 .2819 .73129 .27726 .72536 .26335 Mtetra
.602 .583 .804 r
.72536 .26335 .73129 .27726 .74339 .27305 .73757 .26064 Mtetra
.6 .607 .831 r
.73757 .26064 .74339 .27305 .75556 .2692 .74987 .25811 Mtetra
.597 .633 .858 r
.74987 .25811 .75556 .2692 .76782 .26559 .76223 .2557 Mtetra
.594 .66 .884 r
.76223 .2557 .76782 .26559 .78014 .26213 .77467 .25334 Mtetra
.591 .69 .91 r
.77467 .25334 .78014 .26213 .79252 .25872 .78718 .25095 Mtetra
.73 .765 .881 r
.13161 .46613 .13868 .4723 .14865 .46722 .14166 .46055 Mtetra
.729 .751 .87 r
.14166 .46055 .14865 .46722 .15865 .46211 .15175 .45488 Mtetra
.725 .736 .859 r
.15175 .45488 .15865 .46211 .16867 .45705 .16187 .44914 Mtetra
.721 .718 .847 r
.16187 .44914 .16867 .45705 .17871 .4521 .17201 .44338 Mtetra
.714 .698 .833 r
.17201 .44338 .17871 .4521 .18876 .44733 .18218 .4376 Mtetra
.705 .675 .818 r
.18218 .4376 .18876 .44733 .19881 .44283 .19236 .43189 Mtetra
.693 .649 .801 r
.19236 .43189 .19881 .44283 .20885 .4387 .20256 .42632 Mtetra
.678 .62 .783 r
.20256 .42632 .20885 .4387 .21889 .43499 .21275 .42096 Mtetra
.662 .591 .765 r
.21275 .42096 .21889 .43499 .22891 .4318 .22295 .41591 Mtetra
.645 .562 .746 r
.22295 .41591 .22891 .4318 .23893 .42911 .23314 .41122 Mtetra
.628 .534 .728 r
.23314 .41122 .23893 .42911 .24895 .42696 .24332 .40698 Mtetra
.612 .508 .712 r
.24332 .40698 .24895 .42696 .25897 .42532 .2535 .40327 Mtetra
.596 .485 .697 r
.2535 .40327 .25897 .42532 .269 .4242 .26366 .40015 Mtetra
.581 .465 .685 r
.26366 .40015 .269 .4242 .27905 .42364 .27381 .39768 Mtetra
.567 .446 .675 r
.27381 .39768 .27905 .42364 .2891 .42371 .28396 .39591 Mtetra
.557 .432 .665 r
.28396 .39591 .2891 .42371 .29918 .42434 .29412 .39464 Mtetra
.551 .421 .656 r
.29412 .39464 .29918 .42434 .30929 .42547 .30431 .39373 Mtetra
.551 .414 .648 r
.30431 .39373 .30929 .42547 .31946 .42664 .31456 .39273 Mtetra
.554 .411 .64 r
.31456 .39273 .31946 .42664 .32973 .42748 .32489 .39133 Mtetra
.559 .408 .633 r
.32489 .39133 .32973 .42748 .34011 .42756 .33531 .38941 Mtetra
.564 .407 .627 r
.33531 .38941 .34011 .42756 .35062 .42657 .34582 .38688 Mtetra
.566 .406 .624 r
.34582 .38688 .35062 .42657 .36123 .42465 .35639 .38399 Mtetra
.567 .405 .621 r
.35639 .38399 .36123 .42465 .37193 .42186 .36703 .38091 Mtetra
.36703 .38091 .37193 .42186 .3827 .41857 .3777 .37779 Mtetra
.3777 .37779 .3827 .41857 .39353 .41498 .38842 .37472 Mtetra
.567 .406 .623 r
.38842 .37472 .39353 .41498 .40441 .41127 .39919 .37167 Mtetra
.568 .408 .625 r
.39919 .37167 .40441 .41127 .41533 .40755 .41001 .36858 Mtetra
.57 .411 .627 r
.41001 .36858 .41533 .40755 .4263 .40383 .42088 .36532 Mtetra
.573 .414 .628 r
.42088 .36532 .4263 .40383 .43731 .40012 .4318 .36184 Mtetra
.576 .417 .629 r
.4318 .36184 .43731 .40012 .44836 .39641 .44278 .35808 Mtetra
.578 .419 .629 r
.44278 .35808 .44836 .39641 .45946 .39269 .4538 .35402 Mtetra
.58 .419 .628 r
.4538 .35402 .45946 .39269 .47061 .38899 .46488 .34974 Mtetra
.581 .419 .627 r
.46488 .34974 .47061 .38899 .4818 .38528 .476 .34529 Mtetra
.58 .417 .625 r
.476 .34529 .4818 .38528 .49303 .38157 .48716 .3408 Mtetra
.579 .415 .623 r
.48716 .3408 .49303 .38157 .50432 .37773 .49836 .33631 Mtetra
.578 .413 .621 r
.49836 .33631 .50432 .37773 .51565 .37359 .5096 .33188 Mtetra
.578 .412 .621 r
.5096 .33188 .51565 .37359 .52702 .36894 .52088 .32742 Mtetra
.58 .414 .621 r
.52088 .32742 .52702 .36894 .53844 .3634 .53221 .32274 Mtetra
.584 .419 .623 r
.53221 .32274 .53844 .3634 .54988 .35691 .54357 .31771 Mtetra
.591 .427 .627 r
.54357 .31771 .54988 .35691 .56133 .34932 .55497 .31205 Mtetra
.599 .436 .632 r
.55497 .31205 .56133 .34932 .5728 .34094 .56639 .30584 Mtetra
.607 .447 .639 r
.56639 .30584 .5728 .34094 .58427 .33221 .57784 .29922 Mtetra
.612 .456 .646 r
.57784 .29922 .58427 .33221 .59576 .32349 .58932 .2925 Mtetra
.613 .463 .654 r
.58932 .2925 .59576 .32349 .60728 .31527 .60083 .28613 Mtetra
.612 .468 .662 r
.60083 .28613 .60728 .31527 .61883 .30762 .61239 .28027 Mtetra
.608 .473 .672 r
.61239 .28027 .61883 .30762 .63042 .30058 .624 .27512 Mtetra
.604 .479 .683 r
.624 .27512 .63042 .30058 .64206 .29413 .63568 .27064 Mtetra
.6 .488 .697 r
.63568 .27064 .64206 .29413 .65375 .28819 .64743 .26676 Mtetra
.597 .499 .714 r
.64743 .26676 .65375 .28819 .6655 .28278 .65926 .26342 Mtetra
.593 .513 .734 r
.65926 .26342 .6655 .28278 .67732 .27791 .67116 .26054 Mtetra
.59 .53 .756 r
.67116 .26054 .67732 .27791 .68921 .27356 .68314 .25804 Mtetra
.586 .55 .781 r
.68314 .25804 .68921 .27356 .70118 .26974 .69521 .25586 Mtetra
.582 .572 .807 r
.69521 .25586 .70118 .26974 .71323 .26636 .70736 .25391 Mtetra
.579 .595 .833 r
.70736 .25391 .71323 .26636 .72536 .26335 .71958 .2521 Mtetra
.575 .618 .858 r
.71958 .2521 .72536 .26335 .73757 .26064 .73188 .25037 Mtetra
.573 .64 .879 r
.73188 .25037 .73757 .26064 .74987 .25811 .74426 .24863 Mtetra
.57 .66 .898 r
.74426 .24863 .74987 .25811 .76223 .2557 .7567 .24686 Mtetra
.569 .678 .914 r
.7567 .24686 .76223 .2557 .77467 .25334 .76922 .24503 Mtetra
.568 .695 .927 r
.76922 .24503 .77467 .25334 .78718 .25095 .7818 .24311 Mtetra
.728 .765 .882 r
.12449 .45992 .13161 .46613 .14166 .46055 .13456 .4544 Mtetra
.731 .768 .882 r
.13456 .4544 .14166 .46055 .15175 .45488 .14467 .44875 Mtetra
.735 .77 .881 r
.14467 .44875 .15175 .45488 .16187 .44914 .15482 .44296 Mtetra
.739 .77 .878 r
.15482 .44296 .16187 .44914 .17201 .44338 .16501 .43701 Mtetra
.742 .765 .872 r
.16501 .43701 .17201 .44338 .18218 .4376 .17524 .43087 Mtetra
.742 .756 .864 r
.17524 .43087 .18218 .4376 .19236 .43189 .18551 .42459 Mtetra
.739 .741 .853 r
.18551 .42459 .19236 .43189 .20256 .42632 .1958 .4182 Mtetra
.733 .72 .839 r
.1958 .4182 .20256 .42632 .21275 .42096 .20612 .41181 Mtetra
.722 .695 .823 r
.20612 .41181 .21275 .42096 .22295 .41591 .21646 .40547 Mtetra
.708 .666 .806 r
.21646 .40547 .22295 .41591 .23314 .41122 .2268 .39932 Mtetra
.691 .635 .788 r
.2268 .39932 .23314 .41122 .24332 .40698 .23713 .39346 Mtetra
.673 .604 .77 r
.23713 .39346 .24332 .40698 .2535 .40327 .24746 .38797 Mtetra
.654 .574 .752 r
.24746 .38797 .2535 .40327 .26366 .40015 .25777 .38293 Mtetra
.638 .546 .734 r
.25777 .38293 .26366 .40015 .27381 .39768 .26809 .37825 Mtetra
.624 .52 .716 r
.26809 .37825 .27381 .39768 .28396 .39591 .27841 .37388 Mtetra
.614 .497 .696 r
.27841 .37388 .28396 .39591 .29412 .39464 .28877 .36956 Mtetra
.607 .477 .677 r
.28877 .36956 .29412 .39464 .30431 .39373 .29917 .36511 Mtetra
.601 .458 .66 r
.29917 .36511 .30431 .39373 .31456 .39273 .30961 .36053 Mtetra
.595 .443 .645 r
.30961 .36053 .31456 .39273 .32489 .39133 .32009 .35582 Mtetra
.587 .428 .634 r
.32009 .35582 .32489 .39133 .33531 .38941 .3306 .35135 Mtetra
.578 .417 .627 r
.3306 .35135 .33531 .38941 .34582 .38688 .34111 .34733 Mtetra
.57 .408 .623 r
.34111 .34733 .34582 .38688 .35639 .38399 .35163 .34393 Mtetra
.563 .402 .621 r
.35163 .34393 .35639 .38399 .36703 .38091 .36215 .34119 Mtetra
.559 .4 .622 r
.36215 .34119 .36703 .38091 .3777 .37779 .37271 .33888 Mtetra
.557 .4 .625 r
.37271 .33888 .3777 .37779 .38842 .37472 .3833 .33684 Mtetra
.558 .403 .628 r
.3833 .33684 .38842 .37472 .39919 .37167 .39395 .33476 Mtetra
.561 .408 .631 r
.39395 .33476 .39919 .37167 .41001 .36858 .40466 .33244 Mtetra
.566 .414 .634 r
.40466 .33244 .41001 .36858 .42088 .36532 .41544 .32972 Mtetra
.572 .42 .636 r
.41544 .32972 .42088 .36532 .4318 .36184 .42628 .32647 Mtetra
.579 .425 .636 r
.42628 .32647 .4318 .36184 .44278 .35808 .43719 .32265 Mtetra
.585 .429 .636 r
.43719 .32265 .44278 .35808 .4538 .35402 .44816 .31826 Mtetra
.59 .431 .635 r
.44816 .31826 .4538 .35402 .46488 .34974 .45917 .31334 Mtetra
.592 .432 .633 r
.45917 .31334 .46488 .34974 .476 .34529 .47023 .30801 Mtetra
.593 .431 .631 r
.47023 .30801 .476 .34529 .48716 .3408 .48133 .30243 Mtetra
.592 .427 .628 r
.48133 .30243 .48716 .3408 .49836 .33631 .49246 .29681 Mtetra
.588 .422 .625 r
.49246 .29681 .49836 .33631 .5096 .33188 .50363 .29145 Mtetra
.582 .417 .622 r
.50363 .29145 .5096 .33188 .52088 .32742 .51482 .28652 Mtetra
.576 .411 .621 r
.51482 .28652 .52088 .32742 .53221 .32274 .52606 .28226 Mtetra
.57 .408 .623 r
.52606 .28226 .53221 .32274 .54357 .31771 .53734 .27862 Mtetra
.567 .409 .627 r
.53734 .27862 .54357 .31771 .55497 .31205 .54868 .27544 Mtetra
.567 .415 .634 r
.54868 .27544 .55497 .31205 .56639 .30584 .56007 .27251 Mtetra
.572 .427 .646 r
.56007 .27251 .56639 .30584 .57784 .29922 .57151 .26945 Mtetra
.578 .443 .661 r
.57151 .26945 .57784 .29922 .58932 .2925 .58301 .26625 Mtetra
.586 .463 .679 r
.58301 .26625 .58932 .2925 .60083 .28613 .59455 .26292 Mtetra
.591 .483 .699 r
.59455 .26292 .60083 .28613 .61239 .28027 .60616 .25964 Mtetra
.592 .501 .72 r
.60616 .25964 .61239 .28027 .624 .27512 .61782 .25668 Mtetra
.589 .518 .743 r
.61782 .25668 .624 .27512 .63568 .27064 .62956 .25409 Mtetra
.583 .535 .766 r
.62956 .25409 .63568 .27064 .64743 .26676 .64138 .25197 Mtetra
.576 .553 .792 r
.64138 .25197 .64743 .26676 .65926 .26342 .65327 .25024 Mtetra
.568 .575 .82 r
.65327 .25024 .65926 .26342 .67116 .26054 .66525 .24881 Mtetra
.56 .598 .849 r
.66525 .24881 .67116 .26054 .68314 .25804 .67732 .24757 Mtetra
.553 .623 .876 r
.67732 .24757 .68314 .25804 .69521 .25586 .68946 .2464 Mtetra
.547 .647 .9 r
.68946 .2464 .69521 .25586 .70736 .25391 .70167 .24523 Mtetra
.545 .67 .919 r
.70167 .24523 .70736 .25391 .71958 .2521 .71396 .24396 Mtetra
.546 .687 .932 r
.71396 .24396 .71958 .2521 .73188 .25037 .72632 .24254 Mtetra
.55 .701 .939 r
.72632 .24254 .73188 .25037 .74426 .24863 .73874 .24094 Mtetra
.556 .709 .942 r
.73874 .24094 .74426 .24863 .7567 .24686 .75122 .23917 Mtetra
.561 .713 .942 r
.75122 .23917 .7567 .24686 .76922 .24503 .76376 .23726 Mtetra
.567 .714 .94 r
.76376 .23726 .76922 .24503 .7818 .24311 .77637 .23521 Mtetra
.705 .762 .896 r
.11732 .45366 .12449 .45992 .13456 .4544 .12732 .44889 Mtetra
.712 .787 .91 r
.12732 .44889 .13456 .4544 .14467 .44875 .13737 .44398 Mtetra
.72 .814 .923 r
.13737 .44398 .14467 .44875 .15482 .44296 .14747 .4389 Mtetra
.729 .841 .933 r
.14747 .4389 .15482 .44296 .16501 .43701 .15761 .4336 Mtetra
.738 .865 .94 r
.15761 .4336 .16501 .43701 .17524 .43087 .16782 .42803 Mtetra
.745 .886 .943 r
.16782 .42803 .17524 .43087 .18551 .42459 .17807 .4222 Mtetra
.753 .902 .944 r
.17807 .4222 .18551 .42459 .1958 .4182 .18838 .4161 Mtetra
.757 .913 .943 r
.18838 .4161 .1958 .4182 .20612 .41181 .19873 .40982 Mtetra
.761 .918 .942 r
.19873 .40982 .20612 .41181 .21646 .40547 .20911 .40339 Mtetra
.763 .915 .94 r
.20911 .40339 .21646 .40547 .2268 .39932 .21952 .3969 Mtetra
.763 .906 .938 r
.21952 .3969 .2268 .39932 .23713 .39346 .22995 .39045 Mtetra
.762 .887 .934 r
.22995 .39045 .23713 .39346 .24746 .38797 .24039 .38409 Mtetra
.756 .857 .925 r
.24039 .38409 .24746 .38797 .25777 .38293 .25084 .37787 Mtetra
.749 .817 .906 r
.25084 .37787 .25777 .38293 .26809 .37825 .2613 .37173 Mtetra
.737 .77 .879 r
.2613 .37173 .26809 .37825 .27841 .37388 .27179 .36565 Mtetra
.724 .722 .848 r
.27179 .36565 .27841 .37388 .28877 .36956 .2823 .35956 Mtetra
.71 .679 .818 r
.2823 .35956 .28877 .36956 .29917 .36511 .29283 .35345 Mtetra
.693 .643 .796 r
.29283 .35345 .29917 .36511 .30961 .36053 .30338 .34754 Mtetra
.677 .616 .78 r
.30338 .34754 .30961 .36053 .32009 .35582 .31392 .34197 Mtetra
.659 .597 .774 r
.31392 .34197 .32009 .35582 .3306 .35135 .32446 .33699 Mtetra
.641 .581 .772 r
.32446 .33699 .3306 .35135 .34111 .34733 .33499 .33275 Mtetra
.627 .571 .773 r
.33499 .33275 .34111 .34733 .35163 .34393 .34552 .32912 Mtetra
.614 .562 .773 r
.34552 .32912 .35163 .34393 .36215 .34119 .35606 .32599 Mtetra
.607 .554 .769 r
.35606 .32599 .36215 .34119 .37271 .33888 .36664 .32308 Mtetra
.605 .546 .762 r
.36664 .32308 .37271 .33888 .3833 .33684 .37726 .32022 Mtetra
.604 .537 .752 r
.37726 .32022 .3833 .33684 .39395 .33476 .38794 .31725 Mtetra
.606 .529 .742 r
.38794 .31725 .39395 .33476 .40466 .33244 .39867 .31409 Mtetra
.607 .523 .733 r
.39867 .31409 .40466 .33244 .41544 .32972 .40946 .3107 Mtetra
.609 .519 .727 r
.40946 .3107 .41544 .32972 .42628 .32647 .4203 .30708 Mtetra
.612 .518 .723 r
.4203 .30708 .42628 .32647 .43719 .32265 .43119 .30322 Mtetra
.616 .52 .722 r
.43119 .30322 .43719 .32265 .44816 .31826 .44214 .29913 Mtetra
.621 .526 .725 r
.44214 .29913 .44816 .31826 .45917 .31334 .45313 .29479 Mtetra
.627 .534 .73 r
.45313 .29479 .45917 .31334 .47023 .30801 .46416 .29024 Mtetra
.634 .545 .737 r
.46416 .29024 .47023 .30801 .48133 .30243 .47524 .28548 Mtetra
.639 .557 .746 r
.47524 .28548 .48133 .30243 .49246 .29681 .48636 .28061 Mtetra
.642 .566 .754 r
.48636 .28061 .49246 .29681 .50363 .29145 .49752 .27579 Mtetra
.64 .572 .762 r
.49752 .27579 .50363 .29145 .51482 .28652 .50872 .27118 Mtetra
.631 .571 .769 r
.50872 .27118 .51482 .28652 .52606 .28226 .51996 .26709 Mtetra
.618 .567 .774 r
.51996 .26709 .52606 .28226 .53734 .27862 .53124 .26361 Mtetra
.601 .56 .78 r
.53124 .26361 .53734 .27862 .54868 .27544 .54258 .26087 Mtetra
.587 .559 .79 r
.54258 .26087 .54868 .27544 .56007 .27251 .55398 .25874 Mtetra
.578 .566 .805 r
.55398 .25874 .56007 .27251 .57151 .26945 .56545 .25697 Mtetra
.572 .586 .829 r
.56545 .25697 .57151 .26945 .58301 .26625 .57698 .2554 Mtetra
.571 .619 .861 r
.57698 .2554 .58301 .26625 .59455 .26292 .58858 .25382 Mtetra
.564 .661 .902 r
.58858 .25382 .59455 .26292 .60616 .25964 .60025 .25224 Mtetra
.547 .706 .944 r
.60025 .25224 .60616 .25964 .61782 .25668 .61199 .25072 Mtetra
.517 .744 .978 r
.61199 .25072 .61782 .25668 .62956 .25409 .6238 .24928 Mtetra
.472 .769 .995 r
.6238 .24928 .62956 .25409 .64138 .25197 .63569 .24801 Mtetra
.427 .779 .997 r
.63569 .24801 .64138 .25197 .65327 .25024 .64766 .24683 Mtetra
.393 .781 .989 r
.64766 .24683 .65327 .25024 .66525 .24881 .6597 .24569 Mtetra
.377 .783 .983 r
.6597 .24569 .66525 .24881 .67732 .24757 .67181 .2445 Mtetra
.385 .79 .983 r
.67181 .2445 .67732 .24757 .68946 .2464 .68399 .24317 Mtetra
.409 .799 .989 r
.68399 .24317 .68946 .2464 .70167 .24523 .69624 .24165 Mtetra
.448 .808 .996 r
.69624 .24165 .70167 .24523 .71396 .24396 .70855 .23985 Mtetra
.489 .81 1 r
.70855 .23985 .71396 .24396 .72632 .24254 .72091 .2378 Mtetra
.529 .806 .997 r
.72091 .2378 .72632 .24254 .73874 .24094 .73333 .23546 Mtetra
.56 .793 .986 r
.73333 .23546 .73874 .24094 .75122 .23917 .74579 .23289 Mtetra
.582 .774 .971 r
.74579 .23289 .75122 .23917 .76376 .23726 .75832 .23014 Mtetra
.596 .752 .952 r
.75832 .23014 .76376 .23726 .77637 .23521 .7709 .22725 Mtetra
.663 .753 .917 r
.1101 .44736 .11732 .45366 .12732 .44889 .11998 .44375 Mtetra
.666 .794 .943 r
.11998 .44375 .12732 .44889 .13737 .44398 .12991 .44003 Mtetra
.667 .837 .965 r
.12991 .44003 .13737 .44398 .14747 .4389 .13989 .43615 Mtetra
.662 .88 .979 r
.13989 .43615 .14747 .4389 .15761 .4336 .14994 .43205 Mtetra
.651 .917 .978 r
.14994 .43205 .15761 .4336 .16782 .42803 .16005 .42766 Mtetra
.626 .94 .957 r
.16005 .42766 .16782 .42803 .17807 .4222 .17022 .42296 Mtetra
.589 .944 .914 r
.17022 .42296 .17807 .4222 .18838 .4161 .18046 .41794 Mtetra
.54 .927 .852 r
.18046 .41794 .18838 .4161 .19873 .40982 .19076 .4126 Mtetra
.489 .896 .783 r
.19076 .4126 .19873 .40982 .20911 .40339 .20112 .40697 Mtetra
.442 .861 .717 r
.20112 .40697 .20911 .40339 .21952 .3969 .21154 .40107 Mtetra
.41 .833 .667 r
.21154 .40107 .21952 .3969 .22995 .39045 .22199 .39493 Mtetra
.399 .82 .641 r
.22199 .39493 .22995 .39045 .24039 .38409 .23249 .38858 Mtetra
.413 .828 .644 r
.23249 .38858 .24039 .38409 .25084 .37787 .24303 .38204 Mtetra
.45 .855 .676 r
.24303 .38204 .25084 .37787 .2613 .37173 .2536 .37538 Mtetra
.499 .889 .723 r
.2536 .37538 .2613 .37173 .27179 .36565 .2642 .36864 Mtetra
.536 .915 .771 r
.2642 .36864 .27179 .36565 .2823 .35956 .27481 .36206 Mtetra
.542 .923 .8 r
.27481 .36206 .2823 .35956 .29283 .35345 .28541 .35579 Mtetra
.495 .901 .793 r
.28541 .35579 .29283 .35345 .30338 .34754 .296 .35009 Mtetra
.393 .841 .741 r
.296 .35009 .30338 .34754 .31392 .34197 .30656 .34511 Mtetra
0 0 0 r
.30656 .34511 .31392 .34197 .32446 .33699 .31712 .3407 Mtetra
.31712 .3407 .32446 .33699 .33499 .33275 .32769 .33675 Mtetra
.32769 .33675 .33499 .33275 .34552 .32912 .33829 .33287 Mtetra
.33829 .33287 .34552 .32912 .35606 .32599 .34894 .32886 Mtetra
.34894 .32886 .35606 .32599 .36664 .32308 .35965 .3246 Mtetra
.415 .862 .805 r
.35965 .3246 .36664 .32308 .37726 .32022 .37041 .32006 Mtetra
.558 .928 .928 r
.37041 .32006 .37726 .32022 .38794 .31725 .38121 .31539 Mtetra
.64 .922 .976 r
.38121 .31539 .38794 .31725 .39867 .31409 .39204 .31071 Mtetra
.667 .881 .978 r
.39204 .31071 .39867 .31409 .40946 .3107 .40291 .3062 Mtetra
.666 .84 .967 r
.40291 .3062 .40946 .3107 .4203 .30708 .41381 .30197 Mtetra
.653 .816 .961 r
.41381 .30197 .4203 .30708 .43119 .30322 .42474 .29809 Mtetra
.636 .81 .967 r
.42474 .29809 .43119 .30322 .44214 .29913 .4357 .29455 Mtetra
.612 .825 .982 r
.4357 .29455 .44214 .29913 .45313 .29479 .4467 .29129 Mtetra
.575 .853 .996 r
.4467 .29129 .45313 .29479 .46416 .29024 .45775 .2882 Mtetra
.511 .875 .982 r
.45775 .2882 .46416 .29024 .47524 .28548 .46885 .28511 Mtetra
.404 .854 .901 r
.46885 .28511 .47524 .28548 .48636 .28061 .48 .28189 Mtetra
.28 .779 .756 r
.48 .28189 .48636 .28061 .49752 .27579 .49121 .27838 Mtetra
0 0 0 r
.49121 .27838 .49752 .27579 .50872 .27118 .50246 .27464 Mtetra
.50246 .27464 .50872 .27118 .51996 .26709 .51377 .27074 Mtetra
.51377 .27074 .51996 .26709 .53124 .26361 .52512 .26693 Mtetra
.52512 .26693 .53124 .26361 .54258 .26087 .53653 .26357 Mtetra
.53653 .26357 .54258 .26087 .55398 .25874 .54799 .2608 Mtetra
.54799 .2608 .55398 .25874 .56545 .25697 .55952 .25877 Mtetra
.005 0 0 r
.55952 .25877 .56545 .25697 .57698 .2554 .57111 .25732 Mtetra
.048 0 0 r
.57111 .25732 .57698 .2554 .58858 .25382 .58279 .2562 Mtetra
.098 0 0 r
.58279 .2562 .58858 .25382 .60025 .25224 .59454 .25524 Mtetra
.135 0 0 r
.59454 .25524 .60025 .25224 .61199 .25072 .60636 .25422 Mtetra
.156 0 0 r
.60636 .25422 .61199 .25072 .6238 .24928 .61825 .25308 Mtetra
.159 0 0 r
.61825 .25308 .6238 .24928 .63569 .24801 .63021 .25175 Mtetra
.14 0 0 r
.63021 .25175 .63569 .24801 .64766 .24683 .64224 .2502 Mtetra
.1 0 0 r
.64224 .2502 .64766 .24683 .6597 .24569 .65433 .24842 Mtetra
.034 0 0 r
.65433 .24842 .6597 .24569 .67181 .2445 .66648 .24637 Mtetra
0 0 0 r
.66648 .24637 .67181 .2445 .68399 .24317 .67868 .24401 Mtetra
.181 .712 .727 r
.67868 .24401 .68399 .24317 .69624 .24165 .69093 .24133 Mtetra
.317 .806 .852 r
.69093 .24133 .69624 .24165 .70855 .23985 .70323 .2383 Mtetra
.441 .864 .943 r
.70323 .2383 .70855 .23985 .72091 .2378 .71557 .23496 Mtetra
.538 .88 .988 r
.71557 .23496 .72091 .2378 .73333 .23546 .72796 .23132 Mtetra
.598 .862 .993 r
.72796 .23132 .73333 .23546 .74579 .23289 .74039 .22744 Mtetra
.631 .828 .976 r
.74039 .22744 .74579 .23289 .75832 .23014 .75286 .22339 Mtetra
.646 .788 .95 r
.75286 .22339 .75832 .23014 .7709 .22725 .76539 .21923 Mtetra
.603 .737 .939 r
.10283 .44102 .1101 .44736 .11998 .44375 .11257 .43869 Mtetra
.594 .781 .969 r
.11257 .43869 .11998 .44375 .12991 .44003 .12236 .43629 Mtetra
.577 .825 .992 r
.12236 .43629 .12991 .44003 .13989 .43615 .1322 .43378 Mtetra
.545 .863 .996 r
.1322 .43378 .13989 .43615 .14994 .43205 .14211 .43108 Mtetra
.493 .881 .965 r
.14211 .43108 .14994 .43205 .16005 .42766 .15209 .42815 Mtetra
.415 .862 .887 r
.15209 .42815 .16005 .42766 .17022 .42296 .16214 .42493 Mtetra
.321 .804 .767 r
.16214 .42493 .17022 .42296 .18046 .41794 .17227 .42138 Mtetra
0 0 0 r
.17227 .42138 .18046 .41794 .19076 .4126 .18248 .41749 Mtetra
.18248 .41749 .19076 .4126 .20112 .40697 .19276 .41323 Mtetra
.19276 .41323 .20112 .40697 .21154 .40107 .2031 .40862 Mtetra
.2031 .40862 .21154 .40107 .22199 .39493 .21352 .40367 Mtetra
.039 0 0 r
.21352 .40367 .22199 .39493 .23249 .38858 .22399 .39842 Mtetra
.075 0 0 r
.22399 .39842 .23249 .38858 .24303 .38204 .23452 .3929 Mtetra
.11 0 0 r
.23452 .3929 .24303 .38204 .2536 .37538 .24509 .38723 Mtetra
.147 0 0 r
.24509 .38723 .2536 .37538 .2642 .36864 .25569 .38152 Mtetra
.189 0 .022 r
.25569 .38152 .2642 .36864 .27481 .36206 .2663 .37596 Mtetra
.233 0 .069 r
.2663 .37596 .27481 .36206 .28541 .35579 .27692 .3707 Mtetra
.271 0 .109 r
.27692 .3707 .28541 .35579 .296 .35009 .28755 .36578 Mtetra
.3 0 .138 r
.28755 .36578 .296 .35009 .30656 .34511 .29818 .36121 Mtetra
.309 0 .15 r
.29818 .36121 .30656 .34511 .31712 .3407 .30885 .35671 Mtetra
.305 0 .146 r
.30885 .35671 .31712 .3407 .32769 .33675 .31956 .35209 Mtetra
.283 0 .125 r
.31956 .35209 .32769 .33675 .33829 .33287 .33032 .34717 Mtetra
.248 0 .088 r
.33032 .34717 .33829 .33287 .34894 .32886 .34114 .34186 Mtetra
.207 0 .041 r
.34114 .34186 .34894 .32886 .35965 .3246 .35201 .3363 Mtetra
.164 0 0 r
.35201 .3363 .35965 .3246 .37041 .32006 .36292 .3306 Mtetra
.132 0 0 r
.36292 .3306 .37041 .32006 .38121 .31539 .37385 .32499 Mtetra
.113 0 0 r
.37385 .32499 .38121 .31539 .39204 .31071 .3848 .31965 Mtetra
.115 0 0 r
.3848 .31965 .39204 .31071 .40291 .3062 .39577 .3147 Mtetra
.132 0 0 r
.39577 .3147 .40291 .3062 .41381 .30197 .40676 .31026 Mtetra
.162 0 0 r
.40676 .31026 .41381 .30197 .42474 .29809 .41777 .30636 Mtetra
.199 0 0 r
.41777 .30636 .42474 .29809 .4357 .29455 .42881 .303 Mtetra
.237 0 0 r
.42881 .303 .4357 .29455 .4467 .29129 .43988 .30014 Mtetra
.272 0 0 r
.43988 .30014 .4467 .29129 .45775 .2882 .45099 .2977 Mtetra
.302 0 .001 r
.45099 .2977 .45775 .2882 .46885 .28511 .46216 .29551 Mtetra
.326 0 .041 r
.46216 .29551 .46885 .28511 .48 .28189 .47339 .29343 Mtetra
.341 0 .078 r
.47339 .29343 .48 .28189 .49121 .27838 .48467 .29121 Mtetra
.351 0 .113 r
.48467 .29121 .49121 .27838 .50246 .27464 .49602 .28875 Mtetra
.354 0 .14 r
.49602 .28875 .50246 .27464 .51377 .27074 .50743 .28589 Mtetra
.357 0 .16 r
.50743 .28589 .51377 .27074 .52512 .26693 .51889 .28273 Mtetra
.361 0 .173 r
.51889 .28273 .52512 .26693 .53653 .26357 .53041 .27945 Mtetra
.364 0 .175 r
.53041 .27945 .53653 .26357 .54799 .2608 .54199 .27624 Mtetra
.371 0 .171 r
.54199 .27624 .54799 .2608 .55952 .25877 .55362 .27339 Mtetra
.373 0 .157 r
.55362 .27339 .55952 .25877 .57111 .25732 .56532 .27089 Mtetra
.371 0 .136 r
.56532 .27089 .57111 .25732 .58279 .2562 .57708 .2687 Mtetra
.364 0 .11 r
.57708 .2687 .58279 .2562 .59454 .25524 .58892 .26666 Mtetra
.347 0 .077 r
.58892 .26666 .59454 .25524 .60636 .25422 .60081 .26459 Mtetra
.324 0 .037 r
.60081 .26459 .60636 .25422 .61825 .25308 .61277 .26237 Mtetra
.291 0 0 r
.61277 .26237 .61825 .25308 .63021 .25175 .62479 .25988 Mtetra
.245 0 0 r
.62479 .25988 .63021 .25175 .64224 .2502 .63687 .25708 Mtetra
.183 0 0 r
.63687 .25708 .64224 .2502 .65433 .24842 .64899 .25392 Mtetra
.096 0 0 r
.64899 .25392 .65433 .24842 .66648 .24637 .66116 .2504 Mtetra
0 0 0 r
.66116 .2504 .66648 .24637 .67868 .24401 .67337 .2465 Mtetra
.67337 .2465 .67868 .24401 .69093 .24133 .68561 .24224 Mtetra
.346 .82 .773 r
.68561 .24224 .69093 .24133 .70323 .2383 .6979 .23764 Mtetra
.499 .905 .904 r
.6979 .23764 .70323 .2383 .71557 .23496 .71021 .23273 Mtetra
.606 .926 .968 r
.71021 .23273 .71557 .23496 .72796 .23132 .72256 .22757 Mtetra
.664 .902 .979 r
.72256 .22757 .72796 .23132 .74039 .22744 .73494 .2222 Mtetra
.69 .859 .963 r
.73494 .2222 .74039 .22744 .75286 .22339 .74736 .21671 Mtetra
.697 .812 .936 r
.74736 .21671 .75286 .22339 .76539 .21923 .75983 .21113 Mtetra
.535 .714 .955 r
.09551 .43462 .10283 .44102 .11257 .43869 .10511 .43342 Mtetra
.514 .748 .98 r
.10511 .43342 .11257 .43869 .12236 .43629 .11477 .43221 Mtetra
.482 .781 .997 r
.11477 .43221 .12236 .43629 .1322 .43378 .12449 .43093 Mtetra
.435 .805 .994 r
.12449 .43093 .1322 .43378 .14211 .43108 .13427 .42954 Mtetra
.367 .809 .955 r
.13427 .42954 .14211 .43108 .15209 .42815 .14412 .42799 Mtetra
.277 .777 .868 r
.14412 .42799 .15209 .42815 .16214 .42493 .15405 .42622 Mtetra
.176 .71 .736 r
.15405 .42622 .16214 .42493 .17227 .42138 .16405 .42418 Mtetra
0 0 0 r
.16405 .42418 .17227 .42138 .18248 .41749 .17414 .42184 Mtetra
.007 0 0 r
.17414 .42184 .18248 .41749 .19276 .41323 .18431 .41915 Mtetra
.076 0 0 r
.18431 .41915 .19276 .41323 .2031 .40862 .19455 .41613 Mtetra
.13 0 0 r
.19455 .41613 .2031 .40862 .21352 .40367 .20488 .41276 Mtetra
.178 0 0 r
.20488 .41276 .21352 .40367 .22399 .39842 .21527 .40914 Mtetra
.219 0 0 r
.21527 .40914 .22399 .39842 .23452 .3929 .22572 .4053 Mtetra
.258 0 .044 r
.22572 .4053 .23452 .3929 .24509 .38723 .23622 .40138 Mtetra
.294 0 .101 r
.23622 .40138 .24509 .38723 .25569 .38152 .24676 .39748 Mtetra
.324 0 .149 r
.24676 .39748 .25569 .38152 .2663 .37596 .25733 .39362 Mtetra
.348 0 .186 r
.25733 .39362 .2663 .37596 .27692 .3707 .26794 .38984 Mtetra
.358 0 .209 r
.26794 .38984 .27692 .3707 .28755 .36578 .2786 .3859 Mtetra
.359 .004 .22 r
.2786 .3859 .28755 .36578 .29818 .36121 .28932 .38166 Mtetra
.347 0 .218 r
.28932 .38166 .29818 .36121 .30885 .35671 .30012 .3769 Mtetra
.326 0 .206 r
.30012 .3769 .30885 .35671 .31956 .35209 .31099 .37151 Mtetra
.304 0 .187 r
.31099 .37151 .31956 .35209 .33032 .34717 .32193 .36565 Mtetra
.281 0 .165 r
.32193 .36565 .33032 .34717 .34114 .34186 .33292 .35947 Mtetra
.269 0 .148 r
.33292 .35947 .34114 .34186 .35201 .3363 .34394 .35327 Mtetra
.267 0 .139 r
.34394 .35327 .35201 .3363 .36292 .3306 .35497 .34727 Mtetra
.277 0 .139 r
.35497 .34727 .36292 .3306 .37385 .32499 .36602 .34162 Mtetra
.293 0 .147 r
.36602 .34162 .37385 .32499 .3848 .31965 .37707 .3364 Mtetra
.311 0 .158 r
.37707 .3364 .3848 .31965 .39577 .3147 .38815 .33162 Mtetra
.329 0 .169 r
.38815 .33162 .39577 .3147 .40676 .31026 .39924 .32728 Mtetra
.345 0 .178 r
.39924 .32728 .40676 .31026 .41777 .30636 .41036 .32337 Mtetra
.359 0 .185 r
.41036 .32337 .41777 .30636 .42881 .303 .42152 .31988 Mtetra
.372 0 .188 r
.42152 .31988 .42881 .303 .43988 .30014 .4327 .31685 Mtetra
.383 .005 .191 r
.4327 .31685 .43988 .30014 .45099 .2977 .44393 .31425 Mtetra
.395 .014 .194 r
.44393 .31425 .45099 .2977 .46216 .29551 .45521 .31209 Mtetra
.405 .024 .198 r
.45521 .31209 .46216 .29551 .47339 .29343 .46654 .31029 Mtetra
.413 .033 .205 r
.46654 .31029 .47339 .29343 .48467 .29121 .47793 .3087 Mtetra
.417 .041 .215 r
.47793 .3087 .48467 .29121 .49602 .28875 .48939 .3071 Mtetra
.414 .044 .224 r
.48939 .3071 .49602 .28875 .50743 .28589 .50091 .30518 Mtetra
.409 .045 .233 r
.50091 .30518 .50743 .28589 .51889 .28273 .5125 .30279 Mtetra
.399 .041 .237 r
.5125 .30279 .51889 .28273 .53041 .27945 .52416 .29975 Mtetra
.388 .033 .236 r
.52416 .29975 .53041 .27945 .54199 .27624 .53587 .29619 Mtetra
.379 .023 .229 r
.53587 .29619 .54199 .27624 .55362 .27339 .54763 .29232 Mtetra
.367 .006 .213 r
.54763 .29232 .55362 .27339 .56532 .27089 .55944 .2883 Mtetra
.356 0 .189 r
.55944 .2883 .56532 .27089 .57708 .2687 .5713 .28434 Mtetra
.339 0 .155 r
.5713 .28434 .57708 .2687 .58892 .26666 .58322 .28044 Mtetra
.314 0 .111 r
.58322 .28044 .58892 .26666 .60081 .26459 .59519 .27654 Mtetra
.28 0 .056 r
.59519 .27654 .60081 .26459 .61277 .26237 .60721 .27256 Mtetra
.231 0 0 r
.60721 .27256 .61277 .26237 .62479 .25988 .61928 .26836 Mtetra
.165 0 0 r
.61928 .26836 .62479 .25988 .63687 .25708 .63139 .26388 Mtetra
.072 0 0 r
.63139 .26388 .63687 .25708 .64899 .25392 .64354 .25905 Mtetra
0 0 0 r
.64354 .25905 .64899 .25392 .66116 .2504 .65573 .25387 Mtetra
.65573 .25387 .66116 .2504 .67337 .2465 .66794 .24832 Mtetra
.376 .827 .716 r
.66794 .24832 .67337 .2465 .68561 .24224 .68019 .24244 Mtetra
.531 .922 .855 r
.68019 .24244 .68561 .24224 .6979 .23764 .69246 .23628 Mtetra
.64 .955 .934 r
.69246 .23628 .6979 .23764 .71021 .23273 .70475 .22987 Mtetra
.701 .941 .961 r
.70475 .22987 .71021 .23273 .72256 .22757 .71707 .22329 Mtetra
.729 .905 .956 r
.71707 .22329 .72256 .22757 .73494 .2222 .72942 .21658 Mtetra
.738 .862 .939 r
.72942 .21658 .73494 .2222 .74736 .21671 .74181 .20979 Mtetra
.736 .819 .916 r
.74181 .20979 .74736 .21671 .75983 .21113 .75422 .20298 Mtetra
.491 .697 .96 r
.08813 .42819 .09551 .43462 .10511 .43342 .09767 .42758 Mtetra
.475 .713 .974 r
.09767 .42758 .10511 .43342 .11477 .43221 .10726 .427 Mtetra
.455 .73 .986 r
.10726 .427 .11477 .43221 .12449 .43093 .11691 .42641 Mtetra
.432 .747 .993 r
.11691 .42641 .12449 .43093 .13427 .42954 .12662 .42579 Mtetra
.403 .762 .994 r
.12662 .42579 .13427 .42954 .14412 .42799 .13639 .42509 Mtetra
.366 .773 .983 r
.13639 .42509 .14412 .42799 .15405 .42622 .14623 .42426 Mtetra
.319 .774 .952 r
.14623 .42426 .15405 .42622 .16405 .42418 .15614 .42327 Mtetra
.258 .758 .893 r
.15614 .42327 .16405 .42418 .17414 .42184 .16614 .42207 Mtetra
.188 .72 .803 r
.16614 .42207 .17414 .42184 .18431 .41915 .17621 .42062 Mtetra
0 0 0 r
.17621 .42062 .18431 .41915 .19455 .41613 .18637 .41892 Mtetra
.18637 .41892 .19455 .41613 .20488 .41276 .1966 .41695 Mtetra
.055 0 0 r
.1966 .41695 .20488 .41276 .21527 .40914 .20691 .41477 Mtetra
.124 0 0 r
.20691 .41477 .21527 .40914 .22572 .4053 .21728 .41239 Mtetra
.182 0 0 r
.21728 .41239 .22572 .4053 .23622 .40138 .22772 .40988 Mtetra
.226 0 0 r
.22772 .40988 .23622 .40138 .24676 .39748 .23821 .40725 Mtetra
.254 0 0 r
.23821 .40725 .24676 .39748 .25733 .39362 .24877 .40445 Mtetra
.269 0 .007 r
.24877 .40445 .25733 .39362 .26794 .38984 .25939 .40144 Mtetra
.267 0 .026 r
.25939 .40144 .26794 .38984 .2786 .3859 .27009 .39805 Mtetra
.255 0 .032 r
.27009 .39805 .2786 .3859 .28932 .38166 .28088 .39417 Mtetra
.241 0 .033 r
.28088 .39417 .28932 .38166 .30012 .3769 .29173 .38983 Mtetra
.232 0 .038 r
.29173 .38983 .30012 .3769 .31099 .37151 .30266 .38508 Mtetra
.241 0 .058 r
.30266 .38508 .31099 .37151 .32193 .36565 .31363 .38021 Mtetra
.265 0 .09 r
.31363 .38021 .32193 .36565 .33292 .35947 .32464 .37539 Mtetra
.298 0 .131 r
.32464 .37539 .33292 .35947 .34394 .35327 .33567 .37078 Mtetra
.33 0 .171 r
.33567 .37078 .34394 .35327 .35497 .34727 .34672 .36646 Mtetra
.355 0 .204 r
.34672 .36646 .35497 .34727 .36602 .34162 .3578 .36238 Mtetra
.374 .02 .23 r
.3578 .36238 .36602 .34162 .37707 .3364 .36892 .35848 Mtetra
.385 .037 .247 r
.36892 .35848 .37707 .3364 .38815 .33162 .38008 .35463 Mtetra
.391 .047 .258 r
.38008 .35463 .38815 .33162 .39924 .32728 .39129 .35077 Mtetra
.392 .051 .263 r
.39129 .35077 .39924 .32728 .41036 .32337 .40255 .34686 Mtetra
.391 .05 .262 r
.40255 .34686 .41036 .32337 .42152 .31988 .41385 .34288 Mtetra
.389 .045 .257 r
.41385 .34288 .42152 .31988 .4327 .31685 .42521 .33889 Mtetra
.385 .037 .247 r
.42521 .33889 .4327 .31685 .44393 .31425 .4366 .33496 Mtetra
.38 .026 .233 r
.4366 .33496 .44393 .31425 .45521 .31209 .44805 .33122 Mtetra
.375 .011 .213 r
.44805 .33122 .45521 .31209 .46654 .31029 .45953 .3277 Mtetra
.369 0 .189 r
.45953 .3277 .46654 .31029 .47793 .3087 .47107 .32448 Mtetra
.36 0 .16 r
.47107 .32448 .47793 .3087 .48939 .3071 .48265 .32148 Mtetra
.346 0 .13 r
.48265 .32148 .48939 .3071 .50091 .30518 .49429 .31854 Mtetra
.329 0 .102 r
.49429 .31854 .50091 .30518 .5125 .30279 .506 .31547 Mtetra
.303 0 .075 r
.506 .31547 .5125 .30279 .52416 .29975 .51776 .31198 Mtetra
.276 0 .052 r
.51776 .31198 .52416 .29975 .53587 .29619 .52957 .30802 Mtetra
.248 0 .03 r
.52957 .30802 .53587 .29619 .54763 .29232 .54143 .30357 Mtetra
.218 0 .001 r
.54143 .30357 .54763 .29232 .55944 .2883 .55334 .29873 Mtetra
.185 0 0 r
.55334 .29873 .55944 .2883 .5713 .28434 .56529 .29366 Mtetra
.14 0 0 r
.56529 .29366 .5713 .28434 .58322 .28044 .57729 .28841 Mtetra
.08 0 0 r
.57729 .28841 .58322 .28044 .59519 .27654 .58932 .28304 Mtetra
0 0 0 r
.58932 .28304 .59519 .27654 .60721 .27256 .6014 .27751 Mtetra
.6014 .27751 .60721 .27256 .61928 .26836 .61351 .27178 Mtetra
.61351 .27178 .61928 .26836 .63139 .26388 .62566 .26582 Mtetra
.411 .847 .726 r
.62566 .26582 .63139 .26388 .64354 .25905 .63784 .25958 Mtetra
.543 .928 .844 r
.63784 .25958 .64354 .25905 .65573 .25387 .65004 .25306 Mtetra
.642 .962 .915 r
.65004 .25306 .65573 .25387 .66794 .24832 .66227 .24627 Mtetra
.703 .96 .946 r
.66227 .24627 .66794 .24832 .68019 .24244 .67452 .23925 Mtetra
.736 .939 .952 r
.67452 .23925 .68019 .24244 .69246 .23628 .6868 .23205 Mtetra
.752 .91 .946 r
.6868 .23205 .69246 .23628 .70475 .22987 .6991 .2247 Mtetra
.758 .881 .934 r
.6991 .2247 .70475 .22987 .71707 .22329 .71142 .21727 Mtetra
.758 .854 .921 r
.71142 .21727 .71707 .22329 .72942 .21658 .72378 .20977 Mtetra
.756 .829 .909 r
.72378 .20977 .72942 .21658 .74181 .20979 .73616 .20226 Mtetra
.751 .807 .897 r
.73616 .20226 .74181 .20979 .75422 .20298 .74857 .19475 Mtetra
.486 .695 .961 r
.0807 .4217 .08813 .42819 .09767 .42758 .09024 .42115 Mtetra
.481 .696 .963 r
.09024 .42115 .09767 .42758 .10726 .427 .09984 .42064 Mtetra
.475 .697 .965 r
.09984 .42064 .10726 .427 .11691 .42641 .10948 .42017 Mtetra
.47 .7 .968 r
.10948 .42017 .11691 .42641 .12662 .42579 .11918 .41973 Mtetra
.463 .704 .972 r
.11918 .41973 .12662 .42579 .13639 .42509 .12893 .4193 Mtetra
.457 .712 .978 r
.12893 .4193 .13639 .42509 .14623 .42426 .13874 .41884 Mtetra
.449 .723 .984 r
.13874 .41884 .14623 .42426 .15614 .42327 .14862 .41833 Mtetra
.44 .738 .99 r
.14862 .41833 .15614 .42327 .16614 .42207 .15856 .41773 Mtetra
.426 .754 .995 r
.15856 .41773 .16614 .42207 .17621 .42062 .16858 .417 Mtetra
.405 .771 .994 r
.16858 .417 .17621 .42062 .18637 .41892 .17867 .41613 Mtetra
.373 .783 .982 r
.17867 .41613 .18637 .41892 .1966 .41695 .18884 .4151 Mtetra
.327 .783 .95 r
.18884 .4151 .1966 .41695 .20691 .41477 .19908 .4139 Mtetra
.27 .766 .894 r
.19908 .4139 .20691 .41477 .21728 .41239 .20939 .41251 Mtetra
.211 .736 .819 r
.20939 .41251 .21728 .41239 .22772 .40988 .21979 .41089 Mtetra
.164 .702 .743 r
.21979 .41089 .22772 .40988 .23821 .40725 .23026 .409 Mtetra
0 0 0 r
.23026 .409 .23821 .40725 .24877 .40445 .24082 .40675 Mtetra
.24082 .40675 .24877 .40445 .25939 .40144 .25146 .40407 Mtetra
.25146 .40407 .25939 .40144 .27009 .39805 .26219 .40098 Mtetra
.26219 .40098 .27009 .39805 .28088 .39417 .273 .39753 Mtetra
.273 .39753 .28088 .39417 .29173 .38983 .28386 .39397 Mtetra
.28386 .39397 .29173 .38983 .30266 .38508 .29476 .39051 Mtetra
.051 0 0 r
.29476 .39051 .30266 .38508 .31363 .38021 .30568 .38737 Mtetra
.177 0 0 r
.30568 .38737 .31363 .38021 .32464 .37539 .31662 .38467 Mtetra
.267 0 0 r
.31662 .38467 .32464 .37539 .33567 .37078 .3276 .38228 Mtetra
.325 0 .052 r
.3276 .38228 .33567 .37078 .34672 .36646 .33862 .3801 Mtetra
.354 0 .114 r
.33862 .3801 .34672 .36646 .3578 .36238 .3497 .37787 Mtetra
.367 0 .154 r
.3497 .37787 .3578 .36238 .36892 .35848 .36085 .37541 Mtetra
.368 0 .176 r
.36085 .37541 .36892 .35848 .38008 .35463 .37207 .37255 Mtetra
.362 0 .187 r
.37207 .37255 .38008 .35463 .39129 .35077 .38338 .36919 Mtetra
.351 0 .188 r
.38338 .36919 .39129 .35077 .40255 .34686 .39475 .36526 Mtetra
.335 0 .181 r
.39475 .36526 .40255 .34686 .41385 .34288 .40619 .36078 Mtetra
.314 0 .165 r
.40619 .36078 .41385 .34288 .42521 .33889 .4177 .35578 Mtetra
.288 0 .139 r
.4177 .35578 .42521 .33889 .4366 .33496 .42926 .35038 Mtetra
.257 0 .101 r
.42926 .35038 .4366 .33496 .44805 .33122 .44086 .34474 Mtetra
.218 0 .046 r
.44086 .34474 .44805 .33122 .45953 .3277 .4525 .33904 Mtetra
.172 0 0 r
.4525 .33904 .45953 .3277 .47107 .32448 .46418 .33355 Mtetra
.112 0 0 r
.46418 .33355 .47107 .32448 .48265 .32148 .47589 .32837 Mtetra
.041 0 0 r
.47589 .32837 .48265 .32148 .49429 .31854 .48764 .32363 Mtetra
0 0 0 r
.48764 .32363 .49429 .31854 .506 .31547 .49943 .31921 Mtetra
.49943 .31921 .506 .31547 .51776 .31198 .51126 .31489 Mtetra
.51126 .31489 .51776 .31198 .52957 .30802 .52315 .31046 Mtetra
.278 .763 .672 r
.52315 .31046 .52957 .30802 .54143 .30357 .53508 .30565 Mtetra
.345 .81 .718 r
.53508 .30565 .54143 .30357 .55334 .29873 .54706 .30042 Mtetra
.413 .855 .763 r
.54706 .30042 .55334 .29873 .56529 .29366 .55908 .29474 Mtetra
.49 .901 .817 r
.55908 .29474 .56529 .29366 .57729 .28841 .57113 .28869 Mtetra
.567 .939 .873 r
.57113 .28869 .57729 .28841 .58932 .28304 .58322 .28234 Mtetra
.638 .96 .919 r
.58322 .28234 .58932 .28304 .6014 .27751 .59534 .27575 Mtetra
.691 .959 .946 r
.59534 .27575 .6014 .27751 .61351 .27178 .60749 .26895 Mtetra
.726 .942 .954 r
.60749 .26895 .61351 .27178 .62566 .26582 .61966 .26197 Mtetra
.746 .916 .949 r
.61966 .26197 .62566 .26582 .63784 .25958 .63187 .25481 Mtetra
.756 .889 .938 r
.63187 .25481 .63784 .25958 .65004 .25306 .64409 .24749 Mtetra
.76 .864 .926 r
.64409 .24749 .65004 .25306 .66227 .24627 .65635 .24002 Mtetra
.761 .843 .914 r
.65635 .24002 .66227 .24627 .67452 .23925 .66862 .23244 Mtetra
.76 .827 .904 r
.66862 .23244 .67452 .23925 .6868 .23205 .68093 .22479 Mtetra
.758 .814 .897 r
.68093 .22479 .6868 .23205 .6991 .2247 .69326 .2171 Mtetra
.755 .804 .892 r
.69326 .2171 .6991 .2247 .71142 .21727 .70561 .20941 Mtetra
.753 .797 .888 r
.70561 .20941 .71142 .21727 .72378 .20977 .718 .20174 Mtetra
.751 .792 .886 r
.718 .20174 .72378 .20977 .73616 .20226 .73042 .19408 Mtetra
.749 .789 .885 r
.73042 .19408 .73616 .20226 .74857 .19475 .74288 .18646 Mtetra
.53 .712 .956 r
.07322 .41517 .0807 .4217 .09024 .42115 .08286 .41398 Mtetra
.534 .693 .941 r
.08286 .41398 .09024 .42115 .09984 .42064 .09254 .41286 Mtetra
.536 .675 .927 r
.09254 .41286 .09984 .42064 .10948 .42017 .10227 .41179 Mtetra
.537 .658 .913 r
.10227 .41179 .10948 .42017 .11918 .41973 .11204 .41079 Mtetra
.537 .642 .901 r
.11204 .41079 .11918 .41973 .12893 .4193 .12186 .40987 Mtetra
.537 .63 .891 r
.12186 .40987 .12893 .4193 .13874 .41884 .13173 .409 Mtetra
.538 .62 .882 r
.13173 .409 .13874 .41884 .14862 .41833 .14164 .40816 Mtetra
.539 .613 .875 r
.14164 .40816 .14862 .41833 .15856 .41773 .15162 .40732 Mtetra
.541 .609 .87 r
.15162 .40732 .15856 .41773 .16858 .417 .16166 .40644 Mtetra
.544 .608 .867 r
.16166 .40644 .16858 .417 .17867 .41613 .17176 .4055 Mtetra
.549 .609 .865 r
.17176 .4055 .17867 .41613 .18884 .4151 .18193 .40445 Mtetra
.554 .612 .865 r
.18193 .40445 .18884 .4151 .19908 .4139 .19217 .40326 Mtetra
.561 .616 .865 r
.19217 .40326 .19908 .4139 .20939 .41251 .20249 .4019 Mtetra
.57 .621 .864 r
.20249 .4019 .20939 .41251 .21979 .41089 .21288 .40031 Mtetra
.58 .627 .863 r
.21288 .40031 .21979 .41089 .23026 .409 .22336 .39844 Mtetra
.591 .633 .862 r
.22336 .39844 .23026 .409 .24082 .40675 .23392 .39628 Mtetra
.602 .641 .862 r
.23392 .39628 .24082 .40675 .25146 .40407 .24456 .3938 Mtetra
.609 .649 .865 r
.24456 .3938 .25146 .40407 .26219 .40098 .25526 .39112 Mtetra
.613 .661 .873 r
.25526 .39112 .26219 .40098 .273 .39753 .26603 .38833 Mtetra
.609 .677 .89 r
.26603 .38833 .273 .39753 .28386 .39397 .27684 .38565 Mtetra
.597 .697 .913 r
.27684 .38565 .28386 .39397 .29476 .39051 .28768 .38322 Mtetra
.58 .723 .941 r
.28768 .38322 .29476 .39051 .30568 .38737 .29856 .38103 Mtetra
.557 .747 .966 r
.29856 .38103 .30568 .38737 .31662 .38467 .30948 .37907 Mtetra
.542 .768 .981 r
.30948 .37907 .31662 .38467 .3276 .38228 .32045 .37713 Mtetra
.538 .784 .989 r
.32045 .37713 .3276 .38228 .33862 .3801 .33149 .37509 Mtetra
.551 .795 .989 r
.33149 .37509 .33862 .3801 .3497 .37787 .34261 .37279 Mtetra
.574 .801 .985 r
.34261 .37279 .3497 .37787 .36085 .37541 .3538 .37012 Mtetra
.6 .804 .978 r
.3538 .37012 .36085 .37541 .37207 .37255 .36507 .36705 Mtetra
.624 .805 .969 r
.36507 .36705 .37207 .37255 .38338 .36919 .37641 .36354 Mtetra
.646 .808 .961 r
.37641 .36354 .38338 .36919 .39475 .36526 .38782 .35958 Mtetra
.665 .813 .955 r
.38782 .35958 .39475 .36526 .40619 .36078 .3993 .35519 Mtetra
.682 .822 .95 r
.3993 .35519 .40619 .36078 .4177 .35578 .41083 .35035 Mtetra
.697 .832 .948 r
.41083 .35035 .4177 .35578 .42926 .35038 .42243 .34509 Mtetra
.71 .841 .945 r
.42243 .34509 .42926 .35038 .44086 .34474 .43407 .33947 Mtetra
.719 .845 .942 r
.43407 .33947 .44086 .34474 .4525 .33904 .44576 .33358 Mtetra
.722 .84 .937 r
.44576 .33358 .4525 .33904 .46418 .33355 .45749 .32757 Mtetra
.72 .824 .929 r
.45749 .32757 .46418 .33355 .47589 .32837 .46925 .32157 Mtetra
.711 .797 .918 r
.46925 .32157 .47589 .32837 .48764 .32363 .48105 .31581 Mtetra
.699 .763 .902 r
.48105 .31581 .48764 .32363 .49943 .31921 .49288 .31029 Mtetra
.686 .73 .884 r
.49288 .31029 .49943 .31921 .51126 .31489 .50476 .30501 Mtetra
.678 .704 .867 r
.50476 .30501 .51126 .31489 .52315 .31046 .51667 .29983 Mtetra
.677 .687 .852 r
.51667 .29983 .52315 .31046 .53508 .30565 .52863 .29453 Mtetra
.679 .678 .843 r
.52863 .29453 .53508 .30565 .54706 .30042 .54063 .28902 Mtetra
.685 .676 .836 r
.54063 .28902 .54706 .30042 .55908 .29474 .55267 .28319 Mtetra
.691 .676 .831 r
.55267 .28319 .55908 .29474 .57113 .28869 .56475 .27704 Mtetra
.697 .678 .828 r
.56475 .27704 .57113 .28869 .58322 .28234 .57686 .2706 Mtetra
.701 .678 .825 r
.57686 .2706 .58322 .28234 .59534 .27575 .589 .26392 Mtetra
.704 .679 .822 r
.589 .26392 .59534 .27575 .60749 .26895 .60117 .25704 Mtetra
.707 .679 .82 r
.60117 .25704 .60749 .26895 .61966 .26197 .61337 .25 Mtetra
.709 .679 .819 r
.61337 .25 .61966 .26197 .63187 .25481 .6256 .24285 Mtetra
.711 .681 .819 r
.6256 .24285 .63187 .25481 .64409 .24749 .63786 .23561 Mtetra
.712 .684 .821 r
.63786 .23561 .64409 .24749 .65635 .24002 .65015 .22832 Mtetra
.714 .689 .824 r
.65015 .22832 .65635 .24002 .66862 .23244 .66247 .22102 Mtetra
.715 .695 .83 r
.66247 .22102 .66862 .23244 .68093 .22479 .67482 .21374 Mtetra
.718 .704 .837 r
.67482 .21374 .68093 .22479 .69326 .2171 .68721 .20649 Mtetra
.719 .716 .846 r
.68721 .20649 .69326 .2171 .70561 .20941 .69963 .19931 Mtetra
.722 .729 .856 r
.69963 .19931 .70561 .20941 .718 .20174 .71209 .19219 Mtetra
.725 .745 .868 r
.71209 .19219 .718 .20174 .73042 .19408 .72459 .18513 Mtetra
.728 .762 .88 r
.72459 .18513 .73042 .19408 .74288 .18646 .73713 .1781 Mtetra
.594 .734 .942 r
.06568 .40859 .07322 .41517 .08286 .41398 .07548 .40631 Mtetra
.596 .701 .917 r
.07548 .40631 .08286 .41398 .09254 .41286 .08532 .40409 Mtetra
.594 .67 .892 r
.08532 .40409 .09254 .41286 .10227 .41179 .0952 .40194 Mtetra
.591 .641 .869 r
.0952 .40194 .10227 .41179 .11204 .41079 .10512 .39988 Mtetra
.586 .616 .849 r
.10512 .39988 .11204 .41079 .12186 .40987 .11506 .39795 Mtetra
.581 .594 .83 r
.11506 .39795 .12186 .40987 .13173 .409 .12505 .3961 Mtetra
.577 .575 .814 r
.12505 .3961 .13173 .409 .14164 .40816 .13507 .39436 Mtetra
.574 .559 .8 r
.13507 .39436 .14164 .40816 .15162 .40732 .14514 .39267 Mtetra
.571 .546 .787 r
.14514 .39267 .15162 .40732 .16166 .40644 .15525 .39101 Mtetra
.571 .535 .777 r
.15525 .39101 .16166 .40644 .17176 .4055 .16542 .38933 Mtetra
.571 .527 .767 r
.16542 .38933 .17176 .4055 .18193 .40445 .17565 .3876 Mtetra
.572 .52 .759 r
.17565 .3876 .18193 .40445 .19217 .40326 .18595 .38576 Mtetra
.574 .515 .751 r
.18595 .38576 .19217 .40326 .20249 .4019 .19631 .38379 Mtetra
.577 .511 .744 r
.19631 .38379 .20249 .4019 .21288 .40031 .20674 .38165 Mtetra
.58 .508 .738 r
.20674 .38165 .21288 .40031 .22336 .39844 .21724 .37933 Mtetra
.581 .505 .734 r
.21724 .37933 .22336 .39844 .23392 .39628 .2278 .3769 Mtetra
.582 .503 .731 r
.2278 .3769 .23392 .39628 .24456 .3938 .23842 .3744 Mtetra
.58 .502 .732 r
.23842 .3744 .24456 .3938 .25526 .39112 .24909 .37198 Mtetra
.577 .503 .735 r
.24909 .37198 .25526 .39112 .26603 .38833 .25979 .36972 Mtetra
.573 .507 .742 r
.25979 .36972 .26603 .38833 .27684 .38565 .27054 .36764 Mtetra
.57 .511 .75 r
.27054 .36764 .27684 .38565 .28768 .38322 .28132 .36576 Mtetra
.572 .518 .757 r
.28132 .36576 .28768 .38322 .29856 .38103 .29217 .36383 Mtetra
.576 .524 .76 r
.29217 .36383 .29856 .38103 .30948 .37907 .30308 .36173 Mtetra
.584 .528 .758 r
.30308 .36173 .30948 .37907 .32045 .37713 .31408 .35928 Mtetra
.592 .528 .751 r
.31408 .35928 .32045 .37713 .33149 .37509 .32516 .3564 Mtetra
.598 .523 .741 r
.32516 .3564 .33149 .37509 .34261 .37279 .33631 .35314 Mtetra
.601 .517 .731 r
.33631 .35314 .34261 .37279 .3538 .37012 .34754 .34955 Mtetra
.602 .51 .722 r
.34754 .34955 .3538 .37012 .36507 .36705 .35882 .34576 Mtetra
.602 .505 .716 r
.35882 .34576 .36507 .36705 .37641 .36354 .37016 .34184 Mtetra
.602 .502 .713 r
.37016 .34184 .37641 .36354 .38782 .35958 .38155 .33784 Mtetra
.603 .503 .713 r
.38155 .33784 .38782 .35958 .3993 .35519 .393 .33376 Mtetra
.606 .507 .716 r
.393 .33376 .3993 .35519 .41083 .35035 .40449 .32956 Mtetra
.611 .516 .721 r
.40449 .32956 .41083 .35035 .42243 .34509 .41604 .32515 Mtetra
.62 .528 .728 r
.41604 .32515 .42243 .34509 .43407 .33947 .42765 .32041 Mtetra
.63 .541 .736 r
.42765 .32041 .43407 .33947 .44576 .33358 .43931 .31528 Mtetra
.641 .555 .742 r
.43931 .31528 .44576 .33358 .45749 .32757 .45102 .30971 Mtetra
.649 .564 .745 r
.45102 .30971 .45749 .32757 .46925 .32157 .46278 .30378 Mtetra
.653 .567 .746 r
.46278 .30378 .46925 .32157 .48105 .31581 .47458 .29766 Mtetra
.652 .563 .742 r
.47458 .29766 .48105 .31581 .49288 .31029 .48642 .2915 Mtetra
.645 .554 .737 r
.48642 .2915 .49288 .31029 .50476 .30501 .49829 .28552 Mtetra
.639 .544 .732 r
.49829 .28552 .50476 .30501 .51667 .29983 .5102 .27972 Mtetra
.633 .536 .727 r
.5102 .27972 .51667 .29983 .52863 .29453 .52214 .27409 Mtetra
.631 .532 .724 r
.52214 .27409 .52863 .29453 .54063 .28902 .53413 .26851 Mtetra
.53413 .26851 .54063 .28902 .55267 .28319 .54616 .26287 Mtetra
.634 .536 .726 r
.54616 .26287 .55267 .28319 .56475 .27704 .55823 .2571 Mtetra
.638 .542 .729 r
.55823 .2571 .56475 .27704 .57686 .2706 .57034 .25114 Mtetra
.643 .549 .733 r
.57034 .25114 .57686 .2706 .589 .26392 .58249 .245 Mtetra
.649 .557 .738 r
.58249 .245 .589 .26392 .60117 .25704 .59467 .23871 Mtetra
.653 .566 .744 r
.59467 .23871 .60117 .25704 .61337 .25 .60689 .2323 Mtetra
.658 .575 .75 r
.60689 .2323 .61337 .25 .6256 .24285 .61914 .22583 Mtetra
.662 .585 .758 r
.61914 .22583 .6256 .24285 .63786 .23561 .63144 .21932 Mtetra
.665 .596 .767 r
.63144 .21932 .63786 .23561 .65015 .22832 .64377 .21284 Mtetra
.669 .608 .778 r
.64377 .21284 .65015 .22832 .66247 .22102 .65614 .20641 Mtetra
.673 .622 .79 r
.65614 .20641 .66247 .22102 .67482 .21374 .66855 .20006 Mtetra
.677 .639 .805 r
.66855 .20006 .67482 .21374 .68721 .20649 .68101 .19381 Mtetra
.681 .658 .821 r
.68101 .19381 .68721 .20649 .69963 .19931 .69352 .18766 Mtetra
.685 .681 .84 r
.69352 .18766 .69963 .19931 .71209 .19219 .70608 .18161 Mtetra
.69 .707 .861 r
.70608 .18161 .71209 .19219 .72459 .18513 .71869 .17562 Mtetra
.695 .736 .883 r
.71869 .17562 .72459 .18513 .73713 .1781 .73134 .16968 Mtetra
.659 .752 .919 r
.05808 .40196 .06568 .40859 .07548 .40631 .0681 .39828 Mtetra
.653 .71 .89 r
.0681 .39828 .07548 .40631 .08532 .40409 .07815 .39465 Mtetra
.645 .673 .862 r
.07815 .39465 .08532 .40409 .0952 .40194 .08822 .39109 Mtetra
.636 .639 .836 r
.08822 .39109 .0952 .40194 .10512 .39988 .09833 .38763 Mtetra
.627 .609 .813 r
.09833 .38763 .10512 .39988 .11506 .39795 .10845 .38429 Mtetra
.618 .583 .792 r
.10845 .38429 .11506 .39795 .12505 .3961 .11861 .38106 Mtetra
.609 .56 .774 r
.11861 .38106 .12505 .3961 .13507 .39436 .12879 .37794 Mtetra
.602 .54 .757 r
.12879 .37794 .13507 .39436 .14514 .39267 .139 .37491 Mtetra
.597 .523 .743 r
.139 .37491 .14514 .39267 .15525 .39101 .14925 .37195 Mtetra
.592 .509 .73 r
.14925 .37195 .15525 .39101 .16542 .38933 .15955 .36901 Mtetra
.588 .497 .718 r
.15955 .36901 .16542 .38933 .17565 .3876 .16988 .36607 Mtetra
.585 .486 .708 r
.16988 .36607 .17565 .3876 .18595 .38576 .18027 .36312 Mtetra
.583 .478 .7 r
.18027 .36312 .18595 .38576 .19631 .38379 .19071 .36012 Mtetra
.581 .47 .693 r
.19071 .36012 .19631 .38379 .20674 .38165 .20119 .35712 Mtetra
.579 .464 .687 r
.20119 .35712 .20674 .38165 .21724 .37933 .21172 .35413 Mtetra
.576 .459 .683 r
.21172 .35413 .21724 .37933 .2278 .3769 .22229 .35123 Mtetra
.572 .455 .68 r
.22229 .35123 .2278 .3769 .23842 .3744 .23289 .34848 Mtetra
.568 .451 .679 r
.23289 .34848 .23842 .3744 .24909 .37198 .24352 .34593 Mtetra
.564 .448 .679 r
.24352 .34593 .24909 .37198 .25979 .36972 .25419 .34361 Mtetra
.562 .446 .679 r
.25419 .34361 .25979 .36972 .27054 .36764 .2649 .34141 Mtetra
.2649 .34141 .27054 .36764 .28132 .36576 .27567 .33922 Mtetra
.565 .447 .677 r
.27567 .33922 .28132 .36576 .29217 .36383 .28651 .33679 Mtetra
.57 .448 .674 r
.28651 .33679 .29217 .36383 .30308 .36173 .29743 .33397 Mtetra
.576 .449 .67 r
.29743 .33397 .30308 .36173 .31408 .35928 .30844 .33068 Mtetra
.581 .449 .666 r
.30844 .33068 .31408 .35928 .32516 .3564 .31952 .32691 Mtetra
.584 .447 .661 r
.31952 .32691 .32516 .3564 .33631 .35314 .33068 .32281 Mtetra
.584 .445 .657 r
.33068 .32281 .33631 .35314 .34754 .34955 .34189 .31852 Mtetra
.583 .441 .654 r
.34189 .31852 .34754 .34955 .35882 .34576 .35315 .31421 Mtetra
.581 .438 .652 r
.35315 .31421 .35882 .34576 .37016 .34184 .36445 .31 Mtetra
.578 .436 .651 r
.36445 .31 .37016 .34184 .38155 .33784 .37578 .30595 Mtetra
.576 .434 .651 r
.37578 .30595 .38155 .33784 .393 .33376 .38716 .30206 Mtetra
.575 .434 .652 r
.38716 .30206 .393 .33376 .40449 .32956 .39858 .29827 Mtetra
.575 .436 .655 r
.39858 .29827 .40449 .32956 .41604 .32515 .41005 .29447 Mtetra
.579 .441 .658 r
.41005 .29447 .41604 .32515 .42765 .32041 .42158 .29046 Mtetra
.585 .448 .661 r
.42158 .29046 .42765 .32041 .43931 .31528 .43316 .28613 Mtetra
.593 .457 .665 r
.43316 .28613 .43931 .31528 .45102 .30971 .44481 .28131 Mtetra
.601 .465 .669 r
.44481 .28131 .45102 .30971 .46278 .30378 .45652 .27601 Mtetra
.607 .472 .672 r
.45652 .27601 .46278 .30378 .47458 .29766 .46827 .27031 Mtetra
.612 .477 .674 r
.46827 .27031 .47458 .29766 .48642 .2915 .48007 .26436 Mtetra
.612 .479 .675 r
.48007 .26436 .48642 .2915 .49829 .28552 .4919 .25842 Mtetra
.611 .478 .676 r
.4919 .25842 .49829 .28552 .5102 .27972 .50377 .25258 Mtetra
.607 .476 .676 r
.50377 .25258 .5102 .27972 .52214 .27409 .51568 .24698 Mtetra
.605 .474 .677 r
.51568 .24698 .52214 .27409 .53413 .26851 .52763 .24157 Mtetra
.603 .474 .678 r
.52763 .24157 .53413 .26851 .54616 .26287 .53962 .23631 Mtetra
.603 .476 .681 r
.53962 .23631 .54616 .26287 .55823 .2571 .55167 .23114 Mtetra
.604 .481 .685 r
.55167 .23114 .55823 .2571 .57034 .25114 .56375 .22597 Mtetra
.606 .487 .69 r
.56375 .22597 .57034 .25114 .58249 .245 .57589 .22079 Mtetra
.61 .494 .697 r
.57589 .22079 .58249 .245 .59467 .23871 .58807 .21557 Mtetra
.614 .504 .705 r
.58807 .21557 .59467 .23871 .60689 .2323 .60029 .21032 Mtetra
.618 .514 .714 r
.60029 .21032 .60689 .2323 .61914 .22583 .61257 .20506 Mtetra
.622 .527 .725 r
.61257 .20506 .61914 .22583 .63144 .21932 .62489 .19982 Mtetra
.625 .54 .738 r
.62489 .19982 .63144 .21932 .64377 .21284 .63727 .19465 Mtetra
.629 .555 .752 r
.63727 .19465 .64377 .21284 .65614 .20641 .64969 .18956 Mtetra
.633 .573 .769 r
.64969 .18956 .65614 .20641 .66855 .20006 .66218 .18457 Mtetra
.637 .593 .788 r
.66218 .18457 .66855 .20006 .68101 .19381 .67472 .1797 Mtetra
.64 .615 .809 r
.67472 .1797 .68101 .19381 .69352 .18766 .68732 .17496 Mtetra
.644 .642 .834 r
.68732 .17496 .69352 .18766 .70608 .18161 .69999 .1703 Mtetra
.648 .673 .861 r
.69999 .1703 .70608 .18161 .71869 .17562 .71271 .16572 Mtetra
.651 .709 .89 r
.71271 .16572 .71869 .17562 .73134 .16968 .7255 .16118 Mtetra
.708 .762 .894 r
.05043 .39529 .05808 .40196 .0681 .39828 .06068 .39016 Mtetra
.698 .721 .867 r
.06068 .39016 .0681 .39828 .07815 .39465 .07095 .38507 Mtetra
.687 .684 .842 r
.07095 .38507 .07815 .39465 .08822 .39109 .08123 .38005 Mtetra
.674 .651 .819 r
.08123 .38005 .08822 .39109 .09833 .38763 .09154 .37511 Mtetra
.662 .621 .798 r
.09154 .37511 .09833 .38763 .10845 .38429 .10186 .3703 Mtetra
.651 .595 .779 r
.10186 .3703 .10845 .38429 .11861 .38106 .1122 .3656 Mtetra
.64 .572 .762 r
.1122 .3656 .11861 .38106 .12879 .37794 .12256 .36102 Mtetra
.631 .551 .746 r
.12256 .36102 .12879 .37794 .139 .37491 .13294 .35654 Mtetra
.623 .533 .732 r
.13294 .35654 .139 .37491 .14925 .37195 .14335 .35215 Mtetra
.616 .517 .719 r
.14335 .35215 .14925 .37195 .15955 .36901 .15378 .34782 Mtetra
.61 .503 .708 r
.15378 .34782 .15955 .36901 .16988 .36607 .16424 .34355 Mtetra
.604 .491 .698 r
.16424 .34355 .16988 .36607 .18027 .36312 .17474 .33936 Mtetra
.599 .481 .69 r
.17474 .33936 .18027 .36312 .19071 .36012 .18526 .33524 Mtetra
.593 .471 .683 r
.18526 .33524 .19071 .36012 .20119 .35712 .19581 .33124 Mtetra
.588 .463 .677 r
.19581 .33124 .20119 .35712 .21172 .35413 .20638 .32742 Mtetra
.583 .456 .672 r
.20638 .32742 .21172 .35413 .22229 .35123 .21697 .32382 Mtetra
.577 .449 .669 r
.21697 .32382 .22229 .35123 .23289 .34848 .22759 .32047 Mtetra
.573 .443 .666 r
.22759 .32047 .23289 .34848 .24352 .34593 .23823 .31734 Mtetra
.569 .439 .663 r
.23823 .31734 .24352 .34593 .25419 .34361 .2489 .31437 Mtetra
.568 .436 .66 r
.2489 .31437 .25419 .34361 .2649 .34141 .25962 .31138 Mtetra
.569 .433 .657 r
.25962 .31138 .2649 .34141 .27567 .33922 .27041 .30824 Mtetra
.572 .432 .652 r
.27041 .30824 .27567 .33922 .28651 .33679 .28127 .30478 Mtetra
.575 .431 .648 r
.28127 .30478 .28651 .33679 .29743 .33397 .29221 .30091 Mtetra
.578 .429 .644 r
.29221 .30091 .29743 .33397 .30844 .33068 .30322 .29669 Mtetra
.58 .428 .64 r
.30322 .29669 .30844 .33068 .31952 .32691 .31429 .29215 Mtetra
.58 .426 .637 r
.31429 .29215 .31952 .32691 .33068 .32281 .32542 .28746 Mtetra
.579 .424 .635 r
.32542 .28746 .33068 .32281 .34189 .31852 .33658 .28276 Mtetra
.577 .421 .634 r
.33658 .28276 .34189 .31852 .35315 .31421 .34778 .27818 Mtetra
.574 .419 .633 r
.34778 .27818 .35315 .31421 .36445 .31 .35902 .27381 Mtetra
.57 .416 .633 r
.35902 .27381 .36445 .31 .37578 .30595 .37028 .26971 Mtetra
.567 .414 .633 r
.37028 .26971 .37578 .30595 .38716 .30206 .38158 .26587 Mtetra
.565 .412 .633 r
.38158 .26587 .38716 .30206 .39858 .29827 .39292 .26224 Mtetra
.563 .412 .634 r
.39292 .26224 .39858 .29827 .41005 .29447 .4043 .25874 Mtetra
.564 .413 .635 r
.4043 .25874 .41005 .29447 .42158 .29046 .41574 .25522 Mtetra
.566 .417 .637 r
.41574 .25522 .42158 .29046 .43316 .28613 .42723 .25155 Mtetra
.571 .422 .64 r
.42723 .25155 .43316 .28613 .44481 .28131 .43879 .24757 Mtetra
.576 .428 .644 r
.43879 .24757 .44481 .28131 .45652 .27601 .45041 .24322 Mtetra
.583 .436 .648 r
.45041 .24322 .45652 .27601 .46827 .27031 .46208 .23846 Mtetra
.588 .443 .652 r
.46208 .23846 .46827 .27031 .48007 .26436 .47381 .23338 Mtetra
.592 .449 .656 r
.47381 .23338 .48007 .26436 .4919 .25842 .48558 .22813 Mtetra
.594 .453 .659 r
.48558 .22813 .4919 .25842 .50377 .25258 .4974 .22286 Mtetra
.593 .455 .662 r
.4974 .22286 .50377 .25258 .51568 .24698 .50925 .21776 Mtetra
.591 .456 .665 r
.50925 .21776 .51568 .24698 .52763 .24157 .52116 .21286 Mtetra
.589 .457 .668 r
.52116 .21286 .52763 .24157 .53962 .23631 .53311 .20822 Mtetra
.587 .459 .672 r
.53311 .20822 .53962 .23631 .55167 .23114 .54511 .20381 Mtetra
.587 .462 .677 r
.54511 .20381 .55167 .23114 .56375 .22597 .55717 .19956 Mtetra
.587 .467 .683 r
.55717 .19956 .56375 .22597 .57589 .22079 .56928 .19544 Mtetra
.588 .474 .691 r
.56928 .19544 .57589 .22079 .58807 .21557 .58145 .19141 Mtetra
.59 .482 .7 r
.58145 .19141 .58807 .21557 .60029 .21032 .59368 .18744 Mtetra
.592 .492 .71 r
.59368 .18744 .60029 .21032 .61257 .20506 .60597 .18352 Mtetra
.594 .504 .722 r
.60597 .18352 .61257 .20506 .62489 .19982 .61832 .17968 Mtetra
.597 .518 .736 r
.61832 .17968 .62489 .19982 .63727 .19465 .63074 .17593 Mtetra
.599 .533 .752 r
.63074 .17593 .63727 .19465 .64969 .18956 .64322 .17227 Mtetra
.6 .55 .77 r
.64322 .17227 .64969 .18956 .66218 .18457 .65577 .16874 Mtetra
.602 .57 .79 r
.65577 .16874 .66218 .18457 .67472 .1797 .66839 .16532 Mtetra
.603 .592 .814 r
.66839 .16532 .67472 .1797 .68732 .17496 .68108 .16203 Mtetra
.603 .619 .84 r
.68108 .16203 .68732 .17496 .69999 .1703 .69385 .15883 Mtetra
.603 .65 .869 r
.69385 .15883 .69999 .1703 .71271 .16572 .7067 .1557 Mtetra
.601 .685 .901 r
.7067 .1557 .71271 .16572 .7255 .16118 .71961 .15261 Mtetra
.74 .766 .874 r
.04273 .38856 .05043 .39529 .06068 .39016 .05317 .38222 Mtetra
.73 .734 .854 r
.05317 .38222 .06068 .39016 .07095 .38507 .06363 .37591 Mtetra
.718 .704 .836 r
.06363 .37591 .07095 .38507 .08123 .38005 .07411 .36968 Mtetra
.706 .676 .818 r
.07411 .36968 .08123 .38005 .09154 .37511 .08459 .36353 Mtetra
.694 .651 .802 r
.08459 .36353 .09154 .37511 .10186 .3703 .09509 .35752 Mtetra
.683 .628 .787 r
.09509 .35752 .10186 .3703 .1122 .3656 .10559 .35163 Mtetra
.672 .606 .773 r
.10559 .35163 .1122 .3656 .12256 .36102 .1161 .34588 Mtetra
.662 .587 .761 r
.1161 .34588 .12256 .36102 .13294 .35654 .12661 .34026 Mtetra
.653 .57 .749 r
.12661 .34026 .13294 .35654 .14335 .35215 .13715 .33477 Mtetra
.645 .555 .738 r
.13715 .33477 .14335 .35215 .15378 .34782 .1477 .3294 Mtetra
.638 .542 .729 r
.1477 .3294 .15378 .34782 .16424 .34355 .15826 .32413 Mtetra
.631 .53 .721 r
.15826 .32413 .16424 .34355 .17474 .33936 .16884 .31898 Mtetra
.625 .519 .713 r
.16884 .31898 .17474 .33936 .18526 .33524 .17945 .31394 Mtetra
.62 .509 .706 r
.17945 .31394 .18526 .33524 .19581 .33124 .19007 .30901 Mtetra
.614 .5 .7 r
.19007 .30901 .19581 .33124 .20638 .32742 .20072 .30418 Mtetra
.609 .491 .693 r
.20072 .30418 .20638 .32742 .21697 .32382 .2114 .29944 Mtetra
.604 .481 .685 r
.2114 .29944 .21697 .32382 .22759 .32047 .22211 .29476 Mtetra
.6 .472 .677 r
.22211 .29476 .22759 .32047 .23823 .31734 .23285 .29008 Mtetra
.597 .462 .669 r
.23285 .29008 .23823 .31734 .2489 .31437 .24364 .28534 Mtetra
.594 .453 .659 r
.24364 .28534 .2489 .31437 .25962 .31138 .25448 .28047 Mtetra
.591 .445 .651 r
.25448 .28047 .25962 .31138 .27041 .30824 .26536 .27546 Mtetra
.588 .436 .643 r
.26536 .27546 .27041 .30824 .28127 .30478 .27629 .27036 Mtetra
.585 .429 .637 r
.27629 .27036 .28127 .30478 .29221 .30091 .28726 .26525 Mtetra
.581 .423 .632 r
.28726 .26525 .29221 .30091 .30322 .29669 .29825 .26026 Mtetra
.577 .419 .63 r
.29825 .26026 .30322 .29669 .31429 .29215 .30927 .25546 Mtetra
.574 .416 .629 r
.30927 .25546 .31429 .29215 .32542 .28746 .32032 .25086 Mtetra
.572 .415 .629 r
.32032 .25086 .32542 .28746 .33658 .28276 .33139 .24645 Mtetra
.571 .415 .631 r
.33139 .24645 .33658 .28276 .34778 .27818 .3425 .24216 Mtetra
.571 .416 .632 r
.3425 .24216 .34778 .27818 .35902 .27381 .35365 .23795 Mtetra
.57 .416 .633 r
.35365 .23795 .35902 .27381 .37028 .26971 .36484 .23379 Mtetra
.569 .415 .633 r
.36484 .23379 .37028 .26971 .38158 .26587 .37608 .22968 Mtetra
.568 .414 .632 r
.37608 .22968 .38158 .26587 .39292 .26224 .38736 .22566 Mtetra
.566 .411 .631 r
.38736 .22566 .39292 .26224 .4043 .25874 .39868 .22175 Mtetra
.563 .408 .629 r
.39868 .22175 .4043 .25874 .41574 .25522 .41005 .21804 Mtetra
.56 .406 .629 r
.41005 .21804 .41574 .25522 .42723 .25155 .42146 .21452 Mtetra
.558 .405 .63 r
.42146 .21452 .42723 .25155 .43879 .24757 .43291 .21121 Mtetra
.558 .407 .632 r
.43291 .21121 .43879 .24757 .45041 .24322 .44442 .20801 Mtetra
.559 .411 .637 r
.44442 .20801 .45041 .24322 .46208 .23846 .45599 .2048 Mtetra
.562 .418 .643 r
.45599 .2048 .46208 .23846 .47381 .23338 .46762 .20151 Mtetra
.567 .428 .652 r
.46762 .20151 .47381 .23338 .48558 .22813 .4793 .19807 Mtetra
.571 .438 .66 r
.4793 .19807 .48558 .22813 .4974 .22286 .49105 .19451 Mtetra
.575 .448 .67 r
.49105 .19451 .4974 .22286 .50925 .21776 .50285 .19089 Mtetra
.578 .457 .679 r
.50285 .19089 .50925 .21776 .52116 .21286 .51471 .18726 Mtetra
.58 .466 .688 r
.51471 .18726 .52116 .21286 .53311 .20822 .52663 .18369 Mtetra
.581 .473 .696 r
.52663 .18369 .53311 .20822 .54511 .20381 .5386 .18021 Mtetra
.581 .479 .703 r
.5386 .18021 .54511 .20381 .55717 .19956 .55064 .17684 Mtetra
.581 .485 .711 r
.55064 .17684 .55717 .19956 .56928 .19544 .56274 .17358 Mtetra
.581 .492 .719 r
.56274 .17358 .56928 .19544 .58145 .19141 .57491 .17044 Mtetra
.58 .5 .728 r
.57491 .17044 .58145 .19141 .59368 .18744 .58714 .16741 Mtetra
.58 .508 .738 r
.58714 .16741 .59368 .18744 .60597 .18352 .59944 .16449 Mtetra
.58 .518 .75 r
.59944 .16449 .60597 .18352 .61832 .17968 .61181 .1617 Mtetra
.579 .529 .763 r
.61181 .1617 .61832 .17968 .63074 .17593 .62426 .15904 Mtetra
.578 .542 .778 r
.62426 .15904 .63074 .17593 .64322 .17227 .63678 .15652 Mtetra
.576 .557 .796 r
.63678 .15652 .64322 .17227 .65577 .16874 .64939 .15414 Mtetra
.574 .574 .815 r
.64939 .15414 .65577 .16874 .66839 .16532 .66208 .1519 Mtetra
.57 .593 .836 r
.66208 .1519 .66839 .16532 .68108 .16203 .67485 .1498 Mtetra
.566 .615 .86 r
.67485 .1498 .68108 .16203 .69385 .15883 .6877 .14779 Mtetra
.561 .64 .886 r
.6877 .14779 .69385 .15883 .7067 .1557 .70065 .14586 Mtetra
.554 .668 .913 r
.70065 .14586 .7067 .1557 .71961 .15261 .71368 .14397 Mtetra
.759 .768 .86 r
.03496 .38178 .04273 .38856 .05317 .38222 .04556 .37458 Mtetra
.75 .746 .848 r
.04556 .37458 .05317 .38222 .06363 .37591 .05617 .36743 Mtetra
.741 .725 .836 r
.05617 .36743 .06363 .37591 .07411 .36968 .06679 .36034 Mtetra
.732 .705 .825 r
.06679 .36034 .07411 .36968 .08459 .36353 .07741 .35336 Mtetra
.722 .686 .815 r
.07741 .35336 .08459 .36353 .09509 .35752 .08803 .34651 Mtetra
.713 .669 .805 r
.08803 .34651 .09509 .35752 .10559 .35163 .09866 .33979 Mtetra
.703 .652 .796 r
.09866 .33979 .10559 .35163 .1161 .34588 .10928 .33323 Mtetra
.694 .636 .787 r
.10928 .33323 .1161 .34588 .12661 .34026 .11991 .32682 Mtetra
.685 .621 .778 r
.11991 .32682 .12661 .34026 .13715 .33477 .13054 .32057 Mtetra
.677 .607 .77 r
.13054 .32057 .13715 .33477 .1477 .3294 .14118 .31447 Mtetra
.669 .595 .763 r
.14118 .31447 .1477 .3294 .15826 .32413 .15183 .30852 Mtetra
.663 .584 .756 r
.15183 .30852 .15826 .32413 .16884 .31898 .16249 .30269 Mtetra
.657 .573 .75 r
.16249 .30269 .16884 .31898 .17945 .31394 .17316 .29697 Mtetra
.652 .564 .743 r
.17316 .29697 .17945 .31394 .19007 .30901 .18386 .2913 Mtetra
.647 .555 .736 r
.18386 .2913 .19007 .30901 .20072 .30418 .19459 .28563 Mtetra
.644 .546 .728 r
.19459 .28563 .20072 .30418 .2114 .29944 .20536 .27989 Mtetra
.642 .536 .719 r
.20536 .27989 .2114 .29944 .22211 .29476 .21617 .27399 Mtetra
.64 .526 .709 r
.21617 .27399 .22211 .29476 .23285 .29008 .22703 .26788 Mtetra
.637 .515 .698 r
.22703 .26788 .23285 .29008 .24364 .28534 .23794 .26154 Mtetra
.632 .503 .687 r
.23794 .26154 .24364 .28534 .25448 .28047 .2489 .25503 Mtetra
.627 .491 .677 r
.2489 .25503 .25448 .28047 .26536 .27546 .25988 .24846 Mtetra
.619 .478 .668 r
.25988 .24846 .26536 .27546 .27629 .27036 .27088 .24208 Mtetra
.61 .467 .662 r
.27088 .24208 .27629 .27036 .28726 .26525 .28187 .23607 Mtetra
.6 .456 .658 r
.28187 .23607 .28726 .26525 .29825 .26026 .29285 .23062 Mtetra
.59 .448 .656 r
.29285 .23062 .29825 .26026 .30927 .25546 .30382 .22578 Mtetra
.584 .444 .657 r
.30382 .22578 .30927 .25546 .32032 .25086 .3148 .22142 Mtetra
.579 .442 .658 r
.3148 .22142 .32032 .25086 .33139 .24645 .3258 .2174 Mtetra
.579 .444 .661 r
.3258 .2174 .33139 .24645 .3425 .24216 .33684 .21345 Mtetra
.581 .446 .663 r
.33684 .21345 .3425 .24216 .35365 .23795 .34793 .20942 Mtetra
.584 .449 .664 r
.34793 .20942 .35365 .23795 .36484 .23379 .35908 .20522 Mtetra
.586 .451 .664 r
.35908 .20522 .36484 .23379 .37608 .22968 .37028 .20083 Mtetra
.586 .45 .662 r
.37028 .20083 .37608 .22968 .38736 .22566 .38153 .19637 Mtetra
.584 .447 .66 r
.38153 .19637 .38736 .22566 .39868 .22175 .39282 .19198 Mtetra
.578 .441 .658 r
.39282 .19198 .39868 .22175 .41005 .21804 .40415 .18793 Mtetra
.571 .435 .657 r
.40415 .18793 .41005 .21804 .42146 .21452 .41551 .18435 Mtetra
.562 .429 .658 r
.41551 .18435 .42146 .21452 .43291 .21121 .4269 .1814 Mtetra
.554 .426 .66 r
.4269 .1814 .43291 .21121 .44442 .20801 .43833 .17901 Mtetra
.549 .426 .665 r
.43833 .17901 .44442 .20801 .45599 .2048 .44981 .17701 Mtetra
.548 .431 .673 r
.44981 .17701 .45599 .2048 .46762 .20151 .46136 .17521 Mtetra
.55 .441 .682 r
.46136 .17521 .46762 .20151 .4793 .19807 .47298 .17334 Mtetra
.555 .453 .694 r
.47298 .17334 .4793 .19807 .49105 .19451 .48467 .17131 Mtetra
.562 .468 .706 r
.48467 .17131 .49105 .19451 .50285 .19089 .49643 .16905 Mtetra
.568 .482 .718 r
.49643 .16905 .50285 .19089 .51471 .18726 .50826 .16658 Mtetra
.573 .495 .729 r
.50826 .16658 .51471 .18726 .52663 .18369 .52016 .16395 Mtetra
.576 .506 .739 r
.52016 .16395 .52663 .18369 .5386 .18021 .53212 .16125 Mtetra
.578 .515 .748 r
.53212 .16125 .5386 .18021 .55064 .17684 .54415 .15855 Mtetra
.578 .523 .757 r
.54415 .15855 .55064 .17684 .56274 .17358 .55625 .15591 Mtetra
.576 .529 .765 r
.55625 .15591 .56274 .17358 .57491 .17044 .56842 .15338 Mtetra
.574 .536 .774 r
.56842 .15338 .57491 .17044 .58714 .16741 .58066 .15098 Mtetra
.571 .543 .784 r
.58066 .15098 .58714 .16741 .59944 .16449 .59298 .14873 Mtetra
.568 .551 .795 r
.59298 .14873 .59944 .16449 .61181 .1617 .60537 .14665 Mtetra
.564 .56 .807 r
.60537 .14665 .61181 .1617 .62426 .15904 .61785 .14473 Mtetra
.559 .57 .821 r
.61785 .14473 .62426 .15904 .63678 .15652 .63041 .14297 Mtetra
.554 .581 .836 r
.63041 .14297 .63678 .15652 .64939 .15414 .64306 .14138 Mtetra
.548 .594 .852 r
.64306 .14138 .64939 .15414 .66208 .1519 .6558 .13993 Mtetra
.541 .607 .869 r
.6558 .13993 .66208 .1519 .67485 .1498 .66863 .13862 Mtetra
.533 .623 .887 r
.66863 .13862 .67485 .1498 .6877 .14779 .68156 .13743 Mtetra
.524 .639 .905 r
.68156 .13743 .6877 .14779 .70065 .14586 .69458 .13631 Mtetra
.515 .658 .924 r
.69458 .13631 .70065 .14586 .71368 .14397 .70769 .13525 Mtetra
.766 .768 .855 r
.02714 .37496 .03496 .38178 .04556 .37458 .03782 .36739 Mtetra
.761 .76 .851 r
.03782 .36739 .04556 .37458 .05617 .36743 .04851 .3599 Mtetra
.756 .751 .848 r
.04851 .3599 .05617 .36743 .06679 .36034 .0592 .35249 Mtetra
.751 .744 .845 r
.0592 .35249 .06679 .36034 .07741 .35336 .06989 .34518 Mtetra
.746 .736 .843 r
.06989 .34518 .07741 .35336 .08803 .34651 .08058 .338 Mtetra
.74 .728 .84 r
.08058 .338 .08803 .34651 .09866 .33979 .09128 .33096 Mtetra
.734 .72 .837 r
.09128 .33096 .09866 .33979 .10928 .33323 .10197 .32406 Mtetra
.728 .712 .835 r
.10197 .32406 .10928 .33323 .11991 .32682 .11266 .31731 Mtetra
.722 .703 .832 r
.11266 .31731 .11991 .32682 .13054 .32057 .12335 .31071 Mtetra
.716 .695 .829 r
.12335 .31071 .13054 .32057 .14118 .31447 .13405 .30427 Mtetra
.71 .687 .826 r
.13405 .30427 .14118 .31447 .15183 .30852 .14476 .29797 Mtetra
.704 .679 .822 r
.14476 .29797 .15183 .30852 .16249 .30269 .15547 .2918 Mtetra
.7 .671 .819 r
.15547 .2918 .16249 .30269 .17316 .29697 .1662 .28572 Mtetra
.696 .664 .814 r
.1662 .28572 .17316 .29697 .18386 .2913 .17696 .27968 Mtetra
.694 .657 .809 r
.17696 .27968 .18386 .2913 .19459 .28563 .18774 .2736 Mtetra
.693 .65 .802 r
.18774 .2736 .19459 .28563 .20536 .27989 .19857 .2674 Mtetra
.694 .643 .795 r
.19857 .2674 .20536 .27989 .21617 .27399 .20944 .261 Mtetra
.694 .636 .787 r
.20944 .261 .21617 .27399 .22703 .26788 .22037 .25438 Mtetra
.695 .629 .779 r
.22037 .25438 .22703 .26788 .23794 .26154 .23134 .24752 Mtetra
.693 .622 .772 r
.23134 .24752 .23794 .26154 .2489 .25503 .24234 .24057 Mtetra
.689 .614 .767 r
.24234 .24057 .2489 .25503 .25988 .24846 .25336 .23364 Mtetra
.681 .606 .766 r
.25336 .23364 .25988 .24846 .27088 .24208 .26438 .22703 Mtetra
.67 .598 .766 r
.26438 .22703 .27088 .24208 .28187 .23607 .27539 .22091 Mtetra
.656 .59 .769 r
.27539 .22091 .28187 .23607 .29285 .23062 .28637 .21544 Mtetra
.641 .583 .774 r
.28637 .21544 .29285 .23062 .30382 .22578 .29734 .21066 Mtetra
.63 .578 .778 r
.29734 .21066 .30382 .22578 .3148 .22142 .30831 .20637 Mtetra
.623 .576 .781 r
.30831 .20637 .3148 .22142 .3258 .2174 .3193 .20242 Mtetra
.621 .577 .783 r
.3193 .20242 .3258 .2174 .33684 .21345 .33034 .19851 Mtetra
.624 .579 .784 r
.33034 .19851 .33684 .21345 .34793 .20942 .34143 .1945 Mtetra
.629 .583 .783 r
.34143 .1945 .34793 .20942 .35908 .20522 .35258 .19026 Mtetra
.634 .585 .782 r
.35258 .19026 .35908 .20522 .37028 .20083 .36379 .18578 Mtetra
.636 .586 .781 r
.36379 .18578 .37028 .20083 .38153 .19637 .37505 .1812 Mtetra
.634 .583 .78 r
.37505 .1812 .38153 .19637 .39282 .19198 .38635 .17666 Mtetra
.625 .577 .78 r
.38635 .17666 .39282 .19198 .40415 .18793 .39768 .17246 Mtetra
.613 .569 .781 r
.39768 .17246 .40415 .18793 .41551 .18435 .40904 .16876 Mtetra
.595 .559 .783 r
.40904 .16876 .41551 .18435 .4269 .1814 .42043 .16575 Mtetra
.578 .549 .786 r
.42043 .16575 .4269 .1814 .43833 .17901 .43186 .16339 Mtetra
.564 .542 .789 r
.43186 .16339 .43833 .17901 .44981 .17701 .44334 .16155 Mtetra
.555 .54 .793 r
.44334 .16155 .44981 .17701 .46136 .17521 .45487 .16002 Mtetra
.553 .544 .798 r
.45487 .16002 .46136 .17521 .47298 .17334 .46648 .15853 Mtetra
.556 .552 .805 r
.46648 .15853 .47298 .17334 .48467 .17131 .47817 .15695 Mtetra
.563 .564 .812 r
.47817 .15695 .48467 .17131 .49643 .16905 .48993 .15514 Mtetra
.57 .576 .82 r
.48993 .15514 .49643 .16905 .50826 .16658 .50176 .1531 Mtetra
.576 .587 .827 r
.50176 .1531 .50826 .16658 .52016 .16395 .51366 .15087 Mtetra
.58 .597 .835 r
.51366 .15087 .52016 .16395 .53212 .16125 .52564 .14851 Mtetra
.58 .605 .842 r
.52564 .14851 .53212 .16125 .54415 .15855 .53768 .14613 Mtetra
.579 .611 .849 r
.53768 .14613 .54415 .15855 .55625 .15591 .5498 .14378 Mtetra
.575 .616 .856 r
.5498 .14378 .55625 .15591 .56842 .15338 .56198 .14153 Mtetra
.571 .621 .863 r
.56198 .14153 .56842 .15338 .58066 .15098 .57425 .1394 Mtetra
.564 .624 .87 r
.57425 .1394 .58066 .15098 .59298 .14873 .58659 .13744 Mtetra
.557 .628 .878 r
.58659 .13744 .59298 .14873 .60537 .14665 .59901 .13563 Mtetra
.55 .632 .886 r
.59901 .13563 .60537 .14665 .61785 .14473 .61152 .134 Mtetra
.542 .636 .893 r
.61152 .134 .61785 .14473 .63041 .14297 .62411 .13252 Mtetra
.534 .64 .901 r
.62411 .13252 .63041 .14297 .64306 .14138 .6368 .13119 Mtetra
.525 .644 .908 r
.6368 .13119 .64306 .14138 .6558 .13993 .64958 .13002 Mtetra
.517 .647 .915 r
.64958 .13002 .6558 .13993 .66863 .13862 .66245 .12897 Mtetra
.509 .652 .922 r
.66245 .12897 .66863 .13862 .68156 .13743 .67542 .12805 Mtetra
.501 .656 .929 r
.67542 .12805 .68156 .13743 .69458 .13631 .68849 .12722 Mtetra
.493 .662 .937 r
.68849 .12722 .69458 .13631 .70769 .13525 .70165 .12647 Mtetra
.759 .768 .86 r
.01926 .36808 .02714 .37496 .03782 .36739 .02993 .3608 Mtetra
.759 .777 .867 r
.02993 .3608 .03782 .36739 .04851 .3599 .04059 .35363 Mtetra
.76 .787 .875 r
.04059 .35363 .04851 .3599 .0592 .35249 .05126 .34657 Mtetra
.76 .798 .884 r
.05126 .34657 .0592 .35249 .06989 .34518 .06193 .33961 Mtetra
.76 .809 .892 r
.06193 .33961 .06989 .34518 .08058 .338 .07261 .33276 Mtetra
.759 .82 .9 r
.07261 .33276 .08058 .338 .09128 .33096 .08329 .32602 Mtetra
.757 .83 .908 r
.08329 .32602 .09128 .33096 .10197 .32406 .09398 .31938 Mtetra
.755 .84 .916 r
.09398 .31938 .10197 .32406 .11266 .31731 .10468 .31285 Mtetra
.753 .848 .922 r
.10468 .31285 .11266 .31731 .12335 .31071 .11539 .30642 Mtetra
.749 .854 .928 r
.11539 .30642 .12335 .31071 .13405 .30427 .12611 .3001 Mtetra
.746 .859 .932 r
.12611 .3001 .13405 .30427 .14476 .29797 .13684 .29388 Mtetra
.742 .863 .936 r
.13684 .29388 .14476 .29797 .15547 .2918 .14759 .28777 Mtetra
.737 .865 .94 r
.14759 .28777 .15547 .2918 .1662 .28572 .15835 .28176 Mtetra
.733 .868 .944 r
.15835 .28176 .1662 .28572 .17696 .27968 .16912 .27585 Mtetra
.728 .874 .949 r
.16912 .27585 .17696 .27968 .18774 .2736 .17991 .27005 Mtetra
.722 .883 .955 r
.17991 .27005 .18774 .2736 .19857 .2674 .19073 .26435 Mtetra
.712 .899 .963 r
.19073 .26435 .19857 .2674 .20944 .261 .20156 .25875 Mtetra
.695 .921 .969 r
.20156 .25875 .20944 .261 .22037 .25438 .21241 .25326 Mtetra
.658 .942 .962 r
.21241 .25326 .22037 .25438 .23134 .24752 .22329 .24787 Mtetra
.583 .941 .917 r
.22329 .24787 .23134 .24752 .24234 .24057 .23419 .24258 Mtetra
.459 .885 .81 r
.23419 .24258 .24234 .24057 .25336 .23364 .24512 .23739 Mtetra
.304 .772 .649 r
.24512 .23739 .25336 .23364 .26438 .22703 .25608 .23231 Mtetra
0 0 0 r
.25608 .23231 .26438 .22703 .27539 .22091 .26706 .22732 Mtetra
.26706 .22732 .27539 .22091 .28637 .21544 .27807 .22244 Mtetra
.27807 .22244 .28637 .21544 .29734 .21066 .28912 .21766 Mtetra
.28912 .21766 .29734 .21066 .30831 .20637 .30019 .21299 Mtetra
.30019 .21299 .30831 .20637 .3193 .20242 .31131 .20841 Mtetra
.31131 .20841 .3193 .20242 .33034 .19851 .32246 .20394 Mtetra
.32246 .20394 .33034 .19851 .34143 .1945 .33364 .19957 Mtetra
.33364 .19957 .34143 .1945 .35258 .19026 .34487 .1953 Mtetra
.34487 .1953 .35258 .19026 .36379 .18578 .35613 .19114 Mtetra
.35613 .19114 .36379 .18578 .37505 .1812 .36744 .18707 Mtetra
.36744 .18707 .37505 .1812 .38635 .17666 .37879 .18312 Mtetra
.042 0 0 r
.37879 .18312 .38635 .17666 .39768 .17246 .39019 .17926 Mtetra
.07 0 0 r
.39019 .17926 .39768 .17246 .40904 .16876 .40164 .17551 Mtetra
.077 0 0 r
.40164 .17551 .40904 .16876 .42043 .16575 .41313 .17186 Mtetra
.056 0 0 r
.41313 .17186 .42043 .16575 .43186 .16339 .42468 .16831 Mtetra
.001 0 0 r
.42468 .16831 .43186 .16339 .44334 .16155 .43628 .16487 Mtetra
0 0 0 r
.43628 .16487 .44334 .16155 .45487 .16002 .44793 .16153 Mtetra
.221 .738 .722 r
.44793 .16153 .45487 .16002 .46648 .15853 .45964 .1583 Mtetra
.346 .823 .869 r
.45964 .1583 .46648 .15853 .47817 .15695 .47141 .15518 Mtetra
.44 .856 .956 r
.47141 .15518 .47817 .15695 .48993 .15514 .48324 .15216 Mtetra
.492 .854 .99 r
.48324 .15216 .48993 .15514 .50176 .1531 .49513 .14924 Mtetra
.517 .839 .999 r
.49513 .14924 .50176 .1531 .51366 .15087 .50708 .14644 Mtetra
.526 .825 .999 r
.50708 .14644 .51366 .15087 .52564 .14851 .5191 .14374 Mtetra
.527 .815 .998 r
.5191 .14374 .52564 .14851 .53768 .14613 .53119 .14115 Mtetra
.524 .807 .997 r
.53119 .14115 .53768 .14613 .5498 .14378 .54335 .13866 Mtetra
.519 .801 .997 r
.54335 .13866 .5498 .14378 .56198 .14153 .55558 .13629 Mtetra
.514 .795 .997 r
.55558 .13629 .56198 .14153 .57425 .1394 .56789 .13402 Mtetra
.509 .789 .996 r
.56789 .13402 .57425 .1394 .58659 .13744 .58027 .13187 Mtetra
.505 .781 .994 r
.58027 .13187 .58659 .13744 .59901 .13563 .59273 .12983 Mtetra
.503 .772 .992 r
.59273 .12983 .59901 .13563 .61152 .134 .60528 .1279 Mtetra
.501 .762 .989 r
.60528 .1279 .61152 .134 .62411 .13252 .6179 .12608 Mtetra
.501 .751 .985 r
.6179 .12608 .62411 .13252 .6368 .13119 .63062 .12438 Mtetra
.501 .739 .979 r
.63062 .12438 .6368 .13119 .64958 .13002 .64342 .12279 Mtetra
.501 .726 .973 r
.64342 .12279 .64958 .13002 .66245 .12897 .65631 .12132 Mtetra
.501 .712 .966 r
.65631 .12132 .66245 .12897 .67542 .12805 .6693 .11996 Mtetra
.501 .699 .958 r
.6693 .11996 .67542 .12805 .68849 .12722 .68238 .11873 Mtetra
.5 .686 .95 r
.68238 .11873 .68849 .12722 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Jooooo`;oP;Kg1?n0/_D4ogn_l`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0DOooool0063ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Mooooo`?o00000_ooool00ol0003ooooooooo
o`1?ooooo`;oP;gj1On0^OT5oh2fm`CoP;;e0omo[o<00ol0003oOjocooooo`0Eooooo`03o`000?oo
oooooooo053ooooo001Pooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0001cooooo0_l0
001?ooooo`?oP<?m1?n0`?`4oh2mnPGoP;Wi1?n0]_L5oh2bm@;oOjoc00?o0000ogjYkoooool05?oo
ool00ol0003oooooo`00001Aooooo`00H?ooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00006_ooool3o`0004Wooooo0on1aoh4oh35o@GoP<?m1?n0`?`4oh2mnP;oP;Wi
0_n4YNX4oh:Vk0GoP:O]0_mnZNl00ol0003oOZW_ogjYk`0Fooooo`03o`000?oooooooooo04oooooo
001Pooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000Hooooo`;o
0000B?ooool3oh;9oPGoPLOn1?n0aOd2oh33o@;oRZ;T1?n8XnH4ohJTj0GoQ:GZ1?n2Y^`5oh2Wk@03
ogjYkol0003oOZW_00;oOZW_5_ooool00ol0003oooooooooo`1>ooooo`00H?ooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oMgMgolc<c?l000005Oooool3o`0000;ooooo00?o0000oooooooo
ool0@Oooool3oh?;o`GoP/Wn0_n1aoh2ohjPh0CoS:7R1On:X^@4ohRSiPCoQZCX1On4YNX4oh:Vk0Go
P:O]00Co0000ogjYkon3Z>coPjS/5_ooool00ol0003oooooooooo`1>ooooo`00H?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000004oooool2o`0004;ooooo0on6c_l4ohC=
o`CoPl_o0_n2bOh2oi2OgPGoSZ3P1?n<XN84ohZRi0GoR:?V1?n6Y>P2ohBUjP;oRY_N1?n8Wn<5ohJS
i`03o`000?n3Z>coPjS/00;oPjS/5_ooool00ol0003oooooooooo`1=ooooo`00H?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool03oooool3o`00043ooooo0on6d?l5ohK>
o`;oQ<go00?oTigKoi:Ng?nBW]`00_nBW]`5oi2OgPCoSZ3P1On<XN84ohZRi0;oR:?V0_n=U=H4ohbH
fPGoRY_N1?n8Wn<4ohJSi`03o`000?n3Z>coPjS/00?oPjS/5_ooool00ol0003oooooooooo`1<oooo
o`00P_ooool2o`0003oooooo1?n6dol4ohK@o`;oQ/ko0_nDW=T4oi>Mf`CoTYkL1On@Wmh4ohjPh0;o
S:7R0_n@Slh4ohnAdPGoSICF1?n<V=X4ohZKgPGoR9oS0on6XnL01?l0003oPjS/oh>Xk?n3Z>`2ohf[
jAKooooo00?o0000ooooooooool0C?ooool007oooooo0ol00002ooooo`03o`000?oooooooooo03So
oooo1?n4e_l2ohKCo`;oU9SE1?nDV]L5oiBLf@CoTigK1?nBW]`2oi2OgP;oTX_81?nASL/5oi2?cPCo
Si7B1?n=U=H5ohbHfPCoRY_N0_n8Wn<2oi2Mg0?oSj?R00?o0000ohf[jOn=ZnT01?n=ZnTDooooo`?o
0000COooool007cooooo0ol0000mooooo`?oOM[m0_n4e_l2oi>Fd`GoU9SE1?nDV]L4oiBLf@GoTigK
0_nBW]`00onBRLKoTX_8oi:;b003oi:;b0CoTHg;1?n@Slh4ohnAdPGoSICF0_n<V=X2oi:Bd0CoTIOF
1On@WM`2ohnShP03o`000?n?Xn;oSJ_Y00CoSJ_Y5oooool00ol0003oooooooooo`1:ooooo`00N_oo
ool2o`0003cooooo0_m`fo@2oi2@c`?oTI?A1OnCU]<4oiBHe@CoU9[G1OnDW=T2oi>Mf`;oThO31?nB
RLH4oi:;b0CoTHg;1?n@Slh5ohnAdP;oSICF0_nCS//5oi:Bd0CoTIOF1?n@WM`3ohnShP04o`000?n?
Xn;oSJ_Yohf[j@?oVJoV5_ooool00ol0003oooooooooo`1:ooooo`00Moooool3o`0003Oooooo0olh
_;P2oeSBgP;oSXg>1On@T<l3oi6Cd@CoTiKC1OnDV=D4oiBJe`;oU9cI0_nCQL45oi>7``?oTXW61?nB
RlP4oi6=b`GoT8o>0_n?TM82oi>:a`GoThk;1?nBT]04oi6GePGoT9gL0_n?Xn800ol0003oVZKNoiV_
iP05oiV_iQKooooo00?o0000ooooooooool0BOooool007Gooooo0_l00002ooooo`03o`000?oooooo
oooo03?ooooo00?o>;bhohj:bon=Rl`00_n=Rl`5ohj=cPCoT93?0onATm45oi>Fd`;oU9SE0_nCPKd4
oi>3_`GoThG11?nCQl<3oi:9aPGoTX_81?nASL/2oi2?cP;oU8O31OnCR/L4oi>>b`CoTY;@1OnAUmH2
oi2Mg0;oVYkG0_nJY]h00ol0003oVZKNoiZVgP04oiV_iP03ojJehooooooooooo01Gooooo00?o0000
ooooooooool0B?ooool007;ooooo0ol00005ooooo`03o`000?oooooooooo02_ooooo00?o3P00o`00
0?l000000_l00005ohj:b`?oSH_<1?n>SLh4oi2@c`CoTI?A0_nCU]<2oi9n^PGoTh6m1?nCPkl4oi>5
`@CoThO31?nBRLH2oi:;b0;oU8:l1?nDQ;l5oiB7``CoTh[71?nCS//5oi:Bd0;oTIOF0_nJUm05oiZN
e`03oiZVg_l0003oVZKN00;oVZKN00?oVJoVojJehonV]N<00_nV]N<Fooooo`03o`000?oooooooooo
04Sooooo001`ooooo`;o0000<_ooool01_lC003o3P00o`h00?l>003o0000oi><b@CoT8[91?n>R//3
ohf;c0CoSXg>1On@T<l2oi6Cd@03oi5k]onBO[[oTWjj00;oTWjj1OnCPKd4oi>3_`CoThG11OnCQl<2
oi:9aP03oiAo^_nDP[coU8:l00?oU8:l1?nDQ;l4oiB7``CoTh[71OnCS//2oi:Bd0;oVY7:1OnJUm05
oiZNe`04o`000?nJY]koYJcLojF/g0KoY[GS5_ooool00ol0003oooooooooo`17ooooo`00>?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00008?ooool3o`00033ooooo0_lA
0002oa<00003o`h00?nHSlSoV8o800?oThc91?n@R/T4ohj:b`CoSH_<1?n>SLh2oi2@c`;oSgNd0onA
NkL5oi9n^PCoTh6m1?nCPkl5oi>5`@;oThO30_nDOKP4oiAo^PCoU8:l1?nDQ;l4oiB7``GoTh[70_nC
S//2oiV<a@GoVY7:1?nJUm04oiZNe`03ojBTeOl0003oYJcL00?oYJcL1?nV]N<00ona_>;ooooooooo
o`0Cooooo`?o0000B?ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A401kooooo0_l00003ooooo`03o`000?oooooooooo02[ooooo
00Ko2P00oa400?lA003o4@00oa<00?nLTLL4oiR?b0?oThc91On@R/T4ohj:b`;oSH_<00?oS72^ohic
/On>Lk400_n>Lk44ohmg]0CoTG^g1?nBO[X5oi>1_@CoTh>o0_nCQL42oiAl]PCoU7fh1?nDOkX4oiB2
_0CoU8Bo1OnDQl<2oi>:a`;oVHS01OnIS<D4oiZAbPGoVYO@00GoVYkGojBTeOnTY=GoY:CEo`000005
ojF/g003ojJehona_>;o/KcR00;o/KcR5_ooool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`0Yooooo`00>?ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h07?ooool3o`0002oooooo0ol:
00000olA003oWi?7oibAa`03oibAa`CoV8o81?nCS<T2oi2:b@;oS6fZ1?n<KZ`3oha`[PCoSW>a1On?
Mk@3oi5k]`CoTWjj1OnCPKd2oi>3_`;oU7Zc1?nDO;H5oiAm^0CoU7nj1?nDP[`4oiB4_`;oU8O30_nH
Q;`5oiV8`0CoVHc51OnJTLX2oiZGd0;oXig?1?nTY=D00ol0003oYJcLojF/g002ojF/g003ok2dg?na
_>;o/KcR00Co/KcR5_ooool00ol0003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool0:_ooool003Sooooo00Go0000oooooooooooooooo
o`00000=ooooo`03oiRHV?lQ8B7ok^k^01Sooooo0ol0000`ooooo`04o`000?l:003oXYG7oj:Ea`?o
Wi?71?nLTLL5oiR?b0;oThc900?oSFfXoha]Z_n<KJX00_n<KJX4oha^[0CoS72^1?n>Lk44ohmg]0?o
TG^g1OnBO[X3oi>1_@03oiAi/_nDN[?oU7Zc00;oU7Zc1OnDO;H4oiAm^0CoU7nj1?nDP[`2oiB4_`;o
V86h1OnHQ;`4oiV8`0CoVHc51?nJTLX00onSUlWoXig?oj>Mc`03oj>Mc`?oY:CE00?o0000ojBTeOnU
[=`01?n`]=`4ok6lhP;o^/?Q5_ooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooooooo
ool@41002oooool5o`0002_ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOoIVIVooooo`0Eooooo`?o0000<?ooool00ol0003oXYG7oj:Ea`03oj:Ea`?oWi?71OnLTLL2oiR?
b0;oSffX0on=KJP5oha]ZPCoS6j/0on<L:h4ohic/@CoSgNd1?nANkL4oi9n^P04oi>1_OnDNK;oU7Vb
oiAi/PGoU7Zc1?nDO;H4oiAm^0CoU7nj0onDP[`00onGOKGoV86hoiR1^002oiR1^0GoV8Bl1?nIR<05
oiV<a@03oiZAb_nSUlWoXiO900;oXiO91?nSWLl3ojBTe@03o`000?n_[]Oo/;CL00Go/;CL00?o/KcR
ok[3hOnj`n400onj`n4Eooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0002cooooo000hooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`0Aooooo`?o00000oooool00ol0003oooooooooo`0Zooooo`?o0000
0_nRU/L4oj:Ea`CoWi?70_nLTLL2oi9_Z0CoSffX1?n=KJP4oha]ZPCoS6j/0on<L:h4ohic/@GoSgNd
0onANkL2oi9n^P;oU7N`1OnDNK84oiAj/`CoU7bf1OnDOKP4oiAo^P04oiB2_?nGOKGoUgfeoiMm]@Co
V86h1?nHQ;`5oiV8`0;oVHc50_nRT/@5oj>Gb@GoXig?00?oY:CEojn^eol000000_n_[]L4ok2dg003
okVng_nj`n7o^/?Q00?o^/?Q00?o_lWRooooooooool05?ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000/ooooo`00>?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Aooooo`;o0000<Ooo
ool2o`0000;oXYG80onRU/L5oj:Ea`;oWi?700?oTg2Xoi9_Z?nBKjP00_nBKjP5ohm]Z0?oSFfX1?n<
KJX4oha^[0?oS72^1On>Lk44ohmg]0;oTG^g00?oTgB]oiAg/?nDMk000_nDMk05oiAi/PCoU7Zc1OnD
O;H4oiAm^0;oU7nj0_nGNk<4oiMm]@CoV86h1OnHQ;`3oiV8`003oj6>`?nRT/CoXY;400?oXY;41?nS
UlT4oj>Mc`04ojjXd_n_[]Oo[jkGo`0000?o[jkG00?o/;CLokVng_ni_]h00_ni_]h3ok[3h@?o_lWR
5_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOo
c<c<o`00000/ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c00>ooooo`?o0000<Oooool00ol0003oXYG8oj:Eb003oj:Eb0?oXYK71?nRULL01?nE
LZSoTg2Xoi=`Z?nCL:P5oi9_Z0CoSffX0on=KJP4oha]ZPCoS6j/1?n<L:h4ohic/@;oSgNd0_nCLZ/4
oi=d[@CoU7N`1?nDNK84oiAj/`GoU7bf0_nDOKP2oiIi/0CoUg^c1OnGOKD3oiR1^0GoV8Bl00?oVHS0
oj6>`?nQS/000_nQS/04oj:Ba0GoXiO900?oXig?ojjXd_n^Z=800_n^Z=801On_[]Oo0000ojn^eon_
[]Oo^;[K00Ko^KkN00?o^/?Qoko9h_nobN800onobN8Dooooo`;o00001?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000;?ooool005Wooooo0ol0000_ooooo`;o00001?nQ
ULP4oj:Eb0CoXYK700CoXYG7oiEbZ?nELZSoUG:X1?nCL:P4oi9_Z0CoSffX0on=KJP4oha]ZPGoS6j/
0on<L:h2ohic/@;oTW2X1?nCLZ/4oi=d[@CoU7N`1?nDNK85oiAj/`?oU7bf00?oUWN^oiIi/?nFNK00
0_nFNK05oiMk/`CoUgfe1?nHPKP3oiR4_003oin:_?nQS/3oXHk000?oXHk01?nRT/@4oj>Gb@03ojfS
c_n^Z=;o[ZSB00?o[ZSB00?o[jkGo`000?n_[]L00onh^]/4okVngP;o`<[R1?nobN800oo0c^Gooooo
ooooo`0Aooooo`04o`000?ooooooooooo`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=oooo
o`03ogMgMol0003ooooo02_ooooo001Fooooo`?o00000oooool00ol0003oooooooooo`0Yooooo`?o
00000onOU<P3oj6Eb0GoXYG80_nRU/L00onFLjWoUG:XoiEbZ003oiEbZ0?oTg2X1?nBKjP4ohm]Z0?o
SFfX1On<KJX4oha^[0;oS72^00?oTFfVoi9`Z?nBL:P00_nBL:P5oi=bZ`?oTgB]1?nDMk05oiAi/PCo
U7Zc00CoU7bfoiIg[_nFMjkoUWN^1OnFNK04oiMk/`CoUgfe1?nHPKP00onHQ;coWhZloin:_002oin:
_0CoXHk01OnRT/@00onSUlWo[J?>ojfScP02ojfScPGo[ZSB00?o0000okRjfonh^]/00onh^]/00oni
_]ko`<[Rol3:hP03ol3:hP03oko9h_o0c^Go`<kU00;o`<kU5_ooool00ol0003oooooooooo`10oooo
o`00E?ooool2o`0002oooooo1?l000000onNTlSoWiC8oinDb002oinDb0CoXIG80_nRULP5oiIcZ@Go
UG:X0onCL:P4oi9_Z0CoSffX1?n=KJP4oha]ZP;oS6j/0_n?Jj@3oi5]YPGoTW2X1?nCLZ/4oi=d[@Co
U7N`1?nDNK82oiAj/`;oUWJ]1OnFMjh4oiIi/0CoUg^c1OnGOKD2oiR1^003oin6^OnOR[coWhZl00?o
WhZl1OnQS/03oj:Ba003ojbOb_n]Xlko[J?>00?o[J?>1?n^Z=800onh]mSo0000okRjf`03okRjf`03
ol3<hoo0b^;o`<[R00?o`<[R00?o`MCXol3>iOo0c^D00oo0c^DFooooo`03o`000?oooooooooo043o
oooo001Aooooo`?o0000;oooool2o`0000;oWi?70onNTlP4oinDb0?oXIG800?oUG:YoiIcZOnFLjT0
1_nFLjT4oiEbZ0?oTg2X1?nBKjP5ohm]Z0?oSFfX0_n<KJX2ohmYX`CoSf^T1?nAKJH4oi9`Z0CoTg:[
1?nCM:d4oiAg/0;oU7Vb0_nFMJ`4oiIf[@GoUWN^1?nFNK05oiMk/`?oUgfe00?oWX>foin6^OnOQ[T0
0_nOQ[T4oin:_0GoXHk000?oXY;4ojbOb_n/WlX00_n/WlX5ojfScP05ojjXd_nh]mSo^;OHokRgf?l0
00000onh^]/3ol3<h`?o`<[R0oo1e>P3ol3>i@;o_=7Z5_ooool00ol0003oooooooooo`0oooooo`00
C_ooool5o`0002kooooo00?o0000oinCaonOTlL00onOTlL3oijCb0GoWiC800?oXIG8oiEbZOnELZT0
2?nFLjT4oiEbZ0?oTg2X1OnBKjP4ohm]Z0;oSFfX00?oSVRQohmYXon?JJ<00_n?JJ<5ohm[Y0?oTFfV
1?nBL:P4oi=bZ`CoTgB]0onDMk000onFM:_oUWF/oiIe[002oiIe[0GoUWJ]1?nFMjh4oiIi/0GoUg^c
00CoUgfeoij3]_nNPkKoWX>f1?nOQ[T5oin:_0?oXHk000?oZi_7ojbOb_n/WlX00on/WlX4ojfScP03
okNde_nh]mSo^;OH00;o^;OH00?o0000okRgf?nh^]/01Oo0c><00oo0b^;o`MCXol7Dj003ol7Dj003
ol3>iOnldN[o_=7Z00;o_=7Z5_ooool00ol0003oooooooooo`0nooooo`00C?ooool2o`0000Gooooo
00?o0000ooooooooool0:?ooool2o`0000?oXI?71?nOTlL4oijCb0;oWiC80_nDLZT4oiEbZ@OoUW>Y
1?nELZP4oi=`Z0CoTVnX0_n?KJP2ohiWX@?oSVRQ1?n?JJ<5ohm[Y0?oTFfV1?nBL:P5oi=bZ`CoTgB]
00?oU7N`oiIdZonFM:/01OnFMJ`4oiIf[@CoUWN^1OnFNK03oiMk/`03oif1]?nNPkKoWX>f00?oWX>f
1?nOQ[T4oin:_003oj6>`?n[VlOoZi_700;oZi_71On/WlX00on]Xlko]kCFokNdeP02okNdeP?o^;OH
00?o0000ol7=i?o1cN@01?o0c><2ol;Jj`Co`MCX00?o_=c`okcAj_nldNX00_nldNX00onbcnoooooo
ooooo`0Dooooo`03o`000?oooooooooo03kooooo0019ooooo`?o0000<?ooool2o`0000;oY9G60onQ
TlL5oinCa`;oWY?800?oU76YoiAbZOnDLZT00_nDLZT4oiEbZ@OoUW>Y1OnELZP3oi=`Z0;oTVnX0_n?
Ij44ohiWX@?oSVRQ1On?JJ<4ohm[Y0?oTFfV1?nBL:P5oi=bZ`;oTgB]0_nGM:X4oiIdZ`CoUWF/1?nF
MZd5oiIg[PCoUWV`00CoUg^coif1]?nMPKCoWH6d1OnNPkH4oin6^@?oWhZl00?oZYS4oj^Kaon[VlL0
0on[VlL4ojbObP03okNae?ng]=Ko]kCF00Co]kCF00Co^;OHol7=i?o1cNCo00000_o1cN@00oo0c>?o
`][[ol;Jj`03ol;Jj`03ol7Dj?nlg?3o_=c`00;o_=c`00?o_=7Zok;?konbcnl00_nbcnlDooooo`?o
0000?oooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Pooooo`;o0000<Oooool00ol0003o
Y9G6ojBEaP03ojBEaP?oXI?71?nOTlL01?nDLJSoU76YoiAaZOnDLJT4oiAbZ@CoUG:Y1onFLjT5oiEb
Z0;oTg2X00?oT6RQohmWXOn?Ij400_n?Ij44ohiWX@CoSVRQ1?n?JJ<4ohm[Y0?oTFfV1OnBL:P3oi=b
Z`03oiMdZOnGM:[oUgBZ00;oUgBZ1?nFM:/4oiIe[0CoUWJ]1OnFMjh2oiIi/0;oW7jb1OnMPK@4oij3
]PGoWhJi00CoWhZlojZHa?nZV<CoZYS41On[VlL00on/Wl[o]k7DokNae002okNae0Co]kCF00Ko`]3U
ol7=i?o1cNCo`LgTo`000?o1cN@2ol;Qk`Co`][[00?o^^OdokcLl?nlg?000_nlg?02ok3KmPGo//o_
5Oooool00ol0003oooooooooo`0mooooo`008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo
0ol00002ooooo`03o`000?oooooooooo02_ooooo0_l00003ojNGa0CoY9G61?nQTlL01?nOTlOoU76X
oiAaZ?nDLJP4oiAaZ@?oU7:Y1?nELZT8oiIcZ@CoUG:X00?oTg2Xoi1XXOn@J:401?n?Ij44ohiWX@Co
SVRQ1?n?JJ<4ohm[Y0CoTFfV1?nBL:P01?nCLZ_oUgBYoiMdZOnGM:T5oiMdZP?oUWB[1?nFMJ`5oiIf
[@?oUWN^00?oVgb`oian/_nLO[800_nLO[85oif1]0GoWX>f0onOQ[T00onYUL;oZYS4ojZHa002ojZH
a0CoZi_700?o][3BokNae?ng/M@00ong/M@3okNdeP?o`]3U0_o1cN@00ol0003o`^7_ol;Qk`02ol;Q
k`03ol;JjonjioCo^^Od00;o^^Od00?o_=c`ok3Km_n`foH00on`foH2ok;?k`?oYLWc5Oooool00ol0
003oooooooooo`0looooo`008_ooool01Ol@413ooooooooooooooooo410@01_ooooo0_l0000aoooo
o`;o00000_n[VL@3ojNGa0GoY9G60_nQTlL00onELJSoU76XoiAaZ002oiAaZ0CoU76Y1?nDLZT3oiEb
Z@SoUW>Y0_nELZP2oi1YX@?oT6RQ1On?Ij43ohiWX@CoSVRQ1?n?JJ<5ohm[Y0?oTFfV0onBL:P00onH
LjSoUgBYoiMdZ@03oiMdZ@CoUgBZ0onFM:/4oiIe[0GoUWJ]00CoUWN^oi]l/?nKO;3oVgb`1OnLO[84
oif1]0GoWX>f00?oWhJiojVE`_nYUL800_nYUL83ojZHa0?oZi_70onf/=85okNae003okNde_o2d>Go
`]3U00?o`]3U00?o`LgTo`000?o2hNl00_o2hNl2ok?`mP;o^^Od1?nYi_X2ok3KmP?oXM?i1OnUbO<E
ooooo`03o`000?oooooooooo03_ooooo000Rooooo`05o`000?ooooooooooooooool000006?ooool3
o`00037ooooo00?o0000oj^Ia?n[VL@00on[VL@4ojNGa0;oY9G60_nGLZL3oiEaZ0CoU76X1?nDLJT4
oiAbZ@CoUG:Y1_nFLjT00onAJJ7oT6VQoi1YX@02oi1YX@CoT6RQ1?n?Ij43ohiWX@CoSVRQ1?n?JJ<5
ohm[Y0?oTFfV00CoTW2XoiQcZ?nHLjSoV7>X1OnGM:T4oiMdZP?oUWB[1OnFMJ`3oiIf[@03oiYk[onK
O;3oVgb`00?oVgb`1?nLO[85oif1]0?oWX>f00?oZ9>oojVE`_nYUL800onYUL84ojZHa003oj^Kaonf
/=;o][3B00;o][3B1?ng/M@2ol;Ci`Co`]3U0_o0j?800ol0003o`^7_ok?`mP02ok?`mP;oVngg1?nY
i_X2oiWLoPGoXM?i0_nUbO<2oiS0laGooooo00?o0000ooooooooool0>oooool002;ooooo00Go0000
ooooooooooooooooo`00000Fooooo`?o0000<_ooool3ojjKa0CoZiW40onWUl@00onIM:SoUg:WoiMb
Y`02oiMbY`CoUG6X1?nDLJP3oiAaZ@CoU7:Y1?nELZT2oiIcZ@;oTFZR0onAJJ44oi1YX@CoT6RQ1?n?
Ij44ohiWX@?oSVRQ1On?JJ<4ohm[Y0;oTFfV00?oUg:WoiQcZ?nHLjP00onHLjP4oiMdZ@CoUgBZ1?nF
M:/4oiIe[004oiIf[OnJNjooVW^_oiYk[`GoVgb`1?nLO[85oif1]003oij3]_nXTkooZ9>o00;oZ9>o
1?nYUL83ojZHa003okJ_d_nf/=;o][3B00Co][3B00?o]k7Dol;Cioo2dnL00oo2dnL00oo2d>Go`>Sb
ol3XlP02ol3XlP03o`000?nSm>oo/o3f00GoVngg00?oZNKjoiWLo_nIg?h00onIg?h2oj7Cn@;oU<Kh
1OnH`?<Eooooo`03o`000?oooooooooo03[ooooo000Rooooo`05oa0@4?ooooooooooooooool@4100
4oooool3o`0000;ooooo00?o0000ooooooooool0;_ooool00on`WLCo[Y_4ojjKa002ojjKa0GoZiW4
00?oYiO4oiUdZ?nIM:P01?nGLZL4oiEaZ0CoU76X0onDLJT4oiAbZ@?oUG:Y1OnAJZ83oi5YX@CoT6VQ
1?n@J:44ohmWX@CoSVNQ1?n>J:44ohmYX`?oSf^T00CoUW6VoiMbYonGLZOoUg:W1OnHLjP4oiMdZ@Co
UgBZ1?nFM:/2oiIe[0;oVWV^1OnJNjl4oi]l/0GoW7jb0onMPK@00onWT;koZ9>oojRC_`03ojRC_`Go
ZIG200CoZYS4okJ_d_nf[m;o]ZoB1?nf/=82ol;Gj@Co`]?W0onll?<01?o0j?;oXoC_oj?dkol00003
ogoWi`;oVngg1?n9hO`2oiWLoP;oSl_l1OnDa_P4oiS0laKooooo00?o0000ooooooooool0>Oooool0
02;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`?o0000=Oooool3ok2Ma0?o[Y_41?n[VL@0
0onLMjWoVGBXoiUdZ002oiUdZ0?oUg:W1?nELJP4oiAaZ0CoU76Y0onDLZT00onELZWoTFZRoi5ZXP05
oi5ZXPCoTFVQ0on@JJ44oi1XX@CoSfNQ1?n>Ij44ohiXX@CoSfVS00CoSf^ToiIaY_nFLJKoUW6V1?nG
LZL4oiQcZ0CoUgBY1OnGM:X2oiIdZ`03oiYi[OnJNJkoVWV^00;oVWV^1OnJNjl4oi]l/0GoW7jb00?o
WH6dojN@__nWT;h00_nWT;h4ojRC_`CoZIG200?o]ZkAokJ_d_nf[m800onf[m800onf/=;o`]OYol;G
j@03ol;Gj@03ol;Cionll??o_?3c00;o_?3c0on7k=X00onSm>oo0000ogoWi`04og3Ml@;oRN7l0on7
c_l4oho;o0CoU<Kh0_nH`?<3oi6fl1Cooooo0_l0000kooooo`008_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00kooooo0_l0000fooooo`03ogGRcon`WLCo/9g400;o/9g41?n^Vl@01?n[VLCoW7NYoiag
ZOnLMjT4oiUdZ0CoUg:W0onELJP4oiAaZ0CoU76Y0_nDLZT00onBJZ7oTFZRoi5ZXP06oi5ZXPCoTFVQ
1?n@JJ43oi1XX@CoSfNQ1?n>Ij44ohiXX@;oSfVS0_nEKjD5oiIaYP?oUg:W1?nHLjP5oiMdZ@CoUgBZ
00?oUWB[oiYi[OnJNJd01OnJNJh4oiYk[`GoVgb`0onLO[800onVS[coYi2nojN@_P03ojN@_PGoZ9>o
00?oZIG2okJ^dOnf[]400_nf[]44okJ_dP03ol;MkOo2enWo`]OY00;o`]OY0oncmO801Onll??oQncJ
ohO/f_n7k=[oF=7500;oDLkJ00?o0000og;>o_mbc_h01Ommcol4ohO>o`;oSl_l00?oS[GaohnflOn?
]_400on?]_45oi6fl1Gooooo00?o0000ooooooooool0>?ooool003;ooooo1Ol0000cooooo`;oUO3Z
00?o/Io5ok2Ma?n`WL@00on`WL@3ojjKa003oiijZonLMjWoW7NY00;oW7NY1?nIM:P4oiMbY`?oUG6X
1?nDLJP2oiAaZ@GoTVZQ2?nAJZ84oi5YX@CoT6VQ0on@J:45ohmWX@?oSVNQ0on>J:400onCKJCoUFnU
oiE_Y@02oiE_Y@GoUW6V0onGLZL4oiQcZ0GoUgBY0onGM:X5oiYi[@CoVWV^1?nJNjl5oi]l/003oian
/_nVS[coYXjl00;oYXjl1?nWT;h4ojRC_`03okF]dOnf[]7o]ZkA00?o]ZkA0onf[m83ol;Mk@03ol;G
jOncmO;o/oGb00;o/oGb00CoH=>go`000?mRb__oH/[k0omXc?d2o`0000?oL/kn0_mmcol2oh^_kPCo
S;?`1?n>]O45ohnfl@;oTKK`0_nA/NdFooooo`03o`000?oooooooooo03Oooooo000`ooooo`;o0000
=_ooool3oiG`jP?o/Io51On`WL@00on^VlCoWWZ[oiijZ`04oiagZ@CoVGBX1?nGLZL4oiEaZ0;oU76X
2?nBJZ48oi5ZXPCoTFVQ1?n@JJ44oi1XX@CoSfNQ0on>Ij401?n>J:7oTffToi=]Y?nCKJ@5oiE_Y@Co
UW6V0onGLZL5oiQcZ0CoUgBY00?oUgBZoiYi[OnJNJd01OnJNJd4oiYi[PGoVW^_0onKO;000onTS;_o
YXjlojJ>_003ojJ>_0GoYi2n0_nXTkl3okF]d@Go]ZkA00Co]ZoBol;MkOo2gNgo`]g]0onTm^X00onc
mO;oH<Skof38n`02of;:n`;oSIoP0ol000000on<YNKo0000oh^[j`02oh^[j`GoRjo^1?n</o04ohje
l@;oSkKa0_nA[NT5oi6akAGooooo00?o0000ooooooooool0=oooool002gooooo0ol0000fooooo`?o
Z?7f00?o/J77ok6OaOnaWlD00_naWlD4ok2Ma003oj1m[OnNNZ_oWWZ[00;oWWZ[1?nLMjT3oiUdZ0Co
Ug:W1?nELJP00onDLJSoTVZQoi9ZX@08oi9ZX@SoTFZR0onAJJ44oi1YX@CoT6RQ1?n?Ij42ohiWX@03
oi9/XonCKJCoTffT00;oTffT1OnEKjD4oiIaYP?oUg:W1OnHLjP2oiMdZ@;oVgV]2?nJNJd4oiYi[PGo
VW^_00?oVgb`ojB<^onTS;/00_nTS;/4ojJ>_0GoYi2n00?oZ9>ookF]dOne[M400_ne[M44okJ^d@04
ol7Sl?o2gNgo`]g]ol;Mk@?oY?KZ1?n?VMT01On=Wn3o0000o`000?l0003oSIoP00CoS:GV00Co0000
oh^[jon;Zn_oRj_[1?n;[nh2ohbcl0;oTZ?Q1OnAZ>D4oi6]j@GoTK7]5Oooool00ol0003ooooooooo
o`0fooooo`00;?ooool2o`0003Oooooo0_nXlOH4ok6Qa`Co/Io500Co/9g4oj1m[OnPOJgoX7f]1?nN
NZ/4oiagZ@CoVGBX0onGLZL2oiEaZ0goTVZQ2?nAJZ84oi5YX@?oT6VQ1?n@J:42ohmWX@;oT6ZS0onB
K:<5oi=]Y0CoUFnU1?nFLJH4oiMbY`?oV7>X00?oW7Z]oi]i[OnKNJd00_nKNJd8oiYi[@GoVWV^0onJ
Njl00onSR[[oY8bkojB<^`03ojB<^`GoYXjl0onWT;h00ond[M7o]JgAokF]d@04okF]d@03okJ^dOo1
ho3o`N?`00;o`N?`00?o`]g]ojCfj_nTm^X00onATm401?n?VMWo0000o`000?l00005ohfOh0CoS:GV
00?o0000oh^[jonDV=D01?nCW]/5oi:Sh@GoTJSU1?nA[NT2oi6ak@?oUk3X5Oooool00ol0003ooooo
ooooo`0eooooo`00;?ooool3o`0003?ooooo0onajoP00onaX/Wo/J77ok6Qa`03ok6Qa`?o/Io500?o
XH2_oj1m[OnPOJd00_nPOJd4oiijZ`CoW7NY1?nIM:P2oiMbY`03oi=[XOnBJZ7oTVZQ00goTVZQ2?nA
JZ84oi5YX@?oT6VQ0_n@J:42oi1YXPCoT6ZS0onBK:<5oi=]Y0CoUFnU1OnFLJH3oiMbY`04oiQcZ?nL
NZgoW7Z]oiaj[@GoVgV]1onJNJd5oiYi[P03oiYk[onSR[[oXhZj00;oXhZj1?nTS;/5ojJ>_003ojN@
__nd[M7o]:gA00;o]:gA1?ne[M42okkZlP?o`N?`00?oRngHoi>=b_nCSLX00_nATm43o`0000CoSiWI
0_n=Wn02oiJ<a`CoU9;>00CoU9SEo`000?nDV=GoU9SE1?nCW]/5oi:Sh@;oTJSU0_nHX]/5oiRXhPGo
Uk3X5?ooool00ol0003oooooooooo`0eooooo`00;?ooool01?l0003oooooo`000?l0000_ooooo`Co
]^Kf00Co/N_hok6RbOnaX/Wo/J;91OnaXLL00onaWlGoXH2_oj60[`04oj1m[@CoWWZ[1?nLMjT4oiUd
Z003oiMbYonCJj7oTf^Q00ooTVZQ2?nAJZ84oi5YX@;oT6VQ1On@JJ84oi1ZX`CoTVbS1?nCKJ@4oiE_
Y@GoUW6V0_nGLZL00onLNZcoW7Z]oiaj[@03oiaj[@CoVgV]2?nJNJd3oiYi[P03oj:9^OnSR[[oXhZj
00?oXhZj1OnTS;/3ojJ>_003okB]d_nd[M7o]:gA00Co]:gA00?o]JgAokkZl_nnj_800onnj_801?o1
ho3oUHS4oi>=b_nCSLX3o`0000?oTI?A0_n?VMT2oiN7`@GoUXc70onDT/h01?nDV=Go0000oiBHeOnD
V=D5oi>Nf`;oTZ?Q0_nIVm@5oiRRf`GoV:SR0_nG/>P2oj6diQ?ooooo00?o0000ooooool000002?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<
c<`06Oooool002cooooo0_l00002ooooo`03o`000?oooooooooo02_ooooo1?nfi_H00onaY<_o/J;9
ok6Rb@02ok6Rb@Co/J7700?oXh>boj60[onQP:l00_nQP:l4oj1m[@?oWWZ[1?nLMjT2oiUdZ0;oU6bQ
0onCJj4?oi9ZX@SoTFZR0onAJJ48oi1YXPGoT6ZS0onBK:<4oi=]Y0GoUFnU1?nFLJH00onGLZOoW7Z/
oiaj[005oiaj[@CoVgV]2?nJNJd00onJNJkoXXVioj:9^@02oj:9^@CoXhZj1OnTS;/00onVS[co]:gB
okB]dP02okB]dPCo]:gA0_nilO@4okkZlP;oUHS40ol00002oi>=bP;oTI?A0_nGPk/5oiN7`@CoUXc7
1?nDT/h01?nDV=Go0000oiBHeOnDV=D2oi>Nf`;oVYG=1OnIVm@4oiRRf`CoV:SR00?oXJcOoj6di_nQ
]>H00onQ]>HEooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q01Wooooo000[ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0:?ooool3okSRm003okKVm_naY<_o/JC;00;o/JC;1?naX/T01?na
XLOoXh>boj>3/_nSPk84oj60[`CoX7f]1?nNNZ/2oiagZ@03oiE]XonDK:7oU6bQ00;oU6bQ1?nCJj4?
oi9ZX@OoTFZR00?oTFVQoi1YX_n@JJ802On@JJ84oi1ZX`?oTVbS1?nCKJ@5oiE_Y@?oUW6V1OnLNZ`4
oiaj[@CoVgV]1onJNJd00onQR;WoXXVioj:9^@03oj:9^@GoXhZj0onTS;/00onc[M?o]:gBokB]dP03
okB]dP?o]:gA1?nilO@00onnj_;oUXBnoiF8a002o`0000;oUHS40_nCSLX00onHOkKoUh>koiN3^`03
oiN3^`CoUhO11?nFS<L4oiBBcP;oU9SE00?o0000oiZ?aonJULd01?nJULd4oiVKe0GoV:;K00?oV:SR
oj6/gonQ[=l00_nQ[=l4oj6diQGooooo00?o0000ooooooooool01Oooool01Ol@413ooooooooooooo
oooo410@00_ooooo00Go0000ooooooooooooooooo`00000Iooooo`00:oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo02Gooooo1?nhh_@00onaY/go/JC;ok6Tb`03ok6Tb`?o/J;900?o
XhJeoj>3/_nSPk800onSPk83oj60[`CoX7f]1?nNNZ/00onLMjWoUFfSoiE]X`04oiA/X@CoTf^Q3onB
JZ46oi5ZXP03oi5YX_n@JJ;oT6VR00[oT6VR1?n@JZ<3oi9/X`GoTffT1?nEKjD00onFLJKoW7Z/oiaj
[005oiaj[0CoW7Z]1OnKNJd3oiYi[@GoXHRi1?nRRKT5oj>:^P03ojB<^onc[M?o/jgC00;o/jgC1Ond
[M801?nd[M7o^O7dokWam?nilO@2oiJ4_P?o00000_nER<@2oiUl/PCoV7nf1?nGPk/4oiN7`@GoUXc7
0_nDT/h01?nKR/7oVXo7oiZ?aol00002oiZ?a`CoVYG=1OnIVm@2oiRRf`;oXJGH1OnQ[=l2oj6diP?o
Z[[U5Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003oV9RHoooooonHV9So8B4Q01Wooooo000[ooooo`?o00001Oooool00ol0003oooooooooo`0Roooo
o`Co^]ob00Co^>;dok6VcOnaY/go/JK=1OnaY</00onaX/WoXhJeoj>6]@05oj>3/P?oXH2_1?nPOJd3
oiijZ`04oiI_Y?nEKJ?oUFfSoiE]X`CoU6bQ1?nCJj4?oi9ZX@CoTFZR0onAJJ8<oi1YXPCoT6ZS0onB
K:<5oi=]Y0?oUFnU00?oVgR/oiaj[?nLNZ`01_nLNZ`4oiaj[@GoVgV]00?oVWV]oj68^OnQR;T01OnQ
R;T5oj:9^@?oXhZj00?o/ZgCok>]donc[M<00onc[M<4okB]dP;o/?Gb0_nGP;P3o`0000;oUXBn00?o
VWZ^oiUl/_nIO;800_nIO;84oiQo]PCoUh>k1OnGQl42oiJ<a`;oW8Jk1?nKR/42oiZ?a`03o`000?nJ
SlOoVYG=00CoVYG=0_nIVm@2oj:OdPGoXJGH0onQ[=l00on[/mooZ[[UojZji@04ojZjiAGooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Iooooo`00:oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo023ooooo
1?njgo800onaZ<oo/JK=ok6Vc@02ok6Vc@Co/JC;00?oY8Vhoj>6]OnSQ[D00_nSQ[D4oj>3/PCoXH2_
0onPOJd01?nNNZ_oUVnToiI_Y?nFKj@4oiE]X`?oU6bQ1?nCJj4>oi9ZX@03oi9[X_nAJZ;oTFZR00;o
TFZR0onAJJ8<oi1YXPCoT6ZS1?nBK:<4oi=]Y004oiE_YOnKN:coVgR/oi]h[0SoW7Z/1OnLNZd3oi]i
[@03oj:9^_nQR;WoXHRi00OoXHRi1?nRRKT00onSR[[o/ZgCok:]d`02ok:]d`Go/jgC00Co]:gBok3e
l_n`mO;oUg^b0ol00002oiN0^004oiJ4__nJNZkoVWZ^oiYj[PGoVGbb0onHOkH5oiN3^`;oUhO10_nL
P[H5oib6^`?oVh[10onJSlL01?l0003oVXo7oiZEcOnJULd2oj>Jc0GoXYoB1OnQYMP01?nQ[=ooZk?O
oj^cgon[/ml4ojZji@03ok;1iOoooooooooo01?ooooo00?o0000ooooooooool00oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool06oooool002_ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Mooooo`?o^mka00?o^]obok6XconaZ<l00_naZ<l4ok6Vc@04
ok6TbonTRKSoY8VhojB9^0CoXhJe1?nSPk84oj60[`;oX7f]00?oUg6VoiI_Y?nFKj@00_nFKj@4oiE]
X`CoU6bQ0onCJj4=oi9ZX@;oTV^R1?nAJZ84oi5YXP_oT6VR1On@JZ<3oi9/X`?oTffT00?oVGN[oi]h
[?nKN:`00onKN:`7oiaj[0GoW7Z]00CoVgV]oj:9^_nRRK[oXXVj2OnQR;T3oj:9^@03ok2]e?nb[M?o
/ZgC00?o/ZgC1?nc[M<2oj?ej`?o000000?oUg^boiN0^?nGP;P00_nKNJ`5oiYj[PCoVGbb1?nHOkH3
oiN3^`03oieo/_nLP[KoW8:f00?oW8:f1?nLQ[/3oi^:`@CoVXo700?o0000oj>Jc?nSV/`00onSV/`5
oj:OdP;oXJGH0_n[[]X5oj^cg`03ojZjiOnb`NGo//7U00;o//7U4oooool3o`0000Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01_ooooo000@ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool06_ooool4ok_Nl@03ok:Yd?naZ<oo/JS?00?o/JS?0ona
Y/d00onTRk[oY8VhojB9^003ojB9^0?oXhJe1OnSPk82oj60[`04oiQcZ?nGLJKoUg6VoiMaYPCoUVnT
1?nEKJ<4oiA/X@?oTf^Q2_nBJZ42oi=[XP?oTV^R1?nAJZ84oi5YXPcoT6VR1?n@JZ<3oi9/X`04oi=]
Y?nIMj_oVGN[oiUgZ`GoVgR/2?nLNZ`3oiaj[@03oj>;^onRRK[oXXVj00?oXXVj2OnQR;T01?nRRKWo
/:gDok2]e?n`[M@5ok:]d`03ok>]donSmN_o000000;o000000CoUWJ]oiMk/_nGNk;oW7NY1?nKNJ`5
oiYj[PCoVGbb1?nHOkH01?nGPk_oWGnboieo/_nMOk85oib2]PCoW8Jk1?nKR/401OnJSlOoY9G6ojBE
a_l0003oY9G600CoXi[<1?nRWm800on/Z]GoZjkJoj^^fP03oj^^fP?oZk?O0_nc_n<5ok;1iAGooooo
00Wo0000ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@
410Iooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oo
oooooooo00Cooooo0ol0000:ooooo`03o`000?oooooooooo01Oooooo1?nlgO001?nkg_7o/ZW@ok:Y
d?nbZM05ok6Xc`04ok6VcOnTRk[oY8^jojB;^PCoY8Vh1?nSQ[D4oj>3/P03oj60[onHLjSoV7>X00Co
Ug6V0onFKj@4oiE]X`CoU6bQ1?nCJj45oi9ZX@;oU6bR1?nCJj84oi9[XP?oTFZR1?nAJJ8<oi1YXPCo
T6ZS0_nBK:<00onGM:[oVGN[oiUgZ`03oiUgZ`CoVgR/2?nLNZ`00onLNZgoXh^koj>;^`02oj>;^`Co
XXVj2?nQR;T00on_[MKo/:gDok2]e002ok2]e0Co/ZgC0ol00004oiIf[@04oiMk/_nLMjWoW7NYoiag
Z@CoVgV/1?nJNZh5oiUl/P;oV7nf00?oWGb^oieo/_nMOk800onMOk84oib2]PGoW8Jk0_nKR/400onU
T/7oY9G6ojBEaP02ojBEaP03o`000?nSV/coXi[<00?oXi[<00CoXYoBojbZeOn/Z]Go[:[E1On[[]X0
0on[/moo/koSok>oh`03ok>oh`;o//7U0_nfb>PEooooo`03o`000?oooooooooo02oooooo0008oooo
o`Ko00000_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00005ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool05Oooool4okcMl003ok>[dOnbZM3o/ZW@00?o/ZW@0onaZ<l0
0onUS[coY8^jojB;^P02ojB;^PCoY8Vh1?nSQ[D2oj>3/P;oV7J[1?nHLjP3oiMaYPCoUVnT0onEKJ<4
oiA/X@CoTf^Q0_nBJZ400onDKJ?oU6bRoiA/XP02oiA/XPCoTf^R1?nBJj84oi5ZXP?oTFVR3?n@JJ82
oi1ZX`;oUG:Y0onGM:X5oiUgZ`CoVgR/1onLNZ`00onUSKcoXh^koj>;^`03oj>;^`CoXXVj1_nQR;T4
ojn]ePCo/:gD00?o/ZgCo`000?l000000onCLJT3oiIf[@03oiafYonLMjWoW7NY00;oW7NY1?nKNJ`4
oiYj[PGoVGbb00?oV7nfoiel[_nMO:h01OnMOk85oib2]P?oW8Jk00?oYXnmojFB`OnUT/400_nUT/44
ojBEaP05o`000?nSV/coXi[<oj>Jc?n]Ym401On/Z]D3oj^^fP;o];gQ1?nc_n<00ongc>[o]/SXokK8
j003okK8j1Gooooo00?o0000ooooooooool0;_ooool0013ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Booooo`Co_Mc_00Co_=g`ok>[dOncZm7o/j_A1OnbZM001?naZ<ooYHjlojF>_?nUS[`3ojB;
^PGoY8Vh0_nSQ[D00onIN:goV7J[oiQfZ`02oiQfZ`CoV7>X0onGLJH4oiI_Y0?oUFfS1?nDK:44oi=[
X@03oi9ZXOnDKJ?oU6fS00CoU6bR1?nCJj84oi9[XPCoTFZR0onAJJ8;oi1YXP03oiA`Z?nELZWoUG:Y
00;oUG:Y1?nGM:X4oiUgZ`CoVgR/1_nLNZ`3ojF=_0CoXh^k1OnRRKX3oj68^@03ojf]eon_[MKo[jgF
00?o[jgF0_n`[M@3o`000003oi9]YOnCLJWoTg6Y00;oTg6Y00CoUWJ]oiafYonLMZOoW7JW1?nLMjT4
oi]i[0GoVWZ^0onIO;800onNNZcoWGb^oiel[P02oiel[PCoWGnb1OnLP[H00onLQ[_oYXnmojJ?_@02
ojJ?_@?oYI;11?nTULH00ol0003oXi[<ojfWd@03ojfWd@Co[:[E00?oZjkJokBmhOnd_N400ond_N40
0onc_n?o]lcZokO<jP02okO<jP?o]/SX0_ncbn/Eooooo`03o`000?oooooooooo02gooooo000@oooo
o`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00006ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03_ooool2okkKkPCo_Mc_00?o]:gBok>[dOncZm400onc
Zm42ok:Yd0;oYY2n1?nUS[`4ojB;^PCoY8Vh00?oXhJeoiUh[OnIN:d01?nHMZ/4oiQcZ0?oUg6V1?nF
Kj@4oiE]X`?oU6bQ0_nCJj45oiA]X`GoU6bR0onCJj84oi9[XPCoTFZR1?nAJJ88oi1YXP?oU72X1OnE
LZT3oiMdZPCoVGN[1OnKN:`3oiaj[003ojJ@_OnUSKcoYHfl00;oYHfl1OnSRk/4oj:9^P03oj68^On]
[MOo[JgG00;o[JgG0on_[MH3o`0000GoTVfU0_nCLJT00onLM:GoW7JWoiafY`03oiafY`CoW7NY0onK
NJ`5oiYj[P04oiUl/_nNNZcoWWZ/oiij[0CoWGb^1OnMOk83oib2]P03ojN=^_nVSkgoYXnm00?oYXnm
0onUT/44ojBEaP03ojnUc_l0003o[JOA00Co[JOA0_n/Z]D2okFmg`Co];gQ0_nhdNd4okO<jP03okK8
j?ncbn_o/l_[00?o/l_[5?ooool00ol0003oooooooooo`0]ooooo`004?ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool2o`0000oooooo0_l0000<ooooo`Go_]_^
00?o_Mc_okB]d_nd[M800_nd[M83ok>[d@03ojRB_onVT;koYY2n00?oYY2n0onUS[`4ojB;^P;oY8Vh
0_nJNjl4oiUh[@?oV7J[1?nHLjP3oiMaYPCoUVnT1?nEKJ<2oiA/X@03oi=]Y?nDKJ?oU6fS00KoU6fS
1?nDK:84oi=[XP?oTV^R1?nAJZ84oi5YXPKoT6VR00?oTfnWoiA`Z?nDL:P00onDL:P4oiEbZ@?oUgBZ
1?nIMj/5oi]h[003oiaj[?nVT;goYY2m00;oYY2m0onUSK`5oj>;^`;oXXVj0_n][mX5ojf]e`?o0000
00Co[jgFoi5ZX_nAJZ;oTFZR1?nBKJD00onCLJWoW7BUoiadY@05oiafY`CoW7NY1?nKNJ`3oiYj[P03
oiiiZOnNNZcoWWZ/00?oWWZ/0onMO:h5oieo/P03oib2]_nWSK[oYhfj00;oYhfj1?nVSkd4ojFB`@03
ojBEa_n_YLko[jG>00;o[jG>00Go0000ojfWdOn]Ym7o[JOAokRog`05okFmg`03okBmhOnhdNgo^=7]
00?o^=7]0_ngc>X2okCBl0Co/l_[00?o[L[_ooooooooool04oooool00ol0003oooooooooo`0/oooo
o`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo0onof^d3okkKkP03okF_dond[M;o]:gB
00Co]:gB00Co/j_AojRB_onXT[ooZ9:o1?nVT;h4ojF>_0;oY8^j00?oVgfaoiYk[onJNjl00_nJNjl4
oiUh[@CoV7J[0onHLjP4oiMaYP?oUVnT1?nEKJ<00onDK:7oTffToi=]Y008oiA]X`CoU6bR1?nCJj83
oi9[XPCoTFZR1?nAJJ82oi1YXP;oTfnV0onCKjL5oiA`Z0CoUG:Y0onGM:X5oiUgZ`?oVgR/00?oYi6n
ojJ@_OnVT;d00onVT;d4ojF=_0?oXh^k00?o[KCMojf_f_n][mX00on][mX01_n][MOo0000o`000?l0
003o[JgGojn]ePGoTFZR0onBKJD00onKLZ?oW7BUoiadY@02oiadY@CoW7JW1?nLMjT4oi]i[004oiYj
[_nNNJWoWWVYoiiiZ@GoWWZ/1?nMO:h3oieo/P03ojR<^?nWSK[oYhfj00?oYhfj1OnVSkd2ojFB`@03
ok6Uc?n_YLko[jG>00Co[jG>00?o0000okRogonh_ml00_nh_ml3okFmg`;o^MW`1?nhdNd00oncf_Co
]=;`okCBl003okCBl003ok?;jon]b^oo[L[_00;o[L[_4oooool2o`0002kooooo000@ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool01Oooool5okoJk@04okkKk_ne[m?o]JoCokF_d`Co]:gB00?oZIG1ojRB
_onXT[l00_nXT[l4ojJ@_PCoYHjl00?oY8^joi]m/OnKOK401?nJNjl4oiUh[@CoV7J[1?nHLjP3oiMa
YP?oUVnT0_nEKJ<2oi=^Y@?oTffT2?nDKJ<4oiA/XPCoTf^R1?nBJj83oi5ZXP;oTFVR1_nCKjH4oi=_
Y`CoU72X1?nELZT3oiMdZPGoVGN[00?oVgR/ojNA__nWTKh00_nWTKh4ojJ@_@CoYHfl00?oXh^kojfd
gOn]]=d00_n]]=d2ojf_fP?o00000_n][ML01?mHckOoTFRPoi5XX?nAJ:04oi5ZXP04oi9]YOnKLZ?o
Vg:Soi]bX`CoW7BU1?nLMZL5oiagZ@;oVgV/00?oWgVXoiiiZOnNNJT00onNNJT4oiij[0CoWGb^00?o
WGnbojR<^?nXS;P00_nXS;P4ojN=^PGoYXnm00CoYI;1ok6Uc?naYLco/JG<1?n_YLh00onj`n7o0000
okRog`03okRog`03okFmgonifO3o^MW`00?o^MW`00?o^=7]ok?Jm?ncf_@00_ncf_@2okCBl0?o[=;d
1?n]b^lEooooo`03o`000?oooooooooo02_ooooo000Yooooo`;o00005?ooool00ol0003ooooooooo
o`02ooooo`;o`=W/1?nof^d00ong/MCo]JoCokF_d`03okF_d`03okB]d_nYUL7oZIG100;oZIG10onX
T[l5ojJ@_P;oYHjl00?oWGncoi]m/OnKOK400_nKOK43oiYk[`CoVGR]1?nHMZ/4oiQcZ0?oUg6V0_nF
Kj@00onBKZKoTfjUoi=^Y@02oi=^Y@CoTffT1onDKJ<4oiA/XPCoTf^R1?nBJj82oi5ZXP[oTfnV0onC
KjL4oiA`Z0CoUG:Y1?nGM:X3oiUgZ`03ojJ@__nWTKkoYi6n00?oYi6n1OnVT;d2ojF=_003ojnjh_n]
]=go[KCM00;o[KCM0ol00002ojf_fP03odO3[?nAJ9ooTFRO00CoTFRP0onAJZ800onIKj7oVg:Soi]b
X`02oi]bX`CoW7BU1?nLMZL5oiagZ@03oi]i[?nONJSoWgVX00GoWWVY1?nNNZ`4oiel[PGoZ8bh1OnW
SKX3ojJ?_@03ok>WbonaYLco/JG<00?o/JG<00?o[jG>ok[3hOnj`n400_nj`n400ol0003o^;oOokRo
g`02okWSm0Co^MW`00?o[^Ciok?Jm?ncf_@00_ncf_@2ojOKnPGo[=;d0_n]b^l2ojG4l1Gooooo00?o
0000ooooooooool0:_ooool002Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04
ol3Ik003okoJkOng/MCo]k7D00;o]k7D0one[m<00on[V<?oZIG1ojVE`@03ojVE`@CoZ9:o0onVT;h0
1?nNP[CoWGncoieo/onMOk<4oi]m/@CoVW^_0onIN:d4oiQfZ`CoV7>X0_nGLJH01?nAKZSoTVjVoi9^
Y_nBKZH5oi=^Y@?oTffT1onDKJ<5oiA/XP?oTf^R1?nBJj800onAJZ;oTfnVoi=_YP09oi=_YP?oTfnW
1?nDL:P5oiEbZ@?oUgBZ00?oVGN[ojJ@__nVT;h00_nVT;h4ojNA_PGoYY2m00GoYHflojnjh_n_^^;o
[k[Rojfdg@02o`0000;o[KCM00?o[JoJoi=YW_nAJ9l01?nAJ9l3oi5XX004oi5ZX_nIKj7oVFnQoiU_
X@GoVg:S0onLM:D5oiafY`?oW7NY00?oXGZXoimiZ?nONJP00_nONJP4oiiiZ@GoWWZ/0_nMO:h00onZ
S;KoZ8bhojR<^003ojR<^0GoYhfj00CoYXnmok>WboncYl_o/jO;1?naYL`00onmbNCo^/?Qok[3h@04
ok[3h@03o`000?nihoCo^N?d00;o^N?d00?o^MW`ojkTnOn^i?T00_n^i?T00oncf_CoYm_jojOKnP03
ojOKnP;o[=;d0_nSbO@5ojG4l1Cooooo00?o0000ooooooooool0:_ooool002Wooooo00?o0000oooo
ooooool05Oooool00ol0003o`=W/ol3Ik002ol3Ik0;o^;?D1Ong/M@01?ne[m?oZiS3oj^H`on[V<<4
ojVE`@CoZ9:o00CoYY2noij2]?nNP[CoWX:d1?nMOk<3oi]m/@CoVW^_1?nIN:d3oiQfZ`;oV7>X0_nA
KjP3oi5^Z0CoTVjV1?nCKZD3oi=]Y0OoU6fS1OnDK:83oi=[XP;oTV^R0_nDL:H<oi=_YP?oTfnW1OnD
L:P4oiEbZ@;oUgBZ00?oY8jmojJ@__nVT;h00onVT;h5ojNA_P;oYY2m0_nb`nH2ojnjhP?o00000_n]
]=d01?nDJYooTfVNoi=YW_nCJIh5oi5XW`;oTFRP00?oUffPoiU_XOnIKj400_nIKj45oi]bX`?oW7BU
1OnLMZL01?nLMjWoXGZXoj5jZ?nQNZP4oimiZ0CoWWVY1OnNNZ`01?nMO:koZXbfojZ<]_nZS;H5ojR<
^0?oYhfj00?o]j_=ok>WboncYl/00oncYl/2ok6Uc0?o_LWT1?nj`n42ok;_mP03o`000?nihoCoX^ci
00?oX^ci0_n^i?T3oicRo@;oYm_j0_nNc_P5oj?9m0;oYLC`0onO_^hDooooo`03o`000?oooooooooo
02Wooooo000Yooooo`03o`000?oooooooooo01Cooooo1?o1enX00oo0fNco^;?DokRce002okRce0?o
]k7D00?o[I_5oj^H`on[V<<00_n[V<<5ojVE`@;oZ9:o00?oWhBfoij2]?nNP[@00_nNP[@4oieo/`?o
Vgfa1?nJNjl4oiUh[@;oV7J[00?oTG2Yoi5_Z?nAKjP00_nAKjP4oi5^Z0?oTVjV1?nCKZD3oi=]Y0So
U6fS1?nDK:82oi=[XP03oiE`YonDL:KoU72V00;oU72V3?nCKjH3oi=_Y`GoU72X0onELZT00onQR[co
Y8jmojB>_@02ojB>_@CoYY2n1?nWTKh01?nfc>_o//?Vok;3i_nb`nH3o`0000;o[k[R1?nDJYl4oi=Y
WPCoTFRO00?oTFRPoiM]X?nGKJ001OnIKj44oi]bX`CoW7BU0onLMZL00onSOJWoXGZXoj5jZ003oj5j
Z0?oWgVX1OnNNJT3oiij[003oj^=]_nZS;KoZXbf00;oZXbf1OnXS;P00onWSK[o]j_=okN[c@02okN[
c@Co/jO;00?o/JG<okg9i?nmbN@00onmbN@01onj`n7o/^ofok;_m_nbkoKoQNW/o`000?n5jN`00_nR
k?T3ohWSnP;oW>;m0onGd?`4oik>n0;oXlWd0onM_^l5oinnkQCooooo00?o0000ooooooooool0:?oo
ool002Wooooo0ol0000Cooooo`Co`MOZ00?o^[KEokRce?nh/m@01?nh/m@01?ng/MCo[I_5ojfKaOn]
VlD3oj^H``CoZIG100CoXHNhoin4]_nOQ;KoWhBf1OnNP[@3oieo/`CoVgfa0onJNjl2oiUh[@;oTW6Z
0onAL:T4oi5_Z0CoTFjX0onBKZH4oi=^Y@?oTffT2?nDKJ<3oiA/XP04oiEaZ?nEL:OoUG2WoiE`Y`Go
U72V2onCKjH4oi=_Y`CoU72X00?oUG:Yoj6:_?nQR[`00_nQR[`3ojB>_@GoYY2n00CoYi6nokK<jonf
c>_o]/c[0ol00003ok;3iP03ojnjh_nFK9ooU6ZO00?oU6ZO1?nCJIh3oi5XW`04oiE[WonGKJ3oUffP
oiM]X0GoVFnQ1?nKLZ<4oiadY@;oW7JW0_nSOJT5oj5jZ0?oWgVX1OnNNJT00onNNZcoZhffoj^=]P02
oj^=]P?oZXbf1?nXS;P00onl/m7o]j_=okN[c@03okN[c@?o/jO;0_noeNX4okg9i0;oW??/00Oo/^of
ohGYk?n5jNcoQNW/of[Jk_l0003oJ][^00;oRN?j0on>d?h5oiO@o0;oW/kh0_nK_O05oifnk`;oWkk^
0_nN^^`Cooooo`;o0000:_ooool002Wooooo00?o0000ooooooooool04Oooool4ol7Dj004ol7Gj_nj
]]Go^[KEokZfe@Co^;?D00?o[ik7ojfKaOn]VlD00_n]VlD4oj^H``04ojVE`OnQQkSoXHNhoj67^0Co
WhBf1?nNP[@4oieo/`?oVgfa0_nJNjl00onCLZ_oTW6Zoi9aZP02oi9aZPCoTG2Y0onAKjP4oi5^Z0?o
TVjV1?nCKZD4oi=]Y0OoU6fS00CoU6bRoiEaZ?nELJSoUG6X1?nEL:L4oiA`YPcoTfnV0onCKjL2oiA`
Z0;oWXNj1OnQR[`3ojB>_@CoYY2n0_nhd^d3o`0000;o]/c[0_nb`nH4oiI/W`CoU6ZO1?nCJIh01?nA
J9ooUF^OoiE[WonEJil4oiM]X0CoVFnQ1?nKLZ<4oiadY@03oiafYonSOJWoXgfY00;oXgfY1?nQNZP3
oimiZ0CoWWVY00?o[8jfoj^=]_n[SKH00on[SKH4ojZ<]P;oZ8bh0onl/m45okN[c@03ok>WbonoeN[o
_mGZ00;o_mGZ00Go_LWToicck?nLlncoW??/oe7=a@04od?5e@;oJ][^00?o0000ohG=oon5cOl01?n>
d?h2oiO@o0;oVK[_1OnK_O02oifnk`;oWKOZ1OnN^^`Dooooo`03o`000?oooooooooo02Oooooo000>
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00005ooooo`03o`000?oo
oooooooo017ooooo1?o1e>P00onk^=Ko^[KEokZfe@03okZfe@03okRce?n_W/Oo[ik700;o[ik70on]
VlD3oj^H``03oj>:^_nQQkSoXHNh00?oXHNh0onOQ;H4oij2]0CoWGnc0_nKOK401?nEM:coTg:[oi=b
ZonCLZ/4oi9aZPCoTG2Y0onAKjP4oi5^Z0?oTVjV1OnCKZD3oi=]Y0KoU6fS00?oUG:YoiEaZ?nELJP0
0_nELJP4oiE`Y`CoU72V3?nCKjH2oi=_Y`03oib4^?nNQk[oWXNj00?oWXNj1?nQR[`4ojB>_@03ojJ@
__nhd^go000000;o000000Co^=;]okK<jonfc>_oUfjQ0onGKJ05oiI/W`?oU6ZO0_nCJIh2oiAYWPCo
UF^O1?nGKJ04oiU_X@GoVg:S0onLM:D5oj=mZ@CoXGZX1?nONJP2oiiiZ@;o[8jf1On[SKH4ojZ<]P03
ojR<^?nl/m7o_;?A00;o_;?A1?ngZld00onoiO7o_mGZokoEjP02okoEjP03ofOI`On3/?;oPk3b00Co
Okgk1?mna_h01?n5cOoo0000oiJ/i_nF[>H4oiJdk0GoVK[_0_nK_O02oifbi`GoWKOZ1?nN^^`Eoooo
o`03o`000?oooooooooo02Kooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo00oooooo0oo2dNH0
0oo1e>So^kSFok^heP02ok^heP?o^[KE00?o/J;9ojnNaon_W/L00on_W/L4ojfKa@04oj^H`onSR[[o
XhZjoj>:^PCoXHNh0onOQ;H4oij2]0;oWGnc0_nFMZd3oiEd[0CoTg:[0onBLJX4oi5`Z@CoTFnX0onA
KZP4oi9^YPCoTfjU0onCKJ@2oiA]X`;oU7:Z0onELZT4oiEaZ0CoUG2W1?nDL:H<oi=_YP03oi=_YonL
Q;SoW8Bh00GoWXNj1OnQR[`2ojB>_@?o00000onhd^d4oiM^X@CoUffP1?nFK9l2oiAZW`03oi=YW_nD
JIkoU6VN00;oU6VN1OnEJil3oiM]X0CoVFnQ1OnKLZ<2oiadY@03ojJ0ZonSOJWoXgfY00?oXgfY1?nQ
NZP4oimiZ003oiiiZOn/S[Ko[8jf00;o[8jf1On[SKH2ojZ<]P03ol;1fOnl/m7o_;?A00Co_;?A00?o
]j_=okoUlOnoiO400_noiO400onoeN[oRj;Soh>`lP04oh>`lP;oOkgk00?oUiOBoiFRgOnEX]d00_nE
X]d2oiJ/iP03o`000?nF[>KoUZcV00CoU[C/0_nI^^l2oif^h`GoWK;W1?nM]nX2oijjk0?oXKSY5?oo
ool00ol0003oooooooooo`0Vooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0_l0000>ooooo`Co`]7V0_nm^]L5ok^heP04okZfeOna
X/Wo/J;9ok6Rb@Go[ik70_n]VlD00onUS[coXhZjoj>:^P02oj>:^PCoXHNh1?nOQ;H2oij2]003oiMh
[_nFMZgoUWJ]00;oUWJ]1?nEM:`3oi=bZ`CoTW6Z0onAL:T4oi5_Z0CoTFjX0onBKZH4oi=^Y@;oTffT
00?oTg:[oiAbZ_nDLZX00_nDLZX4oiEbZ@?oUG6X1?nEL:L4oiA`YP[oTfnV0_nKPKL4oib4^0CoWXNj
1OnQR[`2o`0000?o^=O_00?o^=;]oiM^X_nGKZ801OnGKZ43oiM]X0CoUVbO00?oU6ZOoi=YW_nCJIh0
1?nDJIh5oiE[W`?oUffP1OnIKj44oi]bX`04oiadYOnVP:_oYX2[ojJ0Z`CoXgfY1OnQNZP2oimiZ003
ojf@^?n/S[Ko[8jf00?o[8jf1On[SKH01?nZS;Ko`/7Iol;1fOo2`MT4okbcd@?o/OCb0_noiO44oh^R
h`;oPk3b0_nHSLH4oiNGdPCoUJ;M0_nF[>H00ol0003oUZcVoiJ/iP02oiJdk003oifWgOnM[^?oWJkS
00?oWJkS1OnM/^L2oifgjP;oX;?U1OnQ^>TDooooo`03o`000?oooooooooo02Gooooo000>ooooo`05
o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo
00_ooooo1?o2cn@00oo2dNKo_K[Gokfje`02okfje`?o^kSF00?o/jK;ok6RbOnaX/T00_naX/T4ojnN
a`03ojNA_onUS[coYHjl00;oYHjl0onSR[X5oj67^0?oWhBf00?oWX:doiMh[_nGN:h01?nFMZd4oiEd
[0?oTg:[1?nBLJX3oi5`Z@CoTFnX1?nAKZP3oi9^YP;oTfjU0_nALZ`3oi=bZ`CoU7:Z1?nELZT4oiEa
Z0?oUG2W1OnDL:H5oi=_YP;oVX2f1OnKPKL3oib4^0GoWXNj00GoXHZlo`000?l0003o0000okSHl@03
okSGk`CoUfjR1OnGKZ43oiM]X0;oUVbO1OnCJIh5oiAYWPCoUF^O0onGKJ05oiU_X@?oVg:S00?oZ8>]
ojJ0ZonVP:/00_nVP:/4oj=mZ@GoXGZX00CoWgVXojf@^?n]T;So[I2h1?n/S[H4oj^=]P03olODi?o2
`MWo`/7I00?o`/7I00Co_;?Aok7dl_nam?;o/OCb1?nATm82oh^Rh`;oVXFk1?nHSLH4oiNGdPGoUJ;M
0_nF[>H00ol0003oWZ7FoifWg@03oifWg@GoWJkS0_nM/^L2oj6^h0GoX;?U0_nQ^>T2ojJkj1Gooooo
00?o0000ooooooooool09?ooool000kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMg
MomVIVKooooo00Cooooo00?o0000ooooooooool02_ooool4ol;?i003okjleonm^]Oo_K[G00Co_K[G
00Co^kSFok>VboncY/_o/jK;1?naX/T00on_W/OoYi6oojNA_`02ojNA_`?oYHjl1?nSR[X4oj67^0;o
WhBf00?oVG^`oiMh[_nGN:h00_nGN:h3oiIf[@CoUGB/0onCLZ/4oi9aZPCoTG2Y0onAKjP4oi5^Z0;o
TVjV00?oT7:]oi5b[?nALZ`00_nALZ`4oi=bZ`?oU7:Z1?nELZT4oiEaZ0CoUG2W1?nDL:H2oi=_YPGo
VX2f1OnKPKL3oib4^0?oWXNj0ol00005okSHl@03okSGkonGKZ;oUfjR00CoUfjR1?nGKZ42oiM]X003
oiAZWonCJIkoTfVN00KoTfVN1?nDJIh4oiE[W`?oUffP1OnIKj401?nKLZ?oZ8>]ojR3[OnXPjd4ojJ0
Z`GoXgfY0onQNZP00on^U;co[I2hojf@^002ojf@^0Go[8jf0_n[SKH3olODi0?o`/7I00?oNNC;oiN9
`onGRL<00onGRL<2oi6CdP03oif0/onJQK_oVXFk00?oVXFk1?nHSLH4oiNGdP;oUJ;M0_nPV/l2oijQ
eP03o`000?nNXMKoWZ7F00CoWJOM0_nM[^<2oj:Xf`GoXJkP0_nP/nD2ojJgi@GoY[_X4oooool2o`00
00Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<00Wooooo000>ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooooooo
o`03ooooo`;o00002Oooool2ol;<hP?o`/oT0onn_=L4okfje`03okJ[c_ncY/_o/jK;00;o/jK;0ona
X/T00onYU/;oYi6oojNA_`03ojNA_`?oYHjl1?nSR[X2oj67^0;oVWfb0onINk04oiMh[PCoUWJ]0onE
M:`3oi=bZ`CoTW6Z1?nAL:T3oi5_Z0;oTFjX0_n?LZd3oi1b[@CoTG:/1?nCLZ/4oiAbZP?oUG:Y1?nE
LJP4oiE`Y`CoU72V00?oTfnVoiZ0]_nJP;H01OnJP;H4oi^1]`?oW8Bh0ol000000onNQk[o]MOaokGG
l@04okSHl@SoUfjR0onGKZ44oiAZW`SoTfVN1?nDJIh4oiE[W`CoUffP0onIKj400onXQ:koZ8>]ojR3
[@03ojR3[@?oYX2[1OnSOJT2oj5jZ0?o[YBl0on]T;P5ojb>]P03oj^=]_o7e>CoamCT00;oamCT00Co
`/7Ioib3]onLPkOoW8>g1?nGRL<00onPOZkoWH2coif0/`02oif0/`CoVXFk1?nHSLH2oiNGdP;oXiG7
1OnPV/l2oijQeP04o`000?nNXMKoWJOMoifWg@;oXj?E1OnRZ=/3oj6^h003ojNchOnV]nGoY[OU00?o
Y[OU0onV^nP2ojZojACooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B402Oooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool2o`0000Wooooo1?o2
c>800oo2cnCo_[cGokjle`03okjle`03okfjeonfZlko]Z_>00;o]Z_>1?ncY//01?naX/WoZIK2ojVF
`_nYU/84ojNA_`CoYHjl0_nSR[X00onLP;GoVWfboiYm/P02oiYm/PCoVG^`0onGN:h4oiIf[@?oUGB/
1?nCLZ/3oi9aZP;oTG2Y0_n@LZd7ohmb[@CoT7:]0onALZ`4oi=bZ`CoU7:Z0onELZT4oiEaZ0CoUG2W
0_nDL:H2oiZ1]`SoVX2f1?nKPKL3o`000003oib4^?nNQk[o]MOa00Co]MOa00?o^=SaoiE]X_nEKJ80
2?nGKZ800onGKZ7oU6ZOoiAZW`04oiAZW`SoTfVN1?nDJIh4oiE[W`CoUffP0_nIKj42ojR4[PGoZ8>]
0onVP:/5oj=mZ@03oj5jZ?n^U;co[YBl00;o[YBl1?n]T;P3ojb>]P;oaNg_0oo7e>@00onQOjooW8>g
oib3]`03oib3]`04oiN9`onPOZkoX7j^oj1n[PCoWH2c1?nJQK/3oiR=aP03ojJB`?nSULOoXiG700?o
XiG71OnPV/l2oijQeP03o`000?nSXmGoXj?E00?oXj?E1?nRZ=/00onQ[^3oYk?QojNch@02ojNch@Go
Y[OU00?oY[_XojZojOnZ_nT00_nZ_nTDooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000002Oooool000kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool00ol0003ooooooooo
o`06ooooo`;o`/WO0oo2c>83ol2nf0?o_[cG00?o^:o@okJ[c_nfZlh00onfZlh3ok>Vb`03ojbKaOnY
U/;oZIK200;oZIK21OnWTKl3ojF>_003oj>:^_nLP;GoW82e00CoVWfb1?nINk03oiMh[PCoUWJ]1?nE
M:`3oi=bZ`;oTW6Z00?oTG>]oi1b[On@LZd00_n@LZd7ohmb[@CoT7:]1?nALZ`3oi=bZ`CoU7:Z1?nE
LZT3oiEaZ0;oUG2W0_nJP[P4oiZ1]`SoVX2f00GoVh6go`000?l0003o0000oi^1]`02oib4^0?o/]Cb
0_neeo42oiA/XPCoUFfR1_nGKZ800onDJj3oU6ZOoiAZW`06oiAZW`OoTfVN1?nDJIh5oiE[W`?oUffP
00?oVFnQojR4[_nXQ:h00_nXQ:h4ojR3[@CoYX2[0onSOJT00onaW<;o[YBlojjD_003ojjD_0Co[I2h
00?o[8jfolG]koo5kNl00oo5kNl01?o7e>CoXGn_oj5o[onQOjl3oib3]`03ojEoZonPOZkoX7j^00?o
X7j^0onMP;<5oiZ5^`04oiR=a_nVT/3oYY;0ojJB`0CoXiG71?nPV/l01OnXWL_oYYo?ojJOconVWloo
000000GoXj?E0_nRZ=/2ojVag@GoYk?Q0_nV]nD2oj^mi`CoZ[oY00?o[<;Zooooooooool04_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooo
oonHV9So<S8b00Wooooo000Wooooo`03o`000?oooooooooo00Cooooo1Oo2bMl00oo2c>;o`;kHol2n
f003ol2nf004okjleonh[m3o^:o@okR_d0Go]Z_>00Co/jK;ojbKaOn/VlGo[9_50onYU/85ojNA_`;o
YHjl00?oWHBhoib0]OnLP;D00_nLP;D4oiYm/P?oVG^`0onGN:h4oiIf[@CoUGB/0_nCLZ/01?nBM:ko
TG>]oi5c[OnALjd5oi1b[@KoSg:]1?n@LZd4oi5b[0?oTg:[1?nDLZX4oiEbZ@;oUG6X00?oVHBkoiZ2
^?nJP[P00_nJP[P5oiZ1]`GoVX2f0ol00003oi^1]`;o[];c0onbe?800onBJj;oU6bRoiA/XP03oiA/
XP?oUFfR0onGKZ84oiA[X0SoU6ZO1onCJIh4oiAYWPGoUF^O0_nGKJ000onVPjooZ8B^ojR4[P03ojR4
[PCoZ8>]1?nVP:/00onSOJWo/Ic2ok6L`P02ok6L`PGo[YBl0_n]T;P3ojOgiP;oaNg_0_nTOJT4oj5o
[`04oib3]onUOj_oYGn[ojEoZ`GoX7j^1?nMP;<3oiZ5^`03ojV@^onVT/3oYY;000;oYY;01OnSULL0
1?nPV/ooZ9g;ojRMbonXWL/3ojJOc`04o`000?nVWlooXj?Eoj>Se@;o[:oJ1OnY/Md2ojNch@;o[KcU
1On[_NL00onZ_nWo[<;Zojc2jP02ojc2jQCooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c009ooooo`009oooool2o`0000Co
oooo0_o2a]d3ol;9g`03ol70fOo0_]So`;kH00?o`;kH00?o^kCCokR_d?nh[m000_nh[m04okJ[cP03
ojjPbOn/VlGo[9_500;o[9_51?nYU/82ojNA_`;oWhRk1?nMQ;P3oib0]@CoVWfb1?nINk03oiMh[P?o
UWJ]0_nEM:`2oi=e[P?oTWB^1?nALjd4oi1b[@OoSg:]0on@LZd4oi5b[0CoTg:[0onDLZX2oiEbZ@;o
VHFm0onIQ;/5oiZ2^0CoVX6g0onJP;H2o`0000?oVX2f00?oVh6gojkBlon^d_<00on^d_<01?nbe?;o
TV^Roi9[X_nBJj84oiA/XP?oUFfR00?oUfjRoiA[X?nDJj001?nDJj08oiAZW`OoTfVN1?nDJIh5oiE[
W`03oiM]X?nVPjooYX>_00GoZ8B^1OnXPjd2ojJ0Z`03okJZcOnaW<;o/Ic200?o/Ic21On^U;`00on]
T;SoYoOVojOgiP02ojMmYPCoY7fY1?nQOjl5ojEoZ`CoX7j^1?nMP;<00onJQK_oZI2kojV@^`02ojV@
^`CoYY;00_nSULL2ojbMa`GoZ9g;0onVWll00ol0003o[:oJojb_fP03ojb_fP?oZK7M00?o[kgUojfl
iOn]_>D00on]_>D2oj^mi`?o[/?Z1?n/`^XEooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41002Oooool002Oooooo00?o0000
ooooooooool00_ooool4ol;6g@04ol;9goo1`=Wo`L3Iol70f@?o`;kH0onk]=<4okR_d003okJ[c_n^
X<Wo[Z3900;o[Z390on/VlD3ojVF`P03oj6=__nOR;_oWhRk00?oWhRk0onMQ;P3oib0]@CoVWfb1?nI
Nk03oiMh[P;oUWJ]00?oU7J_oi=e[_nCMJh00_nCMJh4oi9d[P?oTG>]1?n@LZd7ohmb[@?oT7:]1?nA
LZ`4oi=bZ`;oU7:Z00?oUhO0oiV5_OnIQKd00_nIQKd4oiV4^`CoVX:h1?nJPKL3o`0000?oVX2f0onZ
d?@4ojkBl`;oT6VR0onBJj84oiA/XP;oUFfR00?oTf^QoiA[X?nDJj001_nDJj07oiAZW`OoTfVN1OnD
JIh3oiE[W`03oj:0[_nVPjooYX>_00;oYX>_1?nXQ:h5ojR3[@04ojJ0ZonfZ/go]Z[=okJZc@Co/Ic2
1?n^U;`00omFbZKoTfZPoi1]YP03ojMmYPCoY7fY1?nQOjl5ojEoZ`GoX7j^0_nMP;<00on^T[WoZI2k
ojV@^`03ojV@^`CoYY;01On/WLL4ojRMb`05ojJOcon_[mSo[joHojn_f?l000001?n/[mX00onY/Mgo
[kgUojnmi@02ojnmi@?o[KcU0_n^aN/5ojk3jP;o[<;Z0_n/a>/Booooo`?o00001?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000009ooooo`009oooool01?l0
003oooooooooooooool4ol;6g@03ol;2fOo1`=Wo`L3I00?o`L3I00?o`;kHok^ddonk]=<00_nk]=<3
okR_d003ok6VcOn^X<Wo[Z3900?o[Z391?n/VlD01?nYU/;oXHfnoj6=__nQSKh4oin8^`?oWHBh1?nL
P;D3oiYm/P;oVG^`0_nEN[<3oiAh/@?oU7J_1OnCMJh3oi9d[P?oTG>]1?n@LZd7ohmb[@CoT7:]0onA
LZ`2oi=bZ`;oUHO21?nGQl04oiV5_@?oVHBk1?nJP[P01OnJPKOo0000o`000?l0003oVX6g00;oVX2f
0_nUc_H5oj[@m003ojkBlon@JJ;oT6VR00;oT6VR0onBJj82oiA/XP;oTfZQ0onCJj48oiA[X0OoU6ZO
2?nCJIh4oiAYWP;oUF^O0_nRP:h4ojJ3[`GoZ8B^0onXPjd00onn_m_o]Z[=okJZc@02okJZc@Go/Ic2
00Go[YBloi=ZX?nCJZ3oTfZPojUnY@04ojMmYPGoY7fY0_nQOjl2oj^3Z`CoYGn[1OnPOZh01?nMP;?o
[Y:iojjB^On^T[T4ojV@^`?oYY;00_nbXLH4ojbMa`?oZ9g;00?o/k;Gojn_f?n_[mP00_n_[mP01?l0
003o[joHojb_f_n/[mX2ok;1i@Go[kgU00?o[KcUojk5jon^aN/00_n^aN/2ojk3jP;o[LS]1On/a>/D
ooooo`09o`000?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@09ooooo`009_ooool3o`0000;o`/CL0oo2a]d3ol;2f@?o`L3I0_nm^MH5ok^dd`04
okR_d?naY/go/JK=ok6Vc@Go[Z390_n/VlD00onST/?oXHfnoj6=_P02oj6=_PCoWhRk1?nMQ;P3oib0
]@;oVWfb00?oUGbeoiEj/onEN[<00_nEN[<3oiAh/@CoU7J_1?nCMJh3oi9d[P?oTG>]1?n@LZd7ohmb
[@CoT7:]0_nALZ`00onCQ/;oUHO2oiF7`P03oiF7`P?oUhO01?nIQKd3oiV4^`;oVX:h0ol00004oiZ1
]`03oiZ0]_nUc_KoYLkf00;oYLkf0_nZd?@3ohmXX@CoT6VR0_nBJj800onBJJ3oTfZQoi=ZX@02oi=Z
X@?oTf^Q2?nDJj07oiAZW`SoTfVN1?nDJIh00onEJiooXX2^oj:0[P02oj:0[P?oYX>_1OnXQ:h01?nX
Pjgo_[oKokjofonn_m/4okJZc@Co/Ic20_nGJYd2oi=ZX0;oZGjU1?nWOJH5ojAmZ@04oj5o[on[Pj_o
Zh>[oj^3Z`CoYGn[1?nPOZh00oncU[Wo[Y:iojjB^@02ojjB^@GoZI2k00CoYY;0ok:Qa_nbXLKo/Z76
1On/WLL01?nXWL_o/k;Gok>beonc/]L4ojn_f003o`000?nb`NGo//7U00?o//7U0_n__ND2ojo9k@Co
[/G[0_n/c?04ojg8k@;o[<C[0_nZ`n`Eooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`00
0?o2a=co`/CL00?o`/CL00?o`/KMol;2fOo2`]T00oo2`]T00oo1`=Wo_KWFokfieP02okfieP?o^kCC
00?o]:gAok6VcOnaY/d00onaY/d3ojjPb@03ojJHaonST/?oXi;300;oXi;30onQSKh5oin8^`?oWHBh
0_nLP;D01?nFOkOoUGbeoiEl]OnEO;D5oiEj/`?oU7Ra0onDMZl4oi=e[P?oTWB^1?nALjd4oi1b[@Go
Sg:]00?oTH:ooi:4`OnBQ<400_nBQ<44oi>6`PCoUHO20onGQl04oiV5_@;oVHBk0ol00003oiZ2^0;o
VX6g1?nOc_P2ojG>mP?oSVNP0on?J:42oi1YXP;oTFVP0onBJJ04oi=ZX@CoTf^Q1onDJj07oiAZW`So
TfVN0_nDJIh2oiil[@GoXX2^0onVPjl4ojR4[P03olGNjonn_m_o_[oK00?o_[oK1?nfZ/d00onaW<;o
UfZMoiMZW@02oiMZW@03oi=ZX?nYOZGoZGjU00;oZGjU0onWOJH4ojAmZ@03okB>[_n[Pj_oZh>[00;o
Zh>[1OnUOj/2oj1n[P;o/iJi1?n^T[T4ojV@^`03okVYb_nbXLKo/Z7600;o/Z761?n/WLL00ong^=[o
/k;Gok>be`03ok>be`05ojn_f?ndb>Wo]<SYokC8jOl000000onb`ND2ok3?l0Co[lW]00?o[/G[ojc<
l?n/c?000on/c?02ojg8k@;oZLK^1?nZ`n`Dooooo`03o`000?oooooooooo01kooooo000Kooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooool;4g002ol;4g0?oa<CJ0oo2`]T00ono
_]Wo_KWFokfieP04okfieP04ok^ddond[M7o]:gAokB]d@Go/JK=00Co[Z39ojJHaonVV<OoYYS70onS
T/<4oj6=_PCoWhRk0_nMQ;P01?nGP[[oUWngoiIo]onFOkL4oiEl]@CoUGZc0onDN;43oiAf[`CoTgF^
1?nBM:h3oi5c[@CoT7:]0_n?LZd00onBPKgoTH:ooi62_`02oi62_`CoTXC10onCQ/84oiF7`PCoUhO0
0_nIQKd3o`0000;oVHBk0_nJP[P4oiW=nP;oWlkh0on>IYl4ohiWX0;oSfRQ00?oTFROoi5YX?nAJJ00
0_nAJJ03oi9YX0CoTfZQ1?nCJj47oiA[X0SoU6ZO1_nCJIh00onJN:_oWWb]oiil[@02oiil[@GoXX2^
1?nVPjl2ojR4[P?oaMk[1?nn_m/2okJZc@CoVfbL0onGJYd5ojUnY@CoYgfV0_nTOJT2okB>[PCoZh>[
1OnUOj/01?nPOZko/iJiok>F^OncU[T5ojjB^@04ojV@^oniZL[o^JW:okVYbPGo/Z7600?o[9g7okNh
f_ng^=X00_ng^=X3ok>be`;o]mC_1?ndb>T00ol0003o/<o`ok3?l003ok3?l0;o[lW]0_n[d?@4ojc<
l003ojS9lOnYa^koZLK^00?oZLK^0_nZ`n`2ojO2kACooooo00?o0000ooooooooool07Oooool001_o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`04o`000?oooooooooool;4g0Goa<CJ00Co`/;I
oknnfOno_]Wo_kkI1?nm^MH00ong]=Ko]:gAokB]d@03okB]d@;o/JK=0_nYW/`4ojJHa`?oXi;31?nQ
SKh2oin8^`;oV8Fn0onGP[X4oiIo]`?oUGbe1?nEN[<3oiAh/@?oU7J_1OnCMJh3oi9d[P;oTG>]00?o
U82koi>0_?nCP;`00_nCP;`4oi:1_@?oTH:o1?nBQ<43oi>6`PGoUHO20_nGQl03o`0000;oVHFm0_nI
Q;/4oi;=o0;oVLgj0on?IYl3ohiVW`;oSVNP0_nAIil3oi5XW`CoTFVP1?nBJJ03oi=ZX@CoTf^Q1onD
Jj08oiAZW`GoTfVN0_nJN:/5oiil[@CoXX2^1?nVPjl00onXQ:koaMk[olGNj`03olGNj`;o_[oK0_nN
Ki`5oi]/W0?oUfZM1OnYOZD4ojMmYP03ojAmZOndSZko]8j^00;o]8j^0on[Pj/4ojEoZ`03okZN_Onc
U[Wo/iJi00?o/iJi0on^T[T00oo4_M?o^JW:okVYbP03okVYbP?o/Z7600?o_LGQokNhf_ng^=X00ong
^=X00onc/]Oo]mC_okODk`03okODk`;o]<SY00?o[MOfo`000?n]eoH00_n`co02ojOFn0GoZm3d00?o
[<c`ojS9lOnXbO400_nXbO42ojW6kP;oY/?^1OnW`^dCooooo`;o00007_ooool001_ooooo00Go410@
oooooooooooooooooa0@4006ooooo`;o00000_ooool4olC4fP03ol;4g?no_]Wo_kkI00?o_kkI00?o
_KWFokNde_ng]=H00_ng]=H3okB]d@03ojbVdOnYW/coZIk<00?oZIk<0onVV<L4oj>B``;oXHfn00?o
VX[1oiR5__nHQKh00_nHQKh4oiN2^P?oUWng0onEO;D4oiEj/`CoU7Ra0onDMZl4oi=e[P;oTWB^1OnD
P;/4oi>0_0?oTX6m0onAP[l4oi:4`@CoThK20onEQl83o`0000?oRLSm1?n=bod2oi;=o0CoT6JN0on?
IYl2ohiVW`03oi5WW_nAIiooTFNO00;oTFNO0onAJ9l4oi5YX0CoTVVP0onCJZ44oi=[X@SoU6^P1onD
JYl2oi=YWP;oV7FZ1?nJN:/4oiil[@GoXX2^0_nVPjl3okchkP;oaMk[0onRLih3oii_W0GoVfbL0_nG
JYd2oj^1YPCoZGjU1?nWOJH5okB>[PCoZh>[0_nUOj/3okZN_@Co/iJi0_n^T[T3olBmd`Co^JW:00?o
/Z76okg5hOnmaN400_nmaN43okNhfP?o/nGg0_nge>l2ojGPn`Co[MOf00?o0000ojOFn?nWe_P00onW
e_P2oj_@m0;oYLcd1?nXbO42ojG4l0CoY/?^0_nW`^d2ojFok1;ooooo00?o0000ooooool000007_oo
ool001_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o
a<CJol;4g?o2a=`00_o2a=`3oknnf@?o^[_J1?ng]=H01?nd[M7o[:KAojbVdOn/Y]44ojVNc0CoYYS7
0_nST/<00onKSlKoVX[1oiZ:`@02oiZ:`@?oV8Fn1?nGP[X3oiIo]`?oUGbe1OnEN[<3oiAh/@?oU7J_
0_nCMJh2oiB1^`OoU82k1?nCP;`3oi:1_@CoTH:o1?nBQ<43oi>6`P03oiF7`_l0003o000000;oR/Ck
1On9b?d2ohg;o@?oTFRO1?n@IYh2ohmVW`CoTFNN1?nAIil4oi5XW`?oTFVP1?nBJJ04oi=ZX@?oTf^Q
2?nDJj06oiAZW`03oiIcZOnHMJ[oV7FZ00;oV7FZ1?nJN:/4oiil[@GoXX2^00CoYX>_okchk_nln>ko
_?S^0_nVN:44oj9cWPCoWVnL1?nKK9`01?nGJYgoZh6Voj^1Y_n[PJH4ojUnY@CoYgfV1OndSZh4oj^3
Z`03ojEoZonjW[go^Yjm00;o^Yjm1?ncU[T00on^T[Woa;gColBmd`02olBmd`?o^JW:0_nmf^h5okg5
h@04okNhf_nciOOo/nGgok?Um`;oT>?l1?nUh?/01On]eoKoWm[loioJo?nOf_co000000;oYmKh0onQ
c_L4ojG<m003ojS9lOnUa?3oYLC`00?oYLC`0_nV`nh00onT_ngoYKo/ojFok003ojFok1Cooooo00?o
0000ooooooooool06oooool001_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo00?ooooo1Oo2a=`00ono_]Wo^[_JokZkfP03okZkfP;o]kCF00?o[joGojbVdOn/Y]400_n/
Y]45ojVNc0;oYYS700?oWYG:oi^?a_nKSlH00_nKSlH3oiZ:`@CoV8Fn0onGP[X4oiIo]`?oUGbe1?nE
N[<2oiAh/@04oi>2__nDP[coU8:loiB2_0CoU86k1onDP;/4oi>0_0CoTX6m0onAP[l2oi:4`@?oU;W`
0ol00002ohjom`?oR/Ck0_n9b?d01?nFKJ;oTfZPoi=ZX?nCJZ03oi5XW`;oT6JN2?nAIih5oi5WW`?o
TFRO0onAJJ04oi9YX0CoTfZQ0onCJj48oiA[X0;oU6ZO0_nFLZP3oiIcZ@GoV7FZ0onJN:/5oiil[@?o
XX2^0_n?kLT00onZOjKoYWRQojIhX@02ojIhX@CoXW>N1?nNKi`3oi]/W003ojf5Z_n[PJKoZh6V00;o
Zh6V1OnYOZD2ojMmYP;o`J2h1?ndSZh4oj^3Z`Go^Yjm0oncU[T2olkRi`Goa;gC00?o^JW:okgJk_nm
f^h00_nmf^h2okg5h@?oUnkc00?o/nGgoi3So?n@ho`00on@ho`2ojGPn`?oT]_n0_nOf_`00ol0003o
W<gioj7>m`04oj7>m`;oYLcd0_nSa?44ojG4l0GoY;o]0onU_n`00onU_^_oooooooooo`0Cooooo`03
o`000?oooooooooo01[ooooo000Kooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003o
ooooooooo`05ooooo`?o`/CL0onma=l3okZkfP03ok:hgOn_[mOo[joG00;o[joG1?n/Y]42ojVNc0;o
X9_@1?nNULX3oi^?aP?oVX[11?nHQKh4oiN2^P?oUWng0onEO;D2oiEj/`;oTX?01?nCP[h3oiB2_0?o
U86k2?nDP;/4oi>0_0?oTX6m0_nAP[l3oiRbj@?o000000CoU;W`ohjomon>_oOoVGFX0onHLJD4oiI]
XP?oTfZP0_nAJ9l00on@IiooTFNNoi5WWP09oi5WWPCoTFNO0onAJ9l4oi5YX0?oTVVP1?nCJZ44oi=[
X@KoU6^P1OnFLZP4oiIcZ@CoV7FZ0onJN:/5oiil[@03oj:0[_n?kLWoSng900?oZWnV1?nVN:44oj9c
WPCoWVnL0_nKK9`2ojf5ZPCoZh6V1OnYOZD01?nWOJKo`J2hol6P^?o1X;P5okB>[P;oZh>[0_o1[lP5
okZN_@03ok>F^Oo>h^Ooc^;W00;oc^;W0_o4_M<3ojGamP;o_M[^0_m;bKl3occ0fP;oJ=S_0omfc_l4
oh?Go`;oT]_n0onFb_X2oic=n@04o`000?nLcOWoXLkgoj7>m`;oX<;a1OnSa?400onUa?3oY;o]ojBo
k@06ojBok@04ojFok?nU_^_oYKk[ojFnjaCooooo00?o0000ooooooooool06_ooool001_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00001oooool00oo2a=co_LCOokg4g`03okg4g`04okZk
f_nb^=go/[SMok:hg@Co[joG0_n/Y]400onRXmKoX9_@oj2Kd003oj2Kd0?oWYG:0onKSlH4oiZ:`@?o
V8Fn1?nGP[X2oiIo]`04oi:6a?nBQL;oTXG2oi:5`PCoTX?01?nCP[h3oiB2_0CoU86k1onDP;/2oi>0
_0;oW:WO1?nK[N<01OnH/^Wo0000o`000?l0003oV;;Y00;oU;W`00CoVgZ]oiUeZ?nIMJSoVGFX0onH
LJD4oiI]XP;oTfZP00CoT6RPoi1WWon@IiooT6NO2onAIih4oi5WW`?oTFRO1?nAJJ03oi9YX0CoTfZQ
1?nCJj45oiA[X0OoUW:X0onFLjT4oiQeZP?oVWR[1?nNO:d00ol0003oWG6QoieaX@05ojYoYP?oYWRQ
1OnRLih3oii_W003oi]/W?n]QJ[o[HFZ00;o[HFZ0on[PJH5ojUnY@Co`J2h1OndSZh01?n[Pj_o`Jo8
ol6_b?o1[lP4okZN_@;oT>g60oo>h^L3o`0000;oYO7f00?oSjOUoh6dm_n1]?H00_n1]?H5ogS4oP;o
M/ko0_nB_?<5oi?5n0;oU/[j0_nL^Nd2oijol003o`000?nN_o3oX<;a00?oX<;a0_nSa?42oj>mk0Oo
Y;o]0_nT_N/5ojFnjaCooooo00?o0000ooooooooool06Oooool001_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`03o`000?oooooooooo00Oooooo1?nma=l00one`nCo/[SMok:hg@03ok:hg@;o
[joG00?oYJcLoj:Se_nRXmH00_nRXmH4oj2Kd0?oWYG:1?nKSlH3oiZ:`@;oV8Fn00?oTX_9oi:8a_nB
R<H00_nBR<H4oi:6a0?oTXG20onBPl04oi>2_P?oU8:l1?nDPK/6oiB0^`03oi^VgOnLZMooW:WO00?o
W:WO00CoVjgSo`000?l0003o00000_nH/^T2oieo/P?oVgZ]0onIMJP2oiQaY@03oheYXon?J:;oSfRR
00;oSfRR0on@J:03oi1WW`_oTFNN1?nAIil3oi5XW`CoTFVP1?nBJJ03oi=ZX@CoTf^Q0_nDJj02oiIa
Y`SoUW:X0onFLjT4oiQeZPCoVWR[0_nNO:d01?nKKiooWG6QoieaXOnMLJ45ojYoYP?oYWRQ1OnRLih3
oii_W0Go[HFZ1?n[PJH3ojUnY@;of<g?1?o1X;P3okB>[P03olSDhoo1[lSo`Jo800;o`Jo80onjW[d4
oi3]aP03olkRionJW=GoVYcE00;oVYcE1?n?YnD4oh6dmP;oN<Cn0_nG/^X5oi:ll`;oTlGh0_nM/nL5
oibik@;oW[o`00?o0000oj:kjonR^n/00onR^n/4oj>mk0;oY;o]0onT^nX4ojBmj`CoYKk[5?ooool0
0ol0003oooooooooo`0Iooooo`009Oooool00ol0003oooooooooo`08ooooo`03okg4gone`nCo]L?T
00;o]L?T0onb^=d00onW]N?oYJcLojF/g002ojF/g0CoXZ?F1?nPVm03oijEbP;oVho600CoTi?@oi:?
c?nBSlcoTXo<1?nBRlT4oi:8aP?oTXK40onBQL84oi:3`0CoTh:n0onDP[`3oiB1^`;oU82k0_nJY=`4
oi^Vg@;oW:WO0ol00002oi^]h`03oin5]onMOk;oWGnb00;oSVjZ0on=JjL3oheYY@?oSFVS1?n?J:83
oi1XX0CoT6NO2_nAIih4oi5WW`?oTFRO1?nAJJ04oi9YX0?oTfZQ0_nCJj46oiIaY`SoUW:X0onFLjT4
oiQeZPCoVWR[00?oWWb]oi]_WonKKil00_nMLJ42ojn9[@CoZWnV0onVN:45oj9cWP;oWVnL00?o[hba
ojf5Z_n]QJX00on]QJX4oj^1YP;oZGjU0ooHcLl4ol6P^003okB>[_o8e>?ob=CS00;ob=CS1?o1[lP0
0onjW[goVYkGojVF`P04oj:Gb@GoVYcE0_n?YnD00onSX]CoWJSNoifXgP03oifXgPCoUk;Z0_nB_?<2
oin/h0GoWK?W0_nL^Nd2oj:di@;oX[SX00?o0000oj:hj?nR^n/01?nR^n/2oj>mk0;oY;WX1OnT^nX2
ojBmj`;oYKcZ1?nU_^/Booooo`03o`000?oooooo000001[ooooo000Uooooo`03o`000?oooooooooo
00[ooooo1?ne`n@01?nb^=goYkGSojNehonW]N<3ojF/g0GoXZ?F0_nPVm001?nFWMWoU9SDoiBHe?nD
V=@4oi>Cd0?oTXo<1?nBRlT3oi:8aP?oTXK40onBQL84oi:3`0CoTh:n0onDP[`2oiB1^`;oUj;L1?nJ
Y=`2oi^Vg@?o000000?oW:WOo`000?l000000onALZ`4ohi^ZP?oSF^W0on=JJD3oheYX`CoSfRR0on@
J:04oi1WW`[oTFNN1?nAIil3oi5XW`CoTFVP1?nBJJ02oi=ZX@WoUW6W2?nFLZP3oiIcZ@GoV7FZ0_nJ
N:/4oi]_W`04oieaXOn_RJgo[hV]ojn9[@CoZWnV1?nVN:44oj9cWP04oii_W?n_S;7o[hbaojn</@Co
[HFZ1?n[PJH00onYOZGof<g?omS=c`02omS=c`?o`J2h0_n:kM/5olSDh`;o`Jo800?oVYkGojVF`_nY
U/800_nYU/84oj:Gb@?oVYcE00?oZIo<oj>Re?nSX]@00_nSX]@5oifXgP;oUk;Z00?oXjOIoin/h?nO
[>000onO[>02oifci`;oY;3P1OnR]>D2oj:hj004o`000?nR^>SoX[_[oj:kj`;oY;OV1OnT^NP2ojBk
jP;oY[_X1OnU_>X2ojFnj`;oYkkZ5?ooool00ol0003oooooooooo`0Gooooo`009Oooool2o`0000co
oooo0_ne`n@2ojS0j`CoYkGS0onU[=`2oj:SeP;oUjCN1?nFWMT3oiBHe0?oTi?@0onBSl`4oi:;b@?o
TXS61?nBQ/@3oi:5`P?oTX?00_nCP[h2oi6Ng@?oU:3L1OnGX]`3oiZTg0;o000000CoVjKMo`000?l0
003o00000_nDMjl3oi5b[0CoSVjZ0on=JjL3oheYY@CoSFVS0on?J:83oi1XX0CoT6NO2_nAIih4oi5W
W`CoTFRO0onAJJ02oi9YX0;oUW:W2onFLJL8oiIbZ0CoUW>Y1?nHMJX00onJN:_oVFjOoi]_W`02oi]_
W`03okBF^?n_RJgo[hV]00;o[hV]1?nZOjH4ojIhX@?oXW>N00?o/IVnojn</On_S;400_n_S;44ojf5
ZPCoZh6V00?oZ_>fomS=cooHcLl00ooHcLl00oo1X;SoR^gKoh[]f`02oh[]f`;ob=CS0onSU/P00on_
V;ooZIK2ojVF`P03ojVF`PCoXYO900?oVYcEojVOc?nYWl`00_nYWl`4oj>Re0;oWJSN0_nXY=84oj>W
f@?oWjcP00?oYjgKojB`h?nT/>000onT/>04oj:di@;oX[SX00?oYKCSo`000?nU]><01?nT]nH2ojBi
j0;oY[[W1OnV^nP2ojFljP;oYkgY1OnW_^XCooooo`03o`000?oooooooooo01Oooooo000Tooooo`03
o`000?oooooooooo00gooooo1?nX`>/2ojNeh`;oV;?Z0onHZn@4oiNTgP?oUYgI0onDV=@3oi>Cd0Co
TXo<1?nBRlT3oi:8aP?oTXK40_nBQL800on=W=goSigMohnMg@02ohnMg@CoTIkM0onDX=`4oiNRg0Go
00000onHO;84oiAg[`?oTG:/0on>KZX3ohe[Y`CoSFVU0on=JJ<3ohmXXP?oT6RP1?n@Iil:oi5WWPGo
TFNO0onAJ9l2oi5YX003oiIbZ?nFLZOoUW:W00;oUW:W3?nFLJL8oiIbZ0?oUW>Y0_nHMJX4oiU^W`;o
VfnO0_ndU[P4ojn9[@CoZWnV1?nVN:42oj9cWP;o/IVn1?n_S;45ojf5ZP;oZh6V0onZlkH2omS=c`03
ojF:^?nNRkoo[9:k00?o[9:k1?nYTkl01?nSU/So[iRoojnH_on_V;l4ojVF`P?oXYO900?o[Yk7ojVO
c?nYWl`00onYWl`3oj>Re003ojfTc_nXY=;oZ:CB00?oZ:CB1?nSYmT01?nO[>3oYjgKojN]fonW[M/5
ojB`h0;oX[CU0_nW/^43ojFdh`04o`000?nU]>?oY;OVojBgiP;oYkSU1?nV^^L2ojJkj0?oYkcX1?nW
_NT2ojNnjP;oZ;oZ5?ooool00ol0003oooooooooo`0Fooooo`009?ooool00ol0003oooooooooo`0>
ooooo`;oZ<3[0_nH^o44oiRcjP?oV:_T0onGY=h4oiJMf@?oU9SD0onCTm02oi:?c003ohVLgon:Vmko
RY_N00;oRY_N0on;Vmd3ohbKg@CoSIcM1?n?WMd3oi6Ng@CoU:3L0ol000000onPR;[oW8:foib2]P02
oib2]PCoV7bb0onDMjl3oi5b[0?oSVjZ0on=JjL4oheYY@?oSFVS0on?J:84oi1XX0?oT6NO2onAIih4
oi5WW`?oTFRO00?oTFVPoiIbZ?nFLZP01OnFLZL;oiIaY`SoUW:X0_nFLjT4oiQ/WP?oVFjO00?oVfnO
okBF^?ndU[P00_ndU[P3ojn9[@GoZWnV0onVN:400onRLiko/IVnok6I_P02ok6I_P?o[hba1On]QJX0
0on[PJKoZH^fojV;]P02ojV;]P;oYHZh00?o[iBkojbB^on/T[/00on/T[/4ojVC_`Co[iRo1OnYU/80
1?nRUlWo[Yk7ojjNaon^W/L5ojVOc004oj>Re?n]Y<ko[JC>ojfTcPCoZ:CB0_nSYmT3oj^[e`CoYjgK
0_nT/>02ojVagPGoYk;Q0_nU]><00ol0003oZ;OSojNhi@04ojNhi@;oY[[W0_nX^nL5ojNlj0;oYkgY
0_nX_^T4ojRojQCooooo00?o0000ooooooooool05Oooool002Cooooo0ol0000?ooooo`CoV;_a1?nH
/nX3oiR[i0?oUjCN0_nFWMT01?n9Y>KoRJ7TohVQi?n9XN@3ohVNh@CoRIcO1?n:Vmh3oh^Kg@?oS9_M
0on=W=d5ohnMg@?oTIkM0ol000001?neZ/ko/:;9oj28^_nPR;X4oib2]PCoV7bb0onDMjl3oi5b[0Co
SVjZ0on=JjL3oheYY@?oSFVS1?n?J:83oi1XX0?oT6NO2onAIih4oi5WW`;oTFRO1OnFLZP4oiIbY`_o
UW6W2?nFLZP00onFLjWoV6bNoiQ/WP03oiQ/WP;oVFjO00?o^JO7okBF^?ndU[P00ondU[P4ojn9[@Co
ZWnV0_nVN:400one/=Co/IVnok6I_P03ok6I_P?o[hba1?n]QJX00on/SKKoZH^fojV;]P03ojV;]P04
ojF:^?n_U;_o[iBkojnD^`Co[9:k0onYTkl2ok>L`0?o[iRo1?nYU/800oncXLKo[Yk7ojjNa`02ojjN
a`CoZIo<00?o/ZO=ojfTc_n]Y<h00_n]Y<h3ojRTdP03ojn/e?n[ZmOoZj_G00CoZj_G0_nW[M/00on]
/McoZK7NojVagP03ojVagP?oYk;Q00KoZ[KRojRghonX]n?oZ;OSo`000?nX]n<2ojNhi@;oZK_V1OnX
^nL2ojNlj0;oZKkY1OnX_^T2ojRojP;oZL3Z4_ooool2o`0000Wooooo1?l000000ol@413ooooooooo
o`07ooooo`009?ooool00ol0003oooooooooo`0@ooooo`CoV;_a0_nH/nX01?n8/O3oRJc]ohV/kOn9
[>d4ohVXj@?oRJCV0on9XN@3ohVNh@CoRIcO0on:Vmh4oh^Kg@?oS9_M0on=W=d2ohnMg@;oALCT0ol0
00001?nh/M;o]J[>okFZc_nUSkh4oj28^PCoW8:f0onHO;83oiAg[`?oTG:/1?n>KZX3ohe[Y`?oSFVU
0on=JJ<4ohmXXP?oT6RP0on@Iil;oi5WWP;oTFNO0_nFLjT7oiIbZ0CoUW:W2onFLJL6oiIbZ0CoUV^N
1?nHK9h01?nIKYoo^JO7okVWaoniYlL4okBF^0Co[hV]1?nZOjH01?nVN:7o]K3DokF`e?ne/=@4ok6I
_PCo[hba0_n]QJX3ojb=]P?oZH^f00?o/INlojnD^on_U;/00_n_U;/5ojbB^`04ojVC_oncW<3o/ic0
ok>L`0Co[iRo00?oZIK2ok>Qa_ncXLH00_ncXLH4ojjNa`03ojVOc?nbYlgo/ZO=00;o/ZO=1?n]Y<h0
1?nXY=;o[jcDojn/e?n_[=@4oj^[e`03ojncfon]/Mco[K7L00;o[K7L1?nY/Mh00onW/^7oZ[KRojZf
hP02ojZfhP?oZ;OS00?o0000ojVki_nY^nH00onY^nH3ojRki`03ojVnj?nY_^WoZKkY00?oZKkY0_nX
_^T7ojW0jQ?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`002Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooooooo
o`0Booooo`?oQkKd0on8/O03ohV/k@CoRJSY0on9Y>H3ohVQi0?oRIkQ1?n9W=l3ohZKgP;oRi_M0omW
aOh4oeo8n`04oe?8lol0003o0000o`0000?o^;7B00?oZIO3ojF?__nUSkh00_nUSkh3oj28^PCoW8:f
0onHO;83oiAg[`?oTG:/1?n>KZX3ohe[Y`?oSFVU0on=JJ<4ohmXXP?oT6RP1?n@Iil9oi5WWP03oiId
Z_nFLjWoUW>Y00;oUW>Y1onFLZP4oiIbY`_oUW6W0_nFLZP00onCJ9koU6VNoiAYWP02oiAYWP?oUV^N
0onHK9h00onl_=Wo^JO7okVWa`02okVWa`Go]9Jh0on_RJd2ojYoYP;o[]Sf1?ne/=@5ok6I_P?o[hba
00?o[HFZojb=]_n/SKH00_n/SKH00onYRkKo/INlok6G_002ok6G_0?o[iBk1?n/T[/00ongX/Co/ic0
ok>L`002ok>L`0?o[iRo00?o]ZG8ok>Qa_ncXLH00oncXLH3ojjNa`03okJ/conbYlgo/ZO=00?o/ZO=
0_n]Y<h2ok:^e0Go[jcD00?oZj_Gojncfon_/m/00_n_/m/4ojfag0;oZK7N0_n/]n44ojZfhP05ojRg
hon[^nGoZk_Uo`000?n[^nD01?nY^nH00onX^nOoZKkXojVnj002ojVnj0?oZKkY2?nY`>X2ojW1jaCo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`002Oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0
003oooooooooo`0Cooooo`?oQkKd0on8/O03ohV/k@;oRJSY0_mh/oL4ogJdn0?oM;Kj0omb^O/4og2l
o@?oKL7n0_mWaOh3ol3Vl@?o00001?nk^=H01?nh/M;oZIO3ojVG`onYUl<3ojF?_P?oX8Rj1?nLP[H4
oiQl/P?oU7N_0onALZ`3ohi^ZP?oSF^W1?n=JJD3oheYX`?oSfRR0on@J:04oi1WW`GoTFNN0_nFMJ`3
oiIdZPCoUW>Y1onFLZP4oiIbY`[oUW6W1?nCJ9h4oiAYWP?oUV^N00?oV6bNokblfOnl_=T00_nl_=T3
okVWa`Go]9Jh0_n_RJd3ofCIg@?o[]Sf0one/=@5ok6I_P;o[hba0_n]SkL4ojb=]PGo/INl1?n_U;/0
1?n/T[_o]j;4okNRa?ngX/@5ok>L`004ojnH_onfYLSo]ZG8okJUb0Go/j7600Co[Yk7okJ/conf[<oo
]Zc?0onbYld00onf/mOo/ZkDok:^e003ok:^e0?o[jcD00?o/kOLojncfon_/m/00on_/m/2ojfag0;o
[kWP1On/]n42ojZfhP;o[;_U0on[^nD01?l0003oZk_UojVki_nY^nH2ojZnj0CoZKkX00?oZKkYojW0
j_nY`>X01?nY`>X7ojW1ja?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09oooo
o`002Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0
003oooooooooo`0Eooooo`?oO;7f0omk/_H3ogVbm`CoN;?g1?mf]?P3ogBfnP?oL[Wk0_m`_?d2od;2
i0;oX?3d0onnh_42o`0000?o_KgJ0_nk^=H2ojfNb0CoZIO30onUSkh4oj28^P?oW8:f1?nHO;83oiAg
[`?oTG:/0on>KZX3ohe[Y`CoSFVU0on=JJ<3ohmXXP?oT6RP1?n@Iil2oi5WWP03oiEf[_nFMJcoUWF/
00;oUWF/1?nFM:X3oiIcZ@OoUW:X1OnFLZL8oiIaY`03oi5WW_nCJ9koTfRN00;oTfRN1?nDJIh2oiI[
WP03okW?jonl_=Wo_;cI00?o_;cI1?niYlL2okBF^003oij2/onRQ[KoY8Ne00?oY8Ne1?nUQkD01?n^
f?Ko]K3DokF`e?ne/=@2ok6I_P;o[Y:j1On]SkL2ojb=]P;o/Y_01?naUk`3ojnD^`03okVZbongX/Co
]j;400?o]j;40oncW<000onh[<ko]ZG8okJUb002okJUb0Co/j7600?o^K?CokJ/conf[<l00onf[<l0
1?nbYlgo][?GokJceonf/mL4ok:^e003ojn/e?nc]mco/kOL00;o/kOL0on_/m/00on`^n;o[kWPojni
h003ojnih0;o[;OQ0_n^_ND5ojbki@;oZk_U00?oZkkXo`000?nZ_^P01?nZ_^P2ojVnj0;oZ/3Y0onY
`>X2oj[1j`WoZL7[4oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo0009
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05ooooo`?o00005_oo
ool3ogbamP?oNk;f0omi/_L2ogRcm`?oK[on1?mW`oh2oeg5n`;oA/KN0_mZg><2oj3`m0;o_^;a0ol0
00001Onm`Mgo_KgJokfmf_nm_M[o/JK=00Go[Ik80onYUl<4ojF?_P?oX8Rj0_nLP[H00onAM:ooSW2]
ohi`[@02ohi`[@?oS6f[0on9JjT3ohMYZ@?oQFR[0on4JZd01?n=JJGoSFVSoheYXon=JJ<3ohmXXP?o
T6RP0_n@Iil2oi9f/0?oUGJ^1?nFMJ`4oiIdZPCoUW>Y1onFLZP4oiIbY`GoUW6W00?oT6JNoi5WW_nA
Iih00_nAIih3oi=XWPCoU6VN00CoUV^NokW?jonicn_o^Lo[1Onl_=T2okVWa`03oij0/onQQKKoXXJf
00?oXXJf0onTQkD5ojF7]@04ojF8]_n^U[ko[YJnojjF_PCo[Y:j1?n]SkL01?n/SKKo/Y_0ok:K`?nb
Vl05ok6G_004ojnD^oniZ/_o^J[;okVZb`Co]j;400?o/ic0okR/c_nh[<h00_nh[<h4okJUb003ok>Q
a_ni/m?o^K?C00;o^K?C0onf[<l00ong^]_o][?GokJce`03okJce`;o/ZkD0_nd_=l5ok>gg004ojnc
fon`^n;o/;_Rok2khP?o[kWP00?o[l3VojjmiOn^_ND00on^_ND2ojbki@?o[<3X0on[_^P00ol0003o
Z[kXojZnj002oj_1jPGoZ/3Y00?oZL3Zoj[1jonZ`N/00_nZ`N/9ojW1ja7ooooo0ol00007ooooo`03
o`000?oooooooooo00Wooooo0009ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`04ooooo`03o`000?oooooooooo01Sooooo0omm/_D4ogVfn@?oM;[l0om^_oh2ofO3oP;o
GLod0omnhOL2ojKZnP05okcMl?l0003o0000o`000?nnh_401?nm`Md01?nm_M[o/JK=ok6VcOnaY/d4
ojfNb0CoZIO30_nUSkh01?nHOkOoU7ZcoiAj/onDN[<3oi5d[`CoSW2]0on<KJ/3ohU[Z@?oQfVY0on5
J:/4ohAZ[@?oQFf`0on9LK43ohid/PCoTWJ`1?nEMZh3oiIe[0CoUWBZ1?nFLjT7oiIbZ0CoUW:W0_nF
LJL01?n>IIooT6JNoi1VW_n@IYh4oi5WWP?oTfRN0_nDJIh3ojkImPCo^Lo[0_nl_=T2oieo/`04oij0
/onQQKKoXHFfoj65]PCoXXJf1?nTQkD3ojF7]@03ojfI`_n^U[ko[YJn00;o[YJn1?n^T[X3ojf?]`03
ok:Pa_nbVl3o/Y_000;o/Y_01?naUk`00onj]=?o^J[;okVZb`02okVZb`?o]j;400?o^KGFokR/c_nh
[<h00onh[<h3okJUb003okZlfoni/m?o^K?C00?o^K?C00?o]Zc?okNjfong^]/00_ng^]/3okJce`03
okG2i?nd_=oo];cO00?o];cO0_nc]m`2ok:oi0Go/;_R00Co[kWPojo0i_n_`>Ko[l3V0on^_ND2ojg1
j@Go[<3X0_n[_^P00ol0003oZl;Zoj_1jP03oj_1jP;oZ/3Y1_nZ`N/00onY`^_oZL7[ojW1j`07ojW1
j`kooooo1?l000000ooooooo0000ooooo`06ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05
oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Wooooo0omm/_D2ogVfn@;oPkoj1?mkaol2ofo>oP?oRmcn0onYhOX3o`0000;o_=g`0_nm`ml3okg1
g@03okB/dOnaY/go/JK=00;o/JK=1On]W/P2ojVG``04oib6^onHOkOoV7ngoiQo]`?oU7Zc1?nAM:l3
ohi`[@?oS6f[1?n9JjT3ohMYZ@?oQFR[0on4JZd3ohE]/0?oRG6a0on>M;85oi9f/0?oUGJ^1?nFMJ`3
oiIdZPCoUW>Y1onFLZP2oiIbY`;oS6FO0on>IIl3oi1VWPCoTFNN0_nCJ9h2oj;FnPGo[]Wf0_nicn/2
oiao/`;oWGnc00?oWhBgoj65]_nQQKH00_nQQKH4oj:6]PCoY8Ne00?oYHNeojfI`_n]VL800_n]VL83
ojjF_PCo[Y:j00?o[Hngok:Pa_nbX<H00_nbX<H4ok:K`004ok6G_?nj]=?o^[CCokZdd`Go^J[;00Co
]j;4okVee_ni]MKo^KGF1Onh[<h01?nfYLSo^[cKokZlfonj_=/3okVcd`;o]/;S1?ng^]/00onf/mOo
]L;TokG2i002okG2i0?o];cO0_naa>P4ok:oi0;o/;_R0_n_`nP5ojo0iP03ojjmiOn]`NWo[L7Y00;o
[L7Y0_n/`>P2oj_3j`?oZl;Z00Co0000oj_2j_n[`N[oZl7Z0_nZ`^/5oj[1j`CoZL;[2OnY`N/:oooo
o`?o00001Oooool00ol0003oooooooooo`03ooooo`03oeEEEOmVIVKo000000_ooooo0009ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo0_l0000K
ooooo`CoR;Kd0on3_oX2og_7o`CoTm?m00?oRmcnojWQn_l000000_l00003ok[GkP03okcMl?nm`moo
_L?O00;o_L?O00Co_L7MokB/dOnd[=7o]:cA1?naY/d2ojfNb0;oX8g01?nLQ[/3oiQo]`?oU7Zc0onA
M:l3ohi`[@?oS6f[1?n9JjT3ohMYZ@?oQFR[0on4JZd4ohE]/0?oRG6a0on>M;84oi9f/0?oUGJ^1?nF
MJ`3oiIdZPCoUW>Y1_nFLZP00on;IJ7oS6FOohaUW`02ohaUW`?oSVFO0on@IYh2oi5WWP?oV/Of1?nR
e_X2ojkImP;oVWjc0_nLOk<2oif3]`CoWhBg1?nQQKH4oj:6]P;oY8Ne00?o[Ig7ojfI`_n]VL800on]
VL84ojjF_P;o[Y:j00?o/ZK=ok:Pa_nbX<H00onbX<H3ok:K`003okRngonj]=?o^[CC00?o^[CC0oni
Z//00ong_n7o^KGFokVeeP03okVeeP;o^:c>0_nha^D5okZlf`03okVcdonf`^?o]/;S00;o]/;S0_ng
^]/2ok?9jPGo]L;T00?o];cOok74j?naa>P00_naa>P2ok:oi0;o[/K/1?n_`nP2ojo0iP;o[LC[1?n]
`NT00on[a>coZl?[oj_3j`03oj_3j`;oZl;Z00?oZ/?/o`000?nZ`^/01?nZ`^/2oj[1j`;oZL;/1?nY
`^/9ojW1j`Kooooo1?l00008ooooo`03o`000?oooooooooo017ooooo0009ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0
6oooool2ohRfm0;oV[c`1?nHaoP2oi?Co@05oj[Fmol0003o0000o`000?nhd>`01?njenh2okg5h0?o
_L?O00?o][;EokB/dOnd[=400_nd[=43ok6Vc@03ojFDaOnPSL3oX8g000?oX8g00onLQ[/3oiQo]`?o
U7Zc0onAM:l4ohi`[@?oS6f[0on9JjT3ohMYZ@?oQFR[1?n4JZd3ohE]/0?oRG6a0on>M;84oi9f/0?o
UGJ^1?nFMJ`4oiIdZP?oUW>Y0_nFLZP2ogmSZ0?oPVfb1?n<IIl3ohiUW`;oT6JN0_nD[NP5oi[7mP;o
X]Kj0_nJO[@2oiYn/`03oi^2]onMPkOoWH>g00?oWH>g0onOQ;L4oj65]PCoXXJf00CoY8NeojfMaon]
WLOo[Ig71?n]VL84ojjF_P04ojjB^_nbY/go/ZK=ok:Vc@Go/Z3600Co/Y_0okRngonh_]oo^;kO1?nj
]=<00oniZ/_o]koQokNoh@02okNoh@?o^KGF0_nbd>l4okS6i@;o^[cK0_ncb^`4okK2h`;o[Lka1?nc
bNX2okG2i0;o[lW]1?naa>P00on/bNoo[/K/ojk6k003ojk6k0;o[l?X0_n/a^d4ojg4j`03ojg1jOn[
a>coZlC/00;oZlC/0_n[`n/3oj[4k0;oZ/?/00Co0000oj[3k?nZ`^_oZ/;[0_nY`n`5ojW2k0CoZL;[
2OnY`N/2ooooo`?o00003?ooool00ol0003oooooooooo`0Aooooo`008_ooool00ol0003ooooooooo
o`0Mooooo`CoV[c`0_nHaoP01OnZbo7o0000o`000?l0003oZ]Kg00Co^=3/00?o^]O^okg5h?nmaN00
0onmaN001?nm`moo][;EokJbeOnf/]D4okB/d@04ok6VcOnUU<GoYIC5ojFDa@CoX8g00onLQ[/3oiQo
]`?oU7Zc0onAM:l4ohi`[@?oS6f[0on9JjT3ohMYZ@?oQFR[1?n4JZd3ohE]/0?oRG6a0on>M;84oi9f
/0?oUGJ^1?nFMJ`4oiIdZP;oUW>Y0_mnGJ43ogmSZ0?oPVfb1?n6O<44ohfBe0CoU:gX0_nJaoH3oiZ0
]P;oVWjd00?oVH2goi^2]onKP[L00_nKP[L4oif3]`?oWhBg1?nQQKH2oj:6]P;oZio;1?n]WLL5ojfI
`P;o[YJn00?o/JgDok:VcOnbY/d00_nbY/d4ok:PaP03okC9jOnh_]oo^;kO00?o^;kO0_nj]=<2ok;:
k0Go]koQ00?o^KGFok;@konbd>l00_nbd>l2okS6i@;oZm3d1?ncb^`00onf`^?o[Lkaojg>l@03ojg>
l@;o/lWZ0_n[cO84ojo9k@03ok74j?n/bNoo[<W_00;o[<W_0_n^a^`2oj[8k`Go[<K]0_n]a>/2oj[6
kP?oZlC/0_nYaNd5oj[4k0;oZ/?/00?o0000ojW3kOnY`n`00onY`n`4ojW2k0GoZL;[1onY`N/2ojS1
j`03o`000?oooooooooo00kooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000oooooooo
ool07_ooool2oiZll0;oZL3Z0_l00002oj[;l@;o]/WX0onhd>`3okc5h@?o_LGP00?o^;OHokJbeOnf
/]D00onf/]D2okB/d@03ojVLbOnUU<GoYIC500;oYIC51?nPSL04oib6^`?oV7ng0onDN[<3oi5d[`?o
SW2]0on<KJ/3ohU[Z@?oQfVY1?n5J:/3ohAZ[@CoQFf`0on9LK43ohid/PCoTWJ`0onEMZh3oiIe[0;o
UWBZ0omnFYd3ogiMX@CoOf>X0on2KK84ohIl`@CoSI;D0_nD[NP00onKPkSoUGjgoiMo]`03oiMo]`Co
VH2g0onKP[L4oif3]`CoWhBg0_nQQKH00onYXLkoZio;oj^Ob`03oj^Ob`?o[Ig71?n]VL800on_/m_o
/JgDok6]e002ok6]e0Co/ZK=00?o/Z36okC9jOndbNT00_ndbNT2okRng`?oZ];e1?nbb^`2okNoh@?o
YmKh0_nbd>l2oj;Dn@GoZm3d0_ncb^`3ojKAmP;o[Lka0_nTc_H5oj_=lP;o[lW]0onXc?82ojc9k`;o
Z<Wa1?nZb>l2ojc6k@;oZLO_1OnZa^h00on[a>coZLG]ojW5k@02ojW5k@;oZ/C/0_nYa>d3ojW3k@03
o`000?nY`ngoZL?/00?oZL?/1?nY`^`2ojW2j`?oZL;/0_nY`N/7ojS1ja3ooooo00?o0000oooooooo
ool04?ooool002;ooooo0_l0000Pooooo`?o00000_nY`>X00onZbo7o]/WXokK9j002okK9j003okS@
k?nlaN7o_<GQ00?o_<GQ00Co_LGPokRgf?nh]mSo^;OH0onf/]D00on]Y<ooZIc9ojVLb@02ojVLb@?o
YIC51OnPSL03oib6^`?oV7ng0onDN[<3oi5d[`?oSW2]0on<KJ/4ohU[Z@?oQfVY0on5J:/3ohAZ[@Co
QFf`0on9LK43ohid/PCoTWJ`0onEMZh2oiIe[0?oP5VK0omnFYd3ogiMX@CoOf>X0on2KK84ohIl`@?o
SI;D0_nCOKP3oiEn]`GoUgng0onIP;L3oi^2]`GoWH>g0onOQ;L01?nQQKKoZJ7>ojVQc_nYXLh4oj^O
b`Co[Ig700?o[IW2ojncfon_/m/00_n_/m/4ok6]e0;o/ZK=0_n^dO<3okC9j@;oXMSk1OnZd_D2ok;:
k0?oWMSl0_nWe_P2oi[Eo0CoX]Ci0_n[d?@3oikBnP;oY]7f0onOcoP4ojC>mP;oZlgb0_nTc?D4ojS<
lP03ojG:lonXbO7oZ<Wa00?oZ<Wa0_nZb>l2ojO8l@CoZLO_0_nZa^h3ojS5kP;oZLG]0_nXa>h5ojW4
k@;oZL?]00?oZ<?]o`000?nY`n`01?nY`n`2ojW2k0;oZ<;/0onY`^`2ojS1k0SoZ<7[4?ooool00ol0
003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0Looooo`?o000000?oooooojW0j_nY
`>X01?nd`nD2okK9j0;o^lCQ1?nlaN42okVlf`Co^;OH00Co][;EojfTcon]Y<oo[JC?0onYW<T4ojFD
a@CoX8g00_nLQ[/01?nAPl7oSGjnohen__n=O[h3ohYj_0?oR7Rk0on7Mk/3ohQi_0CoRF^Y0on7JJT2
ohEXZ`04oh^8bon8U=WoR9CIohRDf@GoOJO^1?mN^_d2oaVVcP;oSfNP0on8Gi`3oh=KV`?oP5VK0omn
FYd4ogiMX@?oOf>X0on2KK85ohIl`@03ohfBe?nCOk[oTgfh00;oTgfh0onEO[L4oiMo]`?oVH2g1?nK
P[L4oif3]`;oWhBg00?oYj7@ojVQc_nYXLh00_nYXLh5oj^Ob`;o[Ig70_n]^N44ojncf`;o/JgD0onV
eoT4ojkAl`03okC9jOnQf?_oXMSk00;oXMSk0_nZd_D3oiGHoP;oWMSl0_nEe?d5oi[Eo0;oX]Ci0onJ
dO/2oikBnP;oW<ki1OnOcoP2ojC>mP?oX<cf0onTc?D00onXc?;oYL[cojG:l`02ojG:l`;oZ<Wa0_nU
b?85ojO8l@;oZLO_0_nWa^l3ojS5kP;oYlG^1?nXa>h2ojW4k@GoZ<?]00Co0000ojS3kOnY`ncoZL?/
1onX`^`00onY`^coZ<7/ojS1k002ojS1k0SoZ<7[3oooool00ol0003oooooooooo`0@ooooo`008_oo
ool00ol0003oooooooooo`0Iooooo`?o00001_ooool3okC3i@;o^/?Q1?nka>400onlaN7o^KcKokVl
f`03okVlf`;o^;OH00?o/:cDojfTcon]Y<l00_n]Y<l4ojVLb@;oYIC500?oVY38oiJ9a?nFRL@00_nF
RL@3oi63`@CoSGjn0on:N[`3ohQh^`?oQgNk0_n8NK`4ohUl_P?oRX731?n;R</3ohRDf@GoOJO^0_mN
^_d2og]PY`?oSfNP0on8Gi`3oh=KV`?oP5VK0omnFYd4ogiMX@CoOf>X0on2KK82ohIl`@CoTgnj0onC
OKP3oiEn]`CoUgng1?nIP;L3oi^2]`;oWH>g0_nTWm44ojNQd0CoZJ7>0_n[Wl/2ojbmiPGo[KWQ0_n_
/m/2oj3Jo0GoY]Oi0_n^dO<3oiWJo@;oXMSk0onBeoh2oiGHoP?oU=?m0onEe?d2oi[Eo0CoV<ok0_nJ
dO/2oi_<n@CoW<ki0_nOcoP3oik:mP;oX<cf0_nQb?@5oj;9m0;oYL[c0_nSao84ojG8lP;oYlSa0_nV
a_05ojO6k`03ojS5k_nWaNkoYlG^00;oYlG^0_nXa>h2ojO3kPKoZ<?]00?oZ<;]o`000?nX`^`01_nX
`^`7ojS1k0OoZ<7[00?oZ<3[ooooooooool03Oooool00ol0003oooooooooo`0@ooooo`008_ooool0
0ol0003oooooooooo`0Fooooo`?o00002_ooool00ond`nGo^/?Qok[3h@02ok[3h@;o^lCQ0onj`=h3
okVlf`03ok>cfOn`[=Co/:cD00;o/:cD1?n]Y<l2ojVLb@03oinHcOnJT<SoVY3800;oVY380onFRL@3
oi63`@CoSGjn0on:N[`3ohQh^`?oQgNk0on8NK`3ohUl_PCoRX730on;R</4ohRDf@;oOJO^0on0IZ/3
og]PY`;oNenW00CoSfNPohQOW?n8GicoR5nL1?n3Fi/3oh1IV`?oOUZM0omnGJ44ogmSZ0;oPVfb00Co
NNGRoiF4__nEQ;koUHBn0onCOkX3oi=m^0?oUGjg1OnGOkL3oiV0]`;oVh:g00?oXIg@ojBOdOnTWm40
0_nTWm45ojNQd0;oZJ7>0_nZ`>X4ojbmiP;o[KWQ1?nKg?d3oj3Jo0;oY]Oi0onDfoh2oiWJo@GoT]On
0onFd_d2oiCCo@?oV/ci1?nHc_X2oiS?n`;oW<_h1OnKc?T2oic>n@?oW/Wf0_nNb_H2oj37l`CoXLSd
0_nRbO@2oj?6lPGoXlOb0_nUb?82ojG6l0CoY/K`0_nWa^l3ojK5k`;oYlG^1onW`nh4ojS3k@?oZ<;]
00?o0000ojS2k?nX`^`00_nX`^`:ojS1k0CoZ<7[1?nX`>/>ooooo`03o`000?oooooooooo013ooooo
000Rooooo`;o00005?ooool3o`0000kooooo1Onj`n45ok[0gP04okVlfonc/mWo/k?Iok>cf@Co/:cD
0_n]Y<l00onSWm7oWiS=oinHc@02oinHc@?oVY381?nFRL@3oi63`@?oSGjn0on:N[`3ohQh^`?oQgNk
0on8NK`4ohUl_P?oRX731?n;R</2ohRDf@03oi=m^?n7Kk3oQfn`00CoP6J[0_mkH:L3og]OY`?oR5nL
1?n3Fi/3oh1IV`?oOUZM0omnGJ43ogmSZ0;oY=Gi00?oVHg5oiF4__nEQ;h00_nEQ;h4oi=o^P?oTgfh
0onEO[L4oiMo]`;oVH2g00?oWYW>oj6Md?nQWM000_nQWM04ojBOd@?oYj7@0_nX`N`4oj[0jP;o[;gV
0onIg_h2oi_Lo@GoT]cn0onGe_d4oi?FoP;oT]On0onHdO/2oiKBo@;oWL_g1OnJc?T2oiS>nP?oWLWf
0onLboP2oi_<n@?oWlOd0_nNbOH2oj75lPGoX<Oc0_nQb?@2oj;5l@CoXlKb0_nSao82ojC5l0GoYLK`
0_nVa_03ojK4k`;oY/G_0_nV`nh6ojO3kP;oYl?]1OnX`nd2ojS2k@03ojS2k?l0003oZ<;/00?oZ<;/
2?nX`N`6ojS1j`CoZ<3[3Oooool00ol0003oooooooooo`0@ooooo`008Oooool2o`0001;ooooo0ol0
000Booooo`Go^/?Q0_nj`=h3okJkgPCo/k?I0_n`[=@00onWZ=OoXioAoj>Od@02oj>Od@?oWiS=0onJ
T<P4oiJ9a0?oTH?11?n=O[h3ohYj_0?oR7Rk0on7Mk/2ohQi_0CoRGbn1?n:PL<2oh^8b`04oj2>`OnC
OKSoTgfhoi=m^0?oQfn`0on0IZ/3og]PY`;oNenW0ommHZT4oh=KV`?oP5VK0omnFYd3ogiMX@04ogmS
Z?nTeOWoY=GiojCEn@?oVHg50onEQ;h4oi=o^P?oTgfh0onEO[L2oiMo]`;oVY?<1?nNVLh3oj6Md0Co
Y9oA00?oYj7@ojS1k?nX`N`00onX`N`2oj[0jP?oV=kn0_nIg_h3oiCMoP;oT]cn0onIeO`4oiOFo@;o
TmKn0onKd?X2oiSAn`;oWlWf1?nMboL2oi[<n@?oWlOd0_nMbOH2oj;4l@GoX<Kc0_nOao@2oj;4l@Co
XLGb0_nPao<2oj;4l@GoX/Ga0_nSa_82ojC4l0CoY<G`0_nUa_03ojG4k`;oY/C_1onV`nh2ojO3kP;o
Yl;]1?nW`nd2ojS3k@;oYl;/0onX`^`01?l0003oZ<;/ojS2k?nX`^`7ojS1k0KoZ<7[1onX`>/<oooo
o`03o`000?oooooooooo013ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Kooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00oooooo0_l0000Foooo
o`?o^/?Q0_ng`n<5okJkgP;o/k?I00?oZk3LojNXeonWZ=L00_nWZ=L3oj>Od@CoWiS=0onJT<P3oiJ9
a0?oTH?11?n=O[h3ohYj_0?oR7Rk0on7Mk/3ohQi_0?oRGbn0_n:PL<2ojjRb`?oX8k10onCOKP3ohM_
/0?oP6J[0omkH:L2og]OY`?oOF:Y0on2JJh01?n3Fi_oP5VKoh1IVon0FI/2ogiJW@03oi:8aOnNYmco
WZOL00?oWZOL00?oY=Gioh]i^_n:NKX00_n:NKX3ohal_0CoSh700onBQl@3oiJ=b0CoVY?<1?nNVLh4
oj6Md0;oY9oA0onW`N`2ojS1k0?oVMon0_nHg_h4oiKNoP;oU=gn0onLeO`2oiWEo0;oX<kh1?nNcoT2
oi_@nP;oXLSd1OnObOH2oig;m`?oXLKc0_nOao@2oj?4l0CoX/Ca0_nPa_<2oj?3l0GoX/Ca0_nQaO82
oj?3l0CoX/Ca0_nRaO42ojC3k`GoY<C`0_nTaO03ojG3k`;oYLC_0_nV`^h6ojK3kP;oY/;]1OnW`^d2
ojO3k@;oYl;]1?nW`^`2ojS2k003ojO1k?l0003oZ<7/00WoZ<7/0_nX`N/:ojS0j`gooooo00?o0000
ooooooooool03oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo0ol0000Iooooo`03ok[3hOng`n?o
]l?S00;o]l?S0onf^mh00on]^N;oZk3Loj^`g002oj^`g0?oYjSG1?nSWm42oinHc@04oiFLf?n@UmKo
T9OFoi2GeP?oS9?E1?n7TML3oh:Cf`?oO9SS1?meXnl4ofRdn`;oCl7f0oni]MD2ojjRb`04oi=j]?n8
KjooR6n_ohQ_[`?oP6N]0on7Kk03oh1VZ`?oNf2W0omkGjL2ogeRZ@CoPVV^0on9MKH4oi:8a@?oWZOL
1?n;NKX3ohYi^P?oS7bl0on?PL04oi:7a0?oUXg81?nJTl`4oijIcP;oXIg@0_nV_^/3ojO1k0?oV^3m
0_nIgoh3oiSNoP;oU]kn0onNeO/2oicEo0;oX/gg1OnPc_P2oik?n@;oXlOc1?nQb?@2oio9mP?oXlGa
0_nQa_<2ojC3k`GoXlC`0_nRa?42ojC2k`CoXl?`0_nRa?42ojC2k`GoXl?`0_nRa?42ojC2k`CoY<?_
0_nTa?03ojG2kP;oYL?_0_nU`^h5ojK2kP;oY/?^1_nV`^d9ojO2k@;oYl;/1OnW`N`00ol0003oZ<7/
ojS1k002ojO1k0CoZ<7/3_nX`>/<ooooo`03o`000?oooooooooo00oooooo0007ooooo`05oa0@4?oo
ooooooooooooool@41002oooool5o`0000Gooooo0_l0000:ooooo`?o00007Oooool5okO3h`04okJk
g_n]^N;o[KWRojfihPCoZk3L0onWZ=L2oj>Od@03oiVRfonEW=SoUIcH00;oUIcH0on@UmH3ohbCe@Co
Qi7G0on2Tm/3ogbHh`CoMJ?_0_mX]?/2ol35gP04ojFD`onLQ[_oW8Jkoib6^`?oTgZd0on8Kjl3oh1W
[@;oMV6]00CoQfn`oh1VZon0IZ_oP6J[0omkH:L3og]OY`?oOF:Y0on2JJh4ohUe]PCoTXS500?oWZOL
ohmm_?n;NKX00on;NKX3ohYi^P?oS7bl1?n?PL03oi:7a0?oUXg81?nJTl`2oijIcP?oYK_Y1?nV_^/0
1?nW`NcoV^3moi[PoOnJh?d3oi_Oo@;oV=kn0onQeOX2oikEn`;oXlgf1?nRcOL2oj3>n0?oY<Ob1?nS
ao<2oj78m0?oY<C`0_nSaO42ojG2kPCoY<?_0_nSa?03ojG2kPCoY<;_0_nS`o02ojG2kPCoY<;_0_nS
`o02ojG2kPGoY<;_0_nT`nl5ojG2kP;oY/7]1?nU`^h2ojK2kP;oY/7]1onV`^d2ojO1k@KoYl;]2OnW
`N`00ol0003oYl7/ojO1k003ojO1k003ojS1k?nX`>_oZ<3[00CoZ<3[0_nW`>/7ojS0j`;oYl3[2ooo
ool00ol0003oooooooooo`0?ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool00ol0003oooooooooo`06ooooo`?o00008Oooool2okO3h`?o[l;X
1?n]^N82oj^`g004oj2`honMZ=koWJSNoifXgPCoVJ;K0onEW=P3oi2GeP?oS9?E1On7TML3oh:Cf`?o
O9SS0_meXnl3olCBi@04ol35g_nUU<?oYIC3ojFD``?oW8Jk0onCN[@3ohQ_[`;oP6N]0omfHJd4oh1V
Z`;oNf2W0omkGjL3ogeRZ@?oPVV^1?n9MKH3oi:8a@CoSgfl0on;NKX3ohYi^P?oS7bl1?n?PL04oi:7
a0?oUXg80_nJTl`2oj>ei@GoYK_Y0_nV_^/00onLh?goWN3moigPo@02oigPo@;oVmom0onRe_X2oj7E
nP;oY<ge1?nScOH2oj;=m`;oYLKa1OnTao82oj?7l`?oYLC_0_nTa?02ojK2kPCoYL;^0_nT`nl2ojK1
k@GoYL;^0_nT`^l2ojK1k@CoYL;^0_nT`^l2ojG1k@CoYL;^0_nT`^l3ojG1k@;oYL;^1onV`Nd2ojG2
kPKoY/7]0_nV`^d2ojK1k0GoYl7]0_nW`^d=ojO1k003o`000?nW`NcoYl7/00CoYl7/0_nX`>/6ojO0
j`;oZ<3[1onW`>/:ooooo`03o`000?oooooooooo00oooooo0007ooooo`05o`000?oooooooooooooo
ool000002oooool01?oMgMgoEEEEooooool00006ooooo`03o`000?oooooooooo00?ooooo0ol0000V
ooooo`Co[l;X0_n]^N800onR]nSoX;3Soj2`h`02oj2`h`?oWJSN1?nIX]/3oiFLf0?oT9OF0on<TmD2
ohNAe`CoNKgl0_mZb?h01?nTm^_o`][[ol;Jjoo2f^/2olCBi@03ojjRc?nUU<?oYIC300;oYIC30onL
Q[/3oi=j]0?oR6n_0on0Ijd2ogIQ[@?oKF6d00CoP6J[og]PYomkH:OoNf2W0_mkGjL3ogeRZ@CoPVV^
1?n9MKH00onBR<GoUhO1oiN7`@03ohmm_0CoRgVj0on:NKX3ohal_0?oSh700_nBQl@2oibTf`CoX:gQ
1?nS]ND2ojFkj@;oW]om0onOhOd2oigPo@?oY=Oi0_nRe_X2ojG>m@GoY<ge0_nScOH2ojK6l0CoYLKa
0_nTao83ojK3k`;oYLC_0_nV`^d5ojK2kP;oYL;^1_nV`Nd2ojG2kPOoY/7]0_nU`^h2ojK1k@CoYL7]
0_nU`^h3ojK1k@;oYL7]0_nV`N`6ojK1k@;oY/7/1onV`Nd6ojK1k0;oYl7]4_nW`N`01?l0003oYl7/
ojO1k?nW`N`CojO0j`[ooooo00?o0000ooooooooool03oooool000Oooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03ogMgMoo<c<co000000Gooooo00Co0000oooooooooooooooo0ol0000Zoooo
o`;o[l;X0_nT_nd3oj:gj0CoX;3S0onMZ=h2oiVRf`;oSZo/0on:[^h3ohF`l@GoP;Gf0_mi_O`2ojCf
j`Co`][[00?o/jkDojjRc?n^X/`00_n^X/`3ojFD``?oW8Jk0onCN[@3ohQ_[`?oP6N]0omfHJd3ofeQ
]0;oH6[600?oNf2Wog]OYomkGjL00ommHZT4oh9Y[P?oRGFf00CoYI[9oiN7`OnGQl7oUhO10on?OK`4
oh]i^P?oRWVj0on<O;`2ohn1`003oiRJe?nLY=_oW:CK00?oW:CK1?nP[N42oj>ei@?oX=kl00CoW]om
oioQoOnOhOgoWn7m0_nUf?T3ojCGn@;oY/ke1?nUc_D2ojC=m@OoY/K`0_nUa_43ojK3kP;oY/?_0_nW
`Nd4ojK2k@;oY/;^0_nW`N`7ojK1k@;oY/7/1_nV`Nd2ojK1k0GoY/7]0_nU`Nd3ojK1k0;oY/7]0_nV
`>`4ojK1k0;oY/7]0_nV`>`4ojK1k0;oY/7]0_nW`N`7ojK1k17oYl7/0_nW`>`3ojO1k003o`000?nW
`>_oYl3[01CoYl3[2Oooool00ol0003oooooooooo`0?ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?ok^k^odA4A?l000001Oooool4o`0002kooooo1?nT_nd3oj:gj0;oX;3S0_nE
]>d3oi:ak0CoSZo/0on:[^h3ohF`l@;oP;Gf0_m4a]X2oj;bl`?o_mg_00?o`][[ok>^e?nc[]@00_nc
[]@3ojjRc0CoYIC30onLQ[/2oi=j]0?oR6n_0on0Ijd3ogIQ[@?oKF6d0omPJ/H3og]OY`?oOF:Y0on2
JJh01?n9MKKoSXC4ohj4a?n>Q<@3ohYo`@?oRGk11?n<P/@3ohn8b0?oTi7>1?nHV]@5oibTf`;oX:gQ
0onRfo/2oj3No0;oXN7l0_nWfOT4ojGHn@03ojCGnOnVc_GoY/ke00;oY/ke0_nUc_D2ojO6l0OoY/K`
0onW`nh2ojK3kPKoYl7]0_nV`^d6ojO1k0;oY/7]0_nW`>`5ojK1k0;oY/7]0_nW`>`4ojK1k0;oY/7]
0_nW`>`4ojK1k003ojO0k?nV`>coY/3/00?oY/3/0_nV`N`00onW`>coY/3/ojK0k003ojK0k0;oY/7/
0_nW`>`4ojO1k0;oY/7/0_nW`>`7ojO1k0;oYl3/1_nW`N`7ojO0k003ojO1k?nW`>_o000001KoYl3[
2Oooool00ol0003oooooooooo`0?ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo
00?oMgMgo`000?ooool01?ooool2o`00037ooooo0_nT_nd2oiVll0?oUkS^1?nE]>d3oi:ak0;oSZo/
0on0aoh4ogG=o`;oHLog00?oM>7[oj;blonRl_<00onogNl00ong^M[o/jkDok>^e003ok>^e0Co[Z;<
0onUU<<3oib6^`?oTgZd0on8Kjl2oh1W[@?oMV6]1?m]HK@3of1ZaP;o<H[]0ommHZT2oh9Y[P?oUi3;
0on>Q<@3ohYo`@?oRGk11?n<P/@3ohn8b0?oTi7>1?nHV]@2oibTf`?oX]Kj0_nRfo/4oj?Qo003oj7Q
o?nWfOWoYmWi00;oYmWi0_nUf?T3ojO?m@;oY/ke0_nWao04ojO6l0;oY/K`1OnW`nh2ojO1k0OoYl7]
2?nW`N`6ojO0k0;oY/7/1onW`>`2ojK1k0KoYl3/00?oY/7/ojO0k?nW`>`00_nW`>`2ojK0k0KoYl3/
0_nV`>`7ojO0k0;oYl7/1_nW`>`2ojO1k0OoYl3/0_nW`N`8ojO0k0GoYl3[00?o0000ojO0jonW`>/0
5?nW`>/8ooooo`03o`000?oooooooooo00oooooo000Rooooo`03o`000?oooooooooo02oooooo1?nI
_?03oiNhkP;oUKC]0_n=__L4ohS2nP;oP<On1?n9f?l2oh7OnP;oXN_j0onjg?401?nogNoo]kWJokNi
f_ng^MX5ok>^e0;o[Z;<00CoVY79oi66a?nAQ/CoTHK40on7OL43oh1g_`?oR6n_0on0Ijd3ogIQ[@?o
KF6d1?mPJ/H00olaR^go]KoQokFoh@03ojFTe0?oUi3;0on>Q<@3ohYo`@?oRGk11?n<P/@3ohn8b0Co
Ti7>0_nHV]@3oj7=m`;oX]Kj0onTh?/2oj?Qo0?oZ=_i0_nWfOT4ojS@m@;oYloe0_nXao04ojO7l0;o
YlK`1OnW`nh6ojO1k0;oYl7]2OnW`N`NojO0k0;oYl3[:?nW`>`9ojO0j`03o`000?nW`>_oYl3[01?o
Yl3[2Oooool00ol0003oooooooooo`0>ooooo`008oooool00ol0003oooooooooo`0_ooooo`;oVKc`
0_nC^_84oi2lm0?oSKkg0_n8`_X4oho@oP;oRMSo0_nPh_`3okGHlP;o^]ca0_nh_n04okNifP;o/jkD
0_nRW<h3oiZAb@CoTHK40on7OL42oh1g_`?oNGC10omiO<T3ogIQ[@?oKF6d0_mPJ/H00om`h=Wo]KoQ
okFoh@02okFoh@CoYJCD0onGT</2ohj4a0?oRWo10on9O/45ohb2a0?oShS80_nCTLh3oik2lP;oXLgg
0onVg_/2ojCPn`?oZMgi0_nXfoT3ojWBmP;oZ=3e0_nXb?05ojS7l0;oYlO`1OnW`nh@ojO1k0WoYl3/
0_nW`>/6ojO0k0;oYl3[1_nW`>`3ojO0j`;oYl3/1onW`>/2ojO0k0;oYl3[1_nW`>`2ojO0j`ooYl3/
0_nW`>/6ojO0k0goYl3[00?o0000ojO0jonW`>/05?nW`>/8ooooo`03o`000?oooooooooo00kooooo
000Tooooo`03o`000?oooooooooo02oooooo1?nC^_82oi2lm0;oUL7e1OnBb?X2oho@oP?oX=Sk00Co
X>;lokGHl_nef?;o]MSb0_nga>@4okRoh0;o]kWJ00?oZJKCoj:Lc_nRW<h00_nRW<h4oiZAb@?oTHK4
0on7OL43oh1g_`?oNGC10_miO<T4ognAf`?oR<7j0oo5fnX2okFoh@03oiRAbon?R<OoShS700;oShS7
0on8P/L3ohJ4bP?oRWo10on9O/42ohb2a0;oTjCQ1OnI/nX2oik2lP?oY]Wi0_nVg_/3oj[Nn@;oZMgi
0onZe?H2ojWBmP;oZLWa1?nXb?02ojS7l0?oZ<C^0_nW`nhAojO1k0;oYl3[1_nW`>`7ojO0j`;oYl3/
1_nW`>/2ojO0k1CoYl3[0_nW`>`6ojO0j`;oYl3/0_nW`>/6ojO0k0OoYl3[0_nW`>`AojO0j`03o`00
0?nW`>_oYl3[01CoYl3[1oooool00ol0003oooooooooo`0>ooooo`009Oooool2o`00033ooooo0_nC
^_82oiRkl@CoUL7e0_nBb?X4oio?n0;oX=Sk0on`d_800onef?;o]lCTokO4i002okO4i0;o^;oP00?o
[JkHojVVdonYY]<00_nYY]<4oj:LcP?oVY790onAQ/@3ohMm`@?oP7No0omiM<43ogUlb@CoOi7K00Go
R<7jolWakOo5fn[oaM_ZojJRdP04oiRAb`?oShS71?n8P/L2ohJ4bP?oR8_?1?n<U]P4oi>Th@?oVK?Z
0_nTd?L3ojKIn@?oZ]oi0_nZg_T3oj_Gm`;oZ]Cf0_nZbo44ojW9l@;oZ<S`1OnXa>h2ojO2k0ooYl7/
1_nW`>/2ojO0k3GoYl3[0_nW`>`NojO0j`03o`000?nW`>_oYl3[01CoYl3[1_ooool00ol0003ooooo
ooooo`0>ooooo`009oooool00ol0003oooooooooo`0^ooooo`CoV;_a0_nE`OD4oio6l`;oWloh0on]
c?02ok3BlP;o]LGV0onga>@00on`]Mco[JkHojf^f002ojf^f0CoZJKC0onRW<h3oiZAb@CoTHK40on7
OL42oh1g_`?oNGC11?miO<T2ognAf`;obO7]00?o/kKKojJRd_nVX]800_nVX]83oiRAb`CoShS70on8
P/L3ohJ4bP?oR8_?1?n<U]P3oi>Th@03oiVcj_nTd?OoY=3g00?oY=3g00CoY]Wioj[OnOnZgoWoZ]oi
0_n/fOL2oj_Gm`?oZlgb1?nZbo42ojW9l@?oZ<G^0_nXa>h2ojS2k0CoYl;/2_nW`NaRojO0j`03o`00
0?nW`>_oYl3[01?oYl3[1_ooool00ol0003oooooooooo`0>ooooo`00:?ooool00ol0003ooooooooo
o`0^ooooo`;oV;_a1?nP_^h2oio6l`;oZlK]0on]c?02ok?5i`Co]LGV00Co]lCTok2eg?n`]Mco/;GL
1?n][]P2ojVVd`04oifLd_nFU<ooUYC?oiJDc`?oSHg>1?n5R]43ogV;f@?oKY[[0omiM<42ogUlb@;o
`_W/00?o_/WSok>ffonc]]/00_nc]]/3ojJRdP?oV97;1?n?R<L3ohR2a`CoQXC:0on8Rll2ohbFf0;o
VkK[1?nQaO82ojC@m`?oZ]ki00CoZ]oiojcImon/fOOo[=Wg0_n/co85oj_=lP;oZ/_a0_nYa^h3ojS5
kPKoZ<;/0_nW`^`8ojO1k6GoYl3[00?o0000ojO0jonW`>/05?nW`>/5ooooo`03o`000?oooooooooo
00kooooo000Yooooo`03o`000?oooooooooo02oooooo0_nP_^h3oj[0jPCoZlK]00?o[Lc`ok?5ionc
aNL00_ncaNL2okG5iP;o/K[P1?n`]M`2ojf^f003oj>SeOnMW=;oWIcB00;oWIcB0onFU<l3ohf=cPCo
QH[A0omiRmT4ofjJj`04odnfn_mfgK?o`_W/ol;ik0?o_/WS1?nc]]/3ojJRdP?oV97;0on?R<L4ohR2
a`;oQXC:00?oSY[JoiFWh_nEYn800_nEYn84oi^fj`;oXLGb0onYfoT2oj[Nn@?o[M_g00?o[=Wgojc?
l_n/co800_n/co82oj_=lP;oZLO_1OnYa^h00onXaNkoZ<;/ojS2k004ojS2k0SoYl7/JOnW`>/00ol0
003oYl3[ojO0j`0DojO0j`Cooooo00?o0000ooooooooool03_ooool002[ooooo0_l0000aooooo`Co
Z/3Z0_n[a^d3ok73j0;o/lGW0_nb_^<4ok6jh0;o/;GL00?oZ:_Ioj>SeOnSXmD00_nSXmD3oifLdP?o
UYC?0on=SLh4ohF:d@CoNH_I0_m^V^/00on3hoOo^_W]ok[ik@02olCKjPCo_/WS0_nc]]/01?nNX=Ko
UIGAoiFEdOnEUM43ohf>c`?oRXg@1?n;T=<4ohjJfPCoUJOR0_nK]^/3ojKEn0;oZM_i0on]foP2ojgK
m`?o[M;c0_n/co82oj[9l0CoZLO_0_nYa^h3ojS3k@;oZ<;/0_nX`N`7ojO1k6goYl3[00?o0000ojO0
jonW`>/05?nW`>/3ooooo`03o`000?oooooooooo00kooooo000/ooooo`03o`000?oooooooooo02oo
oooo0_nZ`>X2ojo2i`?o/L?X0_nb`>D4ok:nh`;o/K[P00?oZk;MojR[fOnXZmT00_nXZmT4oj>Se@?o
WIcB0onFU<l3ohf=cP;oQH[A0_n8/o84ohS:o@03ogOSd_njnNgo^_W]00Coa=_Z0_nnbN<00onY[]_o
WZ3FoijPeP02oijPeP?oUIGA0on=S/l3ohZ=d0CoRi3C1?n>V]X2oiFWhP?oXL_e0_nVeOP3ojcJm`;o
[M_h0on^e?@2ojgBl`;oZl_`1?nZbO02ojW7k`?oZL?]0_nX`nd6ojS1k0;oYl7/L_nW`>/00ol0003o
Yl3[ojO0j`0DojO0j`?ooooo00?o0000ooooooooool03Oooool002gooooo00?o0000ooooooooool0
;oooool4ojo2i`03ok73j?nb`>Go//3U00;o//3U0_nb_^<00on]^>7oZk;Moj^bg@02oj^bg@CoZ:_I
0_nSXmD01?nKZ=ooU:CPoiBTh?nDY>04oi2ShP?oRJKX1?n8/o801?n8b_goMn?Bojgcm?n]lo@3ol3T
l0;oa=_Z0_nb_>43ojV^f`CoWZ3F0onEUM43ohf>c`?oRXg@0on;T=<2ohjJfP?oV[g`0_nQboD4oj[F
m`;o[=[g0on^e_D2ojkDm0;o[<ga1?n[bo02oj[9l0?oZLC]0_nY`nd2ojS2k0KoZ<7/MOnW`>/00ol0
003oYl3[ojO0j`0DojO0j`?ooooo00?o0000ooooooooool03Oooool002kooooo00?o0000oooooooo
ool0;oooool2ojo2i`;o/L;W0onb`>D00on__NCo[KSQojfhh@02ojfhh@CoZk;M0_nXZmT00onP[N7o
VjSOoi^Xg`02oi^Xg`?oU:CP1?n@Xn83ohVVj0;oR;?b00CoNn;bojgcm?n]loCo[O?d0oo0i?02okO8
i`Co/[cQ0onY[]/2oijPeP04oi:He_n>U]OoSYKGohjFe`?oS9WK1?n>XN43oiB^j@?oV[g`0_nVcoD4
oj[Fm`03ojkGmOn^e_Go[]Ke00;o[]Ke00?o[M3bojc=lOn/cO400on/cO42oj_;l0?oZ/K^0_nYa>d6
ojS2k0CoZ<7/MonW`>/00ol0003oYl3[ojO0j`0DojO0j`;ooooo00?o0000ooooooooool03Oooool0
02oooooo00?o0000ooooooooool0;oooool4ok72i`04ok;0iOn__NCo[kgTojnmi0Co[KSQ0_n[/]d2
ojBbhP?oX:gQ1?nKZ=l3oiBTh0;oT:?R0on<ao/2ohGFo`;oY^[j1?njio@00oo0i?3o]lSWokO8i`02
okO8i`;o/[cQ00CoXjOIoi^Ne_nKW]KoVikF1?nBV=H3ohjFe`?oS9WK1?n>XN43oiB^j@03oiZml?nV
coGoY/oe00;oY/oe00?oZ]KgojkGmOn^eoD00_n^eoD00on^e_Go[M3bojg@lP02ojg@lP;o[<ga0on[
anh2oj[6kP;oZL?]1onX`^`6ojS1k7OoYl3[00?o0000ojO0jonW`>/04onW`>/2ooooo`03o`000?oo
oooooooo00gooooo000`ooooo`;o0000<?ooool2ok72i`;o[l;X1?n__N@2ojfhh@;oYkOU1?nT/^83
oj2]h@;oVjSO0_nF^>l4oi2lm0;oS<Ok0_nOgO`3ok3Sn0;o^^Od1?nid>/2okO8i`03ojZagOnSYmWo
XjOI00;oXjOI0onKW]H3oi:HePCoSYKG0on<VM/2ohjQh@;oV[S]1?nQaO82ojK?m@?o[=Kf0_n^eoD3
ojkBl`;o[M3b0on/bNl2oj_7kP;oZLC]1?nY`nd2ojS2k0WoZ<7/N?nW`>/00ol0003oYl3[ojO0j`0D
ojO0j`03ooooool0003ooooo00kooooo000booooo`03o`000?oooooooooo02kooooo1?n_`^P2ojnm
i0;oZKcW1?nW]nD2ojBbhP;oW[SZ0onJ]^`4oiJhk`;oT;cd0onLdO/01?nOgOco/>?hok3Sn?n`hoP2
okKCk`Co^M3[00?o/;[QojZagOnZ/Md00_nZ/Md4oj>Wf@?oVikF0onBV=H2ohjFe`03oi:Uh_nE[NOo
UJgW00;oUJgW1?nJ^>d2oj75lP?oZM;e0_n/e_H3ojkCl`;o[];c0_n/bo03ojc9k`;oZ/G]1?nYa>d2
ojW3k@SoZ<7/OOnW`>/00ol0003oYl3[ojO0j`0CojO0j`03ooooool0003ooooo00kooooo000coooo
o`03o`000?oooooooooo02kooooo0_n_`^P2ojW0jPCoZKcW0_nW]nD2oj6jjPCoW[SZ0onJ]^`2oiJh
k`?oVlWg0_nLdO/3ojWLn@03ok3Sn?nfdnoo]]?_00;o]]?_00?o^M3[ok2jhOn`^^400_n`^^43ojZa
g@;oXjOI0_nKYM`3oiJQg0CoTZ7N0onBYN84oiF]i`;oV[S]0onTbo@2ojWBm@?o[=;d0_n^do<2ojg=
l@Co[<_`00?o[<W_oj[5kOnZaNd00_nZaNd2ojW4k@;oZ<;/1_nX`N`2ojS0jgooYl3[00?o0000ojO0
jonW`>/04onW`>/00ol0003oooooooooo`0=ooooo`00=?ooool00ol0003oooooooooo`0^ooooo`Co
ZL3Z0_nY_>L2oj>lj`CoXK[Z0_nN^>X2oig0l@CoVl?c0_nKbOL3ojCEn@;oZMci0oncdo42okKCk`;o
//7U1?n`^^42ojZag@03oj6[gOnKYMcoVjGL00?oVjGL0onFXM`4oi:QgP?oTZGR0_nE[NL3oio2lP;o
Y<_d0onZd?@2ojcBm0;o[Loa1?n]cO42ojc;l0?oZlO^0_nZaNd2ojW3k0CoZ<;/1?nX`N`4ojS0jgoo
Yl3[00?o0000ojO0jonW`>/04OnW`>/00ooooooo0000ooooo`0>ooooo`00=Oooool2o`0002oooooo
0_nY`>X2ojBok0CoXkc[0_nQ^^X2oijnk`CoWL3a0_nK`o<3oj7=m`;oY=Gi0on^dO82ok?Cl@;o//GX
1?nb`ND2ok2jh@;oY[7O0onQZmd4oi^Ug0CoUZ7L0_nBXMh00onG/NWoVKW^oiVikP03oiVikP;oWl;b
0_nVbo<3oj[@m0;o[<ob1?n]co42ojg=l@?o[<W_0_n[anh2ojW4k@CoZL?/0_nX`^`6ojS1k0;oZ<3[
P?nW`>/00ol0003oYl3[ojO0j`0=ojO0j`Kooooo00?o0000ooooooooool03?ooool003Oooooo00?o
0000ooooooooool0;_ooool3ojBok0;oXkc[0_nP_^h4oijnk`;oWL3a0onPb?@2oj7=m`?oZ/gb0_n^
dO82ok37j`Co//GX0_nb`ND2ojZghPCoY[7O0onQZmd2oi^Ug0;oV:WS0onF[>D4oiNaj@;oVKW^0_nR
aO45ojK;l`03oj[@m?n/co;o[<ob00;o[<ob0_n]co43ojc:l0;o[<W_0_nZaNd4ojW4k@;oZL?/0_nX
`^`6ojS1k0?oZ<3[POnW`>/00ol0003oYl3[ojO0j`09ojO0j`Wooooo00?o0000ooooooooool03?oo
ool003Sooooo00?o0000ooooooooool0;_ooool4oj6nkP?oX;k^0_nN_^l3oj34lP;oX<Sd0_nWbO43
oj[=lP;o[/O/1?n`an/2ok;5j0;o[KcT1?nZ]n82ojJag`03oj2^hOnLZn7oW:_Q00;oW:_Q1?nHZN<3
oiJ/i@;oUk7Y0_nN_^l4oj;5l@;oY/_c0on[c_82ojc?lP?o[<c`0_n/b_02oj_6kPGoZ/G]0_nYa>d0
0onY`^coZ<;/ojS2k003ojS2k0;oZ<7/1OnX`>^3ojO0j`03o`000?nW`>_oYl3[00GoYl3[3?ooool0
0ol0003oooooooooo`0<ooooo`00>Oooool00ol0003oooooooooo`0^ooooo`;oXKk^0_nR_^d4oj31
k`;oX<Cb0_nUaO04ojO9l@03oj[=l_n^anco[/O/00;o[/O/0_n`an/2ojfoi`Co[KcT0_nZ]n82ojFa
h@?oX:kQ1?nLZn42oiRYh`;oVk?Y0onK^>`4oijnk`;oX/Ga0onWbo82oj_>lP?oZlca0_n/c?02oj_8
kPCoZlK^0_nZaNd2ojW3k0CoZL;/0_nX`^`3ojS1j`;oZ<3[R?nW`>/00ol0003oYl3[ojO0j`0@oooo
o`03o`000?oooooooooo00cooooo000jooooo`;o0000;oooool4oj:nk@;oX<7_0_nU`^h4ojG5l0;o
YlWa0on[a^d2ojk7k0;o[L7X1?n]_nL2ojfli0;oZ;KS1?nU/N43oj2^h@;oW:_Q0_nL/^L4oi^cj@?o
VkS/0_nN_^l3ojC7lP;oYl_b0_nZbo43oj_<l@;oZlW_1?n[b>h2oj_6kP;oZLC]1?nY`n`2ojW2k0?o
Z<7/0_nX`N/2ojS0jhWoYl3[00?o0000ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`00
??ooool00ol0003oooooooooo`0]ooooo`;oX[k]0_nU_n`4ojG2kP;oYLG`0onYa>d2oj_6k@;o[<;Y
1?n]`NP2ojfoi`;oZ[WT1?nX]^<2ojFah@03oj6ciOnN/^GoW[;U00;oW[;U1?nL/^L2oi^cj@;oWkg^
1?nQ`_02ojC7lP;oZ<Wa1?nZbo400on[c?7oZlW_oj_9k`02oj_9k`;oZlS^0_nZaNd4ojW4k@;oZL?/
0onX`^`2ojS1k0;oZ<7[1?nX`>^4ojO0j`Gooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0<ooooo`00?Oooool00ol0003oooooooooo`0]ooooo`CoYKo/0_nU`^h3ojS2k0;oZLC]0_n[
`^X4ojc2j@;o[L7X0_n[_>H4ojZii0;oZ;KS0_nT]^D3oj6ci@CoW[;U0_nL/^L2oijjk0CoWkg^0_nQ
`_02ojG6l@CoZ<Wa0_nZbo43oj_9l0;oZlW_0_nZa^h4oj[5k@;oZLC]0onY`^`2ojS2k0;oZ<7/1?nX
`N/2ojS0jh;oYl3[2Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo000n
ooooo`03o`000?oooooooooo02gooooo0_nU_n`3ojS0j`;oZ<;/0_n[`NX4oj_2jP;o[<;Y0_n[_^L4
oj^liP;oZ[WT0_nV^>H4ojBfi@?oXK?U0_nN/^D2oinhjPCoW[[/0_nO_Nh2oj?3l0CoYLKa0_nXbO43
ojW9l0;oZlW`0_nZanh4oj[6kP;oZ/G]0onY`n`2ojW2k0KoZ<7/0_nX`N/2ojS0jgcoYl3[4?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo000oooooo`;o0000;oooool2ojS0
j`;oZ/7Z1?n[`NX2oj_2jP;oZkoX1?n[_^L2oj^liP;oZ;[V1?nV^>H2ojBfi@;oX[SX1?nP]nT3oinh
jP;oW[[/0_nR`>l4oj?3l0;oYLKa0onXb?02ojW9l0;oZ/O_1?nZanh2oj[6kP?oZLC]0_nY`n`2ojS2
k0KoZ<7/1_nX`>]hojO0jaCooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0;oooo
o`00@Oooool00ol0003oooooooooo`0]ooooo`CoZ/7Z0_n[`NX2oj_0j@CoZkoX0_n[_^L2ojVli`Co
Z;[V0_nV^>H2ojBij0CoX[SX0_nP]nT2oj6lk0CoXKg]0onR`>l2oj?3l0?oY/K`0_nXb?02ojW7k`Co
Z/O_0_nZanh5ojW4k@;oZL;/1?nX`^`2ojS1k003ojS1jonX`>_oZ<3[00GoZ<3[M_nW`>/Hooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool004;ooooo00?o0000ooooooooool0
;Oooool4oj[1jPCoZl3Y0_n[_nP2ojVnj0CoZKcW0_nX^^H2ojJjj0CoY;WX0_nR^>P2oj:kj`CoXKc/
0_nQ_Nd2oj?2k`CoY<C`0_nVa_02ojS6k`CoZLO_0_nZanl3ojW5kP;oZLC]00?oZL?/ojW2k?nY`^`0
0onY`^`2ojS2k003ojS1k?nX`N_oZ<7[00;oZ<7[0_nX`>]fojO0jagooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`00@oooool00ol0003oooooooooo`0]ooooo`CoZ/7Z0_n[
`>T2ojZoj@CoZKkX0_nY_>L2ojNlj0CoY[[X0_nT^NP2oj>kjPCoX[_[0_nQ_>`2oj?0kPCoXl;_0_nT
a?02ojK5k`CoZ<K_0_nYanl5ojW5kP03ojW3kOnY`ncoZL?/00;oZL?/0_nY`^`6ojS1k0;oZ<7[0onX
`>]cojO0jb3ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`00A?ooool0
0ol0003oooooooooo`0]ooooo`;oZ/7Z0_nY`>X4ojZoj@;oZKkX0_nX_NT4ojNlj0;oY[[X0_nT_>X4
oj>kjP;oX[_[0_nS_nd4oj?0kP;oXl;_0_nU`nl4ojK5k`;oZ<K_0_nXaNh2ojW5kP;oZLC]1?nY`nd2
ojW3k0;oZ<;/1_nX`N`3ojS1j`;oZ<3[LOnW`>/Tooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02oooool004Gooooo0_l0000_ooooo`?oZL3Z0_nZ_nT3ojRojP?oZ;gY0_nW_>P3ojFm
jP?oY;cZ0_nS^nX2oj>nk0CoXko]0_nS`>h2ojC2kPCoYL?_0_nVaNl2ojO5kP;oZ<G^0_nXa>d4ojW4
k@;oZL?]1_nX`^`2ojS1k0GoZ<7[0_nX`>]^ojO0jbWooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0;ooooo`00Aoooool00ol0003oooooooooo`0]ooooo`CoZ<3[0_nX_nX2ojJoj`Co
Y[kZ0_nU_NX2ojFnk0CoY;k/0onS_^`2oj>ok@;oY<7^0_nT`^h2ojK3kPCoYlC^0_nWaNh2ojS4kPCo
Z<C]0_nYa>d5ojS2k0KoZ<7/0_nX`N/6ojS0jf[oYl3[;?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00_ooooo0018ooooo`03o`000?oooooooooo02gooooo0_nX`>/2ojO0j`CoY[o[
0_nV_^X6ojFnk0;oY;k/00?oY;o]ojC0kOnT`>d00_nT`>d2ojC1kP;oYL;^1?nV`nh2ojO4kP;oYl?^
1?nXa>h2ojS4k@?oZ<?]1?nX`^`6ojS1k0;oZ<7[1_nX`>]XojO0jc3ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0;ooooo`00BOooool00ol0003oooooooooo`0]ooooo`CoYl3[0_nV
_n/2ojFok0KoYKk/00?oY;o/ojBokOnT_nd00_nT_nd2ojC0k@;oYL7^1?nU`^h2ojK3kPKoYl?^0_nX
a>h5ojS3k@KoZ<;/1?nX`N`4ojS1j`;oZ<3[J?nW`>/dooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool004[ooooo0_l0000^ooooo`;oYl3[0_nV_n`4ojFok0;oYKk/0_nU_n`3
ojBok0;oY;o]0_nU`Nd4ojG1kP;oYL;^0onV`^d5ojO3kPGoZ<?]2?nX`^`6ojS1k0;oZ<7[00?oZ<3[
ojO0jonW`>/0I?nW`>/iooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool0
04cooooo00?o0000ooooooooool0;?ooool4ojJok0SoYKo/00?oY;o/ojG0kOnU`>d01?nU`Nd2ojG1
kPGoY/;]1_nW`^d2ojS3k@SoZ<;/2?nX`N`5ojS0jf;oYl3[??ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00[ooooo001=ooooo`03o`000?oooooooooo02cooooo0_nV_n`8ojFok0Go
YL3]1OnU`Nd4ojK2k@KoYl;]0_nW`^`6ojS2k0SoZ<7/0_nX`N/2ojS0jf3oYl3[@oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00[ooooo001>ooooo`03o`000?oooooooooo02gooooo
1onU_n`4ojG0k@KoYL7]0_nV`Nd4ojK2k@CoYl;]1?nW`^`2ojS2k0[oZ<7/0_nX`N]PojO0jdOooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`00Coooool2o`0002kooooo1OnU
_n`2ojG0k0CoYL3]0_nU`Nd6ojK1k@;oY/;]0_nW`N`4ojO2k@;oYl;/0onW`N`9ojS1k0;oZ<3[GOnW
`>]<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool0057ooooo00?o0000
ooooooooool0;?ooool3ojFok0CoYL3/0_nU`>d2ojK0k0KoY/7]0onV`N`3ojO1k0;oYl;]1_nW`N`6
ojS1k0;oYl3[1?nX`>]IojO0jdoooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:
ooooo`00D_ooool00ol0003oooooooooo`0[ooooo`CoYKo/0_nU`>`6ojK0k0;oY/7]1OnV`N`=ojO1
k0;oZ<7/0_nW`N/4ojO0j`;oZ<3[EonW`>]Cooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02_ooool005?ooooo00?o0000ooooooooool0:oooool2ojFok0?oY[o/2?nV`>`2ojK1k17o
Yl7/1?nW`N]IojO0jeOooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`00
E?ooool2o`0002gooooo1?nV_n`6ojK0k0;oYl3/4onW`N`2ojO1jeOoYl3[F_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Wooooo001Fooooo`03o`000?oooooooooo02_ooooo1?nV
_n`4ojK0k0CoYl3/0_nW`N`2ojO0k0GoYl7/0onW`>`5ojO1k5OoYl3[G_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Wooooo001Gooooo`03o`000?oooooooooo02_ooooo0_nV_n`6
ojK0k0SoYl3/00?oYl7/ojO0k?nW`>`00onW`>aFojO0jfKooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`09ooooo`00F?ooool00ol0003oooooooooo`0/ooooo`GoY/3/3?nW`>aFojO0
jf[ooooo00Go0000ooooooooooooooooo`00000;ooooo`00FOooool00ol0003oooooooooo`0/oooo
o`CoYl3[0_nW`>`00onW`>_oYl3/ojO0k004ojO0k5KoYl3[KOooool01Ol0003ooooooooooooooooo
000000_ooooo001Jooooo`;o0000;Oooool7ojO0j`;oYl3/E_nW`>]aooooo`04o`000?oooooooooo
o`0000_ooooo001Looooo`03o`000?oooooooooo02_oooooFonW`>]eooooo`03o`000?oooooo0000
00_ooooo001Mooooo`03o`000?oooooooooo02_oooooEonW`>]hooooo`04o`000?ooooooooooo`00
00[ooooo001Nooooo`03o`000?oooooooooo02_oooooDonW`>]looooo`03o`000?oooooo000000[o
oooo001Oooooo`;o0000;?oooom<ojO0jh?ooooo0_l0000:ooooo`00HOooool00ol0003ooooooooo
o`0ZooooodSoYl3[QOooool3o`0000[ooooo001Rooooo`03o`000?oooooooooo02_ooooo@onW`>^4
ooooo`Co00003Oooool006?ooooo00?o0000ooooooooool0:oooooloojO0jh?ooooo1?l0000Aoooo
o`00I?ooool2o`0002cooooo>onW`>^3ooooo`?o00005Oooool006Kooooo00?o0000ooooooooool0
:ooooolcojO0jhGooooo1?l0000Hooooo`00Ioooool00ol0003oooooooooo`0Zoooooc3oYl3[Q?oo
ool4o`0001cooooo001Xooooo`03o`000?oooooooooo02[ooooo;?nW`>^3ooooo`Co00008?ooool0
06Wooooo0_l0000/ooooobOoYl3[P_ooool4o`0002Cooooo001[ooooo`03o`000?oooooooooo02[o
oooo8onW`>^2ooooo`?o0000:?ooool006cooooo00?o0000ooooooooool0:_oooolMojO0jh?ooooo
1?l0000[ooooo`00KOooool00ol0003oooooooooo`0[oooooaSoYl3[P_ooool4o`0002oooooo001^
ooooo`03o`000?oooooooooo02[ooooo5OnW`>^1ooooo`Co0000<oooool006oooooo0_l0000[oooo
oa7oYl3[P?ooool4o`0003Oooooo001aooooo`03o`000?oooooooooo02[ooooo2OnW`>^2ooooo`Co
0000>oooool007;ooooo00?o0000ooooooooool0:_ooool5ojO0jh;ooooo0ol0000oooooo`00Looo
ool00ol0003oooooooooo`0Zooooo`03ojO0jooooooooooo07oooooo1?l00012ooooo`00M?ooool2
o`0002[ooooo00?o0000ooooooooool0Noooool4o`0004Kooooo001fooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0N?ooool4o`0004[ooooo001gooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0M?ooool4o`0004kooooo001hooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0LOooool3o`0005;ooooo001iooooo`;o00009?ooool00ol0003ooooooooo
o`1]ooooo`Co0000EOooool007_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Y
ooooo`Co0000FOooool007cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Uoooo
o`Co0000GOooool007gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Qooooo`Co
0000HOooool007kooooo0_l0000Oooooo`03o`000?oooooooooo05gooooo1?l0001Uooooo`00P?oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05[ooooo0ol0001Yooooo`00POooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Kooooo1?l0001/ooooo`00P_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo05;ooooo1?l0001`ooooo`00Poooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo04kooooo1?l0001dooooo`00Q?ooool2o`0001Wooooo
00?o0000ooooooooool0B_ooool4o`0007Sooooo0026ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0A_ooool4o`0007cooooo0027ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0@oooool3o`00083ooooo0028ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0?oooool4o`0008?ooooo0029ooooo`;o00005?ooool00ol0003oooooooooo`0kooooo`Co
0000Qoooool008_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0gooooo`Co0000
Roooool008cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0cooooo`Co0000Sooo
ool008gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0`ooooo`?o0000Toooool0
08kooooo0_l0000?ooooo`03o`000?oooooooooo02cooooo1?l0002Fooooo`00T?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo02Sooooo1?l0002Jooooo`00TOooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo02Cooooo1?l0002Nooooo`00T_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo027ooooo1?l0002Rooooo`00Toooool2o`0000Wooooo00?o0000
ooooooooool07Oooool4o`000:Kooooo002Eooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool06_ooool3o`000:[ooooo002Fooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool05_ooool4o`000:gooooo002Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
4_ooool4o`000;7ooooo002Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_oo
ool4o`000;Gooooo002Iooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000^Oooool0
09_ooooo00Co0000oooooooooooo00002Oooool3o`000;gooooo002Looooo`03o`000?oooooo0000
00Gooooo1?l00030ooooo`00WOooool2o`000003ooooool0003o000000;o0000a?ooool009kooooo
0_l00038ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00[_ooool01OnHV9So0000o`000?m4A4Co
^[Zj00[ooooo1?l000000ol@413oooooooooo`05o`0000Gooooo0_lQ8B6Hooooo`00[_ooool01Ol@
413o^[Zjonk^k_mgMgOo410@00;ooooo1_l00004ooooo`03o`000?oooooooooo00;ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A005ooooo`;o8B4QV?ooool00:kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^0:3ooooo002^ooooo`03o`000?oooooooooo
00Cooooo1_l00004ooooo`03o`000?oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h0Woooool00:ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03ogMgMomVIVKooooo09ko
oooo002/ooooo`03oa0@4?l0003o000000?o00003Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo09gooooo002^ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_oo
ool01Ol0003o^[ZjoooooonHV9So410@09oooooo002^ooooo`03o`000?oooooooooo00cooooo00?o
EEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7oc<c<09oooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -20 0 ]
[.5 .82364 20 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12.8) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69467 Mtetra
.4053 .69467 .41061 .69934 .41957 .69681 .41427 .69213 Mtetra
.41427 .69213 .41957 .69681 .42855 .69428 .42327 .68958 Mtetra
.42327 .68958 .42855 .69428 .43756 .69174 .43231 .68703 Mtetra
.43231 .68703 .43756 .69174 .4466 .68919 .44137 .68446 Mtetra
.44137 .68446 .4466 .68919 .45567 .68663 .45046 .68189 Mtetra
.45046 .68189 .45567 .68663 .46478 .68407 .45958 .67931 Mtetra
.45958 .67931 .46478 .68407 .47391 .68149 .46873 .67672 Mtetra
.46873 .67672 .47391 .68149 .48307 .67891 .47792 .67412 Mtetra
.47792 .67412 .48307 .67891 .49227 .67632 .48713 .67151 Mtetra
.48713 .67151 .49227 .67632 .50149 .67371 .49638 .66889 Mtetra
.49638 .66889 .50149 .67371 .51075 .6711 .50565 .66626 Mtetra
.50565 .66626 .51075 .6711 .52004 .66849 .51496 .66363 Mtetra
.51496 .66363 .52004 .66849 .52936 .66586 .5243 .66098 Mtetra
.5243 .66098 .52936 .66586 .53871 .66322 .53367 .65833 Mtetra
.53367 .65833 .53871 .66322 .54809 .66058 .54308 .65567 Mtetra
.54308 .65567 .54809 .66058 .55751 .65792 .55251 .653 Mtetra
.55251 .653 .55751 .65792 .56695 .65526 .56198 .65032 Mtetra
.56198 .65032 .56695 .65526 .57643 .65259 .57148 .64763 Mtetra
.57148 .64763 .57643 .65259 .58595 .6499 .58102 .64493 Mtetra
.58102 .64493 .58595 .6499 .59549 .64721 .59058 .64222 Mtetra
.59058 .64222 .59549 .64721 .60507 .64451 .60018 .6395 Mtetra
.60018 .6395 .60507 .64451 .61468 .6418 .60982 .63678 Mtetra
.60982 .63678 .61468 .6418 .62432 .63908 .61948 .63404 Mtetra
.61948 .63404 .62432 .63908 .634 .63636 .62918 .63129 Mtetra
.62918 .63129 .634 .63636 .64371 .63362 .63892 .62854 Mtetra
.63892 .62854 .64371 .63362 .65345 .63087 .64868 .62577 Mtetra
.64868 .62577 .65345 .63087 .66323 .62811 .65848 .623 Mtetra
.65848 .623 .66323 .62811 .67304 .62535 .66832 .62021 Mtetra
.66832 .62021 .67304 .62535 .68289 .62257 .67819 .61742 Mtetra
.67819 .61742 .68289 .62257 .69277 .61979 .68809 .61462 Mtetra
.68809 .61462 .69277 .61979 .70269 .61699 .69803 .6118 Mtetra
.69803 .6118 .70269 .61699 .71264 .61418 .70801 .60898 Mtetra
.70801 .60898 .71264 .61418 .72262 .61137 .71802 .60615 Mtetra
.71802 .60615 .72262 .61137 .73264 .60854 .72806 .6033 Mtetra
.72806 .6033 .73264 .60854 .7427 .60571 .73814 .60045 Mtetra
.73814 .60045 .7427 .60571 .75279 .60286 .74826 .59759 Mtetra
.74826 .59759 .75279 .60286 .76291 .60001 .75841 .59471 Mtetra
.75841 .59471 .76291 .60001 .77308 .59714 .7686 .59183 Mtetra
.7686 .59183 .77308 .59714 .78328 .59427 .77882 .58893 Mtetra
.77882 .58893 .78328 .59427 .79351 .59138 .78908 .58603 Mtetra
.78908 .58603 .79351 .59138 .80378 .58849 .79938 .58311 Mtetra
.79938 .58311 .80378 .58849 .81409 .58558 .80971 .58019 Mtetra
.80971 .58019 .81409 .58558 .82443 .58267 .82008 .57725 Mtetra
.82008 .57725 .82443 .58267 .83482 .57974 .83049 .57431 Mtetra
.83049 .57431 .83482 .57974 .84523 .5768 .84094 .57135 Mtetra
.84094 .57135 .84523 .5768 .85569 .57385 .85142 .56838 Mtetra
.85142 .56838 .85569 .57385 .86618 .57089 .86194 .5654 Mtetra
.86194 .5654 .86618 .57089 .87672 .56792 .8725 .56242 Mtetra
.8725 .56242 .87672 .56792 .88729 .56494 .8831 .55942 Mtetra
.8831 .55942 .88729 .56494 .89789 .56195 .89374 .5564 Mtetra
.89374 .5564 .89789 .56195 .90854 .55895 .90441 .55338 Mtetra
.90441 .55338 .90854 .55895 .91923 .55594 .91512 .55035 Mtetra
.91512 .55035 .91923 .55594 .92995 .55292 .92588 .54731 Mtetra
.92588 .54731 .92995 .55292 .94071 .54988 .93667 .54425 Mtetra
.93667 .54425 .94071 .54988 .95152 .54684 .9475 .54118 Mtetra
.9475 .54118 .95152 .54684 .96236 .54378 .95837 .53811 Mtetra
.95837 .53811 .96236 .54378 .97324 .54071 .96928 .53502 Mtetra
.96928 .53502 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.391 .69252 .39636 .6972 .4053 .69467 .39996 .68998 Mtetra
.39996 .68998 .4053 .69467 .41427 .69213 .40895 .68742 Mtetra
.40895 .68742 .41427 .69213 .42327 .68958 .41797 .68486 Mtetra
.41797 .68486 .42327 .68958 .43231 .68703 .42702 .68229 Mtetra
.42702 .68229 .43231 .68703 .44137 .68446 .4361 .67971 Mtetra
.4361 .67971 .44137 .68446 .45046 .68189 .44521 .67712 Mtetra
.44521 .67712 .45046 .68189 .45958 .67931 .45435 .67452 Mtetra
.45435 .67452 .45958 .67931 .46873 .67672 .46352 .67191 Mtetra
.46352 .67191 .46873 .67672 .47792 .67412 .47273 .66929 Mtetra
.47273 .66929 .47792 .67412 .48713 .67151 .48196 .66667 Mtetra
.48196 .66667 .48713 .67151 .49638 .66889 .49123 .66404 Mtetra
.49123 .66404 .49638 .66889 .50565 .66626 .50053 .66139 Mtetra
.50053 .66139 .50565 .66626 .51496 .66363 .50985 .65874 Mtetra
.50985 .65874 .51496 .66363 .5243 .66098 .51922 .65608 Mtetra
.51922 .65608 .5243 .66098 .53367 .65833 .52861 .65341 Mtetra
.52861 .65341 .53367 .65833 .54308 .65567 .53803 .65073 Mtetra
.53803 .65073 .54308 .65567 .55251 .653 .54749 .64804 Mtetra
.54749 .64804 .55251 .653 .56198 .65032 .55698 .64534 Mtetra
.55698 .64534 .56198 .65032 .57148 .64763 .5665 .64264 Mtetra
.5665 .64264 .57148 .64763 .58102 .64493 .57606 .63992 Mtetra
.57606 .63992 .58102 .64493 .59058 .64222 .58565 .6372 Mtetra
.58565 .6372 .59058 .64222 .60018 .6395 .59527 .63446 Mtetra
.59527 .63446 .60018 .6395 .60982 .63678 .60493 .63172 Mtetra
.60493 .63172 .60982 .63678 .61948 .63404 .61461 .62896 Mtetra
.61461 .62896 .61948 .63404 .62918 .63129 .62434 .6262 Mtetra
.62434 .6262 .62918 .63129 .63892 .62854 .63409 .62343 Mtetra
.63409 .62343 .63892 .62854 .64868 .62577 .64388 .62064 Mtetra
.64388 .62064 .64868 .62577 .65848 .623 .65371 .61785 Mtetra
.65371 .61785 .65848 .623 .66832 .62021 .66357 .61505 Mtetra
.66357 .61505 .66832 .62021 .67819 .61742 .67346 .61224 Mtetra
.67346 .61224 .67819 .61742 .68809 .61462 .68339 .60942 Mtetra
.68339 .60942 .68809 .61462 .69803 .6118 .69335 .60658 Mtetra
.69335 .60658 .69803 .6118 .70801 .60898 .70335 .60374 Mtetra
.70335 .60374 .70801 .60898 .71802 .60615 .71338 .60089 Mtetra
.71338 .60089 .71802 .60615 .72806 .6033 .72345 .59803 Mtetra
.72345 .59803 .72806 .6033 .73814 .60045 .73356 .59516 Mtetra
.73356 .59516 .73814 .60045 .74826 .59759 .7437 .59227 Mtetra
.7437 .59227 .74826 .59759 .75841 .59471 .75387 .58938 Mtetra
.75387 .58938 .75841 .59471 .7686 .59183 .76409 .58648 Mtetra
.76409 .58648 .7686 .59183 .77882 .58893 .77434 .58356 Mtetra
.77434 .58356 .77882 .58893 .78908 .58603 .78462 .58064 Mtetra
.78462 .58064 .78908 .58603 .79938 .58311 .79495 .57771 Mtetra
.79495 .57771 .79938 .58311 .80971 .58019 .80531 .57476 Mtetra
.80531 .57476 .80971 .58019 .82008 .57725 .81571 .57181 Mtetra
.81571 .57181 .82008 .57725 .83049 .57431 .82614 .56884 Mtetra
.82614 .56884 .83049 .57431 .84094 .57135 .83661 .56586 Mtetra
.83661 .56586 .84094 .57135 .85142 .56838 .84712 .56288 Mtetra
.84712 .56288 .85142 .56838 .86194 .5654 .85767 .55988 Mtetra
.85767 .55988 .86194 .5654 .8725 .56242 .86826 .55687 Mtetra
.86826 .55687 .8725 .56242 .8831 .55942 .87889 .55385 Mtetra
.87889 .55385 .8831 .55942 .89374 .5564 .88955 .55082 Mtetra
.88955 .55082 .89374 .5564 .90441 .55338 .90025 .54778 Mtetra
.90025 .54778 .90441 .55338 .91512 .55035 .911 .54472 Mtetra
.911 .54472 .91512 .55035 .92588 .54731 .92178 .54166 Mtetra
.92178 .54166 .92588 .54731 .93667 .54425 .9326 .53858 Mtetra
.9326 .53858 .93667 .54425 .9475 .54118 .94346 .53549 Mtetra
.94346 .53549 .9475 .54118 .95837 .53811 .95436 .5324 Mtetra
.95436 .5324 .95837 .53811 .96928 .53502 .9653 .52929 Mtetra
.9653 .52929 .96928 .53502 .98024 .53192 .97628 .52616 Mtetra
.38561 .68781 .391 .69252 .39996 .68998 .39459 .68525 Mtetra
.39459 .68525 .39996 .68998 .40895 .68742 .40359 .68268 Mtetra
.40359 .68268 .40895 .68742 .41797 .68486 .41263 .6801 Mtetra
.41263 .6801 .41797 .68486 .42702 .68229 .4217 .67752 Mtetra
.4217 .67752 .42702 .68229 .4361 .67971 .4308 .67492 Mtetra
.4308 .67492 .4361 .67971 .44521 .67712 .43993 .67231 Mtetra
.43993 .67231 .44521 .67712 .45435 .67452 .44909 .6697 Mtetra
.44909 .6697 .45435 .67452 .46352 .67191 .45828 .66708 Mtetra
.45828 .66708 .46352 .67191 .47273 .66929 .46751 .66444 Mtetra
.46751 .66444 .47273 .66929 .48196 .66667 .47676 .6618 Mtetra
.47676 .6618 .48196 .66667 .49123 .66404 .48605 .65915 Mtetra
.48605 .65915 .49123 .66404 .50053 .66139 .49537 .65649 Mtetra
.49537 .65649 .50053 .66139 .50985 .65874 .50472 .65382 Mtetra
.50472 .65382 .50985 .65874 .51922 .65608 .5141 .65114 Mtetra
.5141 .65114 .51922 .65608 .52861 .65341 .52351 .64846 Mtetra
.52351 .64846 .52861 .65341 .53803 .65073 .53296 .64576 Mtetra
.53296 .64576 .53803 .65073 .54749 .64804 .54244 .64305 Mtetra
.54244 .64305 .54749 .64804 .55698 .64534 .55195 .64034 Mtetra
.55195 .64034 .55698 .64534 .5665 .64264 .56149 .63762 Mtetra
.56149 .63762 .5665 .64264 .57606 .63992 .57107 .63488 Mtetra
.57107 .63488 .57606 .63992 .58565 .6372 .58068 .63214 Mtetra
.58068 .63214 .58565 .6372 .59527 .63446 .59032 .62939 Mtetra
.59032 .62939 .59527 .63446 .60493 .63172 .6 .62663 Mtetra
.6 .62663 .60493 .63172 .61461 .62896 .60971 .62385 Mtetra
.60971 .62385 .61461 .62896 .62434 .6262 .61946 .62107 Mtetra
.61946 .62107 .62434 .6262 .63409 .62343 .62924 .61828 Mtetra
.62924 .61828 .63409 .62343 .64388 .62064 .63905 .61548 Mtetra
.63905 .61548 .64388 .62064 .65371 .61785 .6489 .61267 Mtetra
.6489 .61267 .65371 .61785 .66357 .61505 .65878 .60985 Mtetra
.65878 .60985 .66357 .61505 .67346 .61224 .6687 .60702 Mtetra
.6687 .60702 .67346 .61224 .68339 .60942 .67865 .60418 Mtetra
.67865 .60418 .68339 .60942 .69335 .60658 .68864 .60133 Mtetra
.68864 .60133 .69335 .60658 .70335 .60374 .69866 .59847 Mtetra
.69866 .59847 .70335 .60374 .71338 .60089 .70872 .5956 Mtetra
.70872 .5956 .71338 .60089 .72345 .59803 .71881 .59272 Mtetra
.71881 .59272 .72345 .59803 .73356 .59516 .72894 .58983 Mtetra
.72894 .58983 .73356 .59516 .7437 .59227 .73911 .58692 Mtetra
.73911 .58692 .7437 .59227 .75387 .58938 .74931 .58401 Mtetra
.74931 .58401 .75387 .58938 .76409 .58648 .75955 .58109 Mtetra
.75955 .58109 .76409 .58648 .77434 .58356 .76982 .57816 Mtetra
.76982 .57816 .77434 .58356 .78462 .58064 .78014 .57521 Mtetra
.78014 .57521 .78462 .58064 .79495 .57771 .79049 .57226 Mtetra
.79049 .57226 .79495 .57771 .80531 .57476 .80087 .5693 Mtetra
.80087 .5693 .80531 .57476 .81571 .57181 .8113 .56632 Mtetra
.8113 .56632 .81571 .57181 .82614 .56884 .82176 .56334 Mtetra
.82176 .56334 .82614 .56884 .83661 .56586 .83226 .56034 Mtetra
.83226 .56034 .83661 .56586 .84712 .56288 .8428 .55733 Mtetra
.8428 .55733 .84712 .56288 .85767 .55988 .85337 .55431 Mtetra
.85337 .55431 .85767 .55988 .86826 .55687 .86399 .55129 Mtetra
.86399 .55129 .86826 .55687 .87889 .55385 .87464 .54825 Mtetra
.87464 .54825 .87889 .55385 .88955 .55082 .88534 .54519 Mtetra
.88534 .54519 .88955 .55082 .90025 .54778 .89607 .54213 Mtetra
.89607 .54213 .90025 .54778 .911 .54472 .90684 .53906 Mtetra
.90684 .53906 .911 .54472 .92178 .54166 .91765 .53597 Mtetra
.91765 .53597 .92178 .54166 .9326 .53858 .9285 .53288 Mtetra
.9285 .53288 .9326 .53858 .94346 .53549 .93939 .52977 Mtetra
.93939 .52977 .94346 .53549 .95436 .5324 .95032 .52665 Mtetra
.95032 .52665 .95436 .5324 .9653 .52929 .96129 .52351 Mtetra
.96129 .52351 .9653 .52929 .97628 .52616 .9723 .52037 Mtetra
.38018 .68308 .38561 .68781 .39459 .68525 .38918 .6805 Mtetra
.38918 .6805 .39459 .68525 .40359 .68268 .3982 .67792 Mtetra
.3982 .67792 .40359 .68268 .41263 .6801 .40726 .67532 Mtetra
.40726 .67532 .41263 .6801 .4217 .67752 .41635 .67272 Mtetra
.656 .752 .92 r
.41635 .67272 .4217 .67752 .4308 .67492 .42547 .67011 Mtetra
.42547 .67011 .4308 .67492 .43993 .67231 .43462 .66748 Mtetra
.43462 .66748 .43993 .67231 .44909 .6697 .4438 .66485 Mtetra
.4438 .66485 .44909 .6697 .45828 .66708 .45301 .66221 Mtetra
.45301 .66221 .45828 .66708 .46751 .66444 .46225 .65956 Mtetra
.46225 .65956 .46751 .66444 .47676 .6618 .47153 .6569 Mtetra
.656 .751 .92 r
.47153 .6569 .47676 .6618 .48605 .65915 .48083 .65424 Mtetra
.48083 .65424 .48605 .65915 .49537 .65649 .49017 .65156 Mtetra
.49017 .65156 .49537 .65649 .50472 .65382 .49954 .64887 Mtetra
.49954 .64887 .50472 .65382 .5141 .65114 .50895 .64618 Mtetra
.50895 .64618 .5141 .65114 .52351 .64846 .51838 .64347 Mtetra
.51838 .64347 .52351 .64846 .53296 .64576 .52785 .64076 Mtetra
.52785 .64076 .53296 .64576 .54244 .64305 .53735 .63804 Mtetra
.53735 .63804 .54244 .64305 .55195 .64034 .54688 .6353 Mtetra
.54688 .6353 .55195 .64034 .56149 .63762 .55645 .63256 Mtetra
.55645 .63256 .56149 .63762 .57107 .63488 .56605 .62981 Mtetra
.56605 .62981 .57107 .63488 .58068 .63214 .57568 .62705 Mtetra
.57568 .62705 .58068 .63214 .59032 .62939 .58535 .62428 Mtetra
.58535 .62428 .59032 .62939 .6 .62663 .59505 .6215 Mtetra
.59505 .6215 .6 .62663 .60971 .62385 .60478 .61871 Mtetra
.60478 .61871 .60971 .62385 .61946 .62107 .61455 .61591 Mtetra
.61455 .61591 .61946 .62107 .62924 .61828 .62435 .6131 Mtetra
.62435 .6131 .62924 .61828 .63905 .61548 .63419 .61028 Mtetra
.63419 .61028 .63905 .61548 .6489 .61267 .64406 .60746 Mtetra
.64406 .60746 .6489 .61267 .65878 .60985 .65396 .60462 Mtetra
.65396 .60462 .65878 .60985 .6687 .60702 .66391 .60177 Mtetra
.66391 .60177 .6687 .60702 .67865 .60418 .67388 .59891 Mtetra
.67388 .59891 .67865 .60418 .68864 .60133 .68389 .59604 Mtetra
.68389 .59604 .68864 .60133 .69866 .59847 .69394 .59316 Mtetra
.69394 .59316 .69866 .59847 .70872 .5956 .70402 .59027 Mtetra
.70402 .59027 .70872 .5956 .71881 .59272 .71414 .58737 Mtetra
.71414 .58737 .71881 .59272 .72894 .58983 .7243 .58446 Mtetra
.7243 .58446 .72894 .58983 .73911 .58692 .73449 .58154 Mtetra
.73449 .58154 .73911 .58692 .74931 .58401 .74472 .57861 Mtetra
.74472 .57861 .74931 .58401 .75955 .58109 .75498 .57567 Mtetra
.75498 .57567 .75955 .58109 .76982 .57816 .76528 .57272 Mtetra
.76528 .57272 .76982 .57816 .78014 .57521 .77562 .56975 Mtetra
.77562 .56975 .78014 .57521 .79049 .57226 .786 .56678 Mtetra
.786 .56678 .79049 .57226 .80087 .5693 .79641 .5638 Mtetra
.79641 .5638 .80087 .5693 .8113 .56632 .80686 .5608 Mtetra
.80686 .5608 .8113 .56632 .82176 .56334 .81735 .5578 Mtetra
.81735 .5578 .82176 .56334 .83226 .56034 .82788 .55478 Mtetra
.82788 .55478 .83226 .56034 .8428 .55733 .83844 .55175 Mtetra
.83844 .55175 .8428 .55733 .85337 .55431 .84905 .54871 Mtetra
.84905 .54871 .85337 .55431 .86399 .55129 .85969 .54567 Mtetra
.85969 .54567 .86399 .55129 .87464 .54825 .87037 .54261 Mtetra
.87037 .54261 .87464 .54825 .88534 .54519 .88109 .53953 Mtetra
.88109 .53953 .88534 .54519 .89607 .54213 .89185 .53645 Mtetra
.656 .752 .92 r
.89185 .53645 .89607 .54213 .90684 .53906 .90265 .53336 Mtetra
.90265 .53336 .90684 .53906 .91765 .53597 .91349 .53025 Mtetra
.91349 .53025 .91765 .53597 .9285 .53288 .92437 .52713 Mtetra
.92437 .52713 .9285 .53288 .93939 .52977 .93529 .524 Mtetra
.93529 .524 .93939 .52977 .95032 .52665 .94625 .52086 Mtetra
.656 .751 .92 r
.94625 .52086 .95032 .52665 .96129 .52351 .95725 .5177 Mtetra
.95725 .5177 .96129 .52351 .9723 .52037 .96829 .51454 Mtetra
.37472 .67831 .38018 .68308 .38918 .6805 .38373 .67572 Mtetra
.38373 .67572 .38918 .6805 .3982 .67792 .39278 .67312 Mtetra
.39278 .67312 .3982 .67792 .40726 .67532 .40186 .67051 Mtetra
.656 .752 .92 r
.40186 .67051 .40726 .67532 .41635 .67272 .41096 .66789 Mtetra
.41096 .66789 .41635 .67272 .42547 .67011 .4201 .66526 Mtetra
.4201 .66526 .42547 .67011 .43462 .66748 .42927 .66262 Mtetra
.42927 .66262 .43462 .66748 .4438 .66485 .43847 .65998 Mtetra
.43847 .65998 .4438 .66485 .45301 .66221 .4477 .65732 Mtetra
.4477 .65732 .45301 .66221 .46225 .65956 .45697 .65465 Mtetra
.45697 .65465 .46225 .65956 .47153 .6569 .46626 .65198 Mtetra
.46626 .65198 .47153 .6569 .48083 .65424 .47559 .64929 Mtetra
.47559 .64929 .48083 .65424 .49017 .65156 .48495 .6466 Mtetra
.656 .751 .92 r
.48495 .6466 .49017 .65156 .49954 .64887 .49434 .64389 Mtetra
.49434 .64389 .49954 .64887 .50895 .64618 .50376 .64118 Mtetra
.50376 .64118 .50895 .64618 .51838 .64347 .51322 .63846 Mtetra
.51322 .63846 .51838 .64347 .52785 .64076 .52271 .63573 Mtetra
.52271 .63573 .52785 .64076 .53735 .63804 .53223 .63299 Mtetra
.53223 .63299 .53735 .63804 .54688 .6353 .54178 .63024 Mtetra
.54178 .63024 .54688 .6353 .55645 .63256 .55137 .62748 Mtetra
.55137 .62748 .55645 .63256 .56605 .62981 .56099 .62471 Mtetra
.56099 .62471 .56605 .62981 .57568 .62705 .57065 .62193 Mtetra
.57065 .62193 .57568 .62705 .58535 .62428 .58034 .61914 Mtetra
.58034 .61914 .58535 .62428 .59505 .6215 .59006 .61634 Mtetra
.59006 .61634 .59505 .6215 .60478 .61871 .59982 .61354 Mtetra
.59982 .61354 .60478 .61871 .61455 .61591 .60961 .61072 Mtetra
.60961 .61072 .61455 .61591 .62435 .6131 .61943 .60789 Mtetra
.61943 .60789 .62435 .6131 .63419 .61028 .62929 .60505 Mtetra
.62929 .60505 .63419 .61028 .64406 .60746 .63919 .60221 Mtetra
.63919 .60221 .64406 .60746 .65396 .60462 .64912 .59935 Mtetra
.64912 .59935 .65396 .60462 .66391 .60177 .65908 .59648 Mtetra
.65908 .59648 .66391 .60177 .67388 .59891 .66908 .5936 Mtetra
.66908 .5936 .67388 .59891 .68389 .59604 .67912 .59072 Mtetra
.67912 .59072 .68389 .59604 .69394 .59316 .68919 .58782 Mtetra
.68919 .58782 .69394 .59316 .70402 .59027 .6993 .58491 Mtetra
.6993 .58491 .70402 .59027 .71414 .58737 .70944 .58199 Mtetra
.70944 .58199 .71414 .58737 .7243 .58446 .71962 .57906 Mtetra
.71962 .57906 .7243 .58446 .73449 .58154 .72984 .57612 Mtetra
.72984 .57612 .73449 .58154 .74472 .57861 .74009 .57317 Mtetra
.74009 .57317 .74472 .57861 .75498 .57567 .75038 .57021 Mtetra
.75038 .57021 .75498 .57567 .76528 .57272 .76071 .56724 Mtetra
.76071 .56724 .76528 .57272 .77562 .56975 .77107 .56426 Mtetra
.77107 .56426 .77562 .56975 .786 .56678 .78148 .56126 Mtetra
.78148 .56126 .786 .56678 .79641 .5638 .79192 .55826 Mtetra
.79192 .55826 .79641 .5638 .80686 .5608 .80239 .55524 Mtetra
.80239 .55524 .80686 .5608 .81735 .5578 .81291 .55222 Mtetra
.81291 .55222 .81735 .5578 .82788 .55478 .82346 .54918 Mtetra
.82346 .54918 .82788 .55478 .83844 .55175 .83406 .54614 Mtetra
.83406 .54614 .83844 .55175 .84905 .54871 .84469 .54308 Mtetra
.84469 .54308 .84905 .54871 .85969 .54567 .85536 .54001 Mtetra
.85536 .54001 .85969 .54567 .87037 .54261 .86607 .53693 Mtetra
.656 .752 .92 r
.86607 .53693 .87037 .54261 .88109 .53953 .87682 .53384 Mtetra
.87682 .53384 .88109 .53953 .89185 .53645 .88761 .53073 Mtetra
.88761 .53073 .89185 .53645 .90265 .53336 .89844 .52762 Mtetra
.89844 .52762 .90265 .53336 .91349 .53025 .90931 .52449 Mtetra
.90931 .52449 .91349 .53025 .92437 .52713 .92022 .52135 Mtetra
.92022 .52135 .92437 .52713 .93529 .524 .93117 .5182 Mtetra
.93117 .5182 .93529 .524 .94625 .52086 .94216 .51503 Mtetra
.94216 .51503 .94625 .52086 .95725 .5177 .95319 .51185 Mtetra
.95319 .51185 .95725 .5177 .96829 .51454 .96426 .50866 Mtetra
.656 .751 .92 r
.36922 .67351 .37472 .67831 .38373 .67572 .37826 .67091 Mtetra
.37826 .67091 .38373 .67572 .39278 .67312 .38732 .66829 Mtetra
.656 .752 .92 r
.38732 .66829 .39278 .67312 .40186 .67051 .39642 .66567 Mtetra
.656 .752 .921 r
.39642 .66567 .40186 .67051 .41096 .66789 .40554 .66304 Mtetra
.40554 .66304 .41096 .66789 .4201 .66526 .4147 .66039 Mtetra
.4147 .66039 .4201 .66526 .42927 .66262 .42389 .65774 Mtetra
.42389 .65774 .42927 .66262 .43847 .65998 .43311 .65507 Mtetra
.656 .752 .92 r
.43311 .65507 .43847 .65998 .4477 .65732 .44236 .6524 Mtetra
.44236 .6524 .4477 .65732 .45697 .65465 .45165 .64971 Mtetra
.45165 .64971 .45697 .65465 .46626 .65198 .46096 .64702 Mtetra
.46096 .64702 .46626 .65198 .47559 .64929 .47031 .64432 Mtetra
.47031 .64432 .47559 .64929 .48495 .6466 .47969 .6416 Mtetra
.47969 .6416 .48495 .6466 .49434 .64389 .4891 .63888 Mtetra
.4891 .63888 .49434 .64389 .50376 .64118 .49855 .63615 Mtetra
.656 .751 .92 r
.49855 .63615 .50376 .64118 .51322 .63846 .50802 .63341 Mtetra
.50802 .63341 .51322 .63846 .52271 .63573 .51753 .63066 Mtetra
.51753 .63066 .52271 .63573 .53223 .63299 .52708 .6279 Mtetra
.52708 .6279 .53223 .63299 .54178 .63024 .53665 .62514 Mtetra
.53665 .62514 .54178 .63024 .55137 .62748 .54626 .62236 Mtetra
.54626 .62236 .55137 .62748 .56099 .62471 .55591 .61957 Mtetra
.55591 .61957 .56099 .62471 .57065 .62193 .56558 .61677 Mtetra
.56558 .61677 .57065 .62193 .58034 .61914 .57529 .61397 Mtetra
.57529 .61397 .58034 .61914 .59006 .61634 .58504 .61115 Mtetra
.58504 .61115 .59006 .61634 .59982 .61354 .59482 .60833 Mtetra
.59482 .60833 .59982 .61354 .60961 .61072 .60463 .60549 Mtetra
.60463 .60549 .60961 .61072 .61943 .60789 .61448 .60265 Mtetra
.61448 .60265 .61943 .60789 .62929 .60505 .62437 .59979 Mtetra
.62437 .59979 .62929 .60505 .63919 .60221 .63428 .59692 Mtetra
.63428 .59692 .63919 .60221 .64912 .59935 .64424 .59405 Mtetra
.64424 .59405 .64912 .59935 .65908 .59648 .65423 .59116 Mtetra
.65423 .59116 .65908 .59648 .66908 .5936 .66425 .58826 Mtetra
.66425 .58826 .66908 .5936 .67912 .59072 .67431 .58536 Mtetra
.67431 .58536 .67912 .59072 .68919 .58782 .68441 .58244 Mtetra
.68441 .58244 .68919 .58782 .6993 .58491 .69454 .57951 Mtetra
.69454 .57951 .6993 .58491 .70944 .58199 .70471 .57657 Mtetra
.70471 .57657 .70944 .58199 .71962 .57906 .71491 .57363 Mtetra
.71491 .57363 .71962 .57906 .72984 .57612 .72516 .57067 Mtetra
.72516 .57067 .72984 .57612 .74009 .57317 .73544 .5677 Mtetra
.73544 .5677 .74009 .57317 .75038 .57021 .74575 .56472 Mtetra
.74575 .56472 .75038 .57021 .76071 .56724 .75611 .56172 Mtetra
.75611 .56172 .76071 .56724 .77107 .56426 .7665 .55872 Mtetra
.7665 .55872 .77107 .56426 .78148 .56126 .77693 .55571 Mtetra
.77693 .55571 .78148 .56126 .79192 .55826 .78739 .55268 Mtetra
.78739 .55268 .79192 .55826 .80239 .55524 .7979 .54965 Mtetra
.7979 .54965 .80239 .55524 .81291 .55222 .80844 .54661 Mtetra
.80844 .54661 .81291 .55222 .82346 .54918 .81902 .54355 Mtetra
.81902 .54355 .82346 .54918 .83406 .54614 .82964 .54048 Mtetra
.82964 .54048 .83406 .54614 .84469 .54308 .8403 .53741 Mtetra
.656 .752 .92 r
.8403 .53741 .84469 .54308 .85536 .54001 .851 .53432 Mtetra
.851 .53432 .85536 .54001 .86607 .53693 .86174 .53122 Mtetra
.656 .752 .921 r
.86174 .53122 .86607 .53693 .87682 .53384 .87252 .5281 Mtetra
.87252 .5281 .87682 .53384 .88761 .53073 .88334 .52498 Mtetra
.88334 .52498 .88761 .53073 .89844 .52762 .8942 .52184 Mtetra
.8942 .52184 .89844 .52762 .90931 .52449 .90509 .51869 Mtetra
.656 .752 .92 r
.90509 .51869 .90931 .52449 .92022 .52135 .91603 .51553 Mtetra
.91603 .51553 .92022 .52135 .93117 .5182 .92701 .51236 Mtetra
.92701 .51236 .93117 .5182 .94216 .51503 .93803 .50917 Mtetra
.93803 .50917 .94216 .51503 .95319 .51185 .94909 .50597 Mtetra
.94909 .50597 .95319 .51185 .96426 .50866 .9602 .50275 Mtetra
.655 .751 .92 r
.36369 .66869 .36922 .67351 .37826 .67091 .37275 .66607 Mtetra
.655 .751 .921 r
.37275 .66607 .37826 .67091 .38732 .66829 .38183 .66344 Mtetra
.655 .752 .921 r
.38183 .66344 .38732 .66829 .39642 .66567 .39094 .6608 Mtetra
.656 .752 .921 r
.39094 .6608 .39642 .66567 .40554 .66304 .40009 .65816 Mtetra
.40009 .65816 .40554 .66304 .4147 .66039 .40927 .6555 Mtetra
.40927 .6555 .4147 .66039 .42389 .65774 .41848 .65283 Mtetra
.41848 .65283 .42389 .65774 .43311 .65507 .42772 .65014 Mtetra
.42772 .65014 .43311 .65507 .44236 .6524 .43699 .64745 Mtetra
.43699 .64745 .44236 .6524 .45165 .64971 .44629 .64475 Mtetra
.44629 .64475 .45165 .64971 .46096 .64702 .45563 .64203 Mtetra
.656 .752 .92 r
.45563 .64203 .46096 .64702 .47031 .64432 .465 .63931 Mtetra
.465 .63931 .47031 .64432 .47969 .6416 .4744 .63658 Mtetra
.4744 .63658 .47969 .6416 .4891 .63888 .48383 .63384 Mtetra
.48383 .63384 .4891 .63888 .49855 .63615 .4933 .63109 Mtetra
.4933 .63109 .49855 .63615 .50802 .63341 .50279 .62833 Mtetra
.656 .751 .92 r
.50279 .62833 .50802 .63341 .51753 .63066 .51233 .62556 Mtetra
.51233 .62556 .51753 .63066 .52708 .6279 .52189 .62279 Mtetra
.52189 .62279 .52708 .6279 .53665 .62514 .53149 .62 Mtetra
.53149 .62 .53665 .62514 .54626 .62236 .54112 .61721 Mtetra
.54112 .61721 .54626 .62236 .55591 .61957 .55079 .6144 Mtetra
.55079 .6144 .55591 .61957 .56558 .61677 .56049 .61159 Mtetra
.56049 .61159 .56558 .61677 .57529 .61397 .57022 .60876 Mtetra
.57022 .60876 .57529 .61397 .58504 .61115 .57999 .60593 Mtetra
.57999 .60593 .58504 .61115 .59482 .60833 .58979 .60308 Mtetra
.58979 .60308 .59482 .60833 .60463 .60549 .59963 .60023 Mtetra
.59963 .60023 .60463 .60549 .61448 .60265 .6095 .59737 Mtetra
.6095 .59737 .61448 .60265 .62437 .59979 .61941 .59449 Mtetra
.61941 .59449 .62437 .59979 .63428 .59692 .62935 .59161 Mtetra
.62935 .59161 .63428 .59692 .64424 .59405 .63933 .58871 Mtetra
.63933 .58871 .64424 .59405 .65423 .59116 .64934 .58581 Mtetra
.64934 .58581 .65423 .59116 .66425 .58826 .65939 .58289 Mtetra
.65939 .58289 .66425 .58826 .67431 .58536 .66947 .57996 Mtetra
.66947 .57996 .67431 .58536 .68441 .58244 .67959 .57703 Mtetra
.67959 .57703 .68441 .58244 .69454 .57951 .68975 .57408 Mtetra
.68975 .57408 .69454 .57951 .70471 .57657 .69995 .57112 Mtetra
.69995 .57112 .70471 .57657 .71491 .57363 .71018 .56815 Mtetra
.71018 .56815 .71491 .57363 .72516 .57067 .72044 .56517 Mtetra
.72044 .56517 .72516 .57067 .73544 .5677 .73075 .56218 Mtetra
.73075 .56218 .73544 .5677 .74575 .56472 .74109 .55918 Mtetra
.74109 .55918 .74575 .56472 .75611 .56172 .75147 .55617 Mtetra
.75147 .55617 .75611 .56172 .7665 .55872 .76189 .55315 Mtetra
.76189 .55315 .7665 .55872 .77693 .55571 .77234 .55012 Mtetra
.77234 .55012 .77693 .55571 .78739 .55268 .78284 .54707 Mtetra
.78284 .54707 .78739 .55268 .7979 .54965 .79337 .54402 Mtetra
.79337 .54402 .7979 .54965 .80844 .54661 .80394 .54095 Mtetra
.80394 .54095 .80844 .54661 .81902 .54355 .81455 .53788 Mtetra
.81455 .53788 .81902 .54355 .82964 .54048 .8252 .53479 Mtetra
.656 .752 .92 r
.8252 .53479 .82964 .54048 .8403 .53741 .83589 .5317 Mtetra
.656 .752 .921 r
.83589 .5317 .8403 .53741 .851 .53432 .84662 .52859 Mtetra
.84662 .52859 .851 .53432 .86174 .53122 .85738 .52547 Mtetra
.85738 .52547 .86174 .53122 .87252 .5281 .86819 .52234 Mtetra
.86819 .52234 .87252 .5281 .88334 .52498 .87904 .51919 Mtetra
.87904 .51919 .88334 .52498 .8942 .52184 .88992 .51604 Mtetra
.88992 .51604 .8942 .52184 .90509 .51869 .90085 .51286 Mtetra
.90085 .51286 .90509 .51869 .91603 .51553 .91182 .50968 Mtetra
.91182 .50968 .91603 .51553 .92701 .51236 .92283 .50648 Mtetra
.656 .752 .92 r
.92283 .50648 .92701 .51236 .93803 .50917 .93388 .50326 Mtetra
.93388 .50326 .93803 .50917 .94909 .50597 .94497 .50004 Mtetra
.94497 .50004 .94909 .50597 .9602 .50275 .9561 .4968 Mtetra
.655 .751 .921 r
.35813 .66383 .36369 .66869 .37275 .66607 .3672 .6612 Mtetra
.3672 .6612 .37275 .66607 .38183 .66344 .3763 .65856 Mtetra
.655 .752 .921 r
.3763 .65856 .38183 .66344 .39094 .6608 .38544 .65591 Mtetra
.38544 .65591 .39094 .6608 .40009 .65816 .3946 .65325 Mtetra
.3946 .65325 .40009 .65816 .40927 .6555 .4038 .65058 Mtetra
.656 .752 .921 r
.4038 .65058 .40927 .6555 .41848 .65283 .41303 .64789 Mtetra
.41303 .64789 .41848 .65283 .42772 .65014 .42229 .64519 Mtetra
.42229 .64519 .42772 .65014 .43699 .64745 .43158 .64248 Mtetra
.43158 .64248 .43699 .64745 .44629 .64475 .4409 .63976 Mtetra
.4409 .63976 .44629 .64475 .45563 .64203 .45026 .63702 Mtetra
.45026 .63702 .45563 .64203 .465 .63931 .45965 .63428 Mtetra
.45965 .63428 .465 .63931 .4744 .63658 .46907 .63153 Mtetra
.656 .752 .92 r
.46907 .63153 .4744 .63658 .48383 .63384 .47852 .62877 Mtetra
.47852 .62877 .48383 .63384 .4933 .63109 .48801 .626 Mtetra
.48801 .626 .4933 .63109 .50279 .62833 .49753 .62322 Mtetra
.49753 .62322 .50279 .62833 .51233 .62556 .50709 .62043 Mtetra
.50709 .62043 .51233 .62556 .52189 .62279 .51667 .61764 Mtetra
.656 .751 .92 r
.51667 .61764 .52189 .62279 .53149 .62 .52629 .61484 Mtetra
.52629 .61484 .53149 .62 .54112 .61721 .53595 .61202 Mtetra
.53595 .61202 .54112 .61721 .55079 .6144 .54563 .6092 Mtetra
.54563 .6092 .55079 .6144 .56049 .61159 .55536 .60637 Mtetra
.55536 .60637 .56049 .61159 .57022 .60876 .56511 .60352 Mtetra
.56511 .60352 .57022 .60876 .57999 .60593 .5749 .60067 Mtetra
.5749 .60067 .57999 .60593 .58979 .60308 .58473 .59781 Mtetra
.58473 .59781 .58979 .60308 .59963 .60023 .59459 .59493 Mtetra
.59459 .59493 .59963 .60023 .6095 .59737 .60448 .59205 Mtetra
.60448 .59205 .6095 .59737 .61941 .59449 .61441 .58916 Mtetra
.61441 .58916 .61941 .59449 .62935 .59161 .62438 .58625 Mtetra
.62438 .58625 .62935 .59161 .63933 .58871 .63438 .58334 Mtetra
.63438 .58334 .63933 .58871 .64934 .58581 .64442 .58041 Mtetra
.64442 .58041 .64934 .58581 .65939 .58289 .65449 .57748 Mtetra
.65449 .57748 .65939 .58289 .66947 .57996 .6646 .57453 Mtetra
.6646 .57453 .66947 .57996 .67959 .57703 .67475 .57158 Mtetra
.67475 .57158 .67959 .57703 .68975 .57408 .68493 .56861 Mtetra
.68493 .56861 .68975 .57408 .69995 .57112 .69515 .56563 Mtetra
.69515 .56563 .69995 .57112 .71018 .56815 .70541 .56264 Mtetra
.70541 .56264 .71018 .56815 .72044 .56517 .7157 .55965 Mtetra
.7157 .55965 .72044 .56517 .73075 .56218 .72603 .55664 Mtetra
.72603 .55664 .73075 .56218 .74109 .55918 .7364 .55362 Mtetra
.7364 .55362 .74109 .55918 .75147 .55617 .7468 .55058 Mtetra
.7468 .55058 .75147 .55617 .76189 .55315 .75725 .54754 Mtetra
.75725 .54754 .76189 .55315 .77234 .55012 .76773 .54449 Mtetra
.76773 .54449 .77234 .55012 .78284 .54707 .77825 .54143 Mtetra
.77825 .54143 .78284 .54707 .79337 .54402 .78881 .53835 Mtetra
.78881 .53835 .79337 .54402 .80394 .54095 .79941 .53527 Mtetra
.656 .752 .92 r
.79941 .53527 .80394 .54095 .81455 .53788 .81005 .53217 Mtetra
.656 .752 .921 r
.81005 .53217 .81455 .53788 .8252 .53479 .82073 .52907 Mtetra
.655 .752 .921 r
.82073 .52907 .8252 .53479 .83589 .5317 .83144 .52595 Mtetra
.83144 .52595 .83589 .5317 .84662 .52859 .8422 .52283 Mtetra
.8422 .52283 .84662 .52859 .85738 .52547 .853 .51969 Mtetra
.853 .51969 .85738 .52547 .86819 .52234 .86383 .51654 Mtetra
.656 .752 .921 r
.86383 .51654 .86819 .52234 .87904 .51919 .87471 .51337 Mtetra
.87471 .51337 .87904 .51919 .88992 .51604 .88563 .51019 Mtetra
.88563 .51019 .88992 .51604 .90085 .51286 .89658 .507 Mtetra
.89658 .507 .90085 .51286 .91182 .50968 .90758 .50379 Mtetra
.90758 .50379 .91182 .50968 .92283 .50648 .91862 .50056 Mtetra
.91862 .50056 .92283 .50648 .93388 .50326 .9297 .49732 Mtetra
.656 .752 .92 r
.9297 .49732 .93388 .50326 .94497 .50004 .94082 .49407 Mtetra
.94082 .49407 .94497 .50004 .9561 .4968 .95198 .4908 Mtetra
.655 .751 .921 r
.35253 .65894 .35813 .66383 .3672 .6612 .36162 .65631 Mtetra
.36162 .65631 .3672 .6612 .3763 .65856 .37074 .65366 Mtetra
.655 .752 .921 r
.37074 .65366 .3763 .65856 .38544 .65591 .37989 .651 Mtetra
.37989 .651 .38544 .65591 .3946 .65325 .38908 .64832 Mtetra
.38908 .64832 .3946 .65325 .4038 .65058 .39829 .64564 Mtetra
.655 .753 .921 r
.39829 .64564 .4038 .65058 .41303 .64789 .40754 .64293 Mtetra
.656 .753 .921 r
.40754 .64293 .41303 .64789 .42229 .64519 .41682 .64022 Mtetra
.41682 .64022 .42229 .64519 .43158 .64248 .42614 .63749 Mtetra
.42614 .63749 .43158 .64248 .4409 .63976 .43548 .63475 Mtetra
.43548 .63475 .4409 .63976 .45026 .63702 .44486 .63199 Mtetra
.656 .752 .921 r
.44486 .63199 .45026 .63702 .45965 .63428 .45427 .62923 Mtetra
.45427 .62923 .45965 .63428 .46907 .63153 .46371 .62645 Mtetra
.46371 .62645 .46907 .63153 .47852 .62877 .47319 .62367 Mtetra
.656 .752 .92 r
.47319 .62367 .47852 .62877 .48801 .626 .48269 .62088 Mtetra
.48269 .62088 .48801 .626 .49753 .62322 .49224 .61808 Mtetra
.49224 .61808 .49753 .62322 .50709 .62043 .50181 .61527 Mtetra
.50181 .61527 .50709 .62043 .51667 .61764 .51142 .61246 Mtetra
.51142 .61246 .51667 .61764 .52629 .61484 .52106 .60964 Mtetra
.656 .751 .92 r
.52106 .60964 .52629 .61484 .53595 .61202 .53074 .6068 Mtetra
.53074 .6068 .53595 .61202 .54563 .6092 .54045 .60396 Mtetra
.54045 .60396 .54563 .6092 .55536 .60637 .55019 .60111 Mtetra
.55019 .60111 .55536 .60637 .56511 .60352 .55997 .59825 Mtetra
.55997 .59825 .56511 .60352 .5749 .60067 .56978 .59538 Mtetra
.56978 .59538 .5749 .60067 .58473 .59781 .57963 .59249 Mtetra
.57963 .59249 .58473 .59781 .59459 .59493 .58952 .5896 Mtetra
.58952 .5896 .59459 .59493 .60448 .59205 .59944 .5867 Mtetra
.59944 .5867 .60448 .59205 .61441 .58916 .60939 .58379 Mtetra
.60939 .58379 .61441 .58916 .62438 .58625 .61938 .58087 Mtetra
.61938 .58087 .62438 .58625 .63438 .58334 .62941 .57793 Mtetra
.62941 .57793 .63438 .58334 .64442 .58041 .63947 .57499 Mtetra
.63947 .57499 .64442 .58041 .65449 .57748 .64957 .57203 Mtetra
.64957 .57203 .65449 .57748 .6646 .57453 .6597 .56907 Mtetra
.6597 .56907 .6646 .57453 .67475 .57158 .66987 .56609 Mtetra
.66987 .56609 .67475 .57158 .68493 .56861 .68008 .56311 Mtetra
.68008 .56311 .68493 .56861 .69515 .56563 .69032 .56011 Mtetra
.69032 .56011 .69515 .56563 .70541 .56264 .7006 .5571 Mtetra
.7006 .5571 .70541 .56264 .7157 .55965 .71092 .55408 Mtetra
.71092 .55408 .7157 .55965 .72603 .55664 .72128 .55105 Mtetra
.72128 .55105 .72603 .55664 .7364 .55362 .73168 .54801 Mtetra
.73168 .54801 .7364 .55362 .7468 .55058 .74211 .54496 Mtetra
.74211 .54496 .7468 .55058 .75725 .54754 .75258 .5419 Mtetra
.75258 .5419 .75725 .54754 .76773 .54449 .76309 .53882 Mtetra
.76309 .53882 .76773 .54449 .77825 .54143 .77364 .53574 Mtetra
.77364 .53574 .77825 .54143 .78881 .53835 .78422 .53265 Mtetra
.655 .752 .921 r
.78422 .53265 .78881 .53835 .79941 .53527 .79485 .52955 Mtetra
.79485 .52955 .79941 .53527 .81005 .53217 .80552 .52643 Mtetra
.80552 .52643 .81005 .53217 .82073 .52907 .81622 .52331 Mtetra
.81622 .52331 .82073 .52907 .83144 .52595 .82697 .52018 Mtetra
.82697 .52018 .83144 .52595 .8422 .52283 .83775 .51704 Mtetra
.83775 .51704 .8422 .52283 .853 .51969 .84858 .51388 Mtetra
.84858 .51388 .853 .51969 .86383 .51654 .85944 .51071 Mtetra
.655 .753 .921 r
.85944 .51071 .86383 .51654 .87471 .51337 .87035 .50753 Mtetra
.656 .753 .921 r
.87035 .50753 .87471 .51337 .88563 .51019 .8813 .50432 Mtetra
.8813 .50432 .88563 .51019 .89658 .507 .89228 .50111 Mtetra
.89228 .50111 .89658 .507 .90758 .50379 .90331 .49787 Mtetra
.90331 .49787 .90758 .50379 .91862 .50056 .91438 .49462 Mtetra
.91438 .49462 .91862 .50056 .9297 .49732 .92549 .49135 Mtetra
.657 .752 .92 r
.92549 .49135 .9297 .49732 .94082 .49407 .93664 .48806 Mtetra
.93664 .48806 .94082 .49407 .95198 .4908 .94784 .48476 Mtetra
.654 .751 .921 r
.34689 .65403 .35253 .65894 .36162 .65631 .356 .65138 Mtetra
.356 .65138 .36162 .65631 .37074 .65366 .36514 .64873 Mtetra
.655 .752 .921 r
.36514 .64873 .37074 .65366 .37989 .651 .37431 .64606 Mtetra
.655 .752 .922 r
.37431 .64606 .37989 .651 .38908 .64832 .38352 .64338 Mtetra
.655 .753 .922 r
.38352 .64338 .38908 .64832 .39829 .64564 .39275 .64068 Mtetra
.39275 .64068 .39829 .64564 .40754 .64293 .40202 .63796 Mtetra
.656 .753 .922 r
.40202 .63796 .40754 .64293 .41682 .64022 .41132 .63523 Mtetra
.41132 .63523 .41682 .64022 .42614 .63749 .42066 .63248 Mtetra
.42066 .63248 .42614 .63749 .43548 .63475 .43002 .62972 Mtetra
.656 .753 .921 r
.43002 .62972 .43548 .63475 .44486 .63199 .43942 .62694 Mtetra
.43942 .62694 .44486 .63199 .45427 .62923 .44885 .62415 Mtetra
.44885 .62415 .45427 .62923 .46371 .62645 .45831 .62135 Mtetra
.45831 .62135 .46371 .62645 .47319 .62367 .46781 .61855 Mtetra
.656 .752 .921 r
.46781 .61855 .47319 .62367 .48269 .62088 .47734 .61573 Mtetra
.47734 .61573 .48269 .62088 .49224 .61808 .4869 .61291 Mtetra
.656 .752 .92 r
.4869 .61291 .49224 .61808 .50181 .61527 .4965 .61008 Mtetra
.4965 .61008 .50181 .61527 .51142 .61246 .50613 .60725 Mtetra
.50613 .60725 .51142 .61246 .52106 .60964 .5158 .6044 Mtetra
.5158 .6044 .52106 .60964 .53074 .6068 .52549 .60155 Mtetra
.656 .751 .92 r
.52549 .60155 .53074 .6068 .54045 .60396 .53523 .59869 Mtetra
.53523 .59869 .54045 .60396 .55019 .60111 .54499 .59582 Mtetra
.54499 .59582 .55019 .60111 .55997 .59825 .5548 .59294 Mtetra
.5548 .59294 .55997 .59825 .56978 .59538 .56463 .59005 Mtetra
.56463 .59005 .56978 .59538 .57963 .59249 .5745 .58715 Mtetra
.5745 .58715 .57963 .59249 .58952 .5896 .58441 .58424 Mtetra
.58441 .58424 .58952 .5896 .59944 .5867 .59435 .58132 Mtetra
.59435 .58132 .59944 .5867 .60939 .58379 .60433 .57838 Mtetra
.60433 .57838 .60939 .58379 .61938 .58087 .61435 .57544 Mtetra
.61435 .57544 .61938 .58087 .62941 .57793 .6244 .57249 Mtetra
.6244 .57249 .62941 .57793 .63947 .57499 .63448 .56952 Mtetra
.63448 .56952 .63947 .57499 .64957 .57203 .6446 .56655 Mtetra
.6446 .56655 .64957 .57203 .6597 .56907 .65476 .56357 Mtetra
.65476 .56357 .6597 .56907 .66987 .56609 .66496 .56057 Mtetra
.66496 .56057 .66987 .56609 .68008 .56311 .67519 .55756 Mtetra
.67519 .55756 .68008 .56311 .69032 .56011 .68546 .55455 Mtetra
.68546 .55455 .69032 .56011 .7006 .5571 .69577 .55152 Mtetra
.69577 .55152 .7006 .5571 .71092 .55408 .70612 .54848 Mtetra
.70612 .54848 .71092 .55408 .72128 .55105 .7165 .54543 Mtetra
.7165 .54543 .72128 .55105 .73168 .54801 .72692 .54237 Mtetra
.72692 .54237 .73168 .54801 .74211 .54496 .73738 .53929 Mtetra
.73738 .53929 .74211 .54496 .75258 .5419 .74788 .53621 Mtetra
.74788 .53621 .75258 .5419 .76309 .53882 .75841 .53312 Mtetra
.75841 .53312 .76309 .53882 .77364 .53574 .76899 .53002 Mtetra
.655 .752 .921 r
.76899 .53002 .77364 .53574 .78422 .53265 .7796 .52691 Mtetra
.7796 .52691 .78422 .53265 .79485 .52955 .79026 .52379 Mtetra
.79026 .52379 .79485 .52955 .80552 .52643 .80095 .52066 Mtetra
.80095 .52066 .80552 .52643 .81622 .52331 .81169 .51753 Mtetra
.81169 .51753 .81622 .52331 .82697 .52018 .82246 .51438 Mtetra
.655 .752 .922 r
.82246 .51438 .82697 .52018 .83775 .51704 .83328 .51122 Mtetra
.655 .753 .922 r
.83328 .51122 .83775 .51704 .84858 .51388 .84413 .50805 Mtetra
.84413 .50805 .84858 .51388 .85944 .51071 .85503 .50486 Mtetra
.85503 .50486 .85944 .51071 .87035 .50753 .86596 .50166 Mtetra
.656 .753 .922 r
.86596 .50166 .87035 .50753 .8813 .50432 .87694 .49843 Mtetra
.87694 .49843 .8813 .50432 .89228 .50111 .88796 .49519 Mtetra
.656 .753 .921 r
.88796 .49519 .89228 .50111 .90331 .49787 .89902 .49192 Mtetra
.657 .753 .921 r
.89902 .49192 .90331 .49787 .91438 .49462 .91011 .48864 Mtetra
.91011 .48864 .91438 .49462 .92549 .49135 .92125 .48533 Mtetra
.92125 .48533 .92549 .49135 .93664 .48806 .93243 .48201 Mtetra
.657 .752 .92 r
.93243 .48201 .93664 .48806 .94784 .48476 .94366 .47868 Mtetra
.654 .751 .921 r
.34122 .64908 .34689 .65403 .356 .65138 .35035 .64643 Mtetra
.654 .751 .922 r
.35035 .64643 .356 .65138 .36514 .64873 .35951 .64377 Mtetra
.654 .752 .922 r
.35951 .64377 .36514 .64873 .37431 .64606 .3687 .6411 Mtetra
.654 .753 .922 r
.3687 .6411 .37431 .64606 .38352 .64338 .37792 .63841 Mtetra
.655 .753 .922 r
.37792 .63841 .38352 .64338 .39275 .64068 .38718 .63571 Mtetra
.655 .754 .922 r
.38718 .63571 .39275 .64068 .40202 .63796 .39647 .63298 Mtetra
.39647 .63298 .40202 .63796 .41132 .63523 .40579 .63023 Mtetra
.656 .754 .922 r
.40579 .63023 .41132 .63523 .42066 .63248 .41514 .62747 Mtetra
.41514 .62747 .42066 .63248 .43002 .62972 .42453 .62468 Mtetra
.657 .754 .922 r
.42453 .62468 .43002 .62972 .43942 .62694 .43395 .62188 Mtetra
.43395 .62188 .43942 .62694 .44885 .62415 .4434 .61906 Mtetra
.657 .754 .921 r
.4434 .61906 .44885 .62415 .45831 .62135 .45288 .61624 Mtetra
.657 .753 .921 r
.45288 .61624 .45831 .62135 .46781 .61855 .4624 .6134 Mtetra
.4624 .6134 .46781 .61855 .47734 .61573 .47195 .61056 Mtetra
.656 .753 .921 r
.47195 .61056 .47734 .61573 .4869 .61291 .48154 .60772 Mtetra
.656 .752 .921 r
.48154 .60772 .4869 .61291 .4965 .61008 .49116 .60486 Mtetra
.656 .752 .92 r
.49116 .60486 .4965 .61008 .50613 .60725 .50081 .60201 Mtetra
.50081 .60201 .50613 .60725 .5158 .6044 .5105 .59914 Mtetra
.5105 .59914 .5158 .6044 .52549 .60155 .52022 .59627 Mtetra
.52022 .59627 .52549 .60155 .53523 .59869 .52997 .59339 Mtetra
.656 .751 .92 r
.52997 .59339 .53523 .59869 .54499 .59582 .53976 .5905 Mtetra
.53976 .5905 .54499 .59582 .5548 .59294 .54959 .5876 Mtetra
.54959 .5876 .5548 .59294 .56463 .59005 .55945 .58469 Mtetra
.55945 .58469 .56463 .59005 .5745 .58715 .56934 .58177 Mtetra
.56934 .58177 .5745 .58715 .58441 .58424 .57927 .57884 Mtetra
.57927 .57884 .58441 .58424 .59435 .58132 .58924 .57589 Mtetra
.58924 .57589 .59435 .58132 .60433 .57838 .59924 .57294 Mtetra
.59924 .57294 .60433 .57838 .61435 .57544 .60928 .56998 Mtetra
.60928 .56998 .61435 .57544 .6244 .57249 .61935 .56701 Mtetra
.61935 .56701 .6244 .57249 .63448 .56952 .62946 .56403 Mtetra
.62946 .56403 .63448 .56952 .6446 .56655 .63961 .56103 Mtetra
.63961 .56103 .6446 .56655 .65476 .56357 .64979 .55803 Mtetra
.64979 .55803 .65476 .56357 .66496 .56057 .66002 .55501 Mtetra
.66002 .55501 .66496 .56057 .67519 .55756 .67027 .55198 Mtetra
.67027 .55198 .67519 .55756 .68546 .55455 .68057 .54895 Mtetra
.68057 .54895 .68546 .55455 .69577 .55152 .6909 .5459 Mtetra
.6909 .5459 .69577 .55152 .70612 .54848 .70127 .54284 Mtetra
.70127 .54284 .70612 .54848 .7165 .54543 .71168 .53977 Mtetra
.71168 .53977 .7165 .54543 .72692 .54237 .72213 .53669 Mtetra
.72213 .53669 .72692 .54237 .73738 .53929 .73262 .53359 Mtetra
.73262 .53359 .73738 .53929 .74788 .53621 .74314 .53049 Mtetra
.655 .751 .92 r
.74314 .53049 .74788 .53621 .75841 .53312 .75371 .52738 Mtetra
.655 .752 .921 r
.75371 .52738 .75841 .53312 .76899 .53002 .76431 .52427 Mtetra
.76431 .52427 .76899 .53002 .7796 .52691 .77495 .52114 Mtetra
.77495 .52114 .7796 .52691 .79026 .52379 .78564 .51801 Mtetra
.78564 .51801 .79026 .52379 .80095 .52066 .79636 .51487 Mtetra
.655 .752 .922 r
.79636 .51487 .80095 .52066 .81169 .51753 .80712 .51172 Mtetra
.655 .753 .922 r
.80712 .51172 .81169 .51753 .82246 .51438 .81793 .50856 Mtetra
.81793 .50856 .82246 .51438 .83328 .51122 .82877 .50539 Mtetra
.82877 .50539 .83328 .51122 .84413 .50805 .83966 .5022 Mtetra
.655 .754 .923 r
.83966 .5022 .84413 .50805 .85503 .50486 .85058 .499 Mtetra
.85058 .499 .85503 .50486 .86596 .50166 .86155 .49577 Mtetra
.656 .754 .922 r
.86155 .49577 .86596 .50166 .87694 .49843 .87256 .49252 Mtetra
.87256 .49252 .87694 .49843 .88796 .49519 .8836 .48925 Mtetra
.657 .754 .922 r
.8836 .48925 .88796 .49519 .89902 .49192 .89469 .48595 Mtetra
.89469 .48595 .89902 .49192 .91011 .48864 .90582 .48263 Mtetra
.657 .754 .921 r
.90582 .48263 .91011 .48864 .92125 .48533 .91699 .47929 Mtetra
.657 .753 .921 r
.91699 .47929 .92125 .48533 .93243 .48201 .9282 .47593 Mtetra
.658 .753 .92 r
.9282 .47593 .93243 .48201 .94366 .47868 .93945 .47256 Mtetra
.653 .751 .922 r
.33552 .6441 .34122 .64908 .35035 .64643 .34466 .64145 Mtetra
.34466 .64145 .35035 .64643 .35951 .64377 .35384 .6388 Mtetra
.653 .752 .922 r
.35384 .6388 .35951 .64377 .3687 .6411 .36305 .63613 Mtetra
.653 .753 .923 r
.36305 .63613 .3687 .6411 .37792 .63841 .37229 .63344 Mtetra
.654 .754 .923 r
.37229 .63344 .37792 .63841 .38718 .63571 .38157 .63073 Mtetra
.38157 .63073 .38718 .63571 .39647 .63298 .39087 .628 Mtetra
.655 .755 .923 r
.39087 .628 .39647 .63298 .40579 .63023 .40021 .62524 Mtetra
.656 .755 .923 r
.40021 .62524 .40579 .63023 .41514 .62747 .40959 .62246 Mtetra
.656 .756 .923 r
.40959 .62246 .41514 .62747 .42453 .62468 .419 .61965 Mtetra
.657 .756 .923 r
.419 .61965 .42453 .62468 .43395 .62188 .42844 .61682 Mtetra
.657 .755 .922 r
.42844 .61682 .43395 .62188 .4434 .61906 .43791 .61397 Mtetra
.43791 .61397 .4434 .61906 .45288 .61624 .44742 .61112 Mtetra
.44742 .61112 .45288 .61624 .4624 .6134 .45696 .60825 Mtetra
.657 .754 .921 r
.45696 .60825 .4624 .6134 .47195 .61056 .46653 .60538 Mtetra
.657 .753 .921 r
.46653 .60538 .47195 .61056 .48154 .60772 .47614 .6025 Mtetra
.47614 .6025 .48154 .60772 .49116 .60486 .48578 .59962 Mtetra
.656 .752 .921 r
.48578 .59962 .49116 .60486 .50081 .60201 .49545 .59674 Mtetra
.656 .752 .92 r
.49545 .59674 .50081 .60201 .5105 .59914 .50516 .59385 Mtetra
.50516 .59385 .5105 .59914 .52022 .59627 .5149 .59095 Mtetra
.5149 .59095 .52022 .59627 .52997 .59339 .52468 .58805 Mtetra
.52468 .58805 .52997 .59339 .53976 .5905 .5345 .58514 Mtetra
.656 .751 .92 r
.5345 .58514 .53976 .5905 .54959 .5876 .54434 .58222 Mtetra
.54434 .58222 .54959 .5876 .55945 .58469 .55423 .57929 Mtetra
.55423 .57929 .55945 .58469 .56934 .58177 .56414 .57635 Mtetra
.56414 .57635 .56934 .58177 .57927 .57884 .5741 .5734 Mtetra
.5741 .5734 .57927 .57884 .58924 .57589 .58409 .57044 Mtetra
.58409 .57044 .58924 .57589 .59924 .57294 .59412 .56747 Mtetra
.59412 .56747 .59924 .57294 .60928 .56998 .60418 .56449 Mtetra
.60418 .56449 .60928 .56998 .61935 .56701 .61428 .56149 Mtetra
.61428 .56149 .61935 .56701 .62946 .56403 .62441 .55849 Mtetra
.62441 .55849 .62946 .56403 .63961 .56103 .63458 .55548 Mtetra
.63458 .55548 .63961 .56103 .64979 .55803 .64479 .55245 Mtetra
.64479 .55245 .64979 .55803 .66002 .55501 .65504 .54941 Mtetra
.65504 .54941 .66002 .55501 .67027 .55198 .66532 .54637 Mtetra
.66532 .54637 .67027 .55198 .68057 .54895 .67564 .54331 Mtetra
.67564 .54331 .68057 .54895 .6909 .5459 .686 .54024 Mtetra
.686 .54024 .6909 .5459 .70127 .54284 .6964 .53716 Mtetra
.6964 .53716 .70127 .54284 .71168 .53977 .70684 .53407 Mtetra
.70684 .53407 .71168 .53977 .72213 .53669 .71731 .53097 Mtetra
.71731 .53097 .72213 .53669 .73262 .53359 .72782 .52786 Mtetra
.655 .751 .921 r
.72782 .52786 .73262 .53359 .74314 .53049 .73838 .52474 Mtetra
.655 .752 .921 r
.73838 .52474 .74314 .53049 .75371 .52738 .74897 .52161 Mtetra
.74897 .52161 .75371 .52738 .76431 .52427 .7596 .51848 Mtetra
.7596 .51848 .76431 .52427 .77495 .52114 .77027 .51534 Mtetra
.654 .752 .922 r
.77027 .51534 .77495 .52114 .78564 .51801 .78098 .5122 Mtetra
.78098 .5122 .78564 .51801 .79636 .51487 .79174 .50905 Mtetra
.654 .753 .922 r
.79174 .50905 .79636 .51487 .80712 .51172 .80253 .5059 Mtetra
.654 .753 .923 r
.80253 .5059 .80712 .51172 .81793 .50856 .81336 .50273 Mtetra
.654 .754 .923 r
.81336 .50273 .81793 .50856 .82877 .50539 .82424 .49955 Mtetra
.654 .755 .923 r
.82424 .49955 .82877 .50539 .83966 .5022 .83516 .49635 Mtetra
.655 .755 .924 r
.83516 .49635 .83966 .5022 .85058 .499 .84611 .49313 Mtetra
.84611 .49313 .85058 .499 .86155 .49577 .85711 .48988 Mtetra
.656 .756 .923 r
.85711 .48988 .86155 .49577 .87256 .49252 .86814 .4866 Mtetra
.86814 .4866 .87256 .49252 .8836 .48925 .87922 .48329 Mtetra
.657 .755 .922 r
.87922 .48329 .8836 .48925 .89469 .48595 .89034 .47995 Mtetra
.658 .755 .922 r
.89034 .47995 .89469 .48595 .90582 .48263 .90149 .47659 Mtetra
.658 .755 .921 r
.90149 .47659 .90582 .48263 .91699 .47929 .91269 .47321 Mtetra
.658 .754 .921 r
.91269 .47321 .91699 .47929 .9282 .47593 .92393 .46981 Mtetra
.658 .753 .92 r
.92393 .46981 .9282 .47593 .93945 .47256 .93521 .46639 Mtetra
.652 .75 .922 r
.32977 .63908 .33552 .6441 .34466 .64145 .33894 .63645 Mtetra
.652 .751 .923 r
.33894 .63645 .34466 .64145 .35384 .6388 .34813 .6338 Mtetra
.652 .752 .923 r
.34813 .6338 .35384 .6388 .36305 .63613 .35736 .63114 Mtetra
.652 .753 .924 r
.35736 .63114 .36305 .63613 .37229 .63344 .36662 .62845 Mtetra
.653 .754 .924 r
.36662 .62845 .37229 .63344 .38157 .63073 .37592 .62575 Mtetra
.654 .755 .924 r
.37592 .62575 .38157 .63073 .39087 .628 .38524 .62301 Mtetra
.654 .756 .925 r
.38524 .62301 .39087 .628 .40021 .62524 .3946 .62025 Mtetra
.655 .757 .925 r
.3946 .62025 .40021 .62524 .40959 .62246 .404 .61745 Mtetra
.656 .757 .924 r
.404 .61745 .40959 .62246 .419 .61965 .41343 .61463 Mtetra
.657 .758 .924 r
.41343 .61463 .419 .61965 .42844 .61682 .42289 .61177 Mtetra
.658 .757 .923 r
.42289 .61177 .42844 .61682 .43791 .61397 .43239 .60889 Mtetra
.43239 .60889 .43791 .61397 .44742 .61112 .44191 .606 Mtetra
.658 .756 .922 r
.44191 .606 .44742 .61112 .45696 .60825 .45148 .60309 Mtetra
.658 .755 .922 r
.45148 .60309 .45696 .60825 .46653 .60538 .46107 .60018 Mtetra
.658 .754 .921 r
.46107 .60018 .46653 .60538 .47614 .6025 .4707 .59727 Mtetra
.657 .754 .921 r
.4707 .59727 .47614 .6025 .48578 .59962 .48036 .59435 Mtetra
.657 .753 .921 r
.48036 .59435 .48578 .59962 .49545 .59674 .49006 .59144 Mtetra
.49006 .59144 .49545 .59674 .50516 .59385 .49979 .58852 Mtetra
.656 .752 .92 r
.49979 .58852 .50516 .59385 .5149 .59095 .50956 .5856 Mtetra
.50956 .5856 .5149 .59095 .52468 .58805 .51936 .58268 Mtetra
.51936 .58268 .52468 .58805 .5345 .58514 .52919 .57975 Mtetra
.52919 .57975 .5345 .58514 .54434 .58222 .53907 .57681 Mtetra
.53907 .57681 .54434 .58222 .55423 .57929 .54897 .57386 Mtetra
.656 .751 .92 r
.54897 .57386 .55423 .57929 .56414 .57635 .55891 .5709 Mtetra
.55891 .5709 .56414 .57635 .5741 .5734 .56889 .56793 Mtetra
.56889 .56793 .5741 .5734 .58409 .57044 .57891 .56495 Mtetra
.57891 .56495 .58409 .57044 .59412 .56747 .58896 .56195 Mtetra
.58896 .56195 .59412 .56747 .60418 .56449 .59904 .55895 Mtetra
.59904 .55895 .60418 .56449 .61428 .56149 .60917 .55594 Mtetra
.60917 .55594 .61428 .56149 .62441 .55849 .61933 .55292 Mtetra
.61933 .55292 .62441 .55849 .63458 .55548 .62952 .54988 Mtetra
.62952 .54988 .63458 .55548 .64479 .55245 .63976 .54684 Mtetra
.63976 .54684 .64479 .55245 .65504 .54941 .65003 .54378 Mtetra
.65003 .54378 .65504 .54941 .66532 .54637 .66034 .54071 Mtetra
.66034 .54071 .66532 .54637 .67564 .54331 .67069 .53763 Mtetra
.67069 .53763 .67564 .54331 .686 .54024 .68107 .53454 Mtetra
.68107 .53454 .686 .54024 .6964 .53716 .69149 .53144 Mtetra
.69149 .53144 .6964 .53716 .70684 .53407 .70196 .52833 Mtetra
.70196 .52833 .70684 .53407 .71731 .53097 .71246 .52521 Mtetra
.655 .751 .921 r
.71246 .52521 .71731 .53097 .72782 .52786 .723 .52209 Mtetra
.655 .752 .921 r
.723 .52209 .72782 .52786 .73838 .52474 .73358 .51895 Mtetra
.73358 .51895 .73838 .52474 .74897 .52161 .7442 .51581 Mtetra
.7442 .51581 .74897 .52161 .7596 .51848 .75486 .51267 Mtetra
.654 .752 .922 r
.75486 .51267 .7596 .51848 .77027 .51534 .76556 .50953 Mtetra
.654 .753 .922 r
.76556 .50953 .77027 .51534 .78098 .5122 .7763 .50638 Mtetra
.653 .753 .923 r
.7763 .50638 .78098 .5122 .79174 .50905 .78708 .50323 Mtetra
.653 .754 .924 r
.78708 .50323 .79174 .50905 .80253 .5059 .79791 .50008 Mtetra
.653 .755 .924 r
.79791 .50008 .80253 .5059 .81336 .50273 .80877 .49691 Mtetra
.653 .755 .925 r
.80877 .49691 .81336 .50273 .82424 .49955 .81968 .49372 Mtetra
.654 .756 .925 r
.81968 .49372 .82424 .49955 .83516 .49635 .83063 .49051 Mtetra
.654 .757 .925 r
.83063 .49051 .83516 .49635 .84611 .49313 .84161 .48726 Mtetra
.655 .757 .925 r
.84161 .48726 .84611 .49313 .85711 .48988 .85264 .48398 Mtetra
.656 .757 .924 r
.85264 .48398 .85711 .48988 .86814 .4866 .8637 .48066 Mtetra
.657 .757 .924 r
.8637 .48066 .86814 .4866 .87922 .48329 .87481 .47732 Mtetra
.658 .757 .923 r
.87481 .47732 .87922 .48329 .89034 .47995 .88595 .47394 Mtetra
.658 .756 .922 r
.88595 .47394 .89034 .47995 .90149 .47659 .89714 .47053 Mtetra
.659 .755 .921 r
.89714 .47053 .90149 .47659 .91269 .47321 .90837 .4671 Mtetra
.90837 .4671 .91269 .47321 .92393 .46981 .91964 .46365 Mtetra
.659 .754 .92 r
.91964 .46365 .92393 .46981 .93521 .46639 .93095 .46018 Mtetra
.651 .75 .922 r
.32399 .63404 .32977 .63908 .33894 .63645 .33317 .63141 Mtetra
.651 .751 .923 r
.33317 .63141 .33894 .63645 .34813 .6338 .34239 .62877 Mtetra
.651 .752 .924 r
.34239 .62877 .34813 .6338 .35736 .63114 .35163 .62612 Mtetra
.651 .753 .925 r
.35163 .62612 .35736 .63114 .36662 .62845 .36091 .62345 Mtetra
.652 .755 .925 r
.36091 .62345 .36662 .62845 .37592 .62575 .37023 .62075 Mtetra
.652 .756 .926 r
.37023 .62075 .37592 .62575 .38524 .62301 .37957 .61803 Mtetra
.653 .757 .926 r
.37957 .61803 .38524 .62301 .3946 .62025 .38896 .61527 Mtetra
.654 .758 .926 r
.38896 .61527 .3946 .62025 .404 .61745 .39837 .61247 Mtetra
.656 .759 .926 r
.39837 .61247 .404 .61745 .41343 .61463 .40782 .60963 Mtetra
.657 .76 .926 r
.40782 .60963 .41343 .61463 .42289 .61177 .4173 .60675 Mtetra
.658 .76 .925 r
.4173 .60675 .42289 .61177 .43239 .60889 .42682 .60384 Mtetra
.659 .759 .924 r
.42682 .60384 .43239 .60889 .44191 .606 .43637 .6009 Mtetra
.43637 .6009 .44191 .606 .45148 .60309 .44596 .59795 Mtetra
.659 .758 .923 r
.44596 .59795 .45148 .60309 .46107 .60018 .45558 .59499 Mtetra
.659 .756 .922 r
.45558 .59499 .46107 .60018 .4707 .59727 .46523 .59203 Mtetra
.658 .755 .922 r
.46523 .59203 .4707 .59727 .48036 .59435 .47491 .58908 Mtetra
.658 .754 .921 r
.47491 .58908 .48036 .59435 .49006 .59144 .48463 .58613 Mtetra
.657 .753 .921 r
.48463 .58613 .49006 .59144 .49979 .58852 .49439 .58318 Mtetra
.49439 .58318 .49979 .58852 .50956 .5856 .50418 .58023 Mtetra
.656 .752 .921 r
.50418 .58023 .50956 .5856 .51936 .58268 .514 .57728 Mtetra
.656 .752 .92 r
.514 .57728 .51936 .58268 .52919 .57975 .52386 .57432 Mtetra
.52386 .57432 .52919 .57975 .53907 .57681 .53375 .57136 Mtetra
.53375 .57136 .53907 .57681 .54897 .57386 .54368 .56839 Mtetra
.54368 .56839 .54897 .57386 .55891 .5709 .55365 .56541 Mtetra
.656 .751 .92 r
.55365 .56541 .55891 .5709 .56889 .56793 .56365 .56242 Mtetra
.56365 .56242 .56889 .56793 .57891 .56495 .57369 .55942 Mtetra
.57369 .55942 .57891 .56495 .58896 .56195 .58376 .55641 Mtetra
.58376 .55641 .58896 .56195 .59904 .55895 .59387 .55338 Mtetra
.59387 .55338 .59904 .55895 .60917 .55594 .60402 .55035 Mtetra
.60402 .55035 .60917 .55594 .61933 .55292 .61421 .54731 Mtetra
.61421 .54731 .61933 .55292 .62952 .54988 .62443 .54425 Mtetra
.62443 .54425 .62952 .54988 .63976 .54684 .63469 .54118 Mtetra
.63469 .54118 .63976 .54684 .65003 .54378 .64498 .53811 Mtetra
.64498 .53811 .65003 .54378 .66034 .54071 .65532 .53502 Mtetra
.65532 .53502 .66034 .54071 .67069 .53763 .66569 .53192 Mtetra
.66569 .53192 .67069 .53763 .68107 .53454 .6761 .52881 Mtetra
.6761 .52881 .68107 .53454 .69149 .53144 .68655 .52569 Mtetra
.68655 .52569 .69149 .53144 .70196 .52833 .69704 .52256 Mtetra
.655 .752 .921 r
.69704 .52256 .70196 .52833 .71246 .52521 .70757 .51943 Mtetra
.70757 .51943 .71246 .52521 .723 .52209 .71814 .51628 Mtetra
.71814 .51628 .723 .52209 .73358 .51895 .72875 .51314 Mtetra
.654 .752 .922 r
.72875 .51314 .73358 .51895 .7442 .51581 .7394 .50999 Mtetra
.7394 .50999 .7442 .51581 .75486 .51267 .75009 .50685 Mtetra
.653 .753 .923 r
.75009 .50685 .75486 .51267 .76556 .50953 .76082 .5037 Mtetra
.653 .753 .924 r
.76082 .5037 .76556 .50953 .7763 .50638 .77159 .50056 Mtetra
.652 .754 .925 r
.77159 .50056 .7763 .50638 .78708 .50323 .7824 .49742 Mtetra
.652 .755 .925 r
.7824 .49742 .78708 .50323 .79791 .50008 .79326 .49427 Mtetra
.652 .756 .926 r
.79326 .49427 .79791 .50008 .80877 .49691 .80416 .4911 Mtetra
.652 .757 .927 r
.80416 .4911 .80877 .49691 .81968 .49372 .81509 .48791 Mtetra
.653 .758 .927 r
.81509 .48791 .81968 .49372 .83063 .49051 .82607 .48468 Mtetra
.654 .759 .927 r
.82607 .48468 .83063 .49051 .84161 .48726 .83709 .4814 Mtetra
.656 .759 .926 r
.83709 .4814 .84161 .48726 .85264 .48398 .84814 .47809 Mtetra
.657 .759 .925 r
.84814 .47809 .85264 .48398 .8637 .48066 .85924 .47472 Mtetra
.658 .759 .924 r
.85924 .47472 .8637 .48066 .87481 .47732 .87037 .47132 Mtetra
.659 .758 .923 r
.87037 .47132 .87481 .47732 .88595 .47394 .88154 .46789 Mtetra
.659 .757 .922 r
.88154 .46789 .88595 .47394 .89714 .47053 .89276 .46443 Mtetra
.66 .756 .921 r
.89276 .46443 .89714 .47053 .90837 .4671 .90401 .46095 Mtetra
.66 .755 .921 r
.90401 .46095 .90837 .4671 .91964 .46365 .91531 .45744 Mtetra
.66 .754 .92 r
.91531 .45744 .91964 .46365 .93095 .46018 .92665 .45393 Mtetra
.649 .75 .923 r
.31818 .62896 .32399 .63404 .33317 .63141 .32738 .62634 Mtetra
.649 .751 .924 r
.32738 .62634 .33317 .63141 .34239 .62877 .33661 .62372 Mtetra
.649 .752 .924 r
.33661 .62372 .34239 .62877 .35163 .62612 .34587 .62108 Mtetra
.649 .753 .925 r
.34587 .62108 .35163 .62612 .36091 .62345 .35517 .61842 Mtetra
.65 .755 .926 r
.35517 .61842 .36091 .62345 .37023 .62075 .3645 .61574 Mtetra
.651 .756 .927 r
.3645 .61574 .37023 .62075 .37957 .61803 .37387 .61304 Mtetra
.652 .758 .927 r
.37387 .61304 .37957 .61803 .38896 .61527 .38327 .6103 Mtetra
.653 .76 .928 r
.38327 .6103 .38896 .61527 .39837 .61247 .3927 .60751 Mtetra
.655 .761 .928 r
.3927 .60751 .39837 .61247 .40782 .60963 .40217 .60467 Mtetra
.657 .762 .928 r
.40217 .60467 .40782 .60963 .4173 .60675 .41168 .60178 Mtetra
.658 .763 .927 r
.41168 .60178 .4173 .60675 .42682 .60384 .42122 .59883 Mtetra
.66 .763 .926 r
.42122 .59883 .42682 .60384 .43637 .6009 .43079 .59586 Mtetra
.66 .762 .925 r
.43079 .59586 .43637 .6009 .44596 .59795 .4404 .59285 Mtetra
.66 .761 .924 r
.4404 .59285 .44596 .59795 .45558 .59499 .45004 .58983 Mtetra
.66 .759 .923 r
.45004 .58983 .45558 .59499 .46523 .59203 .45972 .58682 Mtetra
.659 .758 .922 r
.45972 .58682 .46523 .59203 .47491 .58908 .46943 .58381 Mtetra
.659 .756 .922 r
.46943 .58381 .47491 .58908 .48463 .58613 .47917 .58081 Mtetra
.658 .755 .921 r
.47917 .58081 .48463 .58613 .49439 .58318 .48895 .57782 Mtetra
.657 .754 .921 r
.48895 .57782 .49439 .58318 .50418 .58023 .49876 .57483 Mtetra
.657 .753 .921 r
.49876 .57483 .50418 .58023 .514 .57728 .5086 .57185 Mtetra
.656 .752 .921 r
.5086 .57185 .514 .57728 .52386 .57432 .51849 .56887 Mtetra
.656 .752 .92 r
.51849 .56887 .52386 .57432 .53375 .57136 .5284 .56588 Mtetra
.5284 .56588 .53375 .57136 .54368 .56839 .53836 .56289 Mtetra
.53836 .56289 .54368 .56839 .55365 .56541 .54835 .55988 Mtetra
.54835 .55988 .55365 .56541 .56365 .56242 .55837 .55687 Mtetra
.55837 .55687 .56365 .56242 .57369 .55942 .56843 .55385 Mtetra
.656 .751 .92 r
.56843 .55385 .57369 .55942 .58376 .55641 .57853 .55082 Mtetra
.57853 .55082 .58376 .55641 .59387 .55338 .58867 .54778 Mtetra
.58867 .54778 .59387 .55338 .60402 .55035 .59884 .54472 Mtetra
.59884 .54472 .60402 .55035 .61421 .54731 .60905 .54166 Mtetra
.60905 .54166 .61421 .54731 .62443 .54425 .6193 .53858 Mtetra
.6193 .53858 .62443 .54425 .63469 .54118 .62958 .5355 Mtetra
.62958 .5355 .63469 .54118 .64498 .53811 .63991 .5324 Mtetra
.63991 .5324 .64498 .53811 .65532 .53502 .65027 .52929 Mtetra
.65027 .52929 .65532 .53502 .66569 .53192 .66067 .52617 Mtetra
.66067 .52617 .66569 .53192 .6761 .52881 .6711 .52304 Mtetra
.656 .752 .921 r
.6711 .52304 .6761 .52881 .68655 .52569 .68158 .5199 Mtetra
.655 .752 .921 r
.68158 .5199 .68655 .52569 .69704 .52256 .6921 .51676 Mtetra
.6921 .51676 .69704 .52256 .70757 .51943 .70265 .51361 Mtetra
.70265 .51361 .70757 .51943 .71814 .51628 .71325 .51045 Mtetra
.654 .752 .922 r
.71325 .51045 .71814 .51628 .72875 .51314 .72389 .5073 Mtetra
.653 .752 .922 r
.72389 .5073 .72875 .51314 .7394 .50999 .73456 .50416 Mtetra
.653 .753 .923 r
.73456 .50416 .7394 .50999 .75009 .50685 .74528 .50102 Mtetra
.652 .754 .924 r
.74528 .50102 .75009 .50685 .76082 .5037 .75604 .49789 Mtetra
.651 .755 .926 r
.75604 .49789 .76082 .5037 .77159 .50056 .76685 .49477 Mtetra
.65 .756 .927 r
.76685 .49477 .77159 .50056 .7824 .49742 .77769 .49165 Mtetra
.65 .757 .928 r
.77769 .49165 .7824 .49742 .79326 .49427 .78858 .48851 Mtetra
.651 .759 .929 r
.78858 .48851 .79326 .49427 .80416 .4911 .79951 .48534 Mtetra
.652 .76 .929 r
.79951 .48534 .80416 .4911 .81509 .48791 .81048 .48214 Mtetra
.653 .761 .929 r
.81048 .48214 .81509 .48791 .82607 .48468 .82149 .47888 Mtetra
.655 .762 .928 r
.82149 .47888 .82607 .48468 .83709 .4814 .83253 .47557 Mtetra
.657 .762 .927 r
.83253 .47557 .83709 .4814 .84814 .47809 .84362 .47219 Mtetra
.658 .761 .926 r
.84362 .47219 .84814 .47809 .85924 .47472 .85474 .46877 Mtetra
.659 .761 .925 r
.85474 .46877 .85924 .47472 .87037 .47132 .8659 .46531 Mtetra
.66 .759 .923 r
.8659 .46531 .87037 .47132 .88154 .46789 .8771 .46181 Mtetra
.661 .758 .922 r
.8771 .46181 .88154 .46789 .89276 .46443 .88834 .45829 Mtetra
.661 .757 .921 r
.88834 .45829 .89276 .46443 .90401 .46095 .89963 .45475 Mtetra
.661 .756 .92 r
.89963 .45475 .90401 .46095 .91531 .45744 .91095 .4512 Mtetra
.661 .755 .919 r
.91095 .4512 .91531 .45744 .92665 .45393 .92232 .44763 Mtetra
.649 .75 .923 r
.31232 .62385 .31818 .62896 .32738 .62634 .32154 .62123 Mtetra
.648 .75 .924 r
.32154 .62123 .32738 .62634 .33661 .62372 .33079 .61861 Mtetra
.648 .751 .925 r
.33079 .61861 .33661 .62372 .34587 .62108 .34007 .61598 Mtetra
.648 .752 .925 r
.34007 .61598 .34587 .62108 .35517 .61842 .34939 .61334 Mtetra
.648 .753 .926 r
.34939 .61334 .35517 .61842 .3645 .61574 .35874 .61069 Mtetra
.648 .755 .927 r
.35874 .61069 .3645 .61574 .37387 .61304 .36812 .60802 Mtetra
.649 .757 .928 r
.36812 .60802 .37387 .61304 .38327 .6103 .37754 .60531 Mtetra
.651 .76 .929 r
.37754 .60531 .38327 .6103 .3927 .60751 .387 .60255 Mtetra
.653 .762 .93 r
.387 .60255 .3927 .60751 .40217 .60467 .39649 .59973 Mtetra
.655 .764 .93 r
.39649 .59973 .40217 .60467 .41168 .60178 .40601 .59685 Mtetra
.658 .766 .929 r
.40601 .59685 .41168 .60178 .42122 .59883 .41558 .59389 Mtetra
.66 .767 .929 r
.41558 .59389 .42122 .59883 .43079 .59586 .42517 .59088 Mtetra
.661 .767 .928 r
.42517 .59088 .43079 .59586 .4404 .59285 .4348 .58782 Mtetra
.662 .765 .926 r
.4348 .58782 .4404 .59285 .45004 .58983 .44447 .58474 Mtetra
.662 .763 .925 r
.44447 .58474 .45004 .58983 .45972 .58682 .45417 .58165 Mtetra
.661 .761 .924 r
.45417 .58165 .45972 .58682 .46943 .58381 .4639 .57857 Mtetra
.66 .759 .923 r
.4639 .57857 .46943 .58381 .47917 .58081 .47367 .5755 Mtetra
.659 .757 .922 r
.47367 .5755 .47917 .58081 .48895 .57782 .48347 .57246 Mtetra
.658 .755 .922 r
.48347 .57246 .48895 .57782 .49876 .57483 .4933 .56943 Mtetra
.658 .754 .921 r
.4933 .56943 .49876 .57483 .5086 .57185 .50317 .56641 Mtetra
.657 .753 .921 r
.50317 .56641 .5086 .57185 .51849 .56887 .51308 .56339 Mtetra
.656 .753 .921 r
.51308 .56339 .51849 .56887 .5284 .56588 .52302 .56037 Mtetra
.656 .752 .921 r
.52302 .56037 .5284 .56588 .53836 .56289 .533 .55735 Mtetra
.656 .752 .92 r
.533 .55735 .53836 .56289 .54835 .55988 .54301 .55433 Mtetra
.54301 .55433 .54835 .55988 .55837 .55687 .55306 .55129 Mtetra
.55306 .55129 .55837 .55687 .56843 .55385 .56314 .54825 Mtetra
.56314 .54825 .56843 .55385 .57853 .55082 .57327 .5452 Mtetra
.57327 .5452 .57853 .55082 .58867 .54778 .58343 .54213 Mtetra
.58343 .54213 .58867 .54778 .59884 .54472 .59363 .53906 Mtetra
.656 .751 .92 r
.59363 .53906 .59884 .54472 .60905 .54166 .60386 .53597 Mtetra
.60386 .53597 .60905 .54166 .6193 .53858 .61413 .53288 Mtetra
.61413 .53288 .6193 .53858 .62958 .5355 .62444 .52977 Mtetra
.62444 .52977 .62958 .5355 .63991 .5324 .63479 .52665 Mtetra
.656 .752 .92 r
.63479 .52665 .63991 .5324 .65027 .52929 .64518 .52352 Mtetra
.64518 .52352 .65027 .52929 .66067 .52617 .65561 .52039 Mtetra
.655 .752 .921 r
.65561 .52039 .66067 .52617 .6711 .52304 .66607 .51724 Mtetra
.66607 .51724 .6711 .52304 .68158 .5199 .67657 .51409 Mtetra
.67657 .51409 .68158 .5199 .6921 .51676 .68712 .51093 Mtetra
.68712 .51093 .6921 .51676 .70265 .51361 .6977 .50777 Mtetra
.654 .752 .922 r
.6977 .50777 .70265 .51361 .71325 .51045 .70832 .50461 Mtetra
.653 .753 .923 r
.70832 .50461 .71325 .51045 .72389 .5073 .71899 .50147 Mtetra
.652 .753 .924 r
.71899 .50147 .72389 .5073 .73456 .50416 .7297 .49834 Mtetra
.651 .754 .925 r
.7297 .49834 .73456 .50416 .74528 .50102 .74045 .49522 Mtetra
.649 .755 .927 r
.74045 .49522 .74528 .50102 .75604 .49789 .75124 .49212 Mtetra
.648 .757 .929 r
.75124 .49212 .75604 .49789 .76685 .49477 .76208 .48903 Mtetra
.648 .759 .93 r
.76208 .48903 .76685 .49477 .77769 .49165 .77296 .48594 Mtetra
.648 .761 .931 r
.77296 .48594 .77769 .49165 .78858 .48851 .78388 .48281 Mtetra
.649 .763 .932 r
.78388 .48281 .78858 .48851 .79951 .48534 .79484 .47964 Mtetra
.651 .764 .932 r
.79484 .47964 .79951 .48534 .81048 .48214 .80584 .47641 Mtetra
.654 .765 .931 r
.80584 .47641 .81048 .48214 .82149 .47888 .81688 .4731 Mtetra
.656 .765 .93 r
.81688 .4731 .82149 .47888 .83253 .47557 .82795 .46972 Mtetra
.658 .764 .928 r
.82795 .46972 .83253 .47557 .84362 .47219 .83906 .46628 Mtetra
.66 .763 .926 r
.83906 .46628 .84362 .47219 .85474 .46877 .85021 .46278 Mtetra
.661 .761 .924 r
.85021 .46278 .85474 .46877 .8659 .46531 .8614 .45924 Mtetra
.662 .76 .923 r
.8614 .45924 .8659 .46531 .8771 .46181 .87262 .45567 Mtetra
.662 .758 .921 r
.87262 .45567 .8771 .46181 .88834 .45829 .88389 .45209 Mtetra
.662 .757 .92 r
.88389 .45209 .88834 .45829 .89963 .45475 .89521 .4485 Mtetra
.662 .756 .92 r
.89521 .4485 .89963 .45475 .91095 .4512 .90656 .44489 Mtetra
.662 .755 .919 r
.90656 .44489 .91095 .4512 .92232 .44763 .91796 .44128 Mtetra
.648 .75 .923 r
.30643 .61871 .31232 .62385 .32154 .62123 .31567 .61608 Mtetra
.648 .75 .924 r
.31567 .61608 .32154 .62123 .33079 .61861 .32493 .61344 Mtetra
.647 .75 .924 r
.32493 .61344 .33079 .61861 .34007 .61598 .33424 .61081 Mtetra
.647 .75 .925 r
.33424 .61081 .34007 .61598 .34939 .61334 .34357 .60819 Mtetra
.646 .751 .926 r
.34357 .60819 .34939 .61334 .35874 .61069 .35294 .60556 Mtetra
.646 .753 .927 r
.35294 .60556 .35874 .61069 .36812 .60802 .36234 .60293 Mtetra
.646 .755 .929 r
.36234 .60293 .36812 .60802 .37754 .60531 .37178 .60028 Mtetra
.647 .758 .93 r
.37178 .60028 .37754 .60531 .387 .60255 .38125 .59758 Mtetra
.65 .762 .931 r
.38125 .59758 .387 .60255 .39649 .59973 .39076 .59481 Mtetra
.652 .766 .932 r
.39076 .59481 .39649 .59973 .40601 .59685 .40031 .59197 Mtetra
.656 .769 .932 r
.40031 .59197 .40601 .59685 .41558 .59389 .40989 .58902 Mtetra
.659 .771 .932 r
.40989 .58902 .41558 .59389 .42517 .59088 .41951 .586 Mtetra
.662 .772 .931 r
.41951 .586 .42517 .59088 .4348 .58782 .42917 .58289 Mtetra
.664 .771 .929 r
.42917 .58289 .4348 .58782 .44447 .58474 .43886 .57973 Mtetra
.664 .769 .928 r
.43886 .57973 .44447 .58474 .45417 .58165 .44858 .57656 Mtetra
.664 .766 .926 r
.44858 .57656 .45417 .58165 .4639 .57857 .45834 .57339 Mtetra
.663 .763 .925 r
.45834 .57339 .4639 .57857 .47367 .5755 .46813 .57024 Mtetra
.661 .76 .923 r
.46813 .57024 .47367 .5755 .48347 .57246 .47795 .56712 Mtetra
.66 .758 .923 r
.47795 .56712 .48347 .57246 .4933 .56943 .48781 .56403 Mtetra
.659 .756 .922 r
.48781 .56403 .4933 .56943 .50317 .56641 .4977 .56095 Mtetra
.658 .755 .921 r
.4977 .56095 .50317 .56641 .51308 .56339 .50763 .5579 Mtetra
.657 .754 .921 r
.50763 .5579 .51308 .56339 .52302 .56037 .5176 .55484 Mtetra
.657 .753 .921 r
.5176 .55484 .52302 .56037 .533 .55735 .5276 .5518 Mtetra
.656 .752 .921 r
.5276 .5518 .533 .55735 .54301 .55433 .53764 .54874 Mtetra
.53764 .54874 .54301 .55433 .55306 .55129 .54771 .54568 Mtetra
.54771 .54568 .55306 .55129 .56314 .54825 .55782 .54262 Mtetra
.656 .752 .92 r
.55782 .54262 .56314 .54825 .57327 .5452 .56797 .53954 Mtetra
.56797 .53954 .57327 .5452 .58343 .54213 .57815 .53646 Mtetra
.57815 .53646 .58343 .54213 .59363 .53906 .58838 .53336 Mtetra
.58838 .53336 .59363 .53906 .60386 .53597 .59864 .53025 Mtetra
.59864 .53025 .60386 .53597 .61413 .53288 .60893 .52714 Mtetra
.60893 .52714 .61413 .53288 .62444 .52977 .61927 .52401 Mtetra
.656 .752 .921 r
.61927 .52401 .62444 .52977 .63479 .52665 .62964 .52087 Mtetra
.62964 .52087 .63479 .52665 .64518 .52352 .64006 .51772 Mtetra
.655 .752 .921 r
.64006 .51772 .64518 .52352 .65561 .52039 .65051 .51457 Mtetra
.65051 .51457 .65561 .52039 .66607 .51724 .661 .51141 Mtetra
.661 .51141 .66607 .51724 .67657 .51409 .67153 .50824 Mtetra
.654 .752 .922 r
.67153 .50824 .67657 .51409 .68712 .51093 .6821 .50508 Mtetra
.6821 .50508 .68712 .51093 .6977 .50777 .69272 .50192 Mtetra
.652 .753 .923 r
.69272 .50192 .6977 .50777 .70832 .50461 .70337 .49877 Mtetra
.651 .754 .925 r
.70337 .49877 .70832 .50461 .71899 .50147 .71407 .49565 Mtetra
.649 .754 .926 r
.71407 .49565 .71899 .50147 .7297 .49834 .7248 .49255 Mtetra
.648 .756 .928 r
.7248 .49255 .7297 .49834 .74045 .49522 .73559 .48948 Mtetra
.646 .758 .931 r
.73559 .48948 .74045 .49522 .75124 .49212 .74642 .48643 Mtetra
.645 .76 .933 r
.74642 .48643 .75124 .49212 .76208 .48903 .75729 .48339 Mtetra
.645 .763 .935 r
.75729 .48339 .76208 .48903 .77296 .48594 .7682 .48032 Mtetra
.646 .765 .936 r
.7682 .48032 .77296 .48594 .78388 .48281 .77916 .47721 Mtetra
.649 .768 .936 r
.77916 .47721 .78388 .48281 .79484 .47964 .79015 .47401 Mtetra
.652 .769 .935 r
.79015 .47401 .79484 .47964 .80584 .47641 .80118 .47073 Mtetra
.656 .769 .933 r
.80118 .47073 .80584 .47641 .81688 .4731 .81224 .46733 Mtetra
.659 .768 .93 r
.81224 .46733 .81688 .4731 .82795 .46972 .82334 .46386 Mtetra
.661 .766 .927 r
.82334 .46386 .82795 .46972 .83906 .46628 .83447 .46031 Mtetra
.663 .764 .925 r
.83447 .46031 .83906 .46628 .85021 .46278 .84564 .45671 Mtetra
.664 .761 .922 r
.84564 .45671 .85021 .46278 .8614 .45924 .85686 .45308 Mtetra
.664 .759 .921 r
.85686 .45308 .8614 .45924 .87262 .45567 .86811 .44945 Mtetra
.663 .757 .92 r
.86811 .44945 .87262 .45567 .88389 .45209 .87941 .44581 Mtetra
.663 .756 .919 r
.87941 .44581 .88389 .45209 .89521 .4485 .89075 .44217 Mtetra
.663 .755 .919 r
.89075 .44217 .89521 .4485 .90656 .44489 .90214 .43853 Mtetra
.662 .754 .919 r
.90214 .43853 .90656 .44489 .91796 .44128 .91357 .43489 Mtetra
.649 .75 .923 r
.3005 .61354 .30643 .61871 .31567 .61608 .30976 .61086 Mtetra
.649 .749 .923 r
.30976 .61086 .31567 .61608 .32493 .61344 .31905 .60819 Mtetra
.648 .748 .922 r
.31905 .60819 .32493 .61344 .33424 .61081 .32837 .60554 Mtetra
.647 .747 .923 r
.32837 .60554 .33424 .61081 .34357 .60819 .33772 .6029 Mtetra
.645 .747 .924 r
.33772 .6029 .34357 .60819 .35294 .60556 .34711 .60029 Mtetra
.644 .748 .925 r
.34711 .60029 .35294 .60556 .36234 .60293 .35653 .5977 Mtetra
.643 .75 .927 r
.35653 .5977 .36234 .60293 .37178 .60028 .36598 .59511 Mtetra
.643 .753 .929 r
.36598 .59511 .37178 .60028 .38125 .59758 .37547 .59249 Mtetra
.645 .758 .931 r
.37547 .59249 .38125 .59758 .39076 .59481 .38499 .58983 Mtetra
.648 .763 .933 r
.38499 .58983 .39076 .59481 .40031 .59197 .39456 .58707 Mtetra
.652 .768 .934 r
.39456 .58707 .40031 .59197 .40989 .58902 .40416 .5842 Mtetra
.657 .773 .935 r
.40416 .5842 .40989 .58902 .41951 .586 .4138 .5812 Mtetra
.662 .776 .934 r
.4138 .5812 .41951 .586 .42917 .58289 .42348 .57808 Mtetra
.665 .777 .933 r
.42348 .57808 .42917 .58289 .43886 .57973 .4332 .57487 Mtetra
.667 .777 .931 r
.4332 .57487 .43886 .57973 .44858 .57656 .44295 .5716 Mtetra
.667 .774 .929 r
.44295 .5716 .44858 .57656 .45834 .57339 .45273 .56833 Mtetra
.666 .77 .928 r
.45273 .56833 .45834 .57339 .46813 .57024 .46255 .56507 Mtetra
.664 .766 .926 r
.46255 .56507 .46813 .57024 .47795 .56712 .4724 .56185 Mtetra
.662 .763 .924 r
.4724 .56185 .47795 .56712 .48781 .56403 .48228 .55867 Mtetra
.661 .76 .923 r
.48228 .55867 .48781 .56403 .4977 .56095 .4922 .55553 Mtetra
.659 .757 .922 r
.4922 .55553 .4977 .56095 .50763 .5579 .50215 .55241 Mtetra
.658 .755 .922 r
.50215 .55241 .50763 .5579 .5176 .55484 .51214 .54931 Mtetra
.657 .754 .921 r
.51214 .54931 .5176 .55484 .5276 .5518 .52217 .54622 Mtetra
.657 .753 .921 r
.52217 .54622 .5276 .5518 .53764 .54874 .53223 .54314 Mtetra
.656 .753 .921 r
.53223 .54314 .53764 .54874 .54771 .54568 .54232 .54005 Mtetra
.656 .752 .921 r
.54232 .54005 .54771 .54568 .55782 .54262 .55246 .53696 Mtetra
.55246 .53696 .55782 .54262 .56797 .53954 .56263 .53386 Mtetra
.56263 .53386 .56797 .53954 .57815 .53646 .57284 .53075 Mtetra
.57284 .53075 .57815 .53646 .58838 .53336 .58309 .52763 Mtetra
.58309 .52763 .58838 .53336 .59864 .53025 .59337 .5245 Mtetra
.59337 .5245 .59864 .53025 .60893 .52714 .6037 .52136 Mtetra
.6037 .52136 .60893 .52714 .61927 .52401 .61406 .51822 Mtetra
.655 .752 .921 r
.61406 .51822 .61927 .52401 .62964 .52087 .62446 .51506 Mtetra
.62446 .51506 .62964 .52087 .64006 .51772 .6349 .5119 Mtetra
.6349 .5119 .64006 .51772 .65051 .51457 .64538 .50873 Mtetra
.655 .752 .922 r
.64538 .50873 .65051 .51457 .661 .51141 .6559 .50556 Mtetra
.654 .752 .922 r
.6559 .50556 .661 .51141 .67153 .50824 .66646 .50239 Mtetra
.653 .753 .923 r
.66646 .50239 .67153 .50824 .6821 .50508 .67706 .49923 Mtetra
.652 .753 .924 r
.67706 .49923 .6821 .50508 .69272 .50192 .6877 .49609 Mtetra
.65 .754 .926 r
.6877 .49609 .69272 .50192 .70337 .49877 .69838 .49297 Mtetra
.648 .756 .928 r
.69838 .49297 .70337 .49877 .71407 .49565 .70911 .48989 Mtetra
.645 .757 .93 r
.70911 .48989 .71407 .49565 .7248 .49255 .71988 .48686 Mtetra
.643 .76 .933 r
.71988 .48686 .7248 .49255 .73559 .48948 .7307 .48386 Mtetra
.641 .762 .936 r
.7307 .48386 .73559 .48948 .74642 .48643 .74157 .48088 Mtetra
.641 .766 .939 r
.74157 .48088 .74642 .48643 .75729 .48339 .75247 .47788 Mtetra
.642 .769 .94 r
.75247 .47788 .75729 .48339 .7682 .48032 .76342 .47483 Mtetra
.645 .771 .94 r
.76342 .47483 .7682 .48032 .77916 .47721 .77441 .47169 Mtetra
.65 .773 .938 r
.77441 .47169 .77916 .47721 .79015 .47401 .78543 .46842 Mtetra
.655 .773 .936 r
.78543 .46842 .79015 .47401 .80118 .47073 .79648 .46502 Mtetra
.66 .771 .932 r
.79648 .46502 .80118 .47073 .81224 .46733 .80756 .46149 Mtetra
.664 .768 .928 r
.80756 .46149 .81224 .46733 .82334 .46386 .81868 .45786 Mtetra
.666 .765 .924 r
.81868 .45786 .82334 .46386 .83447 .46031 .82984 .45418 Mtetra
.667 .761 .921 r
.82984 .45418 .83447 .46031 .84564 .45671 .84103 .45047 Mtetra
.666 .757 .919 r
.84103 .45047 .84564 .45671 .85686 .45308 .85227 .44677 Mtetra
.665 .755 .917 r
.85227 .44677 .85686 .45308 .86811 .44945 .86356 .44307 Mtetra
.664 .753 .917 r
.86356 .44307 .86811 .44945 .87941 .44581 .87489 .4394 Mtetra
.663 .753 .917 r
.87489 .4394 .87941 .44581 .89075 .44217 .88626 .43574 Mtetra
.662 .753 .917 r
.88626 .43574 .89075 .44217 .90214 .43853 .89768 .4321 Mtetra
.661 .753 .918 r
.89768 .4321 .90214 .43853 .91357 .43489 .90915 .42846 Mtetra
.652 .75 .922 r
.29453 .60833 .3005 .61354 .30976 .61086 .30381 .60558 Mtetra
.651 .748 .921 r
.30381 .60558 .30976 .61086 .31905 .60819 .31312 .60285 Mtetra
.65 .746 .92 r
.31312 .60285 .31905 .60819 .32837 .60554 .32247 .60013 Mtetra
.648 .744 .919 r
.32247 .60013 .32837 .60554 .33772 .6029 .33184 .59745 Mtetra
.645 .742 .92 r
.33184 .59745 .33772 .6029 .34711 .60029 .34124 .59483 Mtetra
.643 .742 .921 r
.34124 .59483 .34711 .60029 .35653 .5977 .35068 .59225 Mtetra
.64 .742 .923 r
.35068 .59225 .35653 .5977 .36598 .59511 .36015 .58972 Mtetra
.638 .745 .926 r
.36015 .58972 .36598 .59511 .37547 .59249 .36965 .58721 Mtetra
.638 .75 .929 r
.36965 .58721 .37547 .59249 .38499 .58983 .37919 .58469 Mtetra
.64 .756 .933 r
.37919 .58469 .38499 .58983 .39456 .58707 .38877 .58209 Mtetra
.645 .764 .936 r
.38877 .58209 .39456 .58707 .40416 .5842 .39839 .57936 Mtetra
.651 .772 .938 r
.39839 .57936 .40416 .5842 .4138 .5812 .40805 .57647 Mtetra
.658 .779 .938 r
.40805 .57647 .4138 .5812 .42348 .57808 .41776 .57339 Mtetra
.664 .783 .938 r
.41776 .57339 .42348 .57808 .4332 .57487 .4275 .57017 Mtetra
.669 .785 .936 r
.4275 .57017 .4332 .57487 .44295 .5716 .43727 .56683 Mtetra
.67 .783 .934 r
.43727 .56683 .44295 .5716 .45273 .56833 .44708 .56344 Mtetra
.67 .779 .931 r
.44708 .56344 .45273 .56833 .46255 .56507 .45693 .56006 Mtetra
.669 .775 .929 r
.45693 .56006 .46255 .56507 .4724 .56185 .4668 .5567 Mtetra
.666 .77 .927 r
.4668 .5567 .4724 .56185 .48228 .55867 .47671 .5534 Mtetra
.664 .765 .925 r
.47671 .5534 .48228 .55867 .4922 .55553 .48666 .55016 Mtetra
.661 .762 .924 r
.48666 .55016 .4922 .55553 .50215 .55241 .49663 .54696 Mtetra
.66 .759 .923 r
.49663 .54696 .50215 .55241 .51214 .54931 .50665 .54379 Mtetra
.658 .757 .922 r
.50665 .54379 .51214 .54931 .52217 .54622 .5167 .54065 Mtetra
.658 .755 .922 r
.5167 .54065 .52217 .54622 .53223 .54314 .52678 .53752 Mtetra
.657 .754 .922 r
.52678 .53752 .53223 .54314 .54232 .54005 .5369 .5344 Mtetra
.656 .753 .921 r
.5369 .5344 .54232 .54005 .55246 .53696 .54706 .53128 Mtetra
.54706 .53128 .55246 .53696 .56263 .53386 .55726 .52815 Mtetra
.55726 .52815 .56263 .53386 .57284 .53075 .56749 .52502 Mtetra
.56749 .52502 .57284 .53075 .58309 .52763 .57777 .52188 Mtetra
.656 .752 .921 r
.57777 .52188 .58309 .52763 .59337 .5245 .58808 .51873 Mtetra
.58808 .51873 .59337 .5245 .6037 .52136 .59843 .51557 Mtetra
.655 .752 .921 r
.59843 .51557 .6037 .52136 .61406 .51822 .60882 .5124 Mtetra
.60882 .5124 .61406 .51822 .62446 .51506 .61924 .50923 Mtetra
.655 .753 .922 r
.61924 .50923 .62446 .51506 .6349 .5119 .62971 .50606 Mtetra
.654 .753 .922 r
.62971 .50606 .6349 .5119 .64538 .50873 .64022 .50288 Mtetra
.654 .753 .923 r
.64022 .50288 .64538 .50873 .6559 .50556 .65076 .49971 Mtetra
.653 .754 .924 r
.65076 .49971 .6559 .50556 .66646 .50239 .66135 .49655 Mtetra
.651 .754 .925 r
.66135 .49655 .66646 .50239 .67706 .49923 .67198 .49342 Mtetra
.649 .755 .927 r
.67198 .49342 .67706 .49923 .6877 .49609 .68265 .49031 Mtetra
.646 .757 .929 r
.68265 .49031 .6877 .49609 .69838 .49297 .69337 .48726 Mtetra
.643 .759 .933 r
.69337 .48726 .69838 .49297 .70911 .48989 .70413 .48426 Mtetra
.64 .761 .936 r
.70413 .48426 .70911 .48989 .71988 .48686 .71494 .48132 Mtetra
.637 .765 .94 r
.71494 .48132 .71988 .48686 .7307 .48386 .72579 .47841 Mtetra
.636 .769 .943 r
.72579 .47841 .7307 .48386 .74157 .48088 .7367 .4755 Mtetra
.637 .773 .945 r
.7367 .4755 .74157 .48088 .75247 .47788 .74764 .47254 Mtetra
.641 .777 .946 r
.74764 .47254 .75247 .47788 .76342 .47483 .75862 .46946 Mtetra
.647 .779 .944 r
.75862 .46946 .76342 .47483 .77441 .47169 .76963 .46623 Mtetra
.655 .779 .94 r
.76963 .46623 .77441 .47169 .78543 .46842 .78067 .4628 Mtetra
.662 .776 .934 r
.78067 .4628 .78543 .46842 .79648 .46502 .79174 .45921 Mtetra
.667 .772 .928 r
.79174 .45921 .79648 .46502 .80756 .46149 .80284 .45547 Mtetra
.67 .766 .922 r
.80284 .45547 .80756 .46149 .81868 .45786 .81398 .45166 Mtetra
.671 .76 .918 r
.81398 .45166 .81868 .45786 .82984 .45418 .82515 .44783 Mtetra
.67 .755 .915 r
.82515 .44783 .82984 .45418 .84103 .45047 .83637 .44401 Mtetra
.667 .752 .913 r
.83637 .44401 .84103 .45047 .85227 .44677 .84764 .44024 Mtetra
.665 .749 .913 r
.84764 .44024 .85227 .44677 .86356 .44307 .85895 .43651 Mtetra
.663 .748 .913 r
.85895 .43651 .86356 .44307 .87489 .4394 .87032 .43284 Mtetra
.661 .748 .915 r
.87032 .43284 .87489 .4394 .88626 .43574 .88173 .4292 Mtetra
.66 .749 .916 r
.88173 .4292 .88626 .43574 .89768 .4321 .89319 .42559 Mtetra
.659 .751 .918 r
.89319 .42559 .89768 .4321 .90915 .42846 .90469 .42197 Mtetra
.655 .751 .92 r
.28853 .60308 .29453 .60833 .30381 .60558 .29783 .60024 Mtetra
.655 .748 .918 r
.29783 .60024 .30381 .60558 .31312 .60285 .30716 .5974 Mtetra
.654 .745 .917 r
.30716 .5974 .31312 .60285 .32247 .60013 .31653 .59459 Mtetra
.651 .741 .915 r
.31653 .59459 .32247 .60013 .33184 .59745 .32593 .59182 Mtetra
.648 .738 .915 r
.32593 .59182 .33184 .59745 .34124 .59483 .33536 .58912 Mtetra
.644 .735 .915 r
.33536 .58912 .34124 .59483 .35068 .59225 .34481 .58651 Mtetra
.639 .733 .916 r
.34481 .58651 .35068 .59225 .36015 .58972 .3543 .584 Mtetra
.635 .733 .919 r
.3543 .584 .36015 .58972 .36965 .58721 .36382 .58157 Mtetra
.632 .735 .923 r
.36382 .58157 .36965 .58721 .37919 .58469 .37337 .57919 Mtetra
.632 .742 .927 r
.37337 .57919 .37919 .58469 .38877 .58209 .38296 .5768 Mtetra
.634 .751 .932 r
.38296 .5768 .38877 .58209 .39839 .57936 .39259 .5743 Mtetra
.64 .763 .937 r
.39259 .5743 .39839 .57936 .40805 .57647 .40227 .57164 Mtetra
.65 .775 .94 r
.40227 .57164 .40805 .57647 .41776 .57339 .41199 .56873 Mtetra
.658 .785 .941 r
.41199 .56873 .41776 .57339 .4275 .57017 .42175 .56561 Mtetra
.667 .791 .941 r
.42175 .56561 .4275 .57017 .43727 .56683 .43155 .56227 Mtetra
.672 .793 .939 r
.43155 .56227 .43727 .56683 .44708 .56344 .44139 .5588 Mtetra
.674 .791 .937 r
.44139 .5588 .44708 .56344 .45693 .56006 .45126 .55529 Mtetra
.674 .787 .934 r
.45126 .55529 .45693 .56006 .4668 .5567 .46116 .55177 Mtetra
.671 .781 .932 r
.46116 .55177 .4668 .5567 .47671 .5534 .4711 .54832 Mtetra
.668 .775 .93 r
.4711 .54832 .47671 .5534 .48666 .55016 .48107 .54493 Mtetra
.665 .769 .928 r
.48107 .54493 .48666 .55016 .49663 .54696 .49107 .54161 Mtetra
.663 .765 .926 r
.49107 .54161 .49663 .54696 .50665 .54379 .50111 .53835 Mtetra
.66 .761 .925 r
.50111 .53835 .50665 .54379 .5167 .54065 .51119 .53513 Mtetra
.659 .759 .924 r
.51119 .53513 .5167 .54065 .52678 .53752 .5213 .53194 Mtetra
.658 .757 .923 r
.5213 .53194 .52678 .53752 .5369 .5344 .53144 .52877 Mtetra
.657 .756 .923 r
.53144 .52877 .5369 .5344 .54706 .53128 .54163 .52561 Mtetra
.657 .755 .922 r
.54163 .52561 .54706 .53128 .55726 .52815 .55185 .52244 Mtetra
.656 .754 .922 r
.55185 .52244 .55726 .52815 .56749 .52502 .56211 .51928 Mtetra
.56211 .51928 .56749 .52502 .57777 .52188 .57241 .51612 Mtetra
.57241 .51612 .57777 .52188 .58808 .51873 .58275 .51295 Mtetra
.655 .754 .922 r
.58275 .51295 .58808 .51873 .59843 .51557 .59312 .50977 Mtetra
.59312 .50977 .59843 .51557 .60882 .5124 .60354 .50659 Mtetra
.655 .754 .923 r
.60354 .50659 .60882 .5124 .61924 .50923 .61399 .50341 Mtetra
.654 .754 .923 r
.61399 .50341 .61924 .50923 .62971 .50606 .62448 .50023 Mtetra
.653 .754 .924 r
.62448 .50023 .62971 .50606 .64022 .50288 .63502 .49706 Mtetra
.652 .755 .925 r
.63502 .49706 .64022 .50288 .65076 .49971 .64559 .49391 Mtetra
.65 .756 .927 r
.64559 .49391 .65076 .49971 .66135 .49655 .65621 .49079 Mtetra
.648 .757 .929 r
.65621 .49079 .66135 .49655 .67198 .49342 .66687 .48771 Mtetra
.644 .759 .932 r
.66687 .48771 .67198 .49342 .68265 .49031 .67758 .48468 Mtetra
.64 .761 .936 r
.67758 .48468 .68265 .49031 .69337 .48726 .68833 .48173 Mtetra
.636 .765 .941 r
.68833 .48173 .69337 .48726 .70413 .48426 .69913 .47885 Mtetra
.632 .768 .945 r
.69913 .47885 .70413 .48426 .71494 .48132 .70997 .47602 Mtetra
.63 .773 .949 r
.70997 .47602 .71494 .48132 .72579 .47841 .72087 .4732 Mtetra
.631 .778 .952 r
.72087 .4732 .72579 .47841 .7367 .4755 .7318 .47033 Mtetra
.635 .782 .952 r
.7318 .47033 .7367 .4755 .74764 .47254 .74278 .46733 Mtetra
.645 .785 .949 r
.74278 .46733 .74764 .47254 .75862 .46946 .75378 .46411 Mtetra
.655 .784 .943 r
.75378 .46411 .75862 .46946 .76963 .46623 .76481 .46066 Mtetra
.666 .78 .934 r
.76481 .46066 .76963 .46623 .78067 .4628 .77586 .45696 Mtetra
.673 .773 .926 r
.77586 .45696 .78067 .4628 .79174 .45921 .78694 .45307 Mtetra
.676 .765 .917 r
.78694 .45307 .79174 .45921 .80284 .45547 .79806 .44909 Mtetra
.677 .757 .911 r
.79806 .44909 .80284 .45547 .81398 .45166 .80921 .44507 Mtetra
.674 .749 .908 r
.80921 .44507 .81398 .45166 .82515 .44783 .82041 .44111 Mtetra
.671 .745 .906 r
.82041 .44111 .82515 .44783 .83637 .44401 .83165 .43723 Mtetra
.667 .742 .906 r
.83165 .43723 .83637 .44401 .84764 .44024 .84295 .43345 Mtetra
.664 .741 .908 r
.84295 .43345 .84764 .44024 .85895 .43651 .8543 .42975 Mtetra
.661 .742 .91 r
.8543 .42975 .85895 .43651 .87032 .43284 .8657 .42613 Mtetra
.658 .743 .913 r
.8657 .42613 .87032 .43284 .88173 .4292 .87716 .42255 Mtetra
.657 .746 .915 r
.87716 .42255 .88173 .4292 .89319 .42559 .88866 .419 Mtetra
.656 .749 .918 r
.88866 .419 .89319 .42559 .90469 .42197 .90021 .41544 Mtetra
.659 .752 .919 r
.28248 .59781 .28853 .60308 .29783 .60024 .29181 .59485 Mtetra
.66 .749 .916 r
.29181 .59485 .29783 .60024 .30716 .5974 .30117 .59188 Mtetra
.659 .744 .913 r
.30117 .59188 .30716 .5974 .31653 .59459 .31057 .58892 Mtetra
.656 .74 .911 r
.31057 .58892 .31653 .59459 .32593 .59182 .31999 .58602 Mtetra
.653 .735 .909 r
.31999 .58602 .32593 .59182 .33536 .58912 .32944 .58318 Mtetra
.649 .729 .908 r
.32944 .58318 .33536 .58912 .34481 .58651 .33892 .58045 Mtetra
.642 .724 .908 r
.33892 .58045 .34481 .58651 .3543 .584 .34843 .57787 Mtetra
.635 .72 .909 r
.34843 .57787 .3543 .584 .36382 .58157 .35797 .57545 Mtetra
.627 .719 .912 r
.35797 .57545 .36382 .58157 .37337 .57919 .36753 .5732 Mtetra
.623 .722 .918 r
.36753 .5732 .37337 .57919 .38296 .5768 .37713 .57102 Mtetra
.621 .73 .925 r
.37713 .57102 .38296 .5768 .39259 .5743 .38677 .56885 Mtetra
.625 .744 .932 r
.38677 .56885 .39259 .5743 .40227 .57164 .39645 .56654 Mtetra
.635 .761 .939 r
.39645 .56654 .40227 .57164 .41199 .56873 .40618 .56396 Mtetra
.646 .778 .944 r
.40618 .56396 .41199 .56873 .42175 .56561 .41596 .56109 Mtetra
.66 .793 .945 r
.41596 .56109 .42175 .56561 .43155 .56227 .42578 .55787 Mtetra
.669 .801 .945 r
.42578 .55787 .43155 .56227 .44139 .5588 .43564 .55442 Mtetra
.676 .804 .943 r
.43564 .55442 .44139 .5588 .45126 .55529 .44554 .55081 Mtetra
.678 .801 .941 r
.44554 .55081 .45126 .55529 .46116 .55177 .45548 .54714 Mtetra
.677 .795 .938 r
.45548 .54714 .46116 .55177 .4711 .54832 .46544 .54351 Mtetra
.674 .788 .935 r
.46544 .54351 .4711 .54832 .48107 .54493 .47544 .53993 Mtetra
.67 .781 .932 r
.47544 .53993 .48107 .54493 .49107 .54161 .48547 .53645 Mtetra
.667 .775 .93 r
.48547 .53645 .49107 .54161 .50111 .53835 .49554 .53305 Mtetra
.664 .769 .928 r
.49554 .53305 .50111 .53835 .51119 .53513 .50564 .52972 Mtetra
.661 .765 .927 r
.50564 .52972 .51119 .53513 .5213 .53194 .51578 .52645 Mtetra
.66 .762 .926 r
.51578 .52645 .5213 .53194 .53144 .52877 .52595 .5232 Mtetra
.658 .76 .925 r
.52595 .5232 .53144 .52877 .54163 .52561 .53616 .51998 Mtetra
.657 .758 .924 r
.53616 .51998 .54163 .52561 .55185 .52244 .54641 .51678 Mtetra
.657 .757 .924 r
.54641 .51678 .55185 .52244 .56211 .51928 .55669 .51358 Mtetra
.656 .757 .924 r
.55669 .51358 .56211 .51928 .57241 .51612 .56701 .51039 Mtetra
.655 .756 .924 r
.56701 .51039 .57241 .51612 .58275 .51295 .57738 .50719 Mtetra
.57738 .50719 .58275 .51295 .59312 .50977 .58778 .504 Mtetra
.654 .756 .924 r
.58778 .504 .59312 .50977 .60354 .50659 .59822 .50082 Mtetra
.653 .756 .925 r
.59822 .50082 .60354 .50659 .61399 .50341 .6087 .49764 Mtetra
.652 .757 .926 r
.6087 .49764 .61399 .50341 .62448 .50023 .61922 .49447 Mtetra
.651 .757 .928 r
.61922 .49447 .62448 .50023 .63502 .49706 .62979 .49133 Mtetra
.649 .759 .93 r
.62979 .49133 .63502 .49706 .64559 .49391 .64039 .48822 Mtetra
.646 .76 .932 r
.64039 .48822 .64559 .49391 .65621 .49079 .65104 .48517 Mtetra
.642 .762 .936 r
.65104 .48517 .65621 .49079 .66687 .48771 .66173 .48218 Mtetra
.637 .765 .94 r
.66173 .48218 .66687 .48771 .67758 .48468 .67248 .47928 Mtetra
.631 .768 .946 r
.67248 .47928 .67758 .48468 .68833 .48173 .68327 .47647 Mtetra
.626 .773 .951 r
.68327 .47647 .68833 .48173 .69913 .47885 .6941 .47373 Mtetra
.622 .778 .956 r
.6941 .47373 .69913 .47885 .70997 .47602 .70499 .47102 Mtetra
.622 .784 .959 r
.70499 .47102 .70997 .47602 .72087 .4732 .71592 .46826 Mtetra
.629 .79 .959 r
.71592 .46826 .72087 .4732 .7318 .47033 .72689 .46533 Mtetra
.64 .793 .956 r
.72689 .46533 .7318 .47033 .74278 .46733 .73788 .46216 Mtetra
.656 .792 .947 r
.73788 .46216 .74278 .46733 .75378 .46411 .7489 .45864 Mtetra
.67 .786 .936 r
.7489 .45864 .75378 .46411 .76481 .46066 .75994 .4548 Mtetra
.681 .776 .923 r
.75994 .4548 .76481 .46066 .77586 .45696 .77099 .45069 Mtetra
.685 .764 .911 r
.77099 .45069 .77586 .45696 .78694 .45307 .78208 .44643 Mtetra
.684 .751 .902 r
.78208 .44643 .78694 .45307 .79806 .44909 .7932 .44217 Mtetra
.681 .742 .897 r
.7932 .44217 .79806 .44909 .80921 .44507 .80437 .43798 Mtetra
.674 .735 .896 r
.80437 .43798 .80921 .44507 .82041 .44111 .81559 .43397 Mtetra
.669 .732 .897 r
.81559 .43397 .82041 .44111 .83165 .43723 .82687 .4301 Mtetra
.663 .731 .9 r
.82687 .4301 .83165 .43723 .84295 .43345 .83821 .4264 Mtetra
.659 .732 .904 r
.83821 .4264 .84295 .43345 .8543 .42975 .8496 .42281 Mtetra
.656 .735 .908 r
.8496 .42281 .8543 .42975 .8657 .42613 .86105 .41928 Mtetra
.654 .739 .912 r
.86105 .41928 .8657 .42613 .87716 .42255 .87255 .41581 Mtetra
.653 .742 .915 r
.87255 .41581 .87716 .42255 .88866 .419 .88409 .41234 Mtetra
.653 .746 .918 r
.88409 .41234 .88866 .419 .90021 .41544 .89569 .40886 Mtetra
.663 .753 .917 r
.27639 .59249 .28248 .59781 .29181 .59485 .28575 .58944 Mtetra
.664 .751 .915 r
.28575 .58944 .29181 .59485 .30117 .59188 .29514 .58636 Mtetra
.663 .747 .912 r
.29514 .58636 .30117 .59188 .31057 .58892 .30456 .58326 Mtetra
.662 .743 .91 r
.30456 .58326 .31057 .58892 .31999 .58602 .31401 .58019 Mtetra
.661 .737 .906 r
.31401 .58019 .31999 .58602 .32944 .58318 .32349 .57715 Mtetra
.656 .73 .903 r
.32349 .57715 .32944 .58318 .33892 .58045 .333 .57421 Mtetra
.65 .721 .901 r
.333 .57421 .33892 .58045 .34843 .57787 .34254 .57142 Mtetra
.641 .712 .899 r
.34254 .57142 .34843 .57787 .35797 .57545 .3521 .56885 Mtetra
.629 .704 .9 r
.3521 .56885 .35797 .57545 .36753 .5732 .36168 .56656 Mtetra
.62 .701 .902 r
.36168 .56656 .36753 .5732 .37713 .57102 .37129 .56448 Mtetra
.611 .701 .908 r
.37129 .56448 .37713 .57102 .38677 .56885 .38093 .5626 Mtetra
.61 .711 .917 r
.38093 .5626 .38677 .56885 .39645 .56654 .39062 .5607 Mtetra
.615 .728 .927 r
.39062 .5607 .39645 .56654 .40618 .56396 .40035 .55863 Mtetra
.626 .752 .937 r
.40035 .55863 .40618 .56396 .41596 .56109 .41013 .55624 Mtetra
.643 .776 .944 r
.41013 .55624 .41596 .56109 .42578 .55787 .41997 .5534 Mtetra
.658 .796 .949 r
.41997 .5534 .42578 .55787 .43564 .55442 .42985 .55019 Mtetra
.671 .81 .95 r
.42985 .55019 .43564 .55442 .44554 .55081 .43978 .54664 Mtetra
.678 .815 .948 r
.43978 .54664 .44554 .55081 .45548 .54714 .44974 .5429 Mtetra
.681 .814 .946 r
.44974 .5429 .45548 .54714 .46544 .54351 .45974 .53911 Mtetra
.68 .808 .944 r
.45974 .53911 .46544 .54351 .47544 .53993 .46977 .53534 Mtetra
.676 .8 .941 r
.46977 .53534 .47544 .53993 .48547 .53645 .47983 .53165 Mtetra
.673 .792 .938 r
.47983 .53165 .48547 .53645 .49554 .53305 .48992 .52806 Mtetra
.668 .784 .935 r
.48992 .52806 .49554 .53305 .50564 .52972 .50005 .52457 Mtetra
.665 .777 .933 r
.50005 .52457 .50564 .52972 .51578 .52645 .51021 .52116 Mtetra
.662 .772 .931 r
.51021 .52116 .51578 .52645 .52595 .5232 .52041 .51781 Mtetra
.66 .769 .93 r
.52041 .51781 .52595 .5232 .53616 .51998 .53065 .51451 Mtetra
.659 .766 .929 r
.53065 .51451 .53616 .51998 .54641 .51678 .54092 .51124 Mtetra
.657 .764 .928 r
.54092 .51124 .54641 .51678 .55669 .51358 .55123 .508 Mtetra
.656 .762 .928 r
.55123 .508 .55669 .51358 .56701 .51039 .56158 .50477 Mtetra
.655 .762 .928 r
.56158 .50477 .56701 .51039 .57738 .50719 .57197 .50155 Mtetra
.654 .761 .928 r
.57197 .50155 .57738 .50719 .58778 .504 .5824 .49835 Mtetra
.653 .761 .929 r
.5824 .49835 .58778 .504 .59822 .50082 .59287 .49517 Mtetra
.651 .762 .93 r
.59287 .49517 .59822 .50082 .6087 .49764 .60338 .49201 Mtetra
.649 .763 .932 r
.60338 .49201 .6087 .49764 .61922 .49447 .61393 .48888 Mtetra
.646 .764 .935 r
.61393 .48888 .61922 .49447 .62979 .49133 .62453 .4858 Mtetra
.642 .766 .938 r
.62453 .4858 .62979 .49133 .64039 .48822 .63516 .48279 Mtetra
.638 .769 .942 r
.63516 .48279 .64039 .48822 .65104 .48517 .64585 .47985 Mtetra
.631 .772 .948 r
.64585 .47985 .65104 .48517 .66173 .48218 .65658 .47702 Mtetra
.625 .777 .954 r
.65658 .47702 .66173 .48218 .67248 .47928 .66736 .47428 Mtetra
.617 .782 .96 r
.66736 .47428 .67248 .47928 .68327 .47647 .67819 .47164 Mtetra
.613 .788 .965 r
.67819 .47164 .68327 .47647 .6941 .47373 .68906 .46902 Mtetra
.614 .794 .968 r
.68906 .46902 .6941 .47373 .70499 .47102 .69998 .46633 Mtetra
.622 .799 .967 r
.69998 .46633 .70499 .47102 .71592 .46826 .71094 .46346 Mtetra
.639 .802 .961 r
.71094 .46346 .71592 .46826 .72689 .46533 .72193 .46025 Mtetra
.659 .797 .949 r
.72193 .46025 .72689 .46533 .73788 .46216 .73293 .45665 Mtetra
.679 .788 .932 r
.73293 .45665 .73788 .46216 .7489 .45864 .74394 .45258 Mtetra
.69 .773 .914 r
.74394 .45258 .7489 .45864 .75994 .4548 .75498 .44818 Mtetra
.695 .756 .899 r
.75498 .44818 .75994 .4548 .77099 .45069 .76603 .44359 Mtetra
.693 .741 .888 r
.76603 .44359 .77099 .45069 .78208 .44643 .77712 .43899 Mtetra
.686 .728 .883 r
.77712 .43899 .78208 .44643 .7932 .44217 .78826 .43458 Mtetra
.678 .721 .882 r
.78826 .43458 .7932 .44217 .80437 .43798 .79946 .43038 Mtetra
.669 .718 .886 r
.79946 .43038 .80437 .43798 .81559 .43397 .81072 .42647 Mtetra
.662 .719 .891 r
.81072 .42647 .81559 .43397 .82687 .4301 .82205 .42278 Mtetra
.656 .723 .898 r
.82205 .42278 .82687 .4301 .83821 .4264 .83343 .41925 Mtetra
.653 .728 .904 r
.83343 .41925 .83821 .4264 .8496 .42281 .84487 .41583 Mtetra
.651 .734 .91 r
.84487 .41583 .8496 .42281 .86105 .41928 .85637 .41243 Mtetra
.65 .738 .914 r
.85637 .41243 .86105 .41928 .87255 .41581 .86791 .40905 Mtetra
.649 .742 .917 r
.86791 .40905 .87255 .41581 .88409 .41234 .8795 .40566 Mtetra
.65 .746 .92 r
.8795 .40566 .88409 .41234 .89569 .40886 .89113 .40224 Mtetra
.664 .753 .917 r
.27027 .58715 .27639 .59249 .28575 .58944 .27964 .58405 Mtetra
.665 .753 .915 r
.27964 .58405 .28575 .58944 .29514 .58636 .28906 .5809 Mtetra
.667 .751 .914 r
.28906 .5809 .29514 .58636 .30456 .58326 .2985 .57771 Mtetra
.668 .749 .911 r
.2985 .57771 .30456 .58326 .31401 .58019 .30798 .57447 Mtetra
.669 .744 .907 r
.30798 .57447 .31401 .58019 .32349 .57715 .3175 .5712 Mtetra
.667 .736 .902 r
.3175 .5712 .32349 .57715 .333 .57421 .32705 .56796 Mtetra
.663 .726 .896 r
.32705 .56796 .333 .57421 .34254 .57142 .33662 .56482 Mtetra
.653 .712 .891 r
.33662 .56482 .34254 .57142 .3521 .56885 .34621 .5619 Mtetra
.64 .698 .888 r
.34621 .5619 .3521 .56885 .36168 .56656 .35582 .55933 Mtetra
.625 .685 .886 r
.35582 .55933 .36168 .56656 .37129 .56448 .36545 .55713 Mtetra
.607 .676 .889 r
.36545 .55713 .37129 .56448 .38093 .5626 .3751 .55538 Mtetra
.597 .676 .896 r
.3751 .55538 .38093 .5626 .39062 .5607 .38479 .55384 Mtetra
.591 .686 .908 r
.38479 .55384 .39062 .5607 .40035 .55863 .39451 .55238 Mtetra
.598 .71 .923 r
.39451 .55238 .40035 .55863 .41013 .55624 .40429 .55069 Mtetra
.615 .742 .936 r
.40429 .55069 .41013 .55624 .41997 .5534 .41412 .54852 Mtetra
.634 .774 .948 r
.41412 .54852 .41997 .5534 .42985 .55019 .42401 .54584 Mtetra
.656 .803 .953 r
.42401 .54584 .42985 .55019 .43978 .54664 .43396 .5426 Mtetra
.671 .82 .955 r
.43396 .5426 .43978 .54664 .44974 .5429 .44395 .53899 Mtetra
.68 .828 .954 r
.44395 .53899 .44974 .5429 .45974 .53911 .45398 .53514 Mtetra
.684 .827 .952 r
.45398 .53514 .45974 .53911 .46977 .53534 .46404 .5312 Mtetra
.682 .821 .95 r
.46404 .5312 .46977 .53534 .47983 .53165 .47414 .52731 Mtetra
.679 .813 .947 r
.47414 .52731 .47983 .53165 .48992 .52806 .48426 .5235 Mtetra
.674 .804 .944 r
.48426 .5235 .48992 .52806 .50005 .52457 .49442 .5198 Mtetra
.67 .795 .941 r
.49442 .5198 .50005 .52457 .51021 .52116 .50461 .51621 Mtetra
.666 .788 .939 r
.50461 .51621 .51021 .52116 .52041 .51781 .51484 .51272 Mtetra
.663 .782 .937 r
.51484 .51272 .52041 .51781 .53065 .51451 .5251 .5093 Mtetra
.66 .778 .936 r
.5251 .5093 .53065 .51451 .54092 .51124 .5354 .50595 Mtetra
.658 .775 .935 r
.5354 .50595 .54092 .51124 .55123 .508 .54574 .50264 Mtetra
.656 .772 .935 r
.54574 .50264 .55123 .508 .56158 .50477 .55612 .49937 Mtetra
.654 .771 .935 r
.55612 .49937 .56158 .50477 .57197 .50155 .56653 .49613 Mtetra
.652 .77 .936 r
.56653 .49613 .57197 .50155 .5824 .49835 .57699 .49293 Mtetra
.65 .77 .937 r
.57699 .49293 .5824 .49835 .59287 .49517 .58749 .48977 Mtetra
.647 .771 .939 r
.58749 .48977 .59287 .49517 .60338 .49201 .59803 .48665 Mtetra
.643 .773 .942 r
.59803 .48665 .60338 .49201 .61393 .48888 .60861 .4836 Mtetra
.639 .775 .946 r
.60861 .4836 .61393 .48888 .62453 .4858 .61924 .48062 Mtetra
.632 .777 .95 r
.61924 .48062 .62453 .4858 .63516 .48279 .62991 .47774 Mtetra
.625 .781 .956 r
.62991 .47774 .63516 .48279 .64585 .47985 .64063 .47497 Mtetra
.616 .786 .963 r
.64063 .47497 .64585 .47985 .65658 .47702 .6514 .47232 Mtetra
.608 .791 .969 r
.6514 .47232 .65658 .47702 .66736 .47428 .66222 .46975 Mtetra
.602 .797 .974 r
.66222 .46975 .66736 .47428 .67819 .47164 .67309 .46723 Mtetra
.603 .804 .977 r
.67309 .46723 .67819 .47164 .68906 .46902 .684 .46462 Mtetra
.615 .81 .975 r
.684 .46462 .68906 .46902 .69998 .46633 .69495 .46177 Mtetra
.636 .811 .967 r
.69495 .46177 .69998 .46633 .71094 .46346 .70592 .45854 Mtetra
.666 .807 .951 r
.70592 .45854 .71094 .46346 .72193 .46025 .71691 .45473 Mtetra
.688 .792 .929 r
.71691 .45473 .72193 .46025 .73293 .45665 .7279 .4504 Mtetra
.704 .771 .904 r
.7279 .4504 .73293 .45665 .74394 .45258 .7389 .44557 Mtetra
.707 .748 .884 r
.7389 .44557 .74394 .45258 .75498 .44818 .74991 .4405 Mtetra
.701 .727 .87 r
.74991 .4405 .75498 .44818 .76603 .44359 .76096 .43549 Mtetra
.693 .713 .864 r
.76096 .43549 .76603 .44359 .77712 .43899 .77207 .4307 Mtetra
.679 .703 .865 r
.77207 .4307 .77712 .43899 .78826 .43458 .78324 .42636 Mtetra
.668 .701 .871 r
.78324 .42636 .78826 .43458 .79946 .43038 .79449 .42241 Mtetra
.658 .704 .881 r
.79449 .42241 .79946 .43038 .81072 .42647 .80581 .41881 Mtetra
.65 .711 .892 r
.80581 .41881 .81072 .42647 .82205 .42278 .81719 .41545 Mtetra
.647 .72 .902 r
.81719 .41545 .82205 .42278 .83343 .41925 .82863 .41218 Mtetra
.644 .728 .91 r
.82863 .41218 .83343 .41925 .84487 .41583 .84013 .40895 Mtetra
.645 .736 .915 r
.84013 .40895 .84487 .41583 .85637 .41243 .85167 .40567 Mtetra
.646 .742 .919 r
.85167 .40567 .85637 .41243 .86791 .40905 .86325 .40236 Mtetra
.647 .745 .921 r
.86325 .40236 .86791 .40905 .8795 .40566 .87488 .39899 Mtetra
.649 .748 .922 r
.87488 .39899 .8795 .40566 .89113 .40224 .88655 .39556 Mtetra
.661 .753 .918 r
.2641 .58177 .27027 .58715 .27964 .58405 .27349 .57872 Mtetra
.663 .756 .919 r
.27349 .57872 .27964 .58405 .28906 .5809 .28292 .57561 Mtetra
.666 .759 .92 r
.28292 .57561 .28906 .5809 .2985 .57771 .29239 .57243 Mtetra
.669 .76 .919 r
.29239 .57243 .2985 .57771 .30798 .57447 .30189 .56914 Mtetra
.674 .76 .916 r
.30189 .56914 .30798 .57447 .3175 .5712 .31144 .56571 Mtetra
.676 .756 .911 r
.31144 .56571 .3175 .5712 .32705 .56796 .32102 .56222 Mtetra
.678 .748 .904 r
.32102 .56222 .32705 .56796 .33662 .56482 .33064 .55867 Mtetra
.672 .734 .896 r
.33064 .55867 .33662 .56482 .34621 .5619 .34027 .55524 Mtetra
.661 .715 .888 r
.34027 .55524 .34621 .5619 .35582 .55933 .34993 .55208 Mtetra
.644 .692 .88 r
.34993 .55208 .35582 .55933 .36545 .55713 .3596 .54935 Mtetra
.621 .669 .875 r
.3596 .54935 .36545 .55713 .3751 .55538 .36928 .54725 Mtetra
.601 .653 .873 r
.36928 .54725 .3751 .55538 .38479 .55384 .37898 .54567 Mtetra
.581 .644 .877 r
.37898 .54567 .38479 .55384 .39451 .55238 .3887 .54458 Mtetra
.576 .653 .888 r
.3887 .54458 .39451 .55238 .40429 .55069 .39846 .54355 Mtetra
.582 .676 .904 r
.39846 .54355 .40429 .55069 .41412 .54852 .40828 .54228 Mtetra
.598 .713 .925 r
.40828 .54228 .41412 .54852 .42401 .54584 .41817 .54052 Mtetra
.625 .757 .941 r
.41817 .54052 .42401 .54584 .43396 .5426 .42811 .53805 Mtetra
.647 .795 .953 r
.42811 .53805 .43396 .5426 .44395 .53899 .43812 .535 Mtetra
.666 .823 .959 r
.43812 .535 .44395 .53899 .45398 .53514 .44817 .53143 Mtetra
.677 .838 .961 r
.44817 .53143 .45398 .53514 .46404 .5312 .45826 .52757 Mtetra
.681 .843 .961 r
.45826 .52757 .46404 .5312 .47414 .52731 .46839 .52359 Mtetra
.681 .841 .96 r
.46839 .52359 .47414 .52731 .48426 .5235 .47855 .5196 Mtetra
.678 .833 .958 r
.47855 .5196 .48426 .5235 .49442 .5198 .48874 .5157 Mtetra
.674 .825 .956 r
.48874 .5157 .49442 .5198 .50461 .51621 .49896 .5119 Mtetra
.669 .816 .954 r
.49896 .5119 .50461 .51621 .51484 .51272 .50922 .50822 Mtetra
.665 .808 .952 r
.50922 .50822 .51484 .51272 .5251 .5093 .51951 .50465 Mtetra
.661 .802 .95 r
.51951 .50465 .5251 .5093 .5354 .50595 .52984 .50118 Mtetra
.658 .797 .949 r
.52984 .50118 .5354 .50595 .54574 .50264 .54021 .49778 Mtetra
.654 .793 .949 r
.54021 .49778 .54574 .50264 .55612 .49937 .55062 .49445 Mtetra
.651 .791 .949 r
.55062 .49445 .55612 .49937 .56653 .49613 .56106 .4912 Mtetra
.647 .79 .95 r
.56106 .4912 .56653 .49613 .57699 .49293 .57155 .48801 Mtetra
.643 .79 .952 r
.57155 .48801 .57699 .49293 .58749 .48977 .58208 .48489 Mtetra
.638 .791 .955 r
.58208 .48489 .58749 .48977 .59803 .48665 .59265 .48185 Mtetra
.632 .793 .96 r
.59265 .48185 .59803 .48665 .60861 .4836 .60326 .47891 Mtetra
.624 .796 .965 r
.60326 .47891 .60861 .4836 .61924 .48062 .61393 .47607 Mtetra
.614 .799 .97 r
.61393 .47607 .61924 .48062 .62991 .47774 .62464 .47337 Mtetra
.604 .804 .976 r
.62464 .47337 .62991 .47774 .64063 .47497 .6354 .47076 Mtetra
.595 .808 .982 r
.6354 .47076 .64063 .47497 .6514 .47232 .6462 .46825 Mtetra
.591 .814 .985 r
.6462 .46825 .6514 .47232 .66222 .46975 .65706 .46573 Mtetra
.596 .818 .985 r
.65706 .46573 .66222 .46975 .67309 .46723 .66796 .46308 Mtetra
.614 .821 .98 r
.66796 .46308 .67309 .46723 .684 .46462 .67889 .46015 Mtetra
.646 .819 .966 r
.67889 .46015 .684 .46462 .69495 .46177 .68985 .45668 Mtetra
.677 .804 .943 r
.68985 .45668 .69495 .46177 .70592 .45854 .70081 .45262 Mtetra
.704 .782 .912 r
.70081 .45262 .70592 .45854 .71691 .45473 .71177 .44782 Mtetra
.715 .754 .883 r
.71177 .44782 .71691 .45473 .7279 .4504 .72273 .44252 Mtetra
.715 .726 .859 r
.72273 .44252 .7279 .4504 .7389 .44557 .73371 .43695 Mtetra
.708 .705 .846 r
.73371 .43695 .7389 .44557 .74991 .4405 .74472 .43145 Mtetra
.692 .69 .843 r
.74472 .43145 .74991 .4405 .76096 .43549 .7558 .42644 Mtetra
.679 .684 .848 r
.7558 .42644 .76096 .43549 .77207 .4307 .76695 .42195 Mtetra
.663 .685 .861 r
.76695 .42195 .77207 .4307 .78324 .42636 .77819 .41812 Mtetra
.65 .694 .877 r
.77819 .41812 .78324 .42636 .79449 .42241 .78951 .41473 Mtetra
.642 .707 .895 r
.78951 .41473 .79449 .42241 .80581 .41881 .8009 .41162 Mtetra
.636 .721 .909 r
.8009 .41162 .80581 .41881 .81719 .41545 .81235 .40863 Mtetra
.637 .735 .919 r
.81235 .40863 .81719 .41545 .82863 .41218 .82385 .40559 Mtetra
.638 .744 .925 r
.82385 .40559 .82863 .41218 .84013 .40895 .83539 .40246 Mtetra
.643 .751 .927 r
.83539 .40246 .84013 .40895 .85167 .40567 .84696 .3992 Mtetra
.646 .753 .927 r
.84696 .3992 .85167 .40567 .86325 .40236 .85858 .39583 Mtetra
.649 .753 .926 r
.85858 .39583 .86325 .40236 .87488 .39899 .87023 .39237 Mtetra
.651 .752 .923 r
.87023 .39237 .87488 .39899 .88655 .39556 .88193 .38884 Mtetra
.654 .751 .921 r
.25789 .57635 .2641 .58177 .27349 .57872 .26729 .57345 Mtetra
.655 .757 .925 r
.26729 .57345 .27349 .57872 .28292 .57561 .27673 .5705 Mtetra
.658 .765 .928 r
.27673 .5705 .28292 .57561 .29239 .57243 .2862 .56746 Mtetra
.664 .772 .93 r
.2862 .56746 .29239 .57243 .30189 .56914 .29573 .56427 Mtetra
.672 .778 .929 r
.29573 .56427 .30189 .56914 .31144 .56571 .30529 .56086 Mtetra
.681 .782 .927 r
.30529 .56086 .31144 .56571 .32102 .56222 .3149 .55723 Mtetra
.691 .779 .919 r
.3149 .55723 .32102 .56222 .33064 .55867 .32456 .55334 Mtetra
.693 .768 .909 r
.32456 .55334 .33064 .55867 .34027 .55524 .33426 .54935 Mtetra
.691 .749 .896 r
.33426 .54935 .34027 .55524 .34993 .55208 .34398 .54536 Mtetra
.677 .72 .882 r
.34398 .54536 .34993 .55208 .3596 .54935 .35371 .54171 Mtetra
.652 .686 .869 r
.35371 .54171 .3596 .54935 .36928 .54725 .36345 .5387 Mtetra
.624 .652 .857 r
.36345 .5387 .36928 .54725 .37898 .54567 .37318 .53649 Mtetra
.589 .622 .853 r
.37318 .53649 .37898 .54567 .3887 .54458 .38292 .53525 Mtetra
.568 .61 .855 r
.38292 .53525 .3887 .54458 .39846 .54355 .39267 .53458 Mtetra
.553 .613 .866 r
.39267 .53458 .39846 .54355 .40828 .54228 .40247 .53421 Mtetra
.557 .639 .888 r
.40247 .53421 .40828 .54228 .41817 .54052 .41233 .53359 Mtetra
.579 .684 .913 r
.41233 .53359 .41817 .54052 .42811 .53805 .42226 .5323 Mtetra
.604 .736 .938 r
.42226 .5323 .42811 .53805 .43812 .535 .43225 .53029 Mtetra
.636 .787 .955 r
.43225 .53029 .43812 .535 .44817 .53143 .44231 .52745 Mtetra
.656 .824 .964 r
.44231 .52745 .44817 .53143 .45826 .52757 .45243 .52404 Mtetra
.67 .847 .968 r
.45243 .52404 .45826 .52757 .46839 .52359 .46258 .52024 Mtetra
.676 .856 .968 r
.46258 .52024 .46839 .52359 .47855 .5196 .47277 .51625 Mtetra
.676 .857 .968 r
.47277 .51625 .47855 .5196 .48874 .5157 .483 .51223 Mtetra
.674 .853 .968 r
.483 .51223 .48874 .5157 .49896 .5119 .49326 .50826 Mtetra
.67 .845 .967 r
.49326 .50826 .49896 .5119 .50922 .50822 .50355 .5044 Mtetra
.665 .838 .966 r
.50355 .5044 .50922 .50822 .51951 .50465 .51388 .50067 Mtetra
.66 .83 .965 r
.51388 .50067 .51951 .50465 .52984 .50118 .52424 .49706 Mtetra
.655 .824 .965 r
.52424 .49706 .52984 .50118 .54021 .49778 .53464 .49356 Mtetra
.65 .82 .965 r
.53464 .49356 .54021 .49778 .55062 .49445 .54507 .49018 Mtetra
.644 .816 .966 r
.54507 .49018 .55062 .49445 .56106 .4912 .55555 .4869 Mtetra
.638 .815 .968 r
.55555 .4869 .56106 .4912 .57155 .48801 .56607 .48372 Mtetra
.631 .814 .97 r
.56607 .48372 .57155 .48801 .58208 .48489 .57663 .48066 Mtetra
.623 .815 .974 r
.57663 .48066 .58208 .48489 .59265 .48185 .58724 .47772 Mtetra
.613 .816 .978 r
.58724 .47772 .59265 .48185 .60326 .47891 .59789 .4749 Mtetra
.602 .819 .983 r
.59789 .4749 .60326 .47891 .61393 .47607 .60859 .4722 Mtetra
.59 .821 .987 r
.60859 .4722 .61393 .47607 .62464 .47337 .61934 .46962 Mtetra
.582 .825 .99 r
.61934 .46962 .62464 .47337 .6354 .47076 .63014 .4671 Mtetra
.58 .828 .992 r
.63014 .4671 .6354 .47076 .6462 .46825 .64098 .46455 Mtetra
.592 .832 .99 r
.64098 .46455 .6462 .46825 .65706 .46573 .65187 .46181 Mtetra
.62 .833 .982 r
.65187 .46181 .65706 .46573 .66796 .46308 .66278 .45866 Mtetra
.657 .825 .964 r
.66278 .45866 .66796 .46308 .67889 .46015 .67371 .45494 Mtetra
.697 .806 .933 r
.67371 .45494 .67889 .46015 .68985 .45668 .68465 .45037 Mtetra
.719 .774 .896 r
.68465 .45037 .68985 .45668 .70081 .45262 .69557 .44504 Mtetra
.728 .739 .86 r
.69557 .44504 .70081 .45262 .71177 .44782 .7065 .43902 Mtetra
.724 .707 .834 r
.7065 .43902 .71177 .44782 .72273 .44252 .71743 .43274 Mtetra
.709 .681 .82 r
.71743 .43274 .72273 .44252 .73371 .43695 .7284 .42676 Mtetra
.694 .666 .818 r
.7284 .42676 .73371 .43695 .74472 .43145 .73944 .42135 Mtetra
.671 .658 .829 r
.73944 .42135 .74472 .43145 .7558 .42644 .75058 .41694 Mtetra
.653 .664 .848 r
.75058 .41694 .7558 .42644 .76695 .42195 .76182 .41335 Mtetra
.635 .678 .874 r
.76182 .41335 .76695 .42195 .77819 .41812 .77316 .41041 Mtetra
.622 .699 .9 r
.77316 .41041 .77819 .41812 .78951 .41473 .78457 .40784 Mtetra
.619 .724 .922 r
.78457 .40784 .78951 .41473 .8009 .41162 .79604 .40526 Mtetra
.619 .744 .936 r
.79604 .40526 .8009 .41162 .81235 .40863 .80755 .40259 Mtetra
.628 .761 .942 r
.80755 .40259 .81235 .40863 .82385 .40559 .81909 .39964 Mtetra
.636 .768 .943 r
.81909 .39964 .82385 .40559 .83539 .40246 .83066 .39645 Mtetra
.645 .771 .94 r
.83066 .39645 .83539 .40246 .84696 .3992 .84226 .39304 Mtetra
.651 .769 .935 r
.84226 .39304 .84696 .3992 .85858 .39583 .85389 .38947 Mtetra
.656 .764 .93 r
.85389 .38947 .85858 .39583 .87023 .39237 .86556 .3858 Mtetra
.657 .758 .924 r
.86556 .3858 .87023 .39237 .88193 .38884 .87727 .38207 Mtetra
.645 .749 .925 r
.25164 .57089 .25789 .57635 .26729 .57345 .26105 .56817 Mtetra
.644 .756 .93 r
.26105 .56817 .26729 .57345 .27673 .5705 .27049 .56544 Mtetra
.646 .765 .935 r
.27049 .56544 .27673 .5705 .2862 .56746 .27997 .56264 Mtetra
.65 .776 .94 r
.27997 .56264 .2862 .56746 .29573 .56427 .28949 .5597 Mtetra
.658 .789 .944 r
.28949 .5597 .29573 .56427 .30529 .56086 .29906 .55656 Mtetra
.67 .803 .946 r
.29906 .55656 .30529 .56086 .3149 .55723 .30869 .55313 Mtetra
.687 .814 .943 r
.30869 .55313 .3149 .55723 .32456 .55334 .31837 .54928 Mtetra
.701 .819 .938 r
.31837 .54928 .32456 .55334 .33426 .54935 .3281 .54508 Mtetra
.716 .814 .926 r
.3281 .54508 .33426 .54935 .34398 .54536 .33788 .54049 Mtetra
.715 .792 .912 r
.33788 .54049 .34398 .54536 .35371 .54171 .34769 .53589 Mtetra
.702 .757 .894 r
.34769 .53589 .35371 .54171 .36345 .5387 .35751 .53154 Mtetra
.673 .708 .874 r
.35751 .53154 .36345 .5387 .37318 .53649 .36733 .52792 Mtetra
.631 .656 .856 r
.36733 .52792 .37318 .53649 .38292 .53525 .37713 .52546 Mtetra
.595 .613 .84 r
.37713 .52546 .38292 .53525 .39267 .53458 .38692 .52405 Mtetra
.559 .581 .832 r
.38692 .52405 .39267 .53458 .40247 .53421 .39672 .52369 Mtetra
.545 .575 .836 r
.39672 .52369 .40247 .53421 .41233 .53359 .40656 .52371 Mtetra
.545 .589 .85 r
.40656 .52371 .41233 .53359 .42226 .5323 .41645 .52364 Mtetra
.559 .626 .875 r
.41645 .52364 .42226 .5323 .43225 .53029 .42642 .52304 Mtetra
.589 .68 .904 r
.42642 .52304 .43225 .53029 .44231 .52745 .43646 .52155 Mtetra
.615 .737 .933 r
.43646 .52155 .44231 .52745 .45243 .52404 .44657 .5193 Mtetra
.641 .79 .954 r
.44657 .5193 .45243 .52404 .46258 .52024 .45674 .5163 Mtetra
.655 .828 .967 r
.45674 .5163 .46258 .52024 .47277 .51625 .46695 .51284 Mtetra
.661 .853 .973 r
.46695 .51284 .47277 .51625 .483 .51223 .47721 .5091 Mtetra
.662 .865 .976 r
.47721 .5091 .483 .51223 .49326 .50826 .4875 .50523 Mtetra
.659 .869 .979 r
.4875 .50523 .49326 .50826 .50355 .5044 .49783 .50137 Mtetra
.654 .869 .98 r
.49783 .50137 .50355 .5044 .51388 .50067 .50819 .49757 Mtetra
.648 .866 .981 r
.50819 .49757 .51388 .50067 .52424 .49706 .51859 .49388 Mtetra
.641 .861 .983 r
.51859 .49388 .52424 .49706 .53464 .49356 .52902 .49031 Mtetra
.634 .857 .984 r
.52902 .49031 .53464 .49356 .54507 .49018 .53949 .48688 Mtetra
.625 .854 .986 r
.53949 .48688 .54507 .49018 .55555 .4869 .55001 .48358 Mtetra
.616 .851 .988 r
.55001 .48358 .55555 .4869 .56607 .48372 .56056 .48041 Mtetra
.606 .849 .99 r
.56056 .48041 .56607 .48372 .57663 .48066 .57116 .47738 Mtetra
.596 .848 .992 r
.57116 .47738 .57663 .48066 .58724 .47772 .5818 .47447 Mtetra
.586 .846 .994 r
.5818 .47447 .58724 .47772 .59789 .4749 .59249 .47168 Mtetra
.579 .846 .995 r
.59249 .47168 .59789 .4749 .60859 .4722 .60323 .46895 Mtetra
.578 .845 .995 r
.60323 .46895 .60859 .4722 .61934 .46962 .61401 .46623 Mtetra
.59 .844 .993 r
.61401 .46623 .61934 .46962 .63014 .4671 .62483 .46338 Mtetra
.615 .84 .985 r
.62483 .46338 .63014 .4671 .64098 .46455 .63569 .46025 Mtetra
.651 .828 .968 r
.63569 .46025 .64098 .46455 .65187 .46181 .64658 .45664 Mtetra
.689 .805 .937 r
.64658 .45664 .65187 .46181 .66278 .45866 .65748 .45228 Mtetra
.713 .769 .896 r
.65748 .45228 .66278 .45866 .67371 .45494 .66838 .44712 Mtetra
.727 .732 .854 r
.66838 .44712 .67371 .45494 .68465 .45037 .67927 .44106 Mtetra
.726 .696 .821 r
.67927 .44106 .68465 .45037 .69557 .44504 .69015 .43444 Mtetra
.718 .668 .8 r
.69015 .43444 .69557 .44504 .7065 .43902 .70106 .42771 Mtetra
.705 .651 .793 r
.70106 .42771 .7065 .43902 .71743 .43274 .712 .42136 Mtetra
.683 .64 .8 r
.712 .42136 .71743 .43274 .7284 .42676 .72304 .41608 Mtetra
.663 .644 .82 r
.72304 .41608 .7284 .42676 .73944 .42135 .73418 .41188 Mtetra
.636 .657 .854 r
.73418 .41188 .73944 .42135 .75058 .41694 .74544 .40887 Mtetra
.611 .683 .893 r
.74544 .40887 .75058 .41694 .76182 .41335 .7568 .40662 Mtetra
.593 .719 .931 r
.7568 .40662 .76182 .41335 .77316 .41041 .76824 .40463 Mtetra
.582 .75 .957 r
.76824 .40463 .77316 .41041 .78457 .40784 .77974 .40263 Mtetra
.592 .779 .969 r
.77974 .40263 .78457 .40784 .79604 .40526 .79126 .40023 Mtetra
.607 .793 .97 r
.79126 .40023 .79604 .40526 .80755 .40259 .8028 .39746 Mtetra
.628 .799 .964 r
.8028 .39746 .80755 .40259 .81909 .39964 .81436 .39426 Mtetra
.644 .796 .956 r
.81436 .39426 .81909 .39964 .83066 .39645 .82594 .39075 Mtetra
.655 .788 .946 r
.82594 .39075 .83066 .39645 .84226 .39304 .83754 .38703 Mtetra
.661 .78 .937 r
.83754 .38703 .84226 .39304 .85389 .38947 .84918 .38315 Mtetra
.665 .771 .929 r
.84918 .38315 .85389 .38947 .86556 .3858 .86086 .3792 Mtetra
.665 .762 .923 r
.86086 .3792 .86556 .3858 .87727 .38207 .87259 .37524 Mtetra
.638 .747 .927 r
.24535 .5654 .25164 .57089 .26105 .56817 .25476 .56281 Mtetra
.634 .751 .933 r
.25476 .56281 .26105 .56817 .27049 .56544 .26421 .56028 Mtetra
.632 .759 .939 r
.26421 .56028 .27049 .56544 .27997 .56264 .27369 .55774 Mtetra
.632 .77 .946 r
.27369 .55774 .27997 .56264 .28949 .5597 .28321 .55516 Mtetra
.632 .785 .955 r
.28321 .55516 .28949 .5597 .29906 .55656 .29277 .5525 Mtetra
.64 .807 .963 r
.29277 .5525 .29906 .55656 .30869 .55313 .30238 .54958 Mtetra
.656 .833 .968 r
.30238 .54958 .30869 .55313 .31837 .54928 .31206 .54626 Mtetra
.679 .859 .968 r
.31206 .54626 .31837 .54928 .3281 .54508 .3218 .54236 Mtetra
.713 .877 .958 r
.3218 .54236 .3281 .54508 .33788 .54049 .33162 .53769 Mtetra
.737 .876 .945 r
.33162 .53769 .33788 .54049 .34769 .53589 .34149 .53245 Mtetra
.755 .852 .923 r
.34149 .53245 .34769 .53589 .35751 .53154 .35142 .52672 Mtetra
.741 .8 .899 r
.35142 .52672 .35751 .53154 .36733 .52792 .36135 .52124 Mtetra
.706 .733 .872 r
.36135 .52124 .36733 .52792 .37713 .52546 .37127 .51658 Mtetra
.656 .66 .842 r
.37127 .51658 .37713 .52546 .38692 .52405 .38115 .51324 Mtetra
.599 .596 .82 r
.38115 .51324 .38692 .52405 .39672 .52369 .391 .51168 Mtetra
.561 .556 .806 r
.391 .51168 .39672 .52369 .40656 .52371 .40085 .51135 Mtetra
.531 .535 .804 r
.40085 .51135 .40656 .52371 .41645 .52364 .41072 .51195 Mtetra
.524 .544 .817 r
.41072 .51195 .41645 .52364 .42642 .52304 .42065 .51265 Mtetra
.536 .576 .842 r
.42065 .51265 .42642 .52304 .43646 .52155 .43065 .51282 Mtetra
.557 .626 .876 r
.43065 .51282 .43646 .52155 .44657 .5193 .44073 .51223 Mtetra
.59 .689 .911 r
.44073 .51223 .44657 .5193 .45674 .5163 .45089 .51065 Mtetra
.615 .749 .941 r
.45089 .51065 .45674 .5163 .46695 .51284 .46111 .5083 Mtetra
.635 .8 .962 r
.46111 .5083 .46695 .51284 .47721 .5091 .47138 .50532 Mtetra
.644 .835 .974 r
.47138 .50532 .47721 .5091 .4875 .50523 .4817 .50195 Mtetra
.646 .857 .98 r
.4817 .50195 .4875 .50523 .49783 .50137 .49206 .49837 Mtetra
.643 .869 .983 r
.49206 .49837 .49783 .50137 .50819 .49757 .50245 .49471 Mtetra
.636 .874 .986 r
.50245 .49471 .50819 .49757 .51859 .49388 .51289 .49108 Mtetra
.628 .875 .988 r
.51289 .49108 .51859 .49388 .52902 .49031 .52336 .48752 Mtetra
.619 .873 .99 r
.52336 .48752 .52902 .49031 .53949 .48688 .53387 .48408 Mtetra
.61 .871 .991 r
.53387 .48408 .53949 .48688 .55001 .48358 .54442 .48076 Mtetra
.601 .868 .993 r
.54442 .48076 .55001 .48358 .56056 .48041 .55501 .47756 Mtetra
.592 .864 .994 r
.55501 .47756 .56056 .48041 .57116 .47738 .56564 .47448 Mtetra
.588 .862 .995 r
.56564 .47448 .57116 .47738 .5818 .47447 .57632 .47147 Mtetra
.588 .858 .995 r
.57632 .47147 .5818 .47447 .59249 .47168 .58704 .46849 Mtetra
.598 .855 .993 r
.58704 .46849 .59249 .47168 .60323 .46895 .59781 .46544 Mtetra
.619 .849 .987 r
.59781 .46544 .60323 .46895 .61401 .46623 .60861 .46217 Mtetra
.65 .837 .972 r
.60861 .46217 .61401 .46623 .62483 .46338 .61945 .45851 Mtetra
.686 .815 .944 r
.61945 .45851 .62483 .46338 .63569 .46025 .6303 .4542 Mtetra
.713 .78 .905 r
.6303 .4542 .63569 .46025 .64658 .45664 .64117 .44911 Mtetra
.731 .74 .859 r
.64117 .44911 .64658 .45664 .65748 .45228 .65203 .44299 Mtetra
.732 .699 .819 r
.65203 .44299 .65748 .45228 .66838 .44712 .66288 .4361 Mtetra
.727 .665 .788 r
.66288 .4361 .66838 .44712 .67927 .44106 .67372 .42866 Mtetra
.714 .638 .772 r
.67372 .42866 .67927 .44106 .69015 .43444 .68459 .42129 Mtetra
.693 .618 .769 r
.68459 .42129 .69015 .43444 .70106 .42771 .69552 .41486 Mtetra
.672 .612 .78 r
.69552 .41486 .70106 .42771 .712 .42136 .70654 .40969 Mtetra
.638 .614 .809 r
.70654 .40969 .712 .42136 .72304 .41608 .71771 .40635 Mtetra
.604 .636 .856 r
.71771 .40635 .72304 .41608 .73418 .41188 .72901 .40435 Mtetra
.563 .678 .916 r
.72901 .40435 .73418 .41188 .74544 .40887 .74043 .40321 Mtetra
.518 .726 .968 r
.74043 .40321 .74544 .40887 .7568 .40662 .75192 .40235 Mtetra
.505 .78 .994 r
.75192 .40235 .7568 .40662 .76824 .40463 .76345 .40097 Mtetra
.519 .815 .999 r
.76345 .40097 .76824 .40463 .77974 .40263 .77499 .39902 Mtetra
.569 .84 .996 r
.77499 .39902 .77974 .40263 .79126 .40023 .78652 .39626 Mtetra
.614 .843 .987 r
.78652 .39626 .79126 .40023 .8028 .39746 .79806 .3929 Mtetra
.646 .832 .972 r
.79806 .3929 .8028 .39746 .81436 .39426 .80961 .38912 Mtetra
.664 .815 .956 r
.80961 .38912 .81436 .39426 .82594 .39075 .82118 .38506 Mtetra
.67 .797 .942 r
.82118 .38506 .82594 .39075 .83754 .38703 .83278 .38092 Mtetra
.673 .783 .932 r
.83278 .38092 .83754 .38703 .84918 .38315 .84443 .37672 Mtetra
.673 .772 .925 r
.84443 .37672 .84918 .38315 .86086 .3792 .85612 .37252 Mtetra
.67 .763 .92 r
.85612 .37252 .86086 .3792 .87259 .37524 .86786 .36837 Mtetra
.64 .747 .927 r
.23902 .55988 .24535 .5654 .25476 .56281 .24845 .55723 Mtetra
.635 .745 .927 r
.24845 .55723 .25476 .56281 .26421 .56028 .25792 .55467 Mtetra
.631 .744 .929 r
.25792 .55467 .26421 .56028 .27369 .55774 .26741 .5522 Mtetra
.626 .745 .933 r
.26741 .5522 .27369 .55774 .28321 .55516 .27693 .54981 Mtetra
.618 .751 .941 r
.27693 .54981 .28321 .55516 .29277 .5525 .28649 .54754 Mtetra
.617 .766 .951 r
.28649 .54754 .29277 .5525 .30238 .54958 .29608 .54521 Mtetra
.618 .791 .965 r
.29608 .54521 .30238 .54958 .31206 .54626 .30573 .54272 Mtetra
.632 .83 .977 r
.30573 .54272 .31206 .54626 .3218 .54236 .31544 .53976 Mtetra
.659 .875 .979 r
.31544 .53976 .3218 .54236 .33162 .53769 .32523 .53603 Mtetra
.691 .917 .971 r
.32523 .53603 .33162 .53769 .34149 .53245 .33511 .53138 Mtetra
.739 .942 .95 r
.33511 .53138 .34149 .53245 .35142 .52672 .34508 .52557 Mtetra
.766 .941 .938 r
.34508 .52557 .35142 .52672 .36135 .52124 .3551 .51916 Mtetra
.783 .908 .927 r
.3551 .51916 .36135 .52124 .37127 .51658 .36514 .51251 Mtetra
.757 .832 .91 r
.36514 .51251 .37127 .51658 .38115 .51324 .37517 .5066 Mtetra
.698 .735 .88 r
.37517 .5066 .38115 .51324 .391 .51168 .38516 .50219 Mtetra
.636 .641 .838 r
.38516 .50219 .391 .51168 .40085 .51135 .39511 .49943 Mtetra
.577 .567 .806 r
.39511 .49943 .40085 .51135 .41072 .51195 .40503 .49854 Mtetra
.547 .529 .786 r
.40503 .49854 .41072 .51195 .42065 .51265 .41497 .49872 Mtetra
.532 .514 .781 r
.41497 .49872 .42065 .51265 .43065 .51282 .42495 .49944 Mtetra
.533 .523 .79 r
.42495 .49944 .43065 .51282 .44073 .51223 .43499 .50005 Mtetra
.549 .551 .808 r
.43499 .50005 .44073 .51223 .45089 .51065 .44511 .50003 Mtetra
.569 .59 .835 r
.44511 .50003 .45089 .51065 .46111 .5083 .45531 .4993 Mtetra
.594 .639 .865 r
.45531 .4993 .46111 .5083 .47138 .50532 .46557 .49774 Mtetra
.614 .687 .895 r
.46557 .49774 .47138 .50532 .4817 .50195 .47589 .49557 Mtetra
.631 .732 .921 r
.47589 .49557 .4817 .50195 .49206 .49837 .48626 .49289 Mtetra
.64 .769 .941 r
.48626 .49289 .49206 .49837 .50245 .49471 .49668 .48989 Mtetra
.644 .796 .956 r
.49668 .48989 .50245 .49471 .51289 .49108 .50714 .48669 Mtetra
.643 .814 .965 r
.50714 .48669 .51289 .49108 .52336 .48752 .51764 .4834 Mtetra
.641 .825 .971 r
.51764 .4834 .52336 .48752 .53387 .48408 .52819 .48006 Mtetra
.639 .83 .974 r
.52819 .48006 .53387 .48408 .54442 .48076 .53877 .47672 Mtetra
.53877 .47672 .54442 .48076 .55501 .47756 .54939 .47337 Mtetra
.642 .826 .971 r
.54939 .47337 .55501 .47756 .56564 .47448 .56006 .46999 Mtetra
.65 .816 .963 r
.56006 .46999 .56564 .47448 .57632 .47147 .57076 .4665 Mtetra
.662 .802 .95 r
.57076 .4665 .57632 .47147 .58704 .46849 .5815 .46281 Mtetra
.677 .78 .928 r
.5815 .46281 .58704 .46849 .59781 .46544 .59228 .4588 Mtetra
.693 .753 .898 r
.59228 .4588 .59781 .46544 .60861 .46217 .60308 .45427 Mtetra
.705 .72 .862 r
.60308 .45427 .60861 .46217 .61945 .45851 .6139 .44911 Mtetra
.713 .688 .825 r
.6139 .44911 .61945 .45851 .6303 .4542 .62472 .44311 Mtetra
.714 .657 .792 r
.62472 .44311 .6303 .4542 .64117 .44911 .63555 .43637 Mtetra
.712 .632 .767 r
.63555 .43637 .64117 .44911 .65203 .44299 .64637 .42898 Mtetra
.704 .613 .752 r
.64637 .42898 .65203 .44299 .66288 .4361 .65721 .42146 Mtetra
.692 .6 .749 r
.65721 .42146 .66288 .4361 .67372 .42866 .66808 .41448 Mtetra
.677 .598 .76 r
.66808 .41448 .67372 .42866 .68459 .42129 .67902 .40859 Mtetra
.649 .603 .789 r
.67902 .40859 .68459 .42129 .69552 .41486 .6901 .40459 Mtetra
.613 .629 .843 r
.6901 .40459 .69552 .41486 .70654 .40969 .7013 .40229 Mtetra
.543 .673 .922 r
.7013 .40229 .70654 .40969 .71771 .40635 .71265 .40155 Mtetra
.428 .718 .985 r
.71265 .40155 .71771 .40635 .72901 .40435 .72411 .40157 Mtetra
.32 .745 .974 r
.72411 .40157 .72901 .40435 .74043 .40321 .73562 .40135 Mtetra
.296 .762 .943 r
.73562 .40135 .74043 .40321 .75192 .40235 .74717 .40052 Mtetra
.407 .829 .965 r
.74717 .40052 .75192 .40235 .76345 .40097 .75869 .3985 Mtetra
.531 .87 .992 r
.75869 .3985 .76345 .40097 .77499 .39902 .7702 .39552 Mtetra
.624 .868 .988 r
.7702 .39552 .77499 .39902 .78652 .39626 .7817 .39175 Mtetra
.668 .842 .966 r
.7817 .39175 .78652 .39626 .79806 .3929 .7932 .38747 Mtetra
.681 .81 .944 r
.7932 .38747 .79806 .3929 .80961 .38912 .80474 .38303 Mtetra
.684 .787 .928 r
.80474 .38303 .80961 .38912 .82118 .38506 .8163 .37852 Mtetra
.68 .77 .919 r
.8163 .37852 .82118 .38506 .83278 .38092 .82792 .37412 Mtetra
.676 .761 .915 r
.82792 .37412 .83278 .38092 .84443 .37672 .8396 .36981 Mtetra
.673 .757 .914 r
.8396 .36981 .84443 .37672 .85612 .37252 .85132 .36558 Mtetra
.669 .756 .915 r
.85132 .36558 .85612 .37252 .86786 .36837 .8631 .36144 Mtetra
.651 .75 .922 r
.23264 .55431 .23902 .55988 .24845 .55723 .24212 .5514 Mtetra
.647 .741 .917 r
.24212 .5514 .24845 .55723 .25792 .55467 .25162 .54856 Mtetra
.641 .73 .913 r
.25162 .54856 .25792 .55467 .26741 .5522 .26115 .54587 Mtetra
.632 .721 .911 r
.26115 .54587 .26741 .5522 .27693 .54981 .27069 .5434 Mtetra
.618 .714 .914 r
.27069 .5434 .27693 .54981 .28649 .54754 .28025 .54124 Mtetra
.604 .714 .922 r
.28025 .54124 .28649 .54754 .29608 .54521 .28984 .53934 Mtetra
.585 .724 .939 r
.28984 .53934 .29608 .54521 .30573 .54272 .29944 .53773 Mtetra
.576 .755 .963 r
.29944 .53773 .30573 .54272 .31544 .53976 .30909 .53604 Mtetra
.567 .806 .989 r
.30909 .53604 .31544 .53976 .32523 .53603 .31881 .53407 Mtetra
.571 .878 .993 r
.31881 .53407 .32523 .53603 .33511 .53138 .32862 .5312 Mtetra
.595 .935 .948 r
.32862 .5312 .33511 .53138 .34508 .52557 .33854 .52689 Mtetra
.62 .959 .876 r
.33854 .52689 .34508 .52557 .3551 .51916 .34858 .52107 Mtetra
.711 .987 .85 r
.34858 .52107 .3551 .51916 .36514 .51251 .35872 .5135 Mtetra
.787 .992 .883 r
.35872 .5135 .36514 .51251 .37517 .5066 .3689 .50533 Mtetra
.82 .935 .906 r
.3689 .50533 .37517 .5066 .38516 .50219 .37909 .49732 Mtetra
.771 .807 .882 r
.37909 .49732 .38516 .50219 .39511 .49943 .38922 .49064 Mtetra
.684 .677 .837 r
.38922 .49064 .39511 .49943 .40503 .49854 .39929 .48622 Mtetra
.617 .582 .792 r
.39929 .48622 .40503 .49854 .41497 .49872 .40931 .48382 Mtetra
.564 .52 .764 r
.40931 .48382 .41497 .49872 .42495 .49944 .41932 .4834 Mtetra
.54 .494 .753 r
.41932 .4834 .42495 .49944 .43499 .50005 .42935 .48398 Mtetra
.531 .489 .754 r
.42935 .48398 .43499 .50005 .44511 .50003 .43943 .48489 Mtetra
.535 .502 .766 r
.43943 .48489 .44511 .50003 .45531 .4993 .44958 .48559 Mtetra
.55 .53 .785 r
.44958 .48559 .45531 .4993 .46557 .49774 .45981 .48563 Mtetra
.568 .564 .809 r
.45981 .48563 .46557 .49774 .47589 .49557 .47011 .48498 Mtetra
.589 .603 .834 r
.47011 .48498 .47589 .49557 .48626 .49289 .48048 .48358 Mtetra
.608 .64 .857 r
.48048 .48358 .48626 .49289 .49668 .48989 .4909 .4816 Mtetra
.624 .674 .877 r
.4909 .4816 .49668 .48989 .50714 .48669 .50137 .47913 Mtetra
.637 .7 .892 r
.50137 .47913 .50714 .48669 .51764 .4834 .51189 .4763 Mtetra
.647 .719 .901 r
.51189 .4763 .51764 .4834 .52819 .48006 .52246 .47318 Mtetra
.655 .729 .904 r
.52246 .47318 .52819 .48006 .53877 .47672 .53307 .46982 Mtetra
.664 .732 .901 r
.53307 .46982 .53877 .47672 .54939 .47337 .54371 .4662 Mtetra
.672 .728 .891 r
.54371 .4662 .54939 .47337 .56006 .46999 .5544 .4623 Mtetra
.682 .717 .875 r
.5544 .4623 .56006 .46999 .57076 .4665 .56512 .45803 Mtetra
.691 .7 .854 r
.56512 .45803 .57076 .4665 .5815 .46281 .57586 .45326 Mtetra
.698 .678 .827 r
.57586 .45326 .5815 .46281 .59228 .4588 .58663 .4479 Mtetra
.704 .656 .799 r
.58663 .4479 .59228 .4588 .60308 .45427 .59741 .44177 Mtetra
.704 .631 .773 r
.59741 .44177 .60308 .45427 .6139 .44911 .6082 .43494 Mtetra
.703 .61 .75 r
.6082 .43494 .6139 .44911 .62472 .44311 .61899 .42743 Mtetra
.697 .592 .735 r
.61899 .42743 .62472 .44311 .63555 .43637 .62978 .41967 Mtetra
.686 .577 .727 r
.62978 .41967 .63555 .43637 .64637 .42898 .64061 .41225 Mtetra
.671 .569 .731 r
.64061 .41225 .64637 .42898 .65721 .42146 .65149 .40584 Mtetra
.644 .564 .75 r
.65149 .40584 .65721 .42146 .66808 .41448 .66247 .40143 Mtetra
.61 .578 .793 r
.66247 .40143 .66808 .41448 .67902 .40859 .67359 .39909 Mtetra
.532 .607 .873 r
.67359 .39909 .67902 .40859 .6901 .40459 .68488 .39906 Mtetra
.36 .65 .966 r
.68488 .39906 .6901 .40459 .7013 .40229 .69631 .40041 Mtetra
.041 .584 .844 r
.69631 .40041 .7013 .40229 .71265 .40155 .70784 .40195 Mtetra
.138 0 0 r
.70784 .40195 .71265 .40155 .72411 .40157 .7194 .40288 Mtetra
.051 0 0 r
.7194 .40288 .72411 .40157 .73562 .40135 .73094 .40203 Mtetra
.181 .713 .734 r
.73094 .40203 .73562 .40135 .74717 .40052 .74243 .3996 Mtetra
.495 .897 .934 r
.74243 .3996 .74717 .40052 .75869 .3985 .75387 .3957 Mtetra
.663 .909 .979 r
.75387 .3957 .75869 .3985 .7702 .39552 .76529 .39086 Mtetra
.706 .848 .95 r
.76529 .39086 .7702 .39552 .7817 .39175 .77672 .3857 Mtetra
.71 .797 .919 r
.77672 .3857 .7817 .39175 .7932 .38747 .78819 .38047 Mtetra
.697 .761 .901 r
.78819 .38047 .7932 .38747 .80474 .38303 .79971 .37553 Mtetra
.687 .743 .894 r
.79971 .37553 .80474 .38303 .8163 .37852 .8113 .37085 Mtetra
.676 .734 .894 r
.8113 .37085 .8163 .37852 .82792 .37412 .82296 .36649 Mtetra
.668 .733 .898 r
.82296 .36649 .82792 .37412 .8396 .36981 .83468 .36236 Mtetra
.663 .737 .905 r
.83468 .36236 .8396 .36981 .85132 .36558 .84647 .35837 Mtetra
.66 .745 .913 r
.84647 .35837 .85132 .36558 .8631 .36144 .85831 .35446 Mtetra
.667 .754 .916 r
.22623 .54871 .23264 .55431 .24212 .5514 .23575 .5454 Mtetra
.665 .741 .906 r
.23575 .5454 .24212 .5514 .25162 .54856 .24531 .5421 Mtetra
.66 .725 .897 r
.24531 .5421 .25162 .54856 .26115 .54587 .25489 .53893 Mtetra
.65 .708 .89 r
.25489 .53893 .26115 .54587 .27069 .5434 .26449 .53599 Mtetra
.636 .69 .883 r
.26449 .53599 .27069 .5434 .28025 .54124 .2741 .53339 Mtetra
.619 .672 .879 r
.2741 .53339 .28025 .54124 .28984 .53934 .28371 .53122 Mtetra
.596 .657 .88 r
.28371 .53122 .28984 .53934 .29944 .53773 .29332 .52965 Mtetra
.577 .651 .886 r
.29332 .52965 .29944 .53773 .30909 .53604 .30295 .5285 Mtetra
.553 .657 .905 r
.30295 .5285 .30909 .53604 .31881 .53407 .3126 .52776 Mtetra
.551 .699 .938 r
.3126 .52776 .31881 .53407 .32862 .5312 .32231 .52679 Mtetra
.56 .777 .98 r
.32231 .52679 .32862 .5312 .33854 .52689 .33211 .52511 Mtetra
.579 .888 .99 r
.33211 .52511 .33854 .52689 .34858 .52107 .34204 .52198 Mtetra
.595 .949 .894 r
.34204 .52198 .34858 .52107 .35872 .5135 .35211 .51673 Mtetra
.552 .915 .736 r
.35211 .51673 .35872 .5135 .3689 .50533 .3623 .50969 Mtetra
.588 .913 .672 r
.3623 .50969 .3689 .50533 .37909 .49732 .37257 .50099 Mtetra
.663 .956 .733 r
.37257 .50099 .37909 .49732 .38922 .49064 .38286 .49207 Mtetra
.76 .995 .865 r
.38286 .49207 .38922 .49064 .39929 .48622 .39312 .48391 Mtetra
.778 .907 .93 r
.39312 .48391 .39929 .48622 .40931 .48382 .40334 .47729 Mtetra
.697 .744 .888 r
.40334 .47729 .40931 .48382 .41932 .4834 .41349 .47287 Mtetra
.629 .62 .823 r
.41349 .47287 .41932 .4834 .42935 .48398 .42363 .47017 Mtetra
.583 .546 .778 r
.42363 .47017 .42935 .48398 .43943 .48489 .43376 .46897 Mtetra
.564 .51 .754 r
.43376 .46897 .43943 .48489 .44958 .48559 .44393 .46851 Mtetra
.559 .496 .742 r
.44393 .46851 .44958 .48559 .45981 .48563 .45415 .46829 Mtetra
.562 .496 .739 r
.45415 .46829 .45981 .48563 .47011 .48498 .46442 .46792 Mtetra
.572 .505 .742 r
.46442 .46792 .47011 .48498 .48048 .48358 .47477 .4671 Mtetra
.583 .518 .747 r
.47477 .4671 .48048 .48358 .4909 .4816 .48517 .46579 Mtetra
.596 .532 .753 r
.48517 .46579 .4909 .4816 .50137 .47913 .49564 .46391 Mtetra
.608 .545 .759 r
.49564 .46391 .50137 .47913 .51189 .4763 .50615 .4615 Mtetra
.62 .557 .762 r
.50615 .4615 .51189 .4763 .52246 .47318 .51671 .45859 Mtetra
.63 .565 .763 r
.51671 .45859 .52246 .47318 .53307 .46982 .52732 .45519 Mtetra
.639 .57 .761 r
.52732 .45519 .53307 .46982 .54371 .4662 .53797 .45131 Mtetra
.648 .572 .756 r
.53797 .45131 .54371 .4662 .5544 .4623 .54865 .44691 Mtetra
.655 .571 .749 r
.54865 .44691 .5544 .4623 .56512 .45803 .55936 .44199 Mtetra
.661 .568 .74 r
.55936 .44199 .56512 .45803 .57586 .45326 .57009 .43648 Mtetra
.665 .564 .731 r
.57009 .43648 .57586 .45326 .58663 .4479 .58085 .43047 Mtetra
.669 .561 .724 r
.58085 .43047 .58663 .4479 .59741 .44177 .59162 .42399 Mtetra
.669 .559 .721 r
.59162 .42399 .59741 .44177 .6082 .43494 .60241 .41736 Mtetra
.667 .559 .724 r
.60241 .41736 .6082 .43494 .61899 .42743 .61322 .41094 Mtetra
.661 .565 .736 r
.61322 .41094 .61899 .42743 .62978 .41967 .62409 .40528 Mtetra
.644 .578 .766 r
.62409 .40528 .62978 .41967 .64061 .41225 .63503 .40113 Mtetra
.614 .613 .826 r
.63503 .40113 .64061 .41225 .65149 .40584 .64608 .39874 Mtetra
.506 .666 .934 r
.64608 .39874 .65149 .40584 .66247 .40143 .65727 .39859 Mtetra
.147 .632 .92 r
.65727 .39859 .66247 .40143 .67359 .39909 .6686 .40003 Mtetra
.305 0 0 r
.6686 .40003 .67359 .39909 .68488 .39906 .68005 .40228 Mtetra
.405 0 0 r
.68005 .40228 .68488 .39906 .69631 .40041 .69158 .40431 Mtetra
.328 0 0 r
.69158 .40431 .69631 .40041 .70784 .40195 .7031 .40465 Mtetra
.116 0 0 r
.7031 .40465 .70784 .40195 .7194 .40288 .71458 .40316 Mtetra
.361 .833 .829 r
.71458 .40316 .7194 .40288 .73094 .40203 .72599 .39948 Mtetra
.675 .921 .973 r
.72599 .39948 .73094 .40203 .74243 .3996 .73735 .3943 Mtetra
.734 .83 .924 r
.73735 .3943 .74243 .3996 .75387 .3957 .74869 .38838 Mtetra
.731 .762 .878 r
.74869 .38838 .75387 .3957 .76529 .39086 .76005 .3822 Mtetra
.71 .718 .856 r
.76005 .3822 .76529 .39086 .77672 .3857 .77146 .37644 Mtetra
.695 .698 .849 r
.77146 .37644 .77672 .3857 .78819 .38047 .78294 .37111 Mtetra
.679 .69 .853 r
.78294 .37111 .78819 .38047 .79971 .37553 .79452 .36639 Mtetra
.668 .691 .862 r
.79452 .36639 .79971 .37553 .8113 .37085 .80617 .36212 Mtetra
.659 .698 .875 r
.80617 .36212 .8113 .37085 .82296 .36649 .8179 .35821 Mtetra
.652 .708 .888 r
.8179 .35821 .82296 .36649 .83468 .36236 .8297 .35453 Mtetra
.648 .72 .901 r
.8297 .35453 .83468 .36236 .84647 .35837 .84156 .35097 Mtetra
.646 .734 .913 r
.84156 .35097 .84647 .35837 .85831 .35446 .85348 .34743 Mtetra
.681 .757 .909 r
.21976 .54307 .22623 .54871 .23575 .5454 .22935 .53936 Mtetra
.683 .745 .898 r
.22935 .53936 .23575 .5454 .24531 .5421 .23896 .53557 Mtetra
.68 .729 .887 r
.23896 .53557 .24531 .5421 .25489 .53893 .24861 .5318 Mtetra
.674 .71 .875 r
.24861 .5318 .25489 .53893 .26449 .53599 .25828 .52813 Mtetra
.665 .688 .862 r
.25828 .52813 .26449 .53599 .2741 .53339 .26797 .52464 Mtetra
.649 .661 .849 r
.26797 .52464 .2741 .53339 .28371 .53122 .27766 .52156 Mtetra
.627 .632 .837 r
.27766 .52156 .28371 .53122 .29332 .52965 .28734 .51909 Mtetra
.599 .603 .826 r
.28734 .51909 .29332 .52965 .30295 .5285 .29701 .51743 Mtetra
.563 .576 .825 r
.29701 .51743 .30295 .5285 .3126 .52776 .30665 .51685 Mtetra
.532 .564 .833 r
.30665 .51685 .3126 .52776 .32231 .52679 .31629 .51707 Mtetra
.487 .569 .864 r
.31629 .51707 .32231 .52679 .33211 .52511 .32594 .51806 Mtetra
.458 .635 .932 r
.32594 .51806 .33211 .52511 .34204 .52198 .33566 .51872 Mtetra
.398 .761 .993 r
.33566 .51872 .34204 .52198 .35211 .51673 .34551 .51825 Mtetra
.214 .733 .718 r
.34551 .51825 .35211 .51673 .3623 .50969 .35553 .51555 Mtetra
0 0 0 r
.35553 .51555 .3623 .50969 .37257 .50099 .36574 .50972 Mtetra
.36574 .50972 .37257 .50099 .38286 .49207 .37608 .50143 Mtetra
.37608 .50143 .38286 .49207 .39312 .48391 .38651 .49105 Mtetra
.38651 .49105 .39312 .48391 .40334 .47729 .39695 .48038 Mtetra
.744 .986 .774 r
.39695 .48038 .40334 .47729 .41349 .47287 .40734 .47067 Mtetra
.818 .911 .903 r
.40734 .47067 .41349 .47287 .42363 .47017 .41769 .46265 Mtetra
.725 .726 .851 r
.41769 .46265 .42363 .47017 .43376 .46897 .42797 .4569 Mtetra
.654 .607 .79 r
.42797 .4569 .43376 .46897 .44393 .46851 .43823 .45292 Mtetra
.609 .54 .752 r
.43823 .45292 .44393 .46851 .45415 .46829 .44849 .45042 Mtetra
.589 .508 .731 r
.44849 .45042 .45415 .46829 .46442 .46792 .45878 .44871 Mtetra
.581 .493 .72 r
.45878 .44871 .46442 .46792 .47477 .4671 .46911 .44732 Mtetra
.581 .489 .715 r
.46911 .44732 .47477 .4671 .48517 .46579 .4795 .44586 Mtetra
.587 .492 .714 r
.4795 .44586 .48517 .46579 .49564 .46391 .48994 .44405 Mtetra
.595 .498 .714 r
.48994 .44405 .49564 .46391 .50615 .4615 .50043 .44178 Mtetra
.605 .505 .714 r
.50043 .44178 .50615 .4615 .51671 .45859 .51098 .43893 Mtetra
.615 .512 .714 r
.51098 .43893 .51671 .45859 .52732 .45519 .52157 .4355 Mtetra
.624 .517 .712 r
.52157 .4355 .52732 .45519 .53797 .45131 .5322 .43147 Mtetra
.632 .521 .71 r
.5322 .43147 .53797 .45131 .54865 .44691 .54286 .42687 Mtetra
.638 .524 .708 r
.54286 .42687 .54865 .44691 .55936 .44199 .55356 .4218 Mtetra
.642 .525 .706 r
.55356 .4218 .55936 .44199 .57009 .43648 .56428 .41637 Mtetra
.643 .527 .706 r
.56428 .41637 .57009 .43648 .58085 .43047 .57503 .41087 Mtetra
.641 .529 .711 r
.57503 .41087 .58085 .43047 .59162 .42399 .58581 .40567 Mtetra
.633 .534 .724 r
.58581 .40567 .59162 .42399 .60241 .41736 .59664 .40127 Mtetra
.614 .543 .751 r
.59664 .40127 .60241 .41736 .61322 .41094 .60755 .39837 Mtetra
.577 .568 .807 r
.60755 .39837 .61322 .41094 .62409 .40528 .61856 .39727 Mtetra
.448 .607 .914 r
.61856 .39727 .62409 .40528 .63503 .40113 .6297 .3985 Mtetra
0 .494 .819 r
.6297 .3985 .63503 .40113 .64608 .39874 .64099 .40146 Mtetra
.496 0 0 r
.64099 .40146 .64608 .39874 .65727 .39859 .6524 .40542 Mtetra
.541 .071 .088 r
.6524 .40542 .65727 .39859 .6686 .40003 .6639 .40911 Mtetra
.49 .055 .138 r
.6639 .40911 .6686 .40003 .68005 .40228 .6754 .41069 Mtetra
.391 0 .068 r
.6754 .41069 .68005 .40228 .69158 .40431 .68685 .40976 Mtetra
.097 0 0 r
.68685 .40976 .69158 .40431 .7031 .40465 .6982 .40559 Mtetra
.547 .927 .815 r
.6982 .40559 .7031 .40465 .71458 .40316 .70945 .39914 Mtetra
.789 .888 .916 r
.70945 .39914 .71458 .40316 .72599 .39948 .72067 .39149 Mtetra
.766 .754 .842 r
.72067 .39149 .72599 .39948 .73735 .3943 .73187 .3835 Mtetra
.724 .677 .804 r
.73187 .3835 .73735 .3943 .74869 .38838 .74315 .37627 Mtetra
.698 .644 .792 r
.74315 .37627 .74869 .38838 .76005 .3822 .75451 .36988 Mtetra
.675 .63 .797 r
.75451 .36988 .76005 .3822 .77146 .37644 .76598 .36459 Mtetra
.659 .63 .81 r
.76598 .36459 .77146 .37644 .78294 .37111 .77755 .36014 Mtetra
.648 .641 .83 r
.77755 .36014 .78294 .37111 .79452 .36639 .78921 .35632 Mtetra
.639 .657 .851 r
.78921 .35632 .79452 .36639 .80617 .36212 .80097 .35292 Mtetra
.636 .676 .872 r
.80097 .35292 .80617 .36212 .8179 .35821 .81279 .3497 Mtetra
.632 .694 .89 r
.81279 .3497 .8179 .35821 .8297 .35453 .82468 .3466 Mtetra
.631 .711 .905 r
.82468 .3466 .8297 .35453 .84156 .35097 .83662 .34352 Mtetra
.632 .728 .917 r
.83662 .34352 .84156 .35097 .85348 .34743 .84861 .34035 Mtetra
.684 .758 .907 r
.21326 .53739 .21976 .54307 .22935 .53936 .22287 .53357 Mtetra
.689 .756 .903 r
.22287 .53357 .22935 .53936 .23896 .53557 .23252 .52961 Mtetra
.692 .751 .897 r
.23252 .52961 .23896 .53557 .24861 .5318 .24222 .52553 Mtetra
.693 .742 .889 r
.24222 .52553 .24861 .5318 .25828 .52813 .25194 .52137 Mtetra
.693 .728 .877 r
.25194 .52137 .25828 .52813 .26797 .52464 .26171 .51712 Mtetra
.685 .705 .863 r
.26171 .51712 .26797 .52464 .27766 .52156 .27149 .51301 Mtetra
.671 .675 .846 r
.27149 .51301 .27766 .52156 .28734 .51909 .28129 .50917 Mtetra
.646 .637 .826 r
.28129 .50917 .28734 .51909 .29701 .51743 .29106 .506 Mtetra
.613 .594 .808 r
.29106 .506 .29701 .51743 .30665 .51685 .30081 .50382 Mtetra
.576 .551 .789 r
.30081 .50382 .30665 .51685 .31629 .51707 .31052 .50287 Mtetra
.531 .51 .778 r
.31052 .50287 .31629 .51707 .32594 .51806 .32018 .50345 Mtetra
.502 .488 .775 r
.32018 .50345 .32594 .51806 .33566 .51872 .32985 .505 Mtetra
.473 .485 .79 r
.32985 .505 .33566 .51872 .34551 .51825 .33954 .50718 Mtetra
.48 .537 .838 r
.33954 .50718 .34551 .51825 .35553 .51555 .34935 .5086 Mtetra
.523 .671 .93 r
.34935 .5086 .35553 .51555 .36574 .50972 .35931 .50817 Mtetra
.537 .884 .984 r
.35931 .50817 .36574 .50972 .37608 .50143 .36944 .50522 Mtetra
.37 .8 .623 r
.36944 .50522 .37608 .50143 .38651 .49105 .37975 .49916 Mtetra
0 0 0 r
.37975 .49916 .38651 .49105 .39695 .48038 .39017 .49102 Mtetra
.39017 .49102 .39695 .48038 .40734 .47067 .40065 .48146 Mtetra
.40065 .48146 .40734 .47067 .41769 .46265 .41113 .47179 Mtetra
.41113 .47179 .41769 .46265 .42797 .4569 .42159 .46291 Mtetra
.42159 .46291 .42797 .4569 .43823 .45292 .43202 .45518 Mtetra
.53 .914 .776 r
.43202 .45518 .43823 .45292 .44849 .45042 .44242 .4489 Mtetra
.689 .934 .966 r
.44242 .4489 .44849 .45042 .45878 .44871 .45282 .44375 Mtetra
.688 .804 .937 r
.45282 .44375 .45878 .44871 .46911 .44732 .46324 .43955 Mtetra
.663 .705 .878 r
.46324 .43955 .46911 .44732 .4795 .44586 .47367 .4359 Mtetra
.646 .645 .835 r
.47367 .4359 .4795 .44586 .48994 .44405 .48414 .43256 Mtetra
.638 .613 .809 r
.48414 .43256 .48994 .44405 .50043 .44178 .49466 .42929 Mtetra
.635 .596 .793 r
.49466 .42929 .50043 .44178 .51098 .43893 .50521 .42596 Mtetra
.636 .59 .785 r
.50521 .42596 .51098 .43893 .52157 .4355 .5158 .4225 Mtetra
.639 .591 .785 r
.5158 .4225 .52157 .4355 .5322 .43147 .52644 .4189 Mtetra
.642 .6 .791 r
.52644 .4189 .5322 .43147 .54286 .42687 .53712 .41523 Mtetra
.644 .616 .807 r
.53712 .41523 .54286 .42687 .55356 .4218 .54783 .41165 Mtetra
.642 .644 .836 r
.54783 .41165 .55356 .4218 .56428 .41637 .5586 .40836 Mtetra
.628 .691 .89 r
.5586 .40836 .56428 .41637 .57503 .41087 .56941 .40565 Mtetra
.56 .762 .972 r
.56941 .40565 .57503 .41087 .58581 .40567 .58029 .40388 Mtetra
.269 .747 .933 r
.58029 .40388 .58581 .40567 .59664 .40127 .59125 .40327 Mtetra
.267 0 0 r
.59125 .40327 .59664 .40127 .60755 .39837 .6023 .40414 Mtetra
.472 0 .005 r
.6023 .40414 .60755 .39837 .61856 .39727 .61346 .4062 Mtetra
.53 .093 .155 r
.61346 .4062 .61856 .39727 .6297 .3985 .62474 .40909 Mtetra
.533 .117 .198 r
.62474 .40909 .6297 .3985 .64099 .40146 .63609 .41188 Mtetra
.492 .074 .175 r
.63609 .41188 .64099 .40146 .6524 .40542 .64749 .41323 Mtetra
.384 0 .039 r
.64749 .41323 .6524 .40542 .6639 .40911 .65887 .41248 Mtetra
0 0 0 r
.65887 .41248 .6639 .40911 .6754 .41069 .67018 .40854 Mtetra
.734 .945 .95 r
.67018 .40854 .6754 .41069 .68685 .40976 .68141 .40201 Mtetra
.777 .762 .839 r
.68141 .40201 .68685 .40976 .6982 .40559 .69256 .39356 Mtetra
.747 .666 .771 r
.69256 .39356 .6982 .40559 .70945 .39914 .70368 .3843 Mtetra
.714 .615 .746 r
.70368 .3843 .70945 .39914 .72067 .39149 .71484 .37568 Mtetra
.693 .595 .741 r
.71484 .37568 .72067 .39149 .73187 .3835 .72608 .36804 Mtetra
.671 .586 .752 r
.72608 .36804 .73187 .3835 .74315 .37627 .73744 .36197 Mtetra
.654 .592 .772 r
.73744 .36197 .74315 .37627 .75451 .36988 .74892 .35717 Mtetra
.64 .607 .8 r
.74892 .35717 .75451 .36988 .76598 .36459 .76052 .3534 Mtetra
.628 .628 .831 r
.76052 .3534 .76598 .36459 .77755 .36014 .77222 .35031 Mtetra
.622 .655 .861 r
.77222 .35031 .77755 .36014 .78921 .35632 .78399 .34751 Mtetra
.617 .679 .886 r
.78399 .34751 .78921 .35632 .80097 .35292 .79584 .34486 Mtetra
.619 .702 .904 r
.79584 .34486 .80097 .35292 .81279 .3497 .80773 .3421 Mtetra
.62 .718 .916 r
.80773 .3421 .81279 .3497 .82468 .3466 .81968 .33927 Mtetra
.623 .728 .922 r
.81968 .33927 .82468 .3466 .83662 .34352 .83167 .33631 Mtetra
.628 .736 .925 r
.83167 .33631 .83662 .34352 .84861 .34035 .8437 .33321 Mtetra
.675 .756 .912 r
.20671 .53168 .21326 .53739 .22287 .53357 .21632 .52809 Mtetra
.681 .766 .915 r
.21632 .52809 .22287 .53357 .23252 .52961 .22597 .52434 Mtetra
.689 .776 .918 r
.22597 .52434 .23252 .52961 .24222 .52553 .23568 .52039 Mtetra
.699 .783 .916 r
.23568 .52039 .24222 .52553 .25194 .52137 .24544 .51615 Mtetra
.711 .783 .908 r
.24544 .51615 .25194 .52137 .26171 .51712 .25525 .51155 Mtetra
.718 .772 .896 r
.25525 .51155 .26171 .51712 .27149 .51301 .26512 .50667 Mtetra
.721 .749 .875 r
.26512 .50667 .27149 .51301 .28129 .50917 .27503 .5015 Mtetra
.71 .711 .849 r
.27503 .5015 .28129 .50917 .29106 .506 .28496 .49639 Mtetra
.689 .661 .817 r
.28496 .49639 .29106 .506 .30081 .50382 .2949 .49154 Mtetra
.654 .601 .783 r
.2949 .49154 .30081 .50382 .31052 .50287 .30481 .48756 Mtetra
.613 .543 .752 r
.30481 .48756 .31052 .50287 .32018 .50345 .31467 .48493 Mtetra
.568 .488 .724 r
.31467 .48493 .32018 .50345 .32985 .505 .32445 .48415 Mtetra
.519 .44 .707 r
.32445 .48415 .32985 .505 .33954 .50718 .33414 .48572 Mtetra
.479 .411 .702 r
.33414 .48572 .33954 .50718 .34935 .5086 .34381 .48908 Mtetra
.43 .394 .718 r
.34381 .48908 .34935 .5086 .35931 .50817 .35348 .49389 Mtetra
.386 .428 .782 r
.35348 .49389 .35931 .50817 .36944 .50522 .36325 .49831 Mtetra
.288 .559 .928 r
.36325 .49831 .36944 .50522 .37975 .49916 .37319 .50094 Mtetra
.145 0 0 r
.37319 .50094 .37975 .49916 .39017 .49102 .38333 .50069 Mtetra
.252 0 .027 r
.38333 .50069 .39017 .49102 .40065 .48146 .39367 .49672 Mtetra
.263 0 .163 r
.39367 .49672 .40065 .48146 .41113 .47179 .40415 .48995 Mtetra
.239 0 .195 r
.40415 .48995 .41113 .47179 .42159 .46291 .41472 .48096 Mtetra
.207 0 .18 r
.41472 .48096 .42159 .46291 .43202 .45518 .42532 .47115 Mtetra
.162 0 .13 r
.42532 .47115 .43202 .45518 .44242 .4489 .43591 .46148 Mtetra
.082 0 .025 r
.43591 .46148 .44242 .4489 .45282 .44375 .44649 .45252 Mtetra
0 0 0 r
.44649 .45252 .45282 .44375 .46324 .43955 .45705 .4447 Mtetra
.45705 .4447 .46324 .43955 .47367 .4359 .46761 .43793 Mtetra
.476 .888 .77 r
.46761 .43793 .47367 .4359 .48414 .43256 .47817 .43221 Mtetra
.601 .942 .937 r
.47817 .43221 .48414 .43256 .49466 .42929 .48874 .42734 Mtetra
.627 .91 .982 r
.48874 .42734 .49466 .42929 .50521 .42596 .49934 .4232 Mtetra
.611 .877 .991 r
.49934 .4232 .50521 .42596 .5158 .4225 .50997 .41971 Mtetra
.563 .86 .997 r
.50997 .41971 .5158 .4225 .52644 .4189 .52065 .41688 Mtetra
.453 .841 .983 r
.52065 .41688 .52644 .4189 .53712 .41523 .53137 .41479 Mtetra
.205 .729 .842 r
.53137 .41479 .53712 .41523 .54783 .41165 .54215 .41356 Mtetra
.163 0 0 r
.54215 .41356 .54783 .41165 .5586 .40836 .55299 .41338 Mtetra
.4 0 0 r
.55299 .41338 .5586 .40836 .56941 .40565 .56392 .41429 Mtetra
.504 .063 .134 r
.56392 .41429 .56941 .40565 .58029 .40388 .57493 .41636 Mtetra
.539 .144 .241 r
.57493 .41636 .58029 .40388 .59125 .40327 .58604 .41917 Mtetra
.546 .179 .295 r
.58604 .41917 .59125 .40327 .6023 .40414 .59724 .42214 Mtetra
.533 .179 .314 r
.59724 .42214 .6023 .40414 .61346 .4062 .60851 .42431 Mtetra
.491 .142 .3 r
.60851 .42431 .61346 .4062 .62474 .40909 .6198 .42423 Mtetra
.408 .044 .232 r
.6198 .42423 .62474 .40909 .63609 .41188 .63107 .4213 Mtetra
.129 0 0 r
.63107 .4213 .63609 .41188 .64749 .41323 .64225 .41457 Mtetra
.74 .99 .803 r
.64225 .41457 .64749 .41323 .65887 .41248 .65334 .40487 Mtetra
.828 .775 .802 r
.65334 .40487 .65887 .41248 .67018 .40854 .66434 .39332 Mtetra
.753 .63 .724 r
.66434 .39332 .67018 .40854 .68141 .40201 .67532 .38134 Mtetra
.7 .561 .694 r
.67532 .38134 .68141 .40201 .69256 .39356 .68636 .37082 Mtetra
.67 .531 .687 r
.68636 .37082 .69256 .39356 .70368 .3843 .69749 .36211 Mtetra
.643 .518 .696 r
.69749 .36211 .70368 .3843 .71484 .37568 .70878 .35582 Mtetra
.625 .522 .717 r
.70878 .35582 .71484 .37568 .72608 .36804 .72021 .35143 Mtetra
.611 .542 .752 r
.72021 .35143 .72608 .36804 .73744 .36197 .73177 .34844 Mtetra
.598 .573 .796 r
.73177 .34844 .73744 .36197 .74892 .35717 .74345 .34634 Mtetra
.592 .617 .846 r
.74345 .34634 .74892 .35717 .76052 .3534 .75521 .34453 Mtetra
.585 .662 .891 r
.75521 .34453 .76052 .3534 .77222 .35031 .76704 .34277 Mtetra
.589 .705 .923 r
.76704 .34277 .77222 .35031 .78399 .34751 .77891 .34073 Mtetra
.595 .734 .941 r
.77891 .34073 .78399 .34751 .79584 .34486 .79081 .33839 Mtetra
.608 .752 .947 r
.79081 .33839 .79584 .34486 .80773 .3421 .80275 .33566 Mtetra
.62 .759 .945 r
.80275 .33566 .80773 .3421 .81968 .33927 .81472 .33265 Mtetra
.629 .758 .94 r
.81472 .33265 .81968 .33927 .83167 .33631 .82672 .32942 Mtetra
.636 .752 .932 r
.82672 .32942 .83167 .33631 .8437 .33321 .83876 .32602 Mtetra
.652 .751 .922 r
.20012 .52592 .20671 .53168 .21632 .52809 .20969 .52287 Mtetra
.655 .771 .935 r
.20969 .52287 .21632 .52809 .22597 .52434 .21932 .51972 Mtetra
.662 .796 .946 r
.21932 .51972 .22597 .52434 .23568 .52039 .22899 .51635 Mtetra
.674 .821 .954 r
.22899 .51635 .23568 .52039 .24544 .51615 .23873 .51265 Mtetra
.691 .846 .957 r
.23873 .51265 .24544 .51615 .25525 .51155 .24854 .50848 Mtetra
.712 .866 .955 r
.24854 .50848 .25525 .51155 .26512 .50667 .25842 .50379 Mtetra
.737 .876 .945 r
.25842 .50379 .26512 .50667 .27503 .5015 .26838 .49846 Mtetra
.755 .871 .932 r
.26838 .49846 .27503 .5015 .28496 .49639 .2784 .49263 Mtetra
.768 .845 .91 r
.2784 .49263 .28496 .49639 .2949 .49154 .28847 .48634 Mtetra
.756 .794 .884 r
.28847 .48634 .2949 .49154 .30481 .48756 .29856 .48012 Mtetra
.727 .724 .847 r
.29856 .48012 .30481 .48756 .31467 .48493 .30863 .47431 Mtetra
.675 .639 .806 r
.30863 .47431 .31467 .48493 .32445 .48415 .31866 .46976 Mtetra
.614 .555 .765 r
.31866 .46976 .32445 .48415 .33414 .48572 .32859 .46716 Mtetra
.558 .482 .726 r
.32859 .46716 .33414 .48572 .34381 .48908 .33844 .46682 Mtetra
.505 .423 .697 r
.33844 .46682 .34381 .48908 .35348 .49389 .3482 .46911 Mtetra
.479 .392 .68 r
.3482 .46911 .35348 .49389 .36325 .49831 .35795 .47295 Mtetra
.464 .38 .676 r
.35795 .47295 .36325 .49831 .37319 .50094 .36774 .47761 Mtetra
.472 .397 .69 r
.36774 .47761 .37319 .50094 .38333 .50069 .37766 .48157 Mtetra
.501 .445 .726 r
.37766 .48157 .38333 .50069 .39367 .49672 .38773 .48366 Mtetra
.546 .541 .801 r
.38773 .48366 .39367 .49672 .40415 .48995 .39797 .48357 Mtetra
.623 .736 .928 r
.39797 .48357 .40415 .48995 .41472 .48096 .40835 .48096 Mtetra
.546 .923 .924 r
.40835 .48096 .41472 .48096 .42532 .47115 .41883 .47658 Mtetra
0 0 0 r
.41883 .47658 .42532 .47115 .43591 .46148 .42938 .4709 Mtetra
.102 0 0 r
.42938 .4709 .43591 .46148 .44649 .45252 .43998 .46465 Mtetra
.209 0 .074 r
.43998 .46465 .44649 .45252 .45705 .4447 .45059 .45837 Mtetra
.266 0 .136 r
.45059 .45837 .45705 .4447 .46761 .43793 .46123 .45237 Mtetra
.305 0 .17 r
.46123 .45237 .46761 .43793 .47817 .43221 .47188 .44692 Mtetra
.333 0 .189 r
.47188 .44692 .47817 .43221 .48874 .42734 .48255 .44208 Mtetra
.358 0 .201 r
.48255 .44208 .48874 .42734 .49934 .4232 .49325 .43791 Mtetra
.38 .013 .211 r
.49325 .43791 .49934 .4232 .50997 .41971 .50398 .43442 Mtetra
.401 .033 .22 r
.50398 .43442 .50997 .41971 .52065 .41688 .51475 .43161 Mtetra
.422 .052 .229 r
.51475 .43161 .52065 .41688 .53137 .41479 .52556 .42947 Mtetra
.439 .067 .235 r
.52556 .42947 .53137 .41479 .54215 .41356 .53644 .42795 Mtetra
.452 .077 .236 r
.53644 .42795 .54215 .41356 .55299 .41338 .54737 .42698 Mtetra
.454 .072 .223 r
.54737 .42698 .55299 .41338 .56392 .41429 .55836 .42632 Mtetra
.441 .042 .186 r
.55836 .42632 .56392 .41429 .57493 .41636 .56942 .42563 Mtetra
.385 0 .086 r
.56942 .42563 .57493 .41636 .58604 .41917 .58054 .42438 Mtetra
.176 0 0 r
.58054 .42438 .58604 .41917 .59724 .42214 .59168 .42182 Mtetra
.513 .91 .916 r
.59168 .42182 .59724 .42214 .60851 .42431 .60284 .41744 Mtetra
.753 .777 .872 r
.60284 .41744 .60851 .42431 .6198 .42423 .61397 .41051 Mtetra
.731 .635 .752 r
.61397 .41051 .6198 .42423 .63107 .4213 .62504 .40132 Mtetra
.71 .571 .696 r
.62504 .40132 .63107 .4213 .64225 .41457 .63606 .39022 Mtetra
.694 .539 .671 r
.63606 .39022 .64225 .41457 .65334 .40487 .64704 .37837 Mtetra
.678 .52 .664 r
.64704 .37837 .65334 .40487 .66434 .39332 .65805 .36732 Mtetra
.665 .513 .669 r
.65805 .36732 .66434 .39332 .67532 .38134 .66912 .35785 Mtetra
.645 .512 .687 r
.66912 .35785 .67532 .38134 .68636 .37082 .68032 .35106 Mtetra
.626 .523 .717 r
.68032 .35106 .68636 .37082 .69749 .36211 .69167 .34659 Mtetra
.603 .548 .766 r
.69167 .34659 .69749 .36211 .70878 .35582 .70318 .34413 Mtetra
.573 .59 .832 r
.70318 .34413 .70878 .35582 .72021 .35143 .71482 .34296 Mtetra
.542 .651 .906 r
.71482 .34296 .72021 .35143 .73177 .34844 .72655 .34224 Mtetra
.502 .71 .964 r
.72655 .34224 .73177 .34844 .74345 .34634 .73836 .34159 Mtetra
.487 .762 .992 r
.73836 .34159 .74345 .34634 .75521 .34453 .75021 .34047 Mtetra
.493 .796 .999 r
.75021 .34047 .75521 .34453 .76704 .34277 .76209 .33884 Mtetra
.532 .82 .999 r
.76209 .33884 .76704 .34277 .77891 .34073 .77399 .33654 Mtetra
.573 .829 .994 r
.77399 .33654 .77891 .34073 .79081 .33839 .7859 .3337 Mtetra
.611 .825 .982 r
.7859 .3337 .79081 .33839 .80275 .33566 .79783 .33037 Mtetra
.636 .812 .967 r
.79783 .33037 .80275 .33566 .81472 .33265 .80978 .3267 Mtetra
.651 .793 .95 r
.80978 .3267 .81472 .33265 .82672 .32942 .82176 .32279 Mtetra
.658 .772 .934 r
.82176 .32279 .82672 .32942 .83876 .32602 .83378 .31877 Mtetra
.621 .742 .933 r
.19348 .52013 .20012 .52592 .20969 .52287 .20301 .51774 Mtetra
.615 .766 .952 r
.20301 .51774 .20969 .52287 .21932 .51972 .21258 .51534 Mtetra
.613 .795 .969 r
.21258 .51534 .21932 .51972 .22899 .51635 .2222 .51282 Mtetra
.612 .83 .983 r
.2222 .51282 .22899 .51635 .23873 .51265 .23189 .51006 Mtetra
.611 .867 .991 r
.23189 .51006 .23873 .51265 .24854 .50848 .24164 .50695 Mtetra
.612 .905 .985 r
.24164 .50695 .24854 .50848 .25842 .50379 .25147 .50332 Mtetra
.617 .935 .961 r
.25147 .50332 .25842 .50379 .26838 .49846 .26139 .49898 Mtetra
.625 .954 .924 r
.26139 .49898 .26838 .49846 .2784 .49263 .2714 .49385 Mtetra
.657 .97 .894 r
.2714 .49385 .2784 .49263 .28847 .48634 .2815 .48776 Mtetra
.704 .983 .884 r
.2815 .48776 .28847 .48634 .29856 .48012 .29169 .48083 Mtetra
.778 .985 .9 r
.29169 .48083 .29856 .48012 .30863 .47431 .30194 .47307 Mtetra
.821 .934 .905 r
.30194 .47307 .30863 .47431 .31866 .46976 .31223 .46493 Mtetra
.802 .811 .859 r
.31223 .46493 .31866 .46976 .32859 .46716 .32254 .4567 Mtetra
.731 .665 .785 r
.32254 .4567 .32859 .46716 .33844 .46682 .3328 .44931 Mtetra
.659 .551 .721 r
.3328 .44931 .33844 .46682 .3482 .46911 .34299 .44349 Mtetra
.598 .467 .673 r
.34299 .44349 .3482 .46911 .35795 .47295 .35307 .44019 Mtetra
.549 .41 .644 r
.35307 .44019 .35795 .47295 .36774 .47761 .36302 .44014 Mtetra
.515 .375 .628 r
.36302 .44014 .36774 .47761 .37766 .48157 .3729 .44292 Mtetra
.485 .351 .623 r
.3729 .44292 .37766 .48157 .38773 .48366 .38275 .44826 Mtetra
.466 .346 .632 r
.38275 .44826 .38773 .48366 .39797 .48357 .39265 .45454 Mtetra
.451 .356 .657 r
.39265 .45454 .39797 .48357 .40835 .48096 .40266 .46058 Mtetra
.436 .395 .714 r
.40266 .46058 .40835 .48096 .41883 .47658 .41281 .46537 Mtetra
.412 .505 .844 r
.41281 .46537 .41883 .47658 .42938 .4709 .42312 .46815 Mtetra
.171 .656 .925 r
.42312 .46815 .42938 .4709 .43998 .46465 .43356 .46906 Mtetra
.252 0 0 r
.43356 .46906 .43998 .46465 .45059 .45837 .44411 .46817 Mtetra
.352 0 .082 r
.44411 .46817 .45059 .45837 .46123 .45237 .45474 .46608 Mtetra
.382 .002 .188 r
.45474 .46608 .46123 .45237 .47188 .44692 .46544 .46316 Mtetra
.397 .039 .236 r
.46544 .46316 .47188 .44692 .48255 .44208 .47619 .45983 Mtetra
.407 .059 .26 r
.47619 .45983 .48255 .44208 .49325 .43791 .48699 .45635 Mtetra
.412 .069 .27 r
.48699 .45635 .49325 .43791 .50398 .43442 .49783 .45286 Mtetra
.49783 .45286 .50398 .43442 .51475 .43161 .50871 .44934 Mtetra
.403 .056 .258 r
.50871 .44934 .51475 .43161 .52556 .42947 .51964 .44568 Mtetra
.378 .021 .228 r
.51964 .44568 .52556 .42947 .53644 .42795 .5306 .4416 Mtetra
.315 0 .158 r
.5306 .4416 .53644 .42795 .54737 .42698 .54161 .43669 Mtetra
.148 0 0 r
.54161 .43669 .54737 .42698 .55836 .42632 .55264 .43055 Mtetra
0 0 0 r
.55264 .43055 .55836 .42632 .56942 .42563 .56367 .42259 Mtetra
.847 .908 .877 r
.56367 .42259 .56942 .42563 .58054 .42438 .57469 .41272 Mtetra
.784 .684 .753 r
.57469 .41272 .58054 .42438 .59168 .42182 .58567 .40079 Mtetra
.725 .572 .683 r
.58567 .40079 .59168 .42182 .60284 .41744 .59661 .38754 Mtetra
.685 .513 .648 r
.59661 .38754 .60284 .41744 .61397 .41051 .60752 .37403 Mtetra
.658 .479 .631 r
.60752 .37403 .61397 .41051 .62504 .40132 .61843 .36144 Mtetra
.631 .454 .625 r
.61843 .36144 .62504 .40132 .63606 .39022 .62941 .35143 Mtetra
.611 .442 .629 r
.62941 .35143 .63606 .39022 .64704 .37837 .6405 .34429 Mtetra
.588 .438 .644 r
.6405 .34429 .64704 .37837 .65805 .36732 .65174 .34048 Mtetra
.566 .447 .676 r
.65174 .34048 .65805 .36732 .66912 .35785 .66314 .33925 Mtetra
.54 .481 .738 r
.66314 .33925 .66912 .35785 .68032 .35106 .67468 .33964 Mtetra
.488 .549 .845 r
.67468 .33964 .68032 .35106 .69167 .34659 .68634 .3409 Mtetra
.361 .655 .968 r
.68634 .3409 .69167 .34659 .70318 .34413 .69808 .3421 Mtetra
.125 .646 .885 r
.69808 .3421 .70318 .34413 .71482 .34296 .70988 .34291 Mtetra
.009 .584 .715 r
.70988 .34291 .71482 .34296 .72655 .34224 .72172 .34288 Mtetra
0 0 0 r
.72172 .34288 .72655 .34224 .73836 .34159 .73357 .34198 Mtetra
.15 .692 .745 r
.73357 .34198 .73836 .34159 .75021 .34047 .74543 .3401 Mtetra
.312 .802 .858 r
.74543 .3401 .75021 .34047 .76209 .33884 .75729 .3374 Mtetra
.474 .879 .951 r
.75729 .3374 .76209 .33884 .77399 .33654 .76915 .33396 Mtetra
.583 .897 .986 r
.76915 .33396 .77399 .33654 .7859 .3337 .78102 .32996 Mtetra
.642 .878 .985 r
.78102 .32996 .7859 .3337 .79783 .33037 .79291 .3256 Mtetra
.671 .848 .967 r
.79291 .3256 .79783 .33037 .80978 .3267 .80482 .32099 Mtetra
.682 .816 .947 r
.80482 .32099 .80978 .3267 .82176 .32279 .81677 .31623 Mtetra
.684 .787 .928 r
.81677 .31623 .82176 .32279 .83378 .31877 .82876 .31146 Mtetra
.6 .736 .94 r
.18679 .51429 .19348 .52013 .20301 .51774 .1963 .51229 Mtetra
.59 .748 .952 r
.1963 .51229 .20301 .51774 .21258 .51534 .20585 .51037 Mtetra
.581 .764 .966 r
.20585 .51037 .21258 .51534 .2222 .51282 .21543 .50848 Mtetra
.572 .787 .98 r
.21543 .50848 .2222 .51282 .23189 .51006 .22506 .50653 Mtetra
.555 .815 .994 r
.22506 .50653 .23189 .51006 .24164 .50695 .23475 .50451 Mtetra
.536 .851 .998 r
.23475 .50451 .24164 .50695 .25147 .50332 .2445 .50219 Mtetra
.502 .879 .974 r
.2445 .50219 .25147 .50332 .26139 .49898 .25432 .49944 Mtetra
.451 .881 .896 r
.25432 .49944 .26139 .49898 .2714 .49385 .26424 .496 Mtetra
.393 .845 .769 r
.26424 .496 .2714 .49385 .2815 .48776 .27427 .49163 Mtetra
.341 .786 .627 r
.27427 .49163 .2815 .48776 .29169 .48083 .2844 .48615 Mtetra
0 0 0 r
.2844 .48615 .29169 .48083 .30194 .47307 .29466 .47936 Mtetra
.29466 .47936 .30194 .47307 .31223 .46493 .30501 .47134 Mtetra
.30501 .47134 .31223 .46493 .32254 .4567 .31545 .46211 Mtetra
.596 .903 .632 r
.31545 .46211 .32254 .4567 .3328 .44931 .32591 .4524 Mtetra
.758 .992 .793 r
.32591 .4524 .3328 .44931 .34299 .44349 .33638 .44276 Mtetra
.822 .955 .903 r
.33638 .44276 .34299 .44349 .35307 .44019 .34677 .43438 Mtetra
.75 .783 .88 r
.34677 .43438 .35307 .44019 .36302 .44014 .35706 .42816 Mtetra
.647 .608 .796 r
.35706 .42816 .36302 .44014 .3729 .44292 .36725 .42444 Mtetra
.568 .49 .728 r
.36725 .42444 .3729 .44292 .38275 .44826 .37735 .42352 Mtetra
.531 .428 .682 r
.37735 .42352 .38275 .44826 .39265 .45454 .38742 .4245 Mtetra
.514 .395 .655 r
.38742 .4245 .39265 .45454 .40266 .46058 .39751 .42679 Mtetra
.514 .384 .641 r
.39751 .42679 .40266 .46058 .41281 .46537 .40766 .4294 Mtetra
.521 .383 .634 r
.40766 .4294 .41281 .46537 .42312 .46815 .41791 .4316 Mtetra
.53 .389 .634 r
.41791 .4316 .42312 .46815 .43356 .46906 .42825 .43303 Mtetra
.542 .399 .636 r
.42825 .43303 .43356 .46906 .44411 .46817 .43869 .43341 Mtetra
.554 .41 .64 r
.43869 .43341 .44411 .46817 .45474 .46608 .44922 .43284 Mtetra
.565 .422 .646 r
.44922 .43284 .45474 .46608 .46544 .46316 .45983 .43134 Mtetra
.575 .433 .651 r
.45983 .43134 .46544 .46316 .47619 .45983 .47051 .42907 Mtetra
.584 .443 .655 r
.47051 .42907 .47619 .45983 .48699 .45635 .48125 .42614 Mtetra
.591 .45 .657 r
.48125 .42614 .48699 .45635 .49783 .45286 .49204 .4226 Mtetra
.598 .454 .657 r
.49204 .4226 .49783 .45286 .50871 .44934 .50287 .41845 Mtetra
.604 .456 .654 r
.50287 .41845 .50871 .44934 .51964 .44568 .51375 .41361 Mtetra
.61 .457 .649 r
.51375 .41361 .51964 .44568 .5306 .4416 .52466 .40801 Mtetra
.616 .457 .644 r
.52466 .40801 .5306 .4416 .54161 .43669 .5356 .40147 Mtetra
.621 .457 .638 r
.5356 .40147 .54161 .43669 .55264 .43055 .54655 .39396 Mtetra
.627 .458 .634 r
.54655 .39396 .55264 .43055 .56367 .42259 .55751 .38536 Mtetra
.632 .46 .632 r
.55751 .38536 .56367 .42259 .57469 .41272 .56848 .37597 Mtetra
.636 .464 .632 r
.56848 .37597 .57469 .41272 .58567 .40079 .57943 .36615 Mtetra
.639 .47 .638 r
.57943 .36615 .58567 .40079 .59661 .38754 .5904 .35663 Mtetra
.637 .478 .651 r
.5904 .35663 .59661 .38754 .60752 .37403 .6014 .34841 Mtetra
.632 .493 .675 r
.6014 .34841 .60752 .37403 .61843 .36144 .61247 .34213 Mtetra
.611 .516 .723 r
.61247 .34213 .61843 .36144 .62941 .35143 .62365 .33869 Mtetra
.565 .565 .813 r
.62365 .33869 .62941 .35143 .6405 .34429 .63497 .3378 Mtetra
.382 .634 .954 r
.63497 .3378 .6405 .34429 .65174 .34048 .64644 .33915 Mtetra
0 .444 .705 r
.64644 .33915 .65174 .34048 .66314 .33925 .65805 .34179 Mtetra
.407 0 0 r
.65805 .34179 .66314 .33925 .67468 .33964 .66976 .34453 Mtetra
.447 0 0 r
.66976 .34453 .67468 .33964 .68634 .3409 .68154 .3468 Mtetra
.411 0 0 r
.68154 .3468 .68634 .3409 .69808 .3421 .69334 .34784 Mtetra
.345 0 0 r
.69334 .34784 .69808 .3421 .70988 .34291 .70516 .34762 Mtetra
.225 0 0 r
.70516 .34762 .70988 .34291 .72172 .34288 .71698 .34605 Mtetra
.039 0 0 r
.71698 .34605 .72172 .34288 .73357 .34198 .72878 .34334 Mtetra
.225 .735 .692 r
.72878 .34334 .73357 .34198 .74543 .3401 .74058 .33966 Mtetra
.472 .892 .895 r
.74058 .33966 .74543 .3401 .75729 .3374 .75238 .33526 Mtetra
.617 .924 .972 r
.75238 .33526 .75729 .3374 .76915 .33396 .76419 .3304 Mtetra
.678 .897 .975 r
.76419 .3304 .76915 .33396 .78102 .32996 .77602 .32523 Mtetra
.697 .858 .959 r
.77602 .32523 .78102 .32996 .79291 .3256 .78788 .31996 Mtetra
.703 .827 .941 r
.78788 .31996 .79291 .3256 .80482 .32099 .79978 .31464 Mtetra
.702 .802 .927 r
.79978 .31464 .80482 .32099 .81677 .31623 .81172 .30933 Mtetra
.698 .783 .916 r
.81172 .30933 .81677 .31623 .82876 .31146 .82371 .3041 Mtetra
.6 .736 .94 r
.18006 .50842 .18679 .51429 .1963 .51229 .18959 .50639 Mtetra
.591 .733 .942 r
.18959 .50639 .1963 .51229 .20585 .51037 .19915 .50452 Mtetra
.581 .732 .947 r
.19915 .50452 .20585 .51037 .21543 .50848 .20873 .50281 Mtetra
.567 .735 .955 r
.20873 .50281 .21543 .50848 .22506 .50653 .21834 .50127 Mtetra
.544 .743 .969 r
.21834 .50127 .22506 .50653 .23475 .50451 .22798 .49997 Mtetra
.518 .764 .986 r
.22798 .49997 .23475 .50451 .2445 .50219 .23765 .49876 Mtetra
.472 .791 .999 r
.23765 .49876 .2445 .50219 .25432 .49944 .24738 .49757 Mtetra
.401 .814 .976 r
.24738 .49757 .25432 .49944 .26424 .496 .25717 .49613 Mtetra
.271 .776 .848 r
.25717 .49613 .26424 .496 .27427 .49163 .26704 .49423 Mtetra
0 0 0 r
.26704 .49423 .27427 .49163 .2844 .48615 .27702 .4916 Mtetra
.032 0 0 r
.27702 .4916 .2844 .48615 .29466 .47936 .28711 .48796 Mtetra
.127 0 0 r
.28711 .48796 .29466 .47936 .30501 .47134 .29731 .48322 Mtetra
.178 0 .03 r
.29731 .48322 .30501 .47134 .31545 .46211 .30762 .47722 Mtetra
.21 0 .117 r
.30762 .47722 .31545 .46211 .32591 .4524 .31803 .46997 Mtetra
.213 0 .158 r
.31803 .46997 .32591 .4524 .33638 .44276 .32854 .46142 Mtetra
.186 0 .16 r
.32854 .46142 .33638 .44276 .34677 .43438 .33913 .45156 Mtetra
.091 0 .094 r
.33913 .45156 .34677 .43438 .35706 .42816 .34978 .44042 Mtetra
0 0 0 r
.34978 .44042 .35706 .42816 .36725 .42444 .36046 .42864 Mtetra
.792 .986 .73 r
.36046 .42864 .36725 .42444 .37735 .42352 .37113 .41675 Mtetra
.822 .766 .8 r
.37113 .41675 .37735 .42352 .38742 .4245 .38174 .40582 Mtetra
.697 .566 .703 r
.38174 .40582 .38742 .4245 .39751 .42679 .39228 .39661 Mtetra
.63 .474 .651 r
.39228 .39661 .39751 .42679 .40766 .4294 .40274 .38941 Mtetra
.592 .425 .624 r
.40274 .38941 .40766 .4294 .41791 .4316 .41314 .38439 Mtetra
.572 .4 .61 r
.41314 .38439 .41791 .4316 .42825 .43303 .42352 .38096 Mtetra
.56 .386 .602 r
.42352 .38096 .42825 .43303 .43869 .43341 .43391 .3787 Mtetra
.556 .38 .598 r
.43391 .3787 .43869 .43341 .44922 .43284 .44434 .37693 Mtetra
.555 .378 .596 r
.44434 .37693 .44922 .43284 .45983 .43134 .45481 .37514 Mtetra
.558 .38 .596 r
.45481 .37514 .45983 .43134 .47051 .42907 .46535 .37296 Mtetra
.562 .383 .597 r
.46535 .37296 .47051 .42907 .48125 .42614 .47595 .37013 Mtetra
.568 .387 .597 r
.47595 .37013 .48125 .42614 .49204 .4226 .4866 .36651 Mtetra
.572 .391 .597 r
.4866 .36651 .49204 .4226 .50287 .41845 .4973 .36213 Mtetra
.577 .394 .597 r
.4973 .36213 .50287 .41845 .51375 .41361 .50804 .35708 Mtetra
.579 .395 .597 r
.50804 .35708 .51375 .41361 .52466 .40801 .51881 .35163 Mtetra
.579 .396 .597 r
.51881 .35163 .52466 .40801 .5356 .40147 .52962 .34616 Mtetra
.577 .395 .599 r
.52962 .34616 .5356 .40147 .54655 .39396 .54045 .34118 Mtetra
.57 .393 .602 r
.54045 .34118 .54655 .39396 .55751 .38536 .55134 .33737 Mtetra
.561 .392 .609 r
.55134 .33737 .55751 .38536 .56848 .37597 .56228 .33517 Mtetra
.545 .392 .624 r
.56228 .33517 .56848 .37597 .57943 .36615 .57331 .33519 Mtetra
.519 .399 .656 r
.57331 .33519 .57943 .36615 .5904 .35663 .58445 .33726 Mtetra
.459 .422 .73 r
.58445 .33726 .5904 .35663 .6014 .34841 .59571 .34109 Mtetra
.148 .462 .889 r
.59571 .34109 .6014 .34841 .61247 .34213 .6071 .34594 Mtetra
.541 .011 0 r
.6071 .34594 .61247 .34213 .62365 .33869 .6186 .35069 Mtetra
.558 .149 .223 r
.6186 .35069 .62365 .33869 .63497 .3378 .63018 .35482 Mtetra
.536 .168 .29 r
.63018 .35482 .63497 .3378 .64644 .33915 .64181 .35768 Mtetra
.514 .157 .299 r
.64181 .35768 .64644 .33915 .65805 .34179 .65349 .3592 Mtetra
.486 .124 .277 r
.65349 .3592 .65805 .34179 .66976 .34453 .6652 .35941 Mtetra
.445 .067 .227 r
.6652 .35941 .66976 .34453 .68154 .3468 .67692 .35833 Mtetra
.374 0 .132 r
.67692 .35833 .68154 .3468 .69334 .34784 .68865 .35596 Mtetra
.249 0 0 r
.68865 .35596 .69334 .34784 .70516 .34762 .70037 .35246 Mtetra
.015 0 0 r
.70037 .35246 .70516 .34762 .71698 .34605 .71209 .34791 Mtetra
.33 .796 .686 r
.71209 .34791 .71698 .34605 .72878 .34334 .7238 .34259 Mtetra
.604 .948 .92 r
.7238 .34259 .72878 .34334 .74058 .33966 .73552 .33678 Mtetra
.708 .929 .964 r
.73552 .33678 .74058 .33966 .75238 .33526 .74725 .33071 Mtetra
.727 .873 .949 r
.74725 .33071 .75238 .33526 .76419 .3304 .75902 .32465 Mtetra
.726 .829 .929 r
.75902 .32465 .76419 .3304 .77602 .32523 .77083 .31867 Mtetra
.716 .799 .916 r
.77083 .31867 .77602 .32523 .78788 .31996 .78269 .31292 Mtetra
.709 .781 .909 r
.78269 .31292 .78788 .31996 .79978 .31464 .79461 .30735 Mtetra
.702 .772 .906 r
.79461 .30735 .79978 .31464 .81172 .30933 .80658 .30194 Mtetra
.697 .768 .907 r
.80658 .30194 .81172 .30933 .82371 .3041 .81861 .29669 Mtetra
.629 .744 .931 r
.17328 .5025 .18006 .50842 .18959 .50639 .18289 .49988 Mtetra
.624 .724 .918 r
.18289 .49988 .18959 .50639 .19915 .50452 .19252 .49741 Mtetra
.615 .702 .907 r
.19252 .49741 .19915 .50452 .20873 .50281 .20217 .49515 Mtetra
.603 .682 .897 r
.20217 .49515 .20873 .50281 .21834 .50127 .21183 .49319 Mtetra
.585 .664 .892 r
.21183 .49319 .21834 .50127 .22798 .49997 .2215 .49164 Mtetra
.569 .651 .891 r
.2215 .49164 .22798 .49997 .23765 .49876 .23118 .49048 Mtetra
.548 .644 .897 r
.23118 .49048 .23765 .49876 .24738 .49757 .24087 .48972 Mtetra
.53 .65 .911 r
.24087 .48972 .24738 .49757 .25717 .49613 .2506 .48922 Mtetra
.507 .672 .938 r
.2506 .48922 .25717 .49613 .26704 .49423 .26037 .48887 Mtetra
.477 .718 .976 r
.26037 .48887 .26704 .49423 .27702 .4916 .27019 .48842 Mtetra
.408 .775 .994 r
.27019 .48842 .27702 .4916 .28711 .48796 .2801 .48763 Mtetra
.239 .752 .858 r
.2801 .48763 .28711 .48796 .29731 .48322 .29011 .48625 Mtetra
0 0 0 r
.29011 .48625 .29731 .48322 .30762 .47722 .30022 .484 Mtetra
.135 0 0 r
.30022 .484 .30762 .47722 .31803 .46997 .31046 .48051 Mtetra
.189 0 0 r
.31046 .48051 .31803 .46997 .32854 .46142 .32083 .47546 Mtetra
.197 0 .087 r
.32083 .47546 .32854 .46142 .33913 .45156 .33134 .46855 Mtetra
.181 0 .131 r
.33134 .46855 .33913 .45156 .34978 .44042 .34199 .45959 Mtetra
.173 0 .158 r
.34199 .45959 .34978 .44042 .36046 .42864 .35272 .44911 Mtetra
.164 0 .17 r
.35272 .44911 .36046 .42864 .37113 .41675 .36349 .43757 Mtetra
.175 0 .181 r
.36349 .43757 .37113 .41675 .38174 .40582 .37426 .42604 Mtetra
.194 0 .184 r
.37426 .42604 .38174 .40582 .39228 .39661 .38498 .4153 Mtetra
.211 0 .176 r
.38498 .4153 .39228 .39661 .40274 .38941 .39565 .40582 Mtetra
.227 0 .153 r
.39565 .40582 .40274 .38941 .41314 .38439 .40625 .39794 Mtetra
.219 0 .099 r
.40625 .39794 .41314 .38439 .42352 .38096 .41683 .3914 Mtetra
.188 0 .005 r
.41683 .3914 .42352 .38096 .43391 .3787 .42739 .38606 Mtetra
.106 0 0 r
.42739 .38606 .43391 .3787 .44434 .37693 .43795 .3815 Mtetra
0 0 0 r
.43795 .3815 .44434 .37693 .45481 .37514 .44854 .37745 Mtetra
.44854 .37745 .45481 .37514 .46535 .37296 .45916 .37367 Mtetra
.383 .846 .836 r
.45916 .37367 .46535 .37296 .47595 .37013 .46982 .37001 Mtetra
.455 .882 .905 r
.46982 .37001 .47595 .37013 .4866 .36651 .48052 .36637 Mtetra
.45 .879 .904 r
.48052 .36637 .4866 .36651 .4973 .36213 .49127 .36278 Mtetra
.358 .831 .827 r
.49127 .36278 .4973 .36213 .50804 .35708 .50205 .35929 Mtetra
0 0 0 r
.50205 .35929 .50804 .35708 .51881 .35163 .51288 .35608 Mtetra
.1 0 0 r
.51288 .35608 .51881 .35163 .52962 .34616 .52375 .35338 Mtetra
.293 0 0 r
.52375 .35338 .52962 .34616 .54045 .34118 .53468 .35148 Mtetra
.413 0 .121 r
.53468 .35148 .54045 .34118 .55134 .33737 .54567 .35079 Mtetra
.481 .09 .22 r
.54567 .35079 .55134 .33737 .56228 .33517 .55673 .35147 Mtetra
.526 .156 .281 r
.55673 .35147 .56228 .33517 .57331 .33519 .5679 .35379 Mtetra
.55 .192 .314 r
.5679 .35379 .57331 .33519 .58445 .33726 .57918 .35741 Mtetra
.562 .211 .33 r
.57918 .35741 .58445 .33726 .59571 .34109 .59057 .36185 Mtetra
.562 .213 .334 r
.59057 .36185 .59571 .34109 .6071 .34594 .60206 .36634 Mtetra
.546 .196 .325 r
.60206 .36634 .6071 .34594 .6186 .35069 .61363 .36976 Mtetra
.52 .164 .304 r
.61363 .36976 .6186 .35069 .63018 .35482 .62526 .37167 Mtetra
.474 .107 .263 r
.62526 .37167 .63018 .35482 .64181 .35768 .63689 .37148 Mtetra
.406 .02 .19 r
.63689 .37148 .64181 .35768 .65349 .3592 .64853 .36939 Mtetra
.292 0 .056 r
.64853 .36939 .65349 .3592 .6652 .35941 .66017 .3657 Mtetra
.069 0 0 r
.66017 .3657 .6652 .35941 .67692 .35833 .67179 .36073 Mtetra
.339 .792 .653 r
.67179 .36073 .67692 .35833 .68865 .35596 .68341 .35486 Mtetra
.675 .964 .933 r
.68341 .35486 .68865 .35596 .70037 .35246 .69503 .34835 Mtetra
.756 .892 .939 r
.69503 .34835 .70037 .35246 .71209 .34791 .70666 .34149 Mtetra
.754 .811 .898 r
.70666 .34149 .71209 .34791 .7238 .34259 .71831 .33451 Mtetra
.738 .757 .868 r
.71831 .33451 .7238 .34259 .73552 .33678 .72999 .32768 Mtetra
.723 .726 .852 r
.72999 .32768 .73552 .33678 .74725 .33071 .74173 .32109 Mtetra
.709 .709 .848 r
.74173 .32109 .74725 .33071 .75902 .32465 .75352 .31493 Mtetra
.699 .703 .85 r
.75352 .31493 .75902 .32465 .77083 .31867 .76537 .30915 Mtetra
.69 .705 .859 r
.76537 .30915 .77083 .31867 .78269 .31292 .7773 .30378 Mtetra
.683 .712 .87 r
.7773 .30378 .78269 .31292 .79461 .30735 .7893 .29873 Mtetra
.679 .725 .884 r
.7893 .29873 .79461 .30735 .80658 .30194 .80136 .2939 Mtetra
.676 .741 .9 r
.80136 .2939 .80658 .30194 .81861 .29669 .81347 .28921 Mtetra
.669 .755 .914 r
.16646 .49655 .17328 .5025 .18289 .49988 .17618 .49297 Mtetra
.664 .724 .893 r
.17618 .49297 .18289 .49988 .19252 .49741 .18593 .48947 Mtetra
.654 .692 .873 r
.18593 .48947 .19252 .49741 .20217 .49515 .1957 .48615 Mtetra
.641 .661 .855 r
.1957 .48615 .20217 .49515 .21183 .49319 .20547 .48314 Mtetra
.624 .632 .838 r
.20547 .48314 .21183 .49319 .2215 .49164 .21524 .48055 Mtetra
.605 .603 .823 r
.21524 .48055 .2215 .49164 .23118 .49048 .225 .47847 Mtetra
.584 .577 .812 r
.225 .47847 .23118 .49048 .24087 .48972 .23476 .47703 Mtetra
.563 .556 .804 r
.23476 .47703 .24087 .48972 .2506 .48922 .2445 .47622 Mtetra
.541 .539 .802 r
.2445 .47622 .2506 .48922 .26037 .48887 .25424 .47609 Mtetra
.521 .534 .809 r
.25424 .47609 .26037 .48887 .27019 .48842 .264 .47648 Mtetra
.5 .538 .827 r
.264 .47648 .27019 .48842 .2801 .48763 .27379 .47729 Mtetra
.484 .565 .862 r
.27379 .47729 .2801 .48763 .29011 .48625 .28363 .47813 Mtetra
.467 .618 .915 r
.28363 .47813 .29011 .48625 .30022 .484 .29356 .47871 Mtetra
.43 .705 .98 r
.29356 .47871 .30022 .484 .31046 .48051 .30359 .47871 Mtetra
.304 .767 .946 r
.30359 .47871 .31046 .48051 .32083 .47546 .31374 .47786 Mtetra
.033 0 0 r
.31374 .47786 .32083 .47546 .33134 .46855 .32398 .47636 Mtetra
.285 0 0 r
.32398 .47636 .33134 .46855 .34199 .45959 .3343 .4743 Mtetra
.395 .017 .199 r
.3343 .4743 .34199 .45959 .35272 .44911 .34469 .47188 Mtetra
.443 .113 .311 r
.34469 .47188 .35272 .44911 .36349 .43757 .35514 .46919 Mtetra
.46 .159 .367 r
.35514 .46919 .36349 .43757 .37426 .42604 .36567 .46585 Mtetra
.466 .181 .396 r
.36567 .46585 .37426 .42604 .38498 .4153 .37628 .46163 Mtetra
.465 .19 .411 r
.37628 .46163 .38498 .4153 .39565 .40582 .38698 .45632 Mtetra
.461 .191 .418 r
.38698 .45632 .39565 .40582 .40625 .39794 .39775 .44987 Mtetra
.457 .189 .419 r
.39775 .44987 .40625 .39794 .41683 .3914 .40856 .44269 Mtetra
.452 .185 .417 r
.40856 .44269 .41683 .3914 .42739 .38606 .41941 .43512 Mtetra
.45 .181 .412 r
.41941 .43512 .42739 .38606 .43795 .3815 .43027 .42773 Mtetra
.451 .178 .407 r
.43027 .42773 .43795 .3815 .44854 .37745 .44113 .4209 Mtetra
.455 .178 .403 r
.44113 .4209 .44854 .37745 .45916 .37367 .45199 .41496 Mtetra
.464 .182 .4 r
.45199 .41496 .45916 .37367 .46982 .37001 .46286 .41013 Mtetra
.475 .19 .4 r
.46286 .41013 .46982 .37001 .48052 .36637 .47374 .40652 Mtetra
.488 .201 .404 r
.47374 .40652 .48052 .36637 .49127 .36278 .48466 .40411 Mtetra
.501 .214 .41 r
.48466 .40411 .49127 .36278 .50205 .35929 .49561 .40282 Mtetra
.51 .225 .418 r
.49561 .40282 .50205 .35929 .51288 .35608 .50662 .40244 Mtetra
.517 .234 .425 r
.50662 .40244 .51288 .35608 .52375 .35338 .5177 .40265 Mtetra
.519 .239 .43 r
.5177 .40265 .52375 .35338 .53468 .35148 .52884 .40303 Mtetra
.517 .24 .433 r
.52884 .40303 .53468 .35148 .54567 .35079 .54006 .40304 Mtetra
.512 .236 .433 r
.54006 .40304 .54567 .35079 .55673 .35147 .55135 .40232 Mtetra
.502 .227 .429 r
.55135 .40232 .55673 .35147 .5679 .35379 .56269 .40046 Mtetra
.49 .212 .418 r
.56269 .40046 .5679 .35379 .57918 .35741 .57407 .39749 Mtetra
.474 .188 .399 r
.57407 .39749 .57918 .35741 .59057 .36185 .58549 .39363 Mtetra
.448 .149 .364 r
.58549 .39363 .59057 .36185 .60206 .36634 .59693 .38909 Mtetra
.406 .081 .298 r
.59693 .38909 .60206 .36634 .61363 .36976 .60842 .38428 Mtetra
.315 0 .164 r
.60842 .38428 .61363 .36976 .62526 .37167 .61993 .3791 Mtetra
.068 0 0 r
.61993 .3791 .62526 .37167 .63689 .37148 .63146 .37333 Mtetra
.462 .876 .743 r
.63146 .37333 .63689 .37148 .64853 .36939 .64301 .36689 Mtetra
.761 .944 .94 r
.64301 .36689 .64853 .36939 .66017 .3657 .65454 .35955 Mtetra
.78 .822 .886 r
.65454 .35955 .66017 .3657 .67179 .36073 .66607 .35161 Mtetra
.758 .735 .831 r
.66607 .35161 .67179 .36073 .68341 .35486 .67761 .34338 Mtetra
.735 .68 .797 r
.67761 .34338 .68341 .35486 .69503 .34835 .68916 .33517 Mtetra
.714 .644 .778 r
.68916 .33517 .69503 .34835 .70666 .34149 .70076 .32738 Mtetra
.698 .624 .77 r
.70076 .32738 .70666 .34149 .71831 .33451 .7124 .3201 Mtetra
.684 .613 .771 r
.7124 .3201 .71831 .33451 .72999 .32768 .72412 .31352 Mtetra
.673 .612 .778 r
.72412 .31352 .72999 .32768 .74173 .32109 .73591 .30759 Mtetra
.664 .617 .791 r
.73591 .30759 .74173 .32109 .75352 .31493 .74778 .30231 Mtetra
.657 .628 .808 r
.74778 .30231 .75352 .31493 .76537 .30915 .75973 .29756 Mtetra
.652 .644 .829 r
.75973 .29756 .76537 .30915 .7773 .30378 .77177 .29324 Mtetra
.648 .664 .852 r
.77177 .29324 .7773 .30378 .7893 .29873 .78388 .28923 Mtetra
.645 .688 .876 r
.78388 .28923 .7893 .29873 .80136 .2939 .79606 .28542 Mtetra
.644 .716 .9 r
.79606 .28542 .80136 .2939 .81347 .28921 .8083 .28168 Mtetra
.701 .761 .898 r
.15958 .49055 .16646 .49655 .17618 .49297 .16943 .48605 Mtetra
.697 .733 .879 r
.16943 .48605 .17618 .49297 .18593 .48947 .1793 .48154 Mtetra
.688 .704 .859 r
.1793 .48154 .18593 .48947 .1957 .48615 .18919 .47711 Mtetra
.676 .674 .84 r
.18919 .47711 .1957 .48615 .20547 .48314 .1991 .47287 Mtetra
.662 .644 .821 r
.1991 .47287 .20547 .48314 .21524 .48055 .20901 .46889 Mtetra
.645 .612 .802 r
.20901 .46889 .21524 .48055 .225 .47847 .21891 .46531 Mtetra
.625 .58 .784 r
.21891 .46531 .225 .47847 .23476 .47703 .2288 .46228 Mtetra
.604 .549 .766 r
.2288 .46228 .23476 .47703 .2445 .47622 .23867 .45988 Mtetra
.583 .52 .75 r
.23867 .45988 .2445 .47622 .25424 .47609 .24853 .45824 Mtetra
.564 .494 .735 r
.24853 .45824 .25424 .47609 .264 .47648 .25837 .45734 Mtetra
.546 .473 .724 r
.25837 .45734 .264 .47648 .27379 .47729 .2682 .45719 Mtetra
.534 .458 .717 r
.2682 .45719 .27379 .47729 .28363 .47813 .27805 .45759 Mtetra
.525 .45 .713 r
.27805 .45759 .28363 .47813 .29356 .47871 .28793 .45839 Mtetra
.519 .448 .716 r
.28793 .45839 .29356 .47871 .30359 .47871 .29786 .45946 Mtetra
.514 .454 .727 r
.29786 .45946 .30359 .47871 .31374 .47786 .30785 .46064 Mtetra
.504 .468 .75 r
.30785 .46064 .31374 .47786 .32398 .47636 .31789 .46202 Mtetra
.485 .493 .791 r
.31789 .46202 .32398 .47636 .3343 .4743 .328 .46358 Mtetra
.456 .546 .86 r
.328 .46358 .3343 .4743 .34469 .47188 .33818 .46504 Mtetra
.39 .63 .95 r
.33818 .46504 .34469 .47188 .35514 .46919 .34844 .46616 Mtetra
.272 .714 .962 r
.34844 .46616 .35514 .46919 .36567 .46585 .35883 .46633 Mtetra
.109 .663 .739 r
.35883 .46633 .36567 .46585 .37628 .46163 .36935 .46514 Mtetra
.006 0 0 r
.36935 .46514 .37628 .46163 .38698 .45632 .37998 .46253 Mtetra
.064 0 0 r
.37998 .46253 .38698 .45632 .39775 .44987 .39072 .45849 Mtetra
.125 0 0 r
.39072 .45849 .39775 .44987 .40856 .44269 .40154 .45352 Mtetra
.18 0 0 r
.40154 .45352 .40856 .44269 .41941 .43512 .41241 .44797 Mtetra
.236 0 .08 r
.41241 .44797 .41941 .43512 .43027 .42773 .42331 .44233 Mtetra
.286 0 .141 r
.42331 .44233 .43027 .42773 .44113 .4209 .43423 .43692 Mtetra
.328 0 .184 r
.43423 .43692 .44113 .4209 .45199 .41496 .44518 .43197 Mtetra
.361 .003 .214 r
.44518 .43197 .45199 .41496 .46286 .41013 .45615 .42766 Mtetra
.387 .03 .232 r
.45615 .42766 .46286 .41013 .47374 .40652 .46714 .42404 Mtetra
.406 .048 .24 r
.46714 .42404 .47374 .40652 .48466 .40411 .47817 .4211 Mtetra
.419 .056 .239 r
.47817 .4211 .48466 .40411 .49561 .40282 .48924 .41881 Mtetra
.425 .053 .227 r
.48924 .41881 .49561 .40282 .50662 .40244 .50036 .41699 Mtetra
.42 .036 .202 r
.50036 .41699 .50662 .40244 .5177 .40265 .51153 .41541 Mtetra
.4 0 .16 r
.51153 .41541 .5177 .40265 .52884 .40303 .52277 .41374 Mtetra
.35 0 .086 r
.52277 .41374 .52884 .40303 .54006 .40304 .53407 .41149 Mtetra
.251 0 0 r
.53407 .41149 .54006 .40304 .55135 .40232 .54542 .40831 Mtetra
.04 0 0 r
.54542 .40831 .55135 .40232 .56269 .40046 .5568 .40367 Mtetra
0 0 0 r
.5568 .40367 .56269 .40046 .57407 .39749 .56821 .39758 Mtetra
.694 .98 .892 r
.56821 .39758 .57407 .39749 .58549 .39363 .57962 .3901 Mtetra
.807 .907 .91 r
.57962 .3901 .58549 .39363 .59693 .38909 .59103 .38163 Mtetra
.786 .78 .847 r
.59103 .38163 .59693 .38909 .60842 .38428 .60245 .37279 Mtetra
.747 .682 .788 r
.60245 .37279 .60842 .38428 .61993 .3791 .61388 .36384 Mtetra
.713 .616 .747 r
.61388 .36384 .61993 .3791 .63146 .37333 .62532 .35505 Mtetra
.69 .576 .721 r
.62532 .35505 .63146 .37333 .64301 .36689 .63679 .34644 Mtetra
.677 .552 .706 r
.63679 .34644 .64301 .36689 .65454 .35955 .64827 .33794 Mtetra
.668 .54 .699 r
.64827 .33794 .65454 .35955 .66607 .35161 .65977 .32968 Mtetra
.662 .534 .698 r
.65977 .32968 .66607 .35161 .67761 .34338 .67131 .32183 Mtetra
.656 .533 .702 r
.67131 .32183 .67761 .34338 .68916 .33517 .6829 .31454 Mtetra
.65 .535 .711 r
.6829 .31454 .68916 .33517 .70076 .32738 .69455 .308 Mtetra
.644 .542 .724 r
.69455 .308 .70076 .32738 .7124 .3201 .70628 .30222 Mtetra
.638 .551 .74 r
.70628 .30222 .7124 .3201 .72412 .31352 .71809 .29722 Mtetra
.632 .564 .76 r
.71809 .29722 .72412 .31352 .73591 .30759 .72999 .29287 Mtetra
.627 .581 .783 r
.72999 .29287 .73591 .30759 .74778 .30231 .74198 .28908 Mtetra
.622 .601 .808 r
.74198 .28908 .74778 .30231 .75973 .29756 .75405 .28572 Mtetra
.619 .624 .834 r
.75405 .28572 .75973 .29756 .77177 .29324 .7662 .28263 Mtetra
.615 .648 .86 r
.7662 .28263 .77177 .29324 .78388 .28923 .77843 .27973 Mtetra
.612 .674 .885 r
.77843 .27973 .78388 .28923 .79606 .28542 .79072 .27691 Mtetra
.611 .702 .909 r
.79072 .27691 .79606 .28542 .8083 .28168 .80308 .27409 Mtetra
.72 .764 .887 r
.15266 .48451 .15958 .49055 .16943 .48605 .1626 .47937 Mtetra
.718 .745 .873 r
.1626 .47937 .16943 .48605 .1793 .48154 .17257 .47414 Mtetra
.714 .725 .859 r
.17257 .47414 .1793 .48154 .18919 .47711 .18257 .46886 Mtetra
.708 .703 .843 r
.18257 .46886 .18919 .47711 .1991 .47287 .19259 .46357 Mtetra
.699 .678 .826 r
.19259 .46357 .1991 .47287 .20901 .46889 .20264 .4583 Mtetra
.687 .649 .807 r
.20264 .4583 .20901 .46889 .21891 .46531 .2127 .45317 Mtetra
.671 .617 .786 r
.2127 .45317 .21891 .46531 .2288 .46228 .22276 .44827 Mtetra
.653 .584 .765 r
.22276 .44827 .2288 .46228 .23867 .45988 .23282 .44375 Mtetra
.634 .551 .743 r
.23282 .44375 .23867 .45988 .24853 .45824 .24287 .43971 Mtetra
.614 .518 .723 r
.24287 .43971 .24853 .45824 .25837 .45734 .2529 .43628 Mtetra
.594 .489 .704 r
.2529 .43628 .25837 .45734 .2682 .45719 .26291 .43356 Mtetra
.576 .462 .687 r
.26291 .43356 .2682 .45719 .27805 .45759 .2729 .43166 Mtetra
.558 .44 .674 r
.2729 .43166 .27805 .45759 .28793 .45839 .28287 .43066 Mtetra
.543 .422 .665 r
.28287 .43066 .28793 .45839 .29786 .45946 .29283 .43057 Mtetra
.529 .408 .66 r
.29283 .43057 .29786 .45946 .30785 .46064 .30278 .43139 Mtetra
.521 .402 .658 r
.30278 .43139 .30785 .46064 .31789 .46202 .31277 .43268 Mtetra
.519 .401 .658 r
.31277 .43268 .31789 .46202 .328 .46358 .32282 .43412 Mtetra
.527 .406 .658 r
.32282 .43412 .328 .46358 .33818 .46504 .33297 .43507 Mtetra
.541 .414 .657 r
.33297 .43507 .33818 .46504 .34844 .46616 .34325 .43507 Mtetra
.553 .419 .652 r
.34325 .43507 .34844 .46616 .35883 .46633 .35362 .43424 Mtetra
.562 .422 .649 r
.35362 .43424 .35883 .46633 .36935 .46514 .3641 .43261 Mtetra
.564 .423 .647 r
.3641 .43261 .36935 .46514 .37998 .46253 .37464 .43076 Mtetra
.564 .425 .651 r
.37464 .43076 .37998 .46253 .39072 .45849 .38523 .42898 Mtetra
.564 .433 .66 r
.38523 .42898 .39072 .45849 .40154 .45352 .39586 .4274 Mtetra
.563 .446 .678 r
.39586 .4274 .40154 .45352 .41241 .44797 .40655 .42605 Mtetra
.568 .472 .706 r
.40655 .42605 .41241 .44797 .42331 .44233 .41729 .42464 Mtetra
.578 .512 .745 r
.41729 .42464 .42331 .44233 .43423 .43692 .42809 .42299 Mtetra
.596 .567 .791 r
.42809 .42299 .43423 .43692 .44518 .43197 .43897 .42082 Mtetra
.62 .626 .835 r
.43897 .42082 .44518 .43197 .45615 .42766 .44992 .41796 Mtetra
.648 .669 .857 r
.44992 .41796 .45615 .42766 .46714 .42404 .46093 .41431 Mtetra
.67 .678 .849 r
.46093 .41431 .46714 .42404 .47817 .4211 .472 .40986 Mtetra
.678 .651 .817 r
.472 .40986 .47817 .4211 .48924 .41881 .48312 .40472 Mtetra
.671 .605 .773 r
.48312 .40472 .48924 .41881 .50036 .41699 .49427 .39904 Mtetra
.655 .556 .731 r
.49427 .39904 .50036 .41699 .51153 .41541 .50546 .39311 Mtetra
.637 .515 .698 r
.50546 .39311 .51153 .41541 .52277 .41374 .51669 .38712 Mtetra
.621 .484 .674 r
.51669 .38712 .52277 .41374 .53407 .41149 .52794 .38136 Mtetra
.61 .464 .658 r
.52794 .38136 .53407 .41149 .54542 .40831 .53922 .37578 Mtetra
.604 .452 .649 r
.53922 .37578 .54542 .40831 .5568 .40367 .55054 .37028 Mtetra
.605 .45 .646 r
.55054 .37028 .5568 .40367 .56821 .39758 .56189 .36453 Mtetra
.613 .457 .647 r
.56189 .36453 .56821 .39758 .57962 .3901 .57326 .35797 Mtetra
.623 .467 .649 r
.57326 .35797 .57962 .3901 .59103 .38163 .58465 .35055 Mtetra
.635 .478 .652 r
.58465 .35055 .59103 .38163 .60245 .37279 .59603 .34214 Mtetra
.642 .483 .653 r
.59603 .34214 .60245 .37279 .61388 .36384 .60741 .33322 Mtetra
.64 .482 .653 r
.60741 .33322 .61388 .36384 .62532 .35505 .61881 .32442 Mtetra
.636 .479 .653 r
.61881 .32442 .62532 .35505 .63679 .34644 .63024 .3161 Mtetra
.627 .474 .656 r
.63024 .3161 .63679 .34644 .64827 .33794 .64171 .30869 Mtetra
.62 .474 .661 r
.64171 .30869 .64827 .33794 .65977 .32968 .65325 .30221 Mtetra
.614 .477 .671 r
.65325 .30221 .65977 .32968 .67131 .32183 .66486 .29665 Mtetra
.61 .484 .684 r
.66486 .29665 .67131 .32183 .6829 .31454 .67654 .29192 Mtetra
.606 .496 .702 r
.67654 .29192 .6829 .31454 .69455 .308 .68831 .28792 Mtetra
.603 .512 .724 r
.68831 .28792 .69455 .308 .70628 .30222 .70016 .28455 Mtetra
.599 .531 .75 r
.70016 .28455 .70628 .30222 .71809 .29722 .7121 .28169 Mtetra
.596 .553 .777 r
.7121 .28169 .71809 .29722 .72999 .29287 .72413 .27921 Mtetra
.593 .578 .806 r
.72413 .27921 .72999 .29287 .74198 .28908 .73623 .27697 Mtetra
.59 .604 .834 r
.73623 .27697 .74198 .28908 .75405 .28572 .74842 .27489 Mtetra
.589 .63 .861 r
.74842 .27489 .75405 .28572 .7662 .28263 .76067 .27283 Mtetra
.587 .655 .884 r
.76067 .27283 .7662 .28263 .77843 .27973 .77299 .27076 Mtetra
.585 .677 .904 r
.77299 .27076 .77843 .27973 .79072 .27691 .78538 .26865 Mtetra
.585 .699 .921 r
.78538 .26865 .79072 .27691 .80308 .27409 .79782 .26643 Mtetra
.719 .764 .888 r
.14569 .47843 .15266 .48451 .1626 .47937 .15565 .47331 Mtetra
.723 .766 .887 r
.15565 .47331 .1626 .47937 .17257 .47414 .16564 .46805 Mtetra
.727 .766 .884 r
.16564 .46805 .17257 .47414 .18257 .46886 .17568 .46263 Mtetra
.73 .763 .879 r
.17568 .46263 .18257 .46886 .19259 .46357 .18576 .45705 Mtetra
.733 .756 .871 r
.18576 .45705 .19259 .46357 .20264 .4583 .19588 .45127 Mtetra
.731 .742 .86 r
.19588 .45127 .20264 .4583 .2127 .45317 .20604 .44537 Mtetra
.727 .722 .846 r
.20604 .44537 .2127 .45317 .22276 .44827 .21622 .43939 Mtetra
.717 .695 .828 r
.21622 .43939 .22276 .44827 .23282 .44375 .22643 .43347 Mtetra
.702 .663 .808 r
.22643 .43347 .23282 .44375 .24287 .43971 .23664 .42769 Mtetra
.683 .626 .786 r
.23664 .42769 .24287 .43971 .2529 .43628 .24684 .42223 Mtetra
.662 .589 .763 r
.24684 .42223 .2529 .43628 .26291 .43356 .25704 .41723 Mtetra
.639 .553 .741 r
.25704 .41723 .26291 .43356 .2729 .43166 .26722 .41284 Mtetra
.615 .518 .721 r
.26722 .41284 .2729 .43166 .28287 .43066 .27736 .40923 Mtetra
.594 .487 .702 r
.27736 .40923 .28287 .43066 .29283 .43057 .28749 .40638 Mtetra
.576 .46 .684 r
.28749 .40638 .29283 .43057 .30278 .43139 .29761 .40433 Mtetra
.566 .441 .668 r
.29761 .40433 .30278 .43139 .31277 .43268 .30775 .40268 Mtetra
.561 .427 .655 r
.30775 .40268 .31277 .43268 .32282 .43412 .31792 .40118 Mtetra
.56 .417 .643 r
.31792 .40118 .32282 .43412 .33297 .43507 .32816 .39958 Mtetra
.561 .411 .635 r
.32816 .39958 .33297 .43507 .34325 .43507 .33846 .3977 Mtetra
.559 .406 .63 r
.33846 .3977 .34325 .43507 .35362 .43424 .34882 .39587 Mtetra
.556 .402 .627 r
.34882 .39587 .35362 .43424 .3641 .43261 .35921 .39428 Mtetra
.551 .398 .627 r
.35921 .39428 .3641 .43261 .37464 .43076 .36963 .39316 Mtetra
.545 .396 .629 r
.36963 .39316 .37464 .43076 .38523 .42898 .38009 .3926 Mtetra
.542 .397 .633 r
.38009 .3926 .38523 .42898 .39586 .4274 .39059 .39234 Mtetra
.541 .4 .638 r
.39059 .39234 .39586 .4274 .40655 .42605 .40116 .39216 Mtetra
.545 .406 .642 r
.40116 .39216 .40655 .42605 .41729 .42464 .4118 .3917 Mtetra
.552 .414 .646 r
.4118 .3917 .41729 .42464 .42809 .42299 .42252 .39068 Mtetra
.562 .423 .649 r
.42252 .39068 .42809 .42299 .43897 .42082 .43332 .38889 Mtetra
.574 .432 .651 r
.43332 .38889 .43897 .42082 .44992 .41796 .44421 .38617 Mtetra
.586 .441 .651 r
.44421 .38617 .44992 .41796 .46093 .41431 .45516 .38247 Mtetra
.596 .448 .65 r
.45516 .38247 .46093 .41431 .472 .40986 .46618 .37778 Mtetra
.606 .454 .649 r
.46618 .37778 .472 .40986 .48312 .40472 .47725 .37215 Mtetra
.613 .457 .647 r
.47725 .37215 .48312 .40472 .49427 .39904 .48836 .36574 Mtetra
.617 .458 .644 r
.48836 .36574 .49427 .39904 .50546 .39311 .4995 .35877 Mtetra
.617 .455 .64 r
.4995 .35877 .50546 .39311 .51669 .38712 .51067 .35149 Mtetra
.614 .45 .637 r
.51067 .35149 .51669 .38712 .52794 .38136 .52185 .34428 Mtetra
.608 .443 .633 r
.52185 .34428 .52794 .38136 .53922 .37578 .53306 .33737 Mtetra
.601 .435 .629 r
.53306 .33737 .53922 .37578 .55054 .37028 .5443 .33101 Mtetra
.595 .429 .627 r
.5443 .33101 .55054 .37028 .56189 .36453 .55557 .32512 Mtetra
.593 .427 .627 r
.55557 .32512 .56189 .36453 .57326 .35797 .56687 .31946 Mtetra
.593 .43 .629 r
.56687 .31946 .57326 .35797 .58465 .35055 .57821 .31385 Mtetra
.599 .438 .634 r
.57821 .31385 .58465 .35055 .59603 .34214 .58957 .30795 Mtetra
.604 .447 .642 r
.58957 .30795 .59603 .34214 .60741 .33322 .60097 .30193 Mtetra
.609 .459 .653 r
.60097 .30193 .60741 .33322 .61881 .32442 .6124 .29606 Mtetra
.611 .47 .666 r
.6124 .29606 .61881 .32442 .63024 .3161 .62388 .29059 Mtetra
.608 .481 .682 r
.62388 .29059 .63024 .3161 .64171 .30869 .63543 .28594 Mtetra
.604 .493 .701 r
.63543 .28594 .64171 .30869 .65325 .30221 .64705 .28206 Mtetra
.597 .507 .723 r
.64705 .28206 .65325 .30221 .66486 .29665 .65875 .27899 Mtetra
.591 .525 .75 r
.65875 .27899 .66486 .29665 .67654 .29192 .67054 .27655 Mtetra
.584 .548 .78 r
.67054 .27655 .67654 .29192 .68831 .28792 .68242 .27458 Mtetra
.577 .574 .813 r
.68242 .27458 .68831 .28792 .70016 .28455 .69438 .27295 Mtetra
.571 .603 .846 r
.69438 .27295 .70016 .28455 .7121 .28169 .70641 .27147 Mtetra
.565 .632 .876 r
.70641 .27147 .7121 .28169 .72413 .27921 .71853 .27005 Mtetra
.563 .659 .901 r
.71853 .27005 .72413 .27921 .73623 .27697 .73071 .26856 Mtetra
.562 .681 .919 r
.73071 .26856 .73623 .27697 .74842 .27489 .74296 .26695 Mtetra
.566 .699 .93 r
.74296 .26695 .74842 .27489 .76067 .27283 .75526 .26514 Mtetra
.571 .71 .936 r
.75526 .26514 .76067 .27283 .77299 .27076 .76762 .26315 Mtetra
.576 .716 .938 r
.76762 .26315 .77299 .27076 .78538 .26865 .78005 .26101 Mtetra
.582 .719 .937 r
.78005 .26101 .78538 .26865 .79782 .26643 .79252 .25872 Mtetra
.7 .761 .899 r
.13868 .4723 .14569 .47843 .15565 .47331 .14859 .46778 Mtetra
.707 .782 .91 r
.14859 .46778 .15565 .47331 .16564 .46805 .15854 .4631 Mtetra
.715 .804 .92 r
.15854 .4631 .16564 .46805 .17568 .46263 .16855 .45821 Mtetra
.726 .824 .926 r
.16855 .45821 .17568 .46263 .18576 .45705 .17861 .45305 Mtetra
.738 .841 .928 r
.17861 .45305 .18576 .45705 .19588 .45127 .18874 .44755 Mtetra
.748 .852 .927 r
.18874 .44755 .19588 .45127 .20604 .44537 .19892 .44173 Mtetra
.759 .856 .922 r
.19892 .44173 .20604 .44537 .21622 .43939 .20915 .43557 Mtetra
.765 .85 .915 r
.20915 .43557 .21622 .43939 .22643 .43347 .21943 .42918 Mtetra
.768 .835 .904 r
.21943 .42918 .22643 .43347 .23664 .42769 .22975 .42261 Mtetra
.763 .809 .889 r
.22975 .42261 .23664 .42769 .24684 .42223 .24009 .416 Mtetra
.752 .774 .87 r
.24009 .416 .24684 .42223 .25704 .41723 .25043 .40948 Mtetra
.735 .73 .846 r
.25043 .40948 .25704 .41723 .26722 .41284 .26079 .40312 Mtetra
.713 .68 .817 r
.26079 .40312 .26722 .41284 .27736 .40923 .27115 .39702 Mtetra
.69 .629 .783 r
.27115 .39702 .27736 .40923 .28749 .40638 .28151 .39113 Mtetra
.667 .58 .748 r
.28151 .39113 .28749 .40638 .29761 .40433 .29188 .38542 Mtetra
.645 .536 .716 r
.29188 .38542 .29761 .40433 .30775 .40268 .30227 .3799 Mtetra
.627 .501 .689 r
.30227 .3799 .30775 .40268 .31792 .40118 .31266 .37462 Mtetra
.608 .47 .669 r
.31266 .37462 .31792 .40118 .32816 .39958 .32305 .36998 Mtetra
.59 .447 .656 r
.32305 .36998 .32816 .39958 .33846 .3977 .33341 .36625 Mtetra
.574 .431 .649 r
.33341 .36625 .33846 .3977 .34882 .39587 .34375 .36357 Mtetra
.559 .418 .646 r
.34375 .36357 .34882 .39587 .35921 .39428 .35408 .36199 Mtetra
.551 .413 .646 r
.35408 .36199 .35921 .39428 .36963 .39316 .36443 .361 Mtetra
.548 .411 .647 r
.36443 .361 .36963 .39316 .38009 .3926 .37483 .36024 Mtetra
.551 .413 .646 r
.37483 .36024 .38009 .3926 .39059 .39234 .3853 .35925 Mtetra
.557 .416 .644 r
.3853 .35925 .39059 .39234 .40116 .39216 .39585 .35773 Mtetra
.563 .416 .639 r
.39585 .35773 .40116 .39216 .4118 .3917 .40648 .35564 Mtetra
.568 .416 .634 r
.40648 .35564 .4118 .3917 .42252 .39068 .41718 .35297 Mtetra
.571 .414 .63 r
.41718 .35297 .42252 .39068 .43332 .38889 .42795 .34986 Mtetra
.573 .413 .626 r
.42795 .34986 .43332 .38889 .44421 .38617 .43877 .34639 Mtetra
.575 .413 .624 r
.43877 .34639 .44421 .38617 .45516 .38247 .44964 .34264 Mtetra
.577 .415 .624 r
.44964 .34264 .45516 .38247 .46618 .37778 .46056 .33859 Mtetra
.582 .419 .626 r
.46056 .33859 .46618 .37778 .47725 .37215 .47153 .33418 Mtetra
.587 .425 .629 r
.47153 .33418 .47725 .37215 .48836 .36574 .48255 .32932 Mtetra
.595 .434 .634 r
.48255 .32932 .48836 .36574 .4995 .35877 .49361 .32387 Mtetra
.603 .444 .638 r
.49361 .32387 .4995 .35877 .51067 .35149 .5047 .31785 Mtetra
.611 .452 .642 r
.5047 .31785 .51067 .35149 .52185 .34428 .51583 .31129 Mtetra
.615 .456 .644 r
.51583 .31129 .52185 .34428 .53306 .33737 .52698 .30448 Mtetra
.612 .455 .645 r
.52698 .30448 .53306 .33737 .5443 .33101 .53816 .29789 Mtetra
.606 .45 .644 r
.53816 .29789 .5443 .33101 .55557 .32512 .54937 .29189 Mtetra
.594 .442 .645 r
.54937 .29189 .55557 .32512 .56687 .31946 .56062 .287 Mtetra
.584 .438 .649 r
.56062 .287 .56687 .31946 .57821 .31385 .57193 .28318 Mtetra
.576 .438 .657 r
.57193 .28318 .57821 .31385 .58957 .30795 .5833 .28029 Mtetra
.571 .446 .671 r
.5833 .28029 .58957 .30795 .60097 .30193 .59474 .27805 Mtetra
.572 .466 .695 r
.59474 .27805 .60097 .30193 .6124 .29606 .60625 .27605 Mtetra
.574 .493 .726 r
.60625 .27605 .6124 .29606 .62388 .29059 .61783 .27426 Mtetra
.574 .529 .767 r
.61783 .27426 .62388 .29059 .63543 .28594 .62947 .27266 Mtetra
.57 .57 .814 r
.62947 .27266 .63543 .28594 .64705 .28206 .6412 .27127 Mtetra
.557 .612 .863 r
.6412 .27127 .64705 .28206 .65875 .27899 .653 .27017 Mtetra
.538 .654 .91 r
.653 .27017 .65875 .27899 .67054 .27655 .66489 .26924 Mtetra
.514 .691 .948 r
.66489 .26924 .67054 .27655 .68242 .27458 .67685 .26841 Mtetra
.492 .722 .974 r
.67685 .26841 .68242 .27458 .69438 .27295 .68889 .26754 Mtetra
.481 .747 .988 r
.68889 .26754 .69438 .27295 .70641 .27147 .70099 .26649 Mtetra
.481 .765 .994 r
.70099 .26649 .70641 .27147 .71853 .27005 .71316 .26521 Mtetra
.498 .78 .995 r
.71316 .26521 .71853 .27005 .73071 .26856 .72538 .26358 Mtetra
.521 .787 .993 r
.72538 .26358 .73071 .26856 .74296 .26695 .73764 .26163 Mtetra
.55 .788 .987 r
.73764 .26163 .74296 .26695 .75526 .26514 .74995 .25932 Mtetra
.574 .781 .977 r
.74995 .25932 .75526 .26514 .76762 .26315 .76231 .25673 Mtetra
.592 .767 .963 r
.76231 .25673 .76762 .26315 .78005 .26101 .77472 .25392 Mtetra
.605 .75 .947 r
.77472 .25392 .78005 .26101 .79252 .25872 .78718 .25095 Mtetra
.66 .752 .919 r
.13161 .46613 .13868 .4723 .14859 .46778 .14141 .46268 Mtetra
.663 .791 .943 r
.14141 .46268 .14859 .46778 .15854 .4631 .15127 .4591 Mtetra
.666 .832 .963 r
.15127 .4591 .15854 .4631 .16855 .45821 .16118 .45533 Mtetra
.666 .874 .977 r
.16118 .45533 .16855 .45821 .17861 .45305 .17116 .45128 Mtetra
.663 .912 .978 r
.17116 .45128 .17861 .45305 .18874 .44755 .1812 .44688 Mtetra
.652 .94 .964 r
.1812 .44688 .18874 .44755 .19892 .44173 .19132 .44208 Mtetra
.635 .954 .934 r
.19132 .44208 .19892 .44173 .20915 .43557 .20151 .43685 Mtetra
.612 .955 .893 r
.20151 .43685 .20915 .43557 .21943 .42918 .21177 .4312 Mtetra
.592 .948 .85 r
.21177 .4312 .21943 .42918 .22975 .42261 .22209 .42516 Mtetra
.577 .94 .817 r
.22209 .42516 .22975 .42261 .24009 .416 .23246 .4188 Mtetra
.578 .938 .801 r
.23246 .4188 .24009 .416 .25043 .40948 .24287 .41217 Mtetra
.6 .948 .81 r
.24287 .41217 .25043 .40948 .26079 .40312 .25332 .40534 Mtetra
.641 .966 .841 r
.25332 .40534 .26079 .40312 .27115 .39702 .2638 .39838 Mtetra
.697 .981 .885 r
.2638 .39838 .27115 .39702 .28151 .39113 .27431 .39132 Mtetra
.745 .977 .92 r
.27431 .39132 .28151 .39113 .29188 .38542 .28483 .38422 Mtetra
.767 .948 .937 r
.28483 .38422 .29188 .38542 .30227 .3799 .29536 .37732 Mtetra
.764 .906 .938 r
.29536 .37732 .30227 .3799 .31266 .37462 .30588 .37081 Mtetra
.741 .862 .937 r
.30588 .37081 .31266 .37462 .32305 .36998 .31637 .36503 Mtetra
.706 .818 .935 r
.31637 .36503 .32305 .36998 .33341 .36625 .32683 .36019 Mtetra
.677 .774 .924 r
.32683 .36019 .33341 .36625 .34375 .36357 .33728 .35609 Mtetra
.653 .722 .9 r
.33728 .35609 .34375 .36357 .35408 .36199 .34774 .35256 Mtetra
.644 .668 .858 r
.34774 .35256 .35408 .36199 .36443 .361 .35823 .34911 Mtetra
.641 .617 .811 r
.35823 .34911 .36443 .361 .37483 .36024 .36877 .34542 Mtetra
.635 .572 .767 r
.36877 .34542 .37483 .36024 .3853 .35925 .37938 .34138 Mtetra
.63 .538 .732 r
.37938 .34138 .3853 .35925 .39585 .35773 .39004 .33694 Mtetra
.622 .512 .707 r
.39004 .33694 .39585 .35773 .40648 .35564 .40074 .33232 Mtetra
.615 .492 .689 r
.40074 .33232 .40648 .35564 .41718 .35297 .41148 .32766 Mtetra
.607 .477 .678 r
.41148 .32766 .41718 .35297 .42795 .34986 .42225 .32318 Mtetra
.599 .466 .671 r
.42225 .32318 .42795 .34986 .43877 .34639 .43305 .31901 Mtetra
.593 .459 .668 r
.43305 .31901 .43877 .34639 .44964 .34264 .44388 .31521 Mtetra
.587 .456 .669 r
.44388 .31521 .44964 .34264 .46056 .33859 .45475 .31178 Mtetra
.584 .457 .672 r
.45475 .31178 .46056 .33859 .47153 .33418 .46565 .30865 Mtetra
.584 .462 .68 r
.46565 .30865 .47153 .33418 .48255 .32932 .47661 .30571 Mtetra
.588 .475 .692 r
.47661 .30571 .48255 .32932 .49361 .32387 .48761 .30273 Mtetra
.596 .496 .71 r
.48761 .30273 .49361 .32387 .5047 .31785 .49866 .29958 Mtetra
.611 .527 .735 r
.49866 .29958 .5047 .31785 .51583 .31129 .50977 .29602 Mtetra
.628 .569 .768 r
.50977 .29602 .51583 .31129 .52698 .30448 .52093 .29211 Mtetra
.647 .62 .809 r
.52093 .29211 .52698 .30448 .53816 .29789 .53213 .28795 Mtetra
.656 .673 .854 r
.53213 .28795 .53816 .29789 .54937 .29189 .54337 .28386 Mtetra
.642 .718 .903 r
.54337 .28386 .54937 .29189 .56062 .287 .55466 .28037 Mtetra
.606 .75 .946 r
.55466 .28037 .56062 .287 .57193 .28318 .56602 .27762 Mtetra
.54 .762 .979 r
.56602 .27762 .57193 .28318 .5833 .28029 .57745 .27583 Mtetra
.452 .766 .996 r
.57745 .27583 .5833 .28029 .59474 .27805 .58895 .27479 Mtetra
.351 .759 .982 r
.58895 .27479 .59474 .27805 .60625 .27605 .60054 .27417 Mtetra
.222 .72 .912 r
.60054 .27417 .60625 .27605 .61783 .27426 .6122 .27375 Mtetra
.095 .651 .789 r
.6122 .27375 .61783 .27426 .62947 .27266 .62394 .2733 Mtetra
.004 0 0 r
.62394 .2733 .62947 .27266 .6412 .27127 .63576 .27277 Mtetra
.064 0 0 r
.63576 .27277 .6412 .27127 .653 .27017 .64764 .2721 Mtetra
.082 0 0 r
.64764 .2721 .653 .27017 .66489 .26924 .6596 .27124 Mtetra
.064 0 0 r
.6596 .27124 .66489 .26924 .67685 .26841 .67162 .27011 Mtetra
.011 0 0 r
.67162 .27011 .67685 .26841 .68889 .26754 .68369 .26866 Mtetra
0 0 0 r
.68369 .26866 .68889 .26754 .70099 .26649 .69581 .26679 Mtetra
.195 .725 .772 r
.69581 .26679 .70099 .26649 .71316 .26521 .70798 .26451 Mtetra
.33 .811 .881 r
.70798 .26451 .71316 .26521 .72538 .26358 .72019 .26176 Mtetra
.452 .863 .958 r
.72019 .26176 .72538 .26358 .73764 .26163 .73244 .25862 Mtetra
.546 .875 .992 r
.73244 .25862 .73764 .26163 .74995 .25932 .74472 .25509 Mtetra
.604 .857 .992 r
.74472 .25509 .74995 .25932 .76231 .25673 .75703 .25128 Mtetra
.635 .824 .973 r
.75703 .25128 .76231 .25673 .77472 .25392 .76939 .24726 Mtetra
.649 .787 .948 r
.76939 .24726 .77472 .25392 .78718 .25095 .7818 .24311 Mtetra
.602 .737 .939 r
.12449 .45992 .13161 .46613 .14141 .46268 .13417 .45769 Mtetra
.592 .779 .969 r
.13417 .45769 .14141 .46268 .15127 .4591 .1439 .45539 Mtetra
.575 .823 .992 r
.1439 .45539 .15127 .4591 .16118 .45533 .15368 .45297 Mtetra
.545 .862 .996 r
.15368 .45297 .16118 .45533 .17116 .45128 .16353 .45034 Mtetra
.495 .881 .966 r
.16353 .45034 .17116 .45128 .1812 .44688 .17346 .44743 Mtetra
.416 .863 .884 r
.17346 .44743 .1812 .44688 .19132 .44208 .18346 .44418 Mtetra
.321 .803 .755 r
.18346 .44418 .19132 .44208 .20151 .43685 .19354 .44051 Mtetra
0 0 0 r
.19354 .44051 .20151 .43685 .21177 .4312 .2037 .43639 Mtetra
.2037 .43639 .21177 .4312 .22209 .42516 .21395 .43177 Mtetra
.21395 .43177 .22209 .42516 .23246 .4188 .22427 .42665 Mtetra
.22427 .42665 .23246 .4188 .24287 .41217 .23466 .42104 Mtetra
.23466 .42104 .24287 .41217 .25332 .40534 .24512 .41499 Mtetra
.008 0 0 r
.24512 .41499 .25332 .40534 .2638 .39838 .25564 .40856 Mtetra
.026 0 0 r
.25564 .40856 .2638 .39838 .27431 .39132 .26619 .40194 Mtetra
.049 0 0 r
.26619 .40194 .27431 .39132 .28483 .38422 .27676 .3953 Mtetra
.091 0 0 r
.27676 .3953 .28483 .38422 .29536 .37732 .28733 .38892 Mtetra
.144 0 0 r
.28733 .38892 .29536 .37732 .30588 .37081 .2979 .383 Mtetra
.186 0 .018 r
.2979 .383 .30588 .37081 .31637 .36503 .30847 .37743 Mtetra
.209 0 .037 r
.30847 .37743 .31637 .36503 .32683 .36019 .31904 .37211 Mtetra
.183 0 .011 r
.31904 .37211 .32683 .36019 .33728 .35609 .32967 .36655 Mtetra
.099 0 0 r
.32967 .36655 .33728 .35609 .34774 .35256 .34035 .36046 Mtetra
0 0 0 r
.34035 .36046 .34774 .35256 .35823 .34911 .35109 .3538 Mtetra
.402 .808 .597 r
.35109 .3538 .35823 .34911 .36877 .34542 .36188 .34659 Mtetra
.69 .981 .875 r
.36188 .34659 .36877 .34542 .37938 .34138 .37269 .33924 Mtetra
.776 .931 .934 r
.37269 .33924 .37938 .34138 .39004 .33694 .38352 .33206 Mtetra
.763 .838 .909 r
.38352 .33206 .39004 .33694 .40074 .33232 .39434 .32533 Mtetra
.731 .766 .881 r
.39434 .32533 .40074 .33232 .41148 .32766 .40516 .31926 Mtetra
.702 .72 .863 r
.40516 .31926 .41148 .32766 .42225 .32318 .41599 .3139 Mtetra
.676 .69 .855 r
.41599 .3139 .42225 .32318 .43305 .31901 .42682 .30931 Mtetra
.652 .671 .856 r
.42682 .30931 .43305 .31901 .44388 .31521 .43767 .30548 Mtetra
.628 .661 .863 r
.43767 .30548 .44388 .31521 .45475 .31178 .44854 .30241 Mtetra
.601 .659 .879 r
.44854 .30241 .45475 .31178 .46565 .30865 .45945 .30011 Mtetra
.569 .668 .905 r
.45945 .30011 .46565 .30865 .47661 .30571 .4704 .29853 Mtetra
.522 .691 .945 r
.4704 .29853 .47661 .30571 .48761 .30273 .4814 .29761 Mtetra
.436 .729 .988 r
.4814 .29761 .48761 .30273 .49866 .29958 .49246 .29717 Mtetra
.255 .727 .942 r
.49246 .29717 .49866 .29958 .50977 .29602 .50359 .2969 Mtetra
.036 0 0 r
.50359 .2969 .50977 .29602 .52093 .29211 .51479 .29651 Mtetra
.222 0 0 r
.51479 .29651 .52093 .29211 .53213 .28795 .52606 .29557 Mtetra
.303 0 0 r
.52606 .29557 .53213 .28795 .54337 .28386 .5374 .29406 Mtetra
.336 0 .052 r
.5374 .29406 .54337 .28386 .55466 .28037 .5488 .29201 Mtetra
.352 0 .098 r
.5488 .29201 .55466 .28037 .56602 .27762 .56026 .28972 Mtetra
.368 0 .116 r
.56026 .28972 .56602 .27762 .57745 .27583 .57179 .2877 Mtetra
.378 0 .115 r
.57179 .2877 .57745 .27583 .58895 .27479 .58338 .28604 Mtetra
.387 0 .103 r
.58338 .28604 .58895 .27479 .60054 .27417 .59505 .28485 Mtetra
.389 0 .088 r
.59505 .28485 .60054 .27417 .6122 .27375 .6068 .28394 Mtetra
.381 0 .07 r
.6068 .28394 .6122 .27375 .62394 .2733 .61862 .28301 Mtetra
.367 0 .048 r
.61862 .28301 .62394 .2733 .63576 .27277 .63051 .2819 Mtetra
.341 0 .017 r
.63051 .2819 .63576 .27277 .64764 .2721 .64245 .2804 Mtetra
.303 0 0 r
.64245 .2804 .64764 .2721 .6596 .27124 .65445 .27846 Mtetra
.246 0 0 r
.65445 .27846 .6596 .27124 .67162 .27011 .6665 .276 Mtetra
.164 0 0 r
.6665 .276 .67162 .27011 .68369 .26866 .67858 .27304 Mtetra
.044 0 0 r
.67858 .27304 .68369 .26866 .69581 .26679 .6907 .26956 Mtetra
0 0 0 r
.6907 .26956 .69581 .26679 .70798 .26451 .70285 .26561 Mtetra
.311 .796 .747 r
.70285 .26561 .70798 .26451 .72019 .26176 .71503 .26121 Mtetra
.485 .899 .897 r
.71503 .26121 .72019 .26176 .73244 .25862 .72723 .25646 Mtetra
.604 .925 .968 r
.72723 .25646 .73244 .25862 .74472 .25509 .73947 .2514 Mtetra
.665 .901 .979 r
.73947 .2514 .74472 .25509 .75703 .25128 .75173 .24613 Mtetra
.691 .858 .962 r
.75173 .24613 .75703 .25128 .76939 .24726 .76403 .24071 Mtetra
.698 .811 .935 r
.76403 .24071 .76939 .24726 .7818 .24311 .77637 .23521 Mtetra
.545 .718 .953 r
.11732 .45366 .12449 .45992 .13417 .45769 .1269 .45237 Mtetra
.527 .747 .976 r
.1269 .45237 .13417 .45769 .1439 .45539 .13653 .45109 Mtetra
.503 .777 .994 r
.13653 .45109 .1439 .45539 .15368 .45297 .14621 .44975 Mtetra
.467 .804 .999 r
.14621 .44975 .15368 .45297 .16353 .45034 .15595 .44831 Mtetra
.413 .819 .979 r
.15595 .44831 .16353 .45034 .17346 .44743 .16576 .44673 Mtetra
.337 .807 .917 r
.16576 .44673 .17346 .44743 .18346 .44418 .17565 .44491 Mtetra
.241 .757 .801 r
.17565 .44491 .18346 .44418 .19354 .44051 .18561 .4428 Mtetra
0 0 0 r
.18561 .4428 .19354 .44051 .2037 .43639 .19565 .44033 Mtetra
.19565 .44033 .2037 .43639 .21395 .43177 .20578 .43742 Mtetra
.038 0 0 r
.20578 .43742 .21395 .43177 .22427 .42665 .216 .43406 Mtetra
.097 0 0 r
.216 .43406 .22427 .42665 .23466 .42104 .2263 .43022 Mtetra
.147 0 0 r
.2263 .43022 .23466 .42104 .24512 .41499 .23668 .42594 Mtetra
.187 0 0 r
.23668 .42594 .24512 .41499 .25564 .40856 .24712 .42126 Mtetra
.226 0 .044 r
.24712 .42126 .25564 .40856 .26619 .40194 .25762 .41635 Mtetra
.261 0 .099 r
.25762 .41635 .26619 .40194 .27676 .3953 .26816 .41134 Mtetra
.292 0 .144 r
.26816 .41134 .27676 .3953 .28733 .38892 .27873 .40632 Mtetra
.316 0 .176 r
.27873 .40632 .28733 .38892 .2979 .383 .28933 .40138 Mtetra
.322 0 .193 r
.28933 .40138 .2979 .383 .30847 .37743 .29997 .39624 Mtetra
.317 0 .196 r
.29997 .39624 .30847 .37743 .31904 .37211 .31067 .39075 Mtetra
.297 0 .185 r
.31067 .39075 .31904 .37211 .32967 .36655 .32143 .38471 Mtetra
.268 0 .165 r
.32143 .38471 .32967 .36655 .34035 .36046 .33226 .37802 Mtetra
.248 0 .148 r
.33226 .37802 .34035 .36046 .35109 .3538 .34313 .37103 Mtetra
.241 0 .141 r
.34313 .37103 .35109 .3538 .36188 .34659 .35402 .36396 Mtetra
.256 0 .151 r
.35402 .36396 .36188 .34659 .37269 .33924 .36492 .35719 Mtetra
.286 0 .174 r
.36492 .35719 .37269 .33924 .38352 .33206 .37582 .35095 Mtetra
.319 0 .201 r
.37582 .35095 .38352 .33206 .39434 .32533 .38672 .34528 Mtetra
.349 .002 .227 r
.38672 .34528 .39434 .32533 .40516 .31926 .39762 .3402 Mtetra
.371 .028 .247 r
.39762 .3402 .40516 .31926 .41599 .3139 .40854 .3356 Mtetra
.388 .047 .261 r
.40854 .3356 .41599 .3139 .42682 .30931 .41949 .33141 Mtetra
.399 .059 .269 r
.41949 .33141 .42682 .30931 .43767 .30548 .43046 .32757 Mtetra
.407 .067 .273 r
.43046 .32757 .43767 .30548 .44854 .30241 .44147 .32408 Mtetra
.414 .071 .272 r
.44147 .32408 .44854 .30241 .45945 .30011 .45252 .32101 Mtetra
.421 .073 .267 r
.45252 .32101 .45945 .30011 .4704 .29853 .46361 .31842 Mtetra
.43 .075 .26 r
.46361 .31842 .4704 .29853 .4814 .29761 .47475 .31643 Mtetra
.437 .076 .252 r
.47475 .31643 .4814 .29761 .49246 .29717 .48594 .31502 Mtetra
.445 .076 .243 r
.48594 .31502 .49246 .29717 .50359 .2969 .49718 .31416 Mtetra
.45 .076 .237 r
.49718 .31416 .50359 .2969 .51479 .29651 .5085 .31361 Mtetra
.447 .072 .233 r
.5085 .31361 .51479 .29651 .52606 .29557 .51988 .31299 Mtetra
.442 .069 .235 r
.51988 .31299 .52606 .29557 .5374 .29406 .53134 .31206 Mtetra
.43 .062 .237 r
.53134 .31206 .5374 .29406 .5488 .29201 .54286 .31049 Mtetra
.419 .056 .238 r
.54286 .31049 .5488 .29201 .56026 .28972 .55445 .30836 Mtetra
.412 .05 .237 r
.55445 .30836 .56026 .28972 .57179 .2877 .56609 .30588 Mtetra
.405 .04 .229 r
.56609 .30588 .57179 .2877 .58338 .28604 .57779 .30321 Mtetra
.399 .028 .214 r
.57779 .30321 .58338 .28604 .59505 .28485 .58955 .30061 Mtetra
.388 .006 .188 r
.58955 .30061 .59505 .28485 .6068 .28394 .60137 .29801 Mtetra
.368 0 .151 r
.60137 .29801 .6068 .28394 .61862 .28301 .61326 .29531 Mtetra
.336 0 .1 r
.61326 .29531 .61862 .28301 .63051 .2819 .62519 .29236 Mtetra
.287 0 .031 r
.62519 .29236 .63051 .2819 .64245 .2804 .63717 .28901 Mtetra
.217 0 0 r
.63717 .28901 .64245 .2804 .65445 .27846 .64919 .28521 Mtetra
.115 0 0 r
.64919 .28521 .65445 .27846 .6665 .276 .66124 .2809 Mtetra
0 0 0 r
.66124 .2809 .6665 .276 .67858 .27304 .67333 .27612 Mtetra
.67333 .27612 .67858 .27304 .6907 .26956 .68543 .27089 Mtetra
.399 .847 .755 r
.68543 .27089 .6907 .26956 .70285 .26561 .69756 .26527 Mtetra
.559 .934 .89 r
.69756 .26527 .70285 .26561 .71503 .26121 .70972 .25933 Mtetra
.658 .951 .952 r
.70972 .25933 .71503 .26121 .72723 .25646 .72189 .25315 Mtetra
.707 .927 .964 r
.72189 .25315 .72723 .25646 .73947 .2514 .7341 .2468 Mtetra
.728 .889 .954 r
.7341 .2468 .73947 .2514 .75173 .24613 .74633 .24033 Mtetra
.733 .849 .935 r
.74633 .24033 .75173 .24613 .76403 .24071 .7586 .23379 Mtetra
.73 .812 .915 r
.7586 .23379 .76403 .24071 .77637 .23521 .7709 .22725 Mtetra
.51 .705 .958 r
.1101 .44736 .11732 .45366 .1269 .45237 .11963 .44657 Mtetra
.494 .718 .971 r
.11963 .44657 .1269 .45237 .13653 .45109 .12921 .44584 Mtetra
.475 .732 .982 r
.12921 .44584 .13653 .45109 .14621 .44975 .13883 .44513 Mtetra
.452 .747 .992 r
.13883 .44513 .14621 .44975 .15595 .44831 .14851 .44444 Mtetra
.418 .761 .995 r
.14851 .44444 .15595 .44831 .16576 .44673 .15824 .44374 Mtetra
.375 .772 .986 r
.15824 .44374 .16576 .44673 .17565 .44491 .16804 .44296 Mtetra
.314 .77 .952 r
.16804 .44296 .17565 .44491 .18561 .4428 .1779 .44206 Mtetra
.233 .744 .876 r
.1779 .44206 .18561 .4428 .19565 .44033 .18784 .44097 Mtetra
.135 .682 .751 r
.18784 .44097 .19565 .44033 .20578 .43742 .19785 .43961 Mtetra
0 0 0 r
.19785 .43961 .20578 .43742 .216 .43406 .20795 .43798 Mtetra
.07 0 0 r
.20795 .43798 .216 .43406 .2263 .43022 .21812 .43602 Mtetra
.155 0 0 r
.21812 .43602 .2263 .43022 .23668 .42594 .22838 .43377 Mtetra
.221 0 0 r
.22838 .43377 .23668 .42594 .24712 .42126 .23871 .43124 Mtetra
.271 0 0 r
.23871 .43124 .24712 .42126 .25762 .41635 .2491 .42847 Mtetra
.307 0 .072 r
.2491 .42847 .25762 .41635 .26816 .41134 .25956 .42546 Mtetra
.325 0 .124 r
.25956 .42546 .26816 .41134 .27873 .40632 .27009 .42209 Mtetra
.33 0 .155 r
.27009 .42209 .27873 .40632 .28933 .40138 .2807 .41825 Mtetra
.323 0 .168 r
.2807 .41825 .28933 .40138 .29997 .39624 .2914 .41379 Mtetra
.308 0 .17 r
.2914 .41379 .29997 .39624 .31067 .39075 .30218 .40863 Mtetra
.299 0 .171 r
.30218 .40863 .31067 .39075 .32143 .38471 .31302 .40308 Mtetra
.302 0 .179 r
.31302 .40308 .32143 .38471 .33226 .37802 .3239 .39738 Mtetra
.327 0 .203 r
.3239 .39738 .33226 .37802 .34313 .37103 .33479 .39205 Mtetra
.363 .017 .238 r
.33479 .39205 .34313 .37103 .35402 .36396 .34568 .38735 Mtetra
.396 .06 .273 r
.34568 .38735 .35402 .36396 .36492 .35719 .35656 .38332 Mtetra
.423 .096 .304 r
.35656 .38332 .36492 .35719 .37582 .35095 .36746 .37991 Mtetra
.439 .12 .326 r
.36746 .37991 .37582 .35095 .38672 .34528 .37839 .3768 Mtetra
.447 .135 .342 r
.37839 .3768 .38672 .34528 .39762 .3402 .38937 .37379 Mtetra
.45 .143 .351 r
.38937 .37379 .39762 .3402 .40854 .3356 .4004 .37064 Mtetra
.449 .145 .356 r
.4004 .37064 .40854 .3356 .41949 .33141 .41149 .36718 Mtetra
.446 .144 .358 r
.41149 .36718 .41949 .33141 .43046 .32757 .42265 .36335 Mtetra
.441 .14 .356 r
.42265 .36335 .43046 .32757 .44147 .32408 .43385 .35914 Mtetra
.436 .133 .352 r
.43385 .35914 .44147 .32408 .45252 .32101 .44511 .35463 Mtetra
.43 .125 .344 r
.44511 .35463 .45252 .32101 .46361 .31842 .45642 .34997 Mtetra
.425 .115 .334 r
.45642 .34997 .46361 .31842 .47475 .31643 .46776 .3454 Mtetra
.422 .104 .32 r
.46776 .3454 .47475 .31643 .48594 .31502 .47914 .34114 Mtetra
.422 .094 .303 r
.47914 .34114 .48594 .31502 .49718 .31416 .49057 .33751 Mtetra
.423 .083 .283 r
.49057 .33751 .49718 .31416 .5085 .31361 .50203 .33454 Mtetra
.425 .073 .263 r
.50203 .33454 .5085 .31361 .51988 .31299 .51355 .33223 Mtetra
.424 .063 .245 r
.51355 .33223 .51988 .31299 .53134 .31206 .52513 .33029 Mtetra
.415 .047 .229 r
.52513 .33029 .53134 .31206 .54286 .31049 .53677 .3282 Mtetra
.402 .032 .217 r
.53677 .3282 .54286 .31049 .55445 .30836 .54848 .32573 Mtetra
.381 .011 .204 r
.54848 .32573 .55445 .30836 .56609 .30588 .56023 .32254 Mtetra
.358 0 .185 r
.56023 .32254 .56609 .30588 .57779 .30321 .57204 .31872 Mtetra
.331 0 .156 r
.57204 .31872 .57779 .30321 .58955 .30061 .58388 .31442 Mtetra
.293 0 .11 r
.58388 .31442 .58955 .30061 .60137 .29801 .59577 .30973 Mtetra
.243 0 .041 r
.59577 .30973 .60137 .29801 .61326 .29531 .6077 .30481 Mtetra
.168 0 0 r
.6077 .30481 .61326 .29531 .62519 .29236 .61967 .29962 Mtetra
.056 0 0 r
.61967 .29962 .62519 .29236 .63717 .28901 .63167 .29414 Mtetra
0 0 0 r
.63167 .29414 .63717 .28901 .64919 .28521 .6437 .28835 Mtetra
.6437 .28835 .64919 .28521 .66124 .2809 .65575 .28221 Mtetra
.477 .89 .779 r
.65575 .28221 .66124 .2809 .67333 .27612 .66783 .27578 Mtetra
.617 .957 .894 r
.66783 .27578 .67333 .27612 .68543 .27089 .67993 .26906 Mtetra
.697 .962 .943 r
.67993 .26906 .68543 .27089 .69756 .26527 .69206 .26213 Mtetra
.736 .937 .952 r
.69206 .26213 .69756 .26527 .70972 .25933 .7042 .25506 Mtetra
.751 .905 .945 r
.7042 .25506 .70972 .25933 .72189 .25315 .71638 .24789 Mtetra
.754 .873 .933 r
.71638 .24789 .72189 .25315 .7341 .2468 .72858 .24071 Mtetra
.752 .845 .921 r
.72858 .24071 .7341 .2468 .74633 .24033 .74082 .23352 Mtetra
.748 .822 .909 r
.74082 .23352 .74633 .24033 .7586 .23379 .75308 .22635 Mtetra
.743 .801 .899 r
.75308 .22635 .7586 .23379 .7709 .22725 .76539 .21923 Mtetra
.524 .71 .956 r
.10283 .44102 .1101 .44736 .11963 .44657 .1124 .44 Mtetra
.521 .702 .952 r
.1124 .44 .11963 .44657 .12921 .44584 .12201 .43907 Mtetra
.518 .695 .949 r
.12201 .43907 .12921 .44584 .13883 .44513 .13166 .43823 Mtetra
.514 .689 .947 r
.13166 .43823 .13883 .44513 .14851 .44444 .14136 .43748 Mtetra
.507 .685 .947 r
.14136 .43748 .14851 .44444 .15824 .44374 .1511 .43683 Mtetra
.501 .685 .949 r
.1511 .43683 .15824 .44374 .16804 .44296 .16088 .43625 Mtetra
.494 .69 .955 r
.16088 .43625 .16804 .44296 .1779 .44206 .17072 .43569 Mtetra
.488 .7 .963 r
.17072 .43569 .1779 .44206 .18784 .44097 .18061 .43512 Mtetra
.48 .717 .974 r
.18061 .43512 .18784 .44097 .19785 .43961 .19057 .43448 Mtetra
.467 .739 .987 r
.19057 .43448 .19785 .43961 .20795 .43798 .2006 .43372 Mtetra
.448 .764 .996 r
.2006 .43372 .20795 .43798 .21812 .43602 .21071 .4328 Mtetra
.414 .787 .994 r
.21071 .4328 .21812 .43602 .22838 .43377 .22088 .4317 Mtetra
.364 .796 .966 r
.22088 .4317 .22838 .43377 .23871 .43124 .23113 .43038 Mtetra
.3 .785 .906 r
.23113 .43038 .23871 .43124 .2491 .42847 .24146 .42879 Mtetra
.232 .751 .817 r
.24146 .42879 .2491 .42847 .25956 .42546 .25187 .42688 Mtetra
.184 .714 .726 r
.25187 .42688 .25956 .42546 .27009 .42209 .26237 .42453 Mtetra
0 0 0 r
.26237 .42453 .27009 .42209 .2807 .41825 .27296 .42165 Mtetra
.27296 .42165 .2807 .41825 .2914 .41379 .28363 .41832 Mtetra
.28363 .41832 .2914 .41379 .30218 .40863 .29438 .4146 Mtetra
.042 0 0 r
.29438 .4146 .30218 .40863 .31302 .40308 .30516 .41092 Mtetra
.165 0 0 r
.30516 .41092 .31302 .40308 .3239 .39738 .31597 .40755 Mtetra
.273 0 0 r
.31597 .40755 .3239 .39738 .33479 .39205 .32679 .40468 Mtetra
.348 0 .103 r
.32679 .40468 .33479 .39205 .34568 .38735 .33763 .40241 Mtetra
.388 0 .17 r
.33763 .40241 .34568 .38735 .35656 .38332 .3485 .40045 Mtetra
.409 .033 .21 r
.3485 .40045 .35656 .38332 .36746 .37991 .35942 .39862 Mtetra
.415 .049 .232 r
.35942 .39862 .36746 .37991 .37839 .3768 .37041 .39662 Mtetra
.413 .053 .243 r
.37041 .39662 .37839 .3768 .38937 .37379 .38148 .39427 Mtetra
.406 .051 .246 r
.38148 .39427 .38937 .37379 .4004 .37064 .39261 .39147 Mtetra
.396 .043 .245 r
.39261 .39147 .4004 .37064 .41149 .36718 .40382 .38816 Mtetra
.384 .034 .242 r
.40382 .38816 .41149 .36718 .42265 .36335 .4151 .38432 Mtetra
.372 .022 .237 r
.4151 .38432 .42265 .36335 .43385 .35914 .42644 .37996 Mtetra
.358 .009 .23 r
.42644 .37996 .43385 .35914 .44511 .35463 .43784 .37508 Mtetra
.343 0 .22 r
.43784 .37508 .44511 .35463 .45642 .34997 .44929 .36975 Mtetra
.327 0 .207 r
.44929 .36975 .45642 .34997 .46776 .3454 .46078 .36406 Mtetra
.31 0 .186 r
.46078 .36406 .46776 .3454 .47914 .34114 .47231 .35819 Mtetra
.294 0 .158 r
.47231 .35819 .47914 .34114 .49057 .33751 .48388 .35244 Mtetra
.272 0 .114 r
.48388 .35244 .49057 .33751 .50203 .33454 .49548 .347 Mtetra
.248 0 .051 r
.49548 .347 .50203 .33454 .51355 .33223 .50711 .34216 Mtetra
.207 0 0 r
.50711 .34216 .51355 .33223 .52513 .33029 .51879 .33782 Mtetra
.14 0 0 r
.51879 .33782 .52513 .33029 .53677 .3282 .53051 .3338 Mtetra
.044 0 0 r
.53051 .3338 .53677 .3282 .54848 .32573 .54228 .32981 Mtetra
0 0 0 r
.54228 .32981 .54848 .32573 .56023 .32254 .55411 .32543 Mtetra
.55411 .32543 .56023 .32254 .57204 .31872 .56597 .32058 Mtetra
.373 .829 .735 r
.56597 .32058 .57204 .31872 .58388 .31442 .57787 .31518 Mtetra
.503 .909 .838 r
.57787 .31518 .58388 .31442 .59577 .30973 .5898 .30933 Mtetra
.606 .951 .91 r
.5898 .30933 .59577 .30973 .6077 .30481 .60176 .30313 Mtetra
.681 .956 .949 r
.60176 .30313 .6077 .30481 .61967 .29962 .61375 .29665 Mtetra
.725 .934 .957 r
.61375 .29665 .61967 .29962 .63167 .29414 .62577 .28993 Mtetra
.745 .899 .947 r
.62577 .28993 .63167 .29414 .6437 .28835 .63781 .28301 Mtetra
.753 .863 .93 r
.63781 .28301 .6437 .28835 .65575 .28221 .64988 .27592 Mtetra
.754 .832 .912 r
.64988 .27592 .65575 .28221 .66783 .27578 .66197 .26869 Mtetra
.752 .808 .897 r
.66197 .26869 .66783 .27578 .67993 .26906 .67409 .26137 Mtetra
.748 .79 .887 r
.67409 .26137 .67993 .26906 .69206 .26213 .68623 .25402 Mtetra
.745 .778 .88 r
.68623 .25402 .69206 .26213 .7042 .25506 .69841 .24668 Mtetra
.741 .771 .877 r
.69841 .24668 .7042 .25506 .71638 .24789 .71062 .2394 Mtetra
.738 .767 .877 r
.71062 .2394 .71638 .24789 .72858 .24071 .72286 .23222 Mtetra
.736 .768 .879 r
.72286 .23222 .72858 .24071 .74082 .23352 .73514 .22511 Mtetra
.734 .771 .882 r
.73514 .22511 .74082 .23352 .75308 .22635 .74747 .21809 Mtetra
.733 .775 .887 r
.74747 .21809 .75308 .22635 .76539 .21923 .75983 .21113 Mtetra
.573 .727 .947 r
.09551 .43462 .10283 .44102 .1124 .44 .10519 .43283 Mtetra
.574 .702 .929 r
.10519 .43283 .1124 .44 .12201 .43907 .11491 .43111 Mtetra
.572 .678 .912 r
.11491 .43111 .12201 .43907 .13166 .43823 .12466 .42951 Mtetra
.568 .656 .895 r
.12466 .42951 .13166 .43823 .14136 .43748 .13445 .42806 Mtetra
.562 .635 .881 r
.13445 .42806 .14136 .43748 .1511 .43683 .14426 .42678 Mtetra
.557 .618 .869 r
.14426 .42678 .1511 .43683 .16088 .43625 .15411 .42566 Mtetra
.551 .603 .859 r
.15411 .42566 .16088 .43625 .17072 .43569 .16399 .42471 Mtetra
.547 .593 .852 r
.16399 .42471 .17072 .43569 .18061 .43512 .17392 .42388 Mtetra
.544 .587 .848 r
.17392 .42388 .18061 .43512 .19057 .43448 .18389 .42314 Mtetra
.542 .585 .847 r
.18389 .42314 .19057 .43448 .2006 .43372 .19391 .42243 Mtetra
.543 .587 .848 r
.19391 .42243 .2006 .43372 .21071 .4328 .20399 .42169 Mtetra
.546 .593 .852 r
.20399 .42169 .21071 .4328 .22088 .4317 .21415 .42086 Mtetra
.552 .602 .858 r
.21415 .42086 .22088 .4317 .23113 .43038 .22437 .41986 Mtetra
.561 .615 .863 r
.22437 .41986 .23113 .43038 .24146 .42879 .23468 .4186 Mtetra
.573 .629 .869 r
.23468 .4186 .24146 .42879 .25187 .42688 .24507 .41701 Mtetra
.585 .642 .874 r
.24507 .41701 .25187 .42688 .26237 .42453 .25554 .41511 Mtetra
.596 .659 .882 r
.25554 .41511 .26237 .42453 .27296 .42165 .26609 .41291 Mtetra
.595 .677 .898 r
.26609 .41291 .27296 .42165 .28363 .41832 .27669 .41068 Mtetra
.583 .705 .927 r
.27669 .41068 .28363 .41832 .29438 .4146 .28734 .40862 Mtetra
.541 .746 .971 r
.28734 .40862 .29438 .4146 .30516 .41092 .298 .40698 Mtetra
.435 .777 .997 r
.298 .40698 .30516 .41092 .31597 .40755 .30869 .40589 Mtetra
.253 .744 .916 r
.30869 .40589 .31597 .40755 .32679 .40468 .31942 .40508 Mtetra
.054 .621 .716 r
.31942 .40508 .32679 .40468 .33763 .40241 .33021 .40437 Mtetra
.041 0 0 r
.33021 .40437 .33763 .40241 .3485 .40045 .34108 .40335 Mtetra
.052 0 0 r
.34108 .40335 .3485 .40045 .35942 .39862 .35205 .40178 Mtetra
.01 0 0 r
.35205 .40178 .35942 .39862 .37041 .39662 .3631 .39962 Mtetra
0 0 0 r
.3631 .39962 .37041 .39662 .38148 .39427 .37424 .39685 Mtetra
.37424 .39685 .38148 .39427 .39261 .39147 .38546 .39363 Mtetra
.225 .734 .687 r
.38546 .39363 .39261 .39147 .40382 .38816 .39674 .39005 Mtetra
.276 .772 .726 r
.39674 .39005 .40382 .38816 .4151 .38432 .40808 .38619 Mtetra
.304 .791 .738 r
.40808 .38619 .4151 .38432 .42644 .37996 .41947 .38206 Mtetra
.319 .797 .727 r
.41947 .38206 .42644 .37996 .43784 .37508 .43092 .37755 Mtetra
.326 .797 .703 r
.43092 .37755 .43784 .37508 .44929 .36975 .44243 .3726 Mtetra
.349 .805 .684 r
.44243 .3726 .44929 .36975 .46078 .36406 .45399 .36703 Mtetra
.39 .828 .689 r
.45399 .36703 .46078 .36406 .47231 .35819 .4656 .36085 Mtetra
.463 .874 .729 r
.4656 .36085 .47231 .35819 .48388 .35244 .47725 .35411 Mtetra
.564 .934 .812 r
.47725 .35411 .48388 .35244 .49548 .347 .48893 .34705 Mtetra
.659 .969 .902 r
.48893 .34705 .49548 .347 .50711 .34216 .50065 .34006 Mtetra
.72 .948 .953 r
.50065 .34006 .50711 .34216 .51879 .33782 .51238 .33336 Mtetra
.726 .875 .951 r
.51238 .33336 .51879 .33782 .53051 .3338 .52415 .3272 Mtetra
.712 .801 .921 r
.52415 .3272 .53051 .3338 .54228 .32981 .53595 .32147 Mtetra
.699 .746 .888 r
.53595 .32147 .54228 .32981 .55411 .32543 .5478 .3159 Mtetra
.693 .714 .865 r
.5478 .3159 .55411 .32543 .56597 .32058 .55968 .31029 Mtetra
.696 .699 .849 r
.55968 .31029 .56597 .32058 .57787 .31518 .5716 .30437 Mtetra
.7 .69 .837 r
.5716 .30437 .57787 .31518 .5898 .30933 .58355 .29812 Mtetra
.704 .685 .828 r
.58355 .29812 .5898 .30933 .60176 .30313 .59553 .29152 Mtetra
.707 .679 .82 r
.59553 .29152 .60176 .30313 .61375 .29665 .60753 .28464 Mtetra
.708 .672 .813 r
.60753 .28464 .61375 .29665 .62577 .28993 .61956 .27758 Mtetra
.707 .667 .808 r
.61956 .27758 .62577 .28993 .63781 .28301 .63162 .2704 Mtetra
.706 .662 .804 r
.63162 .2704 .63781 .28301 .64988 .27592 .6437 .26318 Mtetra
.704 .66 .803 r
.6437 .26318 .64988 .27592 .66197 .26869 .65582 .25599 Mtetra
.703 .66 .805 r
.65582 .25599 .66197 .26869 .67409 .26137 .66797 .24887 Mtetra
.702 .664 .809 r
.66797 .24887 .67409 .26137 .68623 .25402 .68016 .24186 Mtetra
.702 .671 .817 r
.68016 .24186 .68623 .25402 .69841 .24668 .69239 .23502 Mtetra
.702 .68 .826 r
.69239 .23502 .69841 .24668 .71062 .2394 .70466 .22833 Mtetra
.702 .693 .839 r
.70466 .22833 .71062 .2394 .72286 .23222 .71698 .22182 Mtetra
.703 .709 .853 r
.71698 .22182 .72286 .23222 .73514 .22511 .72935 .21544 Mtetra
.705 .728 .868 r
.72935 .21544 .73514 .22511 .74747 .21809 .74176 .20917 Mtetra
.708 .75 .885 r
.74176 .20917 .74747 .21809 .75983 .21113 .75422 .20298 Mtetra
.636 .746 .928 r
.08813 .42819 .09551 .43462 .10519 .43283 .09799 .42514 Mtetra
.633 .708 .9 r
.09799 .42514 .10519 .43283 .11491 .43111 .10788 .42216 Mtetra
.627 .672 .874 r
.10788 .42216 .11491 .43111 .12466 .42951 .1178 .41929 Mtetra
.618 .64 .85 r
.1178 .41929 .12466 .42951 .13445 .42806 .12775 .41657 Mtetra
.608 .61 .828 r
.12775 .41657 .13445 .42806 .14426 .42678 .13771 .41405 Mtetra
.599 .584 .808 r
.13771 .41405 .14426 .42678 .15411 .42566 .14769 .41174 Mtetra
.589 .561 .791 r
.14769 .41174 .15411 .42566 .16399 .42471 .15769 .40964 Mtetra
.582 .542 .775 r
.15769 .40964 .16399 .42471 .17392 .42388 .16772 .40773 Mtetra
.575 .525 .762 r
.16772 .40773 .17392 .42388 .18389 .42314 .17779 .40599 Mtetra
.57 .512 .751 r
.17779 .40599 .18389 .42314 .19391 .42243 .18789 .40437 Mtetra
.567 .502 .741 r
.18789 .40437 .19391 .42243 .20399 .42169 .19803 .40282 Mtetra
.566 .494 .733 r
.19803 .40282 .20399 .42169 .21415 .42086 .20823 .40126 Mtetra
.566 .488 .726 r
.20823 .40126 .21415 .42086 .22437 .41986 .21849 .39965 Mtetra
.567 .484 .721 r
.21849 .39965 .22437 .41986 .23468 .4186 .22882 .39792 Mtetra
.57 .483 .717 r
.22882 .39792 .23468 .4186 .24507 .41701 .23921 .39604 Mtetra
.571 .481 .715 r
.23921 .39604 .24507 .41701 .25554 .41511 .24966 .39409 Mtetra
.571 .482 .715 r
.24966 .39409 .25554 .41511 .26609 .41291 .26016 .39211 Mtetra
.568 .482 .717 r
.26016 .39211 .26609 .41291 .27669 .41068 .27071 .39029 Mtetra
.563 .482 .722 r
.27071 .39029 .27669 .41068 .28734 .40862 .28129 .38874 Mtetra
.559 .484 .728 r
.28129 .38874 .28734 .40862 .298 .40698 .29191 .38742 Mtetra
.556 .486 .732 r
.29191 .38742 .298 .40698 .30869 .40589 .30258 .38624 Mtetra
.561 .488 .731 r
.30258 .38624 .30869 .40589 .31942 .40508 .31333 .38482 Mtetra
.57 .489 .725 r
.31333 .38482 .31942 .40508 .33021 .40437 .32417 .38291 Mtetra
.58 .487 .713 r
.32417 .38291 .33021 .40437 .34108 .40335 .3351 .38037 Mtetra
.589 .483 .701 r
.3351 .38037 .34108 .40335 .35205 .40178 .34613 .37712 Mtetra
.593 .476 .689 r
.34613 .37712 .35205 .40178 .3631 .39962 .35723 .37337 Mtetra
.594 .469 .679 r
.35723 .37337 .3631 .39962 .37424 .39685 .36839 .3693 Mtetra
.592 .462 .672 r
.36839 .3693 .37424 .39685 .38546 .39363 .3796 .36515 Mtetra
.589 .456 .667 r
.3796 .36515 .38546 .39363 .39674 .39005 .39086 .36108 Mtetra
.586 .452 .665 r
.39086 .36108 .39674 .39005 .40808 .38619 .40215 .35717 Mtetra
.583 .45 .665 r
.40215 .35717 .40808 .38619 .41947 .38206 .41348 .35343 Mtetra
.583 .452 .668 r
.41348 .35343 .41947 .38206 .43092 .37755 .42486 .34977 Mtetra
.585 .457 .672 r
.42486 .34977 .43092 .37755 .44243 .3726 .43629 .34603 Mtetra
.592 .468 .679 r
.43629 .34603 .44243 .3726 .45399 .36703 .44778 .34195 Mtetra
.603 .482 .688 r
.44778 .34195 .45399 .36703 .4656 .36085 .45933 .33738 Mtetra
.618 .501 .697 r
.45933 .33738 .4656 .36085 .47725 .35411 .47094 .33209 Mtetra
.633 .519 .707 r
.47094 .33209 .47725 .35411 .48893 .34705 .48259 .32615 Mtetra
.645 .534 .714 r
.48259 .32615 .48893 .34705 .50065 .34006 .49428 .31971 Mtetra
.651 .542 .718 r
.49428 .31971 .50065 .34006 .51238 .33336 .50601 .31301 Mtetra
.648 .541 .719 r
.50601 .31301 .51238 .33336 .52415 .3272 .51777 .30646 Mtetra
.643 .535 .716 r
.51777 .30646 .52415 .3272 .53595 .32147 .52956 .30011 Mtetra
.637 .527 .712 r
.52956 .30011 .53595 .32147 .5478 .3159 .54138 .29404 Mtetra
.632 .521 .709 r
.54138 .29404 .5478 .3159 .55968 .31029 .55324 .28812 Mtetra
.631 .518 .707 r
.55324 .28812 .55968 .31029 .5716 .30437 .56514 .28217 Mtetra
.632 .519 .707 r
.56514 .28217 .5716 .30437 .58355 .29812 .57708 .27613 Mtetra
.635 .522 .708 r
.57708 .27613 .58355 .29812 .59553 .29152 .58905 .26992 Mtetra
.638 .527 .711 r
.58905 .26992 .59553 .29152 .60753 .28464 .60106 .2636 Mtetra
.642 .533 .716 r
.60106 .2636 .60753 .28464 .61956 .27758 .61309 .25719 Mtetra
.645 .54 .721 r
.61309 .25719 .61956 .27758 .63162 .2704 .62517 .25078 Mtetra
.647 .548 .729 r
.62517 .25078 .63162 .2704 .6437 .26318 .63728 .24443 Mtetra
.649 .557 .737 r
.63728 .24443 .6437 .26318 .65582 .25599 .64944 .23818 Mtetra
.651 .568 .748 r
.64944 .23818 .65582 .25599 .66797 .24887 .66164 .23211 Mtetra
.653 .58 .761 r
.66164 .23211 .66797 .24887 .68016 .24186 .67388 .22622 Mtetra
.655 .595 .776 r
.67388 .22622 .68016 .24186 .69239 .23502 .68619 .22056 Mtetra
.657 .613 .793 r
.68619 .22056 .69239 .23502 .70466 .22833 .69855 .21509 Mtetra
.659 .634 .813 r
.69855 .21509 .70466 .22833 .71698 .22182 .71097 .20983 Mtetra
.662 .659 .836 r
.71097 .20983 .71698 .22182 .72935 .21544 .72344 .20471 Mtetra
.665 .687 .861 r
.72344 .20471 .72935 .21544 .74176 .20917 .73598 .1997 Mtetra
.669 .721 .888 r
.73598 .1997 .74176 .20917 .75422 .20298 .74857 .19475 Mtetra
.691 .759 .904 r
.0807 .4217 .08813 .42819 .09799 .42514 .09077 .41724 Mtetra
.682 .717 .876 r
.09077 .41724 .09799 .42514 .10788 .42216 .10086 .41282 Mtetra
.671 .679 .849 r
.10086 .41282 .10788 .42216 .1178 .41929 .11098 .40848 Mtetra
.659 .645 .825 r
.11098 .40848 .1178 .41929 .12775 .41657 .12111 .40428 Mtetra
.646 .614 .803 r
.12111 .40428 .12775 .41657 .13771 .41405 .13125 .40026 Mtetra
.634 .586 .783 r
.13125 .40026 .13771 .41405 .14769 .41174 .14141 .39644 Mtetra
.622 .561 .765 r
.14141 .39644 .14769 .41174 .15769 .40964 .15158 .39284 Mtetra
.612 .539 .748 r
.15158 .39284 .15769 .40964 .16772 .40773 .16176 .38946 Mtetra
.602 .52 .734 r
.16176 .38946 .16772 .40773 .17779 .40599 .17196 .38627 Mtetra
.595 .503 .721 r
.17196 .38627 .17779 .40599 .18789 .40437 .18219 .38325 Mtetra
.588 .489 .709 r
.18219 .38325 .18789 .40437 .19803 .40282 .19245 .38035 Mtetra
.583 .477 .699 r
.19245 .38035 .19803 .40282 .20823 .40126 .20274 .37754 Mtetra
.58 .468 .69 r
.20274 .37754 .20823 .40126 .21849 .39965 .21307 .37479 Mtetra
.576 .46 .683 r
.21307 .37479 .21849 .39965 .22882 .39792 .22345 .37211 Mtetra
.573 .453 .678 r
.22345 .37211 .22882 .39792 .23921 .39604 .23386 .3695 Mtetra
.569 .447 .674 r
.23386 .3695 .23921 .39604 .24966 .39409 .24431 .36704 Mtetra
.565 .443 .671 r
.24431 .36704 .24966 .39409 .26016 .39211 .25479 .36479 Mtetra
.562 .439 .67 r
.25479 .36479 .26016 .39211 .27071 .39029 .26531 .36271 Mtetra
.56 .437 .669 r
.26531 .36271 .27071 .39029 .28129 .38874 .27588 .36077 Mtetra
.562 .437 .667 r
.27588 .36077 .28129 .38874 .29191 .38742 .28651 .35865 Mtetra
.567 .437 .663 r
.28651 .35865 .29191 .38742 .30258 .38624 .29722 .35613 Mtetra
.574 .437 .657 r
.29722 .35613 .30258 .38624 .31333 .38482 .30803 .35292 Mtetra
.582 .436 .649 r
.30803 .35292 .31333 .38482 .32417 .38291 .31895 .34888 Mtetra
.585 .433 .641 r
.31895 .34888 .32417 .38291 .3351 .38037 .32995 .34419 Mtetra
.587 .428 .633 r
.32995 .34419 .3351 .38037 .34613 .37712 .34101 .339 Mtetra
.585 .422 .627 r
.34101 .339 .34613 .37712 .35723 .37337 .35212 .33367 Mtetra
.581 .416 .623 r
.35212 .33367 .35723 .37337 .36839 .3693 .36326 .32845 Mtetra
.577 .411 .62 r
.36326 .32845 .36839 .3693 .3796 .36515 .37442 .32355 Mtetra
.571 .405 .618 r
.37442 .32355 .3796 .36515 .39086 .36108 .3856 .31909 Mtetra
.566 .401 .617 r
.3856 .31909 .39086 .36108 .40215 .35717 .3968 .31512 Mtetra
.561 .397 .617 r
.3968 .31512 .40215 .35717 .41348 .35343 .40803 .31165 Mtetra
.557 .395 .618 r
.40803 .31165 .41348 .35343 .42486 .34977 .41929 .30862 Mtetra
.554 .395 .62 r
.41929 .30862 .42486 .34977 .43629 .34603 .4306 .30591 Mtetra
.554 .397 .623 r
.4306 .30591 .43629 .34603 .44778 .34195 .44196 .30332 Mtetra
.556 .402 .627 r
.44196 .30332 .44778 .34195 .45933 .33738 .45339 .30059 Mtetra
.564 .412 .634 r
.45339 .30059 .45933 .33738 .47094 .33209 .46488 .29736 Mtetra
.574 .425 .641 r
.46488 .29736 .47094 .33209 .48259 .32615 .47643 .29347 Mtetra
.587 .44 .649 r
.47643 .29347 .48259 .32615 .49428 .31971 .48805 .28874 Mtetra
.598 .453 .656 r
.48805 .28874 .49428 .31971 .50601 .31301 .49972 .28331 Mtetra
.606 .463 .661 r
.49972 .28331 .50601 .31301 .51777 .30646 .51142 .27746 Mtetra
.61 .469 .665 r
.51142 .27746 .51777 .30646 .52956 .30011 .52317 .27143 Mtetra
.609 .47 .666 r
.52317 .27143 .52956 .30011 .54138 .29404 .53495 .26552 Mtetra
.607 .469 .668 r
.53495 .26552 .54138 .29404 .55324 .28812 .54677 .25979 Mtetra
.605 .469 .669 r
.54677 .25979 .55324 .28812 .56514 .28217 .55864 .25426 Mtetra
.604 .47 .672 r
.55864 .25426 .56514 .28217 .57708 .27613 .57054 .24887 Mtetra
.605 .474 .675 r
.57054 .24887 .57708 .27613 .58905 .26992 .58249 .24356 Mtetra
.606 .479 .681 r
.58249 .24356 .58905 .26992 .60106 .2636 .59449 .23831 Mtetra
.609 .486 .688 r
.59449 .23831 .60106 .2636 .61309 .25719 .60653 .23311 Mtetra
.611 .495 .696 r
.60653 .23311 .61309 .25719 .62517 .25078 .61862 .228 Mtetra
.613 .504 .706 r
.61862 .228 .62517 .25078 .63728 .24443 .63076 .22301 Mtetra
.615 .515 .718 r
.63076 .22301 .63728 .24443 .64944 .23818 .64296 .21819 Mtetra
.616 .528 .731 r
.64296 .21819 .64944 .23818 .66164 .23211 .65521 .21357 Mtetra
.617 .542 .747 r
.65521 .21357 .66164 .23211 .67388 .22622 .66753 .20916 Mtetra
.618 .559 .765 r
.66753 .20916 .67388 .22622 .68619 .22056 .67991 .20498 Mtetra
.619 .578 .786 r
.67991 .20498 .68619 .22056 .69855 .21509 .69236 .201 Mtetra
.62 .601 .809 r
.69236 .201 .69855 .21509 .71097 .20983 .70489 .19721 Mtetra
.621 .628 .836 r
.70489 .19721 .71097 .20983 .72344 .20471 .71748 .19355 Mtetra
.622 .659 .865 r
.71748 .19355 .72344 .20471 .73598 .1997 .73014 .18999 Mtetra
.622 .695 .896 r
.73014 .18999 .73598 .1997 .74857 .19475 .74288 .18646 Mtetra
.728 .765 .882 r
.07322 .41517 .0807 .4217 .09077 .41724 .08348 .40945 Mtetra
.718 .73 .86 r
.08348 .40945 .09077 .41724 .10086 .41282 .09376 .40374 Mtetra
.707 .697 .839 r
.09376 .40374 .10086 .41282 .11098 .40848 .10406 .3981 Mtetra
.694 .667 .819 r
.10406 .3981 .11098 .40848 .12111 .40428 .11437 .39255 Mtetra
.682 .639 .8 r
.11437 .39255 .12111 .40428 .13125 .40026 .12469 .38714 Mtetra
.669 .612 .783 r
.12469 .38714 .13125 .40026 .14141 .39644 .13502 .38191 Mtetra
.656 .588 .767 r
.13502 .38191 .14141 .39644 .15158 .39284 .14536 .37687 Mtetra
.644 .566 .751 r
.14536 .37687 .15158 .39284 .16176 .38946 .1557 .37202 Mtetra
.634 .545 .737 r
.1557 .37202 .16176 .38946 .17196 .38627 .16605 .36739 Mtetra
.624 .527 .724 r
.16605 .36739 .17196 .38627 .18219 .38325 .17642 .36293 Mtetra
.615 .511 .713 r
.17642 .36293 .18219 .38325 .19245 .38035 .1868 .35864 Mtetra
.608 .497 .702 r
.1868 .35864 .19245 .38035 .20274 .37754 .1972 .3545 Mtetra
.601 .485 .693 r
.1972 .3545 .20274 .37754 .21307 .37479 .20763 .35051 Mtetra
.595 .475 .685 r
.20763 .35051 .21307 .37479 .22345 .37211 .21808 .34666 Mtetra
.59 .465 .679 r
.21808 .34666 .22345 .37211 .23386 .3695 .22855 .34299 Mtetra
.584 .457 .673 r
.22855 .34299 .23386 .3695 .24431 .36704 .23905 .33949 Mtetra
.58 .449 .667 r
.23905 .33949 .24431 .36704 .25479 .36479 .24958 .33617 Mtetra
.576 .443 .662 r
.24958 .33617 .25479 .36479 .26531 .36271 .26015 .33293 Mtetra
.575 .437 .657 r
.26015 .33293 .26531 .36271 .27588 .36077 .27076 .32966 Mtetra
.576 .434 .651 r
.27076 .32966 .27588 .36077 .28651 .35865 .28144 .32613 Mtetra
.578 .431 .645 r
.28144 .32613 .28651 .35865 .29722 .35613 .29219 .3222 Mtetra
.581 .429 .64 r
.29219 .3222 .29722 .35613 .30803 .35292 .30302 .31784 Mtetra
.583 .427 .636 r
.30302 .31784 .30803 .35292 .31895 .34888 .31392 .31309 Mtetra
.584 .426 .633 r
.31392 .31309 .31895 .34888 .32995 .34419 .32486 .3082 Mtetra
.583 .425 .633 r
.32486 .3082 .32995 .34419 .34101 .339 .33583 .30334 Mtetra
.582 .425 .634 r
.33583 .30334 .34101 .339 .35212 .33367 .34684 .29863 Mtetra
.58 .425 .636 r
.34684 .29863 .35212 .33367 .36326 .32845 .35787 .29415 Mtetra
.579 .427 .639 r
.35787 .29415 .36326 .32845 .37442 .32355 .36894 .28984 Mtetra
.578 .428 .642 r
.36894 .28984 .37442 .32355 .3856 .31909 .38004 .28571 Mtetra
.577 .429 .643 r
.38004 .28571 .3856 .31909 .3968 .31512 .39118 .28169 Mtetra
.575 .427 .643 r
.39118 .28169 .3968 .31512 .40803 .31165 .40236 .27779 Mtetra
.573 .424 .642 r
.40236 .27779 .40803 .31165 .41929 .30862 .41358 .27405 Mtetra
.569 .42 .639 r
.41358 .27405 .41929 .30862 .4306 .30591 .42484 .2705 Mtetra
.565 .415 .637 r
.42484 .2705 .4306 .30591 .44196 .30332 .43615 .26717 Mtetra
.563 .412 .634 r
.43615 .26717 .44196 .30332 .45339 .30059 .44751 .26401 Mtetra
.562 .41 .633 r
.44751 .26401 .45339 .30059 .46488 .29736 .45892 .26087 Mtetra
.563 .412 .633 r
.45892 .26087 .46488 .29736 .47643 .29347 .47039 .2576 Mtetra
.568 .417 .636 r
.47039 .2576 .47643 .29347 .48805 .28874 .48192 .25392 Mtetra
.575 .424 .64 r
.48192 .25392 .48805 .28874 .49972 .28331 .4935 .24982 Mtetra
.581 .433 .645 r
.4935 .24982 .49972 .28331 .51142 .27746 .50514 .2453 Mtetra
.587 .441 .65 r
.50514 .2453 .51142 .27746 .52317 .27143 .51683 .24051 Mtetra
.59 .447 .656 r
.51683 .24051 .52317 .27143 .53495 .26552 .52856 .2357 Mtetra
.591 .453 .661 r
.52856 .2357 .53495 .26552 .54677 .25979 .54034 .23096 Mtetra
.591 .457 .667 r
.54034 .23096 .54677 .25979 .55864 .25426 .55216 .2264 Mtetra
.59 .461 .672 r
.55216 .2264 .55864 .25426 .57054 .24887 .56404 .22201 Mtetra
.59 .466 .679 r
.56404 .22201 .57054 .24887 .58249 .24356 .57597 .2178 Mtetra
.59 .472 .686 r
.57597 .2178 .58249 .24356 .59449 .23831 .58796 .21374 Mtetra
.591 .479 .694 r
.58796 .21374 .59449 .23831 .60653 .23311 .6 .20982 Mtetra
.592 .487 .704 r
.6 .20982 .60653 .23311 .61862 .228 .6121 .20605 Mtetra
.592 .497 .716 r
.6121 .20605 .61862 .228 .63076 .22301 .62427 .20246 Mtetra
.592 .509 .729 r
.62427 .20246 .63076 .22301 .64296 .21819 .63651 .19906 Mtetra
.592 .521 .744 r
.63651 .19906 .64296 .21819 .65521 .21357 .64881 .19586 Mtetra
.591 .536 .762 r
.64881 .19586 .65521 .21357 .66753 .20916 .66119 .19287 Mtetra
.59 .553 .781 r
.66119 .19287 .66753 .20916 .67991 .20498 .67365 .19009 Mtetra
.588 .572 .803 r
.67365 .19009 .67991 .20498 .69236 .201 .68619 .18748 Mtetra
.586 .593 .826 r
.68619 .18748 .69236 .201 .70489 .19721 .6988 .18502 Mtetra
.583 .618 .852 r
.6988 .18502 .70489 .19721 .71748 .19355 .7115 .18267 Mtetra
.58 .645 .88 r
.7115 .18267 .71748 .19355 .73014 .18999 .72428 .18038 Mtetra
.575 .677 .909 r
.72428 .18038 .73014 .18999 .74288 .18646 .73713 .1781 Mtetra
.75 .767 .867 r
.06568 .40859 .07322 .41517 .08348 .40945 .07609 .40194 Mtetra
.742 .743 .852 r
.07609 .40194 .08348 .40945 .09376 .40374 .08652 .39528 Mtetra
.733 .719 .837 r
.08652 .39528 .09376 .40374 .10406 .3981 .09697 .38865 Mtetra
.723 .696 .823 r
.09697 .38865 .10406 .3981 .11437 .39255 .10743 .38208 Mtetra
.713 .673 .81 r
.10743 .38208 .11437 .39255 .12469 .38714 .1179 .3756 Mtetra
.702 .651 .796 r
.1179 .3756 .12469 .38714 .13502 .38191 .12838 .36925 Mtetra
.691 .63 .783 r
.12838 .36925 .13502 .38191 .14536 .37687 .13886 .36306 Mtetra
.679 .609 .77 r
.13886 .36306 .14536 .37687 .1557 .37202 .14934 .35703 Mtetra
.668 .59 .758 r
.14934 .35703 .1557 .37202 .16605 .36739 .15983 .35119 Mtetra
.658 .571 .746 r
.15983 .35119 .16605 .36739 .17642 .36293 .17032 .34554 Mtetra
.648 .555 .735 r
.17032 .34554 .17642 .36293 .1868 .35864 .18082 .34007 Mtetra
.639 .539 .725 r
.18082 .34007 .1868 .35864 .1972 .3545 .19133 .33478 Mtetra
.631 .525 .716 r
.19133 .33478 .1972 .3545 .20763 .35051 .20185 .32968 Mtetra
.623 .513 .708 r
.20185 .32968 .20763 .35051 .21808 .34666 .21239 .32476 Mtetra
.616 .502 .7 r
.21239 .32476 .21808 .34666 .22855 .34299 .22294 .32 Mtetra
.611 .492 .693 r
.22294 .32 .22855 .34299 .23905 .33949 .23352 .31535 Mtetra
.606 .483 .686 r
.23352 .31535 .23905 .33949 .24958 .33617 .24412 .31076 Mtetra
.603 .474 .678 r
.24412 .31076 .24958 .33617 .26015 .33293 .25477 .3061 Mtetra
.601 .467 .67 r
.25477 .3061 .26015 .33293 .27076 .32966 .26547 .3013 Mtetra
.6 .459 .662 r
.26547 .3013 .27076 .32966 .28144 .32613 .27622 .29631 Mtetra
.598 .453 .655 r
.27622 .29631 .28144 .32613 .29219 .3222 .28702 .29115 Mtetra
.594 .446 .65 r
.28702 .29115 .29219 .3222 .30302 .31784 .29785 .28606 Mtetra
.59 .441 .647 r
.29785 .28606 .30302 .31784 .31392 .31309 .30869 .28123 Mtetra
.584 .436 .647 r
.30869 .28123 .31392 .31309 .32486 .3082 .31954 .27684 Mtetra
.578 .434 .65 r
.31954 .27684 .32486 .3082 .33583 .30334 .3304 .27298 Mtetra
.575 .436 .654 r
.3304 .27298 .33583 .30334 .34684 .29863 .34128 .26948 Mtetra
.574 .44 .661 r
.34128 .26948 .34684 .29863 .35787 .29415 .3522 .26618 Mtetra
.578 .448 .667 r
.3522 .26618 .35787 .29415 .36894 .28984 .36317 .26277 Mtetra
.583 .456 .672 r
.36317 .26277 .36894 .28984 .38004 .28571 .37421 .2591 Mtetra
.59 .462 .675 r
.37421 .2591 .38004 .28571 .39118 .28169 .38531 .25504 Mtetra
.595 .466 .674 r
.38531 .25504 .39118 .28169 .40236 .27779 .39647 .25058 Mtetra
.598 .465 .671 r
.39647 .25058 .40236 .27779 .41358 .27405 .40769 .24585 Mtetra
.596 .46 .666 r
.40769 .24585 .41358 .27405 .42484 .2705 .41895 .24102 Mtetra
.591 .451 .66 r
.41895 .24102 .42484 .2705 .43615 .26717 .43025 .23638 Mtetra
.583 .441 .654 r
.43025 .23638 .43615 .26717 .44751 .26401 .44158 .2321 Mtetra
.574 .432 .65 r
.44158 .2321 .44751 .26401 .45892 .26087 .45294 .22836 Mtetra
.567 .425 .647 r
.45294 .22836 .45892 .26087 .47039 .2576 .46434 .22507 Mtetra
.564 .423 .648 r
.46434 .22507 .47039 .2576 .48192 .25392 .4758 .22203 Mtetra
.564 .425 .651 r
.4758 .22203 .48192 .25392 .4935 .24982 .48731 .21907 Mtetra
.568 .432 .656 r
.48731 .21907 .4935 .24982 .50514 .2453 .49888 .21594 Mtetra
.572 .441 .663 r
.49888 .21594 .50514 .2453 .51683 .24051 .51051 .21262 Mtetra
.577 .451 .672 r
.51051 .21262 .51683 .24051 .52856 .2357 .5222 .20915 Mtetra
.58 .46 .68 r
.5222 .20915 .52856 .2357 .54034 .23096 .53394 .20562 Mtetra
.582 .467 .688 r
.53394 .20562 .54034 .23096 .55216 .2264 .54574 .20215 Mtetra
.583 .474 .696 r
.54574 .20215 .55216 .2264 .56404 .22201 .5576 .19878 Mtetra
.582 .48 .704 r
.5576 .19878 .56404 .22201 .57597 .2178 .56952 .19559 Mtetra
.581 .487 .713 r
.56952 .19559 .57597 .2178 .58796 .21374 .58151 .19258 Mtetra
.58 .495 .723 r
.58151 .19258 .58796 .21374 .6 .20982 .59356 .18975 Mtetra
.578 .503 .735 r
.59356 .18975 .6 .20982 .6121 .20605 .60568 .18712 Mtetra
.576 .513 .748 r
.60568 .18712 .6121 .20605 .62427 .20246 .61787 .18469 Mtetra
.574 .525 .762 r
.61787 .18469 .62427 .20246 .63651 .19906 .63014 .18245 Mtetra
.571 .537 .778 r
.63014 .18245 .63651 .19906 .64881 .19586 .6425 .1804 Mtetra
.568 .551 .796 r
.6425 .1804 .64881 .19586 .66119 .19287 .65493 .17853 Mtetra
.563 .567 .815 r
.65493 .17853 .66119 .19287 .67365 .19009 .66745 .17683 Mtetra
.559 .584 .835 r
.66745 .17683 .67365 .19009 .68619 .18748 .68005 .17526 Mtetra
.554 .602 .856 r
.68005 .17526 .68619 .18748 .6988 .18502 .69274 .1738 Mtetra
.548 .622 .877 r
.69274 .1738 .6988 .18502 .7115 .18267 .70552 .1724 Mtetra
.542 .643 .899 r
.70552 .1724 .7115 .18267 .72428 .18038 .71839 .17104 Mtetra
.535 .666 .921 r
.71839 .17104 .72428 .18038 .73713 .1781 .73134 .16968 Mtetra
.756 .768 .862 r
.05808 .40196 .06568 .40859 .07609 .40194 .06857 .39498 Mtetra
.754 .76 .857 r
.06857 .39498 .07609 .40194 .08652 .39528 .07908 .38798 Mtetra
.751 .751 .852 r
.07908 .38798 .08652 .39528 .09697 .38865 .0896 .38098 Mtetra
.747 .742 .848 r
.0896 .38098 .09697 .38865 .10743 .38208 .10014 .37401 Mtetra
.742 .732 .843 r
.10014 .37401 .10743 .38208 .1179 .3756 .11069 .36709 Mtetra
.736 .722 .837 r
.11069 .36709 .1179 .3756 .12838 .36925 .12124 .36027 Mtetra
.73 .71 .832 r
.12124 .36027 .12838 .36925 .13886 .36306 .13181 .35357 Mtetra
.723 .698 .826 r
.13181 .35357 .13886 .36306 .14934 .35703 .14237 .34701 Mtetra
.715 .685 .821 r
.14237 .34701 .14934 .35703 .15983 .35119 .15294 .34062 Mtetra
.706 .673 .815 r
.15294 .34062 .15983 .35119 .17032 .34554 .16351 .33439 Mtetra
.698 .66 .809 r
.16351 .33439 .17032 .34554 .18082 .34007 .17408 .32836 Mtetra
.69 .647 .802 r
.17408 .32836 .18082 .34007 .19133 .33478 .18466 .32249 Mtetra
.682 .635 .796 r
.18466 .32249 .19133 .33478 .20185 .32968 .19526 .31679 Mtetra
.676 .623 .789 r
.19526 .31679 .20185 .32968 .21239 .32476 .20586 .31122 Mtetra
.669 .611 .781 r
.20586 .31122 .21239 .32476 .22294 .32 .21649 .30574 Mtetra
.664 .6 .773 r
.21649 .30574 .22294 .32 .23352 .31535 .22715 .30026 Mtetra
.66 .588 .763 r
.22715 .30026 .23352 .31535 .24412 .31076 .23784 .29474 Mtetra
.657 .576 .752 r
.23784 .29474 .24412 .31076 .25477 .3061 .24857 .28908 Mtetra
.655 .564 .741 r
.24857 .28908 .25477 .3061 .26547 .3013 .25935 .28326 Mtetra
.65 .553 .731 r
.25935 .28326 .26547 .3013 .27622 .29631 .27016 .27737 Mtetra
.645 .542 .723 r
.27016 .27737 .27622 .29631 .28702 .29115 .28101 .27149 Mtetra
.637 .532 .718 r
.28101 .27149 .28702 .29115 .29785 .28606 .29185 .26593 Mtetra
.627 .522 .716 r
.29185 .26593 .29785 .28606 .30869 .28123 .3027 .26084 Mtetra
.616 .514 .716 r
.3027 .26084 .30869 .28123 .31954 .27684 .31354 .25633 Mtetra
.604 .506 .716 r
.31354 .25633 .31954 .27684 .3304 .27298 .32438 .25241 Mtetra
.597 .502 .717 r
.32438 .25241 .3304 .27298 .34128 .26948 .33525 .24886 Mtetra
.593 .5 .717 r
.33525 .24886 .34128 .26948 .3522 .26618 .34615 .2455 Mtetra
.595 .5 .717 r
.34615 .2455 .3522 .26618 .36317 .26277 .3571 .24204 Mtetra
.599 .503 .716 r
.3571 .24204 .36317 .26277 .37421 .2591 .36812 .23831 Mtetra
.606 .507 .716 r
.36812 .23831 .37421 .2591 .38531 .25504 .3792 .23421 Mtetra
.612 .511 .715 r
.3792 .23421 .38531 .25504 .39647 .25058 .39034 .22972 Mtetra
.617 .514 .714 r
.39034 .22972 .39647 .25058 .40769 .24585 .40154 .22496 Mtetra
.618 .514 .714 r
.40154 .22496 .40769 .24585 .41895 .24102 .41279 .22011 Mtetra
.615 .513 .715 r
.41279 .22011 .41895 .24102 .43025 .23638 .42407 .21544 Mtetra
.608 .509 .716 r
.42407 .21544 .43025 .23638 .44158 .2321 .43538 .21114 Mtetra
.597 .502 .717 r
.43538 .21114 .44158 .2321 .45294 .22836 .44672 .20744 Mtetra
.586 .496 .719 r
.44672 .20744 .45294 .22836 .46434 .22507 .4581 .20432 Mtetra
.577 .493 .722 r
.4581 .20432 .46434 .22507 .4758 .22203 .46953 .20169 Mtetra
.572 .493 .727 r
.46953 .20169 .4758 .22203 .48731 .21907 .48101 .19937 Mtetra
.572 .499 .734 r
.48101 .19937 .48731 .21907 .49888 .21594 .49256 .19707 Mtetra
.575 .509 .744 r
.49256 .19707 .49888 .21594 .51051 .21262 .50417 .19471 Mtetra
.581 .523 .755 r
.50417 .19471 .51051 .21262 .5222 .20915 .51584 .19218 Mtetra
.586 .536 .766 r
.51584 .19218 .5222 .20915 .53394 .20562 .52758 .18953 Mtetra
.589 .55 .778 r
.52758 .18953 .53394 .20562 .54574 .20215 .53939 .18681 Mtetra
.59 .561 .79 r
.53939 .18681 .54574 .20215 .5576 .19878 .55125 .18412 Mtetra
.589 .571 .801 r
.55125 .18412 .5576 .19878 .56952 .19559 .56319 .18151 Mtetra
.586 .579 .812 r
.56319 .18151 .56952 .19559 .58151 .19258 .57519 .17904 Mtetra
.581 .587 .823 r
.57519 .17904 .58151 .19258 .59356 .18975 .58726 .17675 Mtetra
.576 .594 .834 r
.58726 .17675 .59356 .18975 .60568 .18712 .59941 .17463 Mtetra
.57 .601 .845 r
.59941 .17463 .60568 .18712 .61787 .18469 .61163 .17271 Mtetra
.563 .609 .857 r
.61163 .17271 .61787 .18469 .63014 .18245 .62394 .17097 Mtetra
.556 .617 .869 r
.62394 .17097 .63014 .18245 .6425 .1804 .63632 .1694 Mtetra
.548 .625 .88 r
.63632 .1694 .6425 .1804 .65493 .17853 .6488 .16799 Mtetra
.541 .633 .892 r
.6488 .16799 .65493 .17853 .66745 .17683 .66136 .16671 Mtetra
.534 .641 .902 r
.66136 .16671 .66745 .17683 .68005 .17526 .67401 .16552 Mtetra
.528 .65 .912 r
.67401 .16552 .68005 .17526 .69274 .1738 .68675 .16441 Mtetra
.522 .658 .921 r
.68675 .16441 .69274 .1738 .70552 .1724 .69958 .16333 Mtetra
.518 .666 .929 r
.69958 .16333 .70552 .1724 .71839 .17104 .7125 .16226 Mtetra
.515 .674 .936 r
.7125 .16226 .71839 .17104 .73134 .16968 .7255 .16118 Mtetra
.751 .767 .866 r
.05043 .39529 .05808 .40196 .06857 .39498 .06091 .38852 Mtetra
.753 .774 .87 r
.06091 .38852 .06857 .39498 .07908 .38798 .07142 .38171 Mtetra
.755 .781 .874 r
.07142 .38171 .07908 .38798 .0896 .38098 .08195 .37489 Mtetra
.757 .787 .878 r
.08195 .37489 .0896 .38098 .10014 .37401 .09249 .36808 Mtetra
.757 .793 .882 r
.09249 .36808 .10014 .37401 .11069 .36709 .10306 .36128 Mtetra
.757 .797 .886 r
.10306 .36128 .11069 .36709 .12124 .36027 .11364 .35454 Mtetra
.755 .801 .889 r
.11364 .35454 .12124 .36027 .13181 .35357 .12422 .34788 Mtetra
.753 .803 .893 r
.12422 .34788 .13181 .35357 .14237 .34701 .13482 .34133 Mtetra
.749 .804 .896 r
.13482 .34133 .14237 .34701 .15294 .34062 .14542 .33492 Mtetra
.745 .804 .899 r
.14542 .33492 .15294 .34062 .16351 .33439 .15602 .32864 Mtetra
.74 .803 .902 r
.15602 .32864 .16351 .33439 .17408 .32836 .16664 .32252 Mtetra
.736 .801 .904 r
.16664 .32252 .17408 .32836 .18466 .32249 .17727 .31652 Mtetra
.731 .797 .904 r
.17727 .31652 .18466 .32249 .19526 .31679 .18791 .31064 Mtetra
.728 .792 .903 r
.18791 .31064 .19526 .31679 .20586 .31122 .19857 .30482 Mtetra
.726 .785 .899 r
.19857 .30482 .20586 .31122 .21649 .30574 .20926 .299 Mtetra
.726 .776 .893 r
.20926 .299 .21649 .30574 .22715 .30026 .21998 .29313 Mtetra
.726 .765 .884 r
.21998 .29313 .22715 .30026 .23784 .29474 .23074 .28716 Mtetra
.725 .754 .875 r
.23074 .28716 .23784 .29474 .24857 .28908 .24154 .28108 Mtetra
.724 .743 .867 r
.24154 .28108 .24857 .28908 .25935 .28326 .25237 .27492 Mtetra
.72 .734 .862 r
.25237 .27492 .25935 .28326 .27016 .27737 .26323 .26882 Mtetra
.713 .728 .862 r
.26323 .26882 .27016 .27737 .28101 .27149 .27409 .26292 Mtetra
.703 .725 .867 r
.27409 .26292 .28101 .27149 .29185 .26593 .28496 .25737 Mtetra
.69 .722 .874 r
.28496 .25737 .29185 .26593 .3027 .26084 .29583 .25229 Mtetra
.677 .719 .881 r
.29583 .25229 .3027 .26084 .31354 .25633 .3067 .24764 Mtetra
.664 .712 .884 r
.3067 .24764 .31354 .25633 .32438 .25241 .31759 .24337 Mtetra
.654 .7 .88 r
.31759 .24337 .32438 .25241 .33525 .24886 .3285 .23933 Mtetra
.648 .686 .872 r
.3285 .23933 .33525 .24886 .34615 .2455 .33945 .23541 Mtetra
.646 .673 .862 r
.33945 .23541 .34615 .2455 .3571 .24204 .35045 .23148 Mtetra
.646 .663 .852 r
.35045 .23148 .3571 .24204 .36812 .23831 .3615 .22748 Mtetra
.648 .659 .846 r
.3615 .22748 .36812 .23831 .3792 .23421 .3726 .22334 Mtetra
.652 .66 .845 r
.3726 .22334 .3792 .23421 .39034 .22972 .38375 .21907 Mtetra
.655 .667 .849 r
.38375 .21907 .39034 .22972 .40154 .22496 .39495 .21471 Mtetra
.656 .677 .858 r
.39495 .21471 .40154 .22496 .41279 .22011 .40619 .21035 Mtetra
.655 .689 .87 r
.40619 .21035 .41279 .22011 .42407 .21544 .41748 .20611 Mtetra
.648 .698 .882 r
.41748 .20611 .42407 .21544 .43538 .21114 .42881 .2021 Mtetra
.636 .701 .893 r
.42881 .2021 .43538 .21114 .44672 .20744 .44017 .19847 Mtetra
.619 .698 .901 r
.44017 .19847 .44672 .20744 .4581 .20432 .45157 .19528 Mtetra
.6 .689 .904 r
.45157 .19528 .4581 .20432 .46953 .20169 .46303 .19256 Mtetra
.585 .68 .906 r
.46303 .19256 .46953 .20169 .48101 .19937 .47453 .19021 Mtetra
.576 .676 .908 r
.47453 .19021 .48101 .19937 .49256 .19707 .4861 .18805 Mtetra
.572 .679 .913 r
.4861 .18805 .49256 .19707 .50417 .19471 .49773 .18597 Mtetra
.574 .689 .919 r
.49773 .18597 .50417 .19471 .51584 .19218 .50943 .18381 Mtetra
.575 .702 .928 r
.50943 .18381 .51584 .19218 .52758 .18953 .5212 .18154 Mtetra
.577 .716 .937 r
.5212 .18154 .52758 .18953 .53939 .18681 .53303 .17917 Mtetra
.576 .727 .946 r
.53303 .17917 .53939 .18681 .55125 .18412 .54493 .17675 Mtetra
.572 .736 .953 r
.54493 .17675 .55125 .18412 .56319 .18151 .5569 .17434 Mtetra
.566 .741 .958 r
.5569 .17434 .56319 .18151 .57519 .17904 .56894 .17199 Mtetra
.558 .742 .962 r
.56894 .17199 .57519 .17904 .58726 .17675 .58105 .16977 Mtetra
.549 .741 .966 r
.58105 .16977 .58726 .17675 .59941 .17463 .59323 .16767 Mtetra
.539 .739 .968 r
.59323 .16767 .59941 .17463 .61163 .17271 .60549 .16574 Mtetra
.53 .735 .969 r
.60549 .16574 .61163 .17271 .62394 .17097 .61783 .16396 Mtetra
.522 .731 .969 r
.61783 .16396 .62394 .17097 .63632 .1694 .63026 .16232 Mtetra
.516 .726 .969 r
.63026 .16232 .63632 .1694 .6488 .16799 .64276 .1608 Mtetra
.511 .721 .968 r
.64276 .1608 .6488 .16799 .66136 .16671 .65536 .15937 Mtetra
.51 .716 .965 r
.65536 .15937 .66136 .16671 .67401 .16552 .66804 .158 Mtetra
.51 .711 .962 r
.66804 .158 .67401 .16552 .68675 .16441 .6808 .15666 Mtetra
.512 .706 .958 r
.6808 .15666 .68675 .16441 .69958 .16333 .69365 .15533 Mtetra
.516 .7 .953 r
.69365 .15533 .69958 .16333 .7125 .16226 .70659 .15398 Mtetra
.52 .695 .948 r
.70659 .15398 .7125 .16226 .7255 .16118 .71961 .15261 Mtetra
.73 .765 .881 r
.04273 .38856 .05043 .39529 .06091 .38852 .05311 .38261 Mtetra
.737 .791 .896 r
.05311 .38261 .06091 .38852 .07142 .38171 .06353 .37663 Mtetra
.742 .817 .911 r
.06353 .37663 .07142 .38171 .08195 .37489 .07398 .37061 Mtetra
.745 .844 .925 r
.07398 .37061 .08195 .37489 .09249 .36808 .08445 .36456 Mtetra
.746 .871 .938 r
.08445 .36456 .09249 .36808 .10306 .36128 .09495 .35851 Mtetra
.743 .896 .948 r
.09495 .35851 .10306 .36128 .11364 .35454 .10548 .35246 Mtetra
.735 .918 .955 r
.10548 .35246 .11364 .35454 .12422 .34788 .11602 .34645 Mtetra
.723 .936 .957 r
.11602 .34645 .12422 .34788 .13482 .34133 .12659 .34048 Mtetra
.705 .949 .955 r
.12659 .34048 .13482 .34133 .14542 .33492 .13717 .33458 Mtetra
.684 .957 .949 r
.13717 .33458 .14542 .33492 .15602 .32864 .14777 .32875 Mtetra
.661 .959 .938 r
.14777 .32875 .15602 .32864 .16664 .32252 .15839 .32299 Mtetra
.637 .957 .926 r
.15839 .32299 .16664 .32252 .17727 .31652 .16903 .3173 Mtetra
.613 .953 .912 r
.16903 .3173 .17727 .31652 .18791 .31064 .1797 .31167 Mtetra
.592 .947 .898 r
.1797 .31167 .18791 .31064 .19857 .30482 .19039 .30608 Mtetra
.57 .94 .882 r
.19039 .30608 .19857 .30482 .20926 .299 .2011 .30054 Mtetra
.544 .929 .863 r
.2011 .30054 .20926 .299 .21998 .29313 .21184 .29504 Mtetra
.507 .91 .833 r
.21184 .29504 .21998 .29313 .23074 .28716 .22261 .28962 Mtetra
.446 .875 .783 r
.22261 .28962 .23074 .28716 .24154 .28108 .23339 .28433 Mtetra
.356 .813 .7 r
.23339 .28433 .24154 .28108 .25237 .27492 .24419 .27922 Mtetra
0 0 0 r
.24419 .27922 .25237 .27492 .26323 .26882 .25501 .27439 Mtetra
.25501 .27439 .26323 .26882 .27409 .26292 .26583 .26986 Mtetra
.015 0 0 r
.26583 .26986 .27409 .26292 .28496 .25737 .27668 .26557 Mtetra
.095 0 0 r
.27668 .26557 .28496 .25737 .29583 .25229 .28755 .26147 Mtetra
.135 0 0 r
.28755 .26147 .29583 .25229 .3067 .24764 .29847 .25735 Mtetra
.147 0 0 r
.29847 .25735 .3067 .24764 .31759 .24337 .30944 .25309 Mtetra
.139 0 0 r
.30944 .25309 .31759 .24337 .3285 .23933 .32046 .24868 Mtetra
.119 0 0 r
.32046 .24868 .3285 .23933 .33945 .23541 .33154 .24413 Mtetra
.099 0 0 r
.33154 .24413 .33945 .23541 .35045 .23148 .34265 .23962 Mtetra
.085 0 0 r
.34265 .23962 .35045 .23148 .3615 .22748 .3538 .23524 Mtetra
.086 0 0 r
.3538 .23524 .3615 .22748 .3726 .22334 .36498 .23108 Mtetra
.104 0 0 r
.36498 .23108 .3726 .22334 .38375 .21907 .3762 .22714 Mtetra
.129 0 0 r
.3762 .22714 .38375 .21907 .39495 .21471 .38746 .22333 Mtetra
.154 0 0 r
.38746 .22333 .39495 .21471 .40619 .21035 .39877 .21956 Mtetra
.168 0 0 r
.39877 .21956 .40619 .21035 .41748 .20611 .41014 .21565 Mtetra
.171 0 0 r
.41014 .21565 .41748 .20611 .42881 .2021 .42156 .21159 Mtetra
.163 0 0 r
.42156 .21159 .42881 .2021 .44017 .19847 .43303 .20739 Mtetra
.144 0 0 r
.43303 .20739 .44017 .19847 .45157 .19528 .44455 .20317 Mtetra
.117 0 0 r
.44455 .20317 .45157 .19528 .46303 .19256 .45612 .19913 Mtetra
.077 0 0 r
.45612 .19913 .46303 .19256 .47453 .19021 .46773 .19534 Mtetra
.026 0 0 r
.46773 .19534 .47453 .19021 .4861 .18805 .4794 .19186 Mtetra
0 0 0 r
.4794 .19186 .4861 .18805 .49773 .18597 .49112 .18866 Mtetra
.49112 .18866 .49773 .18597 .50943 .18381 .50289 .18564 Mtetra
.50289 .18564 .50943 .18381 .5212 .18154 .51473 .18277 Mtetra
.187 .715 .719 r
.51473 .18277 .5212 .18154 .53303 .17917 .52663 .17996 Mtetra
.215 .738 .758 r
.52663 .17996 .53303 .17917 .54493 .17675 .53859 .17722 Mtetra
.235 .753 .786 r
.53859 .17722 .54493 .17675 .5569 .17434 .55062 .17451 Mtetra
.252 .764 .809 r
.55062 .17451 .5569 .17434 .56894 .17199 .56272 .17185 Mtetra
.268 .775 .832 r
.56272 .17185 .56894 .17199 .58105 .16977 .57489 .16926 Mtetra
.288 .786 .859 r
.57489 .16926 .58105 .16977 .59323 .16767 .58712 .16674 Mtetra
.311 .798 .887 r
.58712 .16674 .59323 .16767 .60549 .16574 .59943 .1643 Mtetra
.34 .809 .918 r
.59943 .1643 .60549 .16574 .61783 .16396 .61182 .16193 Mtetra
.372 .818 .947 r
.61182 .16193 .61783 .16396 .63026 .16232 .62428 .15963 Mtetra
.407 .822 .973 r
.62428 .15963 .63026 .16232 .64276 .1608 .63682 .15738 Mtetra
.441 .821 .99 r
.63682 .15738 .64276 .1608 .65536 .15937 .64943 .15517 Mtetra
.473 .812 .999 r
.64943 .15517 .65536 .15937 .66804 .158 .66213 .15297 Mtetra
.501 .798 .999 r
.66213 .15297 .66804 .158 .6808 .15666 .6749 .15076 Mtetra
.524 .779 .99 r
.6749 .15076 .6808 .15666 .69365 .15533 .68774 .14853 Mtetra
.542 .757 .976 r
.68774 .14853 .69365 .15533 .70659 .15398 .70067 .14627 Mtetra
.555 .733 .958 r
.70067 .14627 .70659 .15398 .71961 .15261 .71368 .14397 Mtetra
.695 .76 .902 r
.03496 .38178 .04273 .38856 .05311 .38261 .04519 .37703 Mtetra
.7 .798 .926 r
.04519 .37703 .05311 .38261 .06353 .37663 .05547 .37223 Mtetra
.701 .838 .948 r
.05547 .37223 .06353 .37663 .07398 .37061 .06577 .36739 Mtetra
.696 .878 .966 r
.06577 .36739 .07398 .37061 .08445 .36456 .07612 .3625 Mtetra
.681 .912 .974 r
.07612 .3625 .08445 .36456 .09495 .35851 .08651 .35756 Mtetra
.653 .936 .967 r
.08651 .35756 .09495 .35851 .10548 .35246 .09693 .3526 Mtetra
.608 .943 .941 r
.09693 .3526 .10548 .35246 .11602 .34645 .10739 .34762 Mtetra
.548 .929 .893 r
.10739 .34762 .11602 .34645 .12659 .34048 .11788 .34262 Mtetra
.477 .896 .827 r
.11788 .34262 .12659 .34048 .13717 .33458 .1284 .33762 Mtetra
.403 .848 .75 r
.1284 .33762 .13717 .33458 .14777 .32875 .13896 .3326 Mtetra
.331 .793 .671 r
.13896 .3326 .14777 .32875 .15839 .32299 .14955 .32758 Mtetra
0 0 0 r
.14955 .32758 .15839 .32299 .16903 .3173 .16018 .32256 Mtetra
.16018 .32256 .16903 .3173 .1797 .31167 .17084 .31754 Mtetra
.17084 .31754 .1797 .31167 .19039 .30608 .18153 .31257 Mtetra
.18153 .31257 .19039 .30608 .2011 .30054 .19225 .30767 Mtetra
.19225 .30767 .2011 .30054 .21184 .29504 .20298 .30294 Mtetra
.03 0 0 r
.20298 .30294 .21184 .29504 .22261 .28962 .21373 .29845 Mtetra
.103 0 0 r
.21373 .29845 .22261 .28962 .23339 .28433 .22449 .2943 Mtetra
.175 0 0 r
.22449 .2943 .23339 .28433 .24419 .27922 .23524 .29056 Mtetra
.237 0 0 r
.23524 .29056 .24419 .27922 .25501 .27439 .24601 .28722 Mtetra
.286 0 .043 r
.24601 .28722 .25501 .27439 .26583 .26986 .2568 .28421 Mtetra
.313 0 .089 r
.2568 .28421 .26583 .26986 .27668 .26557 .26763 .28127 Mtetra
.326 0 .119 r
.26763 .28127 .27668 .26557 .28755 .26147 .27853 .2782 Mtetra
.322 0 .133 r
.27853 .2782 .28755 .26147 .29847 .25735 .28951 .27468 Mtetra
.309 0 .135 r
.28951 .27468 .29847 .25735 .30944 .25309 .30058 .27057 Mtetra
.294 0 .13 r
.30058 .27057 .30944 .25309 .32046 .24868 .31173 .26595 Mtetra
.279 0 .12 r
.31173 .26595 .32046 .24868 .33154 .24413 .32295 .26098 Mtetra
.275 0 .113 r
.32295 .26098 .33154 .24413 .34265 .23962 .3342 .25605 Mtetra
.281 0 .109 r
.3342 .25605 .34265 .23962 .3538 .23524 .34548 .25139 Mtetra
.296 0 .112 r
.34548 .25139 .3538 .23524 .36498 .23108 .35678 .24722 Mtetra
.314 0 .121 r
.35678 .24722 .36498 .23108 .3762 .22714 .3681 .24353 Mtetra
.327 0 .131 r
.3681 .24353 .3762 .22714 .38746 .22333 .37945 .24011 Mtetra
.333 0 .14 r
.37945 .24011 .38746 .22333 .39877 .21956 .39086 .23674 Mtetra
.326 0 .143 r
.39086 .23674 .39877 .21956 .41014 .21565 .40234 .23301 Mtetra
.312 0 .139 r
.40234 .23301 .41014 .21565 .42156 .21159 .41389 .22877 Mtetra
.291 0 .128 r
.41389 .22877 .42156 .21159 .43303 .20739 .42551 .22393 Mtetra
.268 0 .108 r
.42551 .22393 .43303 .20739 .44455 .20317 .43718 .21864 Mtetra
.246 0 .08 r
.43718 .21864 .44455 .20317 .45612 .19913 .44891 .21321 Mtetra
.224 0 .044 r
.44891 .21321 .45612 .19913 .46773 .19534 .46067 .20784 Mtetra
.206 0 .001 r
.46067 .20784 .46773 .19534 .4794 .19186 .47247 .20282 Mtetra
.187 0 0 r
.47247 .20282 .4794 .19186 .49112 .18866 .48431 .19818 Mtetra
.169 0 0 r
.48431 .19818 .49112 .18866 .50289 .18564 .49619 .19397 Mtetra
.149 0 0 r
.49619 .19397 .50289 .18564 .51473 .18277 .50813 .1901 Mtetra
.128 0 0 r
.50813 .1901 .51473 .18277 .52663 .17996 .52012 .18647 Mtetra
.106 0 0 r
.52012 .18647 .52663 .17996 .53859 .17722 .53218 .18302 Mtetra
.079 0 0 r
.53218 .18302 .53859 .17722 .55062 .17451 .54429 .17964 Mtetra
.049 0 0 r
.54429 .17964 .55062 .17451 .56272 .17185 .55647 .17631 Mtetra
.013 0 0 r
.55647 .17631 .56272 .17185 .57489 .16926 .56871 .17298 Mtetra
0 0 0 r
.56871 .17298 .57489 .16926 .58712 .16674 .58101 .16965 Mtetra
.58101 .16965 .58712 .16674 .59943 .1643 .59338 .16632 Mtetra
.59338 .16632 .59943 .1643 .61182 .16193 .60582 .16297 Mtetra
.229 .745 .739 r
.60582 .16297 .61182 .16193 .62428 .15963 .61832 .15962 Mtetra
.313 .804 .832 r
.61832 .15962 .62428 .15963 .63682 .15738 .63088 .15624 Mtetra
.396 .847 .912 r
.63088 .15624 .63682 .15738 .64943 .15517 .64352 .15285 Mtetra
.47 .867 .967 r
.64352 .15285 .64943 .15517 .66213 .15297 .65622 .14943 Mtetra
.528 .863 .994 r
.65622 .14943 .66213 .15297 .6749 .15076 .66899 .14596 Mtetra
.569 .841 .996 r
.66899 .14596 .6749 .15076 .68774 .14853 .68182 .14244 Mtetra
.595 .808 .981 r
.68182 .14244 .68774 .14853 .70067 .14627 .69472 .13887 Mtetra
.609 .771 .958 r
.69472 .13887 .70067 .14627 .71368 .14397 .70769 .13525 Mtetra
.641 .748 .926 r
.02714 .37496 .03496 .38178 .04519 .37703 .03718 .37158 Mtetra
.639 .793 .956 r
.03718 .37158 .04519 .37703 .05547 .37223 .04727 .36816 Mtetra
.629 .838 .98 r
.04727 .36816 .05547 .37223 .06577 .36739 .05741 .36467 Mtetra
.605 .877 .992 r
.05741 .36467 .06577 .36739 .07612 .3625 .0676 .36112 Mtetra
.562 .901 .979 r
.0676 .36112 .07612 .3625 .08651 .35756 .07784 .35751 Mtetra
.495 .897 .933 r
.07784 .35751 .08651 .35756 .09693 .3526 .08813 .35384 Mtetra
.407 .86 .851 r
.08813 .35384 .09693 .3526 .10739 .34762 .09847 .35011 Mtetra
.309 .795 .743 r
.09847 .35011 .10739 .34762 .11788 .34262 .10885 .34632 Mtetra
0 0 0 r
.10885 .34632 .11788 .34262 .1284 .33762 .11928 .34247 Mtetra
.11928 .34247 .1284 .33762 .13896 .3326 .12977 .33855 Mtetra
.12977 .33855 .13896 .3326 .14955 .32758 .1403 .33457 Mtetra
.004 0 0 r
.1403 .33457 .14955 .32758 .16018 .32256 .15088 .33053 Mtetra
.054 0 0 r
.15088 .33053 .16018 .32256 .17084 .31754 .1615 .32645 Mtetra
.099 0 0 r
.1615 .32645 .17084 .31754 .18153 .31257 .17217 .32238 Mtetra
.14 0 0 r
.17217 .32238 .18153 .31257 .19225 .30767 .18287 .31837 Mtetra
.181 0 0 r
.18287 .31837 .19225 .30767 .20298 .30294 .19359 .31453 Mtetra
.221 0 0 r
.19359 .31453 .20298 .30294 .21373 .29845 .20434 .31093 Mtetra
.26 0 .014 r
.20434 .31093 .21373 .29845 .22449 .2943 .21509 .30766 Mtetra
.295 0 .054 r
.21509 .30766 .22449 .2943 .23524 .29056 .22586 .30479 Mtetra
.322 0 .086 r
.22586 .30479 .23524 .29056 .24601 .28722 .23665 .30224 Mtetra
.341 0 .111 r
.23665 .30224 .24601 .28722 .2568 .28421 .24747 .29991 Mtetra
.346 0 .125 r
.24747 .29991 .2568 .28421 .26763 .28127 .25836 .29752 Mtetra
.342 0 .131 r
.25836 .29752 .26763 .28127 .27853 .2782 .26933 .29484 Mtetra
.326 0 .128 r
.26933 .29484 .27853 .2782 .28951 .27468 .28039 .29159 Mtetra
.306 0 .122 r
.28039 .29159 .28951 .27468 .30058 .27057 .29156 .28766 Mtetra
.288 0 .116 r
.29156 .28766 .30058 .27057 .31173 .26595 .30282 .28317 Mtetra
.276 0 .112 r
.30282 .28317 .31173 .26595 .32295 .26098 .31415 .27828 Mtetra
.279 0 .115 r
.31415 .27828 .32295 .26098 .3342 .25605 .32552 .27339 Mtetra
.289 0 .121 r
.32552 .27339 .3342 .25605 .34548 .25139 .33691 .26875 Mtetra
.306 0 .129 r
.33691 .26875 .34548 .25139 .35678 .24722 .34833 .26457 Mtetra
.322 0 .137 r
.34833 .26457 .35678 .24722 .3681 .24353 .35977 .26083 Mtetra
.33 0 .14 r
.35977 .26083 .3681 .24353 .37945 .24011 .37125 .25734 Mtetra
.33 0 .139 r
.37125 .25734 .37945 .24011 .39086 .23674 .38278 .25386 Mtetra
.316 0 .131 r
.38278 .25386 .39086 .23674 .40234 .23301 .39439 .24997 Mtetra
.296 0 .12 r
.39439 .24997 .40234 .23301 .41389 .22877 .40607 .24553 Mtetra
.27 0 .105 r
.40607 .24553 .41389 .22877 .42551 .22393 .41782 .24039 Mtetra
.246 0 .09 r
.41782 .24039 .42551 .22393 .43718 .21864 .42964 .23468 Mtetra
.229 0 .076 r
.42964 .23468 .43718 .21864 .44891 .21321 .4415 .22866 Mtetra
.217 0 .061 r
.4415 .22866 .44891 .21321 .46067 .20784 .4534 .22257 Mtetra
.214 0 .047 r
.4534 .22257 .46067 .20784 .47247 .20282 .46534 .21671 Mtetra
.211 0 .029 r
.46534 .21671 .47247 .20282 .48431 .19818 .47732 .21116 Mtetra
.21 0 .009 r
.47732 .21116 .48431 .19818 .49619 .19397 .48933 .20601 Mtetra
.205 0 0 r
.48933 .20601 .49619 .19397 .50813 .1901 .50138 .20119 Mtetra
.194 0 0 r
.50138 .20119 .50813 .1901 .52012 .18647 .51349 .19662 Mtetra
.178 0 0 r
.51349 .19662 .52012 .18647 .53218 .18302 .52565 .19222 Mtetra
.153 0 0 r
.52565 .19222 .53218 .18302 .54429 .17964 .53786 .18788 Mtetra
.121 0 0 r
.53786 .18788 .54429 .17964 .55647 .17631 .55013 .18354 Mtetra
.079 0 0 r
.55013 .18354 .55647 .17631 .56871 .17298 .56246 .17916 Mtetra
.026 0 0 r
.56246 .17916 .56871 .17298 .58101 .16965 .57484 .17471 Mtetra
0 0 0 r
.57484 .17471 .58101 .16965 .59338 .16632 .58727 .1702 Mtetra
.58727 .1702 .59338 .16632 .60582 .16297 .59976 .16561 Mtetra
.59976 .16561 .60582 .16297 .61832 .15962 .61231 .16096 Mtetra
.321 .802 .747 r
.61231 .16096 .61832 .15962 .63088 .15624 .62491 .15623 Mtetra
.427 .871 .856 r
.62491 .15623 .63088 .15624 .64352 .15285 .63757 .15145 Mtetra
.521 .908 .936 r
.63757 .15145 .64352 .15285 .65622 .14943 .65028 .14659 Mtetra
.591 .911 .978 r
.65028 .14659 .65622 .14943 .66899 .14596 .66304 .14166 Mtetra
.635 .887 .986 r
.66304 .14166 .66899 .14596 .68182 .14244 .67586 .13666 Mtetra
.658 .847 .972 r
.67586 .13666 .68182 .14244 .69472 .13887 .68873 .1316 Mtetra
.668 .802 .946 r
.68873 .1316 .69472 .13887 .70769 .13525 .70165 .12647 Mtetra
.57 .726 .948 r
.01926 .36808 .02714 .37496 .03718 .37158 .0291 .36609 Mtetra
.557 .77 .978 r
.0291 .36609 .03718 .37158 .04727 .36816 .03901 .36404 Mtetra
.532 .81 .997 r
.03901 .36404 .04727 .36816 .05741 .36467 .04897 .36191 Mtetra
.489 .838 .996 r
.04897 .36191 .05741 .36467 .0676 .36112 .05899 .35971 Mtetra
.424 .843 .962 r
.05899 .35971 .0676 .36112 .07784 .35751 .06907 .35743 Mtetra
.337 .815 .888 r
.06907 .35743 .07784 .35751 .08813 .35384 .07922 .35509 Mtetra
.238 .754 .778 r
.07922 .35509 .08813 .35384 .09847 .35011 .08942 .35267 Mtetra
0 0 0 r
.08942 .35267 .09847 .35011 .10885 .34632 .09968 .35017 Mtetra
.09968 .35017 .10885 .34632 .11928 .34247 .11 .34761 Mtetra
.03 0 0 r
.11 .34761 .11928 .34247 .12977 .33855 .12038 .34496 Mtetra
.093 0 0 r
.12038 .34496 .12977 .33855 .1403 .33457 .13082 .34225 Mtetra
.143 0 0 r
.13082 .34225 .1403 .33457 .15088 .33053 .14132 .33946 Mtetra
.183 0 0 r
.14132 .33946 .15088 .33053 .1615 .32645 .15187 .33659 Mtetra
.215 0 0 r
.15187 .33659 .1615 .32645 .17217 .32238 .16249 .33364 Mtetra
.239 0 0 r
.16249 .33364 .17217 .32238 .18287 .31837 .17316 .33062 Mtetra
.257 0 .001 r
.17316 .33062 .18287 .31837 .19359 .31453 .18389 .32753 Mtetra
.269 0 .025 r
.18389 .32753 .19359 .31453 .20434 .31093 .19468 .32435 Mtetra
.273 0 .037 r
.19468 .32435 .20434 .31093 .21509 .30766 .20552 .3211 Mtetra
.27 0 .035 r
.20552 .3211 .21509 .30766 .22586 .30479 .21642 .31777 Mtetra
.259 0 .019 r
.21642 .31777 .22586 .30479 .23665 .30224 .22738 .31437 Mtetra
.239 0 0 r
.22738 .31437 .23665 .30224 .24747 .29991 .2384 .31088 Mtetra
.208 0 0 r
.2384 .31088 .24747 .29991 .25836 .29752 .24947 .30732 Mtetra
.171 0 0 r
.24947 .30732 .25836 .29752 .26933 .29484 .2606 .30367 Mtetra
.135 0 0 r
.2606 .30367 .26933 .29484 .28039 .29159 .27179 .29995 Mtetra
.113 0 0 r
.27179 .29995 .28039 .29159 .29156 .28766 .28303 .29615 Mtetra
.114 0 0 r
.28303 .29615 .29156 .28766 .30282 .28317 .29433 .29226 Mtetra
.133 0 0 r
.29433 .29226 .30282 .28317 .31415 .27828 .30568 .2883 Mtetra
.161 0 0 r
.30568 .2883 .31415 .27828 .32552 .27339 .31708 .28426 Mtetra
.183 0 0 r
.31708 .28426 .32552 .27339 .33691 .26875 .32854 .28013 Mtetra
.194 0 0 r
.32854 .28013 .33691 .26875 .34833 .26457 .34006 .27592 Mtetra
.19 0 0 r
.34006 .27592 .34833 .26457 .35977 .26083 .35163 .27164 Mtetra
.172 0 0 r
.35163 .27164 .35977 .26083 .37125 .25734 .36325 .26727 Mtetra
.142 0 0 r
.36325 .26727 .37125 .25734 .38278 .25386 .37492 .26281 Mtetra
.104 0 0 r
.37492 .26281 .38278 .25386 .39439 .24997 .38665 .25828 Mtetra
.075 0 0 r
.38665 .25828 .39439 .24997 .40607 .24553 .39843 .25366 Mtetra
.064 0 0 r
.39843 .25366 .40607 .24553 .41782 .24039 .41026 .24896 Mtetra
.08 0 0 r
.41026 .24896 .41782 .24039 .42964 .23468 .42214 .24418 Mtetra
.113 0 0 r
.42214 .24418 .42964 .23468 .4415 .22866 .43407 .23931 Mtetra
.148 0 0 r
.43407 .23931 .4415 .22866 .4534 .22257 .44605 .23436 Mtetra
.178 0 0 r
.44605 .23436 .4534 .22257 .46534 .21671 .45809 .22933 Mtetra
.196 0 0 r
.45809 .22933 .46534 .21671 .47732 .21116 .47017 .22421 Mtetra
.204 0 .001 r
.47017 .22421 .47732 .21116 .48933 .20601 .4823 .21901 Mtetra
.201 0 0 r
.4823 .21901 .48933 .20601 .50138 .20119 .49448 .21373 Mtetra
.188 0 0 r
.49448 .21373 .50138 .20119 .51349 .19662 .50671 .20836 Mtetra
.166 0 0 r
.50671 .20836 .51349 .19662 .52565 .19222 .51899 .2029 Mtetra
.133 0 0 r
.51899 .2029 .52565 .19222 .53786 .18788 .53131 .19736 Mtetra
.09 0 0 r
.53131 .19736 .53786 .18788 .55013 .18354 .54368 .19174 Mtetra
.035 0 0 r
.54368 .19174 .55013 .18354 .56246 .17916 .5561 .18603 Mtetra
0 0 0 r
.5561 .18603 .56246 .17916 .57484 .17471 .56856 .18024 Mtetra
.56856 .18024 .57484 .17471 .58727 .1702 .58107 .17436 Mtetra
.58107 .17436 .58727 .1702 .59976 .16561 .59362 .16839 Mtetra
.319 .782 .653 r
.59362 .16839 .59976 .16561 .61231 .16096 .60621 .16235 Mtetra
.431 .866 .771 r
.60621 .16235 .61231 .16096 .62491 .15623 .61885 .15621 Mtetra
.533 .924 .869 r
.61885 .15621 .62491 .15623 .63757 .15145 .63153 .14999 Mtetra
.615 .947 .935 r
.63153 .14999 .63757 .15145 .65028 .14659 .64426 .14369 Mtetra
.671 .939 .965 r
.64426 .14369 .65028 .14659 .66304 .14166 .65702 .13729 Mtetra
.702 .908 .968 r
.65702 .13729 .66304 .14166 .67586 .13666 .66983 .13082 Mtetra
.716 .866 .952 r
.66983 .13082 .67586 .13666 .68873 .1316 .68268 .12425 Mtetra
.719 .82 .928 r
.68268 .12425 .68873 .1316 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Sooooo`03okSAkOl0003ooooo01Gooooo00?o
0000ooooooooool0DOooool0063ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`0Mooooo`?o00000_ooool00ol0003oooooooooo`1Oooooo`?o^=7]00?o
0000okSAkOooool05Oooool00ol0003oooooooooo`1@ooooo`00H?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol0000Looooo`;o0000IOooool2okOMl`?o^=7]00?o0000oj_=l_ooool05?oo
ool00ol0003oooooo`00001Aooooo`00H?ooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00006_ooool3o`0006Gooooo1OnggO<00onhdNgoZlgbo`000002oj_=lQKooooo
00?o0000ooooooooool0Coooool0063ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgM
gOmEEEGoooooo`0001Sooooo0_l0001Vooooo`;o/nSg1?nggO<2ojSHn003oj_=l_l0003oZlgb00;o
Zlgb5_ooool00ol0003oooooooooo`1>ooooo`00H?ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l000005Oooool3o`0000;ooooo00?o0000ooooooooool0HOooool5ok?Xm`03
okOMlonXf?SoZ=Sh00?oZ=Sh00Co0000oj_=l_nKaOGoVlGe5_ooool00ol0003oooooooooo`1>oooo
o`00H?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000004oooool2o`00
06Oooooo0on[l?L2ok?Xm`?oX^?l0onXf?P2oiS>n`03o`000?nKaOGoVlGe00;oVlGe5_ooool00ol0
003oooooooooo`1=ooooo`00H?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`00
0?ooool03oooool3o`0006Oooooo1?n[l?L00onGjO[oX^?loj;So002oj;So0;oTMOn1?nHc_/00ol0
003oVlGeoi_5m@03oi_5mAKooooo00?o0000ooooooooool0C?ooool008;ooooo0_l0001Xooooo`;o
WO;_00?oZo3goiOYn_nGjOX00onGjOX00onRhocoTMOnoi7GoP03oi7GoP?oV<kk00Co0000oi_5mOnK
aOGoVlGe0_n>^oDFooooo`03o`000?oooooooooo04cooooo001oooooo`?o00000_ooool00ol0003o
ooooooooo`1Sooooo`;oWO;_1?n5j>l2oiOYnPCoQmcn0_nAeoh2ohK7o@?oR/7i00?o0000oh[1nOn>
^oD01?n>^oDDooooo`?o0000COooool007cooooo0ol0001Yooooo`04ohS/g_m]g]_oKMkKofgNf`;o
QNS_1?mhgOL2ohOLoP?oP<co1?n6aod2oh[1n@03o`000?n:`OWoR/7i00CoS[_e5oooool00ol0003o
ooooooooo`1:ooooo`00N_ooool2o`0006[ooooo00CoR>cNofgNfom]g]_oKMkK1?mUf>T2ogSMm`Co
NLoo1?n0c?l4ohK7o@;oR/7i00?o0000ohBclon5/O801?n5/O8Fooooo`03o`000?oooooooooo04[o
oooo001gooooo`?o0000J_ooool2oe;=_`;oD<gD1?mXd_T4og3Bo@;oNLoo0_n2]oL5oh:fmPCoPkCe
00CoQ;?co`000?n4/o?oQ;?c1On5/O8Fooooo`03o`000?oooooooooo04Wooooo001eooooo`;o0000
0_ooool00ol0003oooooooooo`1Uooooo`03oe78Yolj_[go>[jm00CoGm7b0_mXd_T2ohBin0GoP[Sg
1?n2]oL5oh:fmPCoPkCe00Co0000ohBclon4/o?oQ;?c0_n5/O82oh>/kaOooooo00?o0000oooooooo
ool0B?ooool007;ooooo0ol00005ooooo`03o`000?oooooooooo05oooooo0ol000000omAb:OoElo[
oeO?j`02ohNln0GoQK_h1?n4^OP5oh:hm`CoP[Og0_n2]_H2ohNVj@CoQJS[00Co0000ohBZkOn4Z^go
Q:[]1On3[>lFooooo`03o`000?oooooooooo04Sooooo001`ooooo`;o0000Ioooool5o`0000?oRKgg
1?n7_?P5ohFkn0CoQ;Wh0_n2^?L2ohZRi0CoR:CV1On7Y^T3ohFXj`03o`000?n4Z^goQ:[]00;oQ:[]
1On3[>lFooooo`03o`000?oooooooooo04Oooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol0000Pooooo`?o0000IOooool01?l3003o0000o`H00?l60003o`000003
ohbmmon9_OOoRKgg00?oRKgg1?n7_?P2ohFkn0;oSYgN1?n<Wn45ohZRi0CoR:CV1On7Y^T2ohFXj`03
o`000?n5Z>_oQ:[]00?oQ:[]0_n3[>l2ohRZjaGooooo0ol00018ooooo`00>?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@07_ooool2o`00
00?ooooo00?o0000ooooooooool0G_ooool01?l<003o0`00oa@00?lD0003o`H000;o00001?n<_OL2
ohVmm`;oTIWH1?n@Vm/5ohjMgPCoS9oQ1On:X^@4ohRTiP;oQjKY0_n=V]/2ohbOh003o`000?n<Wn3o
RZCV00CoRZCV1?n8Z^/Fooooo`03o`000?oooooooooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo02Wooooo000hooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Looooo`?o0000G_ooool2oa/000?o500000?o
3000oah00?lN00000olD00000ol6003o0000o`000002ohjmmP03oiBFd_nCV=GoTiSE00;oTiSE1OnA
VMP4oi2Kf`CoSYgN1On<Wn42ohZRi0;oT97@1?n?UMD5ohfJf`04ohbOh?l0003oS9oPohbOh0GoRZCV
1?n8Z^/Fooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1oooool00ol0003oooooooooo`0Zooooo`00>?ooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h06?ooool3o`0005gooooo0_lP0003oa/00003oa@00?lW003o9`0000Co
7P0000Co5000o`P00?l0003oT;ge0_nFU<l4oiBFdPCoTiSE1?nAVMP5oi2Kf`CoSYgN0_n<Wn42oi6=
b`GoT97@1?n?UMD4ohfJf`03ohbOh?l0003oS9oP00;oS9oP0_n:Y>H2oiBUh@GoTjgX5_ooool00ol0
003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0002_ooooo000hoooo
o`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Eooooo`?o0000G?ooool0
1OlV003o8000ob000?lP003o6`0000;o;@001?lW0003oah000;o200000?oUY;=oiJDconFU<l00onF
U<l3oiBFdPCoTiSE1OnAVMP2oi2Kf`;oTXK31?nBRLL5oi6=b`CoT97@1?n?UMD5ohfJf`04o`000?n<
Wn3oUIkJoiFNfPGoU:GQ1OnC[NPEooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002cooooo000hooooo`05oa0@4?oooooooooooooo
ool@41003oooool00ol0003oooooooooo`0Aooooo`?o00000oooool00ol0003oooooooooo`1Coooo
o`;o00000_l[0003obH00003ob000?la003o;@0000?o;@000olW00001?lN003o5`00oaL00?l80004
oiJBc@CoUYC?1?nDU]84oi>He@;oTIWH0_nCPkl5oi:6``CoTXW71?nASL/4oi2Ad0GoSiGE0_n=V]/2
oiJGd`03o`000?nEW][oUIkJ00;oUIkJ1?nDYN44oi>]j003oinaiOoooooooooo01Cooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo0000
;?ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41004Oooool2o`0005Wooooo00?o0000obl00?l_00001?l[0002obH000?o<@000ol]00000olW003o
8P00ob800003oaL000;oUho:1?nFT/d5oiJDc`;oU9KB00?oU7jioi>0_?nCP;`00_nCP;`5oi>3_`Co
TXK31?nBRLL5oi6=b`CoT97@0_n?UMD2oiJBc@CoUYOC00?o0000oiFNf_nEW]X00_nEW]X5oiBUh@03
oi>]j?nO/NGoWk7U00;oWk7U5_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00omgMgOoc<c<o`00000/ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00>ooooo`?o0000Doooool2oad000?o4`0000?o1P00
oc@00?l_00000ol_0003ob/00003obH00?ld003o<@0000;o<@000_l]00000olZ003o8P00ob800002
ob800003oaL00?nGSl[oUho:00;oUho:1OnFT/d2oiJDc`;oU7bf1?nDO[T4oi>0_0CoTh>o1?nBQ/<5
oi:9a`;oTHg;0_nGRL<4oiN=a`GoUY;=0onFUm<00ol0003oUIkJoiFNfP03oiFNfP;oU:GQ0_nOZ=d6
oinaiACooooo0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00
000/ooooo`00FOooool3o`0005;ooooo00Go9000oad00?lM003o7@00oa<00002ocT02`?o=0000ol_
00000ol[003o=@02ocD00P03oc@000?o<@000olZ0003ob8000;oUXc71OnGSlX2oiJBc@;oU7Zd1?nD
O;H4oiAn^@CoTh2l1?nCPkl5oi:6``;oTXW70_nGQKh5oiN9``CoUhg71?nFT/d3oiJGd`04o`000?nF
Um?oUIkJoiFNfP;oWZ3F1OnOZ=d4oinai@03oj^hhooooooooooo017ooooo00Co0000oooooooooooo
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0:oooool005Ko
oooo0ol00003ooooo`03o`000?oooooooooo04_ooooo0_lY0003ob@00003oad00?ln01Co>@0;00?o
>@0;0_ld0002obl00003ocH01ole00;o=@0200;o=@020_ld00000ola003o<000oc000003obX000;o
8P0000?oUXW4oiJ<aonFS<L00_nFS<L2oiN?bP;oUGVb1?nDN[@5oiAl]PCoU7ji0onCP;`5oi>3_`?o
TXK300?oUh:joiN5__nGQKh00onGQKh4oiN9``CoUhg71OnFT/d2oiJGd`03o`000?nNVLooWZ3F00Co
WZ3F1OnOZ=d00onO/NGoZkSSoj^hh`02oj^hhaKooooo00?o0000ooooooooool0@?ooool005Cooooo
0_l0001Aooooo`03ob/00?lY003o:@0000;o:@000_lT0003och050?o>@0;0old0003ocH01`?o=@02
00?o=000oc<00?l`00000ol`0003obX000CoUXW40_nFS<L00onDMk3oUGVboiEi/P02oiEi/PGoU7Zd
1?nDO;H4oiAn^@CoTh2l1?nCPkl00onBQ/?oUh:joiN2^P02oiN2^PCoUhFn1?nGRL<5oiN=a`;oUY;=
0_nNTlT2oijIc`03o`000?nNVLooWYW?00GoWZ3F0_nOZ=d2ojZ_g0GoZkSS5_ooool00ol0003ooooo
ooooo`10ooooo`00DOooool3o`0005;ooooo0_l[0003obT00003ob@00?m401_o?P0D00;o?P0D0oli
00/00old003o=P0<ocH03003ocH01`?o=@020olc0003oc000004obX00?nDQL7oU8G1oiB5`@CoUXW4
00?oUXc7oiAg/?nDMk001OnENK84oiAj]0CoU7bf1?nDO[T4oi>0_0;oTh>o0_nGOkL5oiN2^PCoUhFn
1OnGRL<3oiN=a`03oij?`onNTlWoWY?900?oWY?900CoWYW?o`000?nNVLooWYW?1?nNX=H00onYZ=Ko
ZZoLojZ_g003ojZ_g0?oZkSS0_ne_n8Fooooo`03o`000?oooooooooo03oooooo001>ooooo`Go0000
D?ooool4ob/00003obT00?m:023oBP0P00?oA00K0oln01@00oli00_o=`0?ocH03003ocH030?o=P07
00?o=@02oc@00?lc00000_lc0002oc0000;oTh:n1?nDQL42oiJ9a0;oU7F^1?nDMk04oiEi/PCoU7Zd
1OnDO;H4oiAn^@;oTh2l00?oUgbdoiMo]onGOkL00onGOkL4oiN2^PGoUhFn1?nGRL<00onGSLOoWXo3
oij?``02oij?``CoWY?900?oWYW?o`000?nNVLl00_nNVLl00onNX=KoZJSFojVXeP02ojVXePCoZZoL
00?oZkSSokFoh_ne_n800one_n8Fooooo`03o`000?oooooooooo03kooooo001<ooooo`;o00001Ooo
ool00ol0003oooooooooo`1:ooooo`03obL00?l[003o:`0000;o:`0000?oC`0SodX08?m:02000_m:
0202od@06`Co?P0D0_lg00l3ocH030;o=P0700Co<P00oc@00?ld003o=0000olc0004oi>2_P;oU8G1
0_nCLj`4oiAe[PCoU7N`1?nENK85oiAj]0CoU7bf0_nDO[T2oiMj/@?oUgbd1OnGOkL5oiN2^PCoUhFn
0_nGRL<2oif:_`GoWXo31?nNTlT01OnNVLoo0000oijIconNVLooZ:;@00GoZJSF0onZ[m`2okBjgPCo
]KoR00?o^lKSooooooooool05?ooool00ol0003oooooooooo`0nooooo`00BOooool3o`00057ooooo
00Co8@00obL00?lW003o9`000_l[0003odl08`?oBP0P0om401/2och05003ocX04olg00oo=`0?00Co
=P0<0olb0002oc@000;o<`000_nBOk/2oi>2_P;oTW2Y1?nCLj`5oiAe[P?oU7N`1?nENK85oiAj]0;o
U7bf0_nGN:l4oiMj/@CoUgbd1?nGOkL5oiN2^P;oUhFn0_nMQk/5oif:_`CoWXo31OnNTlT00onNVLoo
0000ojRRd002ojRRd0GoZJSF00?oZZoLokBjg_nd^]h00_nd^]h00one_n;o^lKSok_6h`02ok_6haCo
oooo0ol0000oooooo`008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^023ooooo0_l0001Booooo`;o
8@000olW00000ol[003oD`0Todl08`02odl08`?oBP0P1?m401/3ocX04`;o=`0?0_lf00`01?l]003o
<P00oc800?lb0003oc@00004oi9n^_nBOk_oTWnkoi5^Y`CoTW2Y1OnCLj`4oiAe[P?oU7N`1OnENK83
oiAj]003oiMg[OnGN:ooUgR_00;oUgR_1OnGN[43oiMl]0GoUgng0onGP[X00onMPkOoWHNkoif7^`03
oif7^`CoWHZo1OnNSl<2oijCb@;oZ9c;00?oZ:;@o`000?nXX]000_nXX]04ojVXeP03ok>ef_nd^]ko
];[N00;o];[N00?o^lGQok_6honka^<01?nka^<Eooooo`03o`000?oooooooooo03gooooo000Roooo
o`05ogMgMonHV9SooooooiRHV?mgMgL07Oooool3o`0000;ooooo00?o0000ooooooooool0C?ooool2
oaX000;o8@0000?o9`00oeD08omE02<00omC02@3odl08`?oBP0P00?oA00Koch05oln01L00olj01<3
ocL03`?o;@000_lb00000old003oTWjjoi9n^P02oi1/YP?oTFjW1OnBL:T4oi=c[0CoU7F^1?nDMk04
oiEi/P04oiAj]?nGMjgoUgN]oiMg[@GoUgR_1?nGN[43oiMl]0GoUgng00CoUh:joif3]onMPkOoWH>g
1OnMQk/4oif:_`CoWXo300?oYiS6ojRLbonXW</00onXW</00ol0003oZ:;@ojRRd002ojRRd003ojVX
e_nc]M[o/kGJ00;o/kGJ0_nd^]h3ok_5h@Co^lKS0_nncNHEooooo`03o`000?oooooooooo03cooooo
000Rooooo`05oa0@4?ooooooooooooooool@41006oooool2o`00057ooooo00Ko5P00oaX00?lJ003o
6P00ob400?mC0244oeD08`;oD`0T1?m?02<00om:023oA@0Joch05`03och05`;o>P0C0_lg00l01OlU
003o;@00obd00?l]003o<P0000;oTgjh00?oT6bUoi1/Y_n@K:H00_n@K:H4oi5^Y`CoTW2Y1?nCLj`4
oiAe[PCoU7N`0_nENK82oiMf[0GoUgN]1?nGN:l4oiMj/@CoUgbd0onGOkL00onLPKCoWH>goif3]`03
oif3]`CoWHNk1OnMR[l00onNSl?oYiS6ojNHaP02ojNHaPCoZ9c;00Go0000ojRRd?nXX]3oZ:;@ok>a
eP05ok>efP03okBjg_nkaN7o^lGQ00?o^lGQ00?o^lKSokk=i_nncNH00onncNHEooooo`03o`000?oo
oooooooo03_ooooo000Rooooo`05o`000?ooooooooooooooool000006?ooool3o`00053ooooo00Ko
5@00oaH00?lF003o5P00oaX00?m@01h3oe<08@?oE@0S0omC02@3odl08`03odX08?m501[oA@0J00?o
?P0G0olj01<3obD000?o;@0000CoTFbUoi1/YOn@K:GoT6bU1On@K:H3oi5^Y`CoTW2Y1?nCLj`5oiAe
[P;oU7N`00?oUgBZoiMf[?nGMZ`00_nGMZ`5oiMg[@CoUgR_1OnGN[43oiMl]004oiMo]onLPKCoW86d
oib1]0GoWH>g1OnMQk/3oif:_`03ojND`_nWV<KoYiS600?oYiS61?nXW</00ol0003oZ:;@ok>aeP03
ok>aeP?o/kGJ0_nla>44ok_5h@;o_m;X1?nncNH00onjcn[oooooooooo`0Cooooo`03o`000?oooooo
oooo03_ooooo000Rooooo`05o`000?ooooooooooooooool000005_ooool3o`00053ooooo0_lE0003
oaH000?oD00N0_mC0243oeD08`CoD`0T00?oC`0Sod/07_m;01h00_m501X4och05`03ocX04olL003o
9@0000;o9@000_l]0003oi5/Y@CoT6bU1?n@K:H3oi5^Y`CoTW2Y1OnCLj`4oiAe[P03oiAg/?nGM:[o
UgBZ00GoUgJ/1?nGMjd4oiMh[`GoUgZa0_nGO;@00onLO[;oW86doib1]003oib1]0CoWH>g1OnMQk/0
0onMR[ooYiC2ojND`P02ojND`PCoYiS61?nXW</00ol0003o/k7Fok>aeP04ok>aeP03ok>ef_nla>7o
_<CQ00;o_<CQ00?o^lGQokoBj?nod^P00onod^P00onncNKo^/oZok[?jP02ok[?jQGooooo00?o0000
ooooooooool0>_ooool002;ooooo00Go410@oooooooooooooooooa0@400Cooooo`?o00000_ooool0
0ol0003oooooooooo`1<ooooo`04oaT00?lE003o5@00oaH000;oB`0L0om@01h3oe<08@?oE@0S00?o
D`0Toe008Om@02401?m;01h2odD06PCo?P0G0_lL0003obD00003oi9^Y_nAK:GoTFbU00;oTFbU1?n@
K:D4oi1/YP?oTFjW1?nBL:T5oi=c[0;oU7F^0_nGLjT4oiMdZPCoUgJ/1?nGMjd5oiMh[`?oUgZa00?o
Vgb`oian/_nLO[800_nLO[84oib1]0GoWH>g0onMQk/00onVTKooYiC2ojND`P03ojND`PGoYiS600Go
Z9c;ok>^donc[]?o0000ok>^d`04ok>aeP03okc4h?nla>7o_<CQ00;o_<CQ00?o`=S[okoBj?nod^P0
0onod^P00onkfNoo^/oZok[?jP03ok[?jQKooooo00?o0000ooooooooool0>Oooool002;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0@ooooo`?o0000D?ooool2oah000;o6@0000?o5@00odL06om;01`0
0om;01`3oe007P?oD`0Q00?oE@0Soe@08om@02400om@0243od/07P?oA@0J0_ln01L01?lD003o7000
oa`00?lU0005oi9^YP?oTFbU1?n@K:D4oi1/YP?oTFjW1OnBL:T3oi=c[003oiMbYonGLjWoUg>Y00;o
Ug>Y1?nGM:X4oiMf[0CoUgN]1OnGN:l01?nGN[7oVgb`oi]l/?nKO;04oian/PCoW86d1OnMPkL00onM
Qk_oYY6oojJA_`02ojJA_`CoYiC21?nWV<H01OncZm7o/jkCok>^donc[]?o000000;o/jkC00?o/k7F
okc4h?nla>000_nla>02okc4h@?o`=S[0onod^P3ok_Ik`?o^/oZ0_nbcnlDooooo`;o0000>oooool0
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`;o0000D?ooool01_lS003o7P00oah00?lN
003o6@00odH070?oA`0K0om;01`3oe007P;oD`0Q1?mD02<3oe008@?oB`0N0om501X01?ln01Oo5000
oa@00?lL0004oiE`Y`CoTVjV0onAK:D4oi1/Y@CoT6bV1?nAKZL4oi9`Z@04oi=c[?nGLZOoUg:WoiMb
Y`GoUg>Y0onGM:X4oiMf[0GoUgN]0onGN:l00onKNZkoVgb`oi]l/003oi]l/0CoW7jb1?nLPK@3oif3
]`03ojJ>_?nVTKooYY6o00?oYY6o1OnWU<800onWV<Ko/j_Aok>[d@02ok>[d@;o/jkC00?o0000ok>^
donmaN001Onla>000onla>7o`=S[ol3Hj`03ol3Hj`03okoBj?nkfNoo^mW_00?o^mW_00?o^/oZok;?
konbcnl00_nbcnlEooooo`03o`000?oooooooooo03Sooooo000booooo`Go0000COooool01?lU003o
8`00ob<00?lS0002oah000?oAP0L0_m701/3od/070CoD00N1OmD02<4oe008@?oB`0N00?oA@0Joa00
0?lD00000_lD0003oiMcZ0?oUG2W1?nBKZH4oi5/Y@?oT6bU1On@K:H3oi5^Y`;oTW2Y0_nFL:H5oiMb
Y`CoUg>Y0onGM:X5oiMf[0CoUgN]00CoUgR_oi]j[_nKNZkoVgZ^1OnKO;04oian/PCoW86d00?oWH>g
ojJ>_?nVS[`00_nVS[`4ojJA_`CoYiC200?o/jW?ok>[dOncZm400oncZm400onc[]?o0000o`000003
okg5h0?o_<CP0_o1gnh4ol3Hj`?o^^?d0_nkfNl2ok3KmPCo//o_00?oY/Wbooooooooool05?ooool0
0ol0003oooooooooo`0gooooo`00<?ooool2o`00057ooooo0_lU0002ob<00003oah00?m701koAP0L
00;oAP0L0om701/3od/07003oe007_mB02?oDP0S00KoE00S0om@0242od/07P05oa<00?l@003o4000
oa@00?nHMJX01OnGLjP3oiE`Y`CoTVjV1?nAK:D4oi1/Y@CoT6bV0_nAKZL00onDKZGoUW2VoiI`YP02
oiI`YPGoUg:W1?nGLjT3oiMdZPGoUgJ/0_nGMjd2oiYi[0GoVgZ^1?nKO;04oian/P?oW86d00?oYHbj
ojJ>_?nVS[`00onVS[`5ojJA_`03ojND`_ncZLoo/jW?00;o/jW?0_ncZm43o`000003ok>^dol0003o
_LGP00;o_LGP00?o_<CPol7Ok_o1gnh00oo1gnh00oo0f>_o^^?dok[Sm002ok[Sm003oj[Vn_n`foKo
/=_f00?o/=_f00?o//o_ojK9l_nVbO800_nVbO8Eooooo`03o`000?oooooooooo03Oooooo000]oooo
o`?o0000D?ooool2ob8000;o9@0000?o8`00od/08Om701h00_m701h2odH070CoA`0K00?oB`0Lodh0
8OmB02<00omB02<6oe@08`?oD00Q0olC00000onIMj_oV7FZoiQeZP02oiQeZPCoUg>X0onEL:L4oi9^
YPCoTFbU1?n@K:D4oi1/YP03oi5^YonDKZGoU6jU00GoUW2V1?nGLZL4oiMcZ@CoUgBZ0onGMZ`00onJ
N:coVWV/oiYi[002oiYi[0GoVgZ^1?nKO;05oian/P04oib1]?nUS;[oYHbjojF<^PCoYXjl1?nVTKl0
0oncZ<ko/jW?ok>Yc`02ok>Yc`?o00000_ncZm42okk7h@03okg5h?l0003o_LGP00;o`>Oa1?o1gnh3
okC]mP03ok[Sm?nZi_[oZ^Kj00;oZ^Kj0_n`foH3oj;Bn@GoY/Wb5Oooool00ol0003oooooooooo`0f
ooooo`00;?ooool2o`0004oooooo00Co6000ob800?lR003o8P000_lU0003od/08@;oA`0N0om601`0
0om701_oB@0NodT07P03odh08@?oDP0S1_mD02<2oe008@04oaX00?lC003o4`00oa<000;oVGN[1?nH
MJX4oiMcZ0?oUG2W1OnBKZH3oi5/Y@CoT6bU0_n@K:H2oi=/X`CoU6jU1?nFL:H4oiMbY`CoUg>Y1?nG
M:X01?nGMZcoVWR/oiYh[?nJN:`5oiYi[0CoVgZ^1OnKO;03oian/P03ojF:^?nUS;[oYHbj00;oYHbj
1OnVS[`00onVTKoo/jS>ok>XcP02ok>XcP?o00000_ncZLl00oncZm7o_/OQokk7h@03okk7h@03okg5
h?l0003o`>Oa00;o`>Oa00?o`Mo^okC]m_ndkOH00_ndkOH2oi[/m`;oZ^Kj0onJfod5oj;Bn@;oY/Wb
0onJ_o8Eooooo`03o`000?oooooooooo03Gooooo000/ooooo`?o0000COooool01_lH003o8P00ob80
0?lR003o9@00odl08P?oB`0Q0om701h00om601coA`0ModT07P03odT07P;oCP0Q0omB02<5oe@08`;o
90000_lJ00000olC003oV7N/oiUgZ`03oiUgZ`CoV7FZ1?nGLjP4oiE`Y`CoTVjV0onAK:D2oi1/Y@;o
TFZR1?nCK:<4oiA^Y@CoUW2V1?nGLZL5oiMcZ@;oUgBZ00?oVWR[oiYh[?nJN:`00onJN:`4oiYi[0Co
VgZ^1OnKO;000onLO[;oYHZhojF:^002ojF:^0?oYHbj1?nVS[`00ondZ<go/jS>ok>XcP03o`0000Co
/jW?0_nob^<4okk7h@05okc_loo0io7o`>Oao`000?o0io400onXlo<01?ndkOKoV^cgoi[/monJk?L2
oh_Oo@GoV]_m0_nRd_T3oiO4mPGoV[ob5?ooool00ol0003oooooooooo`0eooooo`00;?ooool01?l0
003oooooo`000?l0001:ooooo`03o`<00?lH003o8P0000;oDP0R0om?0283od/08@?oA`0N0_m701d3
odT07P?oCP0Q0omB02<00omD02?o;000ob`00003ob@00003oaX00?nHMjcoV7N/00?oV7N/1?nIMj/3
oiQeZPGoUg>X0onEL:L4oi9^YP;oTFbU00?oT6VRoi5ZX_nAJZ800_nAJZ85oi=/X`?oU6jU1?nFL:H5
oiMbY`CoUg>Y00?oUgBZoiYhZonJN:/01OnJN:`4oiYi[0GoVgZ^0onKO;000onTR;OoYHZhojF:^003
ojF:^0CoYHbj0_nVS[`01?ndZ<go0000o`000?l00004ok>XcP03ok>Yconob^?o_l[S00?o_l[S00?o
_/OQokc_lonlko<00_nlko<01?o0io7o0000ojSclonXlo<2ogcVi@?oLmce1?n;god2oi[Ko@?oT/Oj
1OnGa?H2oiZolP;oU;S_4oooool00ol0003oooooo`000008ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c00Iooooo`00;?ooool2o`0000;o
oooo00?o0000ooooooooool0AOooool2o`<00003oe<07_mB02;oDP0R00;oDP0R0_m?0283od/08@;o
A`0N00?oAP0LodL07Om701d01?m901h3odh08@03oe808ol`003o;00000;o;0000olT0003oiMf[0Co
V7N/1?nIMj/3oiQeZPGoUg>X0onEL:L2oi9^YP;oSfRR0on@JJ84oi5ZXPGoTfbS0onDKZD4oiI`YPGo
Ug:W0_nGLjT2oi]hZ`CoVWR[1?nJN:`4oiYi[0GoVgZ^00?oVgb`ojB8]onTR;L00_nTR;L4ojF:^0Co
YHbj0ol00002okBXc@Co/jS>00?o`<kUoko:honob^<00onob^<2ok;fl@;o_>oc0on?kn<01?m?bkoo
0000oeC?hOmDcn42og?Lm@?oQLWn1On<bO`4oi;7nP;oUlCf0_nC]o05oiBhkaGooooo00?o0000oooo
ooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOo
oooooiRHV?lQ8B406Oooool002_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`12
ooooo`03o`000?l3003o0`0000;oD`0N0omB0283odl08P?oB`0Q0om601`2odL07@?oB@0N0_m>0240
1?la003o<000oc000?l`0002ob`00004ob@00?nEM:coUGB/oiEd[0?oUgJ/1?nHMj`4oiUgZ`CoV7FZ
1?nGLjP2oiE`Y`03oi1YX_n?J:;oSfRR00;oSfRR0on@JJ85oi5ZXPCoTfbS0onDKZD5oiI`YP?oUg:W
00?oVgRZoi]hZonKN:/00_nKN:/4oiYhZ`CoVWR/1OnJNJ`3oi]j[P03oj>6]_nTR;OoY8Rg00?oY8Rg
1OnUR[P00onUS;[o0000o`000005okBXc@?o/jS>0oo0c^D3oko:h`;o/_Ka0omVf<401_n?kn?o<KW5
og_3o_mk`okoOlOno`0000?oOlOn1?n5bOh2ohc9o0;oT;;^1?nB]Nl5oi>gl0CoU;S_5Oooool00ol0
003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000001Wooooo000[ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@?ooool0
0ol0003o0`00oe005P02oe<07P?oDP0R1?m?02800om;027oB@0ModH07002odH070;oA`0M1?m901h3
oc4000;o<00000?o;000oi=bZ_nEM:`01?nEM:`3oiMf[0CoV7N/1?nIMj/4oiQeZP;oUg>X0_n@JZ<3
oi1YXPCoSfRR1?n@JJ84oi5ZXPCoTfbS1?nDKZD4oiI`YP04oiMbYonKN:[oVgRZoi]hZPGoVgR[0onJ
N:/4oiYh[0GoVWV/00CoVgZ^oj>6]_nSQ[KoXhJf1OnTR;L3ojF:^0?o00000ondZLd5okBXc@03ok>X
c_o0c^Go`<kU00?o`<kU00?o_l[Sok;flOnbm_400_mVf<43og^oo0CoNl?n00Co0000ogo7o_n@Z>Ko
T:SV1On?[^/4oi2bkPCoT[G_0_nC]o02oiF]i`GoUK;[5Oooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q01Wooooo000[oooo
o`?o00001Oooool00ol0003oooooooooo`0looooo`03o`000?m900_oB@0;00?oD00F0_mC01h3oe80
8P03odl08_m>01ooCP0O00?oB@0M0om601`2odL07@03odT07_l^003o;P0000?o<@0000?o<000oi9`
ZOnCLZX00onCLZX4oiEd[0?oUgJ/1OnHMj`3oiUgZ`;oV7FZ0_nAJj<4oi1ZX`?oT6VR1On?J:83oi1Y
XPCoTFZR1?nCK:<4oiA^Y@?oUW2V00?oW7RZoi]hZ_nKN:X00onKN:X4oi]hZ`?oVWR[1OnJN:`3oiYi
[003oj:5]OnSQ[KoXhJf00?oXhJf1?nTR;L3o`000003ojF:^?ndZ/ko]:W=00?o]:W=1?ndZ<d2ol7D
j@Co`<kU0_nMm>@3ogfhn@;oNkol0_nBV]P4oi2Qh003oi2Xi_l0003oT:SV00;oT:SV1On?[^/3oi2b
kP;oT[G_0_nFYn85oiF]i`GoUK;[5Oooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<01Wooooo000[ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0>?ooool00omKd;?o?000odT02`03odT02`;oD00F0omC01h0
0omB02;oD`0Podh07`03odh07`;oB@0M0om601`00om701go:@00obh00002obh000?o<@001?nBL:T3
oi=bZPCoUGB/0onGMZ`5oiQg[0;oVGN[00?oTVbToi5[XonAJj<00_nAJj<4oi1ZX`CoT6VR1?n?J:83
oi1YXPCoTFZR1OnCK:<3oiA^Y@04oiI`Y_nLN:[oW7RZoiahZPGoVgRZ1?nKN:/3oiYhZ`GoVWR/00Co
VWV/oj:5]OnRQKGoXXFe1OnSQ[H01_nTR;Oo0000o`000?l0003oY8RgojF:^0Co]:[>1?ndZLd00ond
Z<go`MCYol7Dj@03ol7Dj@03ol3>iOnMm>CoWOCT00;oUHc70onCT]05oi:Jf0CoT:7P00?oT:SVo`00
0?n@Z>H00_n@Z>H2ohn^j`;oUi[E0onFXM`5oiJWhPGoUJgW0_nE/^/2oibcj1Gooooo00?o0000oooo
ooooool00oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool06oooool0
02_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0fooooo`03oe_@/oll003o?000
00?oB@0;0_m@01H3oe<07P03oe808_mC023oD`0P00?oCP0O0_m901d4odH070;o:@000_l^00001?la
003oTfnWoi=_YonCKjL4oi9`Z@?oTg:Z1?nEM:`4oiMf[0?oV7N/00CoTffToi9/Y?nBK:CoTVbT1?nA
Jj<4oi1ZX`CoT6VR1?n?J:83oi1YXPCoTFZR1OnCK:<2oiA^Y@03oi]fZOnLN:[oW7RZ00?oW7RZ1?nK
N:X4oi]hZ`CoVWR[0onJN:`00onQQ;CoXXFeoj:5]@03oj:5]@;oXhJf0ol00003ojB8]`03okF/d?nd
Z/ko]:[>00?o]:[>0ondZLd2ol3LkPCo`MCY00?oN^?7oiN6_onES<L01?nES<L3oi>Bd0CoTY[H1On@
XN001?n@Z>Ko0000oiNCc_nGTlh4oiNJe@CoUZ7L1OnFYn82oiF]i`;oW:cR1OnL/nPCooooo`?o0000
1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P06oooool0013ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0cooooo`;o;0000_ll0003odT02`03
oe005_mH01ooE`0Q00?oE`0Q0_mC0204odh07`;oB@0M00?oAP0Lob800?lR00000_lY00001?l^003o
TfnVoi=_Y_nCKjH3oi=_Y`CoTW2Y0onCLZX5oiEd[0?oUgJ/00CoV7N/oi=]Y?nCKJCoTffT0onBK:@5
oi5[X`?oT6ZS1?n@JJ84ohmXXP?oT6VR1OnAJZ84oi=/X`03oiA^YOnKMZWoVgJY00GoW7RZ1?nKN:X4
oi]hZ`CoVWR[00CoVWR/oj64]?nQQ;CoXHBd1?nRQKD3o`0000?oXhJf0_nTR;L3okF/d0Go]:[>00?o
]:W=ol3Lk_o0g>h00_o0g>h00oo1e>WoUhJooiN6_`03oiN6_`CoUHc70onCT]05oi:Jf0;oT:7P0_nH
SLH00onGTlko0000oiNCcP02oiNCcPCoUi[E1?nFXM`2oiJWhP;oWJGL1OnL[>85oibcj1Gooooo00Wo
0000ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410I
ooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooo
oooo00Cooooo0ol0000:ooooo`03o`000?oooooooooo02oooooo00Co6P00ob`00?l/003o;0000_ll
00000om900_oE`0LoeL07003oeP07`CoE`0Q0_mC0203odh07`03odT07OlM003o8P0000;o8P0000?o
:@00oiE_YOnEKjD01?nCKjH3oi=_Y`CoTW2Y1?nCLZX4oiEd[0;oUgJ/1OnCKJ@4oi9/Y0CoTF^S1?n@
JZ<3oi1YXPCoSfRR1?n@JJ84oi5ZXP?oTfbS00?oVG>Woi]fZOnKMZT00_nKMZT4oiahZPCoVgRZ1OnK
N:/2oiYhZ`KoXHBd0ol000000onRQKGoXhJfoj>6]P03oj>6]P03ojB8]one[=3o]Jc@00;o]Jc@1?nd
Z/h00onni_;o`=c^ol3LkP02ol3LkP?oV86i1?nGQ[l4oiF<a`CoTi;@0_nBV]P2oiV7_`GoV8g600Co
Ui?>o`000?nGTlkoUi?>1?nGV]D2oiJQg0;oWYoE1OnMYM`5oib/hP;oW;?X0_nT]nHEooooo`03o`00
0?oooooooooo02oooooo0008ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00_ooooo
1Ol00005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0;Oooool2oaX000;o;000
00?o?000oe805_mG01`00omG01`2oeP07`CoE`0Q0_mC0204odh07`;o7@000_lR0004oiE_Y@CoTfnV
0onCKjL4oi9`Z@CoTg:Z0_nEM:`:oi=]Y0?oTVbT1?nAJj<4oi1ZX`?oT6VR1?n?J:84oi1YXPCoTFZR
00CoTfbSoiUcYonILjOoVG>W1?nKMZT4oiahZPGoVgRZ1?nKN:/00onJN:_oXHBdoj64]003oj64]0;o
00001OnRQKD3oj>6]P03okB]dOne[=3o]Jc@00Co]Jc@00?o]:[>okkVl_nni_800_nni_800oo0g>ko
VWjcoiR1^@03oiR1^@CoUhJo1OnES<L2oi>Bd003oiZ3^OnIQkooVHNo00?oVHNo1?nHSLH2oiNCcP03
o`000?nGTlkoUi?>00;oUi[E00?oWiW>oijOeOnNWmD00onNWmD5oifUg0;oW:cR0_nU/>05ojBgiQGo
oooo00?o0000ooooooooool0;_ooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Zoooo
o`05o`L00?lJ003o6P00ob`00?m;00d00omB01H3oeL070?oF00O0omG0243oe<08003odh07olL003o
7@0000;o7@0000Co8P00oiM`YOnGL:GoUg2U0onEKjD4oi=_YP?oTfnW1OnBL:T2oi=bZP03oiA]XonC
KJCoTffT00[oTffT0onBK:@4oi5[X`CoT6ZS0on@JJ85ohmXXP?oT6VR0_nAJZ82oiI`YPGoVG>W0onK
MZT4oiahZPGoVgRZ0onKN:/01?nQQKGoXHBdoj64]?nQQ;@3o`0000;oXHBd1OnRQKD00onSQ[Ko]:gA
okB]d@02okB]d@Co]Jc@0_niko@3okkVlP?oVWjc1?nHPKT5oiN6_`;oUHc70_nKO[<4oiZ3^@CoVHNo
1OnHSLH01?nGTlko0000oj2Db?nPU<P4oinIcPGoWYoE0_nMYM`2ojFYfPGoYK3P0_nT]nH3ojfmiQGo
oooo00?o0000ooooooooool0;Oooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Woooo
o`;o1`000_lJ0003od/03@;oDP0F0omG01`3oeP07`CoE`0Q00GoD`0Poa`00?lL003o7000oad00003
oiQbYPCoUg2U1?nEKjD3oi=_YPCoTfnW1?nBL:T00onCLZ[oU6fSoiA]X`0<oi=]Y0?oTVbT1?nAJj<4
oi1ZX`CoT6VR1?n?J:82oi1YXP03oi9/Y?nFL:KoUW2V00;oUW2V1OnILjL3oi]fZ@GoW7RZ1?nKN:X0
1?nKN:_oXHFeoj65]OnQQKD3o`0000KoXHBd0onRQKD00ond[m?o]:gAokB]d@04okB]d@03okF/d?ni
koCo^Nod00?o^Nod00?o_^Kboi]k[_nJO[<00_nJO[<5oiR1^@;oUhJo0_nLNjl5oi]n/`?oVX>i1?nI
Qkl4oiR=aP05oj6@`_nPU<SoX9C8o`000?nPU<P01?nOVLh4oijOe@03ojJTe?nUZM[oYJWJ00?oYJWJ
0onU/>000on]^N;o[KgVojfmiP04ojfmiQCooooo00?o0000ooooooooool0;Oooool0013ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo0_l0000?ooooo`;o0000
9Oooool01Ol0003o1`00o`L00?lJ003o@P0300?oB`0=0_mB01H4oeL070?oF00O00GoE`0Qob/00?l[
003o8P00oa`00003oiUcY`CoV7:V1?nGL:D4oiE_Y@CoTfnV0onCKjL2oi9`Z@;oU6bR0onDKJ<<oi=]
Y0?oTVbT1OnAJj<3oi1ZX`CoT6VR1?n?J:800on@JJ;oTVbToi9/Y005oiI`YPCoVG>W0onKMZT5oiah
ZP;oVgRZ0_nSQ[H01OnQQKGo0000o`000?l0003oXHFe00SoXHBd00?oXXFeokB_dond[m<00_nd[m<4
okB]d@?o[_Cb0_niko@4oi]k[PCoVWjc0onHPKT00onMNZ_oW7^_oiak[`02oiak[`GoVgjc0onJPkT5
oiV7_`03oiR=a_nQT<;oXI3200;oXI320_nPU<P00ol0003oX9C8oinIcP03oinIcP03oijOeOnVY=Co
YZCD00;oYZCD1OnUZMX01?nU/>3o[KWRojfih_n]^N84ojfmiP03ok;4j?oooooooooo01?ooooo00?o
0000ooooooooool0;?ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000000Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Qooooo`03o`000?l7
003o>00000?o@P030_m;00d3oe805P03oeL07?lm003o?@0000?o=@000ol[0003oiUeZ@CoVG>W0onH
LZH4oiM`Y@CoUFnU1?nCKjH2oi=_Y`GoU6bR1?nDKJ<;oi=]Y0CoTVbT1?nAJj<3oi1ZX`CoT6VR0_n?
J:82oi1YXP?oTVbT1OnFL:H4oiUcY`CoVgJY0onLN:X00onTR;OoXhJfoj>6]P03o`0000CoXHFe1onQ
Q;@00onc/=Ko]:oCokB_d`04okB_d`03okB]dOn^m?;o[_Cb00;o[_Cb0onLN:X4oi]k[PCoVWjc00Co
V86ioiejZonMNZ_oWGZ[1OnLNjl4oi]n/`CoVX>i0_nIQkl2oj>=_@GoXI320onPU<P00ol0003oWiW>
oinIcP02ojRPcPGoYZCD1?nUZMX00on^]]ko[KWRojfihP03ojfihP03ojfmi_nba>So//CX00;o//CX
4oooool2o`0002kooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000
ooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07_ooool00ol0003o;P00
ocP00002ocP000;o@P030om;00d00omB01Ko@P04ocd00003ocd000;o=@000ol[0005oiUeZ@?oVG>W
1?nHLZH3oiM`Y@CoUFnU0onCKjH00onEK:;oU6bRoiA/XP05oiA/XPCoU6fS3?nCKJ@3oi9/Y0CoTF^S
0_n@JZ<00on=IIooSVJPohiVX002ohiVX0CoT6VR1?nBK:@4oiI`YPCoVG>W1?nKMZT00onLN:[oY8Rg
ojB8]`03o`0000?oXhJf1?nQQKD6oj64]0?o/k3F1?nd[m<3oi_cj003ojkdl_nKMJOoW7RZ00?oW7RZ
1OnKNjh2oiYn/`03oiiiZOnMNZ_oWGZ[00?oWGZ[1?nLNjl5oi]n/`;oVX>i00?oY8Zioj>=_OnSSKd0
0onSSKd4oj6@`P?oX9C800?o0000ojRPc_nXX<h00onXX<h5ojJTe003ojFYf_n^]]ko[[KN00;o[[KN
0on]^N82ok?5i`Co//CX5Oooool00ol0003oooooooooo`0[ooooo`00:Oooool2o`0001Cooooo00?o
0000ooooooooool06_ooool2o`0000?o;P000_lh0002od800`03od/03Om500SoA@0800?o@P040olm
0002ocD00004ob/00?nIMj_oVGN[oiUgZ`GoVGFY0onILjL4oiQbYPCoUg2U0onEKjD01?nCKjKoUFbR
oiE/X_nEK:87oiA/XPCoU6fS3?nCKJ@3oi9/Y0;oTF^S0_n=IIh3oheUW`CoSVJP1?n@JJ84oi9/Y0Co
UW2V1OnILjL3oi]fZ@?o00000_nTR;L4oj>6]PGoXHFe0onQQ;@00onb/]Wo/k3Fok>`eP03ok>`eP03
okB_donKlnSoVo?X00;oVo?X0onKMJL4oiahZPGoVg^^00?oVWjcoiiiZOnNNJT01OnMNZ/4oiak[`Go
Vgjc00CoVX>iojB:^OnTR[WoY8Zi1?nSSKd5oj6@`P04oj2Db?nYWL[oZIg:o`0000GoZ:3>0_nVY=@2
ok2df`Go[[KN00?o[KWRok?5ioncaNL00oncaNL2ok;4j0;o//SZ5Oooool00ol0003oooooooooo`0Z
ooooo`00:Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Oooooo0_l000001?lS
003o;P00obh00?l^0002ocP00003od800om500WoA@0800?oA@080_m200@3ocd00004ocD00?nXTl3o
VWV]oiYi[@CoVGN[1?nIMJT3oiUcY`CoV7:V1?nGL:D2oiE_Y@03oiE]X_nEK:;oUFbR00;oUFbR1onD
K:84oiA]X`coTffT0_nBK:@00on>IIkoSFFNoheUWP02oheUWP?oSFFO1?n>IZ05oi1YXP?oTVbT1?nF
L:H5oiUcY`03oi]fZOl0003o000000GoY8Rg1OnSQ[H4oj65]@03oj64]?nb/]Wo/[;I00;o/[;I0onc
/=H3oh3XeP03oi_cj?nJLZCoVW:T00CoVgFW0onLN:X4oi]k[P03oj1iYonNNJWoWWVY00;oWWVY1?nM
NZ/5oiak[`?oVgjc00?oYXRfojB:^OnTR[T00_nTR[T4oj>=_@CoXI3200?o[9c7ojVMb_nYWLX00_nY
WLX01Ol0003oZ:3>ojRPc_nXX<ko/[?I00Go/;CK0on^]]h2okG7j0Co/lGW00?o/lg]ok;8j_nbb>X0
0onbb>XDooooo`03o`000?oooooooooo02[ooooo000Yooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool05?ooool01?l0003o6@00ob<00?lS0003obh00003ocP00?m400KoA@0900;oA@09
0om500P2od801003ocd00?nXU/?oZ9K300;oVg^_1?nJNJd3oiUgZ`CoVGFY0onILjL4oiQbYPCoUg2U
00?oUFnUoiE]X_nEKJ801?nEK:88oiA/XP?oU6fS2_nCKJ@2ohmUW@?oSVFN1?n=IIh4oheUW`CoSVJP
1?n@JJ83oi9/Y0GoUW2V0_nILjL3o`0000?oYHZh1?nTR;L5oj>6]P;oXHFe0_na]]d6ok:bf@03ok>`
e_n0j=KoP>SF00GoVW:T1?nKMJL4oiahZP;oVg^^0_nPNJL4oiiiZ@CoWGZ[1OnLNjl01?nKO[?oYXRf
ojJ8]_nVR;H4ojB:^@GoXhfm00CoXI32ojbLaon/W<Oo[9c71OnYWLX00ol0003o/[?Iok:cf@02ok:c
f@Co/;CK00?o[[KNokG7j?neanP00oneanP00oncaNOo/lg]ok?=k@02ok?=k@?o//SZ0_n_bNdDoooo
o`03o`000?oooooooooo02Wooooo000Yooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool04_ooool3oaT00004ob<00?l^003o@@00od4000?oA0060_m500T3odD02004od801?nYVLGoZIW5
oiam/@CoVg^_1?nJNJd3oiUgZ`CoVGFY1?nILjL3oiQbYP;oUg2U1OnEKJ84oiE/XPSoU6bR1?nDKJ<6
oi=]Y003oi1VWOn?IIgoSfFM00;oSfFM0on>IIh5oheUWP?oSFFO1?n>IZ04oi1YXP?oTVbT1?nFL:H3
o`000003oiUcYonVR[OoYHZh00?oYHZh1OnTR;L3oj>6]P03ok:nhona]]go/KKM00?o/KKM1?nb/]T0
1?mOe;coVG2RoiU`X_nIL:85oiYbY0CoVgFW1?nLN:X00onKNjkoX7VWoj1iY`02oj1iY`?oWWVY1OnM
NZ/3oiak[`03ojN8/onVR;KoYXRf00;oYXRf1OnTR[T3oj>=_@03ojnLaOn/W<Oo[9c700?o[9c70onY
WLX00one]MWo0000ok:cf@04ok:cf@;o/;CK0_ngc>X4okG7j003ok?Cl?nccNgo/lg]00?o/lg]00?o
//SZojo9kOn_bNd00on_bNdDooooo`03o`000?oooooooooo02Sooooo000Yooooo`?o00005oooool0
0ol0003oooooooooo`0?ooooo`05o`d00?lI003o6@00oaT00?lm00001?m10002od@01P;oA@0900?o
A@08oj^Laon[W<L00_n[W<L00onYVLGoW7faoiam/@04oi]k[`CoVWV]0onIMj/5oiUeZ@?oVG>W0_nH
LZH00onDKJ?oUFfRoiE]XP06oiE]XP?oUFbR2?nDK:84oiA]X`?oTffT00CoTVNNoi1VWOn@IYgoT6JM
1?n?IId4ohiUWPCoSFFN0on=IIl4ohiVX0CoT6VR1?nBK:@3o`000003oiI`Y_nILjOoYXZg00?oYXZg
0onUR[P5ojB8]`03oj>6]_nb_^?o/[kS00;o/[kS1Ona]]d01?nb/]WoUfjQoiM^XOnGKZ44oiU`XPCo
VW:T1OnKMJL2oiahZP03oj9jYonPNJOoX7VW00?oX7VW0onNNJT5oiejZ`04oiak[onWR;?oYhRcojN8
/`GoYXRf1?nTR[T00onSSKgo[ic5ojnLa@02ojnLa@Co[9c700?oZIg:okFefOne]MT00_ne]MT01Ol0
003o/[?Iok:cfOnb/mWo^MC]00Go]lcZ00?o]LOXok?Cl?ncdo000_ncdo02ok?=k@?o[]3b1?n_bNd0
0onXaNooooooooooo`0Aooooo`;o0000:_ooool002Wooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0<ooooo`03o`000?l=003o6@0000;o6@000_lm0003od4000;oA00600?oA@09ojfO
bOn]WlT00_n]WlT2oj^La`03oif0/onLOK7oW7fa00;oW7fa0onKNjl4oiYi[@?oVGN[1OnIMJT2oiUc
Y`04oi=^YOnDKJ?oU6fSoiA]X`SoUFfR1?nEK:87oiA/XPCoU6fS00CoTffToi9WW_nBIikoTVNN0on@
IYd4ohmUW@CoSVFN1?n=IIh3oheUW`CoSVJP1?n@JJ801?nBK:Co0000o`000?l00003oiI`YP03ojF8
]_nVR[OoYXZg00?oYXZg1?nUR[P3ojB8]`03okK=jonb_^?o/[kS00Co/[kS0_na]]d00ol0003oUffP
oiM^X@03oiM^X@CoVG2R1?nJLZ@5oi]eY`03oiahZ_nRNZOoXWZW00GoX7VW0onNNJT4oiejZ`03ojV8
/_nWR;?oYhRc00?oYhRc1?nVR;H3ojB:^@03ok:OaOn_W<Go[ic500?o[ic50on/W<L00oni^M[o]KGI
okFef@04okFef@03o`000?nie>go^MC]00;o^MC]0_ngc>X3ok;Km@?o/m?`0_n[fOL5ojk@lP03ojo9
kOnXaNooZ<G_00;oZ<G_5?ooool00ol0003oooooooooo`0Wooooo`003_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00Wooooo00Co0000o`d00?l=003o6@000_lg0002ocd000?o@@0000?oA006ojjRbon^
X//01?n]WlT01?nOPkGoWH2coif0/onMP;<4oiam/@CoVg^_0onJNJd4oiUgZ`CoVGFY00?oVG>Woi=^
YOnCKZD00onDKJ<8oiE]XPCoUFbR1onDK:82oiA]X`;oTfVN1?nBIih4oi1VW@?oSfFM1?n>IIh4oheU
WP?oSFFO1?n>IZ02oi1YXP?o00000onBK:@00onFL:KoYHRfojF8]P02ojF8]PCoYXZg1?nUR[P00onT
R;Oo]/g[okK=j`02okK=j`Co/[kS00?o0000oiM]X?nGKJ000_nGKJ05oiM^X@?oVG2R1OnJLZ@3oi]e
Y`03oj=kYonRNZOoXWZW00;oXWZW1?nPNJL4oiiiZ@;oWGZ[0_nYR;85ojN8/`CoYXRf00?oY8Ziok:O
aOnbWlD00_nbWlD5ojnLa@04ojbLaoni^M[o^KWJokVifPCo]KGI00?o^]obo`000?nie>d00_nie>d2
ojgUn@Go/]_e00?o/m?`oj_Imon[fOL00_n[fOL2ojk@lP;oY/_c1OnXaNlEooooo`03o`000?oooooo
oooo02Kooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01_oo
ool2o`400003o`d00?l^003o=`0000;o=`000_lm00001?m1003o/:G=ok2UcOn`YLd4ojjRb`04ojfO
bOnOPkGoWh>eoin3]@CoWH2c0onLOK44oi]k[`CoVWV]0onIMj/2oiUeZ@;oTfnV0onCKZD4oiA]X`Oo
UFfR1?nEK:86oiA/XP03oiAZWonCJIkoTfVN00;oTfVN1?nBIih4oi1VW@?oSfFM1?n>IIh4oheUWP?o
SFFO0on>IZ03o`0000?oT6VR0_nBK:@00onRQ;CoYHRfojF8]P03ojF8]PGoYXZg0_nUR[P3okWOl`Co
]/g[00Co/[kSoi]cY?nHKJ3oV6fP1?nGKJ05oiM^X@?oVG2R1OnJLZ@2oi]eY`;oXg^W1?nRNZL4oj1i
Y`CoWWVY00?oWGZ[ojV8/_nYR;800_nYR;84ojN8/`CoYXRf1OnbWlD4ojnLa@03okc1g_ni^M[o^KWJ
00?o^KWJ00?o]KGIok[Ol_njgo800_njgo800ol0003o^MC]ojgUn@03ojgUn@;o/]_e0onTh?`2oj_I
m`?oX/og1?nVbo<2ojS5k`?oX/3^5?ooool00ol0003oooooooooo`0Vooooo`001_ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0_l0000Moooo
o`03o`000?oooooooooo00?ooooo00?o0000o`400?lT00000_l^0003ocL00003ocd00?nbZ<oo/ZS?
00Go/:G=0_n^X//00onQQ[OoWh>eoin3]@02oin3]@CoWH2c0onLOK44oi]k[`CoVWV]0_nIMj/00onC
KjSoTfnVoi=_YP02oi=_YPCoTfjU0onDKJ<7oiE]XPCoUFbR1OnDK:82oiAZW`CoTfVN1?nBIih4oi1V
W@CoSfFM0on>IIh4oheUWP?oSFFO00?oSVJPo`000?l000000_n>IZ04oi1YXP04oi9/Y?nRQ;CoXXBd
oj:4]0CoYHRf1OnVR[L00onUR[So^MocokWOl`03okWOl`;o]/g[00?oW7BUoiU_XOnHKJ000_nHKJ05
oiM]X0CoUfjQ0onIL:85oiYbY003oi]eYonSNjOoXg^W00;oXg^W0onRNZL5oj1iY`;oWWVY00?oZhZb
ojV8/_nYR;800onYR;85ojN8/`;oYXRf0_nfY<L5ok:Oa@03ojnLaOnl`Mko_<7N00;o_<7N0oni^MX2
okG]mPCo^]ob00CoWNcho`000?n]iOWo[NGi0onEiO`2ojCPo0?oW=?k1OnRcoL2ojK;l`;oXL;`1OnR
`>hDooooo`03o`000?oooooooooo02Gooooo000>ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo01gooooo00Go0000oooooooooooo0000
oaL00002ob@000;o;P0000?o=`00okk=i_nd[=001OnbZ<l3ok2Uc@03oj>9^OnQQ[OoXHJg00;oXHJg
1?nOPkD3oif0/`CoW7fa0onKNjl2oiYi[@;oTg6Y0onCKjP4oi=_YPCoTfjU0onDKJ<8oiE]XP?oUFbR
0onDK:801?nEK:3oU6ZOoiAZWonDJYl5oi=YWP?oTVNN1?n@IYd4ohmUW@?oSVFN1?n=IIh01?n=IIoo
0000o`000?l00004ohiVX0;oT6VR0_nNP;84oj:4]0GoYHRf0onVR[L3okSbl`;o^Moc0_nMM:@01?nL
M:GoVFnQoiU_XOnIKj44oiQ]X0CoUffP1?nGKZ44oiU`XP?oVW:T00?oY7^Woj=kYonSNjL00onSNjL3
oj9jY`GoX7VW00?oWWVYoj^:/_n[R[801OnYR;85ojN8/`04ojJ8]_nfY<Oo]ZC7okJTa`Co/Yo500?o
`LoUokc1g_nl`Mh01?nl`Mh00oni^M[o]NgfokG]mP02okG]mP03ok[Ol_nMk?SoWNch00;oNN7c00Co
0000ogWQlonEiOcoUNGl0_nBe?h5oicCn`;oX/og0_nN`_45oj72l0;oX/3^0_nP_>`Eooooo`03o`00
0?oooooooooo02Cooooo000>ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIV
ooooo`04ooooo`03o`000?oooooooooo01gooooo0_l00002oaL000;o900000Co;P00oko=iOnocNGo
_/gV0ond[=05ok:Xc`03ok2UcOnSRKWoXhVi00CoXHJg1?nOPkD4oif0/`?oW7fa0_nKNjl00onDLZ[o
Tg6Yoi=aZ@02oi=aZ@CoTfnX0onCKjH4oi=^Y@?oU6fS2?nEKJ83oiE/XP04oiA/X_nEK:3oUFbPoiE/
X0CoU6ZO1?nCJIh3oi9WWPCoT6JM1?n?IId3ohiUWP;oSFFN0ol00003oheUW`?oSVJP00?oVW^`oij0
/_nNP;800_nNP;84oj:4]0GoYHRf00?oYXZgokSblonhl_<00_nhl_<2oiacY0;oWGBT00?oVg6RoiU_
XOnIKj400_nIKj44oiQ]X0CoUffP1?nGKZ44oiU`XP;oVW:T0_nTNjL5oj=kY`?oXWZW1?nPNJL00on]
SKCoZhZboj^:/P02oj^:/PGoZHRb0onWR;<00onl[/co]ZC7okJTa`02okJTa`?o/Yo50oo1cnD4okc1
gP;oV_;[0_nekOH2ogSTi@?oClgK0_mihO<00ol0003oR=7oohSAo`04oi;DoP;oW=?k0_nK`?85oik2
l@;oXL;`0onO^^`4oj2lk1?ooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c009ooooo`003_ooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool00oooool2o`0001gooooo00Go0000oaL00?lG003o5`00
ob@00004oko=i@03okN_d_nd[=3o]:c@00;o]:c@1?nbZ<l00onUS[coXhVioj>9^@02oj>9^@?oXHJg
1?nOPkD4oif0/`;oW7fa00CoUGB/oiAbZ_nDLZ[oU7:Z1?nCLJT4oi=_Z0?oTfnV1?nCKZD3oiA]X`So
UFfR0_nEK:800onFKJ;oUFbPoiE/X002oiE/X0CoU6ZO1?nCJIh4oi9WWP?oT6JM1?n?IId2ohiUWP?o
00000on=IIh3oheUW`04ohiVX?nJNk3oVW^`oiYk/0GoWX2b1?nRQ;@3ojF8]P?oZ?SV00?o^?;coiac
Y?nLLj@00_nLLj@00onMM:CoVg6Roi]aXP05oiU_X@?oV6fP1?nGKJ05oiM^X@?oVG2R00?oVW:TojAk
YonTNjL00_nTNjL4oj=kY`CoXWZW0_nPNJL2ojf=]0CoZhZb1OnYR;800onWR;?o_:k<okb^c002okb^
c0Co]ZC700?o/Yo5ol7?iOo1cnD00oo1cnD00onl`MkoV_;[oi[bj`02ocVl/@04obJa__ml`ogoO<?m
ogc3o@GoO/_o00?oR=7oo`000?nF]>`01OnH^o04oi_0lP;oW/;a0onN]nX5oinjk0;oX;c/0_nQ^^XD
ooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OlQ8B7oV9RHoooooonHV9So8B4Q00Wooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo0_l0000Looooo`;o1`0000?o5`00okW_m?ni
ko@00oo0cN@00onocNGo]joBokN_dP02okN_dPCo]:c@00Co/ZS?ojF>_?nUS[coYHjl1?nSRKT4oj66
]`?oWh>e0_nMP;<2oiMg[@?oUGB/1?nDLZX3oi=aZ@CoTfnX1?nCKjH3oi=^Y@CoU6fS1_nEKJ801?nE
KZCoUVfRoiI]X_nFKJ85oiE/X0?oU6ZO1?nCJIh4oi9WWP?oT6JM0on?IId3o`0000;oSVFN1?n=IIh2
oheUW`03oiMg[OnJNk3oVW^`00?oVW^`1?nNP;84oj:4]004ojF8]_nXn>KoZ?SVojShiP?oVW6S0onL
Lj@01?nMLj?oVg6Roi]aX_nKLJ85oiU_X@?oV6fP1?nGKJ05oiM^X@;oVG2R00?oXWZVojAkYonTNjL0
0onTNjL4oj=kY`CoXWZW00?oX7VWojf=]?n]SK@00_n]SK@3oj^:/PCoZHRb00?o`[cDokb^c?nl[/`0
0onl[/`3okJTa`;o`NC`1?o1cnD00omDbjooRZKWoh2emP04oh2emPCoO<?m0_mnbol2oiFYi0;oU[C/
00?o0000oiJdk?nH^o001?nH^o02oi_0lP;oW[?W1OnN]nX2oinjk0;oXKKW1OnQ^^XDooooo`03o`00
0?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool000002Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01?ooool00ol0003oooooooooo`0Gooooo`?o000000Go1`00okc[m?nljoCo_>_dokW_
m003ol3=i003okVbdong[m;o]joB00?o]joB0ond[=000onXT[koYHjlojF>_002ojF>_0CoXhVi1?nQ
Q[L2oin3]@03oiQi[onGMjgoUgN]00;oUgN]1?nEM:`3oiAbZPCoTg6Y0onCKjP4oi=_YPCoTfjU0onD
KJ<4oiE]XP?oUFjT0onFKJ85oiE/X0?oU6ZO1?nCJIh4oi9WWP?oT6JM0ol000000on?IIgoSVFNohiU
WP02ohiUWP;oSFFN0_nEM:`3oiMg[@GoVW^`1?nNP;84oj:4]003oi3_conHKj;oV6nR00CoVW6S0_nL
Lj@2oiecX`CoVg6R1?nIKj43oiQ]X0CoUffP1OnGKZ400onIL:;oXWZVoj9jYP05ojAkY`GoXg^W0onR
NZL5ojf=]0CoZhZb0_nYR;83ol:le0Go_:k<00?o]ZC7ol7Tl?o1i?000_o1i?000oo1cnGoTYODohZV
i`03ohZVi`;oP;Gf0_nIT//4oiNMf0GoUJWT0_nF]>`01?l0003oU[C/oiRkl?nH^o02oif]hPGoW[?W
0_nN]nX2oj6ah`GoXKKW0onQ^^X00onU^nWoooooooooo`0Booooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S802Oooool002Oo
oooo00?o0000ooooooooool05?ooool00ol0003oJ=cIofSLf@02oi_al0Co_>_d0oo1cN<01?o0cNCo
^K;CokVbdoni/]<5okN_dP04okB/d?nXT[koZ9:nojRB_PCoYHjl1?nSRKT2oj66]`04oiUl/OnHNJoo
V7V_oiQi[`CoUgN]1?nEM:`3oiAbZPCoTg6Y0onCKjP4oi=_YPCoTfjU0onDKJ<2oiE]XP03oiA_Y_nE
KZCoUFjT00;oUFjT1?nFKJ84oiE/X0?oU6ZO1?nCJIh4oi9WWP?o000000CoT6JMohmUWOn?IIgoSfFM
0_n>IIh2oiEcZ`CoUGB/1?nGMjd4oiYk/0GoWX2b0_nRQ;@00on@klooV6nRoiQ_XP02oiQ_XP?oVW6S
00CoW7>ToiecXonMLj?oWG>S1?nKLJ84oiU_X@?oV6fP1OnGKJ03oiM^X@03oimgY_nRNZKoXWZV00;o
XWZV1?nTNjL5oj=kY`;oXWZW00?o/9>hojf=]?n]SK@00on]SK@4oj^:/P03ojV8/_o2_=Co`[cD00;o
`[cD1?nl[/`2ojcfkP;o`NC`1OnBUm@2ohZVi`03oib:`?nIT/_oVI;;00?oVI;;1?nGWMP2oiFYi0;o
X:3D0_nOYm`00ol0003oWjOLoinWg004oif]hP;oW[?W0_nR[Ml5oj6ah`CoXKKW00?oXK[ZojFkjOnU
^nT00_nU^nTDooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`05olc<c?l0003o0000o`000?o<c<`02Oooool002Oooooo0_l0000Booooo`;o?<7700CoJ=cIojO_
monWkoOoYnog0onniO800onljoCo`LgSol7=h`03ol7=h`Go^K;C0ong[m800on[Ul;oZ9:nojRB_P02
ojRB_PCoYHjl1?nSRKT00onQQ[OoVGbaoiUl/@04oiQi[`?oUgN]1?nEM:`3oiAbZPCoTg6Y1?nCKjP3
oi=_YPCoTfjU0_nDKJ<01?nBKjSoU6nVoiA_Y_nDKjH5oiE^Y0?oUVfR1?nEK:03oiAZW`CoTfVN0_nB
Iih2o`0000CoT6JM0_n?IId00onELj[oUG>[oiEcZ`02oiEcZ`GoUGB/0onGMjd4oiYk/0GoWX2b00?o
XXBdoiI/XOnHKj801?nHKj82oiYaX`03oiedXonMLj?oWG>S00?oWG>S0onKLJ84oiU_X@?oV6fP1OnG
KJ02oiM^X@;oWgNV1?nRNZH4ojAkY`GoXg^W00CoXWZWok2C^?n`TkSo/9>h1On]SK@2oj^:/P03olOB
h_o2_=Co`[cD00Co`[cD00Co_:k<ojcfk_n/m^ko[?K^1?nJS<@2oi:Ge0;oWhFg1?nLR/04oiVBb`?o
UigH00?oXi_<oj2Pe?nPX=@00onPX=@2oinWg003o`000?nOYmcoWjOL00;oWJgR00?oXjSIoj:]gonR
[Ml00onR[Ml4oj6ah`;oXKKW0onU^>H4ojFkjAGooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4009ooooo`009oooool00ol0
003oooooooooo`0>ooooo`?oE]3S0_mniNh2ojO_m`Co_^Gb0oo1c>83ol7=h`;o^[GD1Oni/]<01?ng
[m;oZiO2oj^G`_n[Ul83ojRB_PCoYHjl0_nSRKT2oi]o/`CoVGba0onHNJl4oiMg[@?oUGB/0onDLZX4
oi=aZ@CoTfnX0onCKjH2oi=^Y@;oTFnY0onBKjP3oiA_YPGoUFjT0onFKJ84oiE/X0?oU6ZO0onCJIh3
o`0000;oTVNN1?n@IYd00on?IIgoUG>ZoiEcZP05oiEcZ`CoUGB/0onGMjd5oiYk/0?oWX2b1?nFK:44
oiQ_XP03oiYaXonMM:?oWGBS00GoWG>S0onKLJ84oiU_X@CoV6fP1?nGKJ000onGKZ7oWgNVoimgYP02
oimgYP?oXWZV1OnTNjL3oj=kY`03okJM_on`TkSo/9>h00;o/9>h1On]SK@01?n[R[;oam;RolOBh_o7
d^84ol:le003oeK:YonPQKOoX8Fg00;oX8Fg0onJS<@00onTQ;;oWhFgoin5]`03oin5]`?oW8[01OnI
T//01?nGWMSoXi_<oj>Kc?nSVl`4oj2Pe0?oWjOL00?o0000ojFTe?nSZ=T00onSZ=T5oj:]g`;oXK7S
0_nV]N<5ojFhiP;oYK_Y0_nX_^TBooooo`?o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_oooooo^[Zjo`000009ooooo`009oooool00ol0003oooooooooo`08ooooo`Co
OMKn0_m/eoH2ohoVnP?o[^Wi1?nng_000onniO;o`LcRol7<hP03ol7<hP03ol7=honj]MCo^[GD00;o
^[GD0_ni/]<2ojfKa@CoZiO21?nXT[h2ojF>_003oif2]_nKOk?oVgnc00;oVgnc1?nIO;43oiQi[`Co
UgN]0onEM:`4oiAbZP?oTg6Y1?nCKjP2oi=_YP03ohm_Z_nAKjWoTFnY00;oTFnY1?nBKjP3oiA_YPCo
UFjT0onFKJ84oiE/X0?oU6ZO0ol00002oi=YWP?oTVNN0_n@IYd2oiIcZPCoUG>Z1?nELj/4oiEd[0?o
UgN]1OnJNk000onNP;;oU6^PoiA[X004oiI/X@?oV6nR00CoWGFToiedXonMM:?oWGBS1OnMLj<3oi]a
XPCoVFnQ1?nHKJ03oiM]X003oiadYOnOMjKoWgNV00?oWgNV0onRNZH5ojAkY`;oXg^W0onfWKl3ok2C
^0Co[Hfd0_o2lO04olOBhP04ol:le?nUPjooYH>_ojF3[`CoX8Fg00?oVXc4ojB4/_nTQ;800_nTQ;84
oin5]`CoW8[00_nIT//2ojNGa@CoXi_<1OnPX=@00onOYmcoYJCDo`000002ojFTe0CoXjSI0_nR[Ml2
ojRbg`GoY[GS0_nU^>H2ojVli`GoZ;kY5?ooool02Ol0003oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT02Oooool002Kooooo0ol00006ooooo`?o
R<oo0_mme_h3oi[Po@Co/^3g00?o[^WiokkNl?nng_000_nng_02ol7;h@Co`LcR0_nl^=H3okZee003
ok2Qb?n]VlGo[I_500?o[I_50on[Ul83ojRB_P04oin6^OnMP[KoWH:foif2]PGoVgnc0onIO;43oiQi
[`CoUgN]1?nEM:`3oiAbZP;oTg6Y00?oSg2[ohm_Zon?Kj/00_n?Kj/3ohm_ZPCoTFnY1?nBKjP3oiA_
YPCoUFjT0onFKJ84oiE/X0?o000000?oU6ZOoi=YW_nCJIh00_nCJIh2oi9WWP03oiIdZ_nFLj[oUW>Z
00;oUW>Z1?nELjX4oiEcZ`CoUGB/1?nGMjd3oiYk/0GoU6^P0onFK:401?nHKj;oWGFToieeY?nMMJ@4
oiedX`CoWG>S0onKLJ85oiU_X@?oV6fP00CoUffPoiadYOnLM:GoW7BU1OnOMjH3oj9jYPGoY7^W00?o
Xg^WokJM_onfWKl00_nfWKl4ok2C^0;o[Hfd1?o2lO02olOBhPGoYH>_1?nPQKL5ojB4/PCoWhFg0onL
R/000on[U/3oYiO5ojNGa@03ojNGa@CoXi_<0_nPX=@2ojRQc`?oYJCD00Co0000ojFTe?nSZ=WoXjSI
0_n[/=`5ojRbg`?oY[GS00?oZk_UojVlionY_>L00onY_>L2ojRnj@;oZl7Z5Oooool00ol0003ooooo
ooooo`0Nooooo`009_ooool00ol0003ooooooi6ilP02oi6ilPCoS/Gj0_n8col4oj7FnP03oi[PoOnb
h?Oo/^3g00;o/^3g1?nnf>`00onng_3o`L_Qol7;h@02ol7;h@03ol7<h_nl^=Ko_;SF00?o_;SF00Co
^[GDok2Qb?n`XLSo/:781?n]VlD4oj^G`P03ojRB__nOQ[WoWhJi00CoWH:f1?nKOk<3oiUl/@CoV7V_
0onGMjd4oiEd[0;oU7:Z00CoT76[ohm`Zon?L:_oSg2[1?n?Kj/4ohm_ZP?oTFnY1?nBKjP3oiA_YPCo
UFjT0onFKJ801OnEK:3o0000o`000?l0003oUFbP00?oU6ZO0_nCJIh2oiMf[0?oUWBZ1OnFLjX3oiEc
ZPCoUG>[1OnEM:`3oiMg[@03oiYk/?nCJYooTfZO00GoU6^P0_nFK:400onLM:GoWGFToieeY002oiee
Y0CoWGBS1?nMLj<4oi]aXPCoVFnQ0_nHKJ000onJLjGoW7BUoiadY@03oiadY@CoWgNV1?nRNZH3ojAk
Y`03okn^bOnfWKoo]Yfo00?o]Yfo1?n`TkP01_n]SKCo`_7`ol;al?o2lO3oUW2Toi1b[@?oZX>[1OnU
Pjl2oj25]`03oj^7[onTQ;;oY8Bb00?oY8Bb1OnOQKL01?nLR/3oZiK0oj^F`?n[U/04ojNGa@?oXi_<
00?o[:7<ojRQconXXLl00onXXLl3ojFTe003o`000?n[/=coZk3L00?oZk3L1?nX/]l00onV]N?oZk_U
oj^ki@02oj^ki@?oZKcW0_n/`NT4oj_1jQCooooo00?o0000ooooooooool07_ooool001_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?ooooooTKWb00?oTKWb0_n>aOX4oj?;m0;oXMKj
1?nce_800onbh?Oo_]S/okkHk002okkHk0;o`LWP0oo1bn43okfke`?o_;SF00?o/jK;ok2Qb?n`XLP0
0_n`XLP5ojfKa@;oZiO200?oXX^loin6^OnOQ[T00_nOQ[T3oif2]PCoVgnc1?nIO;43oiQi[`;oUgN]
00?oTW>]oi5b[?nALZ`00_nALZ`3oi1aZ`CoSg2[0on?Kj/4ohm_ZP?oTFnY1?nBKjP3oiA_YPCoUFjT
00CoUVfRo`000?l0003o00001?nEK:02oiAZW`03oiQh[OnGMZcoUgJ/00;oUgJ/1?nFM:X4oiIcZP?o
UG>Z1?nELj/5oiEd[0;oUgN]00?oFLj_oi=ZWonCJYl00_nCJYl4oiA[X003oiI/XOnLM:GoW7BU00Go
WGFT0onMM:<4oiecX`CoVg6R1?nIKj400onHKJ3oVW>UoiYcY@05oiadY@CoWgNV1?nRNZH2ojAkY`?o
_jk91OnfWKl2ok2C^003ogKP__nLLJ7oUW2T00;oUW2T00?o[HFYojZ3ZonZPj/00_nZPj/5ojF3[`04
oj25]on[QjooZhN_oj^7[`GoY8Bb0onOQKL00onaV;goZiK0oj^F`002oj^F`0GoYiO500CoXi_<ojbQ
c?n/XLco[:7<1OnXXLl01?nUY=Co[K3Jojf`f_l00005oj^`g0;oZ;;O0_n]^n@5oj^ki@03ojVlion/
`NWo[<7Y00;o[<7Y0_n[`NX2oj_3jaCooooo00?o0000ooooooooool07Oooool001_ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00;oTKWb0onT_nd3oj?;m0;o/lc]1?nc
e_83okgAj@03okkHk?o1bN3o`LWP00?o`LWP00?o`L_Qokfkeonm^mL00onm^mL01?nl^=Ko/jK;ok>V
boncY//3ok2Qb0Co[I_500?oY930oj:;_?nRRk`00_nRRk`3oin6^@?oWH:f1OnKOk<3oiUl/@;oV7V_
00CoTgF^oi9c[OnBLjgoTW>]1?nALZ`4oi1aZ`?oSg2[0on?Kj/4ohm_ZPCoTFnY0onBKjP3oiA_YP;o
UFjT0ol00003oiI]XPCoUFbP00?oU6ZOoiQh[OnHN:d01OnGMZ`3oiIdZPCoUW>Z0onELjX5oiEcZ`?o
UGB/00CoDlbcoi=YWonCJIooTfVO1?nCJYl3oiA[X004oi]dY_nLM:GoW7BUoiadY@GoWGFT0onMM:<5
oiecX`?oVg6R0_nIKj42oiYcYPCoVW>U1?nLM:D5oimgYP?oXWZV00?oY7^Wokn^bOno[/T00_no[/T5
okJM_`04ok2C^?nLLJ7oW76QoiaaX@;oUW2T0_n]QJT4ojZ3Z`CoYH>_00?o/hnaoj^7[on[Qjl00_n[
Qjl5ojB4/P04oin5]onaV;go/IRmok6H_@CoZiK01?nWUlD00onbY<[o[:7<ojbQc002ojbQc0CoZ:7?
00Ko/K;Iojf`f_n]/=[o[K3Jo`000?n]/=X2oj^`g0;o[kkT1On]^n@2oj^ki@;o[L;Z1?n/`NT00on/
aNcoZl?[oj_3j`03oj_3ja?ooooo0_l0000Nooooo`006oooool01Ol@413ooooooooooooooooo410@
00Kooooo0_l00002ooooo`GoY;o]00?oXl_dok?<kOncc>d00_ncc>d00once_;o_M7YokgAj@02okgA
j@?o`LOO0oo1bN02oknmf@Co_K_G00?o]Zc?ok>VboncY//00_ncY//4ok2Qb003ojfKaOnTT<3oY930
00;oY9300onRRk`3oin6^@CoWH:f1?nKOk<2oiUl/@04oiAg/?nCMJkoTgF^oi=e[PCoTW>]0onALZ`4
oi1aZ`?oSg2[1?n?Kj/3ohm_ZPCoTFnY1?nBKjP01?nDKjKo0000o`000?l00003oiE^Y0?oUVfR0_nE
K:02oiMi/0CoV7R]1?nGMZ`3oiIdZPCoUW>Z1?nELjX4oiEcZ`03oiEd[?nBJJ3oTVVP00GoTfVO0onC
JYl01?nDJj3oVgBVoi]dY_nKM:H4oiadY@CoWGFT0onMM:<5oiecX`;oVg6R00?oW7JXoiYcY_nJLjH0
0_nJLjH4oiYcY@CoW7BU1OnOMjH2oj9jYP03olW7f?no[/Wo_jk900?o_jk91?nfWKl00onQM9ooW76Q
oiaaX@02oiaaX@03oiI`Y?n]QJWo[HFY00;o[HFY1?nZPj/2ojF3[`;o/hna1?n[Qjl4ojB4/P03okJM
__naV;go/IRm00?o/IRm1?n[U/001?nWUlGo/ZC:ok:Tb_nbY<X5ojbQc003ojRQcona/]Wo/K;I00;o
/K;I0on]/=X00ol0003o[kkTojnni003ojnni0;o[K_T0_n^aN/5ojg2jP03ojc1jOn/aNco[<G/00;o
[<G/0on[`n/00onZ`ncoooooooooo`0@ooooo`03o`000?oooooo000001kooooo000Kooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`;oY;o]0ona`^H3ok?<k@Co
_<[U00?o_M7Yol77goo1aml00oo1aml00oo1bN3o_kgIoknmf@02oknmf@03okfkeonf[<oo]Zc?00;o
]Zc?1?ncY//2ok2Qb003ojNFa?nTT<3oY93000?oY9300onRRk`4oin6^@?oWH:f0_nKOk<2oiEj/P?o
U7N`1?nCMJh3oi9c[@?oTG:/1?n@LJ/3ohm`Z`CoSfn[0on?KjX4oi5_Z@?oTVnX0_l00002oiA_YPCo
UFjT0_nFKJ800onFNk?oUgV`oiMi/002oiMi/0CoV7R]1?nGMZ`3oiIdZPCoUW>Z1?nELjX2oiEcZ`03
oe7<^_nBJJ7oTVVP00?oTVVP1?nCJIl2oi=ZW`03oiQbY_nKM:KoVgBV00;oVgBV1?nLM:D4oieeY0Co
WGBS1?nMLj<00onKLJ;oW7JXoiafZ005oiYcYP?oVW>U1?nLM:D5oimgYP04oj9jY_o9amSobLOHolW7
f0Go_jk900Co]Yfooj5dWonQM9ooXGBO1?nLLJ45ojf5Z@CoZX>[00?oYH>_ok>?/OncSk400_ncSk44
oj^7[`;oY8Bb0onfWKh4ok6H_@?oZiK000?o^Jg=ok:Tb_nbY<X00onbY<X3ojbQc003okFgfona/]Wo
/K;I00?o/K;I00Go[K3Jok;2i_nb`^Ko//;Vo`000003ojnni0;o[lW]1?n^aN/2ojg2jP?o[<S^1?n/
aN`00on[`n_oZ/?/oj[3k002oj[3k1Cooooo00?o0000ooooooooool06oooool001_ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo1Ona`^H00oncc>go_<[Uokc:
i@03okc:i@03ol36g_o1amoo`LOO00;o`LOO00?o`<3JoknmfOno_MT00ono_MT5okJ/c`?o/jK;00?o
Zic8ojNFa?nWU/@00_nWU/@4ojB@`0CoXX^l0onOQ[T2oif2]P03oiIm]OnEN[;oUGZb00;oUGZb1?nD
Mk03oi=e[P?oTW>]1?nALZ`3oi1aZ`?oSg2[1?n?Kj/4ohm_ZP?oTFnY0ol000001?nBKjSoU6nVoiA_
Y_nDKjH2oiE^Y0;oU7bf0onFNk<4oiMi/0CoV7R]1?nGMZ`3oiIdZPGoUW>Z0_nELjX2odg:_0CoTVVQ
0onBJJ04oi=YW`03oi=ZWonHLZKoV7:V00CoVgBV1?nLM:D4oieeY0CoWGBS0onMLj<01?nNNjcoW7JX
oiafZ?nLMZP5oiYcYP?oVW>U1OnLM:D3oimgYP03olkXj?o9amSobLOH00?obLOH0_no[/T2ojQjX@Go
XGBO0onLLJ45ojf5Z@CoZX>[1OncSk44oj^7[`03ojB4/_nfWKko]Yfn00;o]Yfn1?naV;d00on[U/3o
^Jg=okV]c@02okV]c@Co/ZC:00?o[:7<okFgfone]m/00_ne]m/3ok6bf@;o]Lc[0onb`^H00ol0003o
[kkTojo9k@04ojo9k@;o[/G[0_n[c?45ojc8kP;o[<G/0_nZaNd3oj[3k003ojS2k?oooooooooo01?o
oooo00?o0000ooooooooool06_ooool001_ooooo00Go410@oooooooooooooooooa0@4005ooooo`03
o`000?oooooooooo00Gooooo0ona`^H3ok[3h@?o_<[U0oo0a]h00oo1amoo`<3Jol30fP02ol30fP?o
_kgI0_ni/]85okJ/c`04ok>Vbon[W<SoZic8oj^Lb0?oYiK41OnTT<03oj:;_0;oWhJi00CoV82hoiIm
]OnFOKGoUWfe1?nEN[84oiAg/0?oTgF^0onBLjd4oi5b[0?oT76[1?n?L:/3ohm_Z`CoSfnZ0ol00002
oi9_Z0;oSgbk0onAOKT4oiAl]PCoUW^c0onGNK04oiQh[@CoUgJ/1?nFM:X4oiIcZP04oiEcZ_nAJZ;o
TFZRoi5ZXPCoTVVQ0onBJJ02oi=YW`;oUW2V1?nHLZH3oi]dYPCoW7BU1OnMMJ@3oiedX`04oiecXonN
NjcoWW^/oiik[0CoW7JX1?nJLjH3oiYcY@GoW7BU0_nOMjH3olkXj0?obLOH0_n_PjD3ojQjX@GoXGBO
0_nLLJ42ok69Z`Co[HFY1?nZPj/5ok>?/@CoZhN_1OnfWKh3ok6H_@03olC1eoni[Lgo^Jg=00Co^Jg=
0_nbY<X2ok_3h0Go]KOK00?o/K;IokG<jonec>/00_nec>/2ok;2iP03ojk?lOl0003o[lW]00?o[lW]
00?oZM3doj_<lOn[c?400on[c?42ojc8kP;oZLO_1OnZaNd01?nZ`ncoZ<;/ojS2k?nX`^`Dooooo`03
o`000?oooooooooo01[ooooo000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000Oo
oooo00?o/L;Vok[3hOnj`n400onj`n400onlb^Go`<KNol36gP02ol36gP03ol72foo0`=[o`<3J00?o
`<3J00?o_kgIokVbd_ni/]800_ni/]83okJ/c`03ojjSc?n[W<SoZic800;oZic80onWU/@5ojB@`0;o
XX^l00CoVXFkoiR0^?nHP;SoV82h1?nFOKD3oiEj/PCoU7N`0onCMJh3oi9c[@CoTG:/1?n@LJ/3ohm`
Z`?oSfn[00CoSfnZo`000?l0003o00000on>O;/4ohml^`?oTGfi1?nDO;H4oiIk/`CoUgV`0onHN:d5
oiMf[0?oUWBZ0_nFLjX3oi1ZX`?oTFZR1?nBJJ42oi9YX003oi9^Y_nFL:KoUW2V00;oUW2V1?nHLZH4
oi]dYP?oW7BU1OnMMJ@2oiedX`03oj>3/_nNNjcoWW^/00?oWW^/0onLMZP4oiYcYPCoVW>U1?nLM:D0
0onOMjKoc^SXolkXj003olkXj004olW7f?n_PjGo[h>Uojn3Y@?oZ7ZQ1OnQM9l01?nLLJ7o/HV[ok69
ZonaRJ/5ojf5Z@;oZX>[0_o0XKT5ok>?/@;oZhN_0_noZ/D5okJM_P04ok6H_Oo4`MOoa<7GolC1e`Co
^Jg=00?o^mC/ok_3h?nk`n000onk`n02okFgf`;o]=Wc1?nec>/00on[eoOo[/oaojk?l@02ojk?l@03
o`000?n_bNgoZM3d00?oZM3d0_n[c?42ojO9lPGoZLO_0_nZaNd2ojO3kPGoZ<;/5?ooool00ol0003o
ooooooooo`0Iooooo`006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooooooo
ool01oooool4ok[3h@;o`<CM0oo0a]h3ol72f`?o`<3J00?o^kSFokVbd_ni/]801?ni/]801?nf[<oo
[Z?<ojjSc?n^Xl`3oj^Lb0CoYiK40_nTT<02oib9_`CoVXFk0onHP;P3oiIm]@CoUGZb0onDMk04oi=e
[P?oTW>]0onALZ`4oi1aZ`;oSg2[00?oTG^goi1k^?l000000_l00004ohmk^P?oSWbk1?n?O;/3oi5m
^@CoU7bf0onFNk<4oiMi/0CoV7R]1?nGMZ`2oiIdZP;oSVZT1?n@JZ<2oi5ZXP03oheYYOn?K:KoSfbV
00;oSfbV0onBKZH4oiI`YPCoV7:V1?nKM:H4oiadY@CoWGFT00?oWGBSoj>3/_nSPk801OnNNj`3oiaf
Z0CoVW>V1?nJLjD3oiadY@?o/O[T0_o>j>P00onSN:?o[h>Uojn3Y@03ojn3Y@?oZ7ZQ1OnQM9l4ok69
Z`Go[HFY00CoZX>[ol2Q^Oo0XKWo`:6i1OncSk401?n[Qjoo_j[5oknZaOnoZ/D4okJM_P03olWSj_o4
`MOoa<7G00?oa<7G00?o^Jg=ok_Dk?nke>`00_nke>`3ok_3h0;oZNSj1?ndfO<00onec>_oZmOgoj_G
m`02oj_Gm`;o[/oa0_nUe?P01?l0003oYMChojW@m?nYd?@2ojC;m0CoYlWb0_nYanl3ojK4k`CoYl?^
0_nX`^`2ojK0k1Cooooo00?o0000ooooooooool06Oooool002Gooooo00?o0000ooooooooool02?oo
ool00onj`n7o`<CMol34g@03ol34g@03ol36g_o1`]_o`L;K00?o`L;K00Co`<3Jok^he_nk^=Ko^kSF
1?ni/]800onaZ]7o[Z?<ojjSc002ojjSc0CoZic80_nWU/@00onOSl?oW8Vooib9_`02oib9_`CoVXFk
0onHP;P3oiIm]@CoUGZb1?nDMk03oi=e[P?oTW>]0_nALZ`5oi9k]`04oi5k]ol0003o0000o`0000?o
T7^h1?n?NkX3ohil^`CoSgbk0onAOKT4oiAl]P?oUW^c1?nGNK04oiQh[@;oUgJ/0on:IJ83ohYVX`Co
RfNT0on=JJD4ohm/YPCoTVjV0onFL:H4oiQbYPCoVgBV1?nLM:D3oieeY003ojN>^onSPk;oXh>b00;o
Xh>b1?nNNj`3oiafZ0GoVW>V0onJLjD01?nLM:Go/O[Tok7ji?nan^@2oj9fX@;oXgRS0_niTZh4ojn3
Y@CoZ7ZQ0onQM9l00oneT[;o/HV[ok69Z`02ok69Z`Go[HFY1?o0XKT4ok>?/@03olK3e_noZ/Go_j[5
00;o_j[50onfWKh3olWSjP?oa<7G0_n/joT4ok_Dk003ok_3h?nYj?[oZNSj00?oZNSj0_ndfO<3oioN
o0;oZmOg0onMeo`2ojGDn003o`000?nPc?KoY<_d00CoY<_d0_nWbO82ojG5l0GoY/C_0_nW`nh2ojK0
k@CoY/3/4_ooool00ol0003oooooo`00000Jooooo`009Oooool00ol0003oooooooooo`0:ooooo`?o
`<CM0_o1a=`4ol72f`;o_KkJ1?nk^=H00oni/];o/J[Aok6Zd@02ok6Zd@Co[Z?<0_n[W<P00onRU/So
Who3oin?``02oin?``?oW8Vo1?nJQK/3oiR0^0CoUWfe0onEN[84oiAg/0;oTgF^00CoTG^hoi5k]onA
NkOoTG^g1OnBNkL3o`0000?oTG^g0on@NkP4ohmk^P?oSWbk1?n?O;/3oi5m^@CoU7bf1?nFNk<3oiMi
/0;oV7R]1?n;IJ43ohYUXP?oRVJS1?n;Ij@4oheYY@?oSfbV1?nBKZH3oiI`YPCoV7:V1?nKM:H4oiad
Y@04oieeY?nWS[_oYhjkojN>^`CoXh>b1?nNNj`3oiafZ0GoVW>V0_nJLjD2o`000003oj5eXOnRMZ7o
XWJQ00;oXWJQ00CoXgRSokVB[_niTZko^I:^1?n_PjD4ojQjX@;oXGBO0oneT[83ok69Z`Co[HFY0_oC
a/d4ol2Q^@;o/hna0oo6`mH4oknZa@03okJM__o9hn[obN?Z00;obN?Z00?oa<7Gojc[nOn/joT00on/
joT2ok_Dk0?oO^G_0_nYj?X3ohONo@;oWmkl0onAeoh2oigGo0;oVl_h0onPc?H01?l0003oX<cfojC;
m?nTbo@2oj;4l@GoYLG`0_nVa>l2ojG0k@GoY/3]0_nV`>`2ojJok1Cooooo00?o0000ooooooooool0
5oooool002Gooooo0_l0000<ooooo`03ol34gOo1a=co`LCL00;o`LCL00?o`L;Kokfnf_nm_]X00onm
_]X2ok^heP03okBbe_naZ]7o/J[A00?o/J[A0on^Xl`00onUWLgoXYK8oj:Fb002oj:Fb0?oWho31?nL
RKl4oiZ5^`?oV82h0onFOKD3oiEj/P;oU7N`0_n@O;T3oi5k^0?oTG^g0onBNkL2o`0000?oTW^g0onA
NkL3oi1k^0GoSg^j0on>O;/4ohml^`?oTGfi0onDO;H4oiIk/`;oUgV`0on=IJ04oh]UX@?oRVFR1?n:
IZ<4oh]WY0?oSFVU0on?K:H4oi9^YPCoUW2V1?nHLZH3oi]dYP?oW7BU00?oZi[5ojN>^onWS[/00_nW
S[/4oj>3/PCoWW^/1?nLMZP4oiYcYP03oiYcYOnQMJ7oXGFQ00;oXGFQ1?nRMZ44okVB[PGo[h>U0onX
NZ400onQM9oo]I:bokFB/P02okFB/PCo/HV[0_n]QJT3om?6c@Co`:6i00?o/hnaolK3e_o6`mH00_o6
`mH3oknZa@?oS>g@0_o9hnX3oecEe0;o[>_i0_l^][/3od_3l@;oJ=Cg0_n1aoh5ohC@o`;oTMOn0_nG
aoP4oi_;n0;oX<cf00?oX<;ao`000?nP`_401?nRa?42ojG5l0;oY<3]1OnU`>d2ojK0k@;oYKk[1OnV
_n`Cooooo`03o`000?oooooooooo01Oooooo000Tooooo`03o`000?oooooooooo00gooooo0oo1a=`3
oko4g@?o_KkJ00?o]k[LokBbe_nd/]H00_nd/]H5ok6Zd@04ojjSc?nUWLgoYIg=ojFMc@?oXYK80onO
Sl<4oib9_`CoVXFk0onHP;P2oiIm]@04oi60_On@O[_oT7jkoi1n^`CoT7bi1?nANkP2oi5k]`?o0000
1OnBNkL3oi5k]`CoT7^h1?n?NkX3ohil^`CoSgbk0onAOKT2oiAl]P04ohmYX_n?Ij7oSfNQohmWX@Co
SVJP0on=IJ03oh]UX@CoRVFR0on:IZ<4oh]WY0?oSFVU0on?K:H4oi9^YPCoUW2V1?nHLZH3oi]dYP03
oiadYOn[V/GoZi[500;oZi[51?nWS[/3oj>3/PGoWW^/0onLMZP3oiYcYP;oX7FR1OnQMJ43oj9fX@Co
^I:^1On_PjD2ojQjX@03ok^R`?neT[;o]I:b00?o]I:b1?naRJ/00on]QJWodlK=om?6c@02om?6c@?o
`:6i0_nklO<5olK3eP03oknZaOn<kM3oS>g@00?oRjc/0om]]o`2oe6nn@?oT:gZ1?n4^OL4oh77oP;o
Q=3o0_nD_o@5oiO7n0;oVl_h0_nN_^l3oj32l@04o`000?nP`_7oX/Caoj;4l@;oXkk/1?nT`>d2ojG0
k@?oYKg[1?nU_^/2ojJok0;oY[k[5?ooool00ol0003oooooooooo`0Fooooo`009?ooool00ol0003o
ooooooooo`0>ooooo`03ol74g?noa=go_lCM00?o_lCM00Co_KkJokNjg?ng^]co]k[L1?nd/]H2ok6Z
d@;oZ:GC1?nUWLd3oj:Fb0CoWho30onLRKl2oiZ5^`;oThK30onAPl04oi60_@?oT7jk0on@O;T3oi5k
^0?o000000?oTG^goi9k]onBNkL01_nBNkL3oi5k]`?oT7^h0_n?NkX3ohZnn0CoKlKo0_m0_^X2ohmZ
Y0CoSfVR0on?Ij44ohiVX0?oSFFP0on;IJ44ohYUXP?oRVJS1?n;Ij@3oheYY@CoSfbV0onBKZH4oiI`
YPCoV7:V0_nKM:H00on]Y]7oZi[5oj^Ja@03oj^Ja@CoYhjk0onSPk85oiik[0?oW7JX00?oVW>Voiid
XonPMJ800_nPMJ85oj5eX@;oXWJQ0_o8[l03okVB[PGo[h>U00CoZ7ZQok^R`?nkX/3o^j;01?neT[84
ok69Z`03okgmcOoCa/godlK=00?odlK=00?o`:6iok_alonklO<00_nklO<2olK3ePCoW:7G0_n;[>`2
oj>Mc`CoVZ;K1On@[NX2ohBim`;oW:kT1?nG^>h4oiBom0;oUlOh0_nN^N`5oijnk`;oX<;a00?o0000
oj>ljonS_^`01?nS_^`2ojC0k@;oYKcZ1OnU_N/2ojFnj`;oY[gZ1?nV_^/Dooooo`03o`000?oooooo
oooo01Gooooo000Tooooo`?o00003oooool4oko4g@03ok[3hOng^]co]k[L00?o]k[L0_nd/]H2oj^]
f@CoZ:GC0onUWLd4oj:Fb0;oWho300CoUXo:oiB:a_nDR/KoU8[61OnCQ/<3oi63`0?oTH2m0on@O[/3
oi1l^@?o000000CoTG^hoi5k]onANkOoTG^g2?nBNkL3oi5k]`;oT7^h0onE]>d4ohZnn0;oKlKo0on?
KJL3ohmZY0?oSfVR0on?Ij44ohiVX0?oSFFP1?n;IJ43ohYUXP?oRVJS1?n;Ij@3oheYY@CoSfbV1?nB
KZH3oiI`YP?oV7:V00?oZjgIojfVdOn]Y]400_n]Y]44oj^Ja@CoYhjk1?nSPk84oiik[0;oW7JX0onN
M:<3oj1eXPGoXGFQ00CoXWJQolR_`?o8[l3ob:o01?niTZh3ojn3Y@03ol36gonkX/3o^j;000;o^j;0
1OneT[82ok69Z`?o_Og=0_oCa/d3oibCb`;o^o7c1?nVV/T3oibQe`03ojbLaonSWLooXig?00?oXig?
1?nJX]/2oi2]jP;oXZSJ1OnL[^@2oiNhkP03oj:]gonO/^KoWk;V00?oWk;V1?nN^N`2oijnk`;oX[SX
0onS_>/01?l0003oXkc[oj>nk?nS_^`2ojBjj0GoYKcZ0_nU_N/2ojJlj@GoY[gZ0_nV_^/2ojNnja;o
oooo0_l00009ooooo`Co000000?o410@ooooooooool01oooool002Cooooo00?o0000ooooooooool0
4?ooool00onoa=go^/?Qok[3h@02ok[3h@?o]k[L00?o[[OPoj^]fOn[[MT00on[[MT4ojRUd`?oYIg=
0_nRU/P00onIULkoUXo:oiJ?bP02oiJ?bP?oU8[61?nCQ/<3oi63`0?oTH2m0on@O[/3o`000003oi1l
^OnANkSoTG^h00;oTG^h0onANkL5oi9k]`;oV:SQ1?nH[ND5oiFdk@;oR[kh0_n@L:/4ohm]Y`?oSfZT
0on?JJ83ohmWX@CoSVJP0on=IJ04oh]UX@?oRVFR0on:IZ<4oh]WY0CoSFVU0on?K:H4oi9^YP?oUW2V
00?oV7:Voj^]fOn[[MT00_n[[MT3ojfVd@GoZi[50onWS[/4oj>3/P;oWW^/0onMM:@4oiidX`CoX7FR
0onQMJ400ooHj>3ob:o0olR_`002olR_`0Co^I:^0_n_PjD3ol36g`?o^j;01OneT[801?naRJ_oZi6k
oj^A^on[TK/4ojB@_`04oibCbon]VL;o[IW2ojfI`PGoYY[900CoW:7GojbLaon/W<Oo[9c71OnSWLl2
oiZRf`03ojVTdOnRZ=[oXZSJ00?oXZSJ0onL[^@00onWZMWoXZgOoj:]g`02oj:]g`GoWk;V0_nN^N`2
ojBdi@CoX[SX0_nS_>/00onU^>Ko0000ojFhiP04ojBjj0;oYKcZ0_nV^nP5ojJlj@;oY[gZ0_nW_NX5
ojNnja?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`002Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`0B
ooooo`Co^/?Q00Co]k[Lojjgh?n^]n3o[[OP1On[[MT2ojRUd`04oijSfOnKW=?oVicCoi^Ld`CoVIG>
0onFSlX3oiB:aPCoThK30onAPl03oi60_@?o000000CoT7jkoi1l^On@O;WoT7bi1?nANkP3oi5k]`;o
TW^g00?oUJCOoiRXhOnHZ>400onHZ>44oiR]i@;oUKC]0onCMJl3oi1`Z`CoSffW0on?JZ@4ohmYXP?o
SfNQ0on>IZ03oheUX0CoRfFQ0on:IJ84ohYVX`CoRfNT0on=JJD3ohm/YPCoTVjV0_nFL:H00onUZm_o
ZjgIoj^]f@03oj^]f@Co[JKA1?n[V/D2ojN>^`;oVWBW1OnLM:H3oiedY0CoWWBS1?nPMJ82oj5eX@;o
f>SP1Oo8[l03okVB[P03ojn3YOo0a]oo`<KO00;o`<KO1?nkX/03okFB/P03ojnC^_n[TK_oZi6k00;o
Zi6k0onTT;l00onaVKoo[IW2ojfI`P03ojfI`P?oYY[900?o/Ik4ojbLaon/W<L00_n/W<L4oj>Mc`03
ojjSc?nYY=7oZJCA00;oZJCA1?nRZ=X00onL[^CoYjWIojNYf@02ojNYf@CoXZgO0_nO/^H2ojJah0Go
Y;CU0_nR^>P2ojJfi0;oYKSV00?o0000ojFhi_nU^>H00_nT^^P2ojNji`CoY[_X0_nV_>T2ojNmj@Go
YkgZ0_nW_^/2ojNojaCooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`00
2Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01_ooool00ol0003oooooooooo`0Cooooo`;o^/?Q0_n``^L4ojjgh0;oZjgI0_nP[=l4oijS
f@?oVicC0onIULh3oiJ?bP?oU8[61OnCQ/<2oi63`0?o000000CoTH2moi1n^on@O[_oT7jk0_n@O;T0
0on=V]_oSigLohnMg002ohnMg0?oTZ7N1?nEY=l5oiRXh@;oV:gU0onHO;<4oi=e[`?oT72[0on?KJL3
ohmZY0CoSfVR0on?Ij43ohiVX0?oSFFP1?n;IJ44ohYUXP?oRVJS1?n;Ij@3oheYY@?oSfbV0_nBKZH2
oijPe@CoYJ_K1On[[MT2ojfVd@;oTF>H0_nBI9P2oiUdZ0?oVWBW1OnLM:H3oiedY0CoWWBS1?nPMJ80
0onQMJ7of>SPomSXh002omSXh0Cob:o00_niTZh2oh?XjPCo`<KO1?nkX/001?neT[;o[i>jojnC^_n_
TkX5oj^A^`04ojB@_onaVKoo/IVook6I_`Co[IW200?oYY[9ok6Na?naW/@00_naW/@4ojbLa`04oj>M
con^Xlco[Z?<ojjSc0GoZJCA0_nRZ=X00on[Z=CoYjWIojNYf@03ojNYf@;oXZgO0_nY[m`5ojJah0;o
Y;CU0_nX]>45ojJfi0;oYKSV00?o0000ojNiiOnW^^L01?nW^^L2ojJkj0;oYkcX1?nW_NT2ojNmjP?o
Z;kZ1?nW_n/Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool000Wooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000oooooooo
ool05Oooool4ok32i`;o[[OP0_nR]NH4oj2/g`?oWZ?I0onKW=<4oiVEcP?oUXo:0onDR/H2oi>6``;o
RiKI0_l000001?n:UMSoRiKIoh^FfOn;U]T3oh^GfPCoSI[K1?n?WM`3oi:QgPCoUJCO0_nHZ>401?nS
SKgoWHBhoif4^?nMQ;P3oiQl/`CoTgF_0on@L:/3ohm]Y`?oSfZT1?n?JJ83ohmWX@CoSVJP0on=IJ03
oh]UX@CoRVFR0on:IZ<4oh]WY0;oSFVU00CoTh>noiRAb_nHTL[oV97:1OnNX=D4ojF[f`;oZjgI0on?
HYP2oi5SV003oiMcZ?nIM:SoVGBX00;oVGBX1?nJM:L4oiadYP?oWGBT1OnNM:<3oj1eXP;o00000ooH
j>02olR_`0;oY8Nf00GoXXRioj^?^?n[SkSoZhnhojZ?^@04ol36g`;o^j;00_nbUk`3ojnC^PCoZi6k
00?o]9c0ok6I_onaVKl00_naVKl3ojfI`P03okJSaOnaW/Co/Ik400?o/Ik40on/W<L00ondY/_o[Z?<
ojjSc003ojjSc0?oZJCA00?o/J[Aoj^Xe?n[Z=@00_n[Z=@3ojNYf@03ojf_fOnY[mcoZJoL00?oZJoL
0onV/N000on[/mkoZ;CQojRdh@03ojRdh@?oY[KT00KoZKSTojNiiOnW^NGoYkWUo`000?nW^ND3ojNj
i`03ojRkionW_>SoYkcX00?oYkcX0_nW_NT2ojRnj@GoZ;kZ0_nW_n/2ojS0ja?ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`09ooooo`002Oooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`0001Kooooo0_n``^L2oj:nk@CoX[GV0onP[=l4oijS
f@?oVicC0_nIULh01?n>W]koSI[KohfJfon=V]/4ohbGfP?o000000CoRiKIohZEf?n:UMSoRYGH0on;
U]T3oh^GfPCoSI[K1?n?WM`3oi:QgP;oUJCO00?oZIK3oj>=_OnSSKd00_nSSKd3oif4^0?oV7bc0onC
MJl3oi1`Z`CoSffW0on?JZ@3ohmYXP?oSfNQ1?n>IZ03oheUX0?oRfFQ1?n:IJ82ohYVX`03oi1b[OnA
N;CoTGRd00;oTGRd1?nCPkh3oiRAbPGoWZ3E0_nUZm/2ohiQV0;oSf:H0_nELJL3oiMcZ0GoVGBX0onJ
M:L4oiadYP?oWGBT1OnNM:<2oj1eXPKoY8Jd0onTQkH00on[SkWoZhnhoj^?^002oj^?^0GoZXni00Co
ZI2lok:G_?nbUkco/YNl1?n_TkX01?n[TK_o]9c0okBL`?ndW<05ok6I_`04ojfI`_nfXlGo]Z?5okJS
a@Go/Ik400Co[9c7okBVbondY/_o]:K;1?n^Xl`00onYY=7o/J[Aok6Zd@02ok6Zd@CoZjSD00CoYjWI
ojf_fOn][mWo[JoI1OnY[m`01?nV/N3oZk?Noj^cg_n[/mh4ojRdh@03ojJfi?nY^>CoZKST00;oZKST
0onW^ND00ol0003oYk[WojRki`03ojRki`?oYkcX00?oZKgXojRnjOnX_^T00onX_^T2ojRnjP;oZ;oZ
1OnX`>/Aooooo`?o00001oooool00ol0003oooooooooo`09ooooo`002Oooool01Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`0Hooooo`?oX[k]
1?nR]NH3oj2/g`;oWZ?I00CoTJOUohnRhOn?X^7oSj;Q1?n>W]h3ohfJf`?o000000CoS9OJoh^FfOn;
U]WoRiKI0on:UMP3oh^Ff@CoRiOJ1?n=V]/2ohnMg0;oC<SW0_n^X<T3ojVF``CoXhfm0onMQ;P3oiQl
/`?oTgF_0on@L:/4ohm]Y`?oSfZT0on?JJ83ohmWX@CoSVJP0on=IJ02oh]UX@03oi1/Y_n@KZSoT6jX
00;oT6jX0on@LZd5oi5h]0?oTh>n1?nHTLX2oijPe@?oSV2H0_n>HIP00onCKZKoUG6WoiEaY`02oiEa
Y`CoUg>X1?nIM:P3oiYdY`CoW7BV1?nMM:@4oiidX`03oj1eX_nTQ[CoY8Jd00GoY8Jd00?oY8Nfoj^?
^On[SkT00_n[SkT3oj^?^0CoZXni00?o/ibook:G_?nbUk`00_nbUk`4ojnC^PGo]9c00onaVKl00onj
Z/Wo]Z?5okJSa@02okJSa@Co/Ik400?o]j_<okBVbondY//00_ndY//3ojjSc003okF^dOnaZ]7o/J[A
00?o/J[A0_n[Z=@3ok6`e`Co[JoI0_nY[m`2ojfcg@GoZk?N0_nX]>42oj^ghPCoZKST0_nW^ND00onY
^nKo0000ojVkiP04ojRki`03ojNlj?nY_NSoZKgX00;oZKgX0onX_^T00onY_n[oZ;oZojRojP03ojRo
jP;oZ<3[0_nY`>/>ooooo`Co000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`09oooo
o`002Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Iooooo`?oX[k]0_nR]NH00onB/ngoTZgYoi:]j@02oi:]j@?oTJOU0on?X^43ohjN
gP?o000000?oSI[KohbGf_n<UmX00_n<UmX3oh^Ff@?oRYGH0on;U]T2oh^GfPCoJLWn0_mMboL00onc
ZLko[Z39ojjPb@02ojjPb@CoZIK30_nSSKd01?nCMZooSW2/ohi`[?n>L:`3oh]/ZP?oQfRX0on5IZP4
ohm]Y`?oSfZT0on?JJ83ohmWX@;oSVJP0_n?K:H3oi1/Y@?oT6bV1?n@KZP4oi1b[@CoTGRd0onCPkh3
oiRAbP?oSV6I0_n>H9P01?n@K:GoTfjVoi=^Y_nCKZH5oiEaY`?oUg>X1?nIM:P3oiYdY`GoW7BV0onM
M:@3oiidX`;oXhJe1_nTQ[@00onZT;_oZhnioj^?^@03oj^?^@CoZhnh00CoZXniok>L_oncW;oo/ibo
1OnbUk`2ojnC^P;o]Z741?ndW<02ok6I_`?o^Z[91?nfXlD01?naW/Co]j_<okN[c?ngZl`5okBVb`04
ojjSc?ne[]7o]JkAokF^d@?o/J[A00?o]KCHok6`eona/=L01?na/=L2ojf_f@03ok6fgOn]/mgo[K?M
00?o[K?M0_n[/mh2ojfhh@GoZkOR0_nY^>@2oj^ki@?oZK_V00Co0000ojVki_nX^nOoZ;_W1_nY_NP0
0onX_^WoZKoZojVojP02ojVojP;oZ;oZ0_nY`>X5ojW0j`[ooooo0ol00005ooooo`03o`000?oooooo
oooo00?ooooo00?oEEEEofIVI_l000002oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool2o`0001_ooooo0onB^_83oi:ck@CoTZgY0onA
YnD2ohnRh@?o000000?oSYkNohfJfon=V]/00omn/?@3ogbcmP?oN[Oi1?mg_O`3og;3oP;oJLWn00?o
]k7Cok>Yc_ncZLh00_ncZLh4ojjPb@;oZIK30_nHOK@3oi=f[`?oSW2/0on;K:X3ohMXZ0?oQFJX1?n4
IZP3ohIWZ0?oRVVX0on=JjH4ohm/YP?oT6bU1?n@K:H4oi1^Z0?oT7:]1?nAN;@4oi>3_P03oiRAb_n=
J:?oSFRS00;oSFRS0on@K:D4oi=^YPCoUG6W0onGLjP4oiUdZ0?oVWBW1OnLM:H3oiedY003oiidXonS
Q[GoXhJe00?oXhJe1?nTQ[@3ojZ@^`CoZhni0on[SkP00ondXLGo/ibook>L_`03ok>L_`Co/YNl00Co
[i>jokJQa?nfXLCo]Z741?ndW<000onaVKoo^Z[9okZZb@02okZZb@?o]Z?500?o^K;BokN[c?ngZl`0
0ongZl`3okBVb`03okVdeOne[]7o]JkA00?o]JkA00Co/J[AokFdf?ne]=So]KCH1?na/=L00onc^]ko
/KKMok6fg@02ok6fg@?o[K?M00?o[k[RojfhhOn]^>400on]^>42oj^ghP;o[;cU1On[^nD2ojVkiP03
ojZmiol0003oZKgX00KoZKgX0_nY_nT3ojVojPKoZL3Z0_nY`>/2ojW1j`Kooooo1?l00008ooooo`03
o`000?oooooooooo017ooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool06oooool3oi:jlP?oT[?]0_nB[NT2ohBa
lP04oh>`l_l0003o0000o`0000;oPJob1?n0[o84ogj`m0?oO;?f0omj]oT2ogNmo0Co`]_/00Co`mWZ
okNadong/M?o]k7C1?ncZLh2ojjPb@03oif4^OnHOKCoV7fd00;oV7fd0onCMZl4ohi`[0?oRfbZ0on7
J:P2ohEVZ0CoQ6JX0on6IjP3ohYYZ0?oSF^V1?n?K:H4oi1/Y@?oT6bV1?n@KZP3oi1b[@GoTGRd0_nC
Pkh2ohYVXPCoSFRS1?n@K:D3oi=^YPCoUG6W0onGLjP4oiUdZ0CoVWBW1?nLM:H2oiedY0;oXHFe1OnS
Q[D2ojB6]003ojVA_OnZT;_oZY2k00;oZY2k1On[SkT01?n[SkSo]:75okBQaOndXLD4ok>L_`?o/YNl
00?o]ZS:okJQa?nfXL@00_nfXL@3okBL`003ok^bdOnjZ/Wo^Z[900Co^Z[900Co]Z?5okVbd_ni/];o
^K;B1?ngZl`00ondY/_o^KCEokVde@02okVde@?o]JkA00?o]kWKokFdf?ne]=P00one]=P00ona/=Oo
/k[Nok>jgP02ok>jgPCo/KKM00Co[K?Mojnjh_n_^^;o[k[R0on]^>42ojjmi@Co[;cU0_n[^nD2oj^n
i`?oZ[gW00Co0000ojZmionY_NSoZKgX0_nZ_nT5ojVoj@03ojVoj_nY`>[oZL3Z00CoZL3Z1_nY`N/2
ooooo`?o00003?ooool00ol0003oooooooooo`0Aooooo`008_ooool00ol0003oooooooooo`0Moooo
o`?oQ[Gd0on5/o<01?n4/O;o0000o`000?l00003oh>`lP?oPJob1?n0[o82ogj`m0?oD<Gc0_lk_^00
1?nVl?Ko_m[]okoJkOnof^d3ol;Kk0;o^[SH1?ng/M<2ok>YcP03oj:=__nMQ;WoWHBi00;oWHBi0onH
OK@3oi=f[`CoSW2/0on;K:X3ohMXZ0?oQFJX0on4IZP4ohIWZ0?oRVVX0on=JjH3ohm/YPCoT6bU0on@
K:H4oi1^Z0CoT7:]1?nAN;@01?nCPkkoRVJRohYVX_n:IZ84oheXX`CoT6bU0onCKZH4oiEaY`?oUg>X
1OnIM:P3oiYdY`?oW7BV0_nOQ;H4oj65]@?oXhJe00?oYi:oojVA_OnYTKd00_nYTKd3ojZ@^`CoZhni
00?o]:O<okBQaOndXLD00_ndXLD4ok>L_`03ok:G_?nfZ<[o]ZS:00;o]ZS:1?nfXL@01?ndW<3o^k;A
ok^bdOnk/]44okZZb@03okZkf_ni/];o^K;B00?o^K;B0_ngZl`2okZmg0Co^KCE00?o]JkAokNifong
^M/00_ng^M/3okFdf0;o];oR1?nc^]h2ok6fg@;o/KgS1On_^^800on]^>7o[[gUojjmi@02ojjmi@;o
[;cU0_n/_nP4oj^ni`;oZ[gW00?oZ/3Yo`000?nZ`>T01?nZ_nT2ojVoj@SoZL3Z2?nY`N/00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo01kooooo
0on6]O@00on5/o?o0000o`000002ohBalP?oNK_k1?mc_od3of_2oP;oGlGl0_mFc^X2of[LhP;oY_3f
1Onof^d00oo2fnco^[SHokZhf002okZhf0;o]k7C00?oYiG3oj:=__nRSKh00_nRSKh3oif4^@CoV7fd
0onCMZl3ohi`[0?oRfbZ0on7J:P3ohEVZ0?oQ6JX1?n6IjP3ohYYZ0?oSF^V0on?K:H4oi1/Y@?oT6bV
1?n@KZP4oi1b[@;oTGRd1?n7Hj83ohYVXP?oSFRS1?n@K:D3oi=^YPCoUG6W1?nGLjP4oiUdZ0?oVWBW
00?oW7BVoif3]_nOQ;H00onOQ;H3oj65]@04oj>6]OnWT[ooYi:oojNB_`CoZI6m1?nZT;/00on[SkWo
]:O<okBWc002okBWc0?o]:750oncW;l00onf/=?o]ZS:okJXbP03okJXbP?o]Z7400?o^kgKok^bdOnk
/]400onk/]400onjZ/Wo^[_JokZkfP02okZkfP?o^K;B00?o^<KUokZmg?nj_M`00onj_M`2okVde@;o
]l7R1Ong^M/00one]=So];oRokBohP02okBohP;o/k[N0_na`NH4ok6mh`;o[k[R0_n_`>H4ojjmi@03
ojg1jOn/_nSo[;oX00?o[;oX0_n[_^L2oj_1jP?oZ/3Y00Co0000oj[0jOnZ_nWoZ[oY0_nZ`NX6ojW0
jPcoZL7[4?ooool00ol0003oooooooooo`0@ooooo`008_ooool2o`00023ooooo0ol000000on2]?Go
O[Ohogjgn002ogjgn0?oNK_k0_mc_od3ogO=o`;oJM7j0omnhOL2ojWYnP?o_=O]0_nof^d3ok^mg0?o
^[SH00?oZig9ojNE`onWUL<00_nWUL<3oj:=_P?oWHBi1?nHOK@3oi=f[`?oSW2/0on;K:X3ohMXZ0?o
QFJX1?n4IZP3ohIWZ0?oRVVX0on=JjH4ohm/YP?oT6bU0on@K:H5oi1^Z0;oT7:]00?oPf:TohERX_n5
HZ801?n7Hj83ohYVXP?oSFRS1?n@K:D3oi=^YPGoUG6W0onGLjP4oiUdZ0;oVWBW0onMPkH4oin4]P;o
XHFe00?oYI;1ojNB_onWT[l00_nWT[l4ojVA_@?oZY2k00?o/ZgCokBWc?ndYl`00ondYl`4okBQa@04
ok>L_onf/=?o][3CokJ`d`Go]ZS:00Co]Z74ok^mfonk_M_o^kgK0onk/]400onfa>Go^[_JokZkfP03
okZkfP03okVbd_nha^Go^<KU00;o^<KU0onj_M`00ondb>Wo]l7RokO1hP03okO1hP;o]kWK0_ndaNL4
okBohP03ok35jOna`NKo/L7V00?o/L7V0_na_N<2ojo3j@Co[l3V00?o[[gUojg1jOn]`NT00_n]`NT3
ojboj003oj_2jon[`N[oZl7Z00?oZl7Z0_nZ`>T00onZ`N_o0000oj[1jP04oj[1jP;oZL3Z3onY`N/@
ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo01cooooo0ol000000ooo
ooooP[Ceoh:dm@02oh:dm@;oO[Oh0_n6_oT4oh36oP;oMlgo0on;g?h3oj[OnP04ojWYn_nlengo_=O]
okcGk@;o^l7N1Onk_M`01?nj^=SoZig9oj^MbOn[WLT3ojNE``?oXXfn1?nMQ;T3oiQm]0?oTgJ_0on>
L:`3oh]/ZP?oQfRX0on5IZP4ohAVZ0?oQVNX0on:JJP3ohe[YPCoSfbV0on@K:D4oi1/YPCoT6jX00?o
T7:]oh=RY?n3HZ@00on5HZ83ohMSXP?oRVJR1?n=J:<3oi1/Y@CoTfjV1?nELJL3oiMcZ0;oVGBX0onJ
PKH4oif3]P?oWhBf00?oXi72ojFB`OnUT/400_nUT/44ojNB_`CoZI6m00CoZY2kok:]donb[M?o/ZgC
1OndYl`2okBQa@03okBhg?nf/=?o][3C00?o][3C0_nfZ<X2okK7i`Go^kgK00Co^k;AokK4iOnfa>Go
]/CU0onj^mX2ok;>kPGo^<KU00Co^[gLokC8jOndb>Wo]<SY0ong`N82ok3:k@Co]<GW00?o];oRok35
jOn`aNT00_n`aNT3ok71iP03ojk6k?n_`nWo[l?Y00?o[l?Y0_n_`>H2ojg3jPCo[L7Y00?o[;oXoj_2
jon[`^/00_n[`^/2oj_1jP;oZ/;[0onZ`N/01?l0003oZ/7[oj[1j_nZ`NX2ojW2ja;oZL7[3oooool0
0ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0Iooooo`?o00001_ooool4oh^g
l`?oQ[oi0_n0a_h3oi?Bo@03oh_Lo_nZgo[oZ]oj00;oZ]oj0onid^d00onlengo^l7Nok_1gP02ok_1
gP?o^kgL00?o[jK>oj^MbOn[WLT00_n[WLT3ojNE``CoXXfn0onMQ;T3oiQm]0?oTgJ_1?n>L:`3oh]/
ZP?oQfRX0_n5IZP4ohAVZ0?oQVNX0on:JJP3ohe[YPCoSfbV1?n@K:D3oi1/YP?oT6jX00CoPfFWoh=R
Y?n3HZCoPf:T0on5HZ83ohMSXP?oRVJR1?n=J:<4oi1/Y@?oTfjV1?nELJL2oiMcZ0?oV7nf1?nJPKH3
oif3]P03oin4]_nSTL;oXi7200;oXi720onUT/44ojNB_`?oZI6m00?o/;?Jok:]donb[M<00_nb[M<4
okBWc003ok70iOnd^=co];SL00;o];SL0onf/=<2ojo@l@Co]/OW0_nk_M/2ok3>k`Go]/CU00?o^[_J
ok;>k_nbc^h00_nbc^h2okS6i@;o[Lga1Ondb>T00ong`N;o/<[]ok3:k@02ok3:k@;o]<GW0_n]bNh4
ok35j@03ok71i_n^a^co[/K/00;o[/K/0_n_`nT2ojc5k@Go[L?Z0_n]`NT3oj_4k0;oZl;[0_nZ`n`4
oj[2j`;oZ/7[00?oZL;/o`000?nY`^/01?nY`^/2ojW1j`;oZL;[3?nY`N/00onX`N_oooooooooo`0=
ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo01Kooooo0ol0000:oooo
o`;oRkOc0_nJ_?04oiO7n0;oTm;m1?nZe?H01?nZgo[o^M;]okWBkOnid^d2ok[3h@Go^l7N00Co^kgL
ojnVc_n_Y/ko[jK>0on[WLT4ojNE``?oXXfn0_nMQ;T01?n@O[coRgVioh]i^On;NKT3ohQe]`?oQW>f
00CoSW2/oh]/Z_n;K:[oRfbZ0on7J:P3ohEVZ0?oQ6JX1?n6IjP3ohYYZ0?oSF^V0on?K:H4oi1/Y@?o
T6bV00CoT6jXog=KZ?mcFjSoLe^X0on3HZ@3ohERXP?oQf>R0on:IZ84oheXX`CoT6bU0onCKZH2oiEa
Y`CoUWff1?nHOkH3oiZ1]P;oWH>f00?oXI33oj>A`_nSTL800onSTL83ojFB`@CoYi:o00?oZI6mok2c
f_n`/mX00_n`/mX4ok:]d`03okBWc?na`>Go/L3U00;o/L3U1?nd^=`00onf/=?o[m3aojo@l@02ojo@
l@;o]/OW0_nVdoL4ok3>k`;o]/CU1?nXdoH2ok;>kP;oYM7g1?n]cO42okC8j@?oZ/kc0_n`b^d2ojS<
lPGo[LW^0_n`aNT3oj_9k`;o[/K/0_nZanl4ojc5k@;o[L?Z0_nZaNd4oj_4k003ojW4kOnZ`ncoZ/?/
00?oZ/?/0_nZ`^/2ojW3k0?oZL;/00?o0000ojW2jonY`^/00_nY`^`5ojW2j`OoZL7[1_nX`N/>oooo
o`03o`000?oooooooooo013ooooo000Rooooo`;o00005?ooool3o`0000kooooo1?nJ_?02oiO7n0Co
ZL[a0_nZe?H3okO=j`03okWBkOnj`n7o^/?Q00;o^/?Q0_nk`Mh2ok:]d`Co[jK>1?n[WLT2ojNE``04
oiZ<a?nEQKooUHFooiF5_`CoT7jl0_n;NKT3ohQe]`CoQW>f0on4L[L3oh=d^P?oPGNo0on4IZP4ohIW
Z0?oRVVX0on=JjH3ohm/YPCoT6bU0_n@K:H2ogMHX@?oLe^X0_m_IKH01?n3HZCoQF:RohERX_n5HZ84
ohMSXP?oRVJR0on=J:<4oi1/Y@;oTfjV00CoU7jhoiAm]onDOKOoU7fg0onFOKH4oiQo]P;oVX6f00?o
WXk3oj6@`onQT<<00_nQT<<4oj>A`PCoYI;10_nWT[l2ojjgg`Go/;?J0_nb[M<2ojg7k@Co/L3U0_nd
^=`3ojKFn0;o[m3a0onMeo`4ojKCm`;o/<k_0onNeO/2ojSCmP;oWM;j1OnUdOL2ojg=l@?oX/og0_nZ
c_<2oj?=mPCoZ<cb0_n]bNh3ojO:lP;oZlW_0_nWb?45oj[7k`;o[<G]0_nYa^l4oj[5k@03oj_4k?nY
a>goZLC]00;oZLC]0_nZ`n`2ojW4k@GoZL?/0onY`^`00ol0003oZL;/ojW2k002ojW2k0;oZL;[0_nY
`^`4ojW1j`[oZ<7[3Oooool00ol0003oooooooooo`0@ooooo`008Oooool2o`0001;ooooo0ol0000B
ooooo`;oV[c`0_nX`>/4ojW:l@;o]<SX0ongcN/2ok[4hP?o^/?Q00?o]K?Gok:]donb[M<00onb[M<4
ojnVcP;oZig900?oWiC8oiZ<a?nJS<@00_nJS<@3oiF5_`?oT7jl0on;NKT3ohQe]`?oQW>f1?n4L[L3
oh=d^P;oPGNo0omlO/X3ogB;g004ohIWZ?n:JJSoRVVXohYYZ0?oSF^V0on?K:H2oi1/Y@03oh=OX?ml
FIooO5VO00?oMeRQ0omcFjP3ofmU]P?oQF:R1?n7Hj83ohYVXP?oSFRS0_n@K:D2oiJ2^`?oU7jh0onD
OKL2oiIm]P03oiR8`?nKRl;oVh_200;oVh_21?nNS/<3oj6@``GoXi720_nUT/42ojbji0Co[[OO0_n`
/mX2ojW=l`Go[LO]0_na`>D3oikIo0;oY]Kh0onGf?h4oigGo0;oY]?g0onGe?d2oikEn`?oV=7l0onM
d_X2ojGAm`?oWLoi0_nRcoL2oio<m`GoXlgf0_nXc?83oj?;m0;oYl[b0_nUb?84ojO8l@;oZ/O_0_nW
ao05ojW6k`;oZ/G]0onXaNh2ojW4k@;oZ<C^1?nYa>d2ojW3k0;oZ<?]0onY`^`01?l0003oZL;/ojW2
k?nY`^`2ojS2k0CoZL;/00?oZL7[ojS1jonX`N/02onX`N/<ooooo`03o`000?oooooooooo013ooooo
0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo00oooooo0_l0000Fooooo`CoZ<3[00?oZL[aokC8j?ndb>P0
0ondb>P00ongcN_o^/CRok[4hP02ok[4hP04ok[3hOne/mOo]K?GokFce`Go/ZgC0_n_Y/h00onUW<go
WiC8oinDb002oinDb0?oVXc40onEQKl3oi1n_0?oRgVi0on8MKL3ohIc]PCoQ7:g0on3M;X3oh5g_`?o
O7k:1?mdRm`4of>Ql`;oAKKf00?oS6RToh=OX?n3Gj000_n3Gj03ogaIW`;oMeRQ1?mcFjP2ofmU]P?o
JH7H1?n7Hj83ohYVXP;oSFRS00?oVh[0oiJ2^onFP[/00_nFP[/2oiAn^004oi:1_OnEQ;ooUHBooiF4
_`CoV8S01?nKRl83oij>``CoXI330_nSTL82ojVkiPGo[;[T0_n^]ml2ojK@mPCoZLgc0_n]and4oiWJ
oP;oW]Wl0onCf?h2oiOHoPKoU=?m0_nGe?d3oiO@o0;oV=7l0_nJc?T5oi[=nP;oWLoi0_nMboL4oio<
m`;oXlgf0onQb_D2oj?;m0;oX/Sc1OnUb?82ojO8l@;oYLOa1?nWao02ojW6k`;oYlG_1?nXaNh00onW
a>koZ<C^ojS4kP03ojS4kP;oZLC]1_nX`nd2ojW2k003ojS2k?l0003oZ<;/00CoZ<;/0_nY`^`2ojS1
k0_oZ<7[0_nX`>/=ooooo`03o`000?oooooooooo00oooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<oooo
o`?o00006Oooool2ojS0j`Co/l;V0_ndb>P2okW4h`?o^/CR00?o][WKokFceone/mL00one/mL2ok:]
d`;oZJCB1?nUW<d3oinDb0?oVXc40onEQKl4oi1n_0;oRgVi0on8MKL4ohIc]P?oQ7:g0on3M;X3oh5g
_`?oO7k:1OmdRm`2of>Ql`;oNVB^0on<J:@3oh=OX0?oO5VO0omgF:43og=KZ0?oKfFf1?mYPMP00ol[
YncoUH_7oi22`@02oi22`@OoSgjm1?nBPKd3oiF4_`?oV8S01?nKRl84oij>``;oXI330_nW^^L4ojVk
iP;o[;[T0onTdoP4ojK@mP;oZLgc0onFfoh2oiWJoP?oU=Sn0_nCf?h3oiOBo0KoU=?m0onHc_/2oiO@
o0;oVl[h1?nJc?T2oi[=nP;oW<Wg1OnMboL2oio<m`?oWlSe0_nQb_D2oj77l`CoX/Sc0_nUb?82ojC6
lPGoYLOa0_nWao02ojK5l0CoYlG_00?oZ<G^ojO4k_nWa>h00_nWa>h2ojS4kP;oYl?^1onX`nd2ojS2
k@?oZ<;/00?o0000ojS2k?nX`^`00_nX`^`5ojS1k0WoZ<7[1?nX`>/<ooooo`03o`000?oooooooooo
00oooooo0007ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo0_l0000:oooo
o`?o00007Oooool4ok?2iP;o^<?S1?nia><01?nja>;o][WKokJifonf^M/3okFce`03ojf/eonYY=;o
ZJCB00?oZJCB0onUW<d3oinDb0CoVXc40onEQKl3oi1n_0?oRgVi0on8MKL3ohIc]PCoQ7:g0on3M;X3
oh5g_`?oO7k:0_mdRm`3oh5//P?oNVB^0_mfHJd01?n<J:CoPenPoh=OX?n3Gj03ogaIW`?oMeRQ0omc
FjP4ofmU]P;oJH7H1?nERlL3oi22`@KoSgjm1?nBPKd3oiF4_`?oV8S01OnKRl82oij>``03ojFhi_nW
^^OoYk[W00?oYk[W0_nY^nH2oj?Dn@GoY=?h0_nVd?H3oiKLoP;oU]_n0onFf?h2oiCHoP?oV]7k0_nG
d_`2oig<n0CoV/gi0_nHc_/2oig9mPGoVl[h0_nJc?T3oig8m@?oW<Wg0_nMboL3oio7m0;oWlSe0_nQ
aO85oj77l`;oX/Sc0_nSaO44ojC6lP;oYLOa0_nUaO05ojK5l0;oYlG_0onVa>l2ojO4kPKoYl?^1?nX
`nd5ojS2k@;oZ<;/00?o0000ojS2k?nX`^`00onX`^`5ojS1k0WoZ<7[1?nX`>/;ooooo`03o`000?oo
oooooooo00oooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMoooo
ool00006ooooo`03o`000?oooooooooo00Kooooo0ol0000Qooooo`03ok?2i_nh`n?o^<?S00?o^<?S
0_nia><2okNng`Co][WK00Co]K?Gojf/eon][=Oo[JcG1?nYY=84ojFLc@?oWiC80_nJS<@01?n@S/go
RXW=ohZ9cOn:RLd3ohF8c`?oOhWC0on8MKL3ohIc]PCoQ7:g0on3M;X2oh5g_`?oWHk31?n>NkT2oh5/
/P?oNVB^0omfHJd3oh=OX0?oO5VO0omgF:44og=KZ0;oKfFf0_n;k>`2oj6NdP?oUH_70on@P/47ohmn
_@?oTX6m0onEQ;l4oiR8`0;oVh_20_nS/n@4ojFhiP?oYk[W1_nSe?T2ojCCn0?oUmgn0_nFg?h3oiSI
o@;oU]Sn1?nLd?X2oi[An`;oWl_g1?nMc?P2oi[=n@?oWlOd0onMbOH2oi_:n0CoWlKd0_nMb?D2oj74
lPCoX<Gc0_nOao@2oj74l@CoXLGb0_nQao<2oj;4l@GoXlGa0_nTa_82ojC4l0CoYLG`0_nVaO05ojK4
k`;oY/?^1onW`nh2ojO3k@CoZ<?]0_nX`^d5ojS2k004o`000?nX`^coZ<;/ojS2k0OoZ<7/1_nX`N/7
ojS0j`[ooooo00?o0000ooooooooool03oooool000Oooooo00Go0000ooooooooooooooooo`00000;
ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool00oooool3o`0002Kooooo1Onh
`n<4okNng`;o][WK0_n`]=/3ojf/e`GoZJCB0_nUW<d01?nJV];oUI??oiFCconETll4oi2>c@?oRXW=
0on5R<l2ogn9d`CoNi3L0omgW^X5ofjdnP03odg4l_n/Xlko[:?>00CoWHk30on>NkT2oh5//P?oNVB^
0omfHJd3ogQU/0?oO5VO0omgF:44og=KZ003ofmU]_n;k>coRnc/00?oXIkB0onERlL3oi22`@OoSgjm
1?nBPKd3oiF4_`;oV8S000?oWjcPoj>ci?nS/n@00onS/n@4ojFhiP03ojNjionSe?WoXmCi00CoXmCi
0onIg_h2oiOMoP?oVmWm0_nHfOd3oio@n@;oW=3j0_nQboD5oio;m`;oWLch0onQa_<2oio7m0;oXlCa
1?nQaO82oio6m0;oXl?`1OnQa?82oj35l`;oX/?`1?nQa?42oj75lP;oXl?`1?nRa?42oj?5l@OoY<C`
0_nUaO03ojG3k`;oY/C_1_nV`nh2ojO3kP;oYl;]1OnW`nd2ojS3k@;oYl;]1_nX`^`00onX`Nco0000
ojS1k009ojS1k0?oZ<7[2OnX`>/:ooooo`03o`000?oooooooooo00oooooo0007ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00omgMgOoc<c<o`000005ooooo`04o`000?ooooooooooooooo`?o
0000:_ooool5okS3h`;o]kkO00?o/[_Qok2dfon`]=/00on`]=/3ojf/e`;oZJCB0_nOXMH4oiZJdP?o
UI??0on@S/d3ohZ9c@?oQHS?0omoRM<4og^@g0?oMikZ0_m^]?X3okZif0?o[:?>0onMS/<3ohik^@?o
PFbb0_mjI:h3ogIQ[@?oN6F`0on0LKT3ogMHX@;oLe^X0onO_>d2ok:nh`?oXIkB1?nERlL3oi22`@Ko
Sgjm1?nBPKd2oiF4_`03oi^SfonO[>3oWjcP00;oWjcP1?nS/n@2ojFhiPCoY=?h0_nSe?T3oicNo@;o
VMkn0onMfO`2oi_Io@?oXM3h0_nOd?T2oj?:m0CoXL_e0_nOboL3oj?6lP;oXLKc0_nTa?05oj?4l@;o
XLGb0_nT`nl4oj?3l0;oXLCb0_nS`^l5oj;3l0;oXLCa0_nS`^l4oj?3l0;oX/Ca0_nT`nl6ojC4l0Go
YL?_0_nU`^h7ojK3kP;oY/;]1?nW`^d2ojO3k@OoYl;]0_nX`^`2ojO1k0?oZ<7/00?o0000ojS1k?nX
`N`01onX`N`4ojS1j`WoZ<3[2Oooool00ol0003oooooooooo`0?ooooo`001oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001Oooool4o`0002kooooo0onh`n<00onc`^Go
/[_Qok:kh@02ok:kh@?o/;CK00CoYk7OojBYf_nTZM[oY:WJ1OnOXMH3oiZJdP?oUI??1?n@S/d3ohZ9
c@?oQHS?0omoRM<2og^@g0;o?L3K1?o1bn82okZif004oib;`?nAO;WoTGbioi5l^@?oQ72d0omjJK<3
oh5//P?oNVB^0omfHJd3ogQU/0;oP76i1?n;R/d3oinlk@?oT8G30on:O/04ohMm`@?oR8340on<QlP3
oi6@c`CoUY[E1?nKXm/4oin/h0;oXk?T0onTd?L2ojCCn0?oW]om0_nLg_d3oioJo0;oWMWl1?nSd?L2
oj7@n0;oY<[c1?nSb_@2oj7;m@?oY<Ga0_nSa_82ojG3k`CoY<C`0_nSa?42ojG2kPGoY<?_0_nS`o02
ojC2kPCoXl;_0_nR`o02ojC2kPGoXl;_0_nS`o02ojC2kPCoY<?_0_nTa?03ojG2kP;oYL?_1_nU`^h2
ojK3kPOoY/;]2_nW`^d7ojO1k0;oZ<7/00?o0000ojO1k?nX`N`02?nX`N`2ojS1j`[oZ<3[2Oooool0
0ol0003oooooooooo`0?ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMg
o`000?ooool01?ooool2o`00037ooooo00Co^<?Sok?2iOnc`^Go/l;U1?nb^n401?n`]=_oYk7OojNa
gonW/Ml3ojBYfPGoWj7F0onJV]83oiFCc`;oT8k=00?oQjKYoh6/l?n1[?000_n1[?04ogZgn@;oJ<Kn
00CoZ?STolCHj?o4f>Soa=SX0_o1bn800onWVLSoW8_0oib;`002oib;`0?oTGbi0_n4L;@3ogYY/`;o
KVBg00CoPFbbogYT[_mjI:koNVB^0omfHJd3ogQU/0?oP76i1?n;R/d00onO_>goWIC:oifDbP03oi25
``?oRWk00on7OL44ohR0a0?oS8O80onAT<l4oiJJe@CoVj?K0_nO[>03ojC;m0;oY=3g0onPgo`2oikO
o@?oX]_k0_nOf_`3ojC@m`;oXm3g0_nUb_<5ojC:l`;oXl[d0onUaO02ojC5l@;oY/?^1?nU`nl2ojC4
l0;oY/;^1?nU`^h2ojC3k`;oYL7]1OnT`^h2oj?2k`;oYL7]1?nT`^h2oj?2k`?oYL7^1?nT`^h2ojC3
k`GoYL;^00?oYL7]ojG2k_nU`^h01OnU`^h2ojK1k@KoY/;]0_nV`Nd7ojO2k@goYl7/00?o0000ojO1
k?nX`N`01OnX`N`?ojS0j`Sooooo00?o0000ooooooooool03oooool002;ooooo00?o0000oooooooo
ool0;oooool4ok?2i@;o/[_Q0_nY^N@4ojNag`?oY:WJ0_nOXMH2oiFYi0CoTJKT0on<Y>D3ohNVj@Co
PJc`0_mj]oT3ojShi0?oa=SX00?o/:WAojNIb?nWVLP00_nWVLP3oib;`0?oTGbi0on4L;@2ogYY/`?o
KVBg0omjI:h3ogIQ[@?oN6F`0on0LKT3oh^:c@04ojn]e_nMU<[oWIC:oifDbP?oT8G30on:O/04ohMm
`@?oR8340on<QlP4oi6@c`?oUY[E0_nKXm/4oj?4l0;oY<_d0onRgo`2oj3Oo0?oY=ck0_nRfo/3ojKA
m`;oY=3g0_nVb_84ojG:l`;oY<[c0onVaNl2ojG5l0OoY/?^0_nU`nl2ojK1k@CoY/;^0_nU`^h2ojK1
k@CoYL7]0_nT`^h2ojK1k@GoYL7]0_nT`^h3ojG1k@;oYL7^0_nV`Nd4ojG1k@;oYL;^0_nV`Nd4ojG1
k@;oYL;^1onV`Nd2ojK2k@KoY/7]0_nW`^dBojO1k004o`000?nW`NcoZ<7/ojS1k0;oYl3[1_nX`>/2
ojO0j`OoZ<3[00?oYl3[ooooooooool01oooool00ol0003oooooooooo`0>ooooo`008oooool00ol0
003oooooooooo`0_ooooo`;o/l;U0_n[`NT4ojVii0;oYk7O00?oWK?XoiZ^iOnJ[^D00onJ[^D3oiFY
i0CoTJKT0on<Y>D3ohNVj@;oPJc`00?oALKIoiodk?nOm>`01?o1g^h01?o4f>So/:WAok2YdOn`ZM43
ojNIb0?oW8_00onAO;T3ohA`]0?oNVVc0_m^I;L3of9]b0CoMV6]0omhIK03oh1a^@04oh^:cOn_[MKo
[jgFojn]eP?oWIC:0_n@QL<3ohYn`0CoQgg10on8P<@4ohb7b0;oTI3?0_nM[nD4oj6kj`;oXlC`0onT
g_/2oj;Oo0CoYMgk0_nTg?/3ojOBm`;oY]7g0_nWbo84ojK:lP;oYL[c1OnVaNl2ojO2k@KoY/?^1onV
`Nd2ojK2kP;oY/7/1?nV`Nd2ojG1k@;oY/7/1?nV`Nd2ojG1k@?oY/7]0_nU`Nd2ojK1k0GoY/7]0_nU
`Nd2ojK1k0CoY/7]0_nU`Nd8ojK1k@;oY/7/1onV`NdEojO1k003o`000?nW`>coYl3[00CoYl3[0_nX
`>/6ojO0j`;oZ<3[1_nW`>/8ooooo`03o`000?oooooooooo00kooooo000Tooooo`03o`000?oooooo
oooo02oooooo1?n[`NT2ojVii0;oWkW[0onM/nP5oiZ^i@?oUJWT0_nAY^@2ohC3o0CoN<[o0_mVd?T0
1?mchNGo_>3aokcPlOnlh?42ol7NkP;o]KKI1?n`ZM43ojNIb0CoW8_00onAO;T2ohA`]0?oNVVc0om^
I;L2of9]b0?oBHo]00CoMV6]ogQU/?mhIK3oN6F`0_n0LKT2olG>h@;o[jgF00CoTi7>ohb7bOn<QlWo
S8O90on8PlL3ohYn`0?oQgg11?n8P<@2ohb7b003oiRSgOnM[nGoWJoU00?oWJoU0_nQ^n/3ojGKnP;o
Y=kk0onWg_X2ojGMn`?oZ=Cg0_nWd_L2ojS<lPGoYl_b0_nVb_83ojO5k`;oY/G_1_nW`^d2ojK3kP;o
Yl7/1_nV`Nd2ojO1k0GoY/7/0_nV`Nd2ojO1k0CoY/7/0_nV`Nd3ojK0k0;oY/7]0_nV`>`4ojK1k0;o
Y/7]0_nV`>`5ojK1k0;oY/7]0_nV`N`6ojK1k@KoY/7/0_nV`NdFojO1k0CoYl3/00?o0000ojO0k?nW
`>/05?nW`>/7ooooo`03o`000?oooooooooo00kooooo000Uooooo`;o0000<?ooool2oj_1j@;oXKk^
1?nO^N/3oifcj0;oVZkU0onA_?@4oh^nn0?oQ<?l0_mhb_l2oh3Qn@05oig_m_nlh?7o_>3aokcPlOnh
_ml01One]]T4ok2Yd@?oYiW80onLRl03oi5l^@?oQ72d0_mjJK<3ofiT]`?oHVg81?m9Snd2om7_i`;o
aLkQ0_nRY=H4oi>AcP?oS8O90_n8PlL3ohR5bP?oS8g>1?nAUmD4oiRSg@?oWJoU0_nTeOT3ojGKnP?o
Z=kj0_nWg_X3oj[Fm`;oZ=Cg0_nYcO<4ojS<lP;oYl_b1OnWaNl2ojO3k@OoYl;]1_nW`N`2ojK1k@Ko
Yl7/0_nV`N`2ojO0k0GoYl7/0_nV`N`3ojO0k0;oY/3/0_nW`>`4ojK0k0;oY/7/0_nW`>`4ojK0k0;o
Y/7/0_nW`>`5ojK1k0;oY/7]00?oYl3/ojK1k?nV`N`01OnV`N`EojO1k0WoYl3/00?o0000ojO0jonW
`>/05?nW`>/6ooooo`03o`000?oooooooooo00kooooo000Wooooo`03o`000?oooooooooo02kooooo
1?nQ_^h2oinij`?oUk_a0onD^o84oi6lm0;oRkkh0on>d?h2ohWIo`;oW>Ol0onfgO@01?nlh?7o^;oO
okRogonh_ml5okFff@;o/:WA00CoW9S>oi>=bOnCSLWoThg90on7P/L3oh1laP?oNGc:0omjJK<3ofiT
]`?oHVg800GoBHo]om7_iooAknOodNoWok:lh@05oj:TeP?oTi7>0on<QlT3ohR3a`?oR8G:0on<SLh4
oi6Ge@CoV:?M00?oWJoUojCEnOnTeOT00_nTeOT01?nUfo[oZ=kjojSNn_nXg_X3oj_Hm`;oZ]Kg0_nZ
c_<4ojW=l`;oZ<cb0onXa^l2ojO5k`KoYl?]0_nW`^dAojO1k0KoYl3/0_nW`N`<ojO0k0;oY/3/1_nW
`>`2ojK0k0KoYl3/0_nV`N`6ojO0k0;oY/7/0_nW`>`7ojO1k0;oYl3/1_nW`N`3ojO0k0;oYl7/2?nW
`>`5ojO0j`03o`000?nW`>_oYl3[01?oYl3[1_ooool00ol0003oooooooooo`0>ooooo`00:?ooool0
0ol0003oooooooooo`0^ooooo`;oXKk^0onI_?04oiNkl@?oU;_b0_nA_?@3oi;9nP;oS]3n0onLgOd0
1?nLioco]]gdokKMm?nfgO@2okO5i@Co^;oO0_ne]]T2ojFSd`CoW9S>0onCSLT3ohN2a`?oP7c60_mi
O<X3ogZ9eP;oKVBg0on5Znh01?n9h__obOgRol7Dj?o1e>P3ok:lh@CoXZCF0onCTLh3ohb7b@?oR8?7
0on8QLX4ohb=cP;oTIOE0_nM_o05oj;<mP;oY=Gi0_nYgOT00on/f_OoZmSgoj_Hm`02oj_Hm`;oZm3d
1?nZc_<2ojW=l`?oZ<O_0_nXa^l2ojS3k@KoYl?]4OnW`N`=ojO0k0;oYl3[1_nW`>`2ojO0jagoYl3/
0_nW`N`7ojO0k0;oYl7/3OnW`>`8ojO0j`03o`000?nW`>_oYl3[01CoYl3[1Oooool00ol0003ooooo
ooooo`0>ooooo`00:Oooool00ol0003oooooooooo`0_ooooo`CoVKc`0_nG^o42oiNol`CoU<?g0_nB
bOX3oicDn`;oW=gm0on`f?@00onfgOCo]lGUokO5i@02okO5i@;o^;oO00?oZjcHojFSdonUXm<00onU
Xm<3oibHcP?oThg90on7P/L3oh1laP?oNGc:0omjRMH3ohF[kP;obOgR1?o1e>P3ok:lh@;oXZCF00Go
Shk>ohN8cOn7R<goQhS=oi>AcP03ohb7b@?oR8?70on8QLX2ohb=cP;oUk3Y1?nM_o02oj;<mP?oZM[i
00?oZMgiojcJmon/f_L00_n/f_L00on[f?OoZm3doj_@m003oj_@m0;oZ/kc0onYb>l2ojS7k`;oZ<C]
1?nX`nd2ojO3kA3oYl7/0_nW`>/7ojO0k0?oYl3[0_nW`>`6ojO0j`;oYl3/1_nW`>/2ojO0k0;oYl3[
;?nW`>`=ojO0j`03o`000?nW`>_oYl3[01CoYl3[1?ooool00ol0003oooooooooo`0>ooooo`00:_oo
ool2o`00037ooooo1?nI_?03oiNol`;oU<?g0onLboP2oicDn`?o[=;d0_n`f?@3okK8j0;o]lGU00?o
[kCLoj^/f?n[[=P00_n[[=P4ojFSd`CoW9S>0onCSLT2ohN2a`?oP7c60omiO<X4ogZ9eP03ohF[k_nf
o=Wob>S]00;ob>S]0_o1e>P01?nWZ=OoVISAoiVHdOnIV=44ohn>cP?oQhS=0on6Rm43ohVCe`CoSZ3P
1?nG/>T2oifol0?oYm?g0_nYf_T3ojgKm`;o[=[g0on/do@2oj_@m0;oZ/W`1?nYb>l00onXa>koZ<C]
ojS4k@03ojS4k@;oZ<?]0_nX`N`>ojO1k0KoYl3[0_nW`>`LojO0j`;oYl3/0_nW`>/6ojO0k0;oYl3[
5?nW`>`2ojO0j`KoYl3/4OnW`>/00ol0003oYl3[ojO0j`0DojO0j`?ooooo00?o0000ooooooooool0
3_ooool002cooooo00?o0000ooooooooool0;oooool2oiVll0;oW[g^1?nMa?<2oic;n0?oZL_b0_n/
d_@2ok;8jP?o]/SX00?o/K[Pojndg?n_]=`00_n_]=`4oj^/f0;oYJ?C00?oVI[Coi2Cdon@Tm<00_n@
Tm<3ohR@e@?oO97M0on0O<H3ogUlbP;oNXWF00?oV?;TokKlfOo8j>d00_o8j>d00ond^mooYjSGojNX
e`02ojNXe`?oVISA0on?S/h4ohN8c@?oQX_A0on9TmL4ohjPh0;oUk3Y0onTb_@2ojOCm`Go[M_g0on]
eOD2ojcCm0;oZl_`1?nZbO000onYb>ooZ<C^ojS4kP02ojS4kP;oZ<C]0_nX`^`5ojS1k0[oYl7/;?nW
`>/2ojO0k0KoYl3[0_nW`>`2ojO0j`KoYl3/0onW`>/2ojO0k0OoYl3[0_nW`>`EojO0j`03o`000?nW
`>_oYl3[01CoYl3[0oooool00ol0003oooooooooo`0=ooooo`00;Oooool00ol0003oooooooooo`0_
ooooo`CoW[g^0_nMa?<2ojO5k`?oZL_b0_n`a^/4ok;8jP04okK8j?na^^3o/K[Pok6jh0Co[kCL0_n[
[=P00onPXMKoVI[CoiVJd`02oiVJd`?oT9?C1?n8T=D3ogbAg@CoMJ;^00?oIL;noiSbi?nHl^@00oo4
l?001?o8j>go];_OokBkgond^ml4ojNXe`?oVISA0on?S/h3ohN8c@?oQX_A1?n9TmL2ohjPh0?oWKc^
0_nTb_@3oj_Hm`;o[M_g0on^eoD2ojgEm@;o[<ga1?n[bo02oj[9l0?oZLG^0_nXa>h6ojS2k0;oZ<7/
2?nW`N`mojO0j`;oYl3/9_nW`>/00ol0003oYl3[ojO0j`0DojO0j`?ooooo00?o0000ooooooooool0
3Oooool002kooooo00?o0000ooooooooool0;oooool2oijmkP;oY/3/1?nWaNl00onYbo;o/<K[ok36
j`02ok36j`;o//SZ0_na_N<4ok6jh0;o[kCL00?oYZWIoj2Qe_nPXMH00_nPXMH3oiVJd`CoT9?C0on8
T=D4ogbAg@;oMJ;^0_nDhod01?nNmN3oa?3`olC`l?o4l?02okg<iPCo];_O0_nWZ=L01?nHW=OoSiCD
ohnDe?n?U=@3oh^CeP?oRiKI1?n?X=l4oiJ^i`?oWKc^0_nWd_H3oj_Hm`;o[]Of0on^eoD2ojg@lPCo
[<ga0_n[bo03oj[6kP;oZLG^0_nX`nd6ojS2k0;oZ<7/1_nW`NaYojO0j`03o`000?nW`>_oYl3[01Co
Yl3[0_ooool00ol0003oooooooooo`0=ooooo`00;oooool00ol0003oooooooooo`0_ooooo`CoY/3/
0_nWaNl3ojk4jP;o/<K[0_na`>D4ok6mh`;o/K[P0_nZ/=`3ojJYf@CoX:7F0onIV]<3oi2Cd`;oR93E
0_n=/_04oho6nP;oV>ob0_nmlO<2ol7Jk0Co_LcV0_nd^ml00onQYm_oV9cGoiRLe`02oiRLe`?oSiCD
0on;TmH3oh^Ff@CoSj3O1?nF[^L00onM_>koYm;fojOBmP02ojOBmP03oj_Hmon^eoKo[]Of00;o[]Of
00?o[]Oeojg@l_n]d?800_n]d?82ojc=l@?oZlS_0_nZa^h2ojW3k@CoZ<?]0_nX`^`6ojS1k0;oYl7/
KOnW`>/00ol0003oYl3[ojO0j`0CojO0j`;ooooo00?o0000ooooooooool03Oooool0033ooooo0_l0
000`ooooo`;oY/3/0_n/`NT3ojk4jP;o/<7W1?na`>D2ok6mh`;o[;GO1?nZ/=`3ojJYf@;oX:7F00?o
V:SQoi>Vh_nCY^800_nCY^83ohfXi`CoSK;`00CoSlKjoiS_l_nHko;oV>ob0_nmlO<4ol7Jk0;o_LcV
0_n/]Ml3oj6Wf`?oV9cG0on?U=@3oh^CePCoRiKI0_n?X=l2oiZll0CoX/Wd0_nWd_H3ojgFmP;o[]Of
0on^d_<2ojg@lP?o[<[`0_n[b>l2ojW4k@GoZL?]0_nX`nd8ojS1k73oYl3[00?o0000ojO0jonW`>/0
5?nW`>/00ooooooo0000ooooo`0>ooooo`00<_ooool00ol0003oooooooooo`0^ooooo`Co[<7Y00?o
[/CZok31ion``NL00_n``NL2ok70i@;o[[[S1?n/]Ml2ojZ`g003oj:`h_nN[>7oWZcQ00;oWZcQ0onH
Z>44oi>VhP?oSJSW0_n=/_02oi;PoP?o/>[h0onlh?42ol7Jk0;o/l7T1?n/]Ml3oj6Wf`?oV9cG0on?
U=@3oh^CeP;oRiKI0_nD[nT4oiZll0;oX/Wd0onZd_D2ojgFmP?o[m?c0_n^d_<3ojg<l0;o[<[`0_nZ
a^h4ojW4k@;oZL?]0_nX`^`7ojS1k7CoYl3[00?o0000ojO0jonW`>/04onW`>/00ooooooo0000oooo
o`0>ooooo`00<oooool00ol0003oooooooooo`0^ooooo`;o[<7Y0on_`^P2ok31i`;o[[kU1?n^^^<2
ojbeg`03ojJehonR/>;oX[3R00;oX[3R1?nN[>43oiRXh@;oTjKR0onC`OH2oi7>o@?oZ=oj00?o/>[h
okcPlOnlh?400_nlh?400ongb^Wo/l7Tok?1i003ok?1i0;o[;GO00CoWjKKoiJOf_nFWm[oUYoJ0onA
W=X4ohfLg@?oSZ?S1?nD[nT2oiZll0?oYL_c0_nZd_D3ojkCm0;o[m?c0_n^c_43ojg<l0;oZlO^1?nZ
a^h2ojW4k@KoZ<;/1?nX`NagojO0j`03o`000?nW`>_oYl3[01?oYl3[00?o0000ooooooooool03Ooo
ool003Cooooo00?o0000ooooooooool0;_ooool3ojo2j0;o[/7X1?n^_^D2ojjjh`;oZ;WU0onV]N<4
oj:`hP;oWZcQ0_nJ]^`4oiFil0;oTl7f0onQe?X2ojSOnP?o]^3e00?o_>3aokO:jOngb^T00_ngb^T2
ok?1i0;oYZoN1?nOY]/3oiJOfP?oTIcJ1?n=W=d3ohjSh`;oU:oY0onO`O02ojG;l`?oZm7d0_n^do@2
ojk@lPCo[/ka00?o[Lc`oj_7k_n[anh00_n[anh2oj[6kP;oZL?]1_nX`^`6ojS1k7OoYl3[00?o0000
ojO0jonW`>/04OnW`>/00ooooooo0000ooooo`0>ooooo`00=Oooool2o`0002oooooo00?o[l;Xojk1
j?n^`NP00_n^`NP2ojjni@;oZ[gW1?nX^ND3ojJeh`;oX[3R0_nN]^T4oiZfk0;oUKW`0_nNb_L3oj7D
nP?o[M_g0_nfh?D3okO@k@;o]l[Y00?o[KSQojJ_g_nV[mh00onV[mh3oinVf`CoUYoJ0onAW=X2ohfL
g@;oU:gW1?nI]^`2oio1l0;oYlgc0on[dO@2ojg@lPCo[]3b0_n^c_43ojc9k`;oZlO^0_nZa>d4ojW3
k@;oZ<;/2?nX`NahojO0j`03o`000?nW`>_oYl3[00goYl3[1_ooool00ol0003oooooooooo`0<oooo
o`00=oooool00ol0003oooooooooo`0^ooooo`;o[/7X0_nZ`NX4ojZmi`;oZ;WU0_nT^^T3oj6hj@Co
W[KY0_nJ]^`2oig4l`CoW/[g00CoXMCjojgKmon]foOo[M_g0_ncdO03okO@k@;o/;oU0on]^>44ojJ_
gP;oWjKK00?oVJOOoiBTh?nDY>000_nDY>03oi>Wh`GoU:gW0_nI]^`2oj;6lPCoYlgc00?oZm7dojg@
l_n]d?800_n]d?82ojk@lP?o[L_`0_n/bNl2oj_6kPCoZ/C]0_nY`nd3ojS2k0GoZ<7/0onX`>]iojO0
j`03o`000?nW`>_oYl3[00WoYl3[2Oooool00ol0003oooooooooo`0<ooooo`00>?ooool00ol0003o
ooooooooo`0^ooooo`CoZ/7Z0_nZ_NL2ojFmjPCoY;[Y0onQ^>T2oijfj@;oW/3`1?nMa?<2oik:m`;o
YmGg0_n_d?44ok?Al003okO@kOn`_nGo/;oU00;o/;oU0on]^>42ojJ_gP;oWZ_O0onIYml4oiBTh0?o
TjOS0_nD[NL2oifmk`GoX/Kb0_nWcO<3oj_?l`;o[M3b0on]cO02ojg;l003oj_7k_n[a^koZlK^00?o
ZlK^0_nZa>d3ojW3k0;oZ<;/00?oZ<7/ojS1jonX`N/00onX`N/2ojS0jg_oYl3[00?o0000ojO0jonW
`>/01OnW`>/<ooooo`03o`000?oooooooooo00cooooo000iooooo`03o`000?oooooooooo02kooooo
0_nZ`NX2ojJok0CoYKgZ0_nT^^T2oj6nk@CoX;k^0onN`?02oig4l`?oXlkf00?oYmGgojo@lOn_d?40
0_n_d?42ok?Al0?o/LCX0_n`_nD00onY]n?oY;7QojBah@02ojBah@CoWZ_O0onIYml2oiBTh0;oUjoX
0onI]N`4oifmk`;oX/Kb0onXbo82oj_?l`?o[Lga0_n]cO02ojc9k`CoZlO^0_n[a^h5ojW3k0KoZ<7/
0_nX`N/2ojS0jgkoYl3[00?o0000ojO0jonW`>/04?ooool00ol0003oooooooooo`0<ooooo`00>_oo
ool2o`0002oooooo1?nV_n`2ojFmjP;oX[k]1?nQ_^d2oj2nkP;oXLGb1?nQb?@2oj?>mP?oZlgb0_n_
d?43ok37j`;o/LCX0_n/^nD3ojVgh`CoY;7Q0_nNZml00onK[N?oV:gUoiR]i@02oiR]i@CoUjoX0onI
]N`2oifmk`?oY<Ka0_nXbo82oj_=l@?o[Lga0_n/b^l4ojc9k`;oZlO^0onZaNd2ojW3k0;oZL;/1_nX
`N`2ojS1j`CoZ<3[OOnW`>/00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo000l
ooooo`03o`000?oooooooooo02gooooo0_nV_n`2oj>ok@CoX[k]0_nQ_^d2oj72l0CoXLGb0_nQb?@3
ojS9l@;oZlgb0_n^b>d3ok37j`;o[KoW1?n/^nD3ojVgh`;oY;7Q0_nO[n83oi^]h`CoV:gU0_nG[nP2
oifjk@CoX<3_0_nTa_42ojS;l@CoZlga00?o[Lgaojc:kon/b^l00_n/b^l2ojc9k`?oZlK]0_nZaNd2
ojW3k0CoZL;/0_nX`N`6ojS1j`;oZ<3[N_nW`>/5ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool03?ooool003gooooo00?o0000ooooooooool0;Oooool4oj>ok@;oX[k]0_nR`>h4oj72
l0;oXLGb0onVa_02ojS9l@;o[<O]1?n^b>d00on`an_o[KoWojfoi`02ojfoi`;o[;_U00?oYkKToj>b
honS/^<00_nS/^<4oin_hP?oVjgS0_nH[ND2oibfjPCoWK[]0_nP`>l2ojG7l@CoZ<_a0_n[cO43ojc;
l0;o[<[_0on[anh2oj_6k@;oZLC]1?nY`n`2ojW2k0;oZ<7/1_nX`N]jojO0j`Wooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0<ooooo`00?_ooool00ol0003oooooooooo`0]ooooo`Go
Xko]0onR`>h2oj72l0?oYL?_0_nVa_02ojW5kPCo[<O]0_n^b>d3ojg1j@;o[KoW00?oZKWUojNfi?nW
]^@00_nW]^@4oj>bh`;oWjoR0_nN/nH3oibcj0CoW;KZ0_nM^^d2oj;2l0CoYLOa0_nXbo43oj[:l0;o
[<_`0_n[b>l3oj_7kP;oZ/G]1?nYa>d2ojW3k0;oZ<;/1?nX`N`2ojS1j`;oZ<3[M?nW`>/@ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool003oooooo0_l0000_ooooo`;oXko]
0_nU_n`4ojC1kP;oYL?_0_nX`nd4ojW5kP;o[<O]0on/`^X2ojg1j@;oZ[cV0onY^ND4ojNfi0;oXk;S
0_nQ]>H4oijciP?oW;?X0_nL]^X2oinnkPCoX/;`0_nUao43ojS8l0;oZ/[`1_n[b>l00on[ankoZ/G]
oj[5k@02oj[5k@;oZLC]0_nY`^`4ojS2k0;oZ<7/0_nX`N/4ojS0jg3oYl3[5?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00_ooooo0011ooooo`03o`000?oooooooooo02gooooo1?nU
_n`2ojC1kP;oYl7/1?nX`nd2ojW5kP?oZl;[0_n/`^X2oj^nj0CoZ[cV0onY^ND2ojNfi0;oY;KV1?nQ
]>H2oijciP;oWkS[1?nN^^`3oinnkP;oX/;`0onVa_02ojS8l0;oZLS`1_n[b>l3oj[6k@;oZ/G]00?o
ZL?/ojW2k?nY`^`00onY`^`2ojS2k003ojS1k?nX`N_oZ<7[00?oZ<7[0_nX`>]^ojO0jaSooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`00@_ooool00ol0003oooooooooo`0]
ooooo`;oYKo/0_nW`>/4ojO1k0;oZ<?]0_nZ`^/3oj_2j`;oZkoY1?n[_^P2ojZliP;oYk[W0onV^>H4
ojBfiP;oXKCV0_nP^>T4oinhj`;oW[[/0_nR`>h4oj?3k`;oY/K`0_nXao04ojW8l0;oZlS_0onZa^h2
oj[6k@03ojW4kOnY`ncoZL?/00;oZL?/0_nY`^`6ojS1k0;oZ<7[0onX`>][ojO0jagooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`00@oooool00ol0003oooooooooo`0]oooo
o`CoYl3[0_nW`N`2ojW1j`CoZ/;[00?oZl;[oj^ojOn[_nT00_n[_nT2oj^nj0;oZKcW1?nW^^L3ojJh
iP;oY;KV0_nR^>P4oj2hj@;oWkS[0_nQ_Nd4oj;0kP;oXl?_00?oY/G`ojS7l?nXao000onXao02ojW8
l0CoZ/K^1_nYa>d2ojW3k0?oZ<;/1OnX`N`3ojS1j`;oZ<3[JOnW`>/Pooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02oooool004Cooooo00?o0000ooooooooool0;Oooool2ojO0j`;o
ZL3[1?nY`N/2oj[2j`?oZ/3Y0_n[_nT2ojVnj0CoZKcW0_nW^^L2ojJjj0CoY;WX0onR^>P2oj2hj@;o
XKc/1?nQ_Nd2oj;0kP03ojG3konVaO3oY/G`00;oY/G`0_nXao03ojW6k`;oZ/K^0_nYaNd6ojW4k@?o
ZL;/0_nX`^`2ojS1k0KoZ<7[0_nX`>]WojO0jbCooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`00AOooool2o`0002oooooo0onY`>/2ojW1j`?oZ/3Z0_nZ`>T2ojVoj@CoZKkX
0_nY_>L2ojNlj0CoY[[X0_nT^NP01?nS^n[oX[_[oj:kjonR^n/5oj6lk0;oXKg]0_nS`Nh3ojG3k`;o
Y/G`0onXaNl2ojW6k`;oZLG^1?nYaNd2ojW4k@?oZL?/0_nY`^`2ojS2k0CoZ<7/0_nX`N/6ojS0jf;o
Yl3[:Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo0017ooooo`03o`00
0?oooooooooo02gooooo1?nY`>X2oj[0jP;oZL3Z1?nY_nT2ojVnj0;oYkgY1?nW_>P2ojJjj003ojBl
j_nS^n[oXk_Z00;oXk_Z0onR^n/2oj6lk0?oXko]0_nS`Nh2ojG3kPCoY/C_0_nXaNl2ojS5kPCoZLG^
0_nYaNd3ojW3k@;oZL?/1_nX`^`2ojS1k0;oZ<7[1_nX`>]PojO0jbcooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0;ooooo`00B?ooool00ol0003oooooooooo`0]ooooo`SoZL3Z0_nY
_nT2ojRnj@CoYkgY0_nW_>P00onU_>[oY;cZojBljP02ojBljP;oXk_Z0_nS_N`4oj>nk@;oXko]0_nU
`^h4ojG3kP;oY/C_0_nWa>h4ojS5kP;oZLG^0onYa>d2ojW3k@SoZ<;/0_nX`N`4ojS1j`?oZ<3[GonW
`>/`ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool004Wooooo00?o0000
ooooooooool0;Oooool6ojW0jP;oZ;oZ1?nX_^T2ojNmj@03ojJmj_nU_>[oYKcZ00;oYKcZ0_nT_>X2
ojBmj`CoXkg/0_nS_^d2ojC0k@CoYL;^0_nU`nh2ojK4kPCoYlC^0_nXaNh3ojS4k@;oZLC]0_nX`n`6
ojS2k0KoZ<7/0_nX`N/5ojS0je_oYl3[=?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo001:ooooo`;o0000;_ooool2ojW0jP;oZ<3[1?nX_nX2ojRnj@;oYkkZ0onV_NX2ojFl
jP;oYKg[1?nT_N/2oj>mk0;oY;o]1?nT`>d2ojG2kP?oY/?^0onVa>h2ojO4kPGoZ<C]0_nX`nd4ojS3
k0?oZ<;/1onX`N`2ojS1j`GoZ<3[F?nW`>/iooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02_ooool004cooooo00?o0000ooooooooool0;?ooool4ojS0j`;oZ;oZ0onW_n/3ojNnjP04
ojJmj_nU_^_oYKk[ojFnj`?oYKg[0_nT_N/2ojBok0CoY;o]0_nT`>d3ojG2kP;oY/?^1_nW`nh2ojS4
k@KoZ<?]0_nX`n`5ojS2k0;oZ<7/1OnX`N/2ojS0jeWoYl3[??ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00[ooooo001=ooooo`03o`000?oooooooooo02cooooo0_nX`>/3ojO0j`;o
Yko[00?oY[o[ojJnjonV_^/00_nV_^/2ojFnj`KoYKo/0onT_n`2ojBok@?oYL7]0_nU`^h2ojK2k@Ko
Yl?^2?nX`nd7ojS2k0?oZ<7/0_nX`N/6ojS0je;oYl3[@oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00[ooooo001>ooooo`03o`000?oooooooooo02gooooo0_nW`>/00onV_ncoY[o[
ojJoj`02ojJoj`;oY[k[2?nU_n`6ojG0k@;oYL7]0_nV`Nd4ojK2k@;oYl?^0_nW`^d6ojS3k@CoZ<;/
2?nX`N`2ojS1j`KoZ<3[D?nW`>]7ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2_ooool004oooooo0_l0000^ooooo`?oY[o/0_nV_n/2ojJok0SoYKo/1_nU`>d2ojG1k@CoY/7]0_nV
`^d6ojO2k@;oZ<?]0_nX`^d2ojS2k0[oZ<7/1?nX`N/2ojS0jdooYl3[C?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00[ooooo001Aooooo`03o`000?oooooooooo02cooooo1onV_n`8
ojFok0CoYL3]1?nU`Nd2ojK1k@?oY/;]1onW`^d2ojS2k@;oZ<;/3?nX`N`2ojS1j`;oZ<3[COnW`>]?
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool005;ooooo00?o0000oooo
ooooool0:oooool6ojJok0SoYKo/0onU`>`3ojG0k@;oYL7]0onV`Nd2ojK2k@03ojO1kOnW`^goYl;]
00CoYl;]0_nW`N`4ojS2k0[oZ<7/1_nX`>]9ojO0je?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0:ooooo`00Doooool00ol0003oooooooooo`0[ooooo`;oY[o/1onU_n`6ojG0k0;o
Y/3/1onV`Nd4ojO1k@;oYl;]1_nW`N`2ojS2k0SoZ<7/0onX`N/2ojS0jd[oYl3[Eoooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Wooooo001Dooooo`;o0000;Oooool2ojFok0;oY[o/
1?nU_n`2ojG0k0KoY/3/0_nV`Nd00onV`NcoY/7]ojK1k@02ojK1k@;oYl7]2onW`N`8ojS1k0;oZ<7[
B_nW`>]Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool005Kooooo00?o
0000ooooooooool0:oooool4ojJok0;oYKo/2_nV`>`3ojK1k0;oY/7]3onW`N`6ojS1k4[oYl3[G_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo001Gooooo`03o`000?oooooo
oooo02_ooooo1?nV_n`<ojK0k003ojK1k?nW`NcoYl7/017oYl7/0_nX`Na6ojO0jfKooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`09ooooo`00F?ooool00ol0003oooooooooo`0/oooo
o`?oY[o/3?nV`>`BojO1k003ojO0k?nW`>_oYl3[04?oYl3[J_ooool01Ol0003ooooooooooooooooo
000000_ooooo001Iooooo`03o`000?oooooooooo02cooooo1?nV_n`9ojK0k0;oYl3/3_nW`N`5ojO0
k47oYl3[KOooool01Ol0003ooooooooooooooooo000000_ooooo001Jooooo`;o0000;Oooool4ojJo
k0GoY/3/1_nW`>`2ojO1k0?oYl3/1OnW`N`4ojO0k4;oYl3[LOooool01?l0003oooooooooool0000;
ooooo`00G?ooool00ol0003oooooooooo`0[ooooo`CoY[o/00?oY/3/ojO0k?nW`>`04_nW`>a2ojO0
jgGooooo00?o0000ooooool000002oooool005gooooo00?o0000ooooooooool0:oooool2ojJok1Co
Yl3/@OnW`>]hooooo`04o`000?ooooooooooo`0000[ooooo001Nooooo`03o`000?oooooooooo02_o
oooo0_nW`>`2ojO0j`KoYl3/0_nW`>/6ojO0k47oYl3[O?ooool00ol0003oooooo`00000:ooooo`00
Goooool2o`0002cooooo1?nW`>/2ojO0k0KoYl3[0_nW`>`nojO0jh?ooooo0_l0000:ooooo`00HOoo
ool00ol0003oooooooooo`0ZooooodSoYl3[QOooool3o`0000[ooooo001Rooooo`03o`000?oooooo
oooo02_ooooo@onW`>^4ooooo`Co00003Oooool006?ooooo00?o0000ooooooooool0:oooooloojO0
jh?ooooo1?l0000Aooooo`00I?ooool2o`0002cooooo>onW`>^3ooooo`?o00005Oooool006Kooooo
00?o0000ooooooooool0:ooooolcojO0jhGooooo1?l0000Hooooo`00Ioooool00ol0003ooooooooo
o`0Zoooooc3oYl3[Q?ooool4o`0001cooooo001Xooooo`03o`000?oooooooooo02[ooooo;?nW`>^3
ooooo`Co00008?ooool006Wooooo0_l0000/ooooobOoYl3[P_ooool4o`0002Cooooo001[ooooo`03
o`000?oooooooooo02[ooooo8onW`>^2ooooo`?o0000:?ooool006cooooo00?o0000ooooooooool0
:_oooolMojO0jh?ooooo1?l0000[ooooo`00KOooool00ol0003oooooooooo`0[oooooaSoYl3[P_oo
ool4o`0002oooooo001^ooooo`03o`000?oooooooooo02[ooooo5OnW`>^1ooooo`Co0000<oooool0
06oooooo0_l0000[oooooa7oYl3[P?ooool4o`0003Oooooo001aooooo`03o`000?oooooooooo02[o
oooo2OnW`>^2ooooo`Co0000>oooool007;ooooo00?o0000ooooooooool0:_ooool5ojO0jh;ooooo
0ol0000oooooo`00Loooool00ol0003oooooooooo`0Zooooo`03ojO0jooooooooooo07oooooo1?l0
0012ooooo`00M?ooool2o`0002[ooooo00?o0000ooooooooool0Noooool4o`0004Kooooo001foooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0N?ooool4o`0004[ooooo001gooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0M?ooool4o`0004kooooo001hooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0LOooool3o`0005;ooooo001iooooo`;o00009?oo
ool00ol0003oooooooooo`1]ooooo`Co0000EOooool007_ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`1Yooooo`Co0000FOooool007cooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`1Uooooo`Co0000GOooool007gooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1Qooooo`Co0000HOooool007kooooo0_l0000Oooooo`03o`000?oooooooooo05gooooo
1?l0001Uooooo`00P?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05[ooooo0ol0
001Yooooo`00POooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Kooooo1?l0001/
ooooo`00P_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05;ooooo1?l0001`oooo
o`00Poooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04kooooo1?l0001dooooo`00
Q?ooool2o`0001Wooooo00?o0000ooooooooool0B_ooool4o`0007Sooooo0026ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0A_ooool4o`0007cooooo0027ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0@oooool3o`00083ooooo0028ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0?oooool4o`0008?ooooo0029ooooo`;o00005?ooool00ol0003o
ooooooooo`0kooooo`Co0000Qoooool008_ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0gooooo`Co0000Roooool008cooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0cooooo`Co0000Soooool008gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0`
ooooo`?o0000Toooool008kooooo0_l0000?ooooo`03o`000?oooooooooo02cooooo1?l0002Foooo
o`00T?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Sooooo1?l0002Jooooo`00
TOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Cooooo1?l0002Nooooo`00T_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo1?l0002Rooooo`00Toooool2
o`0000Wooooo00?o0000ooooooooool07Oooool4o`000:Kooooo002Eooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool06_ooool3o`000:[ooooo002Fooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool05_ooool4o`000:gooooo002Gooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool04_ooool4o`000;7ooooo002Hooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool03_ooool4o`000;Gooooo002Iooooo`;o00000oooool00ol0003oooooooooo`0:
ooooo`Co0000^Oooool009_ooooo00Co0000oooooooooooo00002Oooool3o`000;gooooo002Loooo
o`03o`000?oooooo000000Gooooo1?l00030ooooo`00WOooool2o`000003ooooool0003o000000;o
0000a?ooool009kooooo0_l00038ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z_ooool01OnH
V9So0000o`000?m4A4Co^[Zj00[ooooo1?l000000ol@413oooooooooo`05o`0000Gooooo0_lQ8B44
ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0Toooool00:[ooooo00Go410@okZj^_o^k^koMgMgoa0@
4002ooooo`Ko00001?ooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@2Cooooo`00Z_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h03?ooool01Ol0003ooooo
oooooooooooo000009?ooooo002Zooooo`03o`000?oooooooooo00Cooooo1_l00004ooooo`03o`00
0?oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h02oooool01Olb<S;oV9RHoooooonHV9So<S8b09?o
oooo002Zooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool00omgMgOoIVIV
ooooo`0:ooooo`05olc<c?l0003o0000o`000?o<c<`0Toooool00:Sooooo00?o410@o`000?l00000
0ol0000=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool01Ol@413o^[Zj
oooooonj^[[o410@09?ooooo002Zooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
0_ooool01Ol0003o^[ZjoooooonHV9So410@00_ooooo00Go0000okZj^_oooooo^[Zjo`00002Coooo
o`00Z_ooool00ol0003oooooooooo`0<ooooo`03oeEEEOmVIVKo000000Cooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c00;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0Toooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -20 0 ]
[.5 .82364 20 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.6) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69467 Mtetra
.4053 .69467 .41061 .69934 .41957 .69681 .41427 .69213 Mtetra
.656 .752 .92 r
.41427 .69213 .41957 .69681 .42855 .69428 .42327 .68959 Mtetra
.42327 .68959 .42855 .69428 .43756 .69174 .43231 .68703 Mtetra
.43231 .68703 .43756 .69174 .4466 .68919 .44137 .68447 Mtetra
.44137 .68447 .4466 .68919 .45567 .68663 .45046 .68189 Mtetra
.45046 .68189 .45567 .68663 .46478 .68407 .45958 .67931 Mtetra
.45958 .67931 .46478 .68407 .47391 .68149 .46873 .67672 Mtetra
.46873 .67672 .47391 .68149 .48307 .67891 .47792 .67412 Mtetra
.47792 .67412 .48307 .67891 .49227 .67632 .48713 .67151 Mtetra
.48713 .67151 .49227 .67632 .50149 .67371 .49638 .66889 Mtetra
.49638 .66889 .50149 .67371 .51075 .6711 .50565 .66627 Mtetra
.50565 .66627 .51075 .6711 .52004 .66849 .51496 .66363 Mtetra
.51496 .66363 .52004 .66849 .52936 .66586 .5243 .66099 Mtetra
.656 .751 .92 r
.5243 .66099 .52936 .66586 .53871 .66322 .53367 .65833 Mtetra
.53367 .65833 .53871 .66322 .54809 .66058 .54308 .65567 Mtetra
.54308 .65567 .54809 .66058 .55751 .65792 .55251 .653 Mtetra
.55251 .653 .55751 .65792 .56695 .65526 .56198 .65032 Mtetra
.56198 .65032 .56695 .65526 .57643 .65259 .57148 .64763 Mtetra
.57148 .64763 .57643 .65259 .58595 .6499 .58102 .64493 Mtetra
.58102 .64493 .58595 .6499 .59549 .64721 .59058 .64222 Mtetra
.59058 .64222 .59549 .64721 .60507 .64451 .60018 .6395 Mtetra
.60018 .6395 .60507 .64451 .61468 .6418 .60982 .63678 Mtetra
.60982 .63678 .61468 .6418 .62432 .63908 .61948 .63404 Mtetra
.61948 .63404 .62432 .63908 .634 .63636 .62918 .63129 Mtetra
.62918 .63129 .634 .63636 .64371 .63362 .63892 .62854 Mtetra
.63892 .62854 .64371 .63362 .65345 .63087 .64868 .62577 Mtetra
.64868 .62577 .65345 .63087 .66323 .62811 .65848 .623 Mtetra
.65848 .623 .66323 .62811 .67304 .62535 .66832 .62021 Mtetra
.66832 .62021 .67304 .62535 .68289 .62257 .67819 .61742 Mtetra
.67819 .61742 .68289 .62257 .69277 .61979 .68809 .61462 Mtetra
.68809 .61462 .69277 .61979 .70269 .61699 .69803 .6118 Mtetra
.69803 .6118 .70269 .61699 .71264 .61418 .70801 .60898 Mtetra
.70801 .60898 .71264 .61418 .72262 .61137 .71802 .60615 Mtetra
.71802 .60615 .72262 .61137 .73264 .60854 .72806 .6033 Mtetra
.72806 .6033 .73264 .60854 .7427 .60571 .73814 .60045 Mtetra
.73814 .60045 .7427 .60571 .75279 .60286 .74826 .59759 Mtetra
.74826 .59759 .75279 .60286 .76291 .60001 .75841 .59471 Mtetra
.75841 .59471 .76291 .60001 .77308 .59714 .7686 .59183 Mtetra
.7686 .59183 .77308 .59714 .78328 .59427 .77882 .58893 Mtetra
.77882 .58893 .78328 .59427 .79351 .59138 .78908 .58603 Mtetra
.78908 .58603 .79351 .59138 .80378 .58849 .79938 .58312 Mtetra
.79938 .58312 .80378 .58849 .81409 .58558 .80971 .58019 Mtetra
.80971 .58019 .81409 .58558 .82443 .58267 .82008 .57725 Mtetra
.82008 .57725 .82443 .58267 .83482 .57974 .83049 .57431 Mtetra
.83049 .57431 .83482 .57974 .84523 .5768 .84094 .57135 Mtetra
.84094 .57135 .84523 .5768 .85569 .57385 .85142 .56839 Mtetra
.656 .752 .92 r
.85142 .56839 .85569 .57385 .86618 .57089 .86194 .56541 Mtetra
.86194 .56541 .86618 .57089 .87672 .56792 .8725 .56242 Mtetra
.8725 .56242 .87672 .56792 .88729 .56494 .8831 .55942 Mtetra
.8831 .55942 .88729 .56494 .89789 .56195 .89374 .55641 Mtetra
.89374 .55641 .89789 .56195 .90854 .55895 .90441 .55339 Mtetra
.90441 .55339 .90854 .55895 .91923 .55594 .91513 .55036 Mtetra
.91513 .55036 .91923 .55594 .92995 .55292 .92588 .54731 Mtetra
.92588 .54731 .92995 .55292 .94071 .54988 .93667 .54426 Mtetra
.93667 .54426 .94071 .54988 .95152 .54684 .9475 .54119 Mtetra
.9475 .54119 .95152 .54684 .96236 .54378 .95837 .53811 Mtetra
.95837 .53811 .96236 .54378 .97324 .54071 .96928 .53502 Mtetra
.656 .751 .92 r
.96928 .53502 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.391 .69252 .39636 .6972 .4053 .69467 .39996 .68998 Mtetra
.39996 .68998 .4053 .69467 .41427 .69213 .40895 .68743 Mtetra
.656 .752 .92 r
.40895 .68743 .41427 .69213 .42327 .68959 .41797 .68487 Mtetra
.41797 .68487 .42327 .68959 .43231 .68703 .42702 .6823 Mtetra
.42702 .6823 .43231 .68703 .44137 .68447 .4361 .67972 Mtetra
.656 .752 .921 r
.4361 .67972 .44137 .68447 .45046 .68189 .44521 .67713 Mtetra
.44521 .67713 .45046 .68189 .45958 .67931 .45435 .67453 Mtetra
.656 .752 .92 r
.45435 .67453 .45958 .67931 .46873 .67672 .46352 .67192 Mtetra
.46352 .67192 .46873 .67672 .47792 .67412 .47273 .66931 Mtetra
.47273 .66931 .47792 .67412 .48713 .67151 .48196 .66668 Mtetra
.48196 .66668 .48713 .67151 .49638 .66889 .49123 .66404 Mtetra
.49123 .66404 .49638 .66889 .50565 .66627 .50053 .6614 Mtetra
.50053 .6614 .50565 .66627 .51496 .66363 .50985 .65875 Mtetra
.50985 .65875 .51496 .66363 .5243 .66099 .51922 .65608 Mtetra
.656 .751 .92 r
.51922 .65608 .5243 .66099 .53367 .65833 .52861 .65341 Mtetra
.52861 .65341 .53367 .65833 .54308 .65567 .53803 .65073 Mtetra
.53803 .65073 .54308 .65567 .55251 .653 .54749 .64804 Mtetra
.54749 .64804 .55251 .653 .56198 .65032 .55698 .64535 Mtetra
.55698 .64535 .56198 .65032 .57148 .64763 .5665 .64264 Mtetra
.5665 .64264 .57148 .64763 .58102 .64493 .57606 .63992 Mtetra
.57606 .63992 .58102 .64493 .59058 .64222 .58565 .6372 Mtetra
.58565 .6372 .59058 .64222 .60018 .6395 .59527 .63446 Mtetra
.59527 .63446 .60018 .6395 .60982 .63678 .60493 .63172 Mtetra
.60493 .63172 .60982 .63678 .61948 .63404 .61461 .62896 Mtetra
.61461 .62896 .61948 .63404 .62918 .63129 .62434 .6262 Mtetra
.62434 .6262 .62918 .63129 .63892 .62854 .63409 .62343 Mtetra
.63409 .62343 .63892 .62854 .64868 .62577 .64388 .62064 Mtetra
.64388 .62064 .64868 .62577 .65848 .623 .65371 .61785 Mtetra
.65371 .61785 .65848 .623 .66832 .62021 .66357 .61505 Mtetra
.66357 .61505 .66832 .62021 .67819 .61742 .67346 .61224 Mtetra
.67346 .61224 .67819 .61742 .68809 .61462 .68339 .60942 Mtetra
.68339 .60942 .68809 .61462 .69803 .6118 .69335 .60658 Mtetra
.69335 .60658 .69803 .6118 .70801 .60898 .70335 .60374 Mtetra
.70335 .60374 .70801 .60898 .71802 .60615 .71338 .60089 Mtetra
.71338 .60089 .71802 .60615 .72806 .6033 .72345 .59803 Mtetra
.72345 .59803 .72806 .6033 .73814 .60045 .73356 .59516 Mtetra
.73356 .59516 .73814 .60045 .74826 .59759 .7437 .59227 Mtetra
.7437 .59227 .74826 .59759 .75841 .59471 .75387 .58938 Mtetra
.75387 .58938 .75841 .59471 .7686 .59183 .76409 .58648 Mtetra
.76409 .58648 .7686 .59183 .77882 .58893 .77434 .58356 Mtetra
.77434 .58356 .77882 .58893 .78908 .58603 .78462 .58064 Mtetra
.78462 .58064 .78908 .58603 .79938 .58312 .79495 .57771 Mtetra
.79495 .57771 .79938 .58312 .80971 .58019 .80531 .57476 Mtetra
.80531 .57476 .80971 .58019 .82008 .57725 .81571 .57181 Mtetra
.81571 .57181 .82008 .57725 .83049 .57431 .82614 .56884 Mtetra
.82614 .56884 .83049 .57431 .84094 .57135 .83661 .56587 Mtetra
.83661 .56587 .84094 .57135 .85142 .56839 .84712 .56288 Mtetra
.656 .752 .92 r
.84712 .56288 .85142 .56839 .86194 .56541 .85767 .55989 Mtetra
.85767 .55989 .86194 .56541 .8725 .56242 .86826 .55688 Mtetra
.86826 .55688 .8725 .56242 .8831 .55942 .87889 .55386 Mtetra
.87889 .55386 .8831 .55942 .89374 .55641 .88955 .55083 Mtetra
.88955 .55083 .89374 .55641 .90441 .55339 .90025 .54779 Mtetra
.656 .752 .921 r
.90025 .54779 .90441 .55339 .91513 .55036 .911 .54474 Mtetra
.656 .752 .92 r
.911 .54474 .91513 .55036 .92588 .54731 .92178 .54167 Mtetra
.92178 .54167 .92588 .54731 .93667 .54426 .9326 .53859 Mtetra
.9326 .53859 .93667 .54426 .9475 .54119 .94346 .5355 Mtetra
.94346 .5355 .9475 .54119 .95837 .53811 .95436 .5324 Mtetra
.95436 .5324 .95837 .53811 .96928 .53502 .9653 .52929 Mtetra
.9653 .52929 .96928 .53502 .98024 .53192 .97628 .52616 Mtetra
.656 .751 .92 r
.38561 .68781 .391 .69252 .39996 .68998 .39459 .68526 Mtetra
.39459 .68526 .39996 .68998 .40895 .68743 .40359 .68269 Mtetra
.656 .752 .921 r
.40359 .68269 .40895 .68743 .41797 .68487 .41263 .68012 Mtetra
.41263 .68012 .41797 .68487 .42702 .6823 .4217 .67753 Mtetra
.4217 .67753 .42702 .6823 .4361 .67972 .4308 .67494 Mtetra
.4308 .67494 .4361 .67972 .44521 .67713 .43993 .67233 Mtetra
.43993 .67233 .44521 .67713 .45435 .67453 .44909 .66972 Mtetra
.44909 .66972 .45435 .67453 .46352 .67192 .45828 .6671 Mtetra
.45828 .6671 .46352 .67192 .47273 .66931 .46751 .66446 Mtetra
.46751 .66446 .47273 .66931 .48196 .66668 .47676 .66182 Mtetra
.656 .752 .92 r
.47676 .66182 .48196 .66668 .49123 .66404 .48605 .65916 Mtetra
.48605 .65916 .49123 .66404 .50053 .6614 .49537 .6565 Mtetra
.49537 .6565 .50053 .6614 .50985 .65875 .50472 .65383 Mtetra
.50472 .65383 .50985 .65875 .51922 .65608 .5141 .65115 Mtetra
.5141 .65115 .51922 .65608 .52861 .65341 .52351 .64846 Mtetra
.52351 .64846 .52861 .65341 .53803 .65073 .53296 .64576 Mtetra
.656 .751 .92 r
.53296 .64576 .53803 .65073 .54749 .64804 .54244 .64306 Mtetra
.54244 .64306 .54749 .64804 .55698 .64535 .55195 .64034 Mtetra
.55195 .64034 .55698 .64535 .5665 .64264 .56149 .63762 Mtetra
.56149 .63762 .5665 .64264 .57606 .63992 .57107 .63488 Mtetra
.57107 .63488 .57606 .63992 .58565 .6372 .58068 .63214 Mtetra
.58068 .63214 .58565 .6372 .59527 .63446 .59032 .62939 Mtetra
.59032 .62939 .59527 .63446 .60493 .63172 .6 .62663 Mtetra
.6 .62663 .60493 .63172 .61461 .62896 .60971 .62385 Mtetra
.60971 .62385 .61461 .62896 .62434 .6262 .61946 .62107 Mtetra
.61946 .62107 .62434 .6262 .63409 .62343 .62924 .61828 Mtetra
.62924 .61828 .63409 .62343 .64388 .62064 .63905 .61548 Mtetra
.63905 .61548 .64388 .62064 .65371 .61785 .6489 .61267 Mtetra
.6489 .61267 .65371 .61785 .66357 .61505 .65878 .60985 Mtetra
.65878 .60985 .66357 .61505 .67346 .61224 .6687 .60702 Mtetra
.6687 .60702 .67346 .61224 .68339 .60942 .67865 .60418 Mtetra
.67865 .60418 .68339 .60942 .69335 .60658 .68864 .60133 Mtetra
.68864 .60133 .69335 .60658 .70335 .60374 .69866 .59847 Mtetra
.69866 .59847 .70335 .60374 .71338 .60089 .70872 .5956 Mtetra
.70872 .5956 .71338 .60089 .72345 .59803 .71881 .59272 Mtetra
.71881 .59272 .72345 .59803 .73356 .59516 .72894 .58983 Mtetra
.72894 .58983 .73356 .59516 .7437 .59227 .73911 .58692 Mtetra
.73911 .58692 .7437 .59227 .75387 .58938 .74931 .58401 Mtetra
.74931 .58401 .75387 .58938 .76409 .58648 .75955 .58109 Mtetra
.75955 .58109 .76409 .58648 .77434 .58356 .76983 .57816 Mtetra
.76983 .57816 .77434 .58356 .78462 .58064 .78014 .57522 Mtetra
.78014 .57522 .78462 .58064 .79495 .57771 .79049 .57226 Mtetra
.79049 .57226 .79495 .57771 .80531 .57476 .80087 .5693 Mtetra
.80087 .5693 .80531 .57476 .81571 .57181 .8113 .56633 Mtetra
.8113 .56633 .81571 .57181 .82614 .56884 .82176 .56334 Mtetra
.82176 .56334 .82614 .56884 .83661 .56587 .83226 .56035 Mtetra
.656 .752 .92 r
.83226 .56035 .83661 .56587 .84712 .56288 .8428 .55734 Mtetra
.8428 .55734 .84712 .56288 .85767 .55989 .85338 .55433 Mtetra
.656 .752 .921 r
.85338 .55433 .85767 .55989 .86826 .55688 .86399 .5513 Mtetra
.86399 .5513 .86826 .55688 .87889 .55386 .87464 .54827 Mtetra
.87464 .54827 .87889 .55386 .88955 .55083 .88534 .54522 Mtetra
.88534 .54522 .88955 .55083 .90025 .54779 .89607 .54215 Mtetra
.89607 .54215 .90025 .54779 .911 .54474 .90684 .53908 Mtetra
.90684 .53908 .911 .54474 .92178 .54167 .91765 .53599 Mtetra
.91765 .53599 .92178 .54167 .9326 .53859 .9285 .53289 Mtetra
.656 .752 .92 r
.9285 .53289 .9326 .53859 .94346 .5355 .93939 .52978 Mtetra
.93939 .52978 .94346 .5355 .95436 .5324 .95032 .52666 Mtetra
.95032 .52666 .95436 .5324 .9653 .52929 .96129 .52352 Mtetra
.96129 .52352 .9653 .52929 .97628 .52616 .9723 .52037 Mtetra
.655 .751 .92 r
.38018 .68308 .38561 .68781 .39459 .68526 .38918 .68051 Mtetra
.655 .751 .921 r
.38918 .68051 .39459 .68526 .40359 .68269 .3982 .67793 Mtetra
.655 .752 .921 r
.3982 .67793 .40359 .68269 .41263 .68012 .40726 .67534 Mtetra
.40726 .67534 .41263 .68012 .4217 .67753 .41635 .67274 Mtetra
.656 .752 .921 r
.41635 .67274 .4217 .67753 .4308 .67494 .42547 .67014 Mtetra
.42547 .67014 .4308 .67494 .43993 .67233 .43462 .66752 Mtetra
.43462 .66752 .43993 .67233 .44909 .66972 .4438 .66489 Mtetra
.4438 .66489 .44909 .66972 .45828 .6671 .45301 .66224 Mtetra
.45301 .66224 .45828 .6671 .46751 .66446 .46225 .65959 Mtetra
.46225 .65959 .46751 .66446 .47676 .66182 .47153 .65693 Mtetra
.47153 .65693 .47676 .66182 .48605 .65916 .48083 .65426 Mtetra
.48083 .65426 .48605 .65916 .49537 .6565 .49017 .65158 Mtetra
.656 .752 .92 r
.49017 .65158 .49537 .6565 .50472 .65383 .49954 .64889 Mtetra
.49954 .64889 .50472 .65383 .5141 .65115 .50895 .64619 Mtetra
.50895 .64619 .5141 .65115 .52351 .64846 .51838 .64348 Mtetra
.51838 .64348 .52351 .64846 .53296 .64576 .52785 .64076 Mtetra
.52785 .64076 .53296 .64576 .54244 .64306 .53735 .63804 Mtetra
.656 .751 .92 r
.53735 .63804 .54244 .64306 .55195 .64034 .54688 .63531 Mtetra
.54688 .63531 .55195 .64034 .56149 .63762 .55645 .63256 Mtetra
.55645 .63256 .56149 .63762 .57107 .63488 .56605 .62981 Mtetra
.56605 .62981 .57107 .63488 .58068 .63214 .57568 .62705 Mtetra
.57568 .62705 .58068 .63214 .59032 .62939 .58535 .62428 Mtetra
.58535 .62428 .59032 .62939 .6 .62663 .59505 .6215 Mtetra
.59505 .6215 .6 .62663 .60971 .62385 .60478 .61871 Mtetra
.60478 .61871 .60971 .62385 .61946 .62107 .61455 .61591 Mtetra
.61455 .61591 .61946 .62107 .62924 .61828 .62435 .6131 Mtetra
.62435 .6131 .62924 .61828 .63905 .61548 .63419 .61028 Mtetra
.63419 .61028 .63905 .61548 .6489 .61267 .64406 .60746 Mtetra
.64406 .60746 .6489 .61267 .65878 .60985 .65396 .60462 Mtetra
.65396 .60462 .65878 .60985 .6687 .60702 .66391 .60177 Mtetra
.66391 .60177 .6687 .60702 .67865 .60418 .67388 .59891 Mtetra
.67388 .59891 .67865 .60418 .68864 .60133 .68389 .59604 Mtetra
.68389 .59604 .68864 .60133 .69866 .59847 .69394 .59316 Mtetra
.69394 .59316 .69866 .59847 .70872 .5956 .70402 .59027 Mtetra
.70402 .59027 .70872 .5956 .71881 .59272 .71414 .58737 Mtetra
.71414 .58737 .71881 .59272 .72894 .58983 .7243 .58446 Mtetra
.7243 .58446 .72894 .58983 .73911 .58692 .73449 .58154 Mtetra
.73449 .58154 .73911 .58692 .74931 .58401 .74472 .57861 Mtetra
.74472 .57861 .74931 .58401 .75955 .58109 .75498 .57567 Mtetra
.75498 .57567 .75955 .58109 .76983 .57816 .76528 .57272 Mtetra
.76528 .57272 .76983 .57816 .78014 .57522 .77562 .56976 Mtetra
.77562 .56976 .78014 .57522 .79049 .57226 .786 .56678 Mtetra
.786 .56678 .79049 .57226 .80087 .5693 .79641 .5638 Mtetra
.79641 .5638 .80087 .5693 .8113 .56633 .80686 .56081 Mtetra
.80686 .56081 .8113 .56633 .82176 .56334 .81735 .55781 Mtetra
.656 .752 .92 r
.81735 .55781 .82176 .56334 .83226 .56035 .82788 .5548 Mtetra
.656 .752 .921 r
.82788 .5548 .83226 .56035 .8428 .55734 .83844 .55177 Mtetra
.83844 .55177 .8428 .55734 .85338 .55433 .84905 .54874 Mtetra
.84905 .54874 .85338 .55433 .86399 .5513 .85969 .54569 Mtetra
.85969 .54569 .86399 .5513 .87464 .54827 .87037 .54264 Mtetra
.87037 .54264 .87464 .54827 .88534 .54522 .8811 .53957 Mtetra
.8811 .53957 .88534 .54522 .89607 .54215 .89186 .53649 Mtetra
.89186 .53649 .89607 .54215 .90684 .53908 .90266 .53339 Mtetra
.90266 .53339 .90684 .53908 .91765 .53599 .9135 .53028 Mtetra
.9135 .53028 .91765 .53599 .9285 .53289 .92438 .52716 Mtetra
.92438 .52716 .9285 .53289 .93939 .52978 .93529 .52402 Mtetra
.656 .752 .92 r
.93529 .52402 .93939 .52978 .95032 .52666 .94625 .52087 Mtetra
.94625 .52087 .95032 .52666 .96129 .52352 .95725 .51771 Mtetra
.95725 .51771 .96129 .52352 .9723 .52037 .96829 .51454 Mtetra
.655 .751 .921 r
.37472 .67831 .38018 .68308 .38918 .68051 .38373 .67573 Mtetra
.38373 .67573 .38918 .68051 .3982 .67793 .39278 .67314 Mtetra
.655 .752 .921 r
.39278 .67314 .3982 .67793 .40726 .67534 .40185 .67054 Mtetra
.40185 .67054 .40726 .67534 .41635 .67274 .41096 .66793 Mtetra
.41096 .66793 .41635 .67274 .42547 .67014 .4201 .66531 Mtetra
.656 .752 .921 r
.4201 .66531 .42547 .67014 .43462 .66752 .42927 .66267 Mtetra
.42927 .66267 .43462 .66752 .4438 .66489 .43847 .66003 Mtetra
.43847 .66003 .4438 .66489 .45301 .66224 .4477 .65737 Mtetra
.4477 .65737 .45301 .66224 .46225 .65959 .45697 .6547 Mtetra
.45697 .6547 .46225 .65959 .47153 .65693 .46626 .65202 Mtetra
.46626 .65202 .47153 .65693 .48083 .65426 .47559 .64933 Mtetra
.47559 .64933 .48083 .65426 .49017 .65158 .48495 .64663 Mtetra
.48495 .64663 .49017 .65158 .49954 .64889 .49434 .64392 Mtetra
.656 .752 .92 r
.49434 .64392 .49954 .64889 .50895 .64619 .50376 .6412 Mtetra
.50376 .6412 .50895 .64619 .51838 .64348 .51322 .63847 Mtetra
.51322 .63847 .51838 .64348 .52785 .64076 .52271 .63574 Mtetra
.52271 .63574 .52785 .64076 .53735 .63804 .53223 .63299 Mtetra
.53223 .63299 .53735 .63804 .54688 .63531 .54178 .63024 Mtetra
.656 .751 .92 r
.54178 .63024 .54688 .63531 .55645 .63256 .55137 .62748 Mtetra
.55137 .62748 .55645 .63256 .56605 .62981 .56099 .62471 Mtetra
.56099 .62471 .56605 .62981 .57568 .62705 .57065 .62193 Mtetra
.57065 .62193 .57568 .62705 .58535 .62428 .58034 .61914 Mtetra
.58034 .61914 .58535 .62428 .59505 .6215 .59006 .61634 Mtetra
.59006 .61634 .59505 .6215 .60478 .61871 .59982 .61354 Mtetra
.59982 .61354 .60478 .61871 .61455 .61591 .60961 .61072 Mtetra
.60961 .61072 .61455 .61591 .62435 .6131 .61943 .60789 Mtetra
.61943 .60789 .62435 .6131 .63419 .61028 .62929 .60505 Mtetra
.62929 .60505 .63419 .61028 .64406 .60746 .63919 .60221 Mtetra
.63919 .60221 .64406 .60746 .65396 .60462 .64912 .59935 Mtetra
.64912 .59935 .65396 .60462 .66391 .60177 .65908 .59648 Mtetra
.65908 .59648 .66391 .60177 .67388 .59891 .66908 .5936 Mtetra
.66908 .5936 .67388 .59891 .68389 .59604 .67912 .59072 Mtetra
.67912 .59072 .68389 .59604 .69394 .59316 .68919 .58782 Mtetra
.68919 .58782 .69394 .59316 .70402 .59027 .6993 .58491 Mtetra
.6993 .58491 .70402 .59027 .71414 .58737 .70944 .58199 Mtetra
.70944 .58199 .71414 .58737 .7243 .58446 .71962 .57906 Mtetra
.71962 .57906 .7243 .58446 .73449 .58154 .72984 .57612 Mtetra
.72984 .57612 .73449 .58154 .74472 .57861 .74009 .57317 Mtetra
.74009 .57317 .74472 .57861 .75498 .57567 .75038 .57021 Mtetra
.75038 .57021 .75498 .57567 .76528 .57272 .76071 .56724 Mtetra
.76071 .56724 .76528 .57272 .77562 .56976 .77107 .56426 Mtetra
.77107 .56426 .77562 .56976 .786 .56678 .78148 .56127 Mtetra
.78148 .56127 .786 .56678 .79641 .5638 .79192 .55827 Mtetra
.79192 .55827 .79641 .5638 .80686 .56081 .8024 .55526 Mtetra
.656 .752 .921 r
.8024 .55526 .80686 .56081 .81735 .55781 .81291 .55224 Mtetra
.655 .752 .921 r
.81291 .55224 .81735 .55781 .82788 .5548 .82347 .54921 Mtetra
.82347 .54921 .82788 .5548 .83844 .55177 .83406 .54617 Mtetra
.83406 .54617 .83844 .55177 .84905 .54874 .84469 .54312 Mtetra
.84469 .54312 .84905 .54874 .85969 .54569 .85536 .54005 Mtetra
.85536 .54005 .85969 .54569 .87037 .54264 .86608 .53698 Mtetra
.656 .752 .921 r
.86608 .53698 .87037 .54264 .8811 .53957 .87683 .53389 Mtetra
.87683 .53389 .8811 .53957 .89186 .53649 .88762 .53079 Mtetra
.88762 .53079 .89186 .53649 .90266 .53339 .89844 .52767 Mtetra
.89844 .52767 .90266 .53339 .9135 .53028 .90931 .52454 Mtetra
.90931 .52454 .9135 .53028 .92438 .52716 .92022 .52139 Mtetra
.92022 .52139 .92438 .52716 .93529 .52402 .93117 .51823 Mtetra
.93117 .51823 .93529 .52402 .94625 .52087 .94216 .51506 Mtetra
.656 .752 .92 r
.94216 .51506 .94625 .52087 .95725 .51771 .95319 .51187 Mtetra
.95319 .51187 .95725 .51771 .96829 .51454 .96426 .50866 Mtetra
.655 .751 .921 r
.36922 .67351 .37472 .67831 .38373 .67573 .37826 .67093 Mtetra
.37826 .67093 .38373 .67573 .39278 .67314 .38732 .66833 Mtetra
.655 .752 .921 r
.38732 .66833 .39278 .67314 .40185 .67054 .39642 .66572 Mtetra
.39642 .66572 .40185 .67054 .41096 .66793 .40554 .66309 Mtetra
.40554 .66309 .41096 .66793 .4201 .66531 .4147 .66046 Mtetra
.4147 .66046 .4201 .66531 .42927 .66267 .42389 .65781 Mtetra
.656 .753 .921 r
.42389 .65781 .42927 .66267 .43847 .66003 .43311 .65515 Mtetra
.43311 .65515 .43847 .66003 .4477 .65737 .44236 .65247 Mtetra
.44236 .65247 .4477 .65737 .45697 .6547 .45164 .64979 Mtetra
.45164 .64979 .45697 .6547 .46626 .65202 .46096 .64708 Mtetra
.46096 .64708 .46626 .65202 .47559 .64933 .47031 .64437 Mtetra
.47031 .64437 .47559 .64933 .48495 .64663 .47969 .64165 Mtetra
.656 .752 .921 r
.47969 .64165 .48495 .64663 .49434 .64392 .4891 .63892 Mtetra
.4891 .63892 .49434 .64392 .50376 .6412 .49855 .63618 Mtetra
.49855 .63618 .50376 .6412 .51322 .63847 .50802 .63343 Mtetra
.656 .752 .92 r
.50802 .63343 .51322 .63847 .52271 .63574 .51753 .63068 Mtetra
.51753 .63068 .52271 .63574 .53223 .63299 .52708 .62791 Mtetra
.52708 .62791 .53223 .63299 .54178 .63024 .53665 .62514 Mtetra
.53665 .62514 .54178 .63024 .55137 .62748 .54626 .62236 Mtetra
.656 .751 .92 r
.54626 .62236 .55137 .62748 .56099 .62471 .55591 .61957 Mtetra
.55591 .61957 .56099 .62471 .57065 .62193 .56558 .61678 Mtetra
.56558 .61678 .57065 .62193 .58034 .61914 .57529 .61397 Mtetra
.57529 .61397 .58034 .61914 .59006 .61634 .58504 .61115 Mtetra
.58504 .61115 .59006 .61634 .59982 .61354 .59482 .60833 Mtetra
.59482 .60833 .59982 .61354 .60961 .61072 .60463 .60549 Mtetra
.60463 .60549 .60961 .61072 .61943 .60789 .61448 .60265 Mtetra
.61448 .60265 .61943 .60789 .62929 .60505 .62437 .59979 Mtetra
.62437 .59979 .62929 .60505 .63919 .60221 .63428 .59692 Mtetra
.63428 .59692 .63919 .60221 .64912 .59935 .64424 .59405 Mtetra
.64424 .59405 .64912 .59935 .65908 .59648 .65423 .59116 Mtetra
.65423 .59116 .65908 .59648 .66908 .5936 .66425 .58826 Mtetra
.66425 .58826 .66908 .5936 .67912 .59072 .67431 .58536 Mtetra
.67431 .58536 .67912 .59072 .68919 .58782 .68441 .58244 Mtetra
.68441 .58244 .68919 .58782 .6993 .58491 .69454 .57951 Mtetra
.69454 .57951 .6993 .58491 .70944 .58199 .70471 .57657 Mtetra
.70471 .57657 .70944 .58199 .71962 .57906 .71491 .57363 Mtetra
.71491 .57363 .71962 .57906 .72984 .57612 .72516 .57067 Mtetra
.72516 .57067 .72984 .57612 .74009 .57317 .73544 .5677 Mtetra
.73544 .5677 .74009 .57317 .75038 .57021 .74575 .56472 Mtetra
.74575 .56472 .75038 .57021 .76071 .56724 .75611 .56173 Mtetra
.75611 .56173 .76071 .56724 .77107 .56426 .7665 .55873 Mtetra
.7665 .55873 .77107 .56426 .78148 .56127 .77693 .55572 Mtetra
.77693 .55572 .78148 .56127 .79192 .55827 .78739 .5527 Mtetra
.655 .752 .921 r
.78739 .5527 .79192 .55827 .8024 .55526 .7979 .54967 Mtetra
.7979 .54967 .8024 .55526 .81291 .55224 .80844 .54664 Mtetra
.80844 .54664 .81291 .55224 .82347 .54921 .81903 .54359 Mtetra
.81903 .54359 .82347 .54921 .83406 .54617 .82965 .54053 Mtetra
.82965 .54053 .83406 .54617 .84469 .54312 .84031 .53746 Mtetra
.84031 .53746 .84469 .54312 .85536 .54005 .85101 .53438 Mtetra
.85101 .53438 .85536 .54005 .86608 .53698 .86175 .53129 Mtetra
.655 .753 .921 r
.86175 .53129 .86608 .53698 .87683 .53389 .87253 .52818 Mtetra
.656 .753 .921 r
.87253 .52818 .87683 .53389 .88762 .53079 .88335 .52506 Mtetra
.88335 .52506 .88762 .53079 .89844 .52767 .8942 .52192 Mtetra
.8942 .52192 .89844 .52767 .90931 .52454 .9051 .51876 Mtetra
.9051 .51876 .90931 .52454 .92022 .52139 .91604 .51559 Mtetra
.91604 .51559 .92022 .52139 .93117 .51823 .92702 .5124 Mtetra
.656 .752 .921 r
.92702 .5124 .93117 .51823 .94216 .51506 .93804 .5092 Mtetra
.657 .752 .92 r
.93804 .5092 .94216 .51506 .95319 .51187 .9491 .50598 Mtetra
.9491 .50598 .95319 .51187 .96426 .50866 .9602 .50275 Mtetra
.654 .751 .921 r
.36369 .66869 .36922 .67351 .37826 .67093 .37274 .66609 Mtetra
.37274 .66609 .37826 .67093 .38732 .66833 .38183 .66349 Mtetra
.655 .752 .921 r
.38183 .66349 .38732 .66833 .39642 .66572 .39094 .66087 Mtetra
.655 .752 .922 r
.39094 .66087 .39642 .66572 .40554 .66309 .40009 .65824 Mtetra
.655 .753 .922 r
.40009 .65824 .40554 .66309 .4147 .66046 .40926 .65559 Mtetra
.40926 .65559 .4147 .66046 .42389 .65781 .41847 .65293 Mtetra
.41847 .65293 .42389 .65781 .43311 .65515 .42771 .65025 Mtetra
.656 .753 .922 r
.42771 .65025 .43311 .65515 .44236 .65247 .43699 .64756 Mtetra
.43699 .64756 .44236 .65247 .45164 .64979 .44629 .64485 Mtetra
.656 .753 .921 r
.44629 .64485 .45164 .64979 .46096 .64708 .45563 .64213 Mtetra
.45563 .64213 .46096 .64708 .47031 .64437 .46499 .6394 Mtetra
.46499 .6394 .47031 .64437 .47969 .64165 .4744 .63665 Mtetra
.4744 .63665 .47969 .64165 .4891 .63892 .48383 .6339 Mtetra
.48383 .6339 .4891 .63892 .49855 .63618 .4933 .63114 Mtetra
.656 .752 .921 r
.4933 .63114 .49855 .63618 .50802 .63343 .50279 .62837 Mtetra
.50279 .62837 .50802 .63343 .51753 .63068 .51233 .62559 Mtetra
.656 .752 .92 r
.51233 .62559 .51753 .63068 .52708 .62791 .52189 .6228 Mtetra
.52189 .6228 .52708 .62791 .53665 .62514 .53149 .62001 Mtetra
.53149 .62001 .53665 .62514 .54626 .62236 .54112 .61721 Mtetra
.54112 .61721 .54626 .62236 .55591 .61957 .55079 .61441 Mtetra
.656 .751 .92 r
.55079 .61441 .55591 .61957 .56558 .61678 .56049 .61159 Mtetra
.56049 .61159 .56558 .61678 .57529 .61397 .57022 .60876 Mtetra
.57022 .60876 .57529 .61397 .58504 .61115 .57999 .60593 Mtetra
.57999 .60593 .58504 .61115 .59482 .60833 .58979 .60308 Mtetra
.58979 .60308 .59482 .60833 .60463 .60549 .59963 .60023 Mtetra
.59963 .60023 .60463 .60549 .61448 .60265 .6095 .59737 Mtetra
.6095 .59737 .61448 .60265 .62437 .59979 .61941 .59449 Mtetra
.61941 .59449 .62437 .59979 .63428 .59692 .62935 .59161 Mtetra
.62935 .59161 .63428 .59692 .64424 .59405 .63933 .58871 Mtetra
.63933 .58871 .64424 .59405 .65423 .59116 .64934 .58581 Mtetra
.64934 .58581 .65423 .59116 .66425 .58826 .65939 .58289 Mtetra
.65939 .58289 .66425 .58826 .67431 .58536 .66947 .57996 Mtetra
.66947 .57996 .67431 .58536 .68441 .58244 .67959 .57703 Mtetra
.67959 .57703 .68441 .58244 .69454 .57951 .68975 .57408 Mtetra
.68975 .57408 .69454 .57951 .70471 .57657 .69995 .57112 Mtetra
.69995 .57112 .70471 .57657 .71491 .57363 .71018 .56815 Mtetra
.71018 .56815 .71491 .57363 .72516 .57067 .72044 .56518 Mtetra
.72044 .56518 .72516 .57067 .73544 .5677 .73075 .56219 Mtetra
.73075 .56219 .73544 .5677 .74575 .56472 .74109 .55919 Mtetra
.74109 .55919 .74575 .56472 .75611 .56173 .75147 .55618 Mtetra
.75147 .55618 .75611 .56173 .7665 .55873 .76189 .55316 Mtetra
.655 .751 .92 r
.76189 .55316 .7665 .55873 .77693 .55572 .77235 .55013 Mtetra
.655 .752 .921 r
.77235 .55013 .77693 .55572 .78739 .5527 .78284 .5471 Mtetra
.78284 .5471 .78739 .5527 .7979 .54967 .79337 .54406 Mtetra
.79337 .54406 .7979 .54967 .80844 .54664 .80394 .541 Mtetra
.80394 .541 .80844 .54664 .81903 .54359 .81456 .53794 Mtetra
.81456 .53794 .81903 .54359 .82965 .54053 .82521 .53487 Mtetra
.82521 .53487 .82965 .54053 .84031 .53746 .8359 .53179 Mtetra
.655 .753 .922 r
.8359 .53179 .84031 .53746 .85101 .53438 .84663 .52869 Mtetra
.84663 .52869 .85101 .53438 .86175 .53129 .85739 .52558 Mtetra
.85739 .52558 .86175 .53129 .87253 .52818 .8682 .52245 Mtetra
.656 .753 .922 r
.8682 .52245 .87253 .52818 .88335 .52506 .87905 .51931 Mtetra
.87905 .51931 .88335 .52506 .8942 .52192 .88994 .51615 Mtetra
.88994 .51615 .8942 .52192 .9051 .51876 .90086 .51296 Mtetra
.656 .753 .921 r
.90086 .51296 .9051 .51876 .91604 .51559 .91183 .50976 Mtetra
.657 .753 .921 r
.91183 .50976 .91604 .51559 .92702 .5124 .92284 .50654 Mtetra
.92284 .50654 .92702 .5124 .93804 .5092 .93389 .50331 Mtetra
.93389 .50331 .93804 .5092 .9491 .50598 .94497 .50006 Mtetra
.657 .752 .92 r
.94497 .50006 .9491 .50598 .9602 .50275 .9561 .4968 Mtetra
.654 .751 .921 r
.35813 .66383 .36369 .66869 .37274 .66609 .3672 .66123 Mtetra
.3672 .66123 .37274 .66609 .38183 .66349 .3763 .65862 Mtetra
.654 .752 .922 r
.3763 .65862 .38183 .66349 .39094 .66087 .38543 .656 Mtetra
.38543 .656 .39094 .66087 .40009 .65824 .3946 .65336 Mtetra
.654 .753 .922 r
.3946 .65336 .40009 .65824 .40926 .65559 .40379 .65071 Mtetra
.655 .753 .922 r
.40379 .65071 .40926 .65559 .41847 .65293 .41302 .64804 Mtetra
.655 .754 .922 r
.41302 .64804 .41847 .65293 .42771 .65025 .42228 .64535 Mtetra
.656 .754 .922 r
.42228 .64535 .42771 .65025 .43699 .64756 .43158 .64264 Mtetra
.43158 .64264 .43699 .64756 .44629 .64485 .4409 .63991 Mtetra
.4409 .63991 .44629 .64485 .45563 .64213 .45026 .63717 Mtetra
.657 .754 .922 r
.45026 .63717 .45563 .64213 .46499 .6394 .45965 .63441 Mtetra
.45965 .63441 .46499 .6394 .4744 .63665 .46907 .63164 Mtetra
.657 .754 .921 r
.46907 .63164 .4744 .63665 .48383 .6339 .47852 .62886 Mtetra
.657 .753 .921 r
.47852 .62886 .48383 .6339 .4933 .63114 .48801 .62607 Mtetra
.48801 .62607 .4933 .63114 .50279 .62837 .49753 .62328 Mtetra
.656 .753 .921 r
.49753 .62328 .50279 .62837 .51233 .62559 .50708 .62048 Mtetra
.656 .752 .921 r
.50708 .62048 .51233 .62559 .52189 .6228 .51667 .61767 Mtetra
.656 .752 .92 r
.51667 .61767 .52189 .6228 .53149 .62001 .52629 .61485 Mtetra
.52629 .61485 .53149 .62001 .54112 .61721 .53595 .61203 Mtetra
.53595 .61203 .54112 .61721 .55079 .61441 .54563 .60921 Mtetra
.54563 .60921 .55079 .61441 .56049 .61159 .55536 .60637 Mtetra
.656 .751 .92 r
.55536 .60637 .56049 .61159 .57022 .60876 .56511 .60353 Mtetra
.56511 .60353 .57022 .60876 .57999 .60593 .5749 .60067 Mtetra
.5749 .60067 .57999 .60593 .58979 .60308 .58473 .59781 Mtetra
.58473 .59781 .58979 .60308 .59963 .60023 .59459 .59493 Mtetra
.59459 .59493 .59963 .60023 .6095 .59737 .60448 .59205 Mtetra
.60448 .59205 .6095 .59737 .61941 .59449 .61441 .58916 Mtetra
.61441 .58916 .61941 .59449 .62935 .59161 .62438 .58625 Mtetra
.62438 .58625 .62935 .59161 .63933 .58871 .63438 .58334 Mtetra
.63438 .58334 .63933 .58871 .64934 .58581 .64442 .58041 Mtetra
.64442 .58041 .64934 .58581 .65939 .58289 .65449 .57748 Mtetra
.65449 .57748 .65939 .58289 .66947 .57996 .6646 .57453 Mtetra
.6646 .57453 .66947 .57996 .67959 .57703 .67475 .57158 Mtetra
.67475 .57158 .67959 .57703 .68975 .57408 .68493 .56861 Mtetra
.68493 .56861 .68975 .57408 .69995 .57112 .69515 .56563 Mtetra
.69515 .56563 .69995 .57112 .71018 .56815 .70541 .56265 Mtetra
.70541 .56265 .71018 .56815 .72044 .56518 .7157 .55965 Mtetra
.7157 .55965 .72044 .56518 .73075 .56219 .72603 .55664 Mtetra
.72603 .55664 .73075 .56219 .74109 .55919 .7364 .55362 Mtetra
.7364 .55362 .74109 .55919 .75147 .55618 .74681 .5506 Mtetra
.655 .751 .921 r
.74681 .5506 .75147 .55618 .76189 .55316 .75725 .54756 Mtetra
.655 .752 .921 r
.75725 .54756 .76189 .55316 .77235 .55013 .76773 .54452 Mtetra
.76773 .54452 .77235 .55013 .78284 .5471 .77826 .54147 Mtetra
.77826 .54147 .78284 .5471 .79337 .54406 .78882 .53841 Mtetra
.78882 .53841 .79337 .54406 .80394 .541 .79942 .53534 Mtetra
.655 .752 .922 r
.79942 .53534 .80394 .541 .81456 .53794 .81006 .53227 Mtetra
.655 .753 .922 r
.81006 .53227 .81456 .53794 .82521 .53487 .82074 .52919 Mtetra
.82074 .52919 .82521 .53487 .8359 .53179 .83145 .52609 Mtetra
.83145 .52609 .8359 .53179 .84663 .52869 .84221 .52298 Mtetra
.655 .754 .922 r
.84221 .52298 .84663 .52869 .85739 .52558 .85301 .51985 Mtetra
.85301 .51985 .85739 .52558 .8682 .52245 .86385 .5167 Mtetra
.656 .754 .922 r
.86385 .5167 .8682 .52245 .87905 .51931 .87473 .51354 Mtetra
.87473 .51354 .87905 .51931 .88994 .51615 .88564 .51035 Mtetra
.88564 .51035 .88994 .51615 .90086 .51296 .8966 .50714 Mtetra
.657 .754 .922 r
.8966 .50714 .90086 .51296 .91183 .50976 .90759 .5039 Mtetra
.657 .754 .921 r
.90759 .5039 .91183 .50976 .92284 .50654 .91863 .50065 Mtetra
.657 .753 .921 r
.91863 .50065 .92284 .50654 .93389 .50331 .92971 .49738 Mtetra
.92971 .49738 .93389 .50331 .94497 .50006 .94083 .4941 Mtetra
.657 .753 .92 r
.94083 .4941 .94497 .50006 .9561 .4968 .95198 .4908 Mtetra
.653 .751 .921 r
.35253 .65894 .35813 .66383 .3672 .66123 .36162 .65634 Mtetra
.653 .751 .922 r
.36162 .65634 .3672 .66123 .3763 .65862 .37074 .65373 Mtetra
.653 .752 .922 r
.37074 .65373 .3763 .65862 .38543 .656 .37989 .65111 Mtetra
.654 .753 .923 r
.37989 .65111 .38543 .656 .3946 .65336 .38907 .64847 Mtetra
.38907 .64847 .3946 .65336 .40379 .65071 .39829 .64581 Mtetra
.654 .754 .923 r
.39829 .64581 .40379 .65071 .41302 .64804 .40754 .64313 Mtetra
.655 .754 .923 r
.40754 .64313 .41302 .64804 .42228 .64535 .41682 .64043 Mtetra
.655 .755 .923 r
.41682 .64043 .42228 .64535 .43158 .64264 .42613 .63771 Mtetra
.656 .755 .923 r
.42613 .63771 .43158 .64264 .4409 .63991 .43547 .63497 Mtetra
.43547 .63497 .4409 .63991 .45026 .63717 .44485 .6322 Mtetra
.657 .755 .922 r
.44485 .6322 .45026 .63717 .45965 .63441 .45426 .62942 Mtetra
.45426 .62942 .45965 .63441 .46907 .63164 .46371 .62662 Mtetra
.46371 .62662 .46907 .63164 .47852 .62886 .47318 .62381 Mtetra
.657 .754 .921 r
.47318 .62381 .47852 .62886 .48801 .62607 .48269 .62099 Mtetra
.48269 .62099 .48801 .62607 .49753 .62328 .49223 .61817 Mtetra
.657 .753 .921 r
.49223 .61817 .49753 .62328 .50708 .62048 .50181 .61534 Mtetra
.50181 .61534 .50708 .62048 .51667 .61767 .51142 .6125 Mtetra
.656 .752 .921 r
.51142 .6125 .51667 .61767 .52629 .61485 .52106 .60967 Mtetra
.656 .752 .92 r
.52106 .60967 .52629 .61485 .53595 .61203 .53074 .60682 Mtetra
.53074 .60682 .53595 .61203 .54563 .60921 .54045 .60397 Mtetra
.54045 .60397 .54563 .60921 .55536 .60637 .55019 .60112 Mtetra
.55019 .60112 .55536 .60637 .56511 .60353 .55997 .59825 Mtetra
.656 .751 .92 r
.55997 .59825 .56511 .60353 .5749 .60067 .56978 .59538 Mtetra
.56978 .59538 .5749 .60067 .58473 .59781 .57963 .5925 Mtetra
.57963 .5925 .58473 .59781 .59459 .59493 .58952 .5896 Mtetra
.58952 .5896 .59459 .59493 .60448 .59205 .59944 .5867 Mtetra
.59944 .5867 .60448 .59205 .61441 .58916 .60939 .58379 Mtetra
.60939 .58379 .61441 .58916 .62438 .58625 .61938 .58087 Mtetra
.61938 .58087 .62438 .58625 .63438 .58334 .62941 .57793 Mtetra
.62941 .57793 .63438 .58334 .64442 .58041 .63947 .57499 Mtetra
.63947 .57499 .64442 .58041 .65449 .57748 .64957 .57203 Mtetra
.64957 .57203 .65449 .57748 .6646 .57453 .6597 .56907 Mtetra
.6597 .56907 .6646 .57453 .67475 .57158 .66987 .56609 Mtetra
.66987 .56609 .67475 .57158 .68493 .56861 .68008 .56311 Mtetra
.68008 .56311 .68493 .56861 .69515 .56563 .69032 .56011 Mtetra
.69032 .56011 .69515 .56563 .70541 .56265 .7006 .5571 Mtetra
.7006 .5571 .70541 .56265 .7157 .55965 .71092 .55409 Mtetra
.71092 .55409 .7157 .55965 .72603 .55664 .72128 .55106 Mtetra
.72128 .55106 .72603 .55664 .7364 .55362 .73168 .54802 Mtetra
.655 .751 .921 r
.73168 .54802 .7364 .55362 .74681 .5506 .74211 .54498 Mtetra
.655 .752 .921 r
.74211 .54498 .74681 .5506 .75725 .54756 .75258 .54193 Mtetra
.75258 .54193 .75725 .54756 .76773 .54452 .76309 .53887 Mtetra
.76309 .53887 .76773 .54452 .77826 .54147 .77364 .5358 Mtetra
.77364 .5358 .77826 .54147 .78882 .53841 .78423 .53274 Mtetra
.654 .752 .922 r
.78423 .53274 .78882 .53841 .79942 .53534 .79486 .52966 Mtetra
.654 .753 .922 r
.79486 .52966 .79942 .53534 .81006 .53227 .80553 .52658 Mtetra
.654 .753 .923 r
.80553 .52658 .81006 .53227 .82074 .52919 .81624 .52349 Mtetra
.654 .754 .923 r
.81624 .52349 .82074 .52919 .83145 .52609 .82698 .52038 Mtetra
.82698 .52038 .83145 .52609 .84221 .52298 .83777 .51726 Mtetra
.655 .755 .923 r
.83777 .51726 .84221 .52298 .85301 .51985 .8486 .51411 Mtetra
.8486 .51411 .85301 .51985 .86385 .5167 .85947 .51094 Mtetra
.656 .755 .923 r
.85947 .51094 .86385 .5167 .87473 .51354 .87037 .50775 Mtetra
.87037 .50775 .87473 .51354 .88564 .51035 .88132 .50453 Mtetra
.657 .755 .922 r
.88132 .50453 .88564 .51035 .8966 .50714 .8923 .50129 Mtetra
.8923 .50129 .8966 .50714 .90759 .5039 .90333 .49802 Mtetra
.90333 .49802 .90759 .5039 .91863 .50065 .91439 .49473 Mtetra
.658 .754 .921 r
.91439 .49473 .91863 .50065 .92971 .49738 .9255 .49142 Mtetra
.9255 .49142 .92971 .49738 .94083 .4941 .93665 .4881 Mtetra
.658 .753 .92 r
.93665 .4881 .94083 .4941 .95198 .4908 .94784 .48476 Mtetra
.652 .751 .922 r
.34689 .65403 .35253 .65894 .36162 .65634 .356 .65143 Mtetra
.356 .65143 .36162 .65634 .37074 .65373 .36514 .64882 Mtetra
.652 .752 .923 r
.36514 .64882 .37074 .65373 .37989 .65111 .37431 .64619 Mtetra
.653 .753 .923 r
.37431 .64619 .37989 .65111 .38907 .64847 .38351 .64356 Mtetra
.653 .754 .923 r
.38351 .64356 .38907 .64847 .39829 .64581 .39275 .6409 Mtetra
.654 .754 .924 r
.39275 .6409 .39829 .64581 .40754 .64313 .40201 .63822 Mtetra
.654 .755 .924 r
.40201 .63822 .40754 .64313 .41682 .64043 .41131 .63551 Mtetra
.655 .756 .924 r
.41131 .63551 .41682 .64043 .42613 .63771 .42065 .63278 Mtetra
.656 .756 .924 r
.42065 .63278 .42613 .63771 .43547 .63497 .43001 .63002 Mtetra
.656 .757 .924 r
.43001 .63002 .43547 .63497 .44485 .6322 .43941 .62724 Mtetra
.657 .757 .923 r
.43941 .62724 .44485 .6322 .45426 .62942 .44885 .62443 Mtetra
.657 .756 .923 r
.44885 .62443 .45426 .62942 .46371 .62662 .45831 .6216 Mtetra
.658 .756 .923 r
.45831 .6216 .46371 .62662 .47318 .62381 .46781 .61876 Mtetra
.658 .755 .922 r
.46781 .61876 .47318 .62381 .48269 .62099 .47734 .6159 Mtetra
.47734 .6159 .48269 .62099 .49223 .61817 .4869 .61305 Mtetra
.657 .754 .921 r
.4869 .61305 .49223 .61817 .50181 .61534 .4965 .61018 Mtetra
.657 .753 .921 r
.4965 .61018 .50181 .61534 .51142 .6125 .50613 .60732 Mtetra
.50613 .60732 .51142 .6125 .52106 .60967 .5158 .60445 Mtetra
.657 .752 .921 r
.5158 .60445 .52106 .60967 .53074 .60682 .52549 .60158 Mtetra
.656 .752 .92 r
.52549 .60158 .53074 .60682 .54045 .60397 .53523 .59871 Mtetra
.53523 .59871 .54045 .60397 .55019 .60112 .54499 .59583 Mtetra
.54499 .59583 .55019 .60112 .55997 .59825 .5548 .59295 Mtetra
.5548 .59295 .55997 .59825 .56978 .59538 .56463 .59005 Mtetra
.56463 .59005 .56978 .59538 .57963 .5925 .5745 .58715 Mtetra
.656 .751 .92 r
.5745 .58715 .57963 .5925 .58952 .5896 .58441 .58424 Mtetra
.58441 .58424 .58952 .5896 .59944 .5867 .59435 .58132 Mtetra
.59435 .58132 .59944 .5867 .60939 .58379 .60433 .57838 Mtetra
.60433 .57838 .60939 .58379 .61938 .58087 .61435 .57544 Mtetra
.61435 .57544 .61938 .58087 .62941 .57793 .6244 .57249 Mtetra
.6244 .57249 .62941 .57793 .63947 .57499 .63448 .56953 Mtetra
.63448 .56953 .63947 .57499 .64957 .57203 .6446 .56655 Mtetra
.6446 .56655 .64957 .57203 .6597 .56907 .65476 .56357 Mtetra
.65476 .56357 .6597 .56907 .66987 .56609 .66496 .56057 Mtetra
.66496 .56057 .66987 .56609 .68008 .56311 .67519 .55756 Mtetra
.67519 .55756 .68008 .56311 .69032 .56011 .68546 .55455 Mtetra
.68546 .55455 .69032 .56011 .7006 .5571 .69577 .55152 Mtetra
.69577 .55152 .7006 .5571 .71092 .55409 .70612 .54849 Mtetra
.70612 .54849 .71092 .55409 .72128 .55106 .7165 .54544 Mtetra
.655 .751 .921 r
.7165 .54544 .72128 .55106 .73168 .54802 .72692 .54239 Mtetra
.655 .752 .921 r
.72692 .54239 .73168 .54802 .74211 .54498 .73738 .53933 Mtetra
.73738 .53933 .74211 .54498 .75258 .54193 .74788 .53626 Mtetra
.74788 .53626 .75258 .54193 .76309 .53887 .75842 .53319 Mtetra
.654 .752 .922 r
.75842 .53319 .76309 .53887 .77364 .5358 .769 .53012 Mtetra
.769 .53012 .77364 .5358 .78423 .53274 .77961 .52705 Mtetra
.654 .753 .923 r
.77961 .52705 .78423 .53274 .79486 .52966 .79027 .52397 Mtetra
.653 .753 .923 r
.79027 .52397 .79486 .52966 .80553 .52658 .80097 .52088 Mtetra
.653 .754 .924 r
.80097 .52088 .80553 .52658 .81624 .52349 .81171 .51778 Mtetra
.653 .755 .924 r
.81171 .51778 .81624 .52349 .82698 .52038 .82249 .51467 Mtetra
.654 .755 .924 r
.82249 .51467 .82698 .52038 .83777 .51726 .83331 .51153 Mtetra
.654 .756 .924 r
.83331 .51153 .83777 .51726 .8486 .51411 .84416 .50837 Mtetra
.655 .756 .924 r
.84416 .50837 .8486 .51411 .85947 .51094 .85506 .50517 Mtetra
.656 .756 .924 r
.85506 .50517 .85947 .51094 .87037 .50775 .86599 .50195 Mtetra
.656 .756 .923 r
.86599 .50195 .87037 .50775 .88132 .50453 .87697 .4987 Mtetra
.657 .756 .923 r
.87697 .4987 .88132 .50453 .8923 .50129 .88798 .49541 Mtetra
.658 .756 .922 r
.88798 .49541 .8923 .50129 .90333 .49802 .89904 .49211 Mtetra
.658 .755 .922 r
.89904 .49211 .90333 .49802 .91439 .49473 .91013 .48878 Mtetra
.658 .755 .921 r
.91013 .48878 .91439 .49473 .9255 .49142 .92126 .48543 Mtetra
.659 .754 .921 r
.92126 .48543 .9255 .49142 .93665 .4881 .93244 .48206 Mtetra
.659 .753 .92 r
.93244 .48206 .93665 .4881 .94784 .48476 .94366 .47868 Mtetra
.651 .75 .922 r
.34122 .64908 .34689 .65403 .356 .65143 .35035 .64648 Mtetra
.651 .751 .923 r
.35035 .64648 .356 .65143 .36514 .64882 .3595 .64388 Mtetra
.651 .752 .923 r
.3595 .64388 .36514 .64882 .37431 .64619 .36869 .64126 Mtetra
.652 .753 .924 r
.36869 .64126 .37431 .64619 .38351 .64356 .37791 .63862 Mtetra
.652 .754 .924 r
.37791 .63862 .38351 .64356 .39275 .6409 .38717 .63597 Mtetra
.653 .755 .925 r
.38717 .63597 .39275 .6409 .40201 .63822 .39646 .63329 Mtetra
.653 .756 .925 r
.39646 .63329 .40201 .63822 .41131 .63551 .40578 .63059 Mtetra
.654 .757 .925 r
.40578 .63059 .41131 .63551 .42065 .63278 .41513 .62786 Mtetra
.655 .758 .925 r
.41513 .62786 .42065 .63278 .43001 .63002 .42452 .62509 Mtetra
.656 .758 .925 r
.42452 .62509 .43001 .63002 .43941 .62724 .43394 .62229 Mtetra
.657 .758 .925 r
.43394 .62229 .43941 .62724 .44885 .62443 .44339 .61945 Mtetra
.658 .758 .924 r
.44339 .61945 .44885 .62443 .45831 .6216 .45288 .61659 Mtetra
.658 .758 .923 r
.45288 .61659 .45831 .6216 .46781 .61876 .4624 .61371 Mtetra
.659 .757 .923 r
.4624 .61371 .46781 .61876 .47734 .6159 .47195 .61082 Mtetra
.658 .756 .922 r
.47195 .61082 .47734 .6159 .4869 .61305 .48154 .60792 Mtetra
.658 .755 .922 r
.48154 .60792 .4869 .61305 .4965 .61018 .49116 .60502 Mtetra
.658 .754 .921 r
.49116 .60502 .4965 .61018 .50613 .60732 .50081 .60212 Mtetra
.657 .754 .921 r
.50081 .60212 .50613 .60732 .5158 .60445 .5105 .59922 Mtetra
.657 .753 .921 r
.5105 .59922 .5158 .60445 .52549 .60158 .52022 .59632 Mtetra
.657 .752 .921 r
.52022 .59632 .52549 .60158 .53523 .59871 .52997 .59342 Mtetra
.656 .752 .92 r
.52997 .59342 .53523 .59871 .54499 .59583 .53976 .59052 Mtetra
.53976 .59052 .54499 .59583 .5548 .59295 .54959 .58761 Mtetra
.54959 .58761 .5548 .59295 .56463 .59005 .55945 .58469 Mtetra
.55945 .58469 .56463 .59005 .5745 .58715 .56934 .58177 Mtetra
.56934 .58177 .5745 .58715 .58441 .58424 .57927 .57884 Mtetra
.656 .751 .92 r
.57927 .57884 .58441 .58424 .59435 .58132 .58924 .5759 Mtetra
.58924 .5759 .59435 .58132 .60433 .57838 .59924 .57295 Mtetra
.59924 .57295 .60433 .57838 .61435 .57544 .60928 .56998 Mtetra
.60928 .56998 .61435 .57544 .6244 .57249 .61935 .56701 Mtetra
.61935 .56701 .6244 .57249 .63448 .56953 .62946 .56403 Mtetra
.62946 .56403 .63448 .56953 .6446 .56655 .63961 .56103 Mtetra
.63961 .56103 .6446 .56655 .65476 .56357 .64979 .55803 Mtetra
.64979 .55803 .65476 .56357 .66496 .56057 .66002 .55501 Mtetra
.66002 .55501 .66496 .56057 .67519 .55756 .67027 .55199 Mtetra
.67027 .55199 .67519 .55756 .68546 .55455 .68057 .54895 Mtetra
.68057 .54895 .68546 .55455 .69577 .55152 .6909 .54591 Mtetra
.6909 .54591 .69577 .55152 .70612 .54849 .70128 .54285 Mtetra
.655 .751 .921 r
.70128 .54285 .70612 .54849 .7165 .54544 .71169 .53979 Mtetra
.655 .752 .921 r
.71169 .53979 .7165 .54544 .72692 .54239 .72213 .53672 Mtetra
.72213 .53672 .72692 .54239 .73738 .53933 .73262 .53365 Mtetra
.73262 .53365 .73738 .53933 .74788 .53626 .74315 .53057 Mtetra
.654 .752 .922 r
.74315 .53057 .74788 .53626 .75842 .53319 .75371 .5275 Mtetra
.75371 .5275 .75842 .53319 .769 .53012 .76432 .52442 Mtetra
.653 .753 .923 r
.76432 .52442 .769 .53012 .77961 .52705 .77497 .52135 Mtetra
.653 .754 .924 r
.77497 .52135 .77961 .52705 .79027 .52397 .78566 .51827 Mtetra
.652 .754 .924 r
.78566 .51827 .79027 .52397 .80097 .52088 .79639 .51519 Mtetra
.652 .755 .925 r
.79639 .51519 .80097 .52088 .81171 .51778 .80715 .51209 Mtetra
.653 .756 .926 r
.80715 .51209 .81171 .51778 .82249 .51467 .81796 .50896 Mtetra
.653 .757 .926 r
.81796 .50896 .82249 .51467 .83331 .51153 .82881 .50581 Mtetra
.654 .758 .926 r
.82881 .50581 .83331 .51153 .84416 .50837 .8397 .50262 Mtetra
.655 .758 .925 r
.8397 .50262 .84416 .50837 .85506 .50517 .85062 .4994 Mtetra
.656 .758 .925 r
.85062 .4994 .85506 .50517 .86599 .50195 .86159 .49614 Mtetra
.657 .758 .924 r
.86159 .49614 .86599 .50195 .87697 .4987 .87259 .49285 Mtetra
.658 .757 .923 r
.87259 .49285 .87697 .4987 .88798 .49541 .88363 .48952 Mtetra
.88363 .48952 .88798 .49541 .89904 .49211 .89471 .48617 Mtetra
.659 .756 .922 r
.89471 .48617 .89904 .49211 .91013 .48878 .90584 .48279 Mtetra
.659 .755 .921 r
.90584 .48279 .91013 .48878 .92126 .48543 .917 .4794 Mtetra
.659 .755 .92 r
.917 .4794 .92126 .48543 .93244 .48206 .9282 .47598 Mtetra
.66 .754 .92 r
.9282 .47598 .93244 .48206 .94366 .47868 .93945 .47256 Mtetra
.651 .75 .922 r
.33552 .6441 .34122 .64908 .35035 .64648 .34466 .6415 Mtetra
.65 .751 .923 r
.34466 .6415 .35035 .64648 .3595 .64388 .35383 .6389 Mtetra
.65 .752 .924 r
.35383 .6389 .3595 .64388 .36869 .64126 .36304 .63629 Mtetra
.651 .753 .924 r
.36304 .63629 .36869 .64126 .37791 .63862 .37228 .63366 Mtetra
.651 .754 .925 r
.37228 .63366 .37791 .63862 .38717 .63597 .38155 .63102 Mtetra
.651 .755 .925 r
.38155 .63102 .38717 .63597 .39646 .63329 .39086 .62835 Mtetra
.652 .756 .926 r
.39086 .62835 .39646 .63329 .40578 .63059 .4002 .62566 Mtetra
.653 .757 .926 r
.4002 .62566 .40578 .63059 .41513 .62786 .40957 .62293 Mtetra
.654 .759 .926 r
.40957 .62293 .41513 .62786 .42452 .62509 .41898 .62016 Mtetra
.656 .76 .926 r
.41898 .62016 .42452 .62509 .43394 .62229 .42842 .61735 Mtetra
.657 .76 .926 r
.42842 .61735 .43394 .62229 .44339 .61945 .4379 .6145 Mtetra
.658 .761 .926 r
.4379 .6145 .44339 .61945 .45288 .61659 .44741 .61161 Mtetra
.659 .76 .925 r
.44741 .61161 .45288 .61659 .4624 .61371 .45695 .60869 Mtetra
.66 .76 .924 r
.45695 .60869 .4624 .61371 .47195 .61082 .46652 .60575 Mtetra
.66 .759 .923 r
.46652 .60575 .47195 .61082 .48154 .60792 .47613 .6028 Mtetra
.659 .758 .923 r
.47613 .6028 .48154 .60792 .49116 .60502 .48578 .59985 Mtetra
.659 .756 .922 r
.48578 .59985 .49116 .60502 .50081 .60212 .49545 .59691 Mtetra
.658 .755 .921 r
.49545 .59691 .50081 .60212 .5105 .59922 .50516 .59397 Mtetra
.658 .754 .921 r
.50516 .59397 .5105 .59922 .52022 .59632 .5149 .59103 Mtetra
.657 .753 .921 r
.5149 .59103 .52022 .59632 .52997 .59342 .52468 .5881 Mtetra
.52468 .5881 .52997 .59342 .53976 .59052 .5345 .58517 Mtetra
.656 .752 .921 r
.5345 .58517 .53976 .59052 .54959 .58761 .54434 .58224 Mtetra
.656 .752 .92 r
.54434 .58224 .54959 .58761 .55945 .58469 .55423 .5793 Mtetra
.55423 .5793 .55945 .58469 .56934 .58177 .56415 .57636 Mtetra
.56415 .57636 .56934 .58177 .57927 .57884 .5741 .5734 Mtetra
.5741 .5734 .57927 .57884 .58924 .5759 .58409 .57044 Mtetra
.656 .751 .92 r
.58409 .57044 .58924 .5759 .59924 .57295 .59412 .56747 Mtetra
.59412 .56747 .59924 .57295 .60928 .56998 .60418 .56449 Mtetra
.60418 .56449 .60928 .56998 .61935 .56701 .61428 .56149 Mtetra
.61428 .56149 .61935 .56701 .62946 .56403 .62441 .55849 Mtetra
.62441 .55849 .62946 .56403 .63961 .56103 .63458 .55548 Mtetra
.63458 .55548 .63961 .56103 .64979 .55803 .64479 .55245 Mtetra
.64479 .55245 .64979 .55803 .66002 .55501 .65504 .54942 Mtetra
.65504 .54942 .66002 .55501 .67027 .55199 .66532 .54637 Mtetra
.66532 .54637 .67027 .55199 .68057 .54895 .67564 .54332 Mtetra
.67564 .54332 .68057 .54895 .6909 .54591 .686 .54025 Mtetra
.655 .752 .921 r
.686 .54025 .6909 .54591 .70128 .54285 .6964 .53718 Mtetra
.6964 .53718 .70128 .54285 .71169 .53979 .70684 .5341 Mtetra
.70684 .5341 .71169 .53979 .72213 .53672 .71731 .53102 Mtetra
.654 .752 .921 r
.71731 .53102 .72213 .53672 .73262 .53365 .72783 .52794 Mtetra
.654 .752 .922 r
.72783 .52794 .73262 .53365 .74315 .53057 .73838 .52486 Mtetra
.653 .752 .923 r
.73838 .52486 .74315 .53057 .75371 .5275 .74898 .52179 Mtetra
.652 .753 .924 r
.74898 .52179 .75371 .5275 .76432 .52442 .75962 .51872 Mtetra
.652 .754 .924 r
.75962 .51872 .76432 .52442 .77497 .52135 .77029 .51566 Mtetra
.651 .755 .925 r
.77029 .51566 .77497 .52135 .78566 .51827 .78101 .51259 Mtetra
.651 .756 .926 r
.78101 .51259 .78566 .51827 .79639 .51519 .79177 .50951 Mtetra
.651 .757 .927 r
.79177 .50951 .79639 .51519 .80715 .51209 .80257 .50641 Mtetra
.652 .758 .927 r
.80257 .50641 .80715 .51209 .81796 .50896 .81341 .50328 Mtetra
.653 .759 .927 r
.81341 .50328 .81796 .50896 .82881 .50581 .82429 .5001 Mtetra
.654 .76 .927 r
.82429 .5001 .82881 .50581 .8397 .50262 .83521 .49688 Mtetra
.656 .76 .926 r
.83521 .49688 .8397 .50262 .85062 .4994 .84616 .49362 Mtetra
.657 .76 .925 r
.84616 .49362 .85062 .4994 .86159 .49614 .85715 .49031 Mtetra
.658 .759 .924 r
.85715 .49031 .86159 .49614 .87259 .49285 .86818 .48697 Mtetra
.659 .758 .923 r
.86818 .48697 .87259 .49285 .88363 .48952 .87925 .48359 Mtetra
.66 .757 .922 r
.87925 .48359 .88363 .48952 .89471 .48617 .89036 .48018 Mtetra
.89036 .48018 .89471 .48617 .90584 .48279 .90151 .47676 Mtetra
.66 .756 .921 r
.90151 .47676 .90584 .48279 .917 .4794 .9127 .47332 Mtetra
.66 .755 .92 r
.9127 .47332 .917 .4794 .9282 .47598 .92394 .46986 Mtetra
.66 .754 .92 r
.92394 .46986 .9282 .47598 .93945 .47256 .93521 .46639 Mtetra
.65 .75 .923 r
.32977 .63908 .33552 .6441 .34466 .6415 .33893 .63649 Mtetra
.33893 .63649 .34466 .6415 .35383 .6389 .34813 .63389 Mtetra
.65 .751 .924 r
.34813 .63389 .35383 .6389 .36304 .63629 .35735 .63128 Mtetra
.649 .752 .924 r
.35735 .63128 .36304 .63629 .37228 .63366 .36661 .62866 Mtetra
.649 .753 .925 r
.36661 .62866 .37228 .63366 .38155 .63102 .3759 .62603 Mtetra
.65 .754 .926 r
.3759 .62603 .38155 .63102 .39086 .62835 .38523 .62338 Mtetra
.65 .756 .927 r
.38523 .62338 .39086 .62835 .4002 .62566 .39459 .62071 Mtetra
.651 .758 .927 r
.39459 .62071 .4002 .62566 .40957 .62293 .40398 .618 Mtetra
.653 .759 .928 r
.40398 .618 .40957 .62293 .41898 .62016 .41341 .61525 Mtetra
.654 .761 .928 r
.41341 .61525 .41898 .62016 .42842 .61735 .42287 .61244 Mtetra
.656 .763 .928 r
.42287 .61244 .42842 .61735 .4379 .6145 .43237 .60958 Mtetra
.658 .763 .927 r
.43237 .60958 .4379 .6145 .44741 .61161 .4419 .60667 Mtetra
.66 .764 .927 r
.4419 .60667 .44741 .61161 .45695 .60869 .45146 .60371 Mtetra
.661 .763 .926 r
.45146 .60371 .45695 .60869 .46652 .60575 .46106 .60072 Mtetra
.661 .762 .925 r
.46106 .60072 .46652 .60575 .47613 .6028 .47069 .59771 Mtetra
.661 .76 .924 r
.47069 .59771 .47613 .6028 .48578 .59985 .48036 .59471 Mtetra
.66 .759 .923 r
.48036 .59471 .48578 .59985 .49545 .59691 .49006 .5917 Mtetra
.659 .757 .922 r
.49006 .5917 .49545 .59691 .50516 .59397 .49979 .58871 Mtetra
.659 .755 .922 r
.49979 .58871 .50516 .59397 .5149 .59103 .50956 .58573 Mtetra
.658 .754 .921 r
.50956 .58573 .5149 .59103 .52468 .5881 .51936 .58277 Mtetra
.657 .753 .921 r
.51936 .58277 .52468 .5881 .5345 .58517 .52919 .5798 Mtetra
.52919 .5798 .5345 .58517 .54434 .58224 .53907 .57684 Mtetra
.656 .752 .921 r
.53907 .57684 .54434 .58224 .55423 .5793 .54897 .57388 Mtetra
.656 .752 .92 r
.54897 .57388 .55423 .5793 .56415 .57636 .55891 .57091 Mtetra
.55891 .57091 .56415 .57636 .5741 .5734 .56889 .56794 Mtetra
.56889 .56794 .5741 .5734 .58409 .57044 .57891 .56495 Mtetra
.57891 .56495 .58409 .57044 .59412 .56747 .58896 .56196 Mtetra
.58896 .56196 .59412 .56747 .60418 .56449 .59904 .55896 Mtetra
.656 .751 .92 r
.59904 .55896 .60418 .56449 .61428 .56149 .60917 .55594 Mtetra
.60917 .55594 .61428 .56149 .62441 .55849 .61933 .55292 Mtetra
.61933 .55292 .62441 .55849 .63458 .55548 .62952 .54989 Mtetra
.62952 .54989 .63458 .55548 .64479 .55245 .63976 .54684 Mtetra
.63976 .54684 .64479 .55245 .65504 .54942 .65003 .54379 Mtetra
.65003 .54379 .65504 .54942 .66532 .54637 .66034 .54072 Mtetra
.656 .752 .92 r
.66034 .54072 .66532 .54637 .67564 .54332 .67069 .53765 Mtetra
.655 .752 .921 r
.67069 .53765 .67564 .54332 .686 .54025 .68107 .53457 Mtetra
.68107 .53457 .686 .54025 .6964 .53718 .6915 .53148 Mtetra
.6915 .53148 .6964 .53718 .70684 .5341 .70196 .52839 Mtetra
.654 .752 .922 r
.70196 .52839 .70684 .5341 .71731 .53102 .71246 .5253 Mtetra
.71246 .5253 .71731 .53102 .72783 .52794 .72301 .52222 Mtetra
.653 .753 .923 r
.72301 .52222 .72783 .52794 .73838 .52486 .73359 .51915 Mtetra
.652 .753 .924 r
.73359 .51915 .73838 .52486 .74898 .52179 .74422 .51608 Mtetra
.651 .754 .925 r
.74422 .51608 .74898 .52179 .75962 .51872 .75488 .51303 Mtetra
.65 .755 .926 r
.75488 .51303 .75962 .51872 .77029 .51566 .76559 .50999 Mtetra
.649 .757 .928 r
.76559 .50999 .77029 .51566 .78101 .51259 .77634 .50694 Mtetra
.649 .758 .929 r
.77634 .50694 .78101 .51259 .79177 .50951 .78713 .50387 Mtetra
.65 .76 .929 r
.78713 .50387 .79177 .50951 .80257 .50641 .79797 .50077 Mtetra
.651 .761 .93 r
.79797 .50077 .80257 .50641 .81341 .50328 .80883 .49762 Mtetra
.653 .762 .929 r
.80883 .49762 .81341 .50328 .82429 .5001 .81974 .49441 Mtetra
.655 .762 .928 r
.81974 .49441 .82429 .5001 .83521 .49688 .83069 .49115 Mtetra
.657 .762 .927 r
.83069 .49115 .83521 .49688 .84616 .49362 .84167 .48783 Mtetra
.658 .761 .926 r
.84167 .48783 .84616 .49362 .85715 .49031 .85269 .48446 Mtetra
.66 .76 .924 r
.85269 .48446 .85715 .49031 .86818 .48697 .86374 .48105 Mtetra
.66 .759 .923 r
.86374 .48105 .86818 .48697 .87925 .48359 .87484 .47761 Mtetra
.661 .758 .922 r
.87484 .47761 .87925 .48359 .89036 .48018 .88598 .47415 Mtetra
.661 .757 .921 r
.88598 .47415 .89036 .48018 .90151 .47676 .89716 .47068 Mtetra
.661 .756 .92 r
.89716 .47068 .90151 .47676 .9127 .47332 .90838 .46719 Mtetra
.661 .755 .92 r
.90838 .46719 .9127 .47332 .92394 .46986 .91964 .46369 Mtetra
.661 .754 .919 r
.91964 .46369 .92394 .46986 .93521 .46639 .93095 .46018 Mtetra
.65 .75 .923 r
.32399 .63404 .32977 .63908 .33893 .63649 .33317 .63143 Mtetra
.649 .75 .923 r
.33317 .63143 .33893 .63649 .34813 .63389 .34239 .62882 Mtetra
.34239 .62882 .34813 .63389 .35735 .63128 .35163 .62621 Mtetra
.649 .751 .924 r
.35163 .62621 .35735 .63128 .36661 .62866 .36091 .62359 Mtetra
.648 .751 .925 r
.36091 .62359 .36661 .62866 .3759 .62603 .37022 .62098 Mtetra
.648 .752 .926 r
.37022 .62098 .3759 .62603 .38523 .62338 .37956 .61835 Mtetra
.648 .754 .927 r
.37956 .61835 .38523 .62338 .39459 .62071 .38894 .61571 Mtetra
.649 .756 .928 r
.38894 .61571 .39459 .62071 .40398 .618 .39835 .61303 Mtetra
.65 .759 .929 r
.39835 .61303 .40398 .618 .41341 .61525 .4078 .61031 Mtetra
.652 .761 .929 r
.4078 .61031 .41341 .61525 .42287 .61244 .41728 .60754 Mtetra
.655 .764 .93 r
.41728 .60754 .42287 .61244 .43237 .60958 .4268 .60469 Mtetra
.657 .766 .929 r
.4268 .60469 .43237 .60958 .4419 .60667 .43635 .60177 Mtetra
.66 .767 .929 r
.43635 .60177 .4419 .60667 .45146 .60371 .44594 .59878 Mtetra
.662 .767 .928 r
.44594 .59878 .45146 .60371 .46106 .60072 .45556 .59575 Mtetra
.663 .766 .927 r
.45556 .59575 .46106 .60072 .47069 .59771 .46522 .59268 Mtetra
.663 .764 .925 r
.46522 .59268 .47069 .59771 .48036 .59471 .47491 .5896 Mtetra
.662 .762 .924 r
.47491 .5896 .48036 .59471 .49006 .5917 .48463 .58653 Mtetra
.661 .76 .923 r
.48463 .58653 .49006 .5917 .49979 .58871 .49438 .58347 Mtetra
.66 .758 .922 r
.49438 .58347 .49979 .58871 .50956 .58573 .50417 .58044 Mtetra
.659 .756 .922 r
.50417 .58044 .50956 .58573 .51936 .58277 .514 .57742 Mtetra
.658 .755 .921 r
.514 .57742 .51936 .58277 .52919 .5798 .52386 .57442 Mtetra
.657 .754 .921 r
.52386 .57442 .52919 .5798 .53907 .57684 .53375 .57142 Mtetra
.657 .753 .921 r
.53375 .57142 .53907 .57684 .54897 .57388 .54368 .56843 Mtetra
.656 .752 .921 r
.54368 .56843 .54897 .57388 .55891 .57091 .55365 .56544 Mtetra
.55365 .56544 .55891 .57091 .56889 .56794 .56365 .56244 Mtetra
.656 .752 .92 r
.56365 .56244 .56889 .56794 .57891 .56495 .57369 .55943 Mtetra
.57369 .55943 .57891 .56495 .58896 .56196 .58376 .55642 Mtetra
.58376 .55642 .58896 .56196 .59904 .55896 .59387 .55339 Mtetra
.59387 .55339 .59904 .55896 .60917 .55594 .60402 .55036 Mtetra
.60402 .55036 .60917 .55594 .61933 .55292 .61421 .54731 Mtetra
.61421 .54731 .61933 .55292 .62952 .54989 .62443 .54426 Mtetra
.62443 .54426 .62952 .54989 .63976 .54684 .63469 .5412 Mtetra
.63469 .5412 .63976 .54684 .65003 .54379 .64498 .53812 Mtetra
.656 .752 .921 r
.64498 .53812 .65003 .54379 .66034 .54072 .65532 .53504 Mtetra
.655 .752 .921 r
.65532 .53504 .66034 .54072 .67069 .53765 .66569 .53195 Mtetra
.66569 .53195 .67069 .53765 .68107 .53457 .67611 .52885 Mtetra
.67611 .52885 .68107 .53457 .6915 .53148 .68656 .52576 Mtetra
.654 .752 .922 r
.68656 .52576 .6915 .53148 .70196 .52839 .69705 .52266 Mtetra
.653 .752 .922 r
.69705 .52266 .70196 .52839 .71246 .5253 .70758 .51957 Mtetra
.652 .753 .923 r
.70758 .51957 .71246 .5253 .72301 .52222 .71815 .5165 Mtetra
.651 .753 .925 r
.71815 .5165 .72301 .52222 .73359 .51915 .72877 .51344 Mtetra
.65 .754 .926 r
.72877 .51344 .73359 .51915 .74422 .51608 .73942 .5104 Mtetra
.648 .756 .928 r
.73942 .5104 .74422 .51608 .75488 .51303 .75012 .50738 Mtetra
.647 .757 .929 r
.75012 .50738 .75488 .51303 .76559 .50999 .76086 .50437 Mtetra
.647 .759 .931 r
.76086 .50437 .76559 .50999 .77634 .50694 .77165 .50134 Mtetra
.648 .761 .932 r
.77165 .50134 .77634 .50694 .78713 .50387 .78247 .49828 Mtetra
.649 .763 .932 r
.78247 .49828 .78713 .50387 .79797 .50077 .79333 .49517 Mtetra
.652 .764 .932 r
.79333 .49517 .79797 .50077 .80883 .49762 .80423 .49198 Mtetra
.654 .765 .931 r
.80423 .49198 .80883 .49762 .81974 .49441 .81516 .48872 Mtetra
.657 .764 .929 r
.81516 .48872 .81974 .49441 .83069 .49115 .82613 .48539 Mtetra
.659 .763 .927 r
.82613 .48539 .83069 .49115 .84167 .48783 .83714 .48199 Mtetra
.661 .762 .925 r
.83714 .48199 .84167 .48783 .85269 .48446 .84819 .47854 Mtetra
.662 .76 .923 r
.84819 .47854 .85269 .48446 .86374 .48105 .85927 .47506 Mtetra
.662 .758 .922 r
.85927 .47506 .86374 .48105 .87484 .47761 .87039 .47156 Mtetra
.662 .757 .921 r
.87039 .47156 .87484 .47761 .88598 .47415 .88156 .46804 Mtetra
.662 .756 .92 r
.88156 .46804 .88598 .47415 .89716 .47068 .89277 .46452 Mtetra
.662 .755 .919 r
.89277 .46452 .89716 .47068 .90838 .46719 .90402 .461 Mtetra
.661 .754 .919 r
.90402 .461 .90838 .46719 .91964 .46369 .91531 .45746 Mtetra
.91531 .45746 .91964 .46369 .93095 .46018 .92665 .45393 Mtetra
.65 .75 .923 r
.31818 .62896 .32399 .63404 .33317 .63143 .32738 .62633 Mtetra
.65 .749 .922 r
.32738 .62633 .33317 .63143 .34239 .62882 .33661 .62369 Mtetra
.649 .749 .923 r
.33661 .62369 .34239 .62882 .35163 .62621 .34587 .62106 Mtetra
.648 .749 .923 r
.34587 .62106 .35163 .62621 .36091 .62359 .35517 .61844 Mtetra
.647 .749 .924 r
.35517 .61844 .36091 .62359 .37022 .62098 .3645 .61583 Mtetra
.647 .75 .924 r
.3645 .61583 .37022 .62098 .37956 .61835 .37386 .61322 Mtetra
.646 .751 .926 r
.37386 .61322 .37956 .61835 .38894 .61571 .38325 .61062 Mtetra
.646 .753 .927 r
.38325 .61062 .38894 .61571 .39835 .61303 .39268 .608 Mtetra
.647 .756 .929 r
.39268 .608 .39835 .61303 .4078 .61031 .40215 .60534 Mtetra
.649 .76 .93 r
.40215 .60534 .4078 .61031 .41728 .60754 .41165 .60262 Mtetra
.652 .764 .931 r
.41165 .60262 .41728 .60754 .4268 .60469 .42119 .59982 Mtetra
.655 .767 .932 r
.42119 .59982 .4268 .60469 .43635 .60177 .43076 .59693 Mtetra
.659 .77 .931 r
.43076 .59693 .43635 .60177 .44594 .59878 .44037 .59393 Mtetra
.662 .771 .93 r
.44037 .59393 .44594 .59878 .45556 .59575 .45002 .59086 Mtetra
.664 .771 .929 r
.45002 .59086 .45556 .59575 .46522 .59268 .4597 .58773 Mtetra
.665 .769 .928 r
.4597 .58773 .46522 .59268 .47491 .5896 .46941 .58457 Mtetra
.665 .767 .926 r
.46941 .58457 .47491 .5896 .48463 .58653 .47916 .58141 Mtetra
.664 .764 .925 r
.47916 .58141 .48463 .58653 .49438 .58347 .48894 .57827 Mtetra
.662 .761 .924 r
.48894 .57827 .49438 .58347 .50417 .58044 .49876 .57516 Mtetra
.661 .759 .923 r
.49876 .57516 .50417 .58044 .514 .57742 .5086 .57208 Mtetra
.659 .756 .922 r
.5086 .57208 .514 .57742 .52386 .57442 .51849 .56903 Mtetra
.658 .755 .921 r
.51849 .56903 .52386 .57442 .53375 .57142 .5284 .56599 Mtetra
.657 .754 .921 r
.5284 .56599 .53375 .57142 .54368 .56843 .53836 .56296 Mtetra
.657 .753 .921 r
.53836 .56296 .54368 .56843 .55365 .56544 .54835 .55993 Mtetra
.656 .753 .921 r
.54835 .55993 .55365 .56544 .56365 .56244 .55837 .55691 Mtetra
.656 .752 .921 r
.55837 .55691 .56365 .56244 .57369 .55943 .56843 .55388 Mtetra
.56843 .55388 .57369 .55943 .58376 .55642 .57853 .55084 Mtetra
.57853 .55084 .58376 .55642 .59387 .55339 .58867 .54779 Mtetra
.58867 .54779 .59387 .55339 .60402 .55036 .59884 .54474 Mtetra
.59884 .54474 .60402 .55036 .61421 .54731 .60905 .54167 Mtetra
.60905 .54167 .61421 .54731 .62443 .54426 .6193 .5386 Mtetra
.6193 .5386 .62443 .54426 .63469 .5412 .62958 .53552 Mtetra
.655 .752 .921 r
.62958 .53552 .63469 .5412 .64498 .53812 .63991 .53242 Mtetra
.63991 .53242 .64498 .53812 .65532 .53504 .65027 .52932 Mtetra
.65027 .52932 .65532 .53504 .66569 .53195 .66067 .52622 Mtetra
.66067 .52622 .66569 .53195 .67611 .52885 .67111 .52311 Mtetra
.654 .752 .922 r
.67111 .52311 .67611 .52885 .68656 .52576 .68159 .52001 Mtetra
.653 .752 .923 r
.68159 .52001 .68656 .52576 .69705 .52266 .69211 .51692 Mtetra
.652 .753 .924 r
.69211 .51692 .69705 .52266 .70758 .51957 .70267 .51384 Mtetra
.65 .754 .925 r
.70267 .51384 .70758 .51957 .71815 .5165 .71327 .51079 Mtetra
.649 .755 .927 r
.71327 .51079 .71815 .5165 .72877 .51344 .72391 .50777 Mtetra
.647 .756 .929 r
.72391 .50777 .72877 .51344 .73942 .5104 .7346 .50478 Mtetra
.645 .758 .931 r
.7346 .50478 .73942 .5104 .75012 .50738 .74533 .5018 Mtetra
.644 .76 .933 r
.74533 .5018 .75012 .50738 .76086 .50437 .75611 .49883 Mtetra
.644 .763 .935 r
.75611 .49883 .76086 .50437 .77165 .50134 .76692 .49582 Mtetra
.646 .765 .935 r
.76692 .49582 .77165 .50134 .78247 .49828 .77778 .49276 Mtetra
.649 .767 .935 r
.77778 .49276 .78247 .49828 .79333 .49517 .78867 .48962 Mtetra
.653 .768 .934 r
.78867 .48962 .79333 .49517 .80423 .49198 .7996 .48636 Mtetra
.657 .768 .931 r
.7996 .48636 .80423 .49198 .81516 .48872 .81056 .48302 Mtetra
.66 .767 .929 r
.81056 .48302 .81516 .48872 .82613 .48539 .82155 .47958 Mtetra
.662 .764 .926 r
.82155 .47958 .82613 .48539 .83714 .48199 .83258 .47608 Mtetra
.663 .762 .923 r
.83258 .47608 .83714 .48199 .84819 .47854 .84365 .47253 Mtetra
.664 .759 .921 r
.84365 .47253 .84819 .47854 .85927 .47506 .85476 .46897 Mtetra
.664 .757 .92 r
.85476 .46897 .85927 .47506 .87039 .47156 .86591 .4654 Mtetra
.663 .755 .919 r
.86591 .4654 .87039 .47156 .88156 .46804 .8771 .46183 Mtetra
.662 .754 .918 r
.8771 .46183 .88156 .46804 .89277 .46452 .88834 .45828 Mtetra
.662 .753 .918 r
.88834 .45828 .89277 .46452 .90402 .461 .89962 .45473 Mtetra
.661 .753 .918 r
.89962 .45473 .90402 .461 .91531 .45746 .91095 .45118 Mtetra
.661 .753 .919 r
.91095 .45118 .91531 .45746 .92665 .45393 .92232 .44763 Mtetra
.652 .75 .922 r
.31232 .62385 .31818 .62896 .32738 .62633 .32154 .62117 Mtetra
.651 .749 .921 r
.32154 .62117 .32738 .62633 .33661 .62369 .3308 .61849 Mtetra
.65 .748 .921 r
.3308 .61849 .33661 .62369 .34587 .62106 .34008 .61582 Mtetra
.649 .747 .921 r
.34008 .61582 .34587 .62106 .35517 .61844 .3494 .61317 Mtetra
.647 .746 .921 r
.3494 .61317 .35517 .61844 .3645 .61583 .35874 .61054 Mtetra
.646 .746 .922 r
.35874 .61054 .3645 .61583 .37386 .61322 .36812 .60795 Mtetra
.644 .746 .923 r
.36812 .60795 .37386 .61322 .38325 .61062 .37754 .60538 Mtetra
.643 .748 .925 r
.37754 .60538 .38325 .61062 .39268 .608 .38698 .60282 Mtetra
.643 .751 .927 r
.38698 .60282 .39268 .608 .40215 .60534 .39647 .60024 Mtetra
.644 .755 .93 r
.39647 .60024 .40215 .60534 .41165 .60262 .40599 .59762 Mtetra
.647 .76 .932 r
.40599 .59762 .41165 .60262 .42119 .59982 .41554 .59491 Mtetra
.651 .766 .933 r
.41554 .59491 .42119 .59982 .43076 .59693 .42514 .59209 Mtetra
.656 .771 .934 r
.42514 .59209 .43076 .59693 .44037 .59393 .43477 .58913 Mtetra
.661 .774 .933 r
.43477 .58913 .44037 .59393 .45002 .59086 .44444 .58606 Mtetra
.665 .776 .932 r
.44444 .58606 .45002 .59086 .4597 .58773 .45414 .58288 Mtetra
.667 .775 .931 r
.45414 .58288 .4597 .58773 .46941 .58457 .46388 .57965 Mtetra
.667 .773 .929 r
.46388 .57965 .46941 .58457 .47916 .58141 .47365 .57639 Mtetra
.667 .77 .927 r
.47365 .57639 .47916 .58141 .48894 .57827 .48346 .57315 Mtetra
.665 .766 .926 r
.48346 .57315 .48894 .57827 .49876 .57516 .4933 .56995 Mtetra
.663 .763 .924 r
.4933 .56995 .49876 .57516 .5086 .57208 .50317 .56678 Mtetra
.661 .76 .923 r
.50317 .56678 .5086 .57208 .51849 .56903 .51308 .56365 Mtetra
.66 .757 .922 r
.51308 .56365 .51849 .56903 .5284 .56599 .52302 .56056 Mtetra
.658 .756 .922 r
.52302 .56056 .5284 .56599 .53836 .56296 .533 .55748 Mtetra
.657 .754 .921 r
.533 .55748 .53836 .56296 .54835 .55993 .54301 .55442 Mtetra
.54301 .55442 .54835 .55993 .55837 .55691 .55306 .55136 Mtetra
.656 .753 .921 r
.55306 .55136 .55837 .55691 .56843 .55388 .56315 .5483 Mtetra
.56315 .5483 .56843 .55388 .57853 .55084 .57327 .54524 Mtetra
.656 .752 .921 r
.57327 .54524 .57853 .55084 .58867 .54779 .58343 .54217 Mtetra
.58343 .54217 .58867 .54779 .59884 .54474 .59363 .53909 Mtetra
.59363 .53909 .59884 .54474 .60905 .54167 .60386 .536 Mtetra
.60386 .536 .60905 .54167 .6193 .5386 .61413 .53291 Mtetra
.655 .752 .921 r
.61413 .53291 .6193 .5386 .62958 .53552 .62444 .52981 Mtetra
.62444 .52981 .62958 .53552 .63991 .53242 .63479 .5267 Mtetra
.63479 .5267 .63991 .53242 .65027 .52932 .64518 .52359 Mtetra
.655 .752 .922 r
.64518 .52359 .65027 .52932 .66067 .52622 .65561 .52048 Mtetra
.654 .753 .922 r
.65561 .52048 .66067 .52622 .67111 .52311 .66608 .51737 Mtetra
.653 .753 .923 r
.66608 .51737 .67111 .52311 .68159 .52001 .67658 .51427 Mtetra
.651 .753 .924 r
.67658 .51427 .68159 .52001 .69211 .51692 .68713 .51119 Mtetra
.65 .754 .926 r
.68713 .51119 .69211 .51692 .70267 .51384 .69772 .50815 Mtetra
.647 .755 .928 r
.69772 .50815 .70267 .51384 .71327 .51079 .70835 .50514 Mtetra
.645 .757 .931 r
.70835 .50514 .71327 .51079 .72391 .50777 .71903 .50218 Mtetra
.642 .759 .933 r
.71903 .50218 .72391 .50777 .7346 .50478 .72975 .49925 Mtetra
.641 .762 .936 r
.72975 .49925 .7346 .50478 .74533 .5018 .74052 .49633 Mtetra
.641 .765 .938 r
.74052 .49633 .74533 .5018 .75611 .49883 .75133 .49339 Mtetra
.642 .768 .939 r
.75133 .49339 .75611 .49883 .76692 .49582 .76218 .4904 Mtetra
.646 .77 .939 r
.76218 .4904 .76692 .49582 .77778 .49276 .77306 .48729 Mtetra
.651 .771 .937 r
.77306 .48729 .77778 .49276 .78867 .48962 .78398 .48406 Mtetra
.657 .771 .934 r
.78398 .48406 .78867 .48962 .7996 .48636 .79493 .4807 Mtetra
.661 .769 .93 r
.79493 .4807 .7996 .48636 .81056 .48302 .80591 .47721 Mtetra
.664 .766 .926 r
.80591 .47721 .81056 .48302 .82155 .47958 .81692 .47363 Mtetra
.666 .762 .922 r
.81692 .47363 .82155 .47958 .83258 .47608 .82798 .47 Mtetra
.667 .758 .919 r
.82798 .47 .83258 .47608 .84365 .47253 .83907 .46635 Mtetra
.666 .755 .917 r
.83907 .46635 .84365 .47253 .85476 .46897 .8502 .46271 Mtetra
.665 .753 .916 r
.8502 .46271 .85476 .46897 .86591 .4654 .86138 .45909 Mtetra
.663 .751 .916 r
.86138 .45909 .86591 .4654 .8771 .46183 .87261 .45549 Mtetra
.662 .751 .916 r
.87261 .45549 .8771 .46183 .88834 .45828 .88388 .45192 Mtetra
.661 .751 .917 r
.88388 .45192 .88834 .45828 .89962 .45473 .89519 .44837 Mtetra
.66 .751 .917 r
.89519 .44837 .89962 .45473 .91095 .45118 .90655 .44483 Mtetra
.66 .752 .918 r
.90655 .44483 .91095 .45118 .92232 .44763 .91796 .44128 Mtetra
.654 .751 .921 r
.30643 .61871 .31232 .62385 .32154 .62117 .31567 .61596 Mtetra
.653 .749 .92 r
.31567 .61596 .32154 .62117 .3308 .61849 .32495 .6132 Mtetra
.653 .747 .919 r
.32495 .6132 .3308 .61849 .34008 .61582 .33426 .61047 Mtetra
.651 .744 .918 r
.33426 .61047 .34008 .61582 .3494 .61317 .34359 .60776 Mtetra
.649 .742 .918 r
.34359 .60776 .3494 .61317 .35874 .61054 .35296 .60509 Mtetra
.646 .741 .918 r
.35296 .60509 .35874 .61054 .36812 .60795 .36236 .60248 Mtetra
.643 .74 .919 r
.36236 .60248 .36812 .60795 .37754 .60538 .37179 .59993 Mtetra
.641 .741 .921 r
.37179 .59993 .37754 .60538 .38698 .60282 .38126 .59742 Mtetra
.638 .743 .924 r
.38126 .59742 .38698 .60282 .39647 .60024 .39075 .59495 Mtetra
.638 .747 .927 r
.39075 .59495 .39647 .60024 .40599 .59762 .40029 .59245 Mtetra
.64 .753 .931 r
.40029 .59245 .40599 .59762 .41554 .59491 .40986 .5899 Mtetra
.644 .761 .934 r
.40986 .5899 .41554 .59491 .42514 .59209 .41947 .58722 Mtetra
.651 .769 .936 r
.41947 .58722 .42514 .59209 .43477 .58913 .42912 .58437 Mtetra
.657 .776 .937 r
.42912 .58437 .43477 .58913 .44444 .58606 .43882 .58135 Mtetra
.664 .781 .936 r
.43882 .58135 .44444 .58606 .45414 .58288 .44854 .57816 Mtetra
.668 .782 .934 r
.44854 .57816 .45414 .58288 .46388 .57965 .45831 .57487 Mtetra
.67 .781 .932 r
.45831 .57487 .46388 .57965 .47365 .57639 .46811 .57151 Mtetra
.67 .778 .93 r
.46811 .57151 .47365 .57639 .48346 .57315 .47794 .56815 Mtetra
.669 .773 .928 r
.47794 .56815 .48346 .57315 .4933 .56995 .4878 .56483 Mtetra
.667 .769 .926 r
.4878 .56483 .4933 .56995 .50317 .56678 .4977 .56155 Mtetra
.664 .765 .925 r
.4977 .56155 .50317 .56678 .51308 .56365 .50763 .55833 Mtetra
.662 .761 .924 r
.50763 .55833 .51308 .56365 .52302 .56056 .5176 .55515 Mtetra
.66 .758 .923 r
.5176 .55515 .52302 .56056 .533 .55748 .5276 .55201 Mtetra
.659 .756 .922 r
.5276 .55201 .533 .55748 .54301 .55442 .53764 .5489 Mtetra
.658 .755 .922 r
.53764 .5489 .54301 .55442 .55306 .55136 .54771 .5458 Mtetra
.657 .754 .922 r
.54771 .5458 .55306 .55136 .56315 .5483 .55782 .54271 Mtetra
.656 .753 .921 r
.55782 .54271 .56315 .5483 .57327 .54524 .56797 .53961 Mtetra
.56797 .53961 .57327 .54524 .58343 .54217 .57815 .53652 Mtetra
.57815 .53652 .58343 .54217 .59363 .53909 .58838 .53342 Mtetra
.58838 .53342 .59363 .53909 .60386 .536 .59864 .53031 Mtetra
.655 .753 .921 r
.59864 .53031 .60386 .536 .61413 .53291 .60893 .5272 Mtetra
.60893 .5272 .61413 .53291 .62444 .52981 .61927 .52408 Mtetra
.655 .753 .922 r
.61927 .52408 .62444 .52981 .63479 .5267 .62965 .52096 Mtetra
.654 .753 .922 r
.62965 .52096 .63479 .5267 .64518 .52359 .64006 .51784 Mtetra
.654 .753 .923 r
.64006 .51784 .64518 .52359 .65561 .52048 .65052 .51473 Mtetra
.653 .753 .924 r
.65052 .51473 .65561 .52048 .66608 .51737 .66101 .51163 Mtetra
.651 .754 .925 r
.66101 .51163 .66608 .51737 .67658 .51427 .67155 .50855 Mtetra
.649 .755 .927 r
.67155 .50855 .67658 .51427 .68713 .51119 .68212 .50551 Mtetra
.646 .756 .929 r
.68212 .50551 .68713 .51119 .69772 .50815 .69275 .50252 Mtetra
.643 .758 .932 r
.69275 .50252 .69772 .50815 .70835 .50514 .70341 .49959 Mtetra
.64 .76 .936 r
.70341 .49959 .70835 .50514 .71903 .50218 .71413 .4967 Mtetra
.637 .763 .939 r
.71413 .4967 .71903 .50218 .72975 .49925 .72488 .49385 Mtetra
.636 .767 .942 r
.72488 .49385 .72975 .49925 .74052 .49633 .73569 .491 Mtetra
.638 .771 .944 r
.73569 .491 .74052 .49633 .75133 .49339 .74653 .48808 Mtetra
.642 .774 .944 r
.74653 .48808 .75133 .49339 .76218 .4904 .75741 .48505 Mtetra
.649 .776 .941 r
.75741 .48505 .76218 .4904 .77306 .48729 .76831 .48185 Mtetra
.656 .776 .937 r
.76831 .48185 .77306 .48729 .78398 .48406 .77925 .47847 Mtetra
.663 .774 .931 r
.77925 .47847 .78398 .48406 .79493 .4807 .79022 .47491 Mtetra
.668 .769 .925 r
.79022 .47491 .79493 .4807 .80591 .47721 .80122 .47123 Mtetra
.67 .763 .92 r
.80122 .47123 .80591 .47721 .81692 .47363 .81225 .46747 Mtetra
.671 .758 .916 r
.81225 .46747 .81692 .47363 .82798 .47 .82332 .46369 Mtetra
.669 .753 .913 r
.82332 .46369 .82798 .47 .83907 .46635 .83444 .45994 Mtetra
.668 .749 .912 r
.83444 .45994 .83907 .46635 .8502 .46271 .8456 .45624 Mtetra
.665 .747 .911 r
.8456 .45624 .8502 .46271 .86138 .45909 .85681 .45259 Mtetra
.663 .746 .912 r
.85681 .45259 .86138 .45909 .87261 .45549 .86806 .449 Mtetra
.661 .746 .913 r
.86806 .449 .87261 .45549 .88388 .45192 .87937 .44544 Mtetra
.659 .747 .915 r
.87937 .44544 .88388 .45192 .89519 .44837 .89072 .44192 Mtetra
.658 .748 .917 r
.89072 .44192 .89519 .44837 .90655 .44483 .90212 .43841 Mtetra
.658 .75 .918 r
.90212 .43841 .90655 .44483 .91796 .44128 .91357 .43489 Mtetra
.657 .752 .92 r
.3005 .61354 .30643 .61871 .31567 .61596 .30977 .6107 Mtetra
.656 .749 .918 r
.30977 .6107 .31567 .61596 .32495 .6132 .31907 .60786 Mtetra
.656 .746 .917 r
.31907 .60786 .32495 .6132 .33426 .61047 .3284 .60503 Mtetra
.654 .743 .915 r
.3284 .60503 .33426 .61047 .34359 .60776 .33776 .60223 Mtetra
.652 .74 .914 r
.33776 .60223 .34359 .60776 .35296 .60509 .34715 .59948 Mtetra
.649 .737 .914 r
.34715 .59948 .35296 .60509 .36236 .60248 .35657 .5968 Mtetra
.644 .734 .914 r
.35657 .5968 .36236 .60248 .37179 .59993 .36602 .59422 Mtetra
.64 .732 .915 r
.36602 .59422 .37179 .59993 .38126 .59742 .3755 .59172 Mtetra
.635 .732 .918 r
.3755 .59172 .38126 .59742 .39075 .59495 .38501 .58933 Mtetra
.633 .735 .921 r
.38501 .58933 .39075 .59495 .40029 .59245 .39456 .58697 Mtetra
.632 .74 .926 r
.39456 .58697 .40029 .59245 .40986 .5899 .40415 .5846 Mtetra
.635 .749 .931 r
.40415 .5846 .40986 .5899 .41947 .58722 .41377 .58214 Mtetra
.641 .76 .935 r
.41377 .58214 .41947 .58722 .42912 .58437 .42344 .5795 Mtetra
.649 .771 .938 r
.42344 .5795 .42912 .58437 .43882 .58135 .43315 .57665 Mtetra
.659 .781 .939 r
.43315 .57665 .43882 .58135 .44854 .57816 .4429 .57354 Mtetra
.666 .787 .938 r
.4429 .57354 .44854 .57816 .45831 .57487 .45269 .57025 Mtetra
.672 .789 .937 r
.45269 .57025 .45831 .57487 .46811 .57151 .46252 .56682 Mtetra
.674 .788 .935 r
.46252 .56682 .46811 .57151 .47794 .56815 .47238 .56334 Mtetra
.673 .783 .932 r
.47238 .56334 .47794 .56815 .4878 .56483 .48227 .55988 Mtetra
.671 .778 .93 r
.48227 .55988 .4878 .56483 .4977 .56155 .49219 .55646 Mtetra
.668 .773 .928 r
.49219 .55646 .4977 .56155 .50763 .55833 .50215 .55311 Mtetra
.665 .768 .926 r
.50215 .55311 .50763 .55833 .5176 .55515 .51214 .54983 Mtetra
.662 .764 .925 r
.51214 .54983 .5176 .55515 .5276 .55201 .52217 .5466 Mtetra
.66 .761 .924 r
.52217 .5466 .5276 .55201 .53764 .5489 .53223 .54342 Mtetra
.659 .758 .923 r
.53223 .54342 .53764 .5489 .54771 .5458 .54233 .54026 Mtetra
.658 .757 .923 r
.54233 .54026 .54771 .5458 .55782 .54271 .55246 .53713 Mtetra
.657 .755 .923 r
.55246 .53713 .55782 .54271 .56797 .53961 .56263 .534 Mtetra
.656 .755 .922 r
.56263 .534 .56797 .53961 .57815 .53652 .57284 .53087 Mtetra
.656 .754 .922 r
.57284 .53087 .57815 .53652 .58838 .53342 .58309 .52775 Mtetra
.58309 .52775 .58838 .53342 .59864 .53031 .59338 .52462 Mtetra
.655 .754 .922 r
.59338 .52462 .59864 .53031 .60893 .5272 .6037 .52149 Mtetra
.655 .754 .923 r
.6037 .52149 .60893 .5272 .61927 .52408 .61406 .51836 Mtetra
.654 .754 .923 r
.61406 .51836 .61927 .52408 .62965 .52096 .62447 .51523 Mtetra
.653 .754 .924 r
.62447 .51523 .62965 .52096 .64006 .51784 .63491 .51211 Mtetra
.652 .755 .925 r
.63491 .51211 .64006 .51784 .65052 .51473 .64539 .50901 Mtetra
.65 .755 .926 r
.64539 .50901 .65052 .51473 .66101 .51163 .65591 .50594 Mtetra
.648 .756 .929 r
.65591 .50594 .66101 .51163 .67155 .50855 .66648 .50291 Mtetra
.645 .758 .931 r
.66648 .50291 .67155 .50855 .68212 .50551 .67709 .49994 Mtetra
.641 .76 .935 r
.67709 .49994 .68212 .50551 .69275 .50252 .68774 .49703 Mtetra
.636 .763 .939 r
.68774 .49703 .69275 .50252 .70341 .49959 .69845 .4942 Mtetra
.633 .766 .943 r
.69845 .4942 .70341 .49959 .71413 .4967 .7092 .49142 Mtetra
.631 .77 .947 r
.7092 .49142 .71413 .4967 .72488 .49385 .71999 .48865 Mtetra
.632 .775 .949 r
.71999 .48865 .72488 .49385 .73569 .491 .73083 .48583 Mtetra
.637 .779 .949 r
.73083 .48583 .73569 .491 .74653 .48808 .7417 .48286 Mtetra
.645 .781 .946 r
.7417 .48286 .74653 .48808 .75741 .48505 .7526 .47971 Mtetra
.656 .781 .94 r
.7526 .47971 .75741 .48505 .76831 .48185 .76353 .4763 Mtetra
.666 .777 .932 r
.76353 .4763 .76831 .48185 .77925 .47847 .77448 .47266 Mtetra
.673 .77 .924 r
.77448 .47266 .77925 .47847 .79022 .47491 .78546 .46884 Mtetra
.676 .763 .916 r
.78546 .46884 .79022 .47491 .80122 .47123 .79647 .46491 Mtetra
.676 .755 .91 r
.79647 .46491 .80122 .47123 .81225 .46747 .80752 .46097 Mtetra
.674 .749 .907 r
.80752 .46097 .81225 .46747 .82332 .46369 .81861 .45706 Mtetra
.67 .744 .905 r
.81861 .45706 .82332 .46369 .83444 .45994 .82975 .45326 Mtetra
.667 .741 .906 r
.82975 .45326 .83444 .45994 .8456 .45624 .84094 .44954 Mtetra
.663 .74 .907 r
.84094 .44954 .8456 .45624 .85681 .45259 .85219 .44592 Mtetra
.66 .741 .909 r
.85219 .44592 .85681 .45259 .86806 .449 .86348 .44237 Mtetra
.658 .742 .912 r
.86348 .44237 .86806 .449 .87937 .44544 .87483 .43887 Mtetra
.657 .744 .914 r
.87483 .43887 .87937 .44544 .89072 .44192 .88622 .43539 Mtetra
.656 .746 .917 r
.88622 .43539 .89072 .44192 .90212 .43841 .89766 .43193 Mtetra
.655 .749 .919 r
.89766 .43193 .90212 .43841 .91357 .43489 .90915 .42846 Mtetra
.659 .752 .919 r
.29453 .60833 .3005 .61354 .30977 .6107 .30382 .60541 Mtetra
.66 .75 .917 r
.30382 .60541 .30977 .6107 .31907 .60786 .31315 .60247 Mtetra
.659 .747 .915 r
.31315 .60247 .31907 .60786 .3284 .60503 .3225 .59954 Mtetra
.658 .743 .913 r
.3225 .59954 .3284 .60503 .33776 .60223 .33189 .59662 Mtetra
.657 .739 .911 r
.33189 .59662 .33776 .60223 .34715 .59948 .3413 .59374 Mtetra
.653 .735 .909 r
.3413 .59374 .34715 .59948 .35657 .5968 .35075 .59093 Mtetra
.648 .729 .908 r
.35075 .59093 .35657 .5968 .36602 .59422 .36022 .58824 Mtetra
.642 .724 .908 r
.36022 .58824 .36602 .59422 .3755 .59172 .36972 .58568 Mtetra
.635 .721 .91 r
.36972 .58568 .3755 .59172 .38501 .58933 .37925 .5833 Mtetra
.629 .72 .913 r
.37925 .5833 .38501 .58933 .39456 .58697 .38882 .58104 Mtetra
.623 .723 .918 r
.38882 .58104 .39456 .58697 .40415 .5846 .39841 .5789 Mtetra
.623 .731 .924 r
.39841 .5789 .40415 .5846 .41377 .58214 .40805 .57672 Mtetra
.627 .744 .931 r
.40805 .57672 .41377 .58214 .42344 .5795 .41772 .5744 Mtetra
.636 .76 .937 r
.41772 .5744 .42344 .5795 .43315 .57665 .42745 .57185 Mtetra
.649 .776 .941 r
.42745 .57185 .43315 .57665 .4429 .57354 .43722 .56895 Mtetra
.66 .788 .943 r
.43722 .56895 .4429 .57354 .45269 .57025 .44703 .56578 Mtetra
.671 .796 .942 r
.44703 .56578 .45269 .57025 .46252 .56682 .45688 .56234 Mtetra
.676 .798 .94 r
.45688 .56234 .46252 .56682 .47238 .56334 .46677 .55877 Mtetra
.677 .795 .937 r
.46677 .55877 .47238 .56334 .48227 .55988 .47669 .55516 Mtetra
.676 .79 .935 r
.47669 .55516 .48227 .55988 .49219 .55646 .48664 .55157 Mtetra
.673 .783 .932 r
.48664 .55157 .49219 .55646 .50215 .55311 .49662 .54806 Mtetra
.67 .777 .93 r
.49662 .54806 .50215 .55311 .51214 .54983 .50664 .54464 Mtetra
.666 .771 .928 r
.50664 .54464 .51214 .54983 .52217 .5466 .51669 .54129 Mtetra
.663 .767 .927 r
.51669 .54129 .52217 .5466 .53223 .54342 .52678 .53801 Mtetra
.661 .763 .926 r
.52678 .53801 .53223 .54342 .54233 .54026 .5369 .53478 Mtetra
.659 .761 .925 r
.5369 .53478 .54233 .54026 .55246 .53713 .54706 .53159 Mtetra
.658 .759 .924 r
.54706 .53159 .55246 .53713 .56263 .534 .55726 .52841 Mtetra
.657 .758 .924 r
.55726 .52841 .56263 .534 .57284 .53087 .5675 .52525 Mtetra
.656 .757 .924 r
.5675 .52525 .57284 .53087 .58309 .52775 .57777 .5221 Mtetra
.655 .756 .924 r
.57777 .5221 .58309 .52775 .59338 .52462 .58808 .51895 Mtetra
.58808 .51895 .59338 .52462 .6037 .52149 .59843 .5158 Mtetra
.654 .756 .925 r
.59843 .5158 .6037 .52149 .61406 .51836 .60882 .51267 Mtetra
.653 .756 .925 r
.60882 .51267 .61406 .51836 .62447 .51523 .61925 .50955 Mtetra
.651 .757 .927 r
.61925 .50955 .62447 .51523 .63491 .51211 .62972 .50644 Mtetra
.649 .757 .928 r
.62972 .50644 .63491 .51211 .64539 .50901 .64023 .50338 Mtetra
.647 .759 .931 r
.64023 .50338 .64539 .50901 .65591 .50594 .65079 .50036 Mtetra
.643 .76 .934 r
.65079 .50036 .65591 .50594 .66648 .50291 .66138 .49741 Mtetra
.638 .762 .938 r
.66138 .49741 .66648 .50291 .67709 .49994 .67203 .49454 Mtetra
.633 .765 .943 r
.67203 .49454 .67709 .49994 .68774 .49703 .68272 .49175 Mtetra
.628 .769 .948 r
.68272 .49175 .68774 .49703 .69845 .4942 .69346 .48905 Mtetra
.624 .774 .952 r
.69346 .48905 .69845 .4942 .7092 .49142 .70424 .48637 Mtetra
.624 .779 .955 r
.70424 .48637 .7092 .49142 .71999 .48865 .71507 .48365 Mtetra
.63 .784 .956 r
.71507 .48365 .71999 .48865 .73083 .48583 .72594 .4808 Mtetra
.642 .788 .952 r
.72594 .4808 .73083 .48583 .7417 .48286 .73683 .47768 Mtetra
.655 .787 .945 r
.73683 .47768 .7417 .48286 .7526 .47971 .74775 .47426 Mtetra
.67 .783 .934 r
.74775 .47426 .7526 .47971 .76353 .4763 .75869 .4705 Mtetra
.68 .774 .922 r
.75869 .4705 .76353 .4763 .77448 .47266 .76965 .46649 Mtetra
.684 .763 .911 r
.76965 .46649 .77448 .47266 .78546 .46884 .78063 .46232 Mtetra
.684 .752 .903 r
.78063 .46232 .78546 .46884 .79647 .46491 .79165 .45812 Mtetra
.68 .742 .898 r
.79165 .45812 .79647 .46491 .80752 .46097 .80272 .45403 Mtetra
.675 .736 .896 r
.80272 .45403 .80752 .46097 .81861 .45706 .81384 .45006 Mtetra
.669 .732 .897 r
.81384 .45006 .81861 .45706 .82975 .45326 .82501 .44628 Mtetra
.664 .732 .9 r
.82501 .44628 .82975 .45326 .84094 .44954 .83624 .44263 Mtetra
.659 .733 .904 r
.83624 .44263 .84094 .44954 .85219 .44592 .84753 .4391 Mtetra
.656 .735 .908 r
.84753 .4391 .85219 .44592 .86348 .44237 .85886 .43564 Mtetra
.654 .739 .911 r
.85886 .43564 .86348 .44237 .87483 .43887 .87025 .43222 Mtetra
.653 .742 .915 r
.87025 .43222 .87483 .43887 .88622 .43539 .88169 .42881 Mtetra
.653 .745 .917 r
.88169 .42881 .88622 .43539 .89766 .43193 .89317 .4254 Mtetra
.653 .748 .919 r
.89317 .4254 .89766 .43193 .90915 .42846 .90469 .42197 Mtetra
.661 .753 .918 r
.28853 .60308 .29453 .60833 .30382 .60541 .29784 .60011 Mtetra
.662 .751 .917 r
.29784 .60011 .30382 .60541 .31315 .60247 .30718 .5971 Mtetra
.662 .75 .915 r
.30718 .5971 .31315 .60247 .3225 .59954 .31656 .59408 Mtetra
.662 .747 .913 r
.31656 .59408 .3225 .59954 .33189 .59662 .32597 .59104 Mtetra
.662 .744 .911 r
.32597 .59104 .33189 .59662 .3413 .59374 .33542 .58801 Mtetra
.66 .738 .908 r
.33542 .58801 .3413 .59374 .35075 .59093 .34489 .58502 Mtetra
.656 .731 .905 r
.34489 .58502 .35075 .59093 .36022 .58824 .35439 .58212 Mtetra
.649 .723 .903 r
.35439 .58212 .36022 .58824 .36972 .58568 .36392 .57938 Mtetra
.64 .715 .902 r
.36392 .57938 .36972 .58568 .37925 .5833 .37347 .57687 Mtetra
.63 .708 .902 r
.37347 .57687 .37925 .5833 .38882 .58104 .38305 .57459 Mtetra
.619 .704 .906 r
.38305 .57459 .38882 .58104 .39841 .5789 .39266 .57257 Mtetra
.613 .707 .912 r
.39266 .57257 .39841 .5789 .40805 .57672 .4023 .57065 Mtetra
.611 .716 .92 r
.4023 .57065 .40805 .57672 .41772 .5744 .41199 .56874 Mtetra
.617 .733 .929 r
.41199 .56874 .41772 .5744 .42745 .57185 .42172 .56662 Mtetra
.631 .755 .937 r
.42172 .56662 .42745 .57185 .43722 .56895 .4315 .56413 Mtetra
.646 .776 .943 r
.4315 .56413 .43722 .56895 .44703 .56578 .44133 .56127 Mtetra
.663 .794 .945 r
.44133 .56127 .44703 .56578 .45688 .56234 .4512 .55799 Mtetra
.673 .804 .945 r
.4512 .55799 .45688 .56234 .46677 .55877 .46111 .55445 Mtetra
.679 .808 .944 r
.46111 .55445 .46677 .55877 .47669 .55516 .47106 .55075 Mtetra
.681 .805 .941 r
.47106 .55075 .47669 .55516 .48664 .55157 .48104 .547 Mtetra
.679 .799 .939 r
.48104 .547 .48664 .55157 .49662 .54806 .49106 .54332 Mtetra
.675 .792 .936 r
.49106 .54332 .49662 .54806 .50664 .54464 .5011 .53971 Mtetra
.671 .784 .934 r
.5011 .53971 .50664 .54464 .51669 .54129 .51118 .53621 Mtetra
.667 .778 .932 r
.51118 .53621 .51669 .54129 .52678 .53801 .5213 .53279 Mtetra
.664 .772 .93 r
.5213 .53279 .52678 .53801 .5369 .53478 .53145 .52945 Mtetra
.661 .768 .929 r
.53145 .52945 .5369 .53478 .54706 .53159 .54163 .52617 Mtetra
.659 .765 .928 r
.54163 .52617 .54706 .53159 .55726 .52841 .55185 .52293 Mtetra
.658 .763 .928 r
.55185 .52293 .55726 .52841 .5675 .52525 .56212 .51972 Mtetra
.656 .762 .927 r
.56212 .51972 .5675 .52525 .57777 .5221 .57241 .51653 Mtetra
.655 .761 .928 r
.57241 .51653 .57777 .5221 .58808 .51895 .58275 .51336 Mtetra
.654 .761 .928 r
.58275 .51336 .58808 .51895 .59843 .5158 .59313 .51021 Mtetra
.652 .761 .929 r
.59313 .51021 .59843 .5158 .60882 .51267 .60355 .50708 Mtetra
.651 .761 .93 r
.60355 .50708 .60882 .51267 .61925 .50955 .614 .50398 Mtetra
.648 .762 .932 r
.614 .50398 .61925 .50955 .62972 .50644 .6245 .50092 Mtetra
.645 .763 .935 r
.6245 .50092 .62972 .50644 .64023 .50338 .63505 .49792 Mtetra
.64 .765 .938 r
.63505 .49792 .64023 .50338 .65079 .50036 .64563 .495 Mtetra
.635 .768 .943 r
.64563 .495 .65079 .50036 .66138 .49741 .65626 .49216 Mtetra
.628 .771 .948 r
.65626 .49216 .66138 .49741 .67203 .49454 .66694 .48944 Mtetra
.622 .775 .954 r
.66694 .48944 .67203 .49454 .68272 .49175 .67767 .48679 Mtetra
.617 .78 .959 r
.67767 .48679 .68272 .49175 .69346 .48905 .68845 .48421 Mtetra
.616 .786 .963 r
.68845 .48421 .69346 .48905 .70424 .48637 .69927 .48158 Mtetra
.623 .791 .963 r
.69927 .48158 .70424 .48637 .71507 .48365 .71013 .47879 Mtetra
.636 .794 .958 r
.71013 .47879 .71507 .48365 .72594 .4808 .72102 .47573 Mtetra
.657 .793 .948 r
.72102 .47573 .72594 .4808 .73683 .47768 .73192 .47225 Mtetra
.674 .786 .933 r
.73192 .47225 .73683 .47768 .74775 .47426 .74284 .46837 Mtetra
.688 .774 .917 r
.74284 .46837 .74775 .47426 .75869 .4705 .75378 .46411 Mtetra
.694 .759 .902 r
.75378 .46411 .75869 .4705 .76965 .46649 .76473 .45964 Mtetra
.692 .744 .891 r
.76473 .45964 .76965 .46649 .78063 .46232 .77573 .45516 Mtetra
.687 .733 .886 r
.77573 .45516 .78063 .46232 .79165 .45812 .78676 .45079 Mtetra
.678 .725 .885 r
.78676 .45079 .79165 .45812 .80272 .45403 .79786 .44668 Mtetra
.671 .722 .888 r
.79786 .44668 .80272 .45403 .81384 .45006 .80901 .4428 Mtetra
.663 .723 .894 r
.80901 .4428 .81384 .45006 .82501 .44628 .82023 .43915 Mtetra
.657 .726 .9 r
.82023 .43915 .82501 .44628 .83624 .44263 .83151 .43567 Mtetra
.654 .73 .906 r
.83151 .43567 .83624 .44263 .84753 .4391 .84284 .43228 Mtetra
.651 .735 .911 r
.84284 .43228 .84753 .4391 .85886 .43564 .85422 .42894 Mtetra
.651 .74 .915 r
.85422 .42894 .85886 .43564 .87025 .43222 .86565 .42559 Mtetra
.65 .743 .917 r
.86565 .42559 .87025 .43222 .88169 .42881 .87712 .42224 Mtetra
.651 .746 .919 r
.87712 .42224 .88169 .42881 .89317 .4254 .88864 .41886 Mtetra
.651 .748 .921 r
.88864 .41886 .89317 .4254 .90469 .42197 .90021 .41544 Mtetra
.66 .752 .918 r
.28248 .59781 .28853 .60308 .29784 .60011 .29181 .59483 Mtetra
.662 .753 .918 r
.29181 .59483 .29784 .60011 .30718 .5971 .30118 .5918 Mtetra
.663 .754 .917 r
.30118 .5918 .30718 .5971 .31656 .59408 .31058 .58872 Mtetra
.665 .753 .916 r
.31058 .58872 .31656 .59408 .32597 .59104 .32001 .5856 Mtetra
.667 .751 .913 r
.32001 .5856 .32597 .59104 .33542 .58801 .32949 .58241 Mtetra
.667 .746 .909 r
.32949 .58241 .33542 .58801 .34489 .58502 .33899 .57921 Mtetra
.666 .739 .905 r
.33899 .57921 .34489 .58502 .35439 .58212 .34853 .57602 Mtetra
.661 .728 .9 r
.34853 .57602 .35439 .58212 .36392 .57938 .35809 .57297 Mtetra
.651 .716 .895 r
.35809 .57297 .36392 .57938 .37347 .57687 .36767 .57014 Mtetra
.639 .703 .892 r
.36767 .57014 .37347 .57687 .38305 .57459 .37728 .56764 Mtetra
.622 .69 .893 r
.37728 .56764 .38305 .57459 .39266 .57257 .3869 .56555 Mtetra
.609 .684 .896 r
.3869 .56555 .39266 .57257 .4023 .57065 .39655 .56378 Mtetra
.597 .685 .903 r
.39655 .56378 .4023 .57065 .41199 .56874 .40624 .56226 Mtetra
.596 .699 .915 r
.40624 .56226 .41199 .56874 .42172 .56662 .41597 .56069 Mtetra
.605 .722 .927 r
.41597 .56069 .42172 .56662 .4315 .56413 .42575 .55882 Mtetra
.621 .751 .939 r
.42575 .55882 .4315 .56413 .44133 .56127 .43559 .55652 Mtetra
.645 .781 .946 r
.43559 .55652 .44133 .56127 .4512 .55799 .44548 .55363 Mtetra
.662 .802 .95 r
.44548 .55363 .4512 .55799 .46111 .55445 .45541 .55031 Mtetra
.676 .815 .95 r
.45541 .55031 .46111 .55445 .47106 .55075 .46539 .54664 Mtetra
.682 .819 .948 r
.46539 .54664 .47106 .55075 .48104 .547 .4754 .5428 Mtetra
.683 .816 .946 r
.4754 .5428 .48104 .547 .49106 .54332 .48545 .53894 Mtetra
.681 .809 .944 r
.48545 .53894 .49106 .54332 .5011 .53971 .49552 .53513 Mtetra
.677 .801 .941 r
.49552 .53513 .5011 .53971 .51118 .53621 .50563 .53143 Mtetra
.672 .793 .939 r
.50563 .53143 .51118 .53621 .5213 .53279 .51577 .52785 Mtetra
.668 .786 .937 r
.51577 .52785 .5213 .53279 .53145 .52945 .52595 .52437 Mtetra
.664 .78 .935 r
.52595 .52437 .53145 .52945 .54163 .52617 .53616 .52097 Mtetra
.661 .776 .934 r
.53616 .52097 .54163 .52617 .55185 .52293 .54641 .51765 Mtetra
.658 .772 .933 r
.54641 .51765 .55185 .52293 .56212 .51972 .5567 .51437 Mtetra
.656 .77 .933 r
.5567 .51437 .56212 .51972 .57241 .51653 .56702 .51114 Mtetra
.654 .769 .933 r
.56702 .51114 .57241 .51653 .58275 .51336 .57739 .50795 Mtetra
.652 .768 .934 r
.57739 .50795 .58275 .51336 .59313 .51021 .58779 .5048 Mtetra
.65 .768 .935 r
.58779 .5048 .59313 .51021 .60355 .50708 .59824 .50169 Mtetra
.647 .768 .937 r
.59824 .50169 .60355 .50708 .614 .50398 .60873 .49863 Mtetra
.643 .77 .94 r
.60873 .49863 .614 .50398 .6245 .50092 .61926 .49564 Mtetra
.638 .772 .944 r
.61926 .49564 .6245 .50092 .63505 .49792 .62983 .49274 Mtetra
.631 .774 .949 r
.62983 .49274 .63505 .49792 .64563 .495 .64045 .48995 Mtetra
.624 .778 .955 r
.64045 .48995 .64563 .495 .65626 .49216 .65112 .48727 Mtetra
.615 .782 .961 r
.65112 .48727 .65626 .49216 .66694 .48944 .66184 .48471 Mtetra
.609 .787 .967 r
.66184 .48471 .66694 .48944 .67767 .48679 .67261 .4822 Mtetra
.607 .793 .971 r
.67261 .4822 .67767 .48679 .68845 .48421 .68342 .47966 Mtetra
.614 .799 .971 r
.68342 .47966 .68845 .48421 .69927 .48158 .69427 .47697 Mtetra
.632 .804 .965 r
.69427 .47697 .69927 .48158 .71013 .47879 .70515 .47391 Mtetra
.656 .801 .953 r
.70515 .47391 .71013 .47879 .72102 .47573 .71604 .47041 Mtetra
.682 .793 .933 r
.71604 .47041 .72102 .47573 .73192 .47225 .72695 .4663 Mtetra
.698 .776 .912 r
.72695 .4663 .73192 .47225 .74284 .46837 .73785 .46175 Mtetra
.705 .756 .892 r
.73785 .46175 .74284 .46837 .75378 .46411 .74878 .45688 Mtetra
.703 .737 .877 r
.74878 .45688 .75378 .46411 .76473 .45964 .75973 .45195 Mtetra
.693 .721 .871 r
.75973 .45195 .76473 .45964 .77573 .45516 .77074 .44728 Mtetra
.683 .712 .87 r
.77074 .44728 .77573 .45516 .78676 .45079 .7818 .44292 Mtetra
.67 .708 .876 r
.7818 .44292 .78676 .45079 .79786 .44668 .79294 .439 Mtetra
.66 .71 .884 r
.79294 .439 .79786 .44668 .80901 .4428 .80415 .4354 Mtetra
.653 .716 .895 r
.80415 .4354 .80901 .4428 .82023 .43915 .81542 .43204 Mtetra
.647 .723 .904 r
.81542 .43204 .82023 .43915 .83151 .43567 .82675 .42881 Mtetra
.646 .732 .912 r
.82675 .42881 .83151 .43567 .84284 .43228 .83813 .4256 Mtetra
.646 .739 .917 r
.83813 .4256 .84284 .43228 .85422 .42894 .84956 .42237 Mtetra
.648 .745 .92 r
.84956 .42237 .85422 .42894 .86565 .42559 .86103 .41908 Mtetra
.649 .748 .922 r
.86103 .41908 .86565 .42559 .87712 .42224 .87254 .41572 Mtetra
.65 .749 .922 r
.87254 .41572 .87712 .42224 .88864 .41886 .88409 .41232 Mtetra
.652 .75 .922 r
.88409 .41232 .88864 .41886 .90021 .41544 .89569 .40886 Mtetra
.657 .752 .92 r
.27639 .59249 .28248 .59781 .29181 .59483 .28574 .58957 Mtetra
.659 .755 .921 r
.28574 .58957 .29181 .59483 .30118 .5918 .29512 .5866 Mtetra
.661 .758 .922 r
.29512 .5866 .30118 .5918 .31058 .58872 .30454 .58356 Mtetra
.664 .761 .922 r
.30454 .58356 .31058 .58872 .32001 .5856 .314 .58043 Mtetra
.669 .763 .921 r
.314 .58043 .32001 .5856 .32949 .58241 .32349 .57718 Mtetra
.672 .762 .918 r
.32349 .57718 .32949 .58241 .33899 .57921 .33303 .57383 Mtetra
.676 .758 .913 r
.33303 .57383 .33899 .57921 .34853 .57602 .3426 .57037 Mtetra
.675 .748 .906 r
.3426 .57037 .34853 .57602 .35809 .57297 .3522 .56693 Mtetra
.669 .735 .899 r
.3522 .56693 .35809 .57297 .36767 .57014 .36182 .56361 Mtetra
.657 .716 .892 r
.36182 .56361 .36767 .57014 .37728 .56764 .37147 .56061 Mtetra
.638 .695 .887 r
.37147 .56061 .37728 .56764 .3869 .56555 .38112 .5581 Mtetra
.618 .676 .883 r
.38112 .5581 .3869 .56555 .39655 .56378 .3908 .55611 Mtetra
.594 .661 .884 r
.3908 .55611 .39655 .56378 .40624 .56226 .40049 .5547 Mtetra
.583 .66 .89 r
.40049 .5547 .40624 .56226 .41597 .56069 .41022 .55354 Mtetra
.58 .672 .902 r
.41022 .55354 .41597 .56069 .42575 .55882 .42 .55237 Mtetra
.591 .7 .919 r
.42 .55237 .42575 .55882 .43559 .55652 .42983 .55086 Mtetra
.615 .738 .934 r
.42983 .55086 .43559 .55652 .44548 .55363 .43972 .54871 Mtetra
.637 .774 .946 r
.43972 .54871 .44548 .55363 .45541 .55031 .44967 .54597 Mtetra
.661 .805 .952 r
.44967 .54597 .45541 .55031 .46539 .54664 .45967 .54262 Mtetra
.675 .823 .955 r
.45967 .54262 .46539 .54664 .4754 .5428 .46971 .53892 Mtetra
.682 .831 .955 r
.46971 .53892 .4754 .5428 .48545 .53894 .47978 .53501 Mtetra
.684 .83 .953 r
.47978 .53501 .48545 .53894 .49552 .53513 .48989 .53105 Mtetra
.681 .824 .952 r
.48989 .53105 .49552 .53513 .50563 .53143 .50003 .52717 Mtetra
.677 .816 .95 r
.50003 .52717 .50563 .53143 .51577 .52785 .5102 .52339 Mtetra
.672 .808 .948 r
.5102 .52339 .51577 .52785 .52595 .52437 .52041 .51973 Mtetra
.667 .8 .946 r
.52041 .51973 .52595 .52437 .53616 .52097 .53065 .51619 Mtetra
.663 .794 .945 r
.53065 .51619 .53616 .52097 .54641 .51765 .54093 .51275 Mtetra
.659 .789 .944 r
.54093 .51275 .54641 .51765 .5567 .51437 .55125 .50939 Mtetra
.656 .786 .944 r
.55125 .50939 .5567 .51437 .56702 .51114 .5616 .50611 Mtetra
.652 .784 .944 r
.5616 .50611 .56702 .51114 .57739 .50795 .57199 .5029 Mtetra
.648 .782 .945 r
.57199 .5029 .57739 .50795 .58779 .5048 .58243 .49976 Mtetra
.644 .782 .947 r
.58243 .49976 .58779 .5048 .59824 .50169 .5929 .49669 Mtetra
.639 .783 .95 r
.5929 .49669 .59824 .50169 .60873 .49863 .60342 .4937 Mtetra
.633 .785 .955 r
.60342 .4937 .60873 .49863 .61926 .49564 .61398 .49082 Mtetra
.625 .788 .96 r
.61398 .49082 .61926 .49564 .62983 .49274 .62459 .48805 Mtetra
.616 .791 .966 r
.62459 .48805 .62983 .49274 .64045 .48995 .63525 .48542 Mtetra
.607 .795 .971 r
.63525 .48542 .64045 .48995 .65112 .48727 .64596 .48289 Mtetra
.599 .799 .976 r
.64596 .48289 .65112 .48727 .66184 .48471 .65671 .48043 Mtetra
.598 .805 .979 r
.65671 .48043 .66184 .48471 .67261 .4822 .66751 .47792 Mtetra
.608 .809 .977 r
.66751 .47792 .67261 .4822 .68342 .47966 .67835 .47522 Mtetra
.63 .811 .969 r
.67835 .47522 .68342 .47966 .69427 .47697 .68922 .47215 Mtetra
.663 .807 .952 r
.68922 .47215 .69427 .47697 .70515 .47391 .7001 .46845 Mtetra
.689 .791 .928 r
.7001 .46845 .70515 .47391 .71604 .47041 .71098 .46415 Mtetra
.709 .769 .899 r
.71098 .46415 .71604 .47041 .72695 .4663 .72186 .45919 Mtetra
.715 .744 .875 r
.72186 .45919 .72695 .4663 .73785 .46175 .73275 .45386 Mtetra
.71 .721 .859 r
.73275 .45386 .73785 .46175 .74878 .45688 .74367 .44853 Mtetra
.7 .706 .852 r
.74367 .44853 .74878 .45688 .75973 .45195 .75464 .44344 Mtetra
.683 .696 .855 r
.75464 .44344 .75973 .45195 .77074 .44728 .76569 .43894 Mtetra
.669 .695 .865 r
.76569 .43894 .77074 .44728 .7818 .44292 .77681 .43497 Mtetra
.655 .701 .88 r
.77681 .43497 .7818 .44292 .79294 .439 .78801 .43152 Mtetra
.644 .711 .896 r
.78801 .43152 .79294 .439 .80415 .4354 .79929 .42839 Mtetra
.639 .724 .91 r
.79929 .42839 .80415 .4354 .81542 .43204 .81062 .42537 Mtetra
.637 .736 .92 r
.81062 .42537 .81542 .43204 .82675 .42881 .82201 .42239 Mtetra
.64 .746 .926 r
.82201 .42239 .82675 .42881 .83813 .4256 .83344 .41929 Mtetra
.643 .753 .929 r
.83344 .41929 .83813 .4256 .84956 .42237 .8449 .41608 Mtetra
.647 .756 .929 r
.8449 .41608 .84956 .42237 .86103 .41908 .8564 .41274 Mtetra
.65 .757 .927 r
.8564 .41274 .86103 .41908 .87254 .41572 .86794 .40931 Mtetra
.653 .756 .925 r
.86794 .40931 .87254 .41572 .88409 .41232 .87951 .4058 Mtetra
.654 .754 .923 r
.87951 .4058 .88409 .41232 .89569 .40886 .89113 .40224 Mtetra
.651 .75 .922 r
.27027 .58715 .27639 .59249 .28574 .58957 .27962 .58434 Mtetra
.652 .755 .925 r
.27962 .58434 .28574 .58957 .29512 .5866 .28901 .5815 Mtetra
.654 .762 .929 r
.28901 .5815 .29512 .5866 .30454 .58356 .29844 .57859 Mtetra
.658 .768 .931 r
.29844 .57859 .30454 .58356 .314 .58043 .30791 .57557 Mtetra
.664 .775 .932 r
.30791 .57557 .314 .58043 .32349 .57718 .31743 .57239 Mtetra
.672 .78 .931 r
.31743 .57239 .32349 .57718 .33303 .57383 .32699 .56901 Mtetra
.682 .782 .926 r
.32699 .56901 .33303 .57383 .3426 .57037 .33659 .56538 Mtetra
.688 .777 .919 r
.33659 .56538 .3426 .57037 .3522 .56693 .34623 .5616 Mtetra
.692 .766 .908 r
.34623 .5616 .3522 .56693 .36182 .56361 .35591 .55768 Mtetra
.684 .744 .897 r
.35591 .55768 .36182 .56361 .37147 .56061 .3656 .55394 Mtetra
.667 .717 .885 r
.3656 .55394 .37147 .56061 .38112 .5581 .37532 .5506 Mtetra
.643 .684 .874 r
.37532 .5506 .38112 .5581 .3908 .55611 .38503 .54791 Mtetra
.609 .653 .868 r
.38503 .54791 .3908 .55611 .40049 .5547 .39475 .54615 Mtetra
.584 .634 .867 r
.39475 .54615 .40049 .5547 .41022 .55354 .40449 .54504 Mtetra
.562 .626 .874 r
.40449 .54504 .41022 .55354 .42 .55237 .41426 .54447 Mtetra
.559 .642 .889 r
.41426 .54447 .42 .55237 .42983 .55086 .42407 .54384 Mtetra
.574 .677 .909 r
.42407 .54384 .42983 .55086 .43972 .54871 .43396 .54274 Mtetra
.597 .722 .932 r
.43396 .54274 .43972 .54871 .44967 .54597 .4439 .54096 Mtetra
.63 .771 .947 r
.4439 .54096 .44967 .54597 .45967 .54262 .45391 .53833 Mtetra
.653 .807 .957 r
.45391 .53833 .45967 .54262 .46971 .53892 .46397 .53509 Mtetra
.671 .832 .961 r
.46397 .53509 .46971 .53892 .47978 .53501 .47407 .53137 Mtetra
.68 .843 .961 r
.47407 .53137 .47978 .53501 .48989 .53105 .48421 .52743 Mtetra
.681 .844 .961 r
.48421 .52743 .48989 .53105 .50003 .52717 .49439 .52343 Mtetra
.679 .84 .96 r
.49439 .52343 .50003 .52717 .5102 .52339 .50459 .51948 Mtetra
.674 .833 .96 r
.50459 .51948 .5102 .52339 .52041 .51973 .51483 .51565 Mtetra
.669 .825 .958 r
.51483 .51565 .52041 .51973 .53065 .51619 .5251 .51194 Mtetra
.664 .818 .958 r
.5251 .51194 .53065 .51619 .54093 .51275 .53541 .50837 Mtetra
.658 .812 .957 r
.53541 .50837 .54093 .51275 .55125 .50939 .54575 .50492 Mtetra
.653 .807 .957 r
.54575 .50492 .55125 .50939 .5616 .50611 .55614 .50158 Mtetra
.648 .804 .958 r
.55614 .50158 .5616 .50611 .57199 .5029 .56656 .49834 Mtetra
.642 .802 .96 r
.56656 .49834 .57199 .5029 .58243 .49976 .57703 .49522 Mtetra
.635 .802 .963 r
.57703 .49522 .58243 .49976 .5929 .49669 .58753 .4922 Mtetra
.627 .802 .966 r
.58753 .4922 .5929 .49669 .60342 .4937 .59809 .48931 Mtetra
.618 .804 .971 r
.59809 .48931 .60342 .4937 .61398 .49082 .60868 .48655 Mtetra
.607 .806 .976 r
.60868 .48655 .61398 .49082 .62459 .48805 .61933 .48392 Mtetra
.596 .809 .981 r
.61933 .48392 .62459 .48805 .63525 .48542 .63003 .48141 Mtetra
.589 .813 .985 r
.63003 .48141 .63525 .48542 .64596 .48289 .64077 .47895 Mtetra
.589 .817 .986 r
.64077 .47895 .64596 .48289 .65671 .48043 .65156 .47645 Mtetra
.603 .821 .983 r
.65156 .47645 .65671 .48043 .66751 .47792 .66238 .47371 Mtetra
.633 .822 .973 r
.66238 .47371 .66751 .47792 .67835 .47522 .67323 .47049 Mtetra
.669 .813 .952 r
.67323 .47049 .67835 .47522 .68922 .47215 .6841 .46664 Mtetra
.704 .794 .92 r
.6841 .46664 .68922 .47215 .7001 .46845 .69496 .46191 Mtetra
.721 .764 .886 r
.69496 .46191 .7001 .46845 .71098 .46415 .70581 .45649 Mtetra
.726 .733 .857 r
.70581 .45649 .71098 .46415 .72186 .45919 .71666 .45057 Mtetra
.719 .707 .838 r
.71666 .45057 .72186 .45919 .73275 .45386 .72754 .44459 Mtetra
.702 .686 .831 r
.72754 .44459 .73275 .45386 .74367 .44853 .73847 .43915 Mtetra
.685 .677 .836 r
.73847 .43915 .74367 .44853 .75464 .44344 .74949 .43437 Mtetra
.663 .675 .851 r
.74949 .43437 .75464 .44344 .76569 .43894 .7606 .43054 Mtetra
.644 .684 .873 r
.7606 .43054 .76569 .43894 .77681 .43497 .77181 .42739 Mtetra
.63 .702 .897 r
.77181 .42739 .77681 .43497 .78801 .43152 .78311 .42465 Mtetra
.621 .722 .919 r
.78311 .42465 .78801 .43152 .79929 .42839 .79446 .42209 Mtetra
.622 .744 .934 r
.79446 .42209 .79929 .42839 .81062 .42537 .80586 .4194 Mtetra
.626 .758 .941 r
.80586 .4194 .81062 .42537 .82201 .42239 .81729 .41654 Mtetra
.636 .768 .943 r
.81729 .41654 .82201 .42239 .83344 .41929 .82875 .41343 Mtetra
.644 .772 .941 r
.82875 .41343 .83344 .41929 .8449 .41608 .84024 .4101 Mtetra
.651 .771 .937 r
.84024 .4101 .8449 .41608 .8564 .41274 .85176 .4066 Mtetra
.656 .768 .932 r
.85176 .4066 .8564 .41274 .86794 .40931 .86332 .40299 Mtetra
.658 .763 .927 r
.86332 .40299 .86794 .40931 .87951 .4058 .87491 .39929 Mtetra
.659 .758 .923 r
.87491 .39929 .87951 .4058 .89113 .40224 .88655 .39556 Mtetra
.646 .749 .924 r
.2641 .58177 .27027 .58715 .27962 .58434 .27347 .57906 Mtetra
.644 .753 .928 r
.27347 .57906 .27962 .58434 .28901 .5815 .28287 .57637 Mtetra
.645 .76 .932 r
.28287 .57637 .28901 .5815 .29844 .57859 .2923 .57363 Mtetra
.648 .768 .936 r
.2923 .57363 .29844 .57859 .30791 .57557 .30178 .57081 Mtetra
.652 .777 .94 r
.30178 .57081 .30791 .57557 .31743 .57239 .3113 .56786 Mtetra
.661 .789 .943 r
.3113 .56786 .31743 .57239 .32699 .56901 .32087 .56468 Mtetra
.675 .8 .942 r
.32087 .56468 .32699 .56901 .33659 .56538 .33049 .56118 Mtetra
.688 .809 .939 r
.33049 .56118 .33659 .56538 .34623 .5616 .34016 .55733 Mtetra
.705 .81 .931 r
.34016 .55733 .34623 .5616 .35591 .55768 .34988 .55308 Mtetra
.709 .798 .92 r
.34988 .55308 .35591 .55768 .3656 .55394 .35964 .54869 Mtetra
.706 .775 .905 r
.35964 .54869 .3656 .55394 .37532 .5506 .36942 .54432 Mtetra
.685 .736 .889 r
.36942 .54432 .37532 .5506 .38503 .54791 .3792 .54047 Mtetra
.65 .69 .875 r
.3792 .54047 .38503 .54791 .39475 .54615 .38898 .53756 Mtetra
.613 .647 .86 r
.38898 .53756 .39475 .54615 .40449 .54504 .39876 .53567 Mtetra
.571 .61 .852 r
.39876 .53567 .40449 .54504 .41426 .54447 .40854 .53493 Mtetra
.552 .597 .853 r
.40854 .53493 .41426 .54447 .42407 .54384 .41835 .53471 Mtetra
.545 .604 .864 r
.41835 .53471 .42407 .54384 .43396 .54274 .42821 .53459 Mtetra
.557 .636 .886 r
.42821 .53459 .43396 .54274 .4439 .54096 .43814 .53402 Mtetra
.586 .687 .911 r
.43814 .53402 .4439 .54096 .45391 .53833 .44814 .5326 Mtetra
.614 .74 .935 r
.44814 .5326 .45391 .53833 .46397 .53509 .4582 .53038 Mtetra
.644 .79 .952 r
.4582 .53038 .46397 .53509 .47407 .53137 .46832 .52737 Mtetra
.661 .824 .962 r
.46832 .52737 .47407 .53137 .48421 .52743 .47849 .52386 Mtetra
.67 .846 .967 r
.47849 .52386 .48421 .52743 .49439 .52343 .48869 .52005 Mtetra
.672 .855 .969 r
.48869 .52005 .49439 .52343 .50459 .51948 .49893 .51613 Mtetra
.669 .856 .971 r
.49893 .51613 .50459 .51948 .51483 .51565 .5092 .51224 Mtetra
.665 .854 .972 r
.5092 .51224 .51483 .51565 .5251 .51194 .51951 .50843 Mtetra
.658 .849 .973 r
.51951 .50843 .5251 .51194 .53541 .50837 .52985 .50476 Mtetra
.651 .844 .974 r
.52985 .50476 .53541 .50837 .54575 .50492 .54022 .50122 Mtetra
.644 .839 .975 r
.54022 .50122 .54575 .50492 .55614 .50158 .55064 .49782 Mtetra
.636 .835 .977 r
.55064 .49782 .55614 .50158 .56656 .49834 .5611 .49456 Mtetra
.628 .832 .979 r
.5611 .49456 .56656 .49834 .57703 .49522 .5716 .49145 Mtetra
.618 .831 .982 r
.5716 .49145 .57703 .49522 .58753 .4922 .58214 .48848 Mtetra
.607 .83 .985 r
.58214 .48848 .58753 .4922 .59809 .48931 .59273 .48565 Mtetra
.596 .83 .988 r
.59273 .48565 .59809 .48931 .60868 .48655 .60336 .48296 Mtetra
.588 .83 .991 r
.60336 .48296 .60868 .48655 .61933 .48392 .61404 .48035 Mtetra
.584 .83 .992 r
.61404 .48035 .61933 .48392 .63003 .48141 .62477 .47777 Mtetra
.592 .831 .99 r
.62477 .47777 .63003 .48141 .64077 .47895 .63554 .47508 Mtetra
.615 .83 .983 r
.63554 .47508 .64077 .47895 .65156 .47645 .64635 .47208 Mtetra
.649 .822 .966 r
.64635 .47208 .65156 .47645 .66238 .47371 .65718 .46859 Mtetra
.689 .804 .936 r
.65718 .46859 .66238 .47371 .67323 .47049 .66801 .46428 Mtetra
.714 .772 .898 r
.66801 .46428 .67323 .47049 .6841 .46664 .67885 .45915 Mtetra
.729 .739 .859 r
.67885 .45915 .6841 .46664 .69496 .46191 .68967 .45314 Mtetra
.729 .707 .83 r
.68967 .45314 .69496 .46191 .70581 .45649 .70049 .44666 Mtetra
.718 .68 .813 r
.70049 .44666 .70581 .45649 .71666 .45057 .71134 .44028 Mtetra
.703 .666 .81 r
.71134 .44028 .71666 .45057 .72754 .44459 .72224 .43441 Mtetra
.678 .657 .822 r
.72224 .43441 .72754 .44459 .73847 .43915 .73325 .42973 Mtetra
.656 .664 .846 r
.73325 .42973 .73847 .43915 .74949 .43437 .74436 .42608 Mtetra
.629 .681 .88 r
.74436 .42608 .74949 .43437 .7606 .43054 .75559 .4234 Mtetra
.605 .706 .915 r
.75559 .4234 .7606 .43054 .77181 .42739 .7669 .42127 Mtetra
.595 .739 .944 r
.7669 .42127 .77181 .42739 .78311 .42465 .77827 .41916 Mtetra
.593 .763 .96 r
.77827 .41916 .78311 .42465 .79446 .42209 .78969 .4169 Mtetra
.609 .783 .965 r
.78969 .4169 .79446 .42209 .80586 .4194 .80113 .41423 Mtetra
.625 .791 .962 r
.80113 .41423 .80586 .4194 .81729 .41654 .81258 .4112 Mtetra
.641 .792 .954 r
.81258 .4112 .81729 .41654 .82875 .41343 .82406 .40782 Mtetra
.653 .787 .946 r
.82406 .40782 .82875 .41343 .84024 .4101 .83556 .40421 Mtetra
.659 .78 .938 r
.83556 .40421 .84024 .4101 .85176 .4066 .84709 .40047 Mtetra
.663 .773 .931 r
.84709 .40047 .85176 .4066 .86332 .40299 .85866 .39662 Mtetra
.665 .766 .925 r
.85866 .39662 .86332 .40299 .87491 .39929 .87027 .39273 Mtetra
.664 .76 .921 r
.87027 .39273 .87491 .39929 .88655 .39556 .88193 .38884 Mtetra
.643 .748 .926 r
.25789 .57635 .2641 .58177 .27347 .57906 .26727 .5737 Mtetra
.639 .75 .929 r
.26727 .5737 .27347 .57906 .28287 .57637 .27668 .5711 Mtetra
.637 .754 .932 r
.27668 .5711 .28287 .57637 .2923 .57363 .28613 .56852 Mtetra
.636 .76 .937 r
.28613 .56852 .2923 .57363 .30178 .57081 .29561 .56593 Mtetra
.635 .77 .944 r
.29561 .56593 .30178 .57081 .3113 .56786 .30513 .56333 Mtetra
.64 .785 .952 r
.30513 .56333 .3113 .56786 .32087 .56468 .3147 .56056 Mtetra
.649 .805 .958 r
.3147 .56056 .32087 .56468 .33049 .56118 .32431 .55753 Mtetra
.667 .829 .961 r
.32431 .55753 .33049 .56118 .34016 .55733 .33399 .55404 Mtetra
.695 .849 .957 r
.33399 .55404 .34016 .55733 .34988 .55308 .34373 .5499 Mtetra
.719 .858 .948 r
.34373 .5499 .34988 .55308 .35964 .54869 .35353 .5452 Mtetra
.742 .848 .929 r
.35353 .5452 .35964 .54869 .36942 .54432 .36339 .5399 Mtetra
.737 .812 .911 r
.36339 .5399 .36942 .54432 .3792 .54047 .37326 .53466 Mtetra
.714 .76 .888 r
.37326 .53466 .3792 .54047 .38898 .53756 .38314 .52993 Mtetra
.67 .694 .864 r
.38314 .52993 .38898 .53756 .39876 .53567 .393 .52633 Mtetra
.613 .63 .844 r
.393 .52633 .39876 .53567 .40854 .53493 .40283 .5244 Mtetra
.571 .586 .829 r
.40283 .5244 .40854 .53493 .41835 .53471 .41266 .52372 Mtetra
.535 .56 .827 r
.41266 .52372 .41835 .53471 .42821 .53459 .42251 .5241 Mtetra
.526 .566 .838 r
.42251 .5241 .42821 .53459 .43814 .53402 .43241 .52462 Mtetra
.538 .597 .861 r
.43241 .52462 .43814 .53402 .44814 .5326 .44238 .52467 Mtetra
.56 .647 .893 r
.44238 .52467 .44814 .5326 .4582 .53038 .45243 .52394 Mtetra
.597 .71 .923 r
.45243 .52394 .4582 .53038 .46832 .52737 .46255 .52217 Mtetra
.624 .767 .948 r
.46255 .52217 .46832 .52737 .47849 .52386 .47272 .51962 Mtetra
.646 .813 .963 r
.47272 .51962 .47849 .52386 .48869 .52005 .48295 .51641 Mtetra
.656 .841 .972 r
.48295 .51641 .48869 .52005 .49893 .51613 .49322 .51285 Mtetra
.657 .858 .976 r
.49322 .51285 .49893 .51613 .5092 .51224 .50352 .50912 Mtetra
.655 .865 .979 r
.50352 .50912 .5092 .51224 .51951 .50843 .51386 .50536 Mtetra
.648 .866 .981 r
.51386 .50536 .51951 .50843 .52985 .50476 .52424 .50167 Mtetra
.641 .864 .983 r
.52424 .50167 .52985 .50476 .54022 .50122 .53465 .4981 Mtetra
.631 .861 .985 r
.53465 .4981 .54022 .50122 .55064 .49782 .5451 .49467 Mtetra
.622 .858 .988 r
.5451 .49467 .55064 .49782 .5611 .49456 .55559 .4914 Mtetra
.611 .855 .99 r
.55559 .4914 .5611 .49456 .5716 .49145 .56613 .48827 Mtetra
.6 .851 .992 r
.56613 .48827 .5716 .49145 .58214 .48848 .57671 .4853 Mtetra
.592 .849 .993 r
.57671 .4853 .58214 .48848 .59273 .48565 .58733 .48244 Mtetra
.586 .847 .994 r
.58733 .48244 .59273 .48565 .60336 .48296 .598 .47965 Mtetra
.59 .845 .993 r
.598 .47965 .60336 .48296 .61404 .48035 .60871 .47684 Mtetra
.605 .842 .989 r
.60871 .47684 .61404 .48035 .62477 .47777 .61946 .47386 Mtetra
.634 .836 .978 r
.61946 .47386 .62477 .47777 .63554 .47508 .63025 .47051 Mtetra
.674 .821 .954 r
.63025 .47051 .63554 .47508 .64635 .47208 .64105 .46651 Mtetra
.706 .792 .918 r
.64105 .46651 .64635 .47208 .65718 .46859 .65186 .4617 Mtetra
.731 .756 .873 r
.65186 .4617 .65718 .46859 .66801 .46428 .66266 .45583 Mtetra
.736 .716 .833 r
.66266 .45583 .66801 .46428 .67885 .45915 .67345 .44915 Mtetra
.731 .682 .803 r
.67345 .44915 .67885 .45915 .68967 .45314 .68424 .44197 Mtetra
.719 .657 .788 r
.68424 .44197 .68967 .45314 .70049 .44666 .69505 .43493 Mtetra
.695 .638 .788 r
.69505 .43493 .70049 .44666 .71134 .44028 .70594 .42896 Mtetra
.672 .634 .803 r
.70594 .42896 .71134 .44028 .72224 .43441 .71693 .42427 Mtetra
.635 .639 .837 r
.71693 .42427 .72224 .43441 .73325 .42973 .72806 .42128 Mtetra
.598 .663 .884 r
.72806 .42128 .73325 .42973 .74436 .42608 .73932 .41946 Mtetra
.562 .705 .937 r
.73932 .41946 .74436 .42608 .75559 .4234 .75067 .41818 Mtetra
.532 .747 .975 r
.75067 .41818 .75559 .4234 .7669 .42127 .76209 .41696 Mtetra
.541 .792 .991 r
.76209 .41696 .7669 .42127 .77827 .41916 .77352 .41513 Mtetra
.567 .817 .992 r
.77352 .41513 .77827 .41916 .78969 .4169 .78497 .41271 Mtetra
.61 .828 .984 r
.78497 .41271 .78969 .4169 .80113 .41423 .79641 .40962 Mtetra
.641 .823 .971 r
.79641 .40962 .80113 .41423 .81258 .4112 .80786 .40606 Mtetra
.659 .809 .955 r
.80786 .40606 .81258 .4112 .82406 .40782 .81933 .40222 Mtetra
.668 .795 .942 r
.81933 .40222 .82406 .40782 .83556 .40421 .83083 .39819 Mtetra
.67 .78 .932 r
.83083 .39819 .83556 .40421 .84709 .40047 .84237 .39415 Mtetra
.67 .771 .926 r
.84237 .39415 .84709 .40047 .85866 .39662 .85396 .3901 Mtetra
.669 .764 .921 r
.85396 .3901 .85866 .39662 .87027 .39273 .86559 .38606 Mtetra
.667 .759 .919 r
.86559 .38606 .87027 .39273 .88193 .38884 .87727 .38207 Mtetra
.646 .749 .924 r
.25164 .57089 .25789 .57635 .26727 .5737 .26105 .56815 Mtetra
.642 .745 .924 r
.26105 .56815 .26727 .5737 .27668 .5711 .27048 .56548 Mtetra
.639 .743 .924 r
.27048 .56548 .27668 .5711 .28613 .56852 .27995 .56289 Mtetra
.634 .741 .926 r
.27995 .56289 .28613 .56852 .29561 .56593 .28944 .56039 Mtetra
.627 .743 .931 r
.28944 .56039 .29561 .56593 .30513 .56333 .29896 .55802 Mtetra
.624 .752 .939 r
.29896 .55802 .30513 .56333 .3147 .56056 .30852 .55566 Mtetra
.622 .768 .95 r
.30852 .55566 .3147 .56056 .32431 .55753 .31812 .55326 Mtetra
.633 .797 .962 r
.31812 .55326 .32431 .55753 .33399 .55404 .32778 .55052 Mtetra
.654 .834 .969 r
.32778 .55052 .33399 .55404 .34373 .5499 .33751 .54721 Mtetra
.684 .875 .97 r
.33751 .54721 .34373 .5499 .35353 .5452 .34731 .54309 Mtetra
.729 .904 .956 r
.34731 .54309 .35353 .5452 .36339 .5399 .35719 .5379 Mtetra
.756 .909 .943 r
.35719 .5379 .36339 .5399 .37326 .53466 .36713 .53204 Mtetra
.774 .886 .926 r
.36713 .53204 .37326 .53466 .38314 .52993 .37711 .52575 Mtetra
.751 .825 .91 r
.37711 .52575 .38314 .52993 .393 .52633 .38708 .52004 Mtetra
.699 .744 .886 r
.38708 .52004 .393 .52633 .40283 .5244 .39703 .51569 Mtetra
.639 .657 .852 r
.39703 .51569 .40283 .5244 .41266 .52372 .40694 .51295 Mtetra
.575 .585 .825 r
.40694 .51295 .41266 .52372 .42251 .5241 .41683 .51214 Mtetra
.543 .547 .809 r
.41683 .51214 .42251 .5241 .43241 .52462 .42673 .51239 Mtetra
.526 .534 .807 r
.42673 .51239 .43241 .52462 .44238 .52467 .43669 .51317 Mtetra
.53 .55 .82 r
.43669 .51317 .44238 .52467 .45243 .52394 .4467 .51372 Mtetra
.552 .587 .843 r
.4467 .51372 .45243 .52394 .46255 .52217 .4568 .5135 Mtetra
.576 .636 .873 r
.4568 .5135 .46255 .52217 .47272 .51962 .46696 .51245 Mtetra
.607 .693 .904 r
.46696 .51245 .47272 .51962 .48295 .51641 .47719 .5105 Mtetra
.628 .744 .931 r
.47719 .5105 .48295 .51641 .49322 .51285 .48747 .50792 Mtetra
.642 .787 .951 r
.48747 .50792 .49322 .51285 .50352 .50912 .4978 .50488 Mtetra
.647 .817 .965 r
.4978 .50488 .50352 .50912 .51386 .50536 .50817 .50157 Mtetra
.645 .836 .974 r
.50817 .50157 .51386 .50536 .52424 .50167 .51858 .49816 Mtetra
.64 .847 .98 r
.51858 .49816 .52424 .50167 .53465 .4981 .52903 .49474 Mtetra
.632 .852 .983 r
.52903 .49474 .53465 .4981 .5451 .49467 .53951 .49136 Mtetra
.625 .853 .986 r
.53951 .49136 .5451 .49467 .55559 .4914 .55004 .48807 Mtetra
.62 .852 .987 r
.55004 .48807 .55559 .4914 .56613 .48827 .56061 .48485 Mtetra
.617 .848 .987 r
.56061 .48485 .56613 .48827 .57671 .4853 .57122 .48169 Mtetra
.622 .842 .984 r
.57122 .48169 .57671 .4853 .58733 .48244 .58187 .47851 Mtetra
.633 .833 .977 r
.58187 .47851 .58733 .48244 .598 .47965 .59256 .47522 Mtetra
.653 .819 .963 r
.59256 .47522 .598 .47965 .60871 .47684 .60329 .47167 Mtetra
.678 .798 .939 r
.60329 .47167 .60871 .47684 .61946 .47386 .61405 .46765 Mtetra
.7 .767 .904 r
.61405 .46765 .61946 .47386 .63025 .47051 .62482 .46298 Mtetra
.719 .733 .862 r
.62482 .46298 .63025 .47051 .64105 .46651 .6356 .4574 Mtetra
.725 .697 .824 r
.6356 .4574 .64105 .46651 .65186 .4617 .64637 .45097 Mtetra
.726 .667 .792 r
.64637 .45097 .65186 .4617 .66266 .45583 .65713 .44373 Mtetra
.718 .643 .772 r
.65713 .44373 .66266 .45583 .67345 .44915 .6679 .43625 Mtetra
.704 .625 .766 r
.6679 .43625 .67345 .44915 .68424 .44197 .67871 .4293 Mtetra
.687 .62 .776 r
.67871 .4293 .68424 .44197 .69505 .43493 .6896 .42342 Mtetra
.653 .622 .806 r
.6896 .42342 .69505 .43493 .70594 .42896 .70061 .4195 Mtetra
.614 .645 .857 r
.70061 .4195 .70594 .42896 .71693 .42427 .71177 .41725 Mtetra
.547 .684 .929 r
.71177 .41725 .71693 .42427 .72806 .42128 .72306 .41639 Mtetra
.457 .725 .983 r
.72306 .41639 .72806 .42128 .73932 .41946 .73445 .41614 Mtetra
.409 .771 .995 r
.73445 .41614 .73932 .41946 .75067 .41818 .74589 .41545 Mtetra
.426 .805 .992 r
.74589 .41545 .75067 .41818 .76209 .41696 .75734 .41408 Mtetra
.523 .848 .998 r
.75734 .41408 .76209 .41696 .77352 .41513 .76877 .4116 Mtetra
.604 .855 .991 r
.76877 .4116 .77352 .41513 .78497 .41271 .78018 .40828 Mtetra
.654 .836 .97 r
.78018 .40828 .78497 .41271 .79641 .40962 .7916 .40437 Mtetra
.676 .811 .947 r
.7916 .40437 .79641 .40962 .80786 .40606 .80303 .4001 Mtetra
.68 .786 .93 r
.80303 .4001 .80786 .40606 .81933 .40222 .81449 .39578 Mtetra
.679 .77 .919 r
.81449 .39578 .81933 .40222 .83083 .39819 .826 .39147 Mtetra
.674 .759 .914 r
.826 .39147 .83083 .39819 .84237 .39415 .83757 .38729 Mtetra
.671 .753 .913 r
.83757 .38729 .84237 .39415 .85396 .3901 .84919 .3832 Mtetra
.667 .752 .914 r
.84919 .3832 .85396 .3901 .86559 .38606 .86086 .37919 Mtetra
.664 .753 .916 r
.86086 .37919 .86559 .38606 .87727 .38207 .87259 .37524 Mtetra
.655 .751 .92 r
.24535 .5654 .25164 .57089 .26105 .56815 .25479 .56242 Mtetra
.653 .743 .915 r
.25479 .56242 .26105 .56815 .27048 .56548 .26427 .55949 Mtetra
.648 .733 .911 r
.26427 .55949 .27048 .56548 .27995 .56289 .27377 .55667 Mtetra
.641 .724 .909 r
.27377 .55667 .27995 .56289 .28944 .56039 .28329 .55403 Mtetra
.629 .717 .91 r
.28329 .55403 .28944 .56039 .29896 .55802 .29283 .55165 Mtetra
.618 .713 .914 r
.29283 .55165 .29896 .55802 .30852 .55566 .30239 .54953 Mtetra
.601 .717 .926 r
.30239 .54953 .30852 .55566 .31812 .55326 .31197 .54771 Mtetra
.594 .736 .943 r
.31197 .54771 .31812 .55326 .32778 .55052 .32159 .54591 Mtetra
.588 .773 .967 r
.32159 .54591 .32778 .55052 .33751 .54721 .33126 .54397 Mtetra
.604 .836 .988 r
.33126 .54397 .33751 .54721 .34731 .54309 .34101 .54132 Mtetra
.641 .904 .983 r
.34101 .54132 .34731 .54309 .35719 .5379 .35086 .53748 Mtetra
.683 .954 .952 r
.35086 .53748 .35719 .5379 .36713 .53204 .36081 .53225 Mtetra
.756 .978 .918 r
.36081 .53225 .36713 .53204 .37711 .52575 .37086 .52535 Mtetra
.797 .963 .915 r
.37086 .52535 .37711 .52575 .38708 .52004 .38095 .51784 Mtetra
.806 .902 .909 r
.38095 .51784 .38708 .52004 .39703 .51569 .39105 .51043 Mtetra
.753 .79 .883 r
.39105 .51043 .39703 .51569 .40694 .51295 .40111 .50438 Mtetra
.669 .674 .846 r
.40111 .50438 .40694 .51295 .41683 .51214 .41111 .50063 Mtetra
.603 .586 .807 r
.41111 .50063 .41683 .51214 .42673 .51239 .42108 .49888 Mtetra
.549 .528 .784 r
.42108 .49888 .42673 .51239 .43669 .51317 .43104 .49904 Mtetra
.527 .507 .778 r
.43104 .49904 .43669 .51317 .4467 .51372 .44104 .5 Mtetra
.523 .511 .785 r
.44104 .5 .4467 .51372 .4568 .5135 .4511 .50103 Mtetra
.533 .536 .804 r
.4511 .50103 .4568 .5135 .46696 .51245 .46124 .50159 Mtetra
.557 .578 .831 r
.46124 .50159 .46696 .51245 .47719 .5105 .47145 .50126 Mtetra
.58 .626 .862 r
.47145 .50126 .47719 .5105 .48747 .50792 .48172 .50013 Mtetra
.605 .676 .891 r
.48172 .50013 .48747 .50792 .4978 .50488 .49206 .49822 Mtetra
.623 .719 .915 r
.49206 .49822 .4978 .50488 .50817 .50157 .50245 .49577 Mtetra
.635 .754 .934 r
.50245 .49577 .50817 .50157 .51858 .49816 .51288 .49294 Mtetra
.642 .779 .947 r
.51288 .49294 .51858 .49816 .52903 .49474 .52336 .48987 Mtetra
.645 .795 .954 r
.52336 .48987 .52903 .49474 .53951 .49136 .53387 .48665 Mtetra
.648 .803 .957 r
.53387 .48665 .53951 .49136 .55004 .48807 .54443 .48333 Mtetra
.652 .804 .956 r
.54443 .48333 .55004 .48807 .56061 .48485 .55503 .47991 Mtetra
.659 .799 .95 r
.55503 .47991 .56061 .48485 .57122 .48169 .56566 .47635 Mtetra
.671 .788 .937 r
.56566 .47635 .57122 .48169 .58187 .47851 .57634 .47254 Mtetra
.686 .77 .916 r
.57634 .47254 .58187 .47851 .59256 .47522 .58704 .46834 Mtetra
.7 .745 .887 r
.58704 .46834 .59256 .47522 .60329 .47167 .59777 .4636 Mtetra
.713 .717 .852 r
.59777 .4636 .60329 .47167 .61405 .46765 .60851 .45806 Mtetra
.719 .685 .816 r
.60851 .45806 .61405 .46765 .62482 .46298 .61925 .45171 Mtetra
.722 .656 .784 r
.61925 .45171 .62482 .46298 .6356 .4574 .62999 .44444 Mtetra
.716 .63 .76 r
.62999 .44444 .6356 .4574 .64637 .45097 .64073 .43667 Mtetra
.705 .609 .747 r
.64073 .43667 .64637 .45097 .65713 .44373 .65148 .42896 Mtetra
.69 .597 .746 r
.65148 .42896 .65713 .44373 .6679 .43625 .66228 .42205 Mtetra
.661 .588 .762 r
.66228 .42205 .6679 .43625 .67871 .4293 .67319 .41708 Mtetra
.627 .598 .801 r
.67319 .41708 .67871 .4293 .6896 .42342 .68424 .41415 Mtetra
.554 .621 .873 r
.68424 .41415 .6896 .42342 .70061 .4195 .69545 .41358 Mtetra
.421 .664 .961 r
.69545 .41358 .70061 .4195 .71177 .41725 .70681 .41442 Mtetra
.209 .671 .944 r
.70681 .41442 .71177 .41725 .72306 .41639 .71825 .41537 Mtetra
.079 .632 .82 r
.71825 .41537 .72306 .41639 .73445 .41614 .72973 .41571 Mtetra
.2 .727 .832 r
.72973 .41571 .73445 .41614 .74589 .41545 .74117 .41434 Mtetra
.42 .854 .936 r
.74117 .41434 .74589 .41545 .75734 .41408 .75257 .41154 Mtetra
.613 .899 .987 r
.75257 .41154 .75734 .41408 .76877 .4116 .76393 .40749 Mtetra
.69 .862 .964 r
.76393 .40749 .76877 .4116 .78018 .40828 .77527 .40271 Mtetra
.702 .808 .931 r
.77527 .40271 .78018 .40828 .7916 .40437 .78664 .39777 Mtetra
.7 .771 .907 r
.78664 .39777 .7916 .40437 .80303 .4001 .79805 .39284 Mtetra
.687 .746 .896 r
.79805 .39284 .80303 .4001 .81449 .39578 .80953 .38823 Mtetra
.678 .734 .893 r
.80953 .38823 .81449 .39578 .826 .39147 .82107 .38388 Mtetra
.669 .73 .895 r
.82107 .38388 .826 .39147 .83757 .38729 .83267 .37979 Mtetra
.663 .731 .9 r
.83267 .37979 .83757 .38729 .84919 .3832 .84435 .37589 Mtetra
.659 .736 .907 r
.84435 .37589 .84919 .3832 .86086 .37919 .85608 .37211 Mtetra
.656 .744 .914 r
.85608 .37211 .86086 .37919 .87259 .37524 .86786 .36837 Mtetra
.667 .754 .915 r
.23902 .55988 .24535 .5654 .25479 .56242 .24851 .55659 Mtetra
.667 .744 .908 r
.24851 .55659 .25479 .56242 .26427 .55949 .25802 .5533 Mtetra
.663 .732 .901 r
.25802 .5533 .26427 .55949 .27377 .55667 .26757 .55009 Mtetra
.656 .718 .894 r
.26757 .55009 .27377 .55667 .28329 .55403 .27714 .54705 Mtetra
.645 .703 .889 r
.27714 .54705 .28329 .55403 .29283 .55165 .28672 .54427 Mtetra
.63 .687 .884 r
.28672 .54427 .29283 .55165 .30239 .54953 .29631 .54186 Mtetra
.61 .672 .885 r
.29631 .54186 .30239 .54953 .31197 .54771 .30591 .53997 Mtetra
.592 .664 .888 r
.30591 .53997 .31197 .54771 .32159 .54591 .31552 .53851 Mtetra
.569 .665 .903 r
.31552 .53851 .32159 .54591 .33126 .54397 .32515 .5375 Mtetra
.566 .696 .928 r
.32515 .5375 .33126 .54397 .34101 .54132 .33483 .53637 Mtetra
.574 .757 .964 r
.33483 .53637 .34101 .54132 .35086 .53748 .34459 .5347 Mtetra
.611 .859 .99 r
.34459 .5347 .35086 .53748 .36081 .53225 .35446 .5317 Mtetra
.669 .949 .956 r
.35446 .5317 .36081 .53225 .37086 .52535 .36447 .52669 Mtetra
.685 .979 .876 r
.36447 .52669 .37086 .52535 .38095 .51784 .37457 .51996 Mtetra
.741 .993 .834 r
.37457 .51996 .38095 .51784 .39105 .51043 .38476 .5116 Mtetra
.788 .995 .872 r
.38476 .5116 .39105 .51043 .40111 .50438 .39496 .50319 Mtetra
.799 .943 .92 r
.39496 .50319 .40111 .50438 .41111 .50063 .40513 .49582 Mtetra
.741 .808 .905 r
.40513 .49582 .41111 .50063 .42108 .49888 .41525 .49027 Mtetra
.648 .667 .855 r
.41525 .49027 .42108 .49888 .43104 .49904 .42532 .48717 Mtetra
.59 .576 .805 r
.42532 .48717 .43104 .49904 .44104 .5 .43538 .48582 Mtetra
.553 .523 .775 r
.43538 .48582 .44104 .5 .4511 .50103 .44546 .48582 Mtetra
.543 .504 .763 r
.44546 .48582 .4511 .50103 .46124 .50159 .45558 .48628 Mtetra
.547 .506 .762 r
.45558 .48628 .46124 .50159 .47145 .50126 .46577 .4866 Mtetra
.557 .521 .77 r
.46577 .4866 .47145 .50126 .48172 .50013 .47602 .48648 Mtetra
.575 .544 .783 r
.47602 .48648 .48172 .50013 .49206 .49822 .48635 .48566 Mtetra
.591 .569 .797 r
.48635 .48566 .49206 .49822 .50245 .49577 .49673 .48421 Mtetra
.609 .594 .811 r
.49673 .48421 .50245 .49577 .51288 .49294 .50717 .48216 Mtetra
.623 .616 .823 r
.50717 .48216 .51288 .49294 .52336 .48987 .51765 .47962 Mtetra
.636 .633 .83 r
.51765 .47962 .52336 .48987 .53387 .48665 .52818 .47665 Mtetra
.647 .644 .832 r
.52818 .47665 .53387 .48665 .54443 .48333 .53875 .47331 Mtetra
.657 .648 .829 r
.53875 .47331 .54443 .48333 .55503 .47991 .54936 .46958 Mtetra
.666 .646 .821 r
.54936 .46958 .55503 .47991 .56566 .47635 .56001 .46543 Mtetra
.674 .639 .807 r
.56001 .46543 .56566 .47635 .57634 .47254 .57068 .46078 Mtetra
.681 .629 .791 r
.57068 .46078 .57634 .47254 .58704 .46834 .58138 .45552 Mtetra
.686 .617 .772 r
.58138 .45552 .58704 .46834 .59777 .4636 .59209 .44962 Mtetra
.691 .605 .755 r
.59209 .44962 .59777 .4636 .60851 .45806 .60281 .443 Mtetra
.691 .594 .742 r
.60281 .443 .60851 .45806 .61925 .45171 .61354 .43592 Mtetra
.689 .586 .735 r
.61354 .43592 .61925 .45171 .62999 .44444 .62428 .42868 Mtetra
.682 .582 .737 r
.62428 .42868 .62999 .44444 .64073 .43667 .63506 .4219 Mtetra
.666 .584 .754 r
.63506 .4219 .64073 .43667 .65148 .42896 .64591 .41648 Mtetra
.643 .602 .793 r
.64591 .41648 .65148 .42896 .66228 .42205 .65685 .41284 Mtetra
.575 .633 .872 r
.65685 .41284 .66228 .42205 .67319 .41708 .66796 .4117 Mtetra
.403 .677 .972 r
.66796 .4117 .67319 .41708 .68424 .41415 .67921 .41244 Mtetra
0 .549 .81 r
.67921 .41244 .68424 .41415 .69545 .41358 .69059 .41425 Mtetra
.245 0 0 r
.69059 .41425 .69545 .41358 .70681 .41442 .70205 .41603 Mtetra
.173 0 0 r
.70205 .41603 .70681 .41442 .71825 .41537 .7135 .41615 Mtetra
0 0 0 r
.7135 .41615 .71825 .41537 .72973 .41571 .72491 .41451 Mtetra
.512 .898 .952 r
.72491 .41451 .72973 .41571 .74117 .41434 .73624 .41078 Mtetra
.697 .886 .967 r
.73624 .41078 .74117 .41434 .75257 .41154 .74753 .40568 Mtetra
.726 .804 .913 r
.74753 .40568 .75257 .41154 .76393 .40749 .7588 .40002 Mtetra
.721 .751 .876 r
.7588 .40002 .76393 .40749 .77527 .40271 .7701 .39422 Mtetra
.702 .716 .86 r
.7701 .39422 .77527 .40271 .78664 .39777 .78147 .38889 Mtetra
.688 .701 .857 r
.78147 .38889 .78664 .39777 .79805 .39284 .79291 .38398 Mtetra
.673 .696 .863 r
.79291 .38398 .79805 .39284 .80953 .38823 .80444 .37961 Mtetra
.663 .699 .873 r
.80444 .37961 .80953 .38823 .82107 .38388 .81604 .37563 Mtetra
.655 .706 .885 r
.81604 .37563 .82107 .38388 .83267 .37979 .82771 .37191 Mtetra
.65 .715 .896 r
.82771 .37191 .83267 .37979 .84435 .37589 .83945 .36837 Mtetra
.646 .726 .907 r
.83945 .36837 .84435 .37589 .85608 .37211 .85125 .36491 Mtetra
.646 .737 .916 r
.85125 .36491 .85608 .37211 .86786 .36837 .8631 .36144 Mtetra
.677 .756 .911 r
.23264 .55431 .23902 .55988 .24851 .55659 .24217 .55077 Mtetra
.679 .748 .903 r
.24217 .55077 .24851 .55659 .25802 .5533 .25174 .54713 Mtetra
.678 .737 .895 r
.25174 .54713 .25802 .5533 .26757 .55009 .26133 .54348 Mtetra
.675 .723 .886 r
.26133 .54348 .26757 .55009 .27714 .54705 .27096 .53988 Mtetra
.669 .706 .875 r
.27096 .53988 .27714 .54705 .28672 .54427 .28061 .53638 Mtetra
.656 .683 .863 r
.28061 .53638 .28672 .54427 .29631 .54186 .29027 .53319 Mtetra
.638 .657 .853 r
.29027 .53319 .29631 .54186 .30591 .53997 .29993 .53051 Mtetra
.612 .629 .843 r
.29993 .53051 .30591 .53997 .31552 .53851 .30958 .52854 Mtetra
.578 .603 .841 r
.30958 .52854 .31552 .53851 .32515 .5375 .31921 .52755 Mtetra
.548 .59 .848 r
.31921 .52755 .32515 .5375 .33483 .53637 .32884 .52732 Mtetra
.507 .593 .875 r
.32884 .52732 .33483 .53637 .34459 .5347 .33849 .52784 Mtetra
.492 .654 .932 r
.33849 .52784 .34459 .5347 .35446 .5317 .34821 .52799 Mtetra
.483 .778 .996 r
.34821 .52799 .35446 .5317 .36447 .52669 .35805 .52697 Mtetra
.435 .872 .894 r
.35805 .52697 .36447 .52669 .37457 .51996 .36804 .5237 Mtetra
.422 .833 .646 r
.36804 .5237 .37457 .51996 .38476 .5116 .37821 .51729 Mtetra
0 0 0 r
.37821 .51729 .38476 .5116 .39496 .50319 .38848 .50869 Mtetra
.589 .888 .594 r
.38848 .50869 .39496 .50319 .40513 .49582 .39882 .49849 Mtetra
.779 .996 .798 r
.39882 .49849 .40513 .49582 .41525 .49027 .40914 .48867 Mtetra
.821 .929 .904 r
.40914 .48867 .41525 .49027 .42532 .48717 .41941 .48058 Mtetra
.737 .751 .864 r
.41941 .48058 .42532 .48717 .43538 .48582 .42962 .47466 Mtetra
.645 .616 .806 r
.42962 .47466 .43538 .48582 .44546 .48582 .43978 .4713 Mtetra
.595 .543 .766 r
.43978 .4713 .44546 .48582 .45558 .48628 .44995 .4696 Mtetra
.568 .504 .744 r
.44995 .4696 .45558 .48628 .46577 .4866 .46014 .46904 Mtetra
.56 .492 .736 r
.46014 .46904 .46577 .4866 .47602 .48648 .47038 .46884 Mtetra
.563 .494 .735 r
.47038 .46884 .47602 .48648 .48635 .48566 .48068 .46848 Mtetra
.572 .504 .74 r
.48068 .46848 .48635 .48566 .49673 .48421 .49104 .46769 Mtetra
.586 .519 .746 r
.49104 .46769 .49673 .48421 .50717 .48216 .50146 .46626 Mtetra
.6 .533 .751 r
.50146 .46626 .50717 .48216 .51765 .47962 .51194 .4642 Mtetra
.615 .547 .755 r
.51194 .4642 .51765 .47962 .52818 .47665 .52247 .46147 Mtetra
.628 .557 .755 r
.52247 .46147 .52818 .47665 .53875 .47331 .53304 .45809 Mtetra
.64 .564 .753 r
.53304 .45809 .53875 .47331 .54936 .46958 .54364 .45407 Mtetra
.651 .567 .747 r
.54364 .45407 .54936 .46958 .56001 .46543 .55428 .44937 Mtetra
.659 .566 .739 r
.55428 .44937 .56001 .46543 .57068 .46078 .56494 .44403 Mtetra
.665 .564 .73 r
.56494 .44403 .57068 .46078 .58138 .45552 .57563 .43803 Mtetra
.668 .559 .723 r
.57563 .43803 .58138 .45552 .59209 .44962 .58632 .4316 Mtetra
.668 .555 .718 r
.58632 .4316 .59209 .44962 .60281 .443 .59704 .42499 Mtetra
.663 .553 .72 r
.59704 .42499 .60281 .443 .61354 .43592 .60779 .41874 Mtetra
.649 .552 .731 r
.60779 .41874 .61354 .43592 .62428 .42868 .61859 .41363 Mtetra
.628 .561 .759 r
.61859 .41363 .62428 .42868 .63506 .4219 .62948 .4102 Mtetra
.57 .578 .822 r
.62948 .4102 .63506 .4219 .64591 .41648 .6405 .40938 Mtetra
.419 .619 .934 r
.6405 .40938 .64591 .41648 .65685 .41284 .65168 .41078 Mtetra
0 .443 .752 r
.65168 .41078 .65685 .41284 .66796 .4117 .66301 .41397 Mtetra
.466 0 0 r
.66301 .41397 .66796 .4117 .67921 .41244 .67445 .41757 Mtetra
.458 0 0 r
.67445 .41757 .67921 .41244 .69059 .41425 .6859 .41955 Mtetra
.35 0 0 r
.6859 .41955 .69059 .41425 .70205 .41603 .69732 .4193 Mtetra
0 0 0 r
.69732 .4193 .70205 .41603 .7135 .41615 .70862 .41583 Mtetra
.608 .952 .908 r
.70862 .41583 .7135 .41615 .72491 .41451 .71984 .41003 Mtetra
.772 .865 .918 r
.71984 .41003 .72491 .41451 .73624 .41078 .731 .40301 Mtetra
.757 .753 .85 r
.731 .40301 .73624 .41078 .74753 .40568 .74216 .39559 Mtetra
.72 .687 .817 r
.74216 .39559 .74753 .40568 .7588 .40002 .75339 .38893 Mtetra
.696 .658 .808 r
.75339 .38893 .7588 .40002 .7701 .39422 .76471 .38305 Mtetra
.673 .646 .815 r
.76471 .38305 .7701 .39422 .78147 .38889 .77613 .37819 Mtetra
.658 .649 .829 r
.77613 .37819 .78147 .38889 .79291 .38398 .78766 .37406 Mtetra
.648 .661 .849 r
.78766 .37406 .79291 .38398 .80444 .37961 .79927 .37045 Mtetra
.64 .676 .868 r
.79927 .37045 .80444 .37961 .81604 .37563 .81097 .36717 Mtetra
.637 .694 .886 r
.81097 .36717 .81604 .37563 .82771 .37191 .82272 .36398 Mtetra
.635 .709 .9 r
.82272 .36398 .82771 .37191 .83945 .36837 .83453 .36085 Mtetra
.634 .722 .911 r
.83453 .36085 .83945 .36837 .85125 .36491 .8464 .35771 Mtetra
.636 .734 .919 r
.8464 .35771 .85125 .36491 .8631 .36144 .85831 .35446 Mtetra
.677 .756 .911 r
.22623 .54871 .23264 .55431 .24217 .55077 .23577 .54515 Mtetra
.681 .757 .909 r
.23577 .54515 .24217 .55077 .25174 .54713 .24537 .54145 Mtetra
.685 .757 .906 r
.24537 .54145 .25174 .54713 .26133 .54348 .255 .53763 Mtetra
.688 .752 .9 r
.255 .53763 .26133 .54348 .27096 .53988 .26467 .53369 Mtetra
.691 .743 .891 r
.26467 .53369 .27096 .53988 .28061 .53638 .27438 .52962 Mtetra
.686 .725 .879 r
.27438 .52962 .28061 .53638 .29027 .53319 .28411 .5256 Mtetra
.677 .699 .863 r
.28411 .5256 .29027 .53319 .29993 .53051 .29387 .52176 Mtetra
.655 .663 .846 r
.29387 .52176 .29993 .53051 .30958 .52854 .30361 .51849 Mtetra
.623 .623 .829 r
.30361 .51849 .30958 .52854 .31921 .52755 .31334 .5161 Mtetra
.586 .579 .812 r
.31334 .5161 .31921 .52755 .32884 .52732 .32303 .51488 Mtetra
.538 .538 .803 r
.32303 .51488 .32884 .52732 .33849 .52784 .33269 .51515 Mtetra
.508 .518 .802 r
.33269 .51515 .33849 .52784 .34821 .52799 .34235 .51631 Mtetra
.478 .52 .823 r
.34235 .51631 .34821 .52799 .35805 .52697 .35205 .51802 Mtetra
.494 .592 .881 r
.35205 .51802 .35805 .52697 .36804 .5237 .36186 .51872 Mtetra
.558 .756 .97 r
.36186 .51872 .36804 .5237 .37821 .51729 .37183 .51721 Mtetra
.567 .929 .937 r
.37183 .51721 .37821 .51729 .38848 .50869 .38197 .51295 Mtetra
.472 .851 .629 r
.38197 .51295 .38848 .50869 .39882 .49849 .39227 .50544 Mtetra
0 0 0 r
.39227 .50544 .39882 .49849 .40914 .48867 .40264 .49621 Mtetra
.40264 .49621 .40914 .48867 .41941 .48058 .41304 .48623 Mtetra
.477 .819 .532 r
.41304 .48623 .41941 .48058 .42962 .47466 .42342 .47694 Mtetra
.654 .966 .804 r
.42342 .47694 .42962 .47466 .43978 .4713 .43375 .46934 Mtetra
.744 .924 .951 r
.43375 .46934 .43978 .4713 .44995 .4696 .44405 .46342 Mtetra
.688 .756 .904 r
.44405 .46342 .44995 .4696 .46014 .46904 .45434 .45927 Mtetra
.64 .643 .837 r
.45434 .45927 .46014 .46904 .47038 .46884 .46464 .45623 Mtetra
.613 .579 .792 r
.46464 .45623 .47038 .46884 .48068 .46848 .47497 .45391 Mtetra
.603 .549 .766 r
.47497 .45391 .48068 .46848 .49104 .46769 .48534 .45182 Mtetra
.602 .535 .751 r
.48534 .45182 .49104 .46769 .50146 .46626 .49576 .44963 Mtetra
.606 .53 .742 r
.49576 .44963 .50146 .46626 .51194 .4642 .50623 .44714 Mtetra
.614 .53 .737 r
.50623 .44714 .51194 .4642 .52247 .46147 .51675 .44422 Mtetra
.622 .534 .734 r
.51675 .44422 .52247 .46147 .53304 .45809 .52731 .44081 Mtetra
.63 .538 .732 r
.52731 .44081 .53304 .45809 .54364 .45407 .53791 .43691 Mtetra
.638 .544 .732 r
.53791 .43691 .54364 .45407 .55428 .44937 .54854 .43257 Mtetra
.644 .551 .735 r
.54854 .43257 .55428 .44937 .56494 .44403 .55921 .42793 Mtetra
.648 .56 .742 r
.55921 .42793 .56494 .44403 .57563 .43803 .56991 .42318 Mtetra
.65 .574 .756 r
.56991 .42318 .57563 .43803 .58632 .4316 .58064 .41867 Mtetra
.644 .595 .785 r
.58064 .41867 .58632 .4316 .59704 .42499 .59143 .41487 Mtetra
.625 .636 .841 r
.59143 .41487 .59704 .42499 .60779 .41874 .60228 .4122 Mtetra
.537 .698 .944 r
.60228 .4122 .60779 .41874 .61859 .41363 .61323 .41132 Mtetra
.157 .657 .911 r
.61323 .41132 .61859 .41363 .62948 .4102 .6243 .41217 Mtetra
.396 0 0 r
.6243 .41217 .62948 .4102 .6405 .40938 .63549 .41475 Mtetra
.519 .023 .018 r
.63549 .41475 .6405 .40938 .65168 .41078 .6468 .41805 Mtetra
.51 .048 .093 r
.6468 .41805 .65168 .41078 .66301 .41397 .65817 .42061 Mtetra
.434 0 .024 r
.65817 .42061 .66301 .41397 .67445 .41757 .66956 .42142 Mtetra
.115 0 0 r
.66956 .42142 .67445 .41757 .6859 .41955 .68085 .41892 Mtetra
.6 .945 .928 r
.68085 .41892 .6859 .41955 .69732 .4193 .69206 .4136 Mtetra
.78 .821 .884 r
.69206 .4136 .69732 .4193 .70862 .41583 .70317 .40599 Mtetra
.759 .706 .802 r
.70317 .40599 .70862 .41583 .71984 .41003 .71424 .39731 Mtetra
.723 .644 .769 r
.71424 .39731 .71984 .41003 .731 .40301 .72535 .38919 Mtetra
.7 .619 .762 r
.72535 .38919 .731 .40301 .74216 .39559 .73653 .38197 Mtetra
.675 .609 .774 r
.73653 .38197 .74216 .39559 .75339 .38893 .74785 .37629 Mtetra
.657 .614 .794 r
.74785 .37629 .75339 .38893 .76471 .38305 .75928 .3718 Mtetra
.642 .63 .823 r
.75928 .3718 .76471 .38305 .77613 .37819 .77083 .36824 Mtetra
.629 .652 .853 r
.77083 .36824 .77613 .37819 .78766 .37406 .78247 .36526 Mtetra
.625 .678 .881 r
.78247 .36526 .78766 .37406 .79927 .37045 .79418 .36246 Mtetra
.621 .701 .902 r
.79418 .36246 .79927 .37045 .81097 .36717 .80595 .35972 Mtetra
.625 .72 .915 r
.80595 .35972 .81097 .36717 .82272 .36398 .81777 .35684 Mtetra
.627 .732 .923 r
.81777 .35684 .82272 .36398 .83453 .36085 .82963 .35383 Mtetra
.631 .739 .926 r
.82963 .35383 .83453 .36085 .8464 .35771 .84153 .3507 Mtetra
.636 .743 .926 r
.84153 .3507 .8464 .35771 .85831 .35446 .85348 .34743 Mtetra
.666 .754 .916 r
.21976 .54307 .22623 .54871 .23577 .54515 .22931 .53976 Mtetra
.67 .765 .921 r
.22931 .53976 .23577 .54515 .24537 .54145 .2389 .53633 Mtetra
.678 .776 .925 r
.2389 .53633 .24537 .54145 .255 .53763 .24854 .5327 Mtetra
.688 .786 .925 r
.24854 .5327 .255 .53763 .26467 .53369 .25823 .5288 Mtetra
.702 .79 .92 r
.25823 .5288 .26467 .53369 .27438 .52962 .26798 .52453 Mtetra
.712 .786 .91 r
.26798 .52453 .27438 .52962 .28411 .5256 .27778 .51994 Mtetra
.719 .768 .891 r
.27778 .51994 .28411 .5256 .29387 .52176 .28763 .51501 Mtetra
.712 .734 .868 r
.28763 .51501 .29387 .52176 .30361 .51849 .29751 .51009 Mtetra
.695 .687 .838 r
.29751 .51009 .30361 .51849 .31334 .5161 .3074 .50537 Mtetra
.659 .627 .806 r
.3074 .50537 .31334 .5161 .32303 .51488 .31726 .50153 Mtetra
.615 .566 .776 r
.31726 .50153 .32303 .51488 .33269 .51515 .32706 .49911 Mtetra
.565 .508 .749 r
.32706 .49911 .33269 .51515 .34235 .51631 .33681 .49858 Mtetra
.507 .456 .735 r
.33681 .49858 .34235 .51631 .35205 .51802 .34647 .50046 Mtetra
.464 .432 .738 r
.34647 .50046 .35205 .51802 .36186 .51872 .35613 .5038 Mtetra
.41 .43 .771 r
.35613 .5038 .36186 .51872 .37183 .51721 .36582 .50799 Mtetra
.37 .523 .879 r
.36582 .50799 .37183 .51721 .38197 .51295 .37565 .51082 Mtetra
.259 .728 .944 r
.37565 .51082 .38197 .51295 .39227 .50544 .38569 .51068 Mtetra
.057 0 0 r
.38569 .51068 .39227 .50544 .40264 .49621 .39591 .50704 Mtetra
.08 0 0 r
.39591 .50704 .40264 .49621 .41304 .48623 .40632 .49946 Mtetra
.061 0 .03 r
.40632 .49946 .41304 .48623 .42342 .47694 .4168 .48973 Mtetra
0 0 0 r
.4168 .48973 .42342 .47694 .43375 .46934 .42732 .47897 Mtetra
.42732 .47897 .43375 .46934 .44405 .46342 .43781 .46863 Mtetra
.473 .825 .551 r
.43781 .46863 .44405 .46342 .45434 .45927 .44827 .45968 Mtetra
.75 .987 .898 r
.44827 .45968 .45434 .45927 .46464 .45623 .45871 .45218 Mtetra
.752 .849 .923 r
.45871 .45218 .46464 .45623 .47497 .45391 .46913 .44623 Mtetra
.701 .719 .863 r
.46913 .44623 .47497 .45391 .48534 .45182 .47956 .44134 Mtetra
.664 .642 .817 r
.47956 .44134 .48534 .45182 .49576 .44963 .49001 .43722 Mtetra
.645 .601 .79 r
.49001 .43722 .49576 .44963 .50623 .44714 .5005 .43352 Mtetra
.636 .58 .774 r
.5005 .43352 .50623 .44714 .51675 .44422 .51102 .43 Mtetra
.632 .57 .767 r
.51102 .43 .51675 .44422 .52731 .44081 .52158 .42656 Mtetra
.63 .57 .768 r
.52158 .42656 .52731 .44081 .53791 .43691 .53218 .42319 Mtetra
.628 .575 .776 r
.53218 .42319 .53791 .43691 .54854 .43257 .54283 .42001 Mtetra
.622 .589 .796 r
.54283 .42001 .54854 .43257 .55921 .42793 .55352 .41725 Mtetra
.604 .614 .834 r
.55352 .41725 .55921 .42793 .56991 .42318 .56427 .41527 Mtetra
.555 .66 .907 r
.56427 .41527 .56991 .42318 .58064 .41867 .57508 .41437 Mtetra
.341 .693 .982 r
.57508 .41437 .58064 .41867 .59143 .41487 .58599 .41504 Mtetra
.253 0 0 r
.58599 .41504 .59143 .41487 .60228 .4122 .597 .4172 Mtetra
.527 .025 .008 r
.597 .4172 .60228 .4122 .61323 .41132 .60813 .42078 Mtetra
.564 .138 .191 r
.60813 .42078 .61323 .41132 .6243 .41217 .61936 .42481 Mtetra
.545 .154 .25 r
.61936 .42481 .6243 .41217 .63549 .41475 .63066 .42783 Mtetra
.496 .109 .237 r
.63066 .42783 .63549 .41475 .6468 .41805 .64197 .42867 Mtetra
.343 0 .118 r
.64197 .42867 .6468 .41805 .65817 .42061 .65319 .4255 Mtetra
0 0 0 r
.65319 .4255 .65817 .42061 .66956 .42142 .66431 .41874 Mtetra
.848 .93 .882 r
.66431 .41874 .66956 .42142 .68085 .41892 .67531 .40891 Mtetra
.795 .715 .776 r
.67531 .40891 .68085 .41892 .69206 .4136 .68624 .39767 Mtetra
.729 .61 .725 r
.68624 .39767 .69206 .4136 .70317 .40599 .69721 .38728 Mtetra
.693 .568 .71 r
.69721 .38728 .70317 .40599 .71424 .39731 .70826 .37836 Mtetra
.659 .548 .717 r
.70826 .37836 .71424 .39731 .72535 .38919 .71947 .37191 Mtetra
.637 .549 .738 r
.71947 .37191 .72535 .38919 .73653 .38197 .73084 .36741 Mtetra
.619 .568 .775 r
.73084 .36741 .73653 .38197 .74785 .37629 .74234 .36438 Mtetra
.603 .599 .82 r
.74234 .36438 .74785 .37629 .75928 .3718 .75396 .36225 Mtetra
.595 .645 .87 r
.75396 .36225 .75928 .3718 .77083 .36824 .76565 .36035 Mtetra
.589 .689 .911 r
.76565 .36035 .77083 .36824 .78247 .36526 .77741 .35845 Mtetra
.595 .729 .937 r
.77741 .35845 .78247 .36526 .79418 .36246 .7892 .3562 Mtetra
.604 .753 .949 r
.7892 .3562 .79418 .36246 .80595 .35972 .80103 .35362 Mtetra
.619 .767 .951 r
.80103 .35362 .80595 .35972 .81777 .35684 .81288 .35065 Mtetra
.631 .77 .947 r
.81288 .35065 .81777 .35684 .82963 .35383 .82475 .3474 Mtetra
.64 .766 .939 r
.82475 .3474 .82963 .35383 .84153 .3507 .83666 .34394 Mtetra
.646 .757 .93 r
.83666 .34394 .84153 .3507 .85348 .34743 .84861 .34035 Mtetra
.645 .749 .924 r
.21326 .53739 .21976 .54307 .22931 .53976 .22278 .53454 Mtetra
.646 .766 .936 r
.22278 .53454 .22931 .53976 .2389 .53633 .23235 .53162 Mtetra
.651 .788 .947 r
.23235 .53162 .2389 .53633 .24854 .5327 .24196 .52853 Mtetra
.662 .811 .955 r
.24196 .52853 .24854 .5327 .25823 .5288 .25164 .52514 Mtetra
.678 .835 .959 r
.25164 .52514 .25823 .5288 .26798 .52453 .26138 .52133 Mtetra
.698 .857 .958 r
.26138 .52133 .26798 .52453 .27778 .51994 .27119 .517 Mtetra
.725 .871 .95 r
.27119 .517 .27778 .51994 .28763 .51501 .28108 .51202 Mtetra
.745 .871 .938 r
.28108 .51202 .28763 .51501 .29751 .51009 .29103 .50651 Mtetra
.762 .849 .916 r
.29103 .50651 .29751 .51009 .3074 .50537 .30103 .50047 Mtetra
.753 .802 .892 r
.30103 .50047 .3074 .50537 .31726 .50153 .31106 .4945 Mtetra
.724 .732 .857 r
.31106 .4945 .31726 .50153 .32706 .49911 .32107 .48901 Mtetra
.668 .644 .817 r
.32107 .48901 .32706 .49911 .33681 .49858 .33102 .48492 Mtetra
.6 .555 .776 r
.33102 .48492 .33681 .49858 .34647 .50046 .34089 .48304 Mtetra
.54 .48 .738 r
.34089 .48304 .34647 .50046 .35613 .5038 .35067 .48355 Mtetra
.481 .42 .712 r
.35067 .48355 .35613 .5038 .36582 .50799 .36038 .48674 Mtetra
.459 .4 .704 r
.36038 .48674 .36582 .50799 .37565 .51082 .37011 .49098 Mtetra
.453 .407 .716 r
.37011 .49098 .37565 .51082 .38569 .51068 .37993 .49517 Mtetra
.479 .467 .766 r
.37993 .49517 .38569 .51068 .39591 .50704 .3899 .49758 Mtetra
.556 .614 .866 r
.3899 .49758 .39591 .50704 .40632 .49946 .40007 .49694 Mtetra
.615 .879 .99 r
.40007 .49694 .40632 .49946 .4168 .48973 .41038 .49349 Mtetra
.363 .793 .612 r
.41038 .49349 .4168 .48973 .42732 .47897 .42082 .48733 Mtetra
0 0 0 r
.42082 .48733 .42732 .47897 .43781 .46863 .43132 .47975 Mtetra
.067 0 0 r
.43132 .47975 .43781 .46863 .44827 .45968 .44185 .47162 Mtetra
.119 0 .031 r
.44185 .47162 .44827 .45968 .45871 .45218 .45238 .46368 Mtetra
.147 0 .035 r
.45238 .46368 .45871 .45218 .46913 .44623 .46292 .45649 Mtetra
.147 0 0 r
.46292 .45649 .46913 .44623 .47956 .44134 .47345 .4501 Mtetra
.139 0 0 r
.47345 .4501 .47956 .44134 .49001 .43722 .48399 .44461 Mtetra
.123 0 0 r
.48399 .44461 .49001 .43722 .5005 .43352 .49456 .43986 Mtetra
.117 0 0 r
.49456 .43986 .5005 .43352 .51102 .43 .50515 .43579 Mtetra
.135 0 0 r
.50515 .43579 .51102 .43 .52158 .42656 .51578 .43233 Mtetra
.185 0 0 r
.51578 .43233 .52158 .42656 .53218 .42319 .52645 .42949 Mtetra
.261 0 0 r
.52645 .42949 .53218 .42319 .54283 .42001 .53716 .42734 Mtetra
.341 0 .001 r
.53716 .42734 .54283 .42001 .55352 .41725 .54794 .42594 Mtetra
.413 0 .091 r
.54794 .42594 .55352 .41725 .56427 .41527 .55878 .42545 Mtetra
.462 .044 .16 r
.55878 .42545 .56427 .41527 .57508 .41437 .56969 .42577 Mtetra
.494 .09 .204 r
.56969 .42577 .57508 .41437 .58599 .41504 .58068 .42687 Mtetra
.501 .102 .215 r
.58068 .42687 .58599 .41504 .597 .4172 .59176 .42818 Mtetra
.48 .071 .186 r
.59176 .42818 .597 .4172 .60813 .42078 .6029 .42894 Mtetra
.395 0 .059 r
.6029 .42894 .60813 .42078 .61936 .42481 .61407 .42828 Mtetra
0 0 0 r
.61407 .42828 .61936 .42481 .63066 .42783 .62522 .42486 Mtetra
.744 .913 .95 r
.62522 .42486 .63066 .42783 .64197 .42867 .63632 .41857 Mtetra
.768 .703 .791 r
.63632 .41857 .64197 .42867 .65319 .4255 .64733 .40916 Mtetra
.736 .61 .718 r
.64733 .40916 .65319 .4255 .66431 .41874 .65827 .39789 Mtetra
.708 .563 .689 r
.65827 .39789 .66431 .41874 .67531 .40891 .66919 .38655 Mtetra
.689 .544 .684 r
.66919 .38655 .67531 .40891 .68624 .39767 .68016 .37626 Mtetra
.663 .534 .697 r
.68016 .37626 .68624 .39767 .69721 .38728 .69126 .36871 Mtetra
.641 .54 .724 r
.69126 .36871 .69721 .38728 .70826 .37836 .70253 .3636 Mtetra
.614 .562 .773 r
.70253 .3636 .70826 .37836 .71947 .37191 .71396 .36076 Mtetra
.581 .602 .838 r
.71396 .36076 .71947 .37191 .73084 .36741 .72554 .35938 Mtetra
.548 .664 .913 r
.72554 .35938 .73084 .36741 .74234 .36438 .73721 .3585 Mtetra
.508 .722 .969 r
.73721 .3585 .74234 .36438 .75396 .36225 .74896 .3577 Mtetra
.5 .774 .993 r
.74896 .3577 .75396 .36225 .76565 .36035 .76074 .35636 Mtetra
.513 .805 .999 r
.76074 .35636 .76565 .36035 .77741 .35845 .77254 .35447 Mtetra
.556 .827 .996 r
.77254 .35447 .77741 .35845 .7892 .3562 .78435 .3519 Mtetra
.596 .831 .989 r
.78435 .3519 .7892 .3562 .80103 .35362 .79618 .34879 Mtetra
.628 .823 .975 r
.79618 .34879 .80103 .35362 .81288 .35065 .80801 .34524 Mtetra
.649 .809 .96 r
.80801 .34524 .81288 .35065 .82475 .3474 .81988 .34138 Mtetra
.66 .791 .944 r
.81988 .34138 .82475 .3474 .83666 .34394 .83177 .33733 Mtetra
.664 .772 .93 r
.83177 .33733 .83666 .34394 .84861 .34035 .8437 .33321 Mtetra
.621 .742 .933 r
.20671 .53168 .21326 .53739 .22278 .53454 .21621 .52931 Mtetra
.615 .76 .948 r
.21621 .52931 .22278 .53454 .23235 .53162 .22574 .52699 Mtetra
.612 .782 .963 r
.22574 .52699 .23235 .53162 .24196 .52853 .23532 .52459 Mtetra
.611 .811 .977 r
.23532 .52459 .24196 .52853 .25164 .52514 .24495 .52201 Mtetra
.61 .844 .988 r
.24495 .52201 .25164 .52514 .26138 .52133 .25464 .51917 Mtetra
.614 .883 .99 r
.25464 .51917 .26138 .52133 .27119 .517 .2644 .51586 Mtetra
.624 .919 .977 r
.2644 .51586 .27119 .517 .28108 .51202 .27425 .51188 Mtetra
.639 .948 .949 r
.27425 .51188 .28108 .51202 .29103 .50651 .28419 .50707 Mtetra
.679 .97 .922 r
.28419 .50707 .29103 .50651 .30103 .50047 .29423 .50121 Mtetra
.73 .982 .91 r
.29423 .50121 .30103 .50047 .31106 .4945 .30436 .49442 Mtetra
.799 .969 .911 r
.30436 .49442 .31106 .4945 .32107 .48901 .31455 .48669 Mtetra
.818 .895 .897 r
.31455 .48669 .32107 .48901 .33102 .48492 .32478 .47869 Mtetra
.779 .766 .841 r
.32478 .47869 .33102 .48492 .34089 .48304 .335 .47091 Mtetra
.698 .625 .771 r
.335 .47091 .34089 .48304 .35067 .48355 .34514 .46467 Mtetra
.621 .517 .715 r
.34514 .46467 .35067 .48355 .36038 .48674 .35518 .46102 Mtetra
.558 .44 .675 r
.35518 .46102 .36038 .48674 .37011 .49098 .36508 .46063 Mtetra
.501 .384 .652 r
.36508 .46063 .37011 .49098 .37993 .49517 .37487 .46409 Mtetra
.466 .358 .647 r
.37487 .46409 .37993 .49517 .3899 .49758 .38464 .46983 Mtetra
.431 .346 .66 r
.38464 .46983 .3899 .49758 .40007 .49694 .39446 .47678 Mtetra
.403 .373 .712 r
.39446 .47678 .40007 .49694 .41038 .49349 .40441 .48278 Mtetra
.364 .485 .849 r
.40441 .48278 .41038 .49349 .42082 .48733 .41454 .48633 Mtetra
.003 .574 .772 r
.41454 .48633 .42082 .48733 .43132 .47975 .42484 .48712 Mtetra
.287 0 0 r
.42484 .48712 .43132 .47975 .44185 .47162 .43528 .48492 Mtetra
.335 0 .165 r
.43528 .48492 .44185 .47162 .45238 .46368 .44582 .48077 Mtetra
.348 .004 .232 r
.44582 .48077 .45238 .46368 .46292 .45649 .45642 .47535 Mtetra
.358 .026 .258 r
.45642 .47535 .46292 .45649 .47345 .4501 .46705 .46952 Mtetra
.37 .04 .27 r
.46705 .46952 .47345 .4501 .48399 .44461 .47771 .46389 Mtetra
.383 .052 .274 r
.47771 .46389 .48399 .44461 .49456 .43986 .48839 .45879 Mtetra
.401 .066 .278 r
.48839 .45879 .49456 .43986 .50515 .43579 .49909 .45448 Mtetra
.42 .082 .283 r
.49909 .45448 .50515 .43579 .51578 .43233 .50983 .45102 Mtetra
.441 .1 .291 r
.50983 .45102 .51578 .43233 .52645 .42949 .52061 .44842 Mtetra
.46 .119 .3 r
.52061 .44842 .52645 .42949 .53716 .42734 .53143 .44661 Mtetra
.472 .132 .308 r
.53143 .44661 .53716 .42734 .54794 .42594 .54232 .44535 Mtetra
.477 .137 .311 r
.54232 .44535 .54794 .42594 .55878 .42545 .55326 .44429 Mtetra
.467 .124 .301 r
.55326 .44429 .55878 .42545 .56969 .42577 .56426 .44282 Mtetra
.428 .077 .266 r
.56426 .44282 .56969 .42577 .58068 .42687 .5753 .44008 Mtetra
.323 0 .162 r
.5753 .44008 .58068 .42687 .59176 .42818 .58635 .43535 Mtetra
0 0 0 r
.58635 .43535 .59176 .42818 .6029 .42894 .59737 .42759 Mtetra
.862 .961 .867 r
.59737 .42759 .6029 .42894 .61407 .42828 .60833 .41702 Mtetra
.802 .695 .747 r
.60833 .41702 .61407 .42828 .62522 .42486 .61921 .40391 Mtetra
.733 .577 .68 r
.61921 .40391 .62522 .42486 .63632 .41857 .63004 .3898 Mtetra
.685 .516 .652 r
.63004 .3898 .63632 .41857 .64733 .40916 .64088 .37689 Mtetra
.655 .487 .644 r
.64088 .37689 .64733 .40916 .65827 .39789 .6518 .36629 Mtetra
.622 .467 .651 r
.6518 .36629 .65827 .39789 .66919 .38655 .66288 .3596 Mtetra
.595 .465 .673 r
.66288 .3596 .66919 .38655 .68016 .37626 .67414 .35626 Mtetra
.564 .483 .722 r
.67414 .35626 .68016 .37626 .69126 .36871 .68559 .35558 Mtetra
.516 .531 .81 r
.68559 .35558 .69126 .36871 .70253 .3636 .69719 .35649 Mtetra
.424 .631 .941 r
.69719 .35649 .70253 .3636 .71396 .36076 .70888 .35764 Mtetra
.225 .677 .951 r
.70888 .35764 .71396 .36076 .72554 .35938 .72064 .35853 Mtetra
.099 .649 .815 r
.72064 .35853 .72554 .35938 .73721 .3585 .73242 .35846 Mtetra
.111 .664 .763 r
.73242 .35846 .73721 .3585 .74896 .3577 .74421 .35744 Mtetra
.246 .76 .832 r
.74421 .35744 .74896 .3577 .76074 .35636 .75599 .35533 Mtetra
.405 .85 .922 r
.75599 .35533 .76074 .35636 .77254 .35447 .76777 .35235 Mtetra
.543 .893 .979 r
.76777 .35235 .77254 .35447 .78435 .3519 .77955 .34868 Mtetra
.623 .888 .988 r
.77955 .34868 .78435 .3519 .79618 .34879 .79133 .34451 Mtetra
.661 .86 .975 r
.79133 .34451 .79618 .34879 .80801 .34524 .80314 .34007 Mtetra
.678 .831 .957 r
.80314 .34007 .80801 .34524 .81988 .34138 .81497 .33543 Mtetra
.684 .804 .939 r
.81497 .33543 .81988 .34138 .83177 .33733 .82684 .33071 Mtetra
.683 .781 .925 r
.82684 .33071 .83177 .33733 .8437 .33321 .83876 .32602 Mtetra
.611 .739 .937 r
.20012 .52592 .20671 .53168 .21621 .52931 .20961 .52374 Mtetra
.603 .744 .944 r
.20961 .52374 .21621 .52931 .22574 .52699 .21914 .52167 Mtetra
.596 .753 .953 r
.21914 .52167 .22574 .52699 .23532 .52459 .2287 .51967 Mtetra
.588 .767 .964 r
.2287 .51967 .23532 .52459 .24495 .52201 .2383 .5177 Mtetra
.575 .787 .979 r
.2383 .5177 .24495 .52201 .25464 .51917 .24794 .51574 Mtetra
.565 .821 .993 r
.24794 .51574 .25464 .51917 .2644 .51586 .25764 .51359 Mtetra
.548 .86 .997 r
.25764 .51359 .2644 .51586 .27425 .51188 .26741 .51108 Mtetra
.526 .897 .966 r
.26741 .51108 .27425 .51188 .28419 .50707 .27726 .50791 Mtetra
.497 .906 .886 r
.27726 .50791 .28419 .50707 .29423 .50121 .28723 .50377 Mtetra
.464 .881 .765 r
.28723 .50377 .29423 .50121 .30436 .49442 .2973 .49842 Mtetra
.477 .867 .674 r
.2973 .49842 .30436 .49442 .31455 .48669 .3075 .49156 Mtetra
.516 .872 .633 r
.3075 .49156 .31455 .48669 .32478 .47869 .3178 .48339 Mtetra
.635 .933 .683 r
.3178 .48339 .32478 .47869 .335 .47091 .32818 .47399 Mtetra
.755 .992 .794 r
.32818 .47399 .335 .47091 .34514 .46467 .33857 .46448 Mtetra
.83 .966 .892 r
.33857 .46448 .34514 .46467 .35518 .46102 .34891 .45572 Mtetra
.764 .798 .88 r
.34891 .45572 .35518 .46102 .36508 .46063 .35916 .4491 Mtetra
.642 .611 .803 r
.35916 .4491 .36508 .46063 .37487 .46409 .36926 .4457 Mtetra
.558 .484 .728 r
.36926 .4457 .37487 .46409 .38464 .46983 .37927 .44532 Mtetra
.505 .411 .683 r
.37927 .44532 .38464 .46983 .39446 .47678 .38922 .44789 Mtetra
.49 .382 .659 r
.38922 .44789 .39446 .47678 .40441 .48278 .39918 .4518 Mtetra
.491 .376 .65 r
.39918 .4518 .40441 .48278 .41454 .48633 .40923 .45595 Mtetra
.503 .387 .654 r
.40923 .45595 .41454 .48633 .42484 .48712 .41938 .45927 Mtetra
.524 .411 .667 r
.41938 .45927 .42484 .48712 .43528 .48492 .42967 .461 Mtetra
.547 .444 .689 r
.42967 .461 .43528 .48492 .44582 .48077 .44006 .46123 Mtetra
.575 .489 .721 r
.44006 .46123 .44582 .48077 .45642 .47535 .45056 .45997 Mtetra
.602 .543 .761 r
.45056 .45997 .45642 .47535 .46705 .46952 .46112 .4577 Mtetra
.627 .606 .809 r
.46112 .4577 .46705 .46952 .47771 .46389 .47175 .45474 Mtetra
.645 .669 .858 r
.47175 .45474 .47771 .46389 .48839 .45879 .48243 .45143 Mtetra
.653 .721 .898 r
.48243 .45143 .48839 .45879 .49909 .45448 .49315 .44799 Mtetra
.654 .75 .92 r
.49315 .44799 .49909 .45448 .50983 .45102 .50391 .4445 Mtetra
.655 .75 .92 r
.50391 .4445 .50983 .45102 .52061 .44842 .51472 .44098 Mtetra
.659 .723 .896 r
.51472 .44098 .52061 .44842 .53143 .44661 .52557 .43732 Mtetra
.664 .676 .852 r
.52557 .43732 .53143 .44661 .54232 .44535 .53646 .43331 Mtetra
.666 .625 .798 r
.53646 .43331 .54232 .44535 .55326 .44429 .54738 .4286 Mtetra
.665 .578 .747 r
.54738 .4286 .55326 .44429 .56426 .44282 .55833 .42287 Mtetra
.666 .544 .706 r
.55833 .42287 .56426 .44282 .5753 .44008 .56929 .41562 Mtetra
.664 .519 .677 r
.56929 .41562 .5753 .44008 .58635 .43535 .58024 .40683 Mtetra
.665 .504 .657 r
.58024 .40683 .58635 .43535 .59737 .42759 .59116 .39641 Mtetra
.663 .495 .647 r
.59116 .39641 .59737 .42759 .60833 .41702 .60206 .38514 Mtetra
.659 .491 .645 r
.60206 .38514 .60833 .41702 .61921 .40391 .61296 .37407 Mtetra
.654 .493 .653 r
.61296 .37407 .61921 .40391 .63004 .3898 .62389 .36434 Mtetra
.638 .498 .675 r
.62389 .36434 .63004 .3898 .64088 .37689 .63493 .35761 Mtetra
.616 .519 .722 r
.63493 .35761 .64088 .37689 .6518 .36629 .64611 .35395 Mtetra
.551 .563 .82 r
.64611 .35395 .6518 .36629 .66288 .3596 .65747 .35359 Mtetra
.33 .621 .956 r
.65747 .35359 .66288 .3596 .67414 .35626 .66901 .35545 Mtetra
.189 0 0 r
.66901 .35545 .67414 .35626 .68559 .35558 .68066 .35809 Mtetra
.397 0 0 r
.68066 .35809 .68559 .35558 .69719 .35649 .69241 .36064 Mtetra
.382 0 0 r
.69241 .36064 .69719 .35649 .70888 .35764 .70418 .36193 Mtetra
.309 0 0 r
.70418 .36193 .70888 .35764 .72064 .35853 .71595 .36189 Mtetra
.149 0 0 r
.71595 .36189 .72064 .35853 .73242 .35846 .7277 .3603 Mtetra
0 0 0 r
.7277 .3603 .73242 .35846 .74421 .35744 .73943 .35745 Mtetra
.386 .848 .85 r
.73943 .35745 .74421 .35744 .75599 .35533 .75115 .3536 Mtetra
.583 .921 .965 r
.75115 .3536 .75599 .35533 .76777 .35235 .76286 .34905 Mtetra
.666 .899 .979 r
.76286 .34905 .76777 .35235 .77955 .34868 .77459 .34413 Mtetra
.695 .86 .961 r
.77459 .34413 .77955 .34868 .79133 .34451 .78634 .33899 Mtetra
.699 .825 .943 r
.78634 .33899 .79133 .34451 .80314 .34007 .79813 .33386 Mtetra
.698 .801 .929 r
.79813 .33386 .80314 .34007 .81497 .33543 .80996 .32875 Mtetra
.695 .784 .92 r
.80996 .32875 .81497 .33543 .82684 .33071 .82185 .3237 Mtetra
.69 .772 .914 r
.82185 .3237 .82684 .33071 .83876 .32602 .83378 .31877 Mtetra
.621 .742 .933 r
.19348 .52013 .20012 .52592 .20961 .52374 .20301 .51774 Mtetra
.614 .734 .931 r
.20301 .51774 .20961 .52374 .21914 .52167 .21257 .5155 Mtetra
.605 .725 .93 r
.21257 .5155 .21914 .52167 .2287 .51967 .22215 .51345 Mtetra
.592 .72 .933 r
.22215 .51345 .2287 .51967 .2383 .5177 .23175 .51163 Mtetra
.572 .72 .942 r
.23175 .51163 .2383 .5177 .24794 .51574 .24137 .51014 Mtetra
.553 .731 .958 r
.24137 .51014 .24794 .51574 .25764 .51359 .25101 .50885 Mtetra
.521 .754 .981 r
.25101 .50885 .25764 .51359 .26741 .51108 .26069 .50772 Mtetra
.48 .795 .999 r
.26069 .50772 .26741 .51108 .27726 .50791 .27043 .50646 Mtetra
.39 .82 .962 r
.27043 .50646 .27726 .50791 .28723 .50377 .28025 .50485 Mtetra
.231 .749 .766 r
.28025 .50485 .28723 .50377 .2973 .49842 .29016 .50249 Mtetra
0 0 0 r
.29016 .50249 .2973 .49842 .3075 .49156 .30019 .49904 Mtetra
.064 0 0 r
.30019 .49904 .3075 .49156 .3178 .48339 .31034 .49419 Mtetra
.109 0 0 r
.31034 .49419 .3178 .48339 .32818 .47399 .32063 .48763 Mtetra
.115 0 .045 r
.32063 .48763 .32818 .47399 .33857 .46448 .33104 .47926 Mtetra
.052 0 .037 r
.33104 .47926 .33857 .46448 .34891 .45572 .34157 .46897 Mtetra
0 0 0 r
.34157 .46897 .34891 .45572 .35916 .4491 .35217 .45732 Mtetra
.541 .815 .459 r
.35217 .45732 .35916 .4491 .36926 .4457 .36279 .44479 Mtetra
.891 .925 .837 r
.36279 .44479 .36926 .4457 .37927 .44532 .37336 .43303 Mtetra
.749 .648 .749 r
.37336 .43303 .37927 .44532 .38922 .44789 .38384 .42322 Mtetra
.644 .502 .674 r
.38384 .42322 .38922 .44789 .39918 .4518 .39419 .41637 Mtetra
.583 .428 .636 r
.39419 .41637 .39918 .4518 .40923 .45595 .40443 .41312 Mtetra
.551 .391 .618 r
.40443 .41312 .40923 .45595 .41938 .45927 .41461 .41264 Mtetra
.531 .371 .61 r
.41461 .41264 .41938 .45927 .42967 .461 .42478 .41435 Mtetra
.523 .366 .609 r
.42478 .41435 .42967 .461 .44006 .46123 .435 .41691 Mtetra
.523 .37 .614 r
.435 .41691 .44006 .46123 .45056 .45997 .4453 .4194 Mtetra
.529 .38 .623 r
.4453 .4194 .45056 .45997 .46112 .4577 .4557 .42118 Mtetra
.542 .398 .635 r
.4557 .42118 .46112 .4577 .47175 .45474 .46619 .42174 Mtetra
.557 .417 .647 r
.46619 .42174 .47175 .45474 .48243 .45143 .47677 .42101 Mtetra
.576 .438 .656 r
.47677 .42101 .48243 .45143 .49315 .44799 .48742 .41886 Mtetra
.594 .454 .661 r
.48742 .41886 .49315 .44799 .50391 .4445 .49814 .41533 Mtetra
.609 .465 .66 r
.49814 .41533 .50391 .4445 .51472 .44098 .5089 .41042 Mtetra
.621 .468 .653 r
.5089 .41042 .51472 .44098 .52557 .43732 .5197 .40408 Mtetra
.627 .465 .643 r
.5197 .40408 .52557 .43732 .53646 .43331 .53053 .39643 Mtetra
.63 .459 .633 r
.53053 .39643 .53646 .43331 .54738 .4286 .54136 .38754 Mtetra
.627 .449 .623 r
.54136 .38754 .54738 .4286 .55833 .42287 .55219 .3779 Mtetra
.621 .439 .615 r
.55219 .3779 .55833 .42287 .56929 .41562 .56302 .36818 Mtetra
.611 .429 .611 r
.56302 .36818 .56929 .41562 .58024 .40683 .57387 .3593 Mtetra
.596 .418 .611 r
.57387 .3593 .58024 .40683 .59116 .39641 .58476 .35262 Mtetra
.579 .412 .619 r
.58476 .35262 .59116 .39641 .60206 .38514 .59574 .34875 Mtetra
.55 .405 .637 r
.59574 .34875 .60206 .38514 .61296 .37407 .60686 .34854 Mtetra
.505 .411 .683 r
.60686 .34854 .61296 .37407 .62389 .36434 .61814 .35135 Mtetra
.364 .444 .81 r
.61814 .35135 .62389 .36434 .63493 .35761 .62957 .35618 Mtetra
.404 0 0 r
.62957 .35618 .63493 .35761 .64611 .35395 .64114 .36182 Mtetra
.57 .113 .129 r
.64114 .36182 .64611 .35395 .65747 .35359 .65279 .3666 Mtetra
.545 .148 .24 r
.65279 .3666 .65747 .35359 .66901 .35545 .66448 .37001 Mtetra
.507 .125 .251 r
.66448 .37001 .66901 .35545 .68066 .35809 .67618 .37147 Mtetra
.457 .068 .212 r
.67618 .37147 .68066 .35809 .69241 .36064 .68788 .37107 Mtetra
.37 0 .109 r
.68788 .37107 .69241 .36064 .70418 .36193 .69955 .36892 Mtetra
.209 0 0 r
.69955 .36892 .70418 .36193 .71595 .36189 .71119 .36533 Mtetra
0 0 0 r
.71119 .36533 .71595 .36189 .7277 .3603 .72282 .3606 Mtetra
.507 .912 .851 r
.72282 .3606 .7277 .3603 .73943 .35745 .73444 .35508 Mtetra
.691 .938 .964 r
.73444 .35508 .73943 .35745 .75115 .3536 .74606 .34919 Mtetra
.729 .875 .949 r
.74606 .34919 .75115 .3536 .76286 .34905 .75771 .34316 Mtetra
.725 .819 .924 r
.75771 .34316 .76286 .34905 .77459 .34413 .76941 .33728 Mtetra
.715 .784 .907 r
.76941 .33728 .77459 .34413 .78634 .33899 .78116 .33161 Mtetra
.703 .764 .9 r
.78116 .33161 .78634 .33899 .79813 .33386 .79297 .32626 Mtetra
.694 .755 .898 r
.79297 .32626 .79813 .33386 .80996 .32875 .80484 .32115 Mtetra
.688 .753 .901 r
.80484 .32115 .80996 .32875 .82185 .3237 .81677 .31623 Mtetra
.683 .756 .907 r
.81677 .31623 .82185 .3237 .83378 .31877 .82876 .31146 Mtetra
.65 .75 .923 r
.18679 .51429 .19348 .52013 .20301 .51774 .1964 .51126 Mtetra
.645 .728 .909 r
.1964 .51126 .20301 .51774 .21257 .5155 .20604 .50834 Mtetra
.636 .705 .896 r
.20604 .50834 .21257 .5155 .22215 .51345 .2157 .50563 Mtetra
.623 .682 .885 r
.2157 .50563 .22215 .51345 .23175 .51163 .22536 .50325 Mtetra
.605 .66 .877 r
.22536 .50325 .23175 .51163 .24137 .51014 .23503 .50131 Mtetra
.587 .642 .872 r
.23503 .50131 .24137 .51014 .25101 .50885 .2447 .49983 Mtetra
.563 .628 .874 r
.2447 .49983 .25101 .50885 .26069 .50772 .25437 .49891 Mtetra
.544 .625 .883 r
.25437 .49891 .26069 .50772 .27043 .50646 .26406 .49839 Mtetra
.519 .636 .905 r
.26406 .49839 .27043 .50646 .28025 .50485 .27377 .4982 Mtetra
.496 .674 .944 r
.27377 .4982 .28025 .50485 .29016 .50249 .28354 .498 Mtetra
.451 .74 .99 r
.28354 .498 .29016 .50249 .30019 .49904 .29339 .49753 Mtetra
.343 .794 .95 r
.29339 .49753 .30019 .49904 .31034 .49419 .30334 .49627 Mtetra
0 0 0 r
.30334 .49627 .31034 .49419 .32063 .48763 .31343 .49378 Mtetra
.026 0 0 r
.31343 .49378 .32063 .48763 .33104 .47926 .32366 .48946 Mtetra
.074 0 0 r
.32366 .48946 .33104 .47926 .34157 .46897 .33407 .4828 Mtetra
.086 0 .032 r
.33407 .4828 .34157 .46897 .35217 .45732 .34462 .47379 Mtetra
.063 0 .072 r
.34462 .47379 .35217 .45732 .36279 .44479 .35529 .46247 Mtetra
.063 0 .092 r
.35529 .46247 .36279 .44479 .37336 .43303 .366 .45021 Mtetra
.052 0 .081 r
.366 .45021 .37336 .43303 .38384 .42322 .37669 .43799 Mtetra
.034 0 .033 r
.37669 .43799 .38384 .42322 .39419 .41637 .38731 .42712 Mtetra
0 0 0 r
.38731 .42712 .39419 .41637 .40443 .41312 .39784 .41853 Mtetra
.39784 .41853 .40443 .41312 .41461 .41264 .40829 .41211 Mtetra
.573 .927 .949 r
.40829 .41211 .41461 .41264 .42478 .41435 .41869 .40784 Mtetra
.635 .738 .923 r
.41869 .40784 .42478 .41435 .435 .41691 .42909 .40493 Mtetra
.603 .59 .811 r
.42909 .40493 .435 .41691 .4453 .4194 .4395 .40284 Mtetra
.589 .523 .748 r
.4395 .40284 .4453 .4194 .4557 .42118 .44996 .401 Mtetra
.586 .491 .714 r
.44996 .401 .4557 .42118 .46619 .42174 .46048 .39897 Mtetra
.588 .477 .694 r
.46048 .39897 .46619 .42174 .47677 .42101 .47105 .39656 Mtetra
.594 .472 .684 r
.47105 .39656 .47677 .42101 .48742 .41886 .48168 .39359 Mtetra
.6 .473 .679 r
.48168 .39359 .48742 .41886 .49814 .41533 .49237 .39002 Mtetra
.608 .478 .678 r
.49237 .39002 .49814 .41533 .5089 .41042 .50309 .38585 Mtetra
.617 .487 .681 r
.50309 .38585 .5089 .41042 .5197 .40408 .51386 .38111 Mtetra
.626 .501 .69 r
.51386 .38111 .5197 .40408 .53053 .39643 .52466 .37598 Mtetra
.637 .522 .706 r
.52466 .37598 .53053 .39643 .54136 .38754 .5355 .37067 Mtetra
.648 .556 .737 r
.5355 .37067 .54136 .38754 .55219 .3779 .54636 .36559 Mtetra
.654 .615 .798 r
.54636 .36559 .55219 .3779 .56302 .36818 .55727 .36134 Mtetra
.627 .734 .924 r
.55727 .36134 .56302 .36818 .57387 .3593 .56824 .35846 Mtetra
.173 .703 .849 r
.56824 .35846 .57387 .3593 .58476 .35262 .57929 .35776 Mtetra
.427 0 0 r
.57929 .35776 .58476 .35262 .59574 .34875 .59045 .35929 Mtetra
.554 .133 .198 r
.59045 .35929 .59574 .34875 .60686 .34854 .60176 .36314 Mtetra
.582 .199 .281 r
.60176 .36314 .60686 .34854 .61814 .35135 .61319 .3684 Mtetra
.58 .213 .309 r
.61319 .3684 .61814 .35135 .62957 .35618 .62474 .37374 Mtetra
.564 .2 .308 r
.62474 .37374 .62957 .35618 .64114 .36182 .63637 .37815 Mtetra
.522 .152 .279 r
.63637 .37815 .64114 .36182 .65279 .3666 .64802 .3802 Mtetra
.458 .069 .213 r
.64802 .3802 .65279 .3666 .66448 .37001 .65965 .37987 Mtetra
.332 0 .071 r
.65965 .37987 .66448 .37001 .67618 .37147 .67125 .37714 Mtetra
.062 0 0 r
.67125 .37714 .67618 .37147 .68788 .37107 .68281 .37251 Mtetra
.441 .869 .758 r
.68281 .37251 .68788 .37107 .69955 .36892 .69434 .36661 Mtetra
.733 .947 .95 r
.69434 .36661 .69955 .36892 .71119 .36533 .70586 .35989 Mtetra
.762 .841 .912 r
.70586 .35989 .71119 .36533 .72282 .3606 .71739 .35287 Mtetra
.747 .765 .868 r
.71739 .35287 .72282 .3606 .73444 .35508 .72894 .34582 Mtetra
.726 .719 .844 r
.72894 .34582 .73444 .35508 .74606 .34919 .74055 .33911 Mtetra
.71 .695 .834 r
.74055 .33911 .74606 .34919 .75771 .34316 .7522 .3328 Mtetra
.695 .683 .835 r
.7522 .3328 .75771 .34316 .76941 .33728 .76394 .32706 Mtetra
.684 .682 .842 r
.76394 .32706 .76941 .33728 .78116 .33161 .77574 .32179 Mtetra
.675 .688 .854 r
.77574 .32179 .78116 .33161 .79297 .32626 .78763 .31698 Mtetra
.668 .699 .869 r
.78763 .31698 .79297 .32626 .80484 .32115 .79959 .31251 Mtetra
.663 .714 .886 r
.79959 .31251 .80484 .32115 .81677 .31623 .81162 .30825 Mtetra
.661 .733 .903 r
.81162 .30825 .81677 .31623 .82876 .31146 .82371 .3041 Mtetra
.683 .757 .908 r
.18006 .50842 .18679 .51429 .1964 .51126 .18978 .50452 Mtetra
.679 .73 .888 r
.18978 .50452 .1964 .51126 .20604 .50834 .19953 .50064 Mtetra
.67 .701 .87 r
.19953 .50064 .20604 .50834 .2157 .50563 .20929 .49691 Mtetra
.657 .671 .852 r
.20929 .49691 .2157 .50563 .22536 .50325 .21906 .49344 Mtetra
.641 .641 .835 r
.21906 .49344 .22536 .50325 .23503 .50131 .22884 .49035 Mtetra
.622 .611 .819 r
.22884 .49035 .23503 .50131 .2447 .49983 .2386 .48779 Mtetra
.599 .582 .805 r
.2386 .48779 .2447 .49983 .25437 .49891 .24835 .48593 Mtetra
.576 .555 .795 r
.24835 .48593 .25437 .49891 .26406 .49839 .25808 .4848 Mtetra
.549 .533 .789 r
.25808 .4848 .26406 .49839 .27377 .4982 .2678 .48454 Mtetra
.527 .52 .791 r
.2678 .48454 .27377 .4982 .28354 .498 .27751 .48495 Mtetra
.503 .517 .804 r
.27751 .48495 .28354 .498 .29339 .49753 .28725 .48596 Mtetra
.484 .535 .833 r
.28725 .48596 .29339 .49753 .30334 .49627 .29703 .48716 Mtetra
.46 .582 .889 r
.29703 .48716 .30334 .49627 .31343 .49378 .30689 .48822 Mtetra
.394 .673 .972 r
.30689 .48822 .31343 .49378 .32366 .48946 .31685 .48882 Mtetra
.093 .647 .802 r
.31685 .48882 .32366 .48946 .33407 .4828 .32691 .48866 Mtetra
.298 0 0 r
.32691 .48866 .33407 .4828 .34462 .47379 .33708 .48766 Mtetra
.405 .023 .197 r
.33708 .48766 .34462 .47379 .35529 .46247 .34735 .48563 Mtetra
.431 .107 .314 r
.34735 .48563 .35529 .46247 .366 .45021 .35776 .48206 Mtetra
.433 .138 .363 r
.35776 .48206 .366 .45021 .37669 .43799 .36829 .47657 Mtetra
.423 .144 .383 r
.36829 .47657 .37669 .43799 .38731 .42712 .37895 .46883 Mtetra
.404 .133 .385 r
.37895 .46883 .38731 .42712 .39784 .41853 .38972 .45877 Mtetra
.379 .109 .374 r
.38972 .45877 .39784 .41853 .40829 .41211 .40054 .44726 Mtetra
.339 .066 .344 r
.40054 .44726 .40829 .41211 .41869 .40784 .41138 .43497 Mtetra
.275 0 .282 r
.41138 .43497 .41869 .40784 .42909 .40493 .42219 .42298 Mtetra
.15 0 .145 r
.42219 .42298 .42909 .40493 .4395 .40284 .43296 .412 Mtetra
0 0 0 r
.43296 .412 .4395 .40284 .44996 .401 .44369 .40238 Mtetra
.714 .987 .852 r
.44369 .40238 .44996 .401 .46048 .39897 .45439 .39438 Mtetra
.762 .84 .912 r
.45439 .39438 .46048 .39897 .47105 .39656 .46507 .38787 Mtetra
.694 .701 .852 r
.46507 .38787 .47105 .39656 .48168 .39359 .47575 .38287 Mtetra
.646 .637 .827 r
.47575 .38287 .48168 .39359 .49237 .39002 .48644 .37927 Mtetra
.605 .618 .838 r
.48644 .37927 .49237 .39002 .50309 .38585 .49717 .37708 Mtetra
.544 .637 .894 r
.49717 .37708 .50309 .38585 .51386 .38111 .50794 .37639 Mtetra
.331 .678 .978 r
.50794 .37639 .51386 .38111 .52466 .37598 .51876 .37724 Mtetra
.353 0 0 r
.51876 .37724 .52466 .37598 .5355 .37067 .52967 .37971 Mtetra
.553 .115 .163 r
.52967 .37971 .5355 .37067 .54636 .36559 .54066 .38359 Mtetra
.574 .214 .32 r
.54066 .38359 .54636 .36559 .55727 .36134 .55176 .38851 Mtetra
.569 .246 .382 r
.55176 .38851 .55727 .36134 .56824 .35846 .56297 .39376 Mtetra
.556 .254 .41 r
.56297 .39376 .56824 .35846 .57929 .35776 .57428 .39826 Mtetra
.542 .25 .421 r
.57428 .39826 .57929 .35776 .59045 .35929 .58566 .40131 Mtetra
.522 .235 .42 r
.58566 .40131 .59045 .35929 .60176 .36314 .59708 .40201 Mtetra
.499 .21 .406 r
.59708 .40201 .60176 .36314 .61319 .3684 .60852 .40044 Mtetra
.467 .169 .375 r
.60852 .40044 .61319 .3684 .62474 .37374 .61996 .39691 Mtetra
.409 .089 .308 r
.61996 .39691 .62474 .37374 .63637 .37815 .6314 .3918 Mtetra
.273 0 .139 r
.6314 .3918 .63637 .37815 .64802 .3802 .64284 .38563 Mtetra
0 0 0 r
.64284 .38563 .64802 .3802 .65965 .37987 .65428 .37858 Mtetra
.759 .975 .92 r
.65428 .37858 .65965 .37987 .67125 .37714 .6657 .37073 Mtetra
.788 .812 .872 r
.6657 .37073 .67125 .37714 .68281 .37251 .67712 .36239 Mtetra
.753 .709 .81 r
.67712 .36239 .68281 .37251 .69434 .36661 .68854 .3539 Mtetra
.726 .654 .777 r
.68854 .3539 .69434 .36661 .70586 .35989 .69999 .34557 Mtetra
.704 .622 .762 r
.69999 .34557 .70586 .35989 .71739 .35287 .7115 .33785 Mtetra
.688 .606 .759 r
.7115 .33785 .71739 .35287 .72894 .34582 .72306 .33083 Mtetra
.673 .598 .764 r
.72306 .33083 .72894 .34582 .74055 .33911 .73471 .32467 Mtetra
.662 .6 .775 r
.73471 .32467 .74055 .33911 .7522 .3328 .74644 .31928 Mtetra
.653 .608 .792 r
.74644 .31928 .7522 .3328 .76394 .32706 .75827 .31461 Mtetra
.645 .622 .812 r
.75827 .31461 .76394 .32706 .77574 .32179 .77019 .31048 Mtetra
.64 .64 .835 r
.77019 .31048 .77574 .32179 .78763 .31698 .78219 .30674 Mtetra
.635 .661 .858 r
.78219 .30674 .78763 .31698 .79959 .31251 .79426 .30329 Mtetra
.632 .686 .882 r
.79426 .30329 .79959 .31251 .81162 .30825 .80641 .29998 Mtetra
.631 .713 .906 r
.80641 .29998 .81162 .30825 .82371 .3041 .81861 .29669 Mtetra
.705 .761 .896 r
.17328 .5025 .18006 .50842 .18978 .50452 .18309 .49795 Mtetra
.703 .742 .881 r
.18309 .49795 .18978 .50452 .19953 .50064 .19293 .49333 Mtetra
.698 .72 .866 r
.19293 .49333 .19953 .50064 .20929 .49691 .20279 .48871 Mtetra
.69 .696 .851 r
.20279 .48871 .20929 .49691 .21906 .49344 .21268 .48419 Mtetra
.679 .669 .833 r
.21268 .48419 .21906 .49344 .22884 .49035 .22258 .47983 Mtetra
.663 .637 .814 r
.22258 .47983 .22884 .49035 .2386 .48779 .23248 .4758 Mtetra
.643 .604 .795 r
.23248 .4758 .2386 .48779 .24835 .48593 .24237 .47225 Mtetra
.621 .569 .775 r
.24237 .47225 .24835 .48593 .25808 .4848 .25224 .46937 Mtetra
.596 .535 .757 r
.25224 .46937 .25808 .4848 .2678 .48454 .26209 .46733 Mtetra
.572 .504 .74 r
.26209 .46733 .2678 .48454 .27751 .48495 .27191 .46617 Mtetra
.549 .477 .726 r
.27191 .46617 .27751 .48495 .28725 .48596 .2817 .46601 Mtetra
.53 .456 .717 r
.2817 .46601 .28725 .48596 .29703 .48716 .2915 .46668 Mtetra
.513 .442 .713 r
.2915 .46668 .29703 .48716 .30689 .48822 .3013 .46812 Mtetra
.498 .435 .717 r
.3013 .46812 .30689 .48822 .31685 .48882 .31113 .47017 Mtetra
.48 .437 .732 r
.31113 .47017 .31685 .48882 .32691 .48866 .321 .4727 Mtetra
.461 .455 .765 r
.321 .4727 .32691 .48866 .33708 .48766 .33094 .47536 Mtetra
.434 .497 .825 r
.33094 .47536 .33708 .48766 .34735 .48563 .34097 .47781 Mtetra
.415 .604 .925 r
.34097 .47781 .34735 .48563 .35776 .48206 .35114 .47909 Mtetra
.362 .763 .984 r
.35114 .47909 .35776 .48206 .36829 .47657 .36147 .47852 Mtetra
0 0 0 r
.36147 .47852 .36829 .47657 .37895 .46883 .37196 .47561 Mtetra
.37196 .47561 .37895 .46883 .38972 .45877 .38261 .47014 Mtetra
.099 0 0 r
.38261 .47014 .38972 .45877 .40054 .44726 .39336 .46288 Mtetra
.182 0 .113 r
.39336 .46288 .40054 .44726 .41138 .43497 .40417 .4544 Mtetra
.255 0 .203 r
.40417 .4544 .41138 .43497 .42219 .42298 .415 .44566 Mtetra
.314 0 .261 r
.415 .44566 .42219 .42298 .43296 .412 .42583 .43729 Mtetra
.358 .05 .299 r
.42583 .43729 .43296 .412 .44369 .40238 .43665 .42965 Mtetra
.393 .089 .326 r
.43665 .42965 .44369 .40238 .45439 .39438 .44745 .42302 Mtetra
.419 .116 .343 r
.44745 .42302 .45439 .39438 .46507 .38787 .45826 .41738 Mtetra
.439 .137 .354 r
.45826 .41738 .46507 .38787 .47575 .38287 .46909 .41279 Mtetra
.456 .153 .362 r
.46909 .41279 .47575 .38287 .48644 .37927 .47993 .40919 Mtetra
.471 .166 .366 r
.47993 .40919 .48644 .37927 .49717 .37708 .4908 .4066 Mtetra
.485 .177 .369 r
.4908 .4066 .49717 .37708 .50794 .37639 .50172 .40506 Mtetra
.497 .186 .368 r
.50172 .40506 .50794 .37639 .51876 .37724 .5127 .40452 Mtetra
.51 .192 .364 r
.5127 .40452 .51876 .37724 .52967 .37971 .52373 .40501 Mtetra
.518 .193 .355 r
.52373 .40501 .52967 .37971 .54066 .38359 .53485 .40626 Mtetra
.521 .185 .338 r
.53485 .40626 .54066 .38359 .55176 .38851 .54604 .4079 Mtetra
.513 .161 .307 r
.54604 .4079 .55176 .38851 .56297 .39376 .55731 .40928 Mtetra
.477 .101 .247 r
.55731 .40928 .56297 .39376 .57428 .39826 .56865 .40945 Mtetra
.388 0 .125 r
.56865 .40945 .57428 .39826 .58566 .40131 .58004 .40782 Mtetra
.114 0 0 r
.58004 .40782 .58566 .40131 .59708 .40201 .59143 .40357 Mtetra
.527 .915 .79 r
.59143 .40357 .59708 .40201 .60852 .40044 .6028 .39694 Mtetra
.81 .907 .907 r
.6028 .39694 .60852 .40044 .61996 .39691 .61415 .38839 Mtetra
.791 .752 .818 r
.61415 .38839 .61996 .39691 .6314 .3918 .62547 .37864 Mtetra
.747 .655 .759 r
.62547 .37864 .6314 .3918 .64284 .38563 .63679 .36864 Mtetra
.715 .599 .725 r
.63679 .36864 .64284 .38563 .65428 .37858 .64812 .35877 Mtetra
.692 .564 .706 r
.64812 .35877 .65428 .37858 .6657 .37073 .65947 .34935 Mtetra
.676 .545 .698 r
.65947 .34935 .6657 .37073 .67712 .36239 .67086 .34055 Mtetra
.665 .535 .697 r
.67086 .34055 .67712 .36239 .68854 .3539 .68229 .33251 Mtetra
.656 .533 .702 r
.68229 .33251 .68854 .3539 .69999 .34557 .69379 .32534 Mtetra
.647 .536 .714 r
.69379 .32534 .69999 .34557 .7115 .33785 .70538 .31917 Mtetra
.64 .543 .729 r
.70538 .31917 .7115 .33785 .72306 .33083 .71705 .31391 Mtetra
.632 .555 .75 r
.71705 .31391 .72306 .33083 .73471 .32467 .72881 .30952 Mtetra
.625 .572 .774 r
.72881 .30952 .73471 .32467 .74644 .31928 .74067 .30581 Mtetra
.62 .592 .801 r
.74067 .30581 .74644 .31928 .75827 .31461 .75262 .3026 Mtetra
.614 .615 .828 r
.75262 .3026 .75827 .31461 .77019 .31048 .76465 .29974 Mtetra
.611 .639 .854 r
.76465 .29974 .77019 .31048 .78219 .30674 .77676 .29705 Mtetra
.608 .663 .878 r
.77676 .29705 .78219 .30674 .79426 .30329 .78893 .29445 Mtetra
.606 .686 .899 r
.78893 .29445 .79426 .30329 .80641 .29998 .80118 .29187 Mtetra
.606 .708 .916 r
.80118 .29187 .80641 .29998 .81861 .29669 .81347 .28921 Mtetra
.712 .763 .892 r
.16646 .49655 .17328 .5025 .18309 .49795 .17631 .49174 Mtetra
.714 .756 .885 r
.17631 .49174 .18309 .49795 .19293 .49333 .18621 .48678 Mtetra
.716 .747 .876 r
.18621 .48678 .19293 .49333 .20279 .48871 .19614 .48169 Mtetra
.716 .734 .865 r
.19614 .48169 .20279 .48871 .21268 .48419 .20611 .47647 Mtetra
.714 .716 .85 r
.20611 .47647 .21268 .48419 .22258 .47983 .21612 .47111 Mtetra
.707 .691 .833 r
.21612 .47111 .22258 .47983 .23248 .4758 .22616 .46574 Mtetra
.695 .66 .811 r
.22616 .46574 .23248 .4758 .24237 .47225 .23622 .46042 Mtetra
.677 .623 .788 r
.23622 .46042 .24237 .47225 .25224 .46937 .24627 .45538 Mtetra
.656 .584 .763 r
.24627 .45538 .25224 .46937 .26209 .46733 .25632 .45077 Mtetra
.631 .544 .738 r
.25632 .45077 .26209 .46733 .27191 .46617 .26635 .44681 Mtetra
.606 .507 .715 r
.26635 .44681 .27191 .46617 .2817 .46601 .27634 .44374 Mtetra
.582 .473 .695 r
.27634 .44374 .2817 .46601 .2915 .46668 .2863 .4417 Mtetra
.558 .444 .679 r
.2863 .4417 .2915 .46668 .3013 .46812 .29621 .44088 Mtetra
.54 .422 .667 r
.29621 .44088 .3013 .46812 .31113 .47017 .30611 .44111 Mtetra
.525 .405 .659 r
.30611 .44111 .31113 .47017 .321 .4727 .31601 .44232 Mtetra
.521 .398 .653 r
.31601 .44232 .321 .4727 .33094 .47536 .32595 .4439 Mtetra
.522 .396 .649 r
.32595 .4439 .33094 .47536 .34097 .47781 .33597 .4454 Mtetra
.526 .396 .646 r
.33597 .4454 .34097 .47781 .35114 .47909 .34607 .44668 Mtetra
.531 .399 .646 r
.34607 .44668 .35114 .47909 .36147 .47852 .35626 .44761 Mtetra
.527 .402 .653 r
.35626 .44761 .36147 .47852 .37196 .47561 .3665 .44876 Mtetra
.517 .411 .673 r
.3665 .44876 .37196 .47561 .38261 .47014 .37679 .45041 Mtetra
.494 .44 .725 r
.37679 .45041 .38261 .47014 .39336 .46288 .38714 .45254 Mtetra
.396 .523 .868 r
.38714 .45254 .39336 .46288 .40417 .4544 .39754 .45506 Mtetra
.318 0 0 r
.39754 .45506 .40417 .4544 .415 .44566 .40804 .45738 Mtetra
.502 .094 .198 r
.40804 .45738 .415 .44566 .42583 .43729 .41863 .45911 Mtetra
.506 .167 .327 r
.41863 .45911 .42583 .43729 .43665 .42965 .42933 .45991 Mtetra
.5 .191 .374 r
.42933 .45991 .43665 .42965 .44745 .42302 .44013 .45959 Mtetra
.494 .2 .395 r
.44013 .45959 .44745 .42302 .45826 .41738 .45102 .45817 Mtetra
.487 .201 .404 r
.45102 .45817 .45826 .41738 .46909 .41279 .46199 .45564 Mtetra
.479 .197 .407 r
.46199 .45564 .46909 .41279 .47993 .40919 .47302 .45206 Mtetra
.469 .188 .404 r
.47302 .45206 .47993 .40919 .4908 .4066 .48412 .44743 Mtetra
.453 .171 .395 r
.48412 .44743 .4908 .4066 .50172 .40506 .49526 .44169 Mtetra
.429 .143 .375 r
.49526 .44169 .50172 .40506 .5127 .40452 .50644 .43483 Mtetra
.387 .091 .337 r
.50644 .43483 .5127 .40452 .52373 .40501 .51764 .42683 Mtetra
.297 0 .248 r
.51764 .42683 .52373 .40501 .53485 .40626 .52886 .41787 Mtetra
.019 0 0 r
.52886 .41787 .53485 .40626 .54604 .4079 .54009 .4083 Mtetra
.802 .997 .86 r
.54009 .4083 .54604 .4079 .55731 .40928 .55132 .39849 Mtetra
.761 .694 .788 r
.55132 .39849 .55731 .40928 .56865 .40945 .56255 .38906 Mtetra
.684 .555 .702 r
.56255 .38906 .56865 .40945 .58004 .40782 .5738 .38011 Mtetra
.648 .497 .665 r
.5738 .38011 .58004 .40782 .59143 .40357 .58507 .37163 Mtetra
.633 .474 .649 r
.58507 .37163 .59143 .40357 .6028 .39694 .59636 .36337 Mtetra
.632 .469 .643 r
.59636 .36337 .6028 .39694 .61415 .38839 .60765 .35473 Mtetra
.634 .469 .642 r
.60765 .35473 .61415 .38839 .62547 .37864 .61894 .34585 Mtetra
.637 .474 .645 r
.61894 .34585 .62547 .37864 .63679 .36864 .63025 .33688 Mtetra
.636 .476 .649 r
.63025 .33688 .63679 .36864 .64812 .35877 .64157 .32826 Mtetra
.63 .476 .654 r
.64157 .32826 .64812 .35877 .65947 .34935 .65295 .32062 Mtetra
.624 .478 .663 r
.65295 .32062 .65947 .34935 .67086 .34055 .6644 .31406 Mtetra
.615 .481 .675 r
.6644 .31406 .67086 .34055 .68229 .33251 .67594 .30875 Mtetra
.608 .49 .693 r
.67594 .30875 .68229 .33251 .69379 .32534 .68757 .30449 Mtetra
.602 .504 .716 r
.68757 .30449 .69379 .32534 .70538 .31917 .69929 .30114 Mtetra
.597 .524 .744 r
.69929 .30114 .70538 .31917 .71705 .31391 .71111 .29848 Mtetra
.592 .55 .776 r
.71111 .29848 .71705 .31391 .72881 .30952 .72302 .29626 Mtetra
.588 .579 .81 r
.72302 .29626 .72881 .30952 .74067 .30581 .73501 .29433 Mtetra
.586 .611 .844 r
.73501 .29433 .74067 .30581 .75262 .3026 .74708 .29246 Mtetra
.584 .64 .872 r
.74708 .29246 .75262 .3026 .76465 .29974 .75921 .29059 Mtetra
.587 .667 .895 r
.75921 .29059 .76465 .29974 .77676 .29705 .7714 .28857 Mtetra
.588 .688 .911 r
.7714 .28857 .77676 .29705 .78893 .29445 .78364 .28642 Mtetra
.591 .704 .922 r
.78364 .28642 .78893 .29445 .80118 .29187 .79594 .28413 Mtetra
.594 .716 .928 r
.79594 .28413 .80118 .29187 .81347 .28921 .8083 .28168 Mtetra
.698 .76 .9 r
.15958 .49055 .16646 .49655 .17631 .49174 .16942 .48614 Mtetra
.705 .775 .906 r
.16942 .48614 .17631 .49174 .18621 .48678 .1793 .48155 Mtetra
.714 .79 .911 r
.1793 .48155 .18621 .48678 .19614 .48169 .18923 .47675 Mtetra
.723 .802 .913 r
.18923 .47675 .19614 .48169 .20611 .47647 .19921 .47168 Mtetra
.735 .809 .91 r
.19921 .47168 .20611 .47647 .21612 .47111 .20926 .46625 Mtetra
.743 .808 .904 r
.20926 .46625 .21612 .47111 .22616 .46574 .21935 .46054 Mtetra
.749 .798 .892 r
.21935 .46054 .22616 .46574 .23622 .46042 .2295 .45452 Mtetra
.747 .776 .877 r
.2295 .45452 .23622 .46042 .24627 .45538 .23968 .44837 Mtetra
.739 .744 .856 r
.23968 .44837 .24627 .45538 .25632 .45077 .24988 .44218 Mtetra
.721 .701 .831 r
.24988 .44218 .25632 .45077 .26635 .44681 .26009 .43619 Mtetra
.696 .653 .803 r
.26009 .43619 .26635 .44681 .27634 .44374 .27028 .43061 Mtetra
.666 .602 .773 r
.27028 .43061 .27634 .44374 .2863 .4417 .28046 .42566 Mtetra
.635 .553 .744 r
.28046 .42566 .2863 .4417 .29621 .44088 .29059 .42157 Mtetra
.609 .51 .716 r
.29059 .42157 .29621 .44088 .30611 .44111 .30071 .41828 Mtetra
.587 .474 .692 r
.30071 .41828 .30611 .44111 .31601 .44232 .31081 .41583 Mtetra
.572 .447 .671 r
.31081 .41583 .31601 .44232 .32595 .4439 .32092 .41396 Mtetra
.563 .428 .655 r
.32092 .41396 .32595 .4439 .33597 .4454 .33106 .41252 Mtetra
.552 .411 .644 r
.33106 .41252 .33597 .4454 .34607 .44668 .3412 .41178 Mtetra
.54 .398 .637 r
.3412 .41178 .34607 .44668 .35626 .44761 .35136 .41187 Mtetra
.527 .387 .634 r
.35136 .41187 .35626 .44761 .3665 .44876 .36152 .4131 Mtetra
.511 .376 .634 r
.36152 .4131 .3665 .44876 .37679 .45041 .3717 .41552 Mtetra
.502 .372 .636 r
.3717 .41552 .37679 .45041 .38714 .45254 .38192 .41859 Mtetra
.498 .372 .64 r
.38192 .41859 .38714 .45254 .39754 .45506 .39222 .42189 Mtetra
.504 .379 .644 r
.39222 .42189 .39754 .45506 .40804 .45738 .40262 .42471 Mtetra
.517 .39 .647 r
.40262 .42471 .40804 .45738 .41863 .45911 .41314 .4266 Mtetra
.532 .402 .648 r
.41314 .4266 .41863 .45911 .42933 .45991 .42378 .42738 Mtetra
.548 .413 .649 r
.42378 .42738 .42933 .45991 .44013 .45959 .43451 .42693 Mtetra
.562 .422 .649 r
.43451 .42693 .44013 .45959 .45102 .45817 .44534 .42537 Mtetra
.574 .43 .648 r
.44534 .42537 .45102 .45817 .46199 .45564 .45625 .42274 Mtetra
.585 .438 .648 r
.45625 .42274 .46199 .45564 .47302 .45206 .46723 .41911 Mtetra
.595 .445 .647 r
.46723 .41911 .47302 .45206 .48412 .44743 .47826 .41448 Mtetra
.606 .453 .647 r
.47826 .41448 .48412 .44743 .49526 .44169 .48935 .40878 Mtetra
.618 .46 .646 r
.48935 .40878 .49526 .44169 .50644 .43483 .50047 .40195 Mtetra
.629 .468 .645 r
.50047 .40195 .50644 .43483 .51764 .42683 .51162 .39386 Mtetra
.639 .475 .644 r
.51162 .39386 .51764 .42683 .52886 .41787 .52279 .38465 Mtetra
.647 .479 .642 r
.52279 .38465 .52886 .41787 .54009 .4083 .53396 .37446 Mtetra
.649 .479 .64 r
.53396 .37446 .54009 .4083 .55132 .39849 .54513 .36378 Mtetra
.645 .474 .637 r
.54513 .36378 .55132 .39849 .56255 .38906 .5563 .3533 Mtetra
.637 .466 .635 r
.5563 .3533 .56255 .38906 .5738 .38011 .56748 .34345 Mtetra
.625 .455 .633 r
.56748 .34345 .5738 .38011 .58507 .37163 .57868 .3348 Mtetra
.615 .448 .633 r
.57868 .3348 .58507 .37163 .59636 .36337 .58991 .32729 Mtetra
.608 .446 .636 r
.58991 .32729 .59636 .36337 .60765 .35473 .60119 .32061 Mtetra
.605 .449 .643 r
.60119 .32061 .60765 .35473 .61894 .34585 .61251 .31464 Mtetra
.607 .458 .653 r
.61251 .31464 .61894 .34585 .63025 .33688 .62387 .30911 Mtetra
.607 .47 .669 r
.62387 .30911 .63025 .33688 .64157 .32826 .63529 .30416 Mtetra
.605 .486 .69 r
.63529 .30416 .64157 .32826 .65295 .32062 .64679 .30006 Mtetra
.601 .505 .717 r
.64679 .30006 .65295 .32062 .6644 .31406 .65836 .29679 Mtetra
.592 .528 .752 r
.65836 .29679 .6644 .31406 .67594 .30875 .67003 .29441 Mtetra
.582 .558 .793 r
.67003 .29441 .67594 .30875 .68757 .30449 .6818 .29268 Mtetra
.569 .594 .838 r
.6818 .29268 .68757 .30449 .69929 .30114 .69365 .29137 Mtetra
.555 .633 .883 r
.69365 .29137 .69929 .30114 .71111 .29848 .70559 .29028 Mtetra
.545 .673 .922 r
.70559 .29028 .71111 .29848 .72302 .29626 .71759 .28916 Mtetra
.537 .706 .949 r
.71759 .28916 .72302 .29626 .73501 .29433 .72967 .2879 Mtetra
.541 .734 .964 r
.72967 .2879 .73501 .29433 .74708 .29246 .74179 .28634 Mtetra
.55 .75 .97 r
.74179 .28634 .74708 .29246 .75921 .29059 .75396 .28448 Mtetra
.568 .76 .969 r
.75396 .28448 .75921 .29059 .7714 .28857 .76617 .28225 Mtetra
.584 .761 .963 r
.76617 .28225 .7714 .28857 .78364 .28642 .77843 .27974 Mtetra
.597 .755 .953 r
.77843 .27974 .78364 .28642 .79594 .28413 .79073 .277 Mtetra
.608 .745 .942 r
.79073 .277 .79594 .28413 .8083 .28168 .80308 .27409 Mtetra
.666 .754 .916 r
.15266 .48451 .15958 .49055 .16942 .48614 .16242 .48097 Mtetra
.671 .786 .935 r
.16242 .48097 .16942 .48614 .1793 .48155 .17223 .47729 Mtetra
.678 .821 .952 r
.17223 .47729 .1793 .48155 .18923 .47675 .1821 .47337 Mtetra
.686 .856 .964 r
.1821 .47337 .18923 .47675 .19921 .47168 .19203 .46914 Mtetra
.697 .889 .968 r
.19203 .46914 .19921 .47168 .20926 .46625 .20203 .46448 Mtetra
.708 .917 .965 r
.20203 .46448 .20926 .46625 .21935 .46054 .21211 .45937 Mtetra
.722 .938 .957 r
.21211 .45937 .21935 .46054 .2295 .45452 .22226 .45373 Mtetra
.736 .95 .948 r
.22226 .45373 .2295 .45452 .23968 .44837 .23247 .44764 Mtetra
.755 .953 .94 r
.23247 .44764 .23968 .44837 .24988 .44218 .24275 .44109 Mtetra
.773 .944 .935 r
.24275 .44109 .24988 .44218 .26009 .43619 .25307 .43424 Mtetra
.787 .917 .926 r
.25307 .43424 .26009 .43619 .27028 .43061 .26342 .42719 Mtetra
.787 .866 .907 r
.26342 .42719 .27028 .43061 .28046 .42566 .2738 .42005 Mtetra
.771 .793 .872 r
.2738 .42005 .28046 .42566 .29059 .42157 .28419 .41297 Mtetra
.739 .71 .824 r
.28419 .41297 .29059 .42157 .30071 .41828 .29457 .40608 Mtetra
.702 .633 .776 r
.29457 .40608 .30071 .41828 .31081 .41583 .30496 .39951 Mtetra
.664 .567 .736 r
.30496 .39951 .31081 .41583 .32092 .41396 .31532 .39367 Mtetra
.63 .517 .706 r
.31532 .39367 .32092 .41396 .33106 .41252 .32563 .38885 Mtetra
.601 .479 .686 r
.32563 .38885 .33106 .41252 .3412 .41178 .33591 .38527 Mtetra
.576 .45 .671 r
.33591 .38527 .3412 .41178 .35136 .41187 .34615 .38304 Mtetra
.565 .433 .66 r
.34615 .38304 .35136 .41187 .36152 .4131 .3564 .38142 Mtetra
.561 .421 .648 r
.3564 .38142 .36152 .4131 .3717 .41552 .3667 .37992 Mtetra
.564 .413 .635 r
.3667 .37992 .3717 .41552 .38192 .41859 .37708 .37786 Mtetra
.57 .407 .621 r
.37708 .37786 .38192 .41859 .39222 .42189 .38756 .37482 Mtetra
.571 .398 .608 r
.38756 .37482 .39222 .42189 .40262 .42471 .3981 .371 Mtetra
.571 .39 .598 r
.3981 .371 .40262 .42471 .41314 .4266 .40871 .36653 Mtetra
.568 .383 .59 r
.40871 .36653 .41314 .4266 .42378 .42738 .41937 .36184 Mtetra
.565 .376 .584 r
.41937 .36184 .42378 .42738 .43451 .42693 .43006 .35719 Mtetra
.562 .371 .58 r
.43006 .35719 .43451 .42693 .44534 .42537 .44077 .35277 Mtetra
.558 .367 .578 r
.44077 .35277 .44534 .42537 .45625 .42274 .45152 .34869 Mtetra
.556 .364 .576 r
.45152 .34869 .45625 .42274 .46723 .41911 .4623 .34498 Mtetra
.554 .363 .576 r
.4623 .34498 .46723 .41911 .47826 .41448 .47311 .34163 Mtetra
.552 .362 .577 r
.47311 .34163 .47826 .41448 .48935 .40878 .48397 .33864 Mtetra
.552 .364 .58 r
.48397 .33864 .48935 .40878 .50047 .40195 .49487 .33587 Mtetra
.553 .367 .583 r
.49487 .33587 .50047 .40195 .51162 .39386 .50583 .33314 Mtetra
.556 .374 .589 r
.50583 .33314 .51162 .39386 .52279 .38465 .51683 .3302 Mtetra
.564 .385 .598 r
.51683 .3302 .52279 .38465 .53396 .37446 .52789 .32659 Mtetra
.574 .4 .608 r
.52789 .32659 .53396 .37446 .54513 .36378 .53898 .3222 Mtetra
.588 .42 .621 r
.53898 .3222 .54513 .36378 .5563 .3533 .55011 .31682 Mtetra
.601 .439 .634 r
.55011 .31682 .5563 .3533 .56748 .34345 .56127 .31085 Mtetra
.607 .453 .647 r
.56127 .31085 .56748 .34345 .57868 .3348 .57246 .30501 Mtetra
.606 .461 .658 r
.57246 .30501 .57868 .3348 .58991 .32729 .58369 .29978 Mtetra
.594 .462 .67 r
.58369 .29978 .58991 .32729 .60119 .32061 .59499 .29591 Mtetra
.582 .467 .687 r
.59499 .29591 .60119 .32061 .61251 .31464 .60637 .29332 Mtetra
.57 .48 .713 r
.60637 .29332 .61251 .31464 .62387 .30911 .61784 .29177 Mtetra
.558 .507 .754 r
.61784 .29177 .62387 .30911 .63529 .30416 .62939 .29097 Mtetra
.545 .555 .815 r
.62939 .29097 .63529 .30416 .64679 .30006 .64104 .29051 Mtetra
.52 .619 .891 r
.64104 .29051 .64679 .30006 .65836 .29679 .65276 .29026 Mtetra
.468 .69 .964 r
.65276 .29026 .65836 .29679 .67003 .29441 .66456 .29007 Mtetra
.388 .736 .991 r
.66456 .29007 .67003 .29441 .6818 .29268 .67644 .28982 Mtetra
.31 .748 .967 r
.67644 .28982 .6818 .29268 .69365 .29137 .68839 .28936 Mtetra
.27 .749 .933 r
.68839 .28936 .69365 .29137 .70559 .29028 .70039 .28858 Mtetra
.285 .766 .924 r
.70039 .28858 .70559 .29028 .71759 .28916 .71245 .28736 Mtetra
.337 .796 .941 r
.71245 .28736 .71759 .28916 .72967 .2879 .72454 .28566 Mtetra
.417 .831 .971 r
.72454 .28566 .72967 .2879 .74179 .28634 .73667 .28342 Mtetra
.494 .85 .992 r
.73667 .28342 .74179 .28634 .75396 .28448 .74884 .28071 Mtetra
.56 .851 .997 r
.74884 .28071 .75396 .28448 .76617 .28225 .76103 .27755 Mtetra
.604 .835 .987 r
.76103 .27755 .76617 .28225 .77843 .27974 .77325 .27406 Mtetra
.63 .808 .968 r
.77325 .27406 .77843 .27974 .79073 .277 .78552 .27032 Mtetra
.644 .778 .945 r
.78552 .27032 .79073 .277 .80308 .27409 .79782 .26643 Mtetra
.618 .741 .934 r
.14569 .47843 .15266 .48451 .16242 .48097 .15535 .47595 Mtetra
.613 .779 .961 r
.15535 .47595 .16242 .48097 .17223 .47729 .16506 .4734 Mtetra
.605 .821 .983 r
.16506 .4734 .17223 .47729 .1821 .47337 .17482 .47069 Mtetra
.592 .863 .994 r
.17482 .47069 .1821 .47337 .19203 .46914 .18466 .46773 Mtetra
.569 .897 .984 r
.18466 .46773 .19203 .46914 .20203 .46448 .19456 .46441 Mtetra
.529 .911 .941 r
.19456 .46441 .20203 .46448 .21211 .45937 .20455 .46065 Mtetra
.477 .897 .862 r
.20455 .46065 .21211 .45937 .22226 .45373 .21462 .45636 Mtetra
.413 .854 .756 r
.21462 .45636 .22226 .45373 .23247 .44764 .22477 .45151 Mtetra
.359 .803 .652 r
.22477 .45151 .23247 .44764 .24275 .44109 .23501 .44604 Mtetra
0 0 0 r
.23501 .44604 .24275 .44109 .25307 .43424 .24532 .43998 Mtetra
.24532 .43998 .25307 .43424 .26342 .42719 .25571 .43335 Mtetra
.25571 .43335 .26342 .42719 .2738 .42005 .26615 .42623 Mtetra
.26615 .42623 .2738 .42005 .28419 .41297 .27664 .41871 Mtetra
.27664 .41871 .28419 .41297 .29457 .40608 .28715 .411 Mtetra
.467 .847 .623 r
.28715 .411 .29457 .40608 .30496 .39951 .29768 .40331 Mtetra
.525 .898 .71 r
.29768 .40331 .30496 .39951 .31532 .39367 .30819 .39605 Mtetra
.575 .938 .808 r
.30819 .39605 .31532 .39367 .32563 .38885 .31867 .38952 Mtetra
.638 .962 .907 r
.31867 .38952 .32563 .38885 .33591 .38527 .32913 .38366 Mtetra
.693 .932 .966 r
.32913 .38366 .33591 .38527 .34615 .38304 .33958 .3784 Mtetra
.724 .831 .931 r
.33958 .3784 .34615 .38304 .3564 .38142 .35006 .37309 Mtetra
.715 .716 .85 r
.35006 .37309 .3564 .38142 .3667 .37992 .3606 .36737 Mtetra
.693 .628 .779 r
.3606 .36737 .3667 .37992 .37708 .37786 .37118 .36116 Mtetra
.674 .572 .732 r
.37118 .36116 .37708 .37786 .38756 .37482 .38181 .35446 Mtetra
.656 .533 .703 r
.38181 .35446 .38756 .37482 .3981 .371 .39246 .34773 Mtetra
.641 .508 .685 r
.39246 .34773 .3981 .371 .40871 .36653 .40312 .34125 Mtetra
.628 .49 .675 r
.40312 .34125 .40871 .36653 .41937 .36184 .41378 .33527 Mtetra
.616 .477 .669 r
.41378 .33527 .41937 .36184 .43006 .35719 .42446 .32991 Mtetra
.607 .468 .667 r
.42446 .32991 .43006 .35719 .44077 .35277 .43514 .32512 Mtetra
.6 .462 .665 r
.43514 .32512 .44077 .35277 .45152 .34869 .44585 .32087 Mtetra
.593 .457 .665 r
.44585 .32087 .45152 .34869 .4623 .34498 .45659 .31711 Mtetra
.586 .453 .666 r
.45659 .31711 .4623 .34498 .47311 .34163 .46735 .31385 Mtetra
.579 .448 .667 r
.46735 .31385 .47311 .34163 .48397 .33864 .47816 .31114 Mtetra
.572 .445 .669 r
.47816 .31114 .48397 .33864 .49487 .33587 .48901 .30899 Mtetra
.563 .442 .673 r
.48901 .30899 .49487 .33587 .50583 .33314 .49991 .30748 Mtetra
.557 .444 .68 r
.49991 .30748 .50583 .33314 .51683 .3302 .51087 .30647 Mtetra
.553 .452 .694 r
.51087 .30647 .51683 .3302 .52789 .32659 .52189 .30573 Mtetra
.555 .472 .716 r
.52189 .30573 .52789 .32659 .53898 .3222 .53298 .30497 Mtetra
.567 .511 .752 r
.53298 .30497 .53898 .3222 .55011 .31682 .54413 .30372 Mtetra
.583 .574 .809 r
.54413 .30372 .55011 .31682 .56127 .31085 .55534 .30198 Mtetra
.595 .671 .893 r
.55534 .30198 .56127 .31085 .57246 .30501 .56661 .29983 Mtetra
.561 .783 .982 r
.56661 .29983 .57246 .30501 .58369 .29978 .57793 .29763 Mtetra
.373 .804 .966 r
.57793 .29763 .58369 .29978 .59499 .29591 .58933 .29605 Mtetra
.085 .645 .742 r
.58933 .29605 .59499 .29591 .60637 .29332 .60081 .29515 Mtetra
.143 0 0 r
.60081 .29515 .60637 .29332 .61784 .29177 .61237 .29502 Mtetra
.266 0 0 r
.61237 .29502 .61784 .29177 .62939 .29097 .62403 .29534 Mtetra
.316 0 0 r
.62403 .29534 .62939 .29097 .64104 .29051 .63577 .29568 Mtetra
.332 0 0 r
.63577 .29568 .64104 .29051 .65276 .29026 .64759 .29585 Mtetra
.323 0 0 r
.64759 .29585 .65276 .29026 .66456 .29007 .65947 .29561 Mtetra
.293 0 0 r
.65947 .29561 .66456 .29007 .67644 .28982 .6714 .29488 Mtetra
.24 0 0 r
.6714 .29488 .67644 .28982 .68839 .28936 .68338 .29357 Mtetra
.157 0 0 r
.68338 .29357 .68839 .28936 .70039 .28858 .6954 .29165 Mtetra
.031 0 0 r
.6954 .29165 .70039 .28858 .71245 .28736 .70745 .2891 Mtetra
0 0 0 r
.70745 .2891 .71245 .28736 .72454 .28566 .71952 .28595 Mtetra
.328 .813 .812 r
.71952 .28595 .72454 .28566 .73667 .28342 .73162 .28226 Mtetra
.491 .895 .933 r
.73162 .28226 .73667 .28342 .74884 .28071 .74374 .2781 Mtetra
.599 .909 .981 r
.74374 .2781 .74884 .28071 .76103 .27755 .75589 .27357 Mtetra
.654 .883 .982 r
.75589 .27357 .76103 .27755 .77325 .27406 .76807 .26876 Mtetra
.679 .843 .962 r
.76807 .26876 .77325 .27406 .78552 .27032 .78027 .26378 Mtetra
.686 .802 .936 r
.78027 .26378 .78552 .27032 .79782 .26643 .79252 .25872 Mtetra
.564 .724 .949 r
.13868 .4723 .14569 .47843 .15535 .47595 .14824 .47078 Mtetra
.547 .755 .973 r
.14824 .47078 .15535 .47595 .16506 .4734 .15785 .46927 Mtetra
.523 .787 .993 r
.15785 .46927 .16506 .4734 .17482 .47069 .16752 .46771 Mtetra
.488 .818 1 r
.16752 .46771 .17482 .47069 .18466 .46773 .17724 .46603 Mtetra
.429 .834 .976 r
.17724 .46603 .18466 .46773 .19456 .46441 .18703 .46418 Mtetra
.342 .816 .897 r
.18703 .46418 .19456 .46441 .20455 .46065 .19689 .46205 Mtetra
.23 .747 .753 r
.19689 .46205 .20455 .46065 .21462 .45636 .20683 .45954 Mtetra
0 0 0 r
.20683 .45954 .21462 .45636 .22477 .45151 .21686 .45655 Mtetra
.21686 .45655 .22477 .45151 .23501 .44604 .22699 .45298 Mtetra
.051 0 0 r
.22699 .45298 .23501 .44604 .24532 .43998 .2372 .4488 Mtetra
.098 0 0 r
.2372 .4488 .24532 .43998 .25571 .43335 .24751 .44395 Mtetra
.135 0 0 r
.24751 .44395 .25571 .43335 .26615 .42623 .25789 .4385 Mtetra
.163 0 .009 r
.25789 .4385 .26615 .42623 .27664 .41871 .26835 .43251 Mtetra
.194 0 .062 r
.26835 .43251 .27664 .41871 .28715 .411 .27885 .4262 Mtetra
.223 0 .105 r
.27885 .4262 .28715 .411 .29768 .40331 .28939 .41972 Mtetra
.247 0 .138 r
.28939 .41972 .29768 .40331 .30819 .39605 .29996 .41314 Mtetra
.258 0 .155 r
.29996 .41314 .30819 .39605 .31867 .38952 .31055 .40648 Mtetra
.239 0 .144 r
.31055 .40648 .31867 .38952 .32913 .38366 .32119 .39938 Mtetra
.185 0 .098 r
.32119 .39938 .32913 .38366 .33958 .3784 .33189 .39164 Mtetra
.082 0 0 r
.33189 .39164 .33958 .3784 .35006 .37309 .34263 .38337 Mtetra
0 0 0 r
.34263 .38337 .35006 .37309 .3606 .36737 .3534 .37473 Mtetra
.3534 .37473 .3606 .36737 .37118 .36116 .36416 .36647 Mtetra
.36416 .36647 .37118 .36116 .38181 .35446 .37489 .35904 Mtetra
.37489 .35904 .38181 .35446 .39246 .34773 .38559 .35268 Mtetra
.38559 .35268 .39246 .34773 .40312 .34125 .39627 .34749 Mtetra
.032 0 0 r
.39627 .34749 .40312 .34125 .41378 .33527 .40695 .34311 Mtetra
.165 0 0 r
.40695 .34311 .41378 .33527 .42446 .32991 .41765 .33929 Mtetra
.237 0 0 r
.41765 .33929 .42446 .32991 .43514 .32512 .42838 .33567 Mtetra
.27 0 .036 r
.42838 .33567 .43514 .32512 .44585 .32087 .43916 .33204 Mtetra
.28 0 .058 r
.43916 .33204 .44585 .32087 .45659 .31711 .44998 .32827 Mtetra
.274 0 .055 r
.44998 .32827 .45659 .31711 .46735 .31385 .46085 .32436 Mtetra
.258 0 .03 r
.46085 .32436 .46735 .31385 .47816 .31114 .47176 .32044 Mtetra
.235 0 0 r
.47176 .32044 .47816 .31114 .48901 .30899 .48272 .31672 Mtetra
.216 0 0 r
.48272 .31672 .48901 .30899 .49991 .30748 .49371 .31356 Mtetra
.204 0 0 r
.49371 .31356 .49991 .30748 .51087 .30647 .50474 .31123 Mtetra
.229 0 0 r
.50474 .31123 .51087 .30647 .52189 .30573 .51583 .31007 Mtetra
.29 0 0 r
.51583 .31007 .52189 .30573 .53298 .30497 .52698 .31001 Mtetra
.367 0 0 r
.52698 .31001 .53298 .30497 .54413 .30372 .53821 .31081 Mtetra
.429 0 .002 r
.53821 .31081 .54413 .30372 .55534 .30198 .54952 .312 Mtetra
.449 .01 .11 r
.54952 .312 .55534 .30198 .56661 .29983 .56091 .31283 Mtetra
.456 .051 .181 r
.56091 .31283 .56661 .29983 .57793 .29763 .57238 .31314 Mtetra
.454 .071 .223 r
.57238 .31314 .57793 .29763 .58933 .29605 .58391 .31281 Mtetra
.449 .077 .238 r
.58391 .31281 .58933 .29605 .60081 .29515 .59551 .31203 Mtetra
.448 .076 .239 r
.59551 .31203 .60081 .29515 .61237 .29502 .60717 .31119 Mtetra
.442 .065 .226 r
.60717 .31119 .61237 .29502 .62403 .29534 .61891 .31024 Mtetra
.43 .043 .202 r
.61891 .31024 .62403 .29534 .63577 .29568 .63071 .30914 Mtetra
.409 .009 .167 r
.63071 .30914 .63577 .29568 .64759 .29585 .64257 .30771 Mtetra
.373 0 .117 r
.64257 .30771 .64759 .29585 .65947 .29561 .65448 .30572 Mtetra
.322 0 .048 r
.65448 .30572 .65947 .29561 .6714 .29488 .66642 .30313 Mtetra
.244 0 0 r
.66642 .30313 .6714 .29488 .68338 .29357 .6784 .29984 Mtetra
.129 0 0 r
.6784 .29984 .68338 .29357 .6954 .29165 .69039 .29592 Mtetra
0 0 0 r
.69039 .29592 .6954 .29165 .70745 .2891 .70241 .29138 Mtetra
.70241 .29138 .70745 .2891 .71952 .28595 .71445 .28635 Mtetra
.467 .891 .833 r
.71445 .28635 .71952 .28595 .73162 .28226 .7265 .28092 Mtetra
.612 .945 .94 r
.7265 .28092 .73162 .28226 .74374 .2781 .73858 .27518 Mtetra
.684 .93 .969 r
.73858 .27518 .74374 .2781 .75589 .27357 .75068 .26926 Mtetra
.714 .891 .961 r
.75068 .26926 .75589 .27357 .76807 .26876 .76281 .26319 Mtetra
.722 .849 .942 r
.76281 .26319 .76807 .26876 .78027 .26378 .77498 .25707 Mtetra
.721 .81 .92 r
.77498 .25707 .78027 .26378 .79252 .25872 .78718 .25095 Mtetra
.537 .715 .954 r
.13161 .46613 .13868 .4723 .14824 .47078 .14114 .465 Mtetra
.524 .725 .965 r
.14114 .465 .14824 .47078 .15785 .46927 .15072 .46395 Mtetra
.509 .738 .977 r
.15072 .46395 .15785 .46927 .16752 .46771 .16034 .46295 Mtetra
.49 .753 .988 r
.16034 .46295 .16752 .46771 .17724 .46603 .17 .46197 Mtetra
.462 .769 .996 r
.17 .46197 .17724 .46603 .18703 .46418 .17972 .46102 Mtetra
.424 .786 .995 r
.17972 .46102 .18703 .46418 .19689 .46205 .18949 .45999 Mtetra
.366 .794 .97 r
.18949 .45999 .19689 .46205 .20683 .45954 .19933 .45881 Mtetra
.283 .775 .897 r
.19933 .45881 .20683 .45954 .21686 .45655 .20925 .45739 Mtetra
.175 .711 .759 r
.20925 .45739 .21686 .45655 .22699 .45298 .21925 .45562 Mtetra
0 0 0 r
.21925 .45562 .22699 .45298 .2372 .4488 .22933 .45344 Mtetra
.049 0 0 r
.22933 .45344 .2372 .4488 .24751 .44395 .23951 .45075 Mtetra
.135 0 0 r
.23951 .45075 .24751 .44395 .25789 .4385 .24977 .44757 Mtetra
.197 0 0 r
.24977 .44757 .25789 .4385 .26835 .43251 .26011 .4439 Mtetra
.245 0 .03 r
.26011 .4439 .26835 .43251 .27885 .4262 .27053 .43981 Mtetra
.278 0 .1 r
.27053 .43981 .27885 .4262 .28939 .41972 .28101 .43534 Mtetra
.294 0 .145 r
.28101 .43534 .28939 .41972 .29996 .41314 .29155 .43037 Mtetra
.299 0 .172 r
.29155 .43037 .29996 .41314 .31055 .40648 .30217 .42482 Mtetra
.291 0 .183 r
.30217 .42482 .31055 .40648 .32119 .39938 .31287 .41857 Mtetra
.279 0 .189 r
.31287 .41857 .32119 .39938 .33189 .39164 .32363 .41159 Mtetra
.285 0 .201 r
.32363 .41159 .33189 .39164 .34263 .38337 .33443 .40443 Mtetra
.308 0 .223 r
.33443 .40443 .34263 .38337 .3534 .37473 .34523 .39747 Mtetra
.347 .018 .257 r
.34523 .39747 .3534 .37473 .36416 .36647 .35601 .39127 Mtetra
.389 .065 .291 r
.35601 .39127 .36416 .36647 .37489 .35904 .36677 .38615 Mtetra
.419 .102 .318 r
.36677 .38615 .37489 .35904 .38559 .35268 .37751 .38191 Mtetra
.44 .128 .337 r
.37751 .38191 .38559 .35268 .39627 .34749 .38827 .3784 Mtetra
.45 .141 .349 r
.38827 .3784 .39627 .34749 .40695 .34311 .39905 .3752 Mtetra
.454 .148 .355 r
.39905 .3752 .40695 .34311 .41765 .33929 .40988 .37206 Mtetra
.454 .15 .358 r
.40988 .37206 .41765 .33929 .42838 .33567 .42076 .36879 Mtetra
.452 .148 .359 r
.42076 .36879 .42838 .33567 .43916 .33204 .4317 .36529 Mtetra
.449 .146 .358 r
.4317 .36529 .43916 .33204 .44998 .32827 .44269 .36153 Mtetra
.445 .143 .357 r
.44269 .36153 .44998 .32827 .46085 .32436 .45373 .3575 Mtetra
.442 .139 .355 r
.45373 .3575 .46085 .32436 .47176 .32044 .46481 .35323 Mtetra
.439 .136 .353 r
.46481 .35323 .47176 .32044 .48272 .31672 .47594 .34884 Mtetra
.438 .134 .35 r
.47594 .34884 .48272 .31672 .49371 .31356 .48711 .3445 Mtetra
.44 .132 .345 r
.48711 .3445 .49371 .31356 .50474 .31123 .49832 .34047 Mtetra
.446 .133 .339 r
.49832 .34047 .50474 .31123 .51583 .31007 .50957 .33719 Mtetra
.454 .133 .33 r
.50957 .33719 .51583 .31007 .52698 .31001 .52087 .33479 Mtetra
.466 .134 .319 r
.52087 .33479 .52698 .31001 .53821 .31081 .53223 .33349 Mtetra
.474 .132 .305 r
.53223 .33349 .53821 .31081 .54952 .312 .54366 .33297 Mtetra
.473 .122 .29 r
.54366 .33297 .54952 .312 .56091 .31283 .55517 .33267 Mtetra
.466 .11 .276 r
.55517 .33267 .56091 .31283 .57238 .31314 .56674 .33219 Mtetra
.448 .088 .261 r
.56674 .33219 .57238 .31314 .58391 .31281 .57838 .33098 Mtetra
.427 .064 .243 r
.57838 .33098 .58391 .31281 .59551 .31203 .59007 .32906 Mtetra
.406 .036 .22 r
.59007 .32906 .59551 .31203 .60717 .31119 .60182 .32654 Mtetra
.378 0 .185 r
.60182 .32654 .60717 .31119 .61891 .31024 .61361 .32352 Mtetra
.341 0 .131 r
.61361 .32352 .61891 .31024 .63071 .30914 .62544 .32011 Mtetra
.284 0 .052 r
.62544 .32011 .63071 .30914 .64257 .30771 .63732 .31627 Mtetra
.192 0 0 r
.63732 .31627 .64257 .30771 .65448 .30572 .64922 .31191 Mtetra
.053 0 0 r
.64922 .31191 .65448 .30572 .66642 .30313 .66116 .30704 Mtetra
0 0 0 r
.66116 .30704 .66642 .30313 .6784 .29984 .67311 .30165 Mtetra
.383 .831 .716 r
.67311 .30165 .6784 .29984 .69039 .29592 .68508 .29582 Mtetra
.572 .94 .881 r
.68508 .29582 .69039 .29592 .70241 .29138 .69708 .28961 Mtetra
.679 .957 .947 r
.69708 .28961 .70241 .29138 .71445 .28635 .70909 .28314 Mtetra
.724 .929 .958 r
.70909 .28314 .71445 .28635 .7265 .28092 .72112 .27651 Mtetra
.74 .893 .948 r
.72112 .27651 .7265 .28092 .73858 .27518 .73319 .26978 Mtetra
.742 .86 .935 r
.73319 .26978 .73858 .27518 .75068 .26926 .74529 .26307 Mtetra
.74 .833 .922 r
.74529 .26307 .75068 .26926 .76281 .26319 .75742 .25636 Mtetra
.736 .812 .911 r
.75742 .25636 .76281 .26319 .77498 .25707 .76959 .2497 Mtetra
.731 .794 .902 r
.76959 .2497 .77498 .25707 .78718 .25095 .7818 .24311 Mtetra
.549 .719 .952 r
.12449 .45992 .13161 .46613 .14114 .465 .13406 .4586 Mtetra
.544 .711 .949 r
.13406 .4586 .14114 .465 .15072 .46395 .14367 .45739 Mtetra
.537 .704 .947 r
.14367 .45739 .15072 .46395 .16034 .46295 .15331 .45631 Mtetra
.528 .698 .947 r
.15331 .45631 .16034 .46295 .17 .46197 .16298 .45537 Mtetra
.515 .695 .951 r
.16298 .45537 .17 .46197 .17972 .46102 .17269 .45461 Mtetra
.502 .698 .957 r
.17269 .45461 .17972 .46102 .18949 .45999 .18243 .45398 Mtetra
.484 .706 .968 r
.18243 .45398 .18949 .45999 .19933 .45881 .19222 .45346 Mtetra
.462 .722 .981 r
.19222 .45346 .19933 .45881 .20925 .45739 .20207 .45297 Mtetra
.429 .745 .993 r
.20207 .45297 .20925 .45739 .21925 .45562 .21197 .45244 Mtetra
.373 .764 .988 r
.21197 .45244 .21925 .45562 .22933 .45344 .22194 .45179 Mtetra
.278 .757 .93 r
.22194 .45179 .22933 .45344 .23951 .45075 .23198 .45096 Mtetra
.135 .682 .775 r
.23198 .45096 .23951 .45075 .24977 .44757 .24211 .44987 Mtetra
.018 0 0 r
.24211 .44987 .24977 .44757 .26011 .4439 .25231 .44845 Mtetra
.133 0 0 r
.25231 .44845 .26011 .4439 .27053 .43981 .2626 .4466 Mtetra
.2 0 0 r
.2626 .4466 .27053 .43981 .28101 .43534 .27299 .4442 Mtetra
.232 0 0 r
.27299 .4442 .28101 .43534 .29155 .43037 .28347 .44116 Mtetra
.247 0 .011 r
.28347 .44116 .29155 .43037 .30217 .42482 .29405 .43741 Mtetra
.272 0 .071 r
.29405 .43741 .30217 .42482 .31287 .41857 .30469 .43329 Mtetra
.309 0 .133 r
.30469 .43329 .31287 .41857 .32363 .41159 .31537 .42906 Mtetra
.363 0 .203 r
.31537 .42906 .32363 .41159 .33443 .40443 .32607 .42533 Mtetra
.413 .066 .265 r
.32607 .42533 .33443 .40443 .34523 .39747 .33676 .42243 Mtetra
.446 .115 .31 r
.33676 .42243 .34523 .39747 .35601 .39127 .34745 .42019 Mtetra
.465 .147 .341 r
.34745 .42019 .35601 .39127 .36677 .38615 .35818 .41845 Mtetra
.471 .161 .358 r
.35818 .41845 .36677 .38615 .37751 .38191 .36897 .41662 Mtetra
.469 .165 .367 r
.36897 .41662 .37751 .38191 .38827 .3784 .37983 .41437 Mtetra
.465 .164 .369 r
.37983 .41437 .38827 .3784 .39905 .3752 .39076 .41161 Mtetra
.459 .159 .369 r
.39076 .41161 .39905 .3752 .40988 .37206 .40177 .40832 Mtetra
.455 .155 .367 r
.40177 .40832 .40988 .37206 .42076 .36879 .41283 .40473 Mtetra
.452 .152 .365 r
.41283 .40473 .42076 .36879 .4317 .36529 .42395 .40099 Mtetra
.452 .151 .364 r
.42395 .40099 .4317 .36529 .44269 .36153 .43511 .39724 Mtetra
.43511 .39724 .44269 .36153 .45373 .3575 .44632 .39347 Mtetra
.45 .151 .364 r
.44632 .39347 .45373 .3575 .46481 .35323 .45758 .38954 Mtetra
.448 .149 .365 r
.45758 .38954 .46481 .35323 .47594 .34884 .46888 .38532 Mtetra
.441 .144 .363 r
.46888 .38532 .47594 .34884 .48711 .3445 .48024 .38056 Mtetra
.434 .137 .36 r
.48024 .38056 .48711 .3445 .49832 .34047 .49165 .37527 Mtetra
.425 .126 .352 r
.49165 .37527 .49832 .34047 .50957 .33719 .50309 .36956 Mtetra
.415 .112 .34 r
.50309 .36956 .50957 .33719 .52087 .33479 .51457 .36375 Mtetra
.41 .098 .322 r
.51457 .36375 .52087 .33479 .53223 .33349 .52609 .35844 Mtetra
.404 .077 .294 r
.52609 .35844 .53223 .33349 .54366 .33297 .53764 .35379 Mtetra
.398 .051 .257 r
.53764 .35379 .54366 .33297 .55517 .33267 .54925 .34999 Mtetra
.384 .016 .211 r
.54925 .34999 .55517 .33267 .56674 .33219 .56091 .34669 Mtetra
.351 0 .154 r
.56091 .34669 .56674 .33219 .57838 .33098 .57262 .34328 Mtetra
.305 0 .088 r
.57262 .34328 .57838 .33098 .59007 .32906 .58438 .33949 Mtetra
.233 0 .006 r
.58438 .33949 .59007 .32906 .60182 .32654 .59618 .33498 Mtetra
.131 0 0 r
.59618 .33498 .60182 .32654 .61361 .32352 .60801 .32979 Mtetra
0 0 0 r
.60801 .32979 .61361 .32352 .62544 .32011 .61986 .32405 Mtetra
.61986 .32405 .62544 .32011 .63732 .31627 .63173 .31784 Mtetra
.479 .889 .767 r
.63173 .31784 .63732 .31627 .64922 .31191 .64362 .31129 Mtetra
.655 .966 .912 r
.64362 .31129 .64922 .31191 .66116 .30704 .65554 .30446 Mtetra
.734 .947 .95 r
.65554 .30446 .66116 .30704 .67311 .30165 .66748 .29741 Mtetra
.757 .899 .941 r
.66748 .29741 .67311 .30165 .68508 .29582 .67944 .29024 Mtetra
.759 .854 .921 r
.67944 .29024 .68508 .29582 .69708 .28961 .69142 .28302 Mtetra
.754 .82 .904 r
.69142 .28302 .69708 .28961 .70909 .28314 .70344 .27581 Mtetra
.746 .796 .893 r
.70344 .27581 .70909 .28314 .72112 .27651 .71549 .2687 Mtetra
.74 .781 .886 r
.71549 .2687 .72112 .27651 .73319 .26978 .72758 .26171 Mtetra
.733 .772 .884 r
.72758 .26171 .73319 .26978 .74529 .26307 .73971 .25489 Mtetra
.728 .769 .885 r
.73971 .25489 .74529 .26307 .75742 .25636 .75189 .24822 Mtetra
.725 .769 .888 r
.75189 .24822 .75742 .25636 .76959 .2497 .76411 .24166 Mtetra
.723 .773 .892 r
.76411 .24166 .76959 .2497 .7818 .24311 .77637 .23521 Mtetra
.598 .735 .941 r
.11732 .45366 .12449 .45992 .13406 .4586 .12701 .45149 Mtetra
.596 .707 .921 r
.12701 .45149 .13406 .4586 .14367 .45739 .13673 .44942 Mtetra
.592 .68 .902 r
.13673 .44942 .14367 .45739 .15331 .45631 .14647 .4475 Mtetra
.585 .655 .885 r
.14647 .4475 .15331 .45631 .16298 .45537 .15624 .44579 Mtetra
.575 .632 .87 r
.15624 .44579 .16298 .45537 .17269 .45461 .16603 .44433 Mtetra
.566 .612 .858 r
.16603 .44433 .17269 .45461 .18243 .45398 .17584 .44312 Mtetra
.556 .595 .848 r
.17584 .44312 .18243 .45398 .19222 .45346 .18567 .44218 Mtetra
.548 .583 .841 r
.18567 .44218 .19222 .45346 .20207 .45297 .19554 .44145 Mtetra
.541 .576 .839 r
.19554 .44145 .20207 .45297 .21197 .45244 .20544 .44092 Mtetra
.537 .574 .84 r
.20544 .44092 .21197 .45244 .22194 .45179 .21539 .44048 Mtetra
.534 .578 .845 r
.21539 .44048 .22194 .45179 .23198 .45096 .22539 .44009 Mtetra
.534 .588 .855 r
.22539 .44009 .23198 .45096 .24211 .44987 .23546 .43965 Mtetra
.538 .605 .869 r
.23546 .43965 .24211 .44987 .25231 .44845 .2456 .43904 Mtetra
.546 .63 .886 r
.2456 .43904 .25231 .44845 .2626 .4466 .25582 .43815 Mtetra
.558 .663 .907 r
.25582 .43815 .2626 .4466 .27299 .4442 .26613 .43686 Mtetra
.569 .702 .931 r
.26613 .43686 .27299 .4442 .28347 .44116 .27653 .43518 Mtetra
.575 .751 .961 r
.27653 .43518 .28347 .44116 .29405 .43741 .28701 .43312 Mtetra
.542 .803 .994 r
.28701 .43312 .29405 .43741 .30469 .43329 .29754 .43105 Mtetra
.428 .825 .982 r
.29754 .43105 .30469 .43329 .31537 .42906 .30811 .42921 Mtetra
.178 .714 .798 r
.30811 .42921 .31537 .42906 .32607 .42533 .3187 .42776 Mtetra
.081 0 0 r
.3187 .42776 .32607 .42533 .33676 .42243 .32933 .42674 Mtetra
.191 0 0 r
.32933 .42674 .33676 .42243 .34745 .42019 .34002 .42562 Mtetra
.21 0 0 r
.34002 .42562 .34745 .42019 .35818 .41845 .3508 .42407 Mtetra
.159 0 0 r
.3508 .42407 .35818 .41845 .36897 .41662 .36167 .42178 Mtetra
.056 0 0 r
.36167 .42178 .36897 .41662 .37983 .41437 .37264 .4186 Mtetra
0 0 0 r
.37264 .4186 .37983 .41437 .39076 .41161 .38368 .41481 Mtetra
.38368 .41481 .39076 .41161 .40177 .40832 .39479 .41061 Mtetra
.287 .775 .702 r
.39479 .41061 .40177 .40832 .41283 .40473 .40593 .40636 Mtetra
.328 .808 .762 r
.40593 .40636 .41283 .40473 .42395 .40099 .41712 .40228 Mtetra
.323 .808 .781 r
.41712 .40228 .42395 .40099 .43511 .39724 .42834 .39851 Mtetra
.288 .785 .767 r
.42834 .39851 .43511 .39724 .44632 .39347 .43959 .39503 Mtetra
.237 .748 .724 r
.43959 .39503 .44632 .39347 .45758 .38954 .4509 .39173 Mtetra
0 0 0 r
.4509 .39173 .45758 .38954 .46888 .38532 .46225 .38838 Mtetra
.46225 .38838 .46888 .38532 .48024 .38056 .47366 .38461 Mtetra
.47366 .38461 .48024 .38056 .49165 .37527 .48513 .38023 Mtetra
.48513 .38023 .49165 .37527 .50309 .36956 .49665 .37495 Mtetra
.49665 .37495 .50309 .36956 .51457 .36375 .50821 .36891 Mtetra
.50821 .36891 .51457 .36375 .52609 .35844 .5198 .36243 Mtetra
.5198 .36243 .52609 .35844 .53764 .35379 .53143 .35583 Mtetra
.447 .87 .751 r
.53143 .35583 .53764 .35379 .54925 .34999 .54309 .34966 Mtetra
.595 .945 .916 r
.54309 .34966 .54925 .34999 .56091 .34669 .55478 .34388 Mtetra
.681 .92 .973 r
.55478 .34388 .56091 .34669 .57262 .34328 .56652 .33832 Mtetra
.707 .853 .952 r
.56652 .33832 .57262 .34328 .58438 .33949 .57829 .33275 Mtetra
.72 .797 .912 r
.57829 .33275 .58438 .33949 .59618 .33498 .59009 .32678 Mtetra
.723 .756 .879 r
.59009 .32678 .59618 .33498 .60801 .32979 .60192 .3204 Mtetra
.724 .727 .852 r
.60192 .3204 .60801 .32979 .61986 .32405 .61377 .3136 Mtetra
.722 .703 .832 r
.61377 .3136 .61986 .32405 .63173 .31784 .62565 .30649 Mtetra
.718 .684 .817 r
.62565 .30649 .63173 .31784 .64362 .31129 .63754 .29921 Mtetra
.714 .67 .806 r
.63754 .29921 .64362 .31129 .65554 .30446 .64946 .29185 Mtetra
.709 .659 .799 r
.64946 .29185 .65554 .30446 .66748 .29741 .6614 .28453 Mtetra
.705 .653 .796 r
.6614 .28453 .66748 .29741 .67944 .29024 .67338 .2773 Mtetra
.701 .651 .797 r
.67338 .2773 .67944 .29024 .69142 .28302 .6854 .27025 Mtetra
.698 .653 .802 r
.6854 .27025 .69142 .28302 .70344 .27581 .69746 .26341 Mtetra
.695 .659 .81 r
.69746 .26341 .70344 .27581 .71549 .2687 .70957 .25683 Mtetra
.693 .668 .821 r
.70957 .25683 .71549 .2687 .72758 .26171 .72172 .25051 Mtetra
.692 .681 .835 r
.72172 .25051 .72758 .26171 .73971 .25489 .73394 .24445 Mtetra
.692 .698 .851 r
.73394 .24445 .73971 .25489 .75189 .24822 .74621 .23858 Mtetra
.693 .718 .869 r
.74621 .23858 .75189 .24822 .76411 .24166 .75853 .23286 Mtetra
.694 .742 .888 r
.75853 .23286 .76411 .24166 .77637 .23521 .7709 .22725 Mtetra
.655 .751 .921 r
.1101 .44736 .11732 .45366 .12701 .45149 .11996 .44395 Mtetra
.65 .713 .893 r
.11996 .44395 .12701 .45149 .13673 .44942 .12984 .44061 Mtetra
.641 .676 .868 r
.12984 .44061 .13673 .44942 .14647 .4475 .13975 .43741 Mtetra
.63 .643 .844 r
.13975 .43741 .14647 .4475 .15624 .44579 .14967 .4344 Mtetra
.618 .612 .823 r
.14967 .4344 .15624 .44579 .16603 .44433 .1596 .43167 Mtetra
.605 .585 .804 r
.1596 .43167 .16603 .44433 .17584 .44312 .16954 .42923 Mtetra
.593 .56 .787 r
.16954 .42923 .17584 .44312 .18567 .44218 .17949 .42712 Mtetra
.582 .539 .773 r
.17949 .42712 .18567 .44218 .19554 .44145 .18945 .42532 Mtetra
.572 .521 .76 r
.18945 .42532 .19554 .44145 .20544 .44092 .19943 .42384 Mtetra
.564 .507 .75 r
.19943 .42384 .20544 .44092 .21539 .44048 .20944 .42259 Mtetra
.559 .496 .742 r
.20944 .42259 .21539 .44048 .22539 .44009 .21949 .42154 Mtetra
.556 .489 .735 r
.21949 .42154 .22539 .44009 .23546 .43965 .22958 .42058 Mtetra
.556 .484 .73 r
.22958 .42058 .23546 .43965 .2456 .43904 .23973 .41962 Mtetra
.556 .482 .727 r
.23973 .41962 .2456 .43904 .25582 .43815 .24994 .41861 Mtetra
.559 .483 .727 r
.24994 .41861 .25582 .43815 .26613 .43686 .26021 .41749 Mtetra
.558 .485 .729 r
.26021 .41749 .26613 .43686 .27653 .43518 .27054 .4164 Mtetra
.556 .489 .736 r
.27054 .4164 .27653 .43518 .28701 .43312 .28092 .4154 Mtetra
.551 .497 .748 r
.28092 .4154 .28701 .43312 .29754 .43105 .29134 .41464 Mtetra
.544 .507 .766 r
.29134 .41464 .29754 .43105 .30811 .42921 .3018 .41415 Mtetra
.547 .527 .785 r
.3018 .41415 .30811 .42921 .3187 .42776 .31234 .41353 Mtetra
.559 .546 .797 r
.31234 .41353 .3187 .42776 .32933 .42674 .32296 .41248 Mtetra
.585 .56 .793 r
.32296 .41248 .32933 .42674 .34002 .42562 .3337 .4105 Mtetra
.613 .564 .775 r
.3337 .4105 .34002 .42562 .3508 .42407 .34456 .40732 Mtetra
.627 .553 .752 r
.34456 .40732 .3508 .42407 .36167 .42178 .35552 .4032 Mtetra
.633 .54 .731 r
.35552 .4032 .36167 .42178 .37264 .4186 .36656 .39833 Mtetra
.63 .525 .716 r
.36656 .39833 .37264 .4186 .38368 .41481 .37764 .3932 Mtetra
.624 .512 .706 r
.37764 .3932 .38368 .41481 .39479 .41061 .38876 .38816 Mtetra
.616 .503 .701 r
.38876 .38816 .39479 .41061 .40593 .40636 .3999 .38342 Mtetra
.608 .495 .699 r
.3999 .38342 .40593 .40636 .41712 .40228 .41107 .37912 Mtetra
.6 .489 .698 r
.41107 .37912 .41712 .40228 .42834 .39851 .42226 .3753 Mtetra
.592 .484 .699 r
.42226 .3753 .42834 .39851 .43959 .39503 .43349 .37196 Mtetra
.585 .48 .701 r
.43349 .37196 .43959 .39503 .4509 .39173 .44475 .36906 Mtetra
.581 .48 .705 r
.44475 .36906 .4509 .39173 .46225 .38838 .45606 .36647 Mtetra
.581 .486 .712 r
.45606 .36647 .46225 .38838 .47366 .38461 .46743 .36397 Mtetra
.587 .499 .722 r
.46743 .36397 .47366 .38461 .48513 .38023 .47885 .36122 Mtetra
.605 .524 .736 r
.47885 .36122 .48513 .38023 .49665 .37495 .49035 .35771 Mtetra
.629 .554 .752 r
.49035 .35771 .49665 .37495 .50821 .36891 .5019 .35324 Mtetra
.659 .588 .764 r
.5019 .35324 .50821 .36891 .5198 .36243 .51349 .34756 Mtetra
.681 .609 .769 r
.51349 .34756 .5198 .36243 .53143 .35583 .52513 .34092 Mtetra
.688 .613 .767 r
.52513 .34092 .53143 .35583 .54309 .34966 .53679 .33383 Mtetra
.685 .601 .756 r
.53679 .33383 .54309 .34966 .55478 .34388 .54848 .3266 Mtetra
.671 .579 .743 r
.54848 .3266 .55478 .34388 .56652 .33832 .5602 .31963 Mtetra
.66 .56 .731 r
.5602 .31963 .56652 .33832 .57829 .33275 .57195 .31289 Mtetra
.653 .546 .721 r
.57195 .31289 .57829 .33275 .59009 .32678 .58373 .30624 Mtetra
.649 .539 .716 r
.58373 .30624 .59009 .32678 .60192 .3204 .59554 .2996 Mtetra
.65 .538 .714 r
.59554 .2996 .60192 .3204 .61377 .3136 .60738 .29284 Mtetra
.651 .539 .714 r
.60738 .29284 .61377 .3136 .62565 .30649 .61925 .28602 Mtetra
.652 .542 .717 r
.61925 .28602 .62565 .30649 .63754 .29921 .63115 .27919 Mtetra
.653 .546 .721 r
.63115 .27919 .63754 .29921 .64946 .29185 .64309 .27244 Mtetra
.653 .551 .727 r
.64309 .27244 .64946 .29185 .6614 .28453 .65506 .26588 Mtetra
.653 .558 .735 r
.65506 .26588 .6614 .28453 .67338 .2773 .66708 .25955 Mtetra
.652 .566 .745 r
.66708 .25955 .67338 .2773 .6854 .27025 .67916 .25354 Mtetra
.651 .577 .758 r
.67916 .25354 .6854 .27025 .69746 .26341 .69128 .24784 Mtetra
.651 .591 .774 r
.69128 .24784 .69746 .26341 .70957 .25683 .70347 .24248 Mtetra
.651 .607 .792 r
.70347 .24248 .70957 .25683 .72172 .25051 .71572 .23742 Mtetra
.651 .628 .814 r
.71572 .23742 .72172 .25051 .73394 .24445 .72804 .23263 Mtetra
.652 .652 .838 r
.72804 .23263 .73394 .24445 .74621 .23858 .74043 .22805 Mtetra
.653 .681 .864 r
.74043 .22805 .74621 .23858 .75853 .23286 .75288 .2236 Mtetra
.655 .714 .892 r
.75288 .2236 .75853 .23286 .7709 .22725 .76539 .21923 Mtetra
.702 .761 .898 r
.10283 .44102 .1101 .44736 .11996 .44395 .11287 .43629 Mtetra
.694 .722 .872 r
.11287 .43629 .11996 .44395 .12984 .44061 .12294 .43159 Mtetra
.682 .686 .847 r
.12294 .43159 .12984 .44061 .13975 .43741 .13302 .42699 Mtetra
.67 .653 .824 r
.13302 .42699 .13975 .43741 .14967 .4344 .14312 .42253 Mtetra
.656 .621 .803 r
.14312 .42253 .14967 .4344 .1596 .43167 .15322 .41829 Mtetra
.642 .592 .783 r
.15322 .41829 .1596 .43167 .16954 .42923 .16333 .41431 Mtetra
.628 .566 .765 r
.16333 .41431 .16954 .42923 .17949 .42712 .17344 .41062 Mtetra
.615 .541 .749 r
.17344 .41062 .17949 .42712 .18945 .42532 .18356 .40725 Mtetra
.602 .52 .733 r
.18356 .40725 .18945 .42532 .19943 .42384 .19368 .4042 Mtetra
.592 .501 .72 r
.19368 .4042 .19943 .42384 .20944 .42259 .20382 .40145 Mtetra
.584 .485 .708 r
.20382 .40145 .20944 .42259 .21949 .42154 .21397 .39895 Mtetra
.577 .471 .697 r
.21397 .39895 .21949 .42154 .22958 .42058 .22415 .39667 Mtetra
.572 .461 .689 r
.22415 .39667 .22958 .42058 .23973 .41962 .23437 .39455 Mtetra
.567 .452 .681 r
.23437 .39455 .23973 .41962 .24994 .41861 .24462 .39257 Mtetra
.564 .445 .676 r
.24462 .39257 .24994 .41861 .26021 .41749 .25491 .39073 Mtetra
.56 .439 .672 r
.25491 .39073 .26021 .41749 .27054 .4164 .26524 .38907 Mtetra
.556 .434 .67 r
.26524 .38907 .27054 .4164 .28092 .4154 .27561 .38763 Mtetra
.553 .431 .668 r
.27561 .38763 .28092 .4154 .29134 .41464 .28602 .38631 Mtetra
.553 .429 .665 r
.28602 .38631 .29134 .41464 .3018 .41415 .29649 .38497 Mtetra
.559 .43 .661 r
.29649 .38497 .3018 .41415 .31234 .41353 .30705 .38316 Mtetra
.568 .432 .656 r
.30705 .38316 .31234 .41353 .32296 .41248 .31771 .3806 Mtetra
.577 .433 .649 r
.31771 .3806 .32296 .41248 .3337 .4105 .32848 .3772 Mtetra
.585 .434 .644 r
.32848 .3772 .3337 .4105 .34456 .40732 .33934 .37295 Mtetra
.587 .433 .64 r
.33934 .37295 .34456 .40732 .35552 .4032 .35026 .36831 Mtetra
.587 .432 .638 r
.35026 .36831 .35552 .4032 .36656 .39833 .36122 .36357 Mtetra
.586 .432 .639 r
.36122 .36357 .36656 .39833 .37764 .3932 .37222 .35898 Mtetra
.583 .431 .641 r
.37222 .35898 .37764 .3932 .38876 .38816 .38324 .35468 Mtetra
.582 .433 .644 r
.38324 .35468 .38876 .38816 .3999 .38342 .3943 .35057 Mtetra
.581 .434 .647 r
.3943 .35057 .3999 .38342 .41107 .37912 .40539 .34662 Mtetra
.581 .435 .648 r
.40539 .34662 .41107 .37912 .42226 .3753 .41652 .34275 Mtetra
.58 .434 .648 r
.41652 .34275 .42226 .3753 .43349 .37196 .4277 .33895 Mtetra
.577 .431 .647 r
.4277 .33895 .43349 .37196 .44475 .36906 .43892 .33532 Mtetra
.574 .427 .644 r
.43892 .33532 .44475 .36906 .45606 .36647 .45018 .33188 Mtetra
.569 .422 .641 r
.45018 .33188 .45606 .36647 .46743 .36397 .46149 .32873 Mtetra
.566 .418 .639 r
.46149 .32873 .46743 .36397 .47885 .36122 .47285 .32574 Mtetra
.567 .418 .639 r
.47285 .32574 .47885 .36122 .49035 .35771 .48427 .32264 Mtetra
.572 .423 .64 r
.48427 .32264 .49035 .35771 .5019 .35324 .49574 .31915 Mtetra
.583 .433 .644 r
.49574 .31915 .5019 .35324 .51349 .34756 .50727 .31481 Mtetra
.594 .445 .648 r
.50727 .31481 .51349 .34756 .52513 .34092 .51884 .3096 Mtetra
.606 .457 .654 r
.51884 .3096 .52513 .34092 .53679 .33383 .53046 .30362 Mtetra
.614 .467 .658 r
.53046 .30362 .53679 .33383 .54848 .3266 .5421 .29716 Mtetra
.616 .471 .662 r
.5421 .29716 .54848 .3266 .5602 .31963 .55378 .29067 Mtetra
.616 .473 .664 r
.55378 .29067 .5602 .31963 .57195 .31289 .56549 .28429 Mtetra
.614 .473 .666 r
.56549 .28429 .57195 .31289 .58373 .30624 .57724 .27812 Mtetra
.613 .475 .669 r
.57724 .27812 .58373 .30624 .59554 .2996 .58903 .27214 Mtetra
.613 .478 .673 r
.58903 .27214 .59554 .2996 .60738 .29284 .60086 .26628 Mtetra
.614 .482 .678 r
.60086 .26628 .60738 .29284 .61925 .28602 .61272 .26057 Mtetra
.615 .488 .685 r
.61272 .26057 .61925 .28602 .63115 .27919 .62464 .25501 Mtetra
.616 .496 .693 r
.62464 .25501 .63115 .27919 .64309 .27244 .6366 .24966 Mtetra
.616 .505 .704 r
.6366 .24966 .64309 .27244 .65506 .26588 .64861 .24458 Mtetra
.617 .516 .716 r
.64861 .24458 .65506 .26588 .66708 .25955 .66069 .23979 Mtetra
.616 .528 .731 r
.66069 .23979 .66708 .25955 .67916 .25354 .67283 .23534 Mtetra
.616 .542 .748 r
.67283 .23534 .67916 .25354 .69128 .24784 .68503 .2312 Mtetra
.615 .559 .768 r
.68503 .2312 .69128 .24784 .70347 .24248 .69731 .22737 Mtetra
.614 .578 .79 r
.69731 .22737 .70347 .24248 .71572 .23742 .70967 .22381 Mtetra
.613 .601 .814 r
.70967 .22381 .71572 .23742 .72804 .23263 .7221 .22047 Mtetra
.612 .627 .841 r
.7221 .22047 .72804 .23263 .74043 .22805 .7346 .21728 Mtetra
.611 .657 .87 r
.7346 .21728 .74043 .22805 .75288 .2236 .74718 .21419 Mtetra
.61 .691 .901 r
.74718 .21419 .75288 .2236 .76539 .21923 .75983 .21113 Mtetra
.734 .766 .879 r
.09551 .43462 .10283 .44102 .11287 .43629 .10571 .42877 Mtetra
.725 .734 .858 r
.10571 .42877 .11287 .43629 .12294 .43159 .11594 .4229 Mtetra
.715 .704 .839 r
.11594 .4229 .12294 .43159 .13302 .42699 .12619 .41706 Mtetra
.703 .675 .82 r
.12619 .41706 .13302 .42699 .14312 .42253 .13646 .41131 Mtetra
.691 .648 .802 r
.13646 .41131 .14312 .42253 .15322 .41829 .14673 .40568 Mtetra
.678 .621 .784 r
.14673 .40568 .15322 .41829 .16333 .41431 .15701 .40022 Mtetra
.664 .595 .767 r
.15701 .40022 .16333 .41431 .17344 .41062 .1673 .39497 Mtetra
.651 .57 .751 r
.1673 .39497 .17344 .41062 .18356 .40725 .17758 .38997 Mtetra
.637 .547 .736 r
.17758 .38997 .18356 .40725 .19368 .4042 .18787 .38525 Mtetra
.625 .526 .721 r
.18787 .38525 .19368 .4042 .20382 .40145 .19816 .3808 Mtetra
.614 .507 .708 r
.19816 .3808 .20382 .40145 .21397 .39895 .20845 .37664 Mtetra
.604 .49 .697 r
.20845 .37664 .21397 .39895 .22415 .39667 .21876 .37275 Mtetra
.595 .476 .686 r
.21876 .37275 .22415 .39667 .23437 .39455 .22907 .36913 Mtetra
.588 .463 .678 r
.22907 .36913 .23437 .39455 .24462 .39257 .23941 .36579 Mtetra
.581 .452 .67 r
.23941 .36579 .24462 .39257 .25491 .39073 .24976 .36271 Mtetra
.575 .444 .664 r
.24976 .36271 .25491 .39073 .26524 .38907 .26014 .35983 Mtetra
.571 .437 .659 r
.26014 .35983 .26524 .38907 .27561 .38763 .27055 .3571 Mtetra
.571 .432 .653 r
.27055 .3571 .27561 .38763 .28602 .38631 .28103 .35422 Mtetra
.573 .429 .647 r
.28103 .35422 .28602 .38631 .29649 .38497 .29157 .351 Mtetra
.577 .426 .64 r
.29157 .351 .29649 .38497 .30705 .38316 .3022 .34724 Mtetra
.581 .424 .633 r
.3022 .34724 .30705 .38316 .31771 .3806 .31291 .34283 Mtetra
.581 .42 .627 r
.31291 .34283 .31771 .3806 .32848 .3772 .32368 .33817 Mtetra
.579 .416 .624 r
.32368 .33817 .32848 .3772 .33934 .37295 .33449 .33351 Mtetra
.575 .411 .623 r
.33449 .33351 .33934 .37295 .35026 .36831 .34531 .32925 Mtetra
.569 .408 .624 r
.34531 .32925 .35026 .36831 .36122 .36357 .35613 .32558 Mtetra
.566 .408 .627 r
.35613 .32558 .36122 .36357 .37222 .35898 .36698 .32234 Mtetra
.564 .411 .632 r
.36698 .32234 .37222 .35898 .38324 .35468 .37787 .31936 Mtetra
.567 .416 .636 r
.37787 .31936 .38324 .35468 .3943 .35057 .38881 .31626 Mtetra
.572 .423 .64 r
.38881 .31626 .3943 .35057 .40539 .34662 .39982 .31284 Mtetra
.578 .429 .642 r
.39982 .31284 .40539 .34662 .41652 .34275 .41089 .30891 Mtetra
.584 .432 .642 r
.41089 .30891 .41652 .34275 .4277 .33895 .42202 .30449 Mtetra
.586 .433 .64 r
.42202 .30449 .4277 .33895 .43892 .33532 .43321 .29973 Mtetra
.586 .429 .636 r
.43321 .29973 .43892 .33532 .45018 .33188 .44443 .29486 Mtetra
.58 .422 .631 r
.44443 .29486 .45018 .33188 .46149 .32873 .4557 .29024 Mtetra
.574 .414 .627 r
.4557 .29024 .46149 .32873 .47285 .32574 .46699 .28606 Mtetra
.567 .407 .624 r
.46699 .28606 .47285 .32574 .48427 .32264 .47833 .28246 Mtetra
.562 .402 .623 r
.47833 .28246 .48427 .32264 .49574 .31915 .4897 .27928 Mtetra
.562 .403 .624 r
.4897 .27928 .49574 .31915 .50727 .31481 .50114 .2761 Mtetra
.566 .409 .627 r
.50114 .2761 .50727 .31481 .51884 .3096 .51262 .27265 Mtetra
.575 .419 .633 r
.51262 .27265 .51884 .3096 .53046 .30362 .52416 .26856 Mtetra
.583 .43 .639 r
.52416 .26856 .53046 .30362 .5421 .29716 .53575 .26391 Mtetra
.59 .44 .646 r
.53575 .26391 .5421 .29716 .55378 .29067 .54738 .2589 Mtetra
.594 .448 .652 r
.54738 .2589 .55378 .29067 .56549 .28429 .55905 .25375 Mtetra
.595 .453 .657 r
.55905 .25375 .56549 .28429 .57724 .27812 .57077 .24874 Mtetra
.595 .457 .663 r
.57077 .24874 .57724 .27812 .58903 .27214 .58253 .24392 Mtetra
.594 .461 .67 r
.58253 .24392 .58903 .27214 .60086 .26628 .59434 .23938 Mtetra
.593 .467 .677 r
.59434 .23938 .60086 .26628 .61272 .26057 .60621 .23511 Mtetra
.593 .474 .687 r
.60621 .23511 .61272 .26057 .62464 .25501 .61814 .23112 Mtetra
.592 .483 .698 r
.61814 .23112 .62464 .25501 .6366 .24966 .63013 .22741 Mtetra
.591 .493 .711 r
.63013 .22741 .6366 .24966 .64861 .24458 .64219 .22399 Mtetra
.59 .505 .727 r
.64219 .22399 .64861 .24458 .66069 .23979 .65433 .22086 Mtetra
.588 .519 .744 r
.65433 .22086 .66069 .23979 .67283 .23534 .66653 .21801 Mtetra
.587 .535 .764 r
.66653 .21801 .67283 .23534 .68503 .2312 .67882 .21542 Mtetra
.584 .553 .785 r
.67882 .21542 .68503 .2312 .69731 .22737 .69118 .21305 Mtetra
.582 .573 .808 r
.69118 .21305 .69731 .22737 .70967 .22381 .70363 .21087 Mtetra
.579 .595 .833 r
.70363 .21087 .70967 .22381 .7221 .22047 .71616 .20881 Mtetra
.575 .619 .859 r
.71616 .20881 .7221 .22047 .7346 .21728 .72877 .20684 Mtetra
.571 .646 .886 r
.72877 .20684 .7346 .21728 .74718 .21419 .74146 .20491 Mtetra
.566 .675 .913 r
.74146 .20491 .74718 .21419 .75983 .21113 .75422 .20298 Mtetra
.747 .767 .869 r
.08813 .42819 .09551 .43462 .10571 .42877 .09844 .42175 Mtetra
.743 .752 .859 r
.09844 .42175 .10571 .42877 .11594 .4229 .10877 .41527 Mtetra
.738 .736 .849 r
.10877 .41527 .11594 .4229 .12619 .41706 .11912 .40877 Mtetra
.732 .719 .839 r
.11912 .40877 .12619 .41706 .13646 .41131 .1295 .40229 Mtetra
.725 .702 .828 r
.1295 .40229 .13646 .41131 .14673 .40568 .13989 .39583 Mtetra
.717 .683 .817 r
.13989 .39583 .14673 .40568 .15701 .40022 .15029 .38946 Mtetra
.707 .663 .805 r
.15029 .38946 .15701 .40022 .1673 .39497 .1607 .38321 Mtetra
.696 .643 .793 r
.1607 .38321 .1673 .39497 .17758 .38997 .17111 .37712 Mtetra
.684 .622 .78 r
.17111 .37712 .17758 .38997 .18787 .38525 .18152 .37124 Mtetra
.672 .601 .768 r
.18152 .37124 .18787 .38525 .19816 .3808 .19194 .36557 Mtetra
.66 .581 .755 r
.19194 .36557 .19816 .3808 .20845 .37664 .20236 .36015 Mtetra
.648 .562 .743 r
.20236 .36015 .20845 .37664 .21876 .37275 .21278 .35499 Mtetra
.637 .544 .732 r
.21278 .35499 .21876 .37275 .22907 .36913 .22321 .35008 Mtetra
.627 .527 .721 r
.22321 .35008 .22907 .36913 .23941 .36579 .23364 .34542 Mtetra
.619 .512 .711 r
.23364 .34542 .23941 .36579 .24976 .36271 .24409 .34099 Mtetra
.612 .499 .701 r
.24409 .34099 .24976 .36271 .26014 .35983 .25457 .33666 Mtetra
.607 .488 .691 r
.25457 .33666 .26014 .35983 .27055 .3571 .26508 .33237 Mtetra
.604 .478 .681 r
.26508 .33237 .27055 .3571 .28103 .35422 .27564 .32793 Mtetra
.604 .47 .672 r
.27564 .32793 .28103 .35422 .29157 .351 .28626 .32324 Mtetra
.602 .463 .665 r
.28626 .32324 .29157 .351 .3022 .34724 .29692 .31837 Mtetra
.6 .458 .659 r
.29692 .31837 .3022 .34724 .31291 .34283 .30762 .31345 Mtetra
.594 .452 .657 r
.30762 .31345 .31291 .34283 .32368 .33817 .31833 .30891 Mtetra
.585 .447 .659 r
.31833 .30891 .32368 .33817 .33449 .33351 .32904 .30502 Mtetra
.577 .444 .663 r
.32904 .30502 .33449 .33351 .34531 .32925 .33975 .30187 Mtetra
.568 .443 .669 r
.33975 .30187 .34531 .32925 .35613 .32558 .35047 .29941 Mtetra
.565 .447 .677 r
.35047 .29941 .35613 .32558 .36698 .32234 .36122 .29724 Mtetra
.567 .454 .684 r
.36122 .29724 .36698 .32234 .37787 .31936 .37203 .29507 Mtetra
.575 .464 .689 r
.37203 .29507 .37787 .31936 .38881 .31626 .38292 .29249 Mtetra
.586 .474 .693 r
.38292 .29249 .38881 .31626 .39982 .31284 .39388 .28928 Mtetra
.599 .484 .693 r
.39388 .28928 .39982 .31284 .41089 .30891 .40492 .28532 Mtetra
.61 .491 .692 r
.40492 .28532 .41089 .30891 .42202 .30449 .41604 .28059 Mtetra
.618 .494 .689 r
.41604 .28059 .42202 .30449 .43321 .29973 .42721 .27522 Mtetra
.622 .493 .685 r
.42721 .27522 .43321 .29973 .44443 .29486 .43844 .26945 Mtetra
.619 .487 .68 r
.43844 .26945 .44443 .29486 .4557 .29024 .44969 .26367 Mtetra
.611 .477 .674 r
.44969 .26367 .4557 .29024 .46699 .28606 .46098 .25817 Mtetra
.599 .463 .668 r
.46098 .25817 .46699 .28606 .47833 .28246 .47228 .25337 Mtetra
.586 .45 .663 r
.47228 .25337 .47833 .28246 .4897 .27928 .48362 .24931 Mtetra
.576 .44 .659 r
.48362 .24931 .4897 .27928 .50114 .2761 .495 .2459 Mtetra
.571 .436 .659 r
.495 .2459 .50114 .2761 .51262 .27265 .50643 .24289 Mtetra
.572 .439 .661 r
.50643 .24289 .51262 .27265 .52416 .26856 .51792 .23982 Mtetra
.576 .446 .666 r
.51792 .23982 .52416 .26856 .53575 .26391 .52946 .23658 Mtetra
.582 .456 .674 r
.52946 .23658 .53575 .26391 .54738 .2589 .54106 .23308 Mtetra
.587 .467 .683 r
.54106 .23308 .54738 .2589 .55905 .25375 .55271 .22942 Mtetra
.59 .477 .693 r
.55271 .22942 .55905 .25375 .57077 .24874 .56441 .2258 Mtetra
.591 .486 .704 r
.56441 .2258 .57077 .24874 .58253 .24392 .57617 .2223 Mtetra
.59 .495 .715 r
.57617 .2223 .58253 .24392 .59434 .23938 .588 .21902 Mtetra
.588 .504 .727 r
.588 .21902 .59434 .23938 .60621 .23511 .59988 .21599 Mtetra
.586 .514 .74 r
.59988 .21599 .60621 .23511 .61814 .23112 .61184 .21323 Mtetra
.583 .525 .755 r
.61184 .21323 .61814 .23112 .63013 .22741 .62386 .21074 Mtetra
.579 .537 .772 r
.62386 .21074 .63013 .22741 .64219 .22399 .63596 .2085 Mtetra
.575 .55 .789 r
.63596 .2085 .64219 .22399 .65433 .22086 .64815 .2065 Mtetra
.571 .565 .808 r
.64815 .2065 .65433 .22086 .66653 .21801 .66041 .20471 Mtetra
.566 .58 .827 r
.66041 .20471 .66653 .21801 .67882 .21542 .67275 .20309 Mtetra
.56 .597 .847 r
.67275 .20309 .67882 .21542 .69118 .21305 .68518 .2016 Mtetra
.555 .613 .865 r
.68518 .2016 .69118 .21305 .70363 .21087 .6977 .2002 Mtetra
.551 .63 .883 r
.6977 .2002 .70363 .21087 .71616 .20881 .71029 .19884 Mtetra
.546 .646 .9 r
.71029 .19884 .71616 .20881 .72877 .20684 .72297 .1975 Mtetra
.542 .662 .915 r
.72297 .1975 .72877 .20684 .74146 .20491 .73573 .19615 Mtetra
.538 .678 .929 r
.73573 .19615 .74146 .20491 .75422 .20298 .74857 .19475 Mtetra
.747 .767 .869 r
.0807 .4217 .08813 .42819 .09844 .42175 .09104 .41524 Mtetra
.748 .767 .869 r
.09104 .41524 .09844 .42175 .10877 .41527 .1014 .40871 Mtetra
.749 .767 .868 r
.1014 .40871 .10877 .41527 .11912 .40877 .11179 .40213 Mtetra
.749 .765 .866 r
.11179 .40213 .11912 .40877 .1295 .40229 .12221 .39549 Mtetra
.749 .762 .863 r
.12221 .39549 .1295 .40229 .13989 .39583 .13265 .3888 Mtetra
.747 .756 .86 r
.13265 .3888 .13989 .39583 .15029 .38946 .14312 .38211 Mtetra
.744 .748 .856 r
.14312 .38211 .15029 .38946 .1607 .38321 .1536 .37545 Mtetra
.739 .737 .85 r
.1536 .37545 .1607 .38321 .17111 .37712 .16409 .36885 Mtetra
.732 .724 .844 r
.16409 .36885 .17111 .37712 .18152 .37124 .17459 .36237 Mtetra
.724 .709 .836 r
.17459 .36237 .18152 .37124 .19194 .36557 .1851 .35603 Mtetra
.714 .693 .828 r
.1851 .35603 .19194 .36557 .20236 .36015 .19561 .34987 Mtetra
.704 .675 .819 r
.19561 .34987 .20236 .36015 .21278 .35499 .20613 .34389 Mtetra
.694 .657 .809 r
.20613 .34389 .21278 .35499 .22321 .35008 .21665 .3381 Mtetra
.684 .638 .797 r
.21665 .3381 .22321 .35008 .23364 .34542 .22719 .33244 Mtetra
.675 .619 .785 r
.22719 .33244 .23364 .34542 .24409 .34099 .23775 .32689 Mtetra
.668 .601 .771 r
.23775 .32689 .24409 .34099 .25457 .33666 .24833 .32136 Mtetra
.661 .583 .757 r
.24833 .32136 .25457 .33666 .26508 .33237 .25895 .31577 Mtetra
.655 .566 .743 r
.25895 .31577 .26508 .33237 .27564 .32793 .2696 .31015 Mtetra
.649 .552 .731 r
.2696 .31015 .27564 .32793 .28626 .32324 .28028 .30452 Mtetra
.639 .538 .724 r
.28028 .30452 .28626 .32324 .29692 .31837 .29096 .2992 Mtetra
.627 .528 .722 r
.29096 .2992 .29692 .31837 .30762 .31345 .30164 .29443 Mtetra
.613 .521 .727 r
.30164 .29443 .30762 .31345 .31833 .30891 .3123 .29049 Mtetra
.596 .517 .736 r
.3123 .29049 .31833 .30891 .32904 .30502 .32293 .28749 Mtetra
.583 .518 .748 r
.32293 .28749 .32904 .30502 .33975 .30187 .33358 .28517 Mtetra
.574 .523 .76 r
.33358 .28517 .33975 .30187 .35047 .29941 .34425 .28328 Mtetra
.576 .531 .768 r
.34425 .28328 .35047 .29941 .36122 .29724 .35498 .28138 Mtetra
.584 .539 .771 r
.35498 .28138 .36122 .29724 .37203 .29507 .36579 .27917 Mtetra
.596 .546 .769 r
.36579 .27917 .37203 .29507 .38292 .29249 .37667 .27645 Mtetra
.61 .552 .765 r
.37667 .27645 .38292 .29249 .39388 .28928 .38764 .2731 Mtetra
.623 .558 .761 r
.38764 .2731 .39388 .28928 .40492 .28532 .39868 .2691 Mtetra
.636 .566 .758 r
.39868 .2691 .40492 .28532 .41604 .28059 .40979 .26444 Mtetra
.649 .573 .756 r
.40979 .26444 .41604 .28059 .42721 .27522 .42096 .25914 Mtetra
.659 .58 .755 r
.42096 .25914 .42721 .27522 .43844 .26945 .43218 .25333 Mtetra
.664 .582 .754 r
.43218 .25333 .43844 .26945 .44969 .26367 .44345 .2472 Mtetra
.662 .578 .75 r
.44345 .2472 .44969 .26367 .46098 .25817 .45475 .24105 Mtetra
.651 .566 .746 r
.45475 .24105 .46098 .25817 .47228 .25337 .46607 .23534 Mtetra
.634 .548 .739 r
.46607 .23534 .47228 .25337 .48362 .24931 .47741 .2303 Mtetra
.613 .527 .733 r
.47741 .2303 .48362 .24931 .495 .2459 .48879 .22622 Mtetra
.595 .51 .729 r
.48879 .22622 .495 .2459 .50643 .24289 .50021 .22297 Mtetra
.583 .502 .729 r
.50021 .22297 .50643 .24289 .51792 .23982 .51167 .22028 Mtetra
.577 .502 .734 r
.51167 .22028 .51792 .23982 .52946 .23658 .5232 .21791 Mtetra
.579 .512 .743 r
.5232 .21791 .52946 .23658 .54106 .23308 .53479 .21553 Mtetra
.582 .525 .757 r
.53479 .21553 .54106 .23308 .55271 .22942 .54644 .21313 Mtetra
.585 .542 .773 r
.54644 .21313 .55271 .22942 .56441 .2258 .55816 .21067 Mtetra
.587 .559 .79 r
.55816 .21067 .56441 .2258 .57617 .2223 .56994 .20823 Mtetra
.586 .575 .807 r
.56994 .20823 .57617 .2223 .588 .21902 .58179 .2059 Mtetra
.583 .589 .825 r
.58179 .2059 .588 .21902 .59988 .21599 .5937 .20372 Mtetra
.577 .603 .842 r
.5937 .20372 .59988 .21599 .61184 .21323 .60569 .20173 Mtetra
.57 .616 .859 r
.60569 .20173 .61184 .21323 .62386 .21074 .61776 .19993 Mtetra
.561 .628 .876 r
.61776 .19993 .62386 .21074 .63596 .2085 .6299 .19833 Mtetra
.553 .64 .891 r
.6299 .19833 .63596 .2085 .64815 .2065 .64213 .19687 Mtetra
.544 .651 .905 r
.64213 .19687 .64815 .2065 .66041 .20471 .65444 .19554 Mtetra
.537 .662 .917 r
.65444 .19554 .66041 .20471 .67275 .20309 .66683 .19428 Mtetra
.532 .671 .926 r
.66683 .19428 .67275 .20309 .68518 .2016 .6793 .19306 Mtetra
.528 .678 .933 r
.6793 .19306 .68518 .2016 .6977 .2002 .69186 .19184 Mtetra
.528 .684 .938 r
.69186 .19184 .6977 .2002 .71029 .19884 .70449 .19057 Mtetra
.528 .688 .94 r
.70449 .19057 .71029 .19884 .72297 .1975 .71721 .18926 Mtetra
.53 .691 .942 r
.71721 .18926 .72297 .1975 .73573 .19615 .73 .1879 Mtetra
.532 .693 .942 r
.73 .1879 .73573 .19615 .74857 .19475 .74288 .18646 Mtetra
.73 .765 .881 r
.07322 .41517 .0807 .4217 .09104 .41524 .08349 .40936 Mtetra
.736 .786 .892 r
.08349 .40936 .09104 .41524 .1014 .40871 .0938 .40347 Mtetra
.742 .807 .904 r
.0938 .40347 .1014 .40871 .11179 .40213 .10414 .39749 Mtetra
.748 .828 .914 r
.10414 .39749 .11179 .40213 .12221 .39549 .11452 .39142 Mtetra
.753 .848 .922 r
.11452 .39142 .12221 .39549 .13265 .3888 .12493 .38524 Mtetra
.755 .867 .93 r
.12493 .38524 .13265 .3888 .14312 .38211 .13538 .379 Mtetra
.757 .883 .936 r
.13538 .379 .14312 .38211 .1536 .37545 .14585 .3727 Mtetra
.755 .896 .941 r
.14585 .3727 .1536 .37545 .16409 .36885 .15635 .3664 Mtetra
.752 .906 .945 r
.15635 .3664 .16409 .36885 .17459 .36237 .16687 .36012 Mtetra
.748 .914 .948 r
.16687 .36012 .17459 .36237 .1851 .35603 .1774 .3539 Mtetra
.742 .918 .952 r
.1774 .3539 .1851 .35603 .19561 .34987 .18795 .34777 Mtetra
.736 .92 .954 r
.18795 .34777 .19561 .34987 .20613 .34389 .19852 .34174 Mtetra
.731 .919 .956 r
.19852 .34174 .20613 .34389 .21665 .3381 .2091 .33581 Mtetra
.729 .916 .957 r
.2091 .33581 .21665 .3381 .22719 .33244 .21969 .32996 Mtetra
.727 .911 .958 r
.21969 .32996 .22719 .33244 .23775 .32689 .23031 .32415 Mtetra
.728 .904 .957 r
.23031 .32415 .23775 .32689 .24833 .32136 .24096 .31837 Mtetra
.73 .897 .955 r
.24096 .31837 .24833 .32136 .25895 .31577 .25164 .31258 Mtetra
.727 .891 .955 r
.25164 .31258 .25895 .31577 .2696 .31015 .26233 .30687 Mtetra
.72 .888 .958 r
.26233 .30687 .2696 .31015 .28028 .30452 .27304 .30132 Mtetra
.7 .89 .967 r
.27304 .30132 .28028 .30452 .29096 .2992 .28376 .29616 Mtetra
.671 .89 .977 r
.28376 .29616 .29096 .2992 .30164 .29443 .29447 .2915 Mtetra
.639 .888 .986 r
.29447 .2915 .30164 .29443 .3123 .29049 .30518 .28734 Mtetra
.615 .875 .99 r
.30518 .28734 .3123 .29049 .32293 .28749 .3159 .2836 Mtetra
.625 .853 .986 r
.3159 .2836 .32293 .28749 .33358 .28517 .32666 .27994 Mtetra
.648 .812 .962 r
.32666 .27994 .33358 .28517 .34425 .28328 .33748 .27613 Mtetra
.662 .753 .917 r
.33748 .27613 .34425 .28328 .35498 .28138 .34835 .27208 Mtetra
.664 .694 .868 r
.34835 .27208 .35498 .28138 .36579 .27917 .35928 .26778 Mtetra
.654 .645 .829 r
.35928 .26778 .36579 .27917 .37667 .27645 .37026 .26344 Mtetra
.643 .612 .803 r
.37026 .26344 .37667 .27645 .38764 .2731 .38127 .25918 Mtetra
.633 .593 .792 r
.38127 .25918 .38764 .2731 .39868 .2691 .39232 .25514 Mtetra
.627 .591 .793 r
.39232 .25514 .39868 .2691 .40979 .26444 .4034 .25132 Mtetra
.629 .605 .807 r
.4034 .25132 .40979 .26444 .42096 .25914 .41453 .24758 Mtetra
.636 .637 .834 r
.41453 .24758 .42096 .25914 .43218 .25333 .4257 .24381 Mtetra
.651 .689 .873 r
.4257 .24381 .43218 .25333 .44345 .2472 .43694 .23978 Mtetra
.665 .754 .916 r
.43694 .23978 .44345 .2472 .45475 .24105 .44822 .2355 Mtetra
.667 .818 .956 r
.44822 .2355 .45475 .24105 .46607 .23534 .45956 .23109 Mtetra
.651 .86 .979 r
.45956 .23109 .46607 .23534 .47741 .2303 .47093 .22674 Mtetra
.612 .873 .991 r
.47093 .22674 .47741 .2303 .48879 .22622 .48235 .22282 Mtetra
.573 .866 .996 r
.48235 .22282 .48879 .22622 .50021 .22297 .49381 .2194 Mtetra
.54 .848 .998 r
.49381 .2194 .50021 .22297 .51167 .22028 .50533 .2165 Mtetra
.518 .832 1 r
.50533 .2165 .51167 .22028 .5232 .21791 .5169 .21399 Mtetra
.509 .824 1 r
.5169 .21399 .5232 .21791 .53479 .21553 .52853 .21165 Mtetra
.5 .821 1 r
.52853 .21165 .53479 .21553 .54644 .21313 .54023 .20939 Mtetra
.492 .823 .999 r
.54023 .20939 .54644 .21313 .55816 .21067 .55199 .20713 Mtetra
.479 .825 .998 r
.55199 .20713 .55816 .21067 .56994 .20823 .56382 .2049 Mtetra
.464 .825 .995 r
.56382 .2049 .56994 .20823 .58179 .2059 .57572 .20272 Mtetra
.448 .823 .991 r
.57572 .20272 .58179 .2059 .5937 .20372 .58768 .20062 Mtetra
.432 .818 .988 r
.58768 .20062 .5937 .20372 .60569 .20173 .59972 .19863 Mtetra
.421 .813 .987 r
.59972 .19863 .60569 .20173 .61776 .19993 .61184 .19674 Mtetra
.416 .808 .987 r
.61184 .19674 .61776 .19993 .6299 .19833 .62403 .19496 Mtetra
.418 .804 .99 r
.62403 .19496 .6299 .19833 .64213 .19687 .63629 .19324 Mtetra
.428 .801 .993 r
.63629 .19324 .64213 .19687 .65444 .19554 .64864 .19155 Mtetra
.443 .798 .997 r
.64864 .19155 .65444 .19554 .66683 .19428 .66106 .18986 Mtetra
.464 .793 .999 r
.66106 .18986 .66683 .19428 .6793 .19306 .67355 .18811 Mtetra
.486 .786 .998 r
.67355 .18811 .6793 .19306 .69186 .19184 .68612 .1863 Mtetra
.509 .776 .992 r
.68612 .1863 .69186 .19184 .70449 .19057 .69877 .18438 Mtetra
.529 .763 .983 r
.69877 .18438 .70449 .19057 .71721 .18926 .71148 .18238 Mtetra
.544 .746 .97 r
.71148 .18238 .71721 .18926 .73 .1879 .72427 .18028 Mtetra
.557 .729 .955 r
.72427 .18028 .73 .1879 .74288 .18646 .73713 .1781 Mtetra
.697 .76 .9 r
.06568 .40859 .07322 .41517 .08349 .40936 .07582 .40387 Mtetra
.704 .796 .922 r
.07582 .40387 .08349 .40936 .0938 .40347 .08601 .39907 Mtetra
.708 .834 .943 r
.08601 .39907 .0938 .40347 .10414 .39749 .09624 .39417 Mtetra
.708 .872 .959 r
.09624 .39417 .10414 .39749 .11452 .39142 .10651 .38916 Mtetra
.703 .907 .967 r
.10651 .38916 .11452 .39142 .12493 .38524 .11684 .384 Mtetra
.688 .935 .966 r
.11684 .384 .12493 .38524 .13538 .379 .1272 .37873 Mtetra
.663 .951 .952 r
.1272 .37873 .13538 .379 .14585 .3727 .13762 .37334 Mtetra
.626 .954 .923 r
.13762 .37334 .14585 .3727 .15635 .3664 .14806 .36787 Mtetra
.578 .943 .882 r
.14806 .36787 .15635 .3664 .16687 .36012 .15855 .36235 Mtetra
.523 .918 .83 r
.15855 .36235 .16687 .36012 .1774 .3539 .16906 .3568 Mtetra
.464 .883 .773 r
.16906 .3568 .1774 .3539 .18795 .34777 .1796 .35126 Mtetra
.409 .844 .716 r
.1796 .35126 .18795 .34777 .19852 .34174 .19017 .34573 Mtetra
.358 .805 .663 r
.19017 .34573 .19852 .34174 .2091 .33581 .20077 .34022 Mtetra
0 0 0 r
.20077 .34022 .2091 .33581 .21969 .32996 .2114 .33474 Mtetra
.2114 .33474 .21969 .32996 .23031 .32415 .22205 .32927 Mtetra
.22205 .32927 .23031 .32415 .24096 .31837 .23273 .32387 Mtetra
.23273 .32387 .24096 .31837 .25164 .31258 .24343 .31854 Mtetra
.24343 .31854 .25164 .31258 .26233 .30687 .25414 .31341 Mtetra
.25414 .31341 .26233 .30687 .27304 .30132 .26487 .30851 Mtetra
.004 0 0 r
.26487 .30851 .27304 .30132 .28376 .29616 .27562 .30386 Mtetra
.054 0 0 r
.27562 .30386 .28376 .29616 .29447 .2915 .28639 .29943 Mtetra
.061 0 0 r
.28639 .29943 .29447 .2915 .30518 .28734 .2972 .29491 Mtetra
.02 0 0 r
.2972 .29491 .30518 .28734 .3159 .2836 .30807 .29008 Mtetra
0 0 0 r
.30807 .29008 .3159 .2836 .32666 .27994 .31902 .28467 Mtetra
.31902 .28467 .32666 .27994 .33748 .27613 .33005 .27859 Mtetra
.517 .91 .784 r
.33005 .27859 .33748 .27613 .34835 .27208 .34112 .27216 Mtetra
.67 .968 .919 r
.34112 .27216 .34835 .27208 .35928 .26778 .35223 .26567 Mtetra
.71 .934 .962 r
.35223 .26567 .35928 .26778 .37026 .26344 .36334 .25968 Mtetra
.693 .88 .968 r
.36334 .25968 .37026 .26344 .38127 .25918 .37443 .25453 Mtetra
.649 .839 .974 r
.37443 .25453 .38127 .25918 .39232 .25514 .38552 .25046 Mtetra
.587 .82 .988 r
.38552 .25046 .39232 .25514 .4034 .25132 .3966 .24748 Mtetra
.503 .818 1 r
.3966 .24748 .4034 .25132 .41453 .24758 .40771 .24534 Mtetra
.371 .803 .965 r
.40771 .24534 .41453 .24758 .4257 .24381 .41886 .24372 Mtetra
.204 .731 .817 r
.41886 .24372 .4257 .24381 .43694 .23978 .43007 .24203 Mtetra
0 0 0 r
.43007 .24203 .43694 .23978 .44822 .2355 .44136 .24 Mtetra
.056 0 0 r
.44136 .24 .44822 .2355 .45956 .23109 .45273 .2373 Mtetra
.105 0 0 r
.45273 .2373 .45956 .23109 .47093 .22674 .46417 .23402 Mtetra
.134 0 0 r
.46417 .23402 .47093 .22674 .48235 .22282 .47566 .23042 Mtetra
.143 0 0 r
.47566 .23042 .48235 .22282 .49381 .2194 .48722 .22673 Mtetra
.148 0 0 r
.48722 .22673 .49381 .2194 .50533 .2165 .49882 .22326 Mtetra
.143 0 0 r
.49882 .22326 .50533 .2165 .5169 .21399 .51048 .22005 Mtetra
.13 0 0 r
.51048 .22005 .5169 .21399 .52853 .21165 .52219 .21709 Mtetra
.114 0 0 r
.52219 .21709 .52853 .21165 .54023 .20939 .53397 .21431 Mtetra
.095 0 0 r
.53397 .21431 .54023 .20939 .55199 .20713 .54581 .21163 Mtetra
.077 0 0 r
.54581 .21163 .55199 .20713 .56382 .2049 .55771 .209 Mtetra
.058 0 0 r
.55771 .209 .56382 .2049 .57572 .20272 .56968 .2064 Mtetra
.035 0 0 r
.56968 .2064 .57572 .20272 .58768 .20062 .58172 .20383 Mtetra
.007 0 0 r
.58172 .20383 .58768 .20062 .59972 .19863 .59382 .20128 Mtetra
0 0 0 r
.59382 .20128 .59972 .19863 .61184 .19674 .60599 .19874 Mtetra
.60599 .19874 .61184 .19674 .62403 .19496 .61823 .19621 Mtetra
.61823 .19621 .62403 .19496 .63629 .19324 .63054 .19366 Mtetra
.213 .738 .773 r
.63054 .19366 .63629 .19324 .64864 .19155 .64291 .19105 Mtetra
.296 .792 .857 r
.64291 .19105 .64864 .19155 .66106 .18986 .65536 .18836 Mtetra
.381 .832 .928 r
.65536 .18836 .66106 .18986 .67355 .18811 .66786 .18556 Mtetra
.456 .852 .976 r
.66786 .18556 .67355 .18811 .68612 .1863 .68043 .18263 Mtetra
.519 .85 .997 r
.68043 .18263 .68612 .1863 .69877 .18438 .69307 .17956 Mtetra
.562 .831 .996 r
.69307 .17956 .69877 .18438 .71148 .18238 .70576 .17636 Mtetra
.59 .801 .98 r
.70576 .17636 .71148 .18238 .72427 .18028 .71852 .17306 Mtetra
.606 .767 .957 r
.71852 .17306 .72427 .18028 .73713 .1781 .73134 .16968 Mtetra
.645 .749 .925 r
.05808 .40196 .06568 .40859 .07582 .40387 .06805 .39862 Mtetra
.644 .795 .955 r
.06805 .39862 .07582 .40387 .08601 .39907 .07807 .3952 Mtetra
.635 .842 .98 r
.07807 .3952 .08601 .39907 .09624 .39417 .08814 .39168 Mtetra
.614 .884 .99 r
.08814 .39168 .09624 .39417 .10651 .38916 .09827 .38804 Mtetra
.575 .91 .975 r
.09827 .38804 .10651 .38916 .11684 .384 .10846 .38424 Mtetra
.512 .907 .925 r
.10846 .38424 .11684 .384 .1272 .37873 .1187 .38029 Mtetra
.427 .871 .839 r
.1187 .38029 .1272 .37873 .13762 .37334 .12901 .37619 Mtetra
.33 .804 .726 r
.12901 .37619 .13762 .37334 .14806 .36787 .13936 .37195 Mtetra
0 0 0 r
.13936 .37195 .14806 .36787 .15855 .36235 .14977 .36759 Mtetra
.14977 .36759 .15855 .36235 .16906 .3568 .16022 .36313 Mtetra
.16022 .36313 .16906 .3568 .1796 .35126 .17072 .35859 Mtetra
.17072 .35859 .1796 .35126 .19017 .34573 .18126 .35399 Mtetra
.038 0 0 r
.18126 .35399 .19017 .34573 .20077 .34022 .19184 .34934 Mtetra
.08 0 0 r
.19184 .34934 .20077 .34022 .2114 .33474 .20246 .34467 Mtetra
.117 0 0 r
.20246 .34467 .2114 .33474 .22205 .32927 .21311 .34 Mtetra
.153 0 0 r
.21311 .34 .22205 .32927 .23273 .32387 .2238 .33541 Mtetra
.187 0 0 r
.2238 .33541 .23273 .32387 .24343 .31854 .2345 .33094 Mtetra
.223 0 .007 r
.2345 .33094 .24343 .31854 .25414 .31341 .24524 .32666 Mtetra
.255 0 .045 r
.24524 .32666 .25414 .31341 .26487 .30851 .25599 .32262 Mtetra
.279 0 .077 r
.25599 .32262 .26487 .30851 .27562 .30386 .26677 .31874 Mtetra
.295 0 .1 r
.26677 .31874 .27562 .30386 .28639 .29943 .27758 .31492 Mtetra
.295 0 .11 r
.27758 .31492 .28639 .29943 .2972 .29491 .28846 .31085 Mtetra
.285 0 .113 r
.28846 .31085 .2972 .29491 .30807 .29008 .29942 .30634 Mtetra
.269 0 .11 r
.29942 .30634 .30807 .29008 .31902 .28467 .31046 .30126 Mtetra
.253 0 .108 r
.31046 .30126 .31902 .28467 .33005 .27859 .32156 .29562 Mtetra
.252 0 .114 r
.32156 .29562 .33005 .27859 .34112 .27216 .33272 .28972 Mtetra
.262 0 .128 r
.33272 .28972 .34112 .27216 .35223 .26567 .34391 .28383 Mtetra
.286 0 .148 r
.34391 .28383 .35223 .26567 .36334 .25968 .35511 .27833 Mtetra
.314 0 .168 r
.35511 .27833 .36334 .25968 .37443 .25453 .36632 .27347 Mtetra
.342 0 .185 r
.36632 .27347 .37443 .25453 .38552 .25046 .37752 .26939 Mtetra
.365 0 .195 r
.37752 .26939 .38552 .25046 .3966 .24748 .38874 .2661 Mtetra
.381 .007 .198 r
.38874 .2661 .3966 .24748 .40771 .24534 .39999 .26344 Mtetra
.389 .011 .195 r
.39999 .26344 .40771 .24534 .41886 .24372 .41127 .26119 Mtetra
.384 .002 .185 r
.41127 .26119 .41886 .24372 .43007 .24203 .42262 .25894 Mtetra
.373 0 .171 r
.42262 .25894 .43007 .24203 .44136 .24 .43404 .25645 Mtetra
.352 0 .155 r
.43404 .25645 .44136 .24 .45273 .2373 .44553 .25339 Mtetra
.33 0 .14 r
.44553 .25339 .45273 .2373 .46417 .23402 .4571 .24976 Mtetra
.312 0 .126 r
.4571 .24976 .46417 .23402 .47566 .23042 .46872 .24568 Mtetra
.297 0 .112 r
.46872 .24568 .47566 .23042 .48722 .22673 .4804 .24134 Mtetra
.29 0 .097 r
.4804 .24134 .48722 .22673 .49882 .22326 .49213 .23707 Mtetra
.284 0 .079 r
.49213 .23707 .49882 .22326 .51048 .22005 .5039 .23296 Mtetra
.279 0 .057 r
.5039 .23296 .51048 .22005 .52219 .21709 .51573 .22908 Mtetra
.27 0 .031 r
.51573 .22908 .52219 .21709 .53397 .21431 .52761 .2254 Mtetra
.258 0 .002 r
.52761 .2254 .53397 .21431 .54581 .21163 .53955 .22185 Mtetra
.242 0 0 r
.53955 .22185 .54581 .21163 .55771 .209 .55155 .21837 Mtetra
.221 0 0 r
.55155 .21837 .55771 .209 .56968 .2064 .56361 .2149 Mtetra
.195 0 0 r
.56361 .2149 .56968 .2064 .58172 .20383 .57573 .21141 Mtetra
.161 0 0 r
.57573 .21141 .58172 .20383 .59382 .20128 .58791 .20786 Mtetra
.118 0 0 r
.58791 .20786 .59382 .20128 .60599 .19874 .60014 .20425 Mtetra
.061 0 0 r
.60014 .20425 .60599 .19874 .61823 .19621 .61244 .20056 Mtetra
0 0 0 r
.61244 .20056 .61823 .19621 .63054 .19366 .62479 .19676 Mtetra
.62479 .19676 .63054 .19366 .64291 .19105 .6372 .19283 Mtetra
.227 .734 .681 r
.6372 .19283 .64291 .19105 .65536 .18836 .64966 .18876 Mtetra
.354 .828 .815 r
.64966 .18876 .65536 .18836 .66786 .18556 .66217 .18453 Mtetra
.472 .889 .918 r
.66217 .18453 .66786 .18556 .68043 .18263 .67474 .18014 Mtetra
.564 .906 .975 r
.67474 .18014 .68043 .18263 .69307 .17956 .68736 .17557 Mtetra
.622 .887 .989 r
.68736 .17557 .69307 .17956 .70576 .17636 .70002 .17088 Mtetra
.652 .847 .975 r
.70002 .17088 .70576 .17636 .71852 .17306 .71274 .16607 Mtetra
.665 .801 .948 r
.71274 .16607 .71852 .17306 .73134 .16968 .7255 .16118 Mtetra
.573 .728 .947 r
.05043 .39529 .05808 .40196 .06805 .39862 .06022 .39333 Mtetra
.559 .772 .978 r
.06022 .39333 .06805 .39862 .07807 .3952 .07006 .39132 Mtetra
.533 .814 .998 r
.07006 .39132 .07807 .3952 .08814 .39168 .07996 .38921 Mtetra
.489 .844 .994 r
.07996 .38921 .08814 .39168 .09827 .38804 .08993 .38698 Mtetra
.423 .848 .953 r
.08993 .38698 .09827 .38804 .10846 .38424 .09997 .38459 Mtetra
.334 .816 .867 r
.09997 .38459 .10846 .38424 .1187 .38029 .11008 .38204 Mtetra
.235 .749 .745 r
.11008 .38204 .1187 .38029 .12901 .37619 .12025 .37931 Mtetra
0 0 0 r
.12025 .37931 .12901 .37619 .13936 .37195 .13049 .37641 Mtetra
.13049 .37641 .13936 .37195 .14977 .36759 .1408 .37335 Mtetra
.023 0 0 r
.1408 .37335 .14977 .36759 .16022 .36313 .15117 .37014 Mtetra
.08 0 0 r
.15117 .37014 .16022 .36313 .17072 .35859 .1616 .36678 Mtetra
.127 0 0 r
.1616 .36678 .17072 .35859 .18126 .35399 .17208 .36331 Mtetra
.165 0 0 r
.17208 .36331 .18126 .35399 .19184 .34934 .18262 .35974 Mtetra
.197 0 0 r
.18262 .35974 .19184 .34934 .20246 .34467 .19321 .35612 Mtetra
.226 0 0 r
.19321 .35612 .20246 .34467 .21311 .34 .20385 .35248 Mtetra
.253 0 .02 r
.20385 .35248 .21311 .34 .2238 .33541 .21452 .34888 Mtetra
.278 0 .057 r
.21452 .34888 .2238 .33541 .2345 .33094 .22523 .34538 Mtetra
.3 0 .088 r
.22523 .34538 .2345 .33094 .24524 .32666 .23598 .342 Mtetra
.319 0 .114 r
.23598 .342 .24524 .32666 .25599 .32262 .24676 .33874 Mtetra
.33 0 .133 r
.24676 .33874 .25599 .32262 .26677 .31874 .25758 .3355 Mtetra
.335 0 .145 r
.25758 .3355 .26677 .31874 .27758 .31492 .26846 .33219 Mtetra
.333 0 .152 r
.26846 .33219 .27758 .31492 .28846 .31085 .27941 .32865 Mtetra
.329 0 .157 r
.27941 .32865 .28846 .31085 .29942 .30634 .29043 .3248 Mtetra
.329 0 .166 r
.29043 .3248 .29942 .30634 .31046 .30126 .30151 .32071 Mtetra
.334 0 .18 r
.30151 .32071 .31046 .30126 .32156 .29562 .31265 .31645 Mtetra
.346 0 .201 r
.31265 .31645 .32156 .29562 .33272 .28972 .32383 .31216 Mtetra
.361 .008 .224 r
.32383 .31216 .33272 .28972 .34391 .28383 .33506 .30793 Mtetra
.373 .027 .244 r
.33506 .30793 .34391 .28383 .35511 .27833 .34632 .30376 Mtetra
.383 .042 .258 r
.34632 .30376 .35511 .27833 .36632 .27347 .35763 .29965 Mtetra
.387 .049 .265 r
.35763 .29965 .36632 .27347 .37752 .26939 .36899 .29556 Mtetra
.388 .05 .265 r
.36899 .29556 .37752 .26939 .38874 .2661 .38039 .29151 Mtetra
.386 .045 .259 r
.38039 .29151 .38874 .2661 .39999 .26344 .39183 .28751 Mtetra
.381 .034 .247 r
.39183 .28751 .39999 .26344 .41127 .26119 .40333 .28357 Mtetra
.372 .018 .229 r
.40333 .28357 .41127 .26119 .42262 .25894 .41487 .27969 Mtetra
.361 0 .208 r
.41487 .27969 .42262 .25894 .43404 .25645 .42646 .27579 Mtetra
.345 0 .185 r
.42646 .27579 .43404 .25645 .44553 .25339 .43811 .27171 Mtetra
.329 0 .166 r
.43811 .27171 .44553 .25339 .4571 .24976 .44982 .26739 Mtetra
.312 0 .149 r
.44982 .26739 .4571 .24976 .46872 .24568 .46159 .26274 Mtetra
.299 0 .136 r
.46159 .26274 .46872 .24568 .4804 .24134 .4734 .25786 Mtetra
.29 0 .124 r
.4734 .25786 .4804 .24134 .49213 .23707 .48526 .25291 Mtetra
.282 0 .11 r
.48526 .25291 .49213 .23707 .5039 .23296 .49717 .24798 Mtetra
.275 0 .092 r
.49717 .24798 .5039 .23296 .51573 .22908 .50912 .24316 Mtetra
.264 0 .07 r
.50912 .24316 .51573 .22908 .52761 .2254 .52113 .23846 Mtetra
.25 0 .042 r
.52113 .23846 .52761 .2254 .53955 .22185 .53318 .23386 Mtetra
.231 0 .009 r
.53318 .23386 .53955 .22185 .55155 .21837 .54528 .2293 Mtetra
.205 0 0 r
.54528 .2293 .55155 .21837 .56361 .2149 .55744 .22472 Mtetra
.172 0 0 r
.55744 .22472 .56361 .2149 .57573 .21141 .56964 .22008 Mtetra
.129 0 0 r
.56964 .22008 .57573 .21141 .58791 .20786 .5819 .21533 Mtetra
.074 0 0 r
.5819 .21533 .58791 .20786 .60014 .20425 .59421 .21046 Mtetra
.002 0 0 r
.59421 .21046 .60014 .20425 .61244 .20056 .60656 .20543 Mtetra
0 0 0 r
.60656 .20543 .61244 .20056 .62479 .19676 .61896 .20024 Mtetra
.61896 .20024 .62479 .19676 .6372 .19283 .6314 .19488 Mtetra
.33 .798 .696 r
.6314 .19488 .6372 .19283 .64966 .18876 .64389 .18933 Mtetra
.462 .888 .825 r
.64389 .18933 .64966 .18876 .66217 .18453 .65642 .1836 Mtetra
.573 .936 .917 r
.65642 .1836 .66217 .18453 .67474 .18014 .66898 .17768 Mtetra
.651 .941 .963 r
.66898 .17768 .67474 .18014 .68736 .17557 .68158 .17159 Mtetra
.694 .913 .97 r
.68158 .17159 .68736 .17557 .70002 .17088 .69422 .16536 Mtetra
.713 .869 .955 r
.69422 .16536 .70002 .17088 .71274 .16607 .7069 .15902 Mtetra
.717 .821 .929 r
.7069 .15902 .71274 .16607 .7255 .16118 .71961 .15261 Mtetra
.5 .701 .959 r
.04273 .38856 .05043 .39529 .06022 .39333 .05236 .38771 Mtetra
.479 .733 .982 r
.05236 .38771 .06022 .39333 .07006 .39132 .06206 .3868 Mtetra
.451 .762 .996 r
.06206 .3868 .07006 .39132 .07996 .38921 .07183 .38581 Mtetra
.413 .784 .994 r
.07183 .38581 .07996 .38921 .08993 .38698 .08167 .3847 Mtetra
.365 .793 .97 r
.08167 .3847 .08993 .38698 .09997 .38459 .09158 .38344 Mtetra
.303 .782 .919 r
.09158 .38344 .09997 .38459 .11008 .38204 .10157 .38201 Mtetra
.232 .749 .84 r
.10157 .38201 .11008 .38204 .12025 .37931 .11164 .38042 Mtetra
.156 .696 .74 r
.11164 .38042 .12025 .37931 .13049 .37641 .12178 .37865 Mtetra
0 0 0 r
.12178 .37865 .13049 .37641 .1408 .37335 .132 .37672 Mtetra
.132 .37672 .1408 .37335 .15117 .37014 .14228 .37464 Mtetra
.049 0 0 r
.14228 .37464 .15117 .37014 .1616 .36678 .15264 .37241 Mtetra
.102 0 0 r
.15264 .37241 .1616 .36678 .17208 .36331 .16306 .37006 Mtetra
.147 0 0 r
.16306 .37006 .17208 .36331 .18262 .35974 .17354 .36761 Mtetra
.185 0 0 r
.17354 .36761 .18262 .35974 .19321 .35612 .18408 .36506 Mtetra
.215 0 0 r
.18408 .36506 .19321 .35612 .20385 .35248 .19469 .36243 Mtetra
.239 0 0 r
.19469 .36243 .20385 .35248 .21452 .34888 .20535 .35971 Mtetra
.255 0 0 r
.20535 .35971 .21452 .34888 .22523 .34538 .21607 .35689 Mtetra
.262 0 0 r
.21607 .35689 .22523 .34538 .23598 .342 .22686 .35392 Mtetra
.261 0 .007 r
.22686 .35392 .23598 .342 .24676 .33874 .23772 .35073 Mtetra
.249 0 .002 r
.23772 .35073 .24676 .33874 .25758 .3355 .24866 .34728 Mtetra
.23 0 0 r
.24866 .34728 .25758 .3355 .26846 .33219 .25966 .34352 Mtetra
.206 0 0 r
.25966 .34352 .26846 .33219 .27941 .32865 .27073 .33952 Mtetra
.186 0 0 r
.27073 .33952 .27941 .32865 .29043 .3248 .28186 .33537 Mtetra
.28186 .33537 .29043 .3248 .30151 .32071 .29303 .33134 Mtetra
.206 0 0 r
.29303 .33134 .30151 .32071 .31265 .31645 .30422 .3276 Mtetra
.238 0 0 r
.30422 .3276 .31265 .31645 .32383 .31216 .31543 .32418 Mtetra
.271 0 .016 r
.31543 .32418 .32383 .31216 .33506 .30793 .32669 .32101 Mtetra
.286 0 .049 r
.32669 .32101 .33506 .30793 .34632 .30376 .338 .31775 Mtetra
.289 0 .069 r
.338 .31775 .34632 .30376 .35763 .29965 .34938 .31418 Mtetra
.277 0 .074 r
.34938 .31418 .35763 .29965 .36899 .29556 .36085 .31009 Mtetra
.256 0 .064 r
.36085 .31009 .36899 .29556 .38039 .29151 .37238 .30546 Mtetra
.233 0 .041 r
.37238 .30546 .38039 .29151 .39183 .28751 .38398 .30052 Mtetra
.21 0 .009 r
.38398 .30052 .39183 .28751 .40333 .28357 .39562 .29548 Mtetra
.197 0 0 r
.39562 .29548 .40333 .28357 .41487 .27969 .4073 .29069 Mtetra
.191 0 0 r
.4073 .29069 .41487 .27969 .42646 .27579 .41901 .28623 Mtetra
.192 0 0 r
.41901 .28623 .42646 .27579 .43811 .27171 .43077 .28205 Mtetra
.197 0 0 r
.43077 .28205 .43811 .27171 .44982 .26739 .44257 .278 Mtetra
.198 0 0 r
.44257 .278 .44982 .26739 .46159 .26274 .45442 .27379 Mtetra
.199 0 0 r
.45442 .27379 .46159 .26274 .4734 .25786 .46633 .26933 Mtetra
.196 0 0 r
.46633 .26933 .4734 .25786 .48526 .25291 .4783 .26457 Mtetra
.189 0 0 r
.4783 .26457 .48526 .25291 .49717 .24798 .49032 .25952 Mtetra
.178 0 0 r
.49032 .25952 .49717 .24798 .50912 .24316 .50239 .25426 Mtetra
.158 0 0 r
.50239 .25426 .50912 .24316 .52113 .23846 .5145 .24883 Mtetra
.132 0 0 r
.5145 .24883 .52113 .23846 .53318 .23386 .52666 .24329 Mtetra
.096 0 0 r
.52666 .24329 .53318 .23386 .54528 .2293 .53887 .23766 Mtetra
.048 0 0 r
.53887 .23766 .54528 .2293 .55744 .22472 .55111 .23193 Mtetra
0 0 0 r
.55111 .23193 .55744 .22472 .56964 .22008 .5634 .22609 Mtetra
.5634 .22609 .56964 .22008 .5819 .21533 .57574 .22014 Mtetra
.57574 .22014 .5819 .21533 .59421 .21046 .58811 .21406 Mtetra
.58811 .21406 .59421 .21046 .60656 .20543 .60052 .20782 Mtetra
.382 .825 .694 r
.60052 .20782 .60656 .20543 .61896 .20024 .61297 .20141 Mtetra
.488 .898 .796 r
.61297 .20141 .61896 .20024 .6314 .19488 .62545 .19482 Mtetra
.582 .944 .875 r
.62545 .19482 .6314 .19488 .64389 .18933 .63797 .18805 Mtetra
.655 .962 .927 r
.63797 .18805 .64389 .18933 .65642 .1836 .65052 .18108 Mtetra
.705 .955 .951 r
.65052 .18108 .65642 .1836 .66898 .17768 .66309 .17394 Mtetra
.735 .931 .954 r
.66309 .17394 .66898 .17768 .68158 .17159 .6757 .16662 Mtetra
.75 .897 .944 r
.6757 .16662 .68158 .17159 .69422 .16536 .68833 .15916 Mtetra
.754 .859 .927 r
.68833 .15916 .69422 .16536 .7069 .15902 .70099 .1516 Mtetra
.751 .822 .907 r
.70099 .1516 .7069 .15902 .71961 .15261 .71368 .14397 Mtetra
.441 .676 .963 r
.03496 .38178 .04273 .38856 .05236 .38771 .0445 .38166 Mtetra
.425 .696 .977 r
.0445 .38166 .05236 .38771 .06206 .3868 .05411 .38148 Mtetra
.408 .715 .986 r
.05411 .38148 .06206 .3868 .07183 .38581 .06379 .38121 Mtetra
.388 .733 .991 r
.06379 .38121 .07183 .38581 .08167 .3847 .07354 .38082 Mtetra
.367 .748 .989 r
.07354 .38082 .08167 .3847 .09158 .38344 .08337 .3803 Mtetra
.341 .758 .978 r
.08337 .3803 .09158 .38344 .10157 .38201 .09329 .37962 Mtetra
.311 .763 .957 r
.09329 .37962 .10157 .38201 .11164 .38042 .10328 .37879 Mtetra
.274 .758 .923 r
.10328 .37879 .11164 .38042 .12178 .37865 .11335 .3778 Mtetra
.231 .742 .876 r
.11335 .3778 .12178 .37865 .132 .37672 .1235 .37667 Mtetra
.181 .714 .815 r
.1235 .37667 .132 .37672 .14228 .37464 .13373 .3754 Mtetra
.127 .676 .742 r
.13373 .3754 .14228 .37464 .15264 .37241 .14402 .37402 Mtetra
0 0 0 r
.14402 .37402 .15264 .37241 .16306 .37006 .15439 .37252 Mtetra
.15439 .37252 .16306 .37006 .17354 .36761 .16482 .37092 Mtetra
.029 0 0 r
.16482 .37092 .17354 .36761 .18408 .36506 .17533 .36919 Mtetra
.067 0 0 r
.17533 .36919 .18408 .36506 .19469 .36243 .18591 .36733 Mtetra
.089 0 0 r
.18591 .36733 .19469 .36243 .20535 .35971 .19657 .36523 Mtetra
.096 0 0 r
.19657 .36523 .20535 .35971 .21607 .35689 .20731 .36285 Mtetra
.083 0 0 r
.20731 .36285 .21607 .35689 .22686 .35392 .21815 .36007 Mtetra
.05 0 0 r
.21815 .36007 .22686 .35392 .23772 .35073 .22908 .35679 Mtetra
0 0 0 r
.22908 .35679 .23772 .35073 .24866 .34728 .24011 .353 Mtetra
.24011 .353 .24866 .34728 .25966 .34352 .25123 .34873 Mtetra
.25123 .34873 .25966 .34352 .27073 .33952 .26241 .34423 Mtetra
.26241 .34423 .27073 .33952 .28186 .33537 .27364 .33971 Mtetra
.27364 .33971 .28186 .33537 .29303 .33134 .28488 .33558 Mtetra
.28488 .33558 .29303 .33134 .30422 .3276 .29612 .33203 Mtetra
.29612 .33203 .30422 .3276 .31543 .32418 .30738 .32904 Mtetra
.055 0 0 r
.30738 .32904 .31543 .32418 .32669 .32101 .31866 .32643 Mtetra
.072 0 0 r
.31866 .32643 .32669 .32101 .338 .31775 .33001 .32365 Mtetra
.057 0 0 r
.33001 .32365 .338 .31775 .34938 .31418 .34146 .32038 Mtetra
.004 0 0 r
.34146 .32038 .34938 .31418 .36085 .31009 .353 .31626 Mtetra
0 0 0 r
.353 .31626 .36085 .31009 .37238 .30546 .36463 .31129 Mtetra
.36463 .31129 .37238 .30546 .38398 .30052 .37633 .30582 Mtetra
.37633 .30582 .38398 .30052 .39562 .29548 .38808 .30018 Mtetra
.38808 .30018 .39562 .29548 .4073 .29069 .39986 .29492 Mtetra
.39986 .29492 .4073 .29069 .41901 .28623 .41166 .29022 Mtetra
.41166 .29022 .41901 .28623 .43077 .28205 .42348 .2861 Mtetra
.42348 .2861 .43077 .28205 .44257 .278 .43535 .28237 Mtetra
.43535 .28237 .44257 .278 .45442 .27379 .44727 .27863 Mtetra
.44727 .27863 .45442 .27379 .46633 .26933 .45925 .27465 Mtetra
.45925 .27465 .46633 .26933 .4783 .26457 .4713 .27017 Mtetra
.4713 .27017 .4783 .26457 .49032 .25952 .48341 .26518 Mtetra
.48341 .26518 .49032 .25952 .50239 .25426 .49557 .25968 Mtetra
.49557 .25968 .50239 .25426 .5145 .24883 .50778 .25376 Mtetra
.50778 .25376 .5145 .24883 .52666 .24329 .52003 .24753 Mtetra
.52003 .24753 .52666 .24329 .53887 .23766 .53232 .24107 Mtetra
.343 .789 .633 r
.53232 .24107 .53887 .23766 .55111 .23193 .54464 .23444 Mtetra
.421 .849 .71 r
.54464 .23444 .55111 .23193 .5634 .22609 .55701 .22768 Mtetra
.496 .9 .784 r
.55701 .22768 .5634 .22609 .57574 .22014 .56941 .22081 Mtetra
.566 .938 .845 r
.56941 .22081 .57574 .22014 .58811 .21406 .58184 .2138 Mtetra
.626 .96 .892 r
.58184 .2138 .58811 .21406 .60052 .20782 .59431 .20666 Mtetra
.673 .968 .923 r
.59431 .20666 .60052 .20782 .61297 .20141 .6068 .19937 Mtetra
.71 .964 .941 r
.6068 .19937 .61297 .20141 .62545 .19482 .61933 .19192 Mtetra
.736 .951 .947 r
.61933 .19192 .62545 .19482 .63797 .18805 .63188 .18429 Mtetra
.754 .932 .946 r
.63188 .18429 .63797 .18805 .65052 .18108 .64446 .17648 Mtetra
.765 .911 .938 r
.64446 .17648 .65052 .18108 .66309 .17394 .65706 .16851 Mtetra
.771 .887 .928 r
.65706 .16851 .66309 .17394 .6757 .16662 .66969 .16037 Mtetra
.773 .863 .916 r
.66969 .16037 .6757 .16662 .68833 .15916 .68233 .15209 Mtetra
.772 .839 .903 r
.68233 .15209 .68833 .15916 .70099 .1516 .695 .14371 Mtetra
.769 .815 .889 r
.695 .14371 .70099 .1516 .71368 .14397 .70769 .13525 Mtetra
.42 .667 .963 r
.02714 .37496 .03496 .38178 .0445 .38166 .03665 .37506 Mtetra
.42 .676 .968 r
.03665 .37506 .0445 .38166 .05411 .38148 .04624 .37508 Mtetra
.422 .685 .972 r
.04624 .37508 .05411 .38148 .06379 .38121 .0559 .375 Mtetra
.426 .694 .976 r
.0559 .375 .06379 .38121 .07354 .38082 .06564 .37481 Mtetra
.431 .704 .979 r
.06564 .37481 .07354 .38082 .08337 .3803 .07545 .37449 Mtetra
.436 .714 .983 r
.07545 .37449 .08337 .3803 .09329 .37962 .08535 .37403 Mtetra
.441 .725 .986 r
.08535 .37403 .09329 .37962 .10328 .37879 .09533 .37344 Mtetra
.444 .735 .989 r
.09533 .37344 .10328 .37879 .11335 .3778 .10539 .37271 Mtetra
.446 .746 .992 r
.10539 .37271 .11335 .3778 .1235 .37667 .11552 .37184 Mtetra
.446 .756 .995 r
.11552 .37184 .1235 .37667 .13373 .3754 .12573 .37087 Mtetra
.444 .766 .997 r
.12573 .37087 .13373 .3754 .14402 .37402 .13601 .36978 Mtetra
.441 .776 .998 r
.13601 .36978 .14402 .37402 .15439 .37252 .14637 .36859 Mtetra
.437 .784 .997 r
.14637 .36859 .15439 .37252 .16482 .37092 .15679 .36729 Mtetra
.436 .794 .996 r
.15679 .36729 .16482 .37092 .17533 .36919 .16729 .36585 Mtetra
.438 .805 .995 r
.16729 .36585 .17533 .36919 .18591 .36733 .17787 .36425 Mtetra
.45 .818 .994 r
.17787 .36425 .18591 .36733 .19657 .36523 .18854 .36237 Mtetra
.47 .834 .993 r
.18854 .36237 .19657 .36523 .20731 .36285 .1993 .36016 Mtetra
.502 .853 .993 r
.1993 .36016 .20731 .36285 .21815 .36007 .21016 .35749 Mtetra
.541 .872 .992 r
.21016 .35749 .21815 .36007 .22908 .35679 .22113 .35428 Mtetra
.576 .887 .99 r
.22113 .35428 .22908 .35679 .24011 .353 .23219 .35056 Mtetra
.606 .899 .987 r
.23219 .35056 .24011 .353 .25123 .34873 .24335 .34637 Mtetra
.615 .904 .985 r
.24335 .34637 .25123 .34873 .26241 .34423 .25456 .34198 Mtetra
.608 .906 .984 r
.25456 .34198 .26241 .34423 .27364 .33971 .26582 .33761 Mtetra
.575 .9 .983 r
.26582 .33761 .27364 .33971 .28488 .33558 .2771 .33359 Mtetra
.526 .885 .98 r
.2771 .33359 .28488 .33558 .29612 .33203 .28838 .3301 Mtetra
.482 .867 .975 r
.28838 .3301 .29612 .33203 .30738 .32904 .29968 .32705 Mtetra
.454 .853 .972 r
.29968 .32705 .30738 .32904 .31866 .32643 .31102 .32432 Mtetra
.474 .861 .977 r
.31102 .32432 .31866 .32643 .33001 .32365 .32243 .3214 Mtetra
.519 .878 .983 r
.32243 .3214 .33001 .32365 .34146 .32038 .33392 .31802 Mtetra
.579 .899 .985 r
.33392 .31802 .34146 .32038 .353 .31626 .34551 .31387 Mtetra
.629 .915 .98 r
.34551 .31387 .353 .31626 .36463 .31129 .35719 .30895 Mtetra
.654 .925 .975 r
.35719 .30895 .36463 .31129 .37633 .30582 .36894 .30357 Mtetra
.66 .929 .972 r
.36894 .30357 .37633 .30582 .38808 .30018 .38074 .298 Mtetra
.638 .926 .974 r
.38074 .298 .38808 .30018 .39986 .29492 .39257 .29273 Mtetra
.607 .916 .977 r
.39257 .29273 .39986 .29492 .41166 .29022 .40443 .28792 Mtetra
.573 .903 .981 r
.40443 .28792 .41166 .29022 .42348 .2861 .41631 .28363 Mtetra
.552 .891 .984 r
.41631 .28363 .42348 .2861 .43535 .28237 .42823 .27969 Mtetra
.557 .888 .987 r
.42823 .27969 .43535 .28237 .44727 .27863 .44021 .27578 Mtetra
.575 .891 .988 r
.44021 .27578 .44727 .27863 .45925 .27465 .45225 .27166 Mtetra
.608 .9 .986 r
.45225 .27166 .45925 .27465 .4713 .27017 .46436 .26706 Mtetra
.641 .908 .982 r
.46436 .26706 .4713 .27017 .48341 .26518 .47652 .26193 Mtetra
.671 .914 .976 r
.47652 .26193 .48341 .26518 .49557 .25968 .48874 .25625 Mtetra
.695 .917 .969 r
.48874 .25625 .49557 .25968 .50778 .25376 .501 .2501 Mtetra
.713 .915 .964 r
.501 .2501 .50778 .25376 .52003 .24753 .51331 .24359 Mtetra
.727 .911 .958 r
.51331 .24359 .52003 .24753 .53232 .24107 .52566 .23679 Mtetra
.735 .904 .953 r
.52566 .23679 .53232 .24107 .54464 .23444 .53804 .22982 Mtetra
.742 .895 .948 r
.53804 .22982 .54464 .23444 .55701 .22768 .55046 .22268 Mtetra
.747 .886 .943 r
.55046 .22268 .55701 .22768 .56941 .22081 .56291 .21543 Mtetra
.751 .876 .937 r
.56291 .21543 .56941 .22081 .58184 .2138 .57539 .20805 Mtetra
.754 .866 .93 r
.57539 .20805 .58184 .2138 .59431 .20666 .58791 .20055 Mtetra
.757 .857 .924 r
.58791 .20055 .59431 .20666 .6068 .19937 .60045 .19291 Mtetra
.76 .848 .917 r
.60045 .19291 .6068 .19937 .61933 .19192 .61302 .18513 Mtetra
.762 .84 .911 r
.61302 .18513 .61933 .19192 .63188 .18429 .62561 .17719 Mtetra
.765 .832 .904 r
.62561 .17719 .63188 .18429 .64446 .17648 .63824 .16909 Mtetra
.767 .826 .898 r
.63824 .16909 .64446 .17648 .65706 .16851 .65088 .16084 Mtetra
.769 .819 .892 r
.65088 .16084 .65706 .16851 .66969 .16037 .66354 .15243 Mtetra
.77 .813 .887 r
.66354 .15243 .66969 .16037 .68233 .15209 .67623 .14389 Mtetra
.77 .807 .882 r
.67623 .14389 .68233 .15209 .695 .14371 .68893 .13523 Mtetra
.771 .801 .877 r
.68893 .13523 .695 .14371 .70769 .13525 .70165 .12647 Mtetra
.453 .681 .963 r
.01926 .36808 .02714 .37496 .03665 .37506 .02884 .36777 Mtetra
.471 .676 .954 r
.02884 .36777 .03665 .37506 .04624 .37508 .0385 .36734 Mtetra
.487 .668 .944 r
.0385 .36734 .04624 .37508 .0559 .375 .04824 .36679 Mtetra
.501 .66 .932 r
.04824 .36679 .0559 .375 .06564 .37481 .05805 .36611 Mtetra
.513 .652 .92 r
.05805 .36611 .06564 .37481 .07545 .37449 .06794 .36531 Mtetra
.524 .643 .909 r
.06794 .36531 .07545 .37449 .08535 .37403 .07791 .36439 Mtetra
.533 .635 .897 r
.07791 .36439 .08535 .37403 .09533 .37344 .08795 .36334 Mtetra
.541 .628 .887 r
.08795 .36334 .09533 .37344 .10539 .37271 .09807 .36216 Mtetra
.548 .621 .876 r
.09807 .36216 .10539 .37271 .11552 .37184 .10827 .36086 Mtetra
.555 .614 .866 r
.10827 .36086 .11552 .37184 .12573 .37087 .11853 .35942 Mtetra
.56 .607 .857 r
.11853 .35942 .12573 .37087 .13601 .36978 .12887 .35786 Mtetra
.565 .6 .847 r
.12887 .35786 .13601 .36978 .14637 .36859 .13929 .35616 Mtetra
.57 .593 .837 r
.13929 .35616 .14637 .36859 .15679 .36729 .14978 .35433 Mtetra
.574 .586 .827 r
.14978 .35433 .15679 .36729 .16729 .36585 .16034 .35237 Mtetra
.577 .579 .818 r
.16034 .35237 .16729 .36585 .17787 .36425 .17097 .35028 Mtetra
.58 .573 .81 r
.17097 .35028 .17787 .36425 .18854 .36237 .18167 .34805 Mtetra
.583 .57 .804 r
.18167 .34805 .18854 .36237 .1993 .36016 .19244 .34569 Mtetra
.587 .57 .802 r
.19244 .34569 .1993 .36016 .21016 .35749 .20328 .34319 Mtetra
.591 .575 .804 r
.20328 .34319 .21016 .35749 .22113 .35428 .21419 .34055 Mtetra
.596 .587 .813 r
.21419 .34055 .22113 .35428 .23219 .35056 .22516 .33777 Mtetra
.602 .607 .829 r
.22516 .33777 .23219 .35056 .24335 .34637 .23621 .33486 Mtetra
.609 .636 .852 r
.23621 .33486 .24335 .34637 .25456 .34198 .24732 .33181 Mtetra
.616 .67 .879 r
.24732 .33181 .25456 .34198 .26582 .33761 .25849 .32862 Mtetra
.622 .703 .903 r
.25849 .32862 .26582 .33761 .2771 .33359 .26974 .32529 Mtetra
.627 .725 .917 r
.26974 .32529 .2771 .33359 .28838 .3301 .28104 .32182 Mtetra
.632 .728 .917 r
.28104 .32182 .28838 .3301 .29968 .32705 .29241 .3182 Mtetra
.637 .715 .904 r
.29241 .3182 .29968 .32705 .31102 .32432 .30383 .31445 Mtetra
.639 .69 .882 r
.30383 .31445 .31102 .32432 .32243 .3214 .31532 .31055 Mtetra
.64 .669 .862 r
.31532 .31055 .32243 .3214 .33392 .31802 .32687 .30651 Mtetra
.641 .656 .849 r
.32687 .30651 .33392 .31802 .34551 .31387 .33848 .30232 Mtetra
.644 .658 .848 r
.33848 .30232 .34551 .31387 .35719 .30895 .35015 .29799 Mtetra
.651 .673 .859 r
.35015 .29799 .35719 .30895 .36894 .30357 .36187 .29352 Mtetra
.659 .698 .875 r
.36187 .29352 .36894 .30357 .38074 .298 .37365 .2889 Mtetra
.666 .726 .894 r
.37365 .2889 .38074 .298 .39257 .29273 .38549 .28414 Mtetra
.672 .742 .903 r
.38549 .28414 .39257 .29273 .40443 .28792 .39738 .27923 Mtetra
.676 .742 .9 r
.39738 .27923 .40443 .28792 .41631 .28363 .40932 .27418 Mtetra
.677 .723 .884 r
.40932 .27418 .41631 .28363 .42823 .27969 .42131 .26898 Mtetra
.674 .693 .86 r
.42131 .26898 .42823 .27969 .44021 .27578 .43335 .26363 Mtetra
.669 .662 .834 r
.43335 .26363 .44021 .27578 .45225 .27166 .44544 .25814 Mtetra
.664 .637 .812 r
.44544 .25814 .45225 .27166 .46436 .26706 .45758 .2525 Mtetra
.661 .619 .797 r
.45758 .2525 .46436 .26706 .47652 .26193 .46977 .24672 Mtetra
.66 .61 .788 r
.46977 .24672 .47652 .26193 .48874 .25625 .482 .24078 Mtetra
.661 .608 .784 r
.482 .24078 .48874 .25625 .501 .2501 .49427 .23471 Mtetra
.665 .611 .785 r
.49427 .23471 .501 .2501 .51331 .24359 .50659 .22848 Mtetra
.669 .617 .788 r
.50659 .22848 .51331 .24359 .52566 .23679 .51895 .22211 Mtetra
.675 .627 .793 r
.51895 .22211 .52566 .23679 .53804 .22982 .53135 .21559 Mtetra
.68 .637 .799 r
.53135 .21559 .53804 .22982 .55046 .22268 .54379 .20892 Mtetra
.686 .648 .806 r
.54379 .20892 .55046 .22268 .56291 .21543 .55626 .20211 Mtetra
.692 .658 .812 r
.55626 .20211 .56291 .21543 .57539 .20805 .56878 .19515 Mtetra
.698 .669 .818 r
.56878 .19515 .57539 .20805 .58791 .20055 .58132 .18805 Mtetra
.704 .679 .823 r
.58132 .18805 .58791 .20055 .60045 .19291 .5939 .1808 Mtetra
.71 .69 .829 r
.5939 .1808 .60045 .19291 .61302 .18513 .60651 .17341 Mtetra
.716 .701 .834 r
.60651 .17341 .61302 .18513 .62561 .17719 .61916 .16587 Mtetra
.723 .712 .84 r
.61916 .16587 .62561 .17719 .63824 .16909 .63183 .15818 Mtetra
.729 .725 .846 r
.63183 .15818 .63824 .16909 .65088 .16084 .64453 .15035 Mtetra
.736 .738 .853 r
.64453 .15035 .65088 .16084 .66354 .15243 .65725 .14238 Mtetra
.743 .751 .859 r
.65725 .14238 .66354 .15243 .67623 .14389 .67 .13427 Mtetra
.749 .765 .866 r
.67 .13427 .67623 .14389 .68893 .13523 .68277 .12601 Mtetra
.756 .778 .872 r
.68277 .12601 .68893 .13523 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Sooooo`03ol77gol0003ooooo01Gooooo00?o
0000ooooooooool0DOooool0063ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`0Mooooo`?o00000_ooool00ol0003oooooooooo`1Oooooo`?o`LOO00?o
0000ol77goooool05Oooool00ol0003oooooooooo`1@ooooo`00H?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol0000Looooo`;o0000IOooool00ono`mgo`LOOol77g`02ol77g`03o`000?o5
cN3ooooo01Cooooo00?o0000ooooool00000DOooool0063ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0001[ooooo0ol0001Vooooo`?o_l?M0oo1aml00ol0003oaLgP
olG=h00Fooooo`03o`000?oooooooooo04oooooo001Pooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool0000Hooooo`;o0000J?ooool5oko3g@03ol77goo5cN3o000000?o
aLgP5_ooool00ol0003oooooooooo`1>ooooo`00H?ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l000005Oooool3o`0000;ooooo00?o0000ooooooooool0Hoooool00onn`=_o
_l?Moko3g@03oko3g@04olG>hOo5cN3oaLgPo`0000;oaLgP00?oa=3Sooooooooool05?ooool00ol0
003oooooooooo`1>ooooo`00H?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4
A?l000004oooool2o`0006Wooooo1?nn`=/3oko3g@?oaLkQ00?oaLgPo`000?o5cN000oo4d><Foooo
o`03o`000?oooooooooo04gooooo001Pooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omg
MgOo0000ooooo`0?ooooo`?o0000JOooool00onl_=[o_/3Kokk0f`04okk0f`03oko3gOo5c^7oaLkQ
00?oaLkQ00?o0000olC@hoo4d><00oo4d><Fooooo`03o`000?oooooooooo04cooooo0022ooooo`;o
0000Joooool3okblfPCo_/3K00?oaM3SolG>hOo5c^400oo5c^400oo5e^Oo0000olC@h`03olC@h`03
ol3Bj?oooooooooo01Cooooo00?o0000ooooooooool0C?ooool007oooooo0ol00002ooooo`03o`00
0?oooooooooo06Oooooo1?nl_=X3okk0f`?oaM3S0oo5c^42olGFi`03o`000?o5e^Ooa=3S00Co`=;X
5?ooool3o`0004gooooo001looooo`?o0000KOooool00onj^MSo_;cJokblfP04okblfP03okk0foo5
d>?oaM3S00?oaM3S00KoaLkQolGFioo5e^OoaMKWo`000?o1fnd5ol3Bj1Oooooo00?o0000oooooooo
ool0B_ooool007[ooooo0_l0001^ooooo`Co^[WH1?nl_=X2olCAi0CoaM3S0_o5g>X3olGFi`03ol7K
kOl0003o`M_]00?o`=;X0_ngd^dFooooo`03o`000?oooooooooo04[ooooo001gooooo`?o0000K_oo
ool00oni]]Oo^[WHokZif004okZif003okblf_o4dNCoa=7T00?oa=7T00?oaM3SolGLj_o5g>X00oo5
g>X01_o5e^Oo`M_]ol7KkOl0003o`M_]ol3Bj0Go]m;]5_ooool00ol0003oooooooooo`19ooooo`00
MOooool2o`0000;ooooo00?o0000ooooooooool0Joooool3okVfe`Co^[WH00?oa=?UolCAi?o4dN@0
0oo4dN@2olGSk@CoaMcZ00Go_nGaol7KkOo1fngo`M_]o`000002okKNm0Co]m;]00?oZ/gboooooooo
ool05Oooool00ol0003oooooooooo`18ooooo`00L_ooool3o`0000Gooooo00?o0000ooooooooool0
JOooool4okVfe`?o^[WH0oo4dnD3olCAi0CoaN?]00?oaMcZokoUlOnoiO400_noiO400oo1fngo]]kd
o`000003okKNm003okOBkOnZcO;oZ/gb00;oZ/gb5_ooool00ol0003oooooooooo`18ooooo`00L?oo
ool2o`0007;ooooo00?o]k?EokVfeoni]]L01?ni]]L00onj^MSoa=?UolCCi@03olCCi@03olCAi?o5
hngoaN?]00;oaN?]00?o_>kdokoUlOnoiO400_noiO43ok7Yn003o`000?nfg_CoY]Si00;oY]Si1OnZ
cO8Fooooo`03o`000?oooooooooo04Oooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo1Ol0000Pooooo`?o0000L_ooool4okNce@Co^KKG0_o3e>L4olCCi@?o`nW`00?o
aN?]okc^m?nlk_@00_nlk_@00onoiO7o/NWhok7Yn002ok7Yn003oioSoOl0003oY]Si00CoY]Si0_nZ
cO82oi_4m1Gooooo0ol00018ooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@07_ooool2o`0000?ooooo00?o0000ooooooooool0
KOooool00one/=Co]k?EokNce@04okNce@03okVfeoo3e>Oo`mCW00?o`mCW00?oa=?Uol?Yl?o3jO00
0_o3jO000ondm??o_>kdokc^m002okc^m0?oY_3f00Ko/NWhoioSoOnOhogoWn?mo`000?nOhod2ojKH
n@?oUlgj1?nKa?@Fooooo`03o`000?oooooooooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo02Wooooo000hooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Looooo`?o0000M?ooool3okF`e0Co]k?E00?o`mOY
ol?Dioo3e>L00oo3e>L2ol7^lP?o`nW`0ondm?<01?nlk_CoY_3fojK`m_nVl?H4oi3Wn@;oWn?m00?o
0000ohoDo_n?e?h01OnGcOX4oi_4m1Kooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02[ooooo000hooooo`05o`000?oo
ooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Hooooo`?o0000M_ooool4okF`e0?o]k?E
0oo3enT3ol?Di`Co`Nkb00Co`nW`okCdlondm??o]?Cc0_nBknX3ogSSj`;oT>Oi0on4fOl00on?e?ko
0000ohoDoP02ohoDoP;oUlgj0_n;__P5ohjjm1Kooooo00?o0000ooooooooool01?ooool01Ol@413o
oooooooooooooooo410@00_ooooo1Ol0000[ooooo`00>?ooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool05Oooool3o`0007Kooooo00?o]:gBokF`e?ne/=@01?ne/=@00ong
/mGo`mOYol?Gj@03ol?Gj@03ol?Dioo1k_;o`Nkb00;o`Nkb0_nWm^d00ondm??oT^oZoi;_jP03ogSS
j`CoM=[i1?n4fOl00ol0003oSmCnohO3n`02ohO3n`CoRkkh1On>^_@Eooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002cooooo000h
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Aooooo`?o00000ooo
ool00ol0003oooooooooo`1aooooo`Co]:gB1?ne/=@2ol;IjPCo`mOY0onllo800oo1k_;oYoK]ojOf
k@02ogKSd`;oF]?@1?mQe>d2ogCJn@?oO<Wo0on2a_d00ol0003oQl?kohO3n`03ohO3n`CoRkkh0_n>
^_@2ohRalAKooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000_ooooo
00CogMgMoeEEEOoooooo0000;?ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41004Oooool2o`0007Sooooo00?o/Z_AokB]d_nd[M801?nd[M800one
/=Co`]WZol;IjP03ol;IjP03ol?GjOnllo;o_??b00;o_??b00CoU?7OoeC</_lj^jko>[^^1?m;b]/2
of7Dk@?oM/_o1OmlbOl2oh;6o@04o`000?n2a_goQl?kohO3n`;oQk3`1On7/?44ohRalAKooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000
;?ooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`03_ooool3o`0007Sooooo1?nbZm44okB]dP03ol7Kk?o2fN[o`]WZ00?o`]WZ0onem_000onllo;o
U?7Oo`000002ocJla@CoKLgn1?mac?l4ogK;o`;oO<Wo0_n7[Nh2ohN_l003o`000?n7[o3oQjo`00Co
Qk3`1On7/?44ohRalACooooo0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^
k^koA4A4o`00000/ooooo`00FOooool3o`0007Sooooo00?o/JS?ok:[dOnbZm400onbZm43okB]dP?o
`M_/0oo2fNX3okGfl003ogcUbomZc_coJlgm00?oJlgm0_m]cOh2oh^Vi`CoRJWZ1On8Znd4ohN]kP03
ohN_l?l0003oQjo`00;oQjo`1?n7/?02ohN`l@;oRZWZ1?n9[NdCooooo`04o`000?ooooooooooo`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02_ooooo001Foooo
o`?o00000oooool00ol0003oooooooooo`1cooooo`Co/JS?1OnbZm400ond[M;o`M_/ol7Kk003ol7K
k003ol;Ij_nem_3o]OK`00;oO>G;0_n?X>04ohfSi0GoRjKW1?n9ZNX5ohR[k@CoQjg^00Co0000ohN_
l?n=XN;oSJ7R1?n;YNH5ohZYjPCoRJg]5_ooool00ol0003oooooooooo`10ooooo`00E?ooool2o`00
07[ooooo00?o[jG>ok6XconaZ<l00onaZ<l4ok:[d@;o`Mg^1?o1fn`2ojcgk003of7C/OnAWM_oSj3P
00CoSj3P1?n=Xn@5oh^Vi`CoRJWZ0_n8Znd2ohnHf0CoSYcM00Co0000ohfQh_n=XN;oSJ7R1On;YNH4
ohZYjPCoRJg]5_ooool00ol0003oooooooooo`10ooooo`00DOooool3o`0007_ooooo0on_YLh5ok6X
c`03ok:[dOo1gNko`Mg^00?o`Mg^00Co`M_/ojcgk?n/mncoTi[G1?nAWM/5ohnPh0CoSJ?T0_n;Y^L2
oi:@cPCoT9CC1?n?V=P4ohjLg@03o`000?n=XN;oSJ7R00;oSJ7R1?n;YNH2ohZYjP;oTZGR1On@[>TF
ooooo`03o`000?oooooooooo03oooooo001>ooooo`Go0000Noooool4ojnUcPCo/JS?0_o0h>l4ol7M
kP;oX?GT0onCV]L5oi6Mf`;oSj3P0_nDRLD4oi><b@GoTY3>1?n@U=<4ohnHf0?oSYcM00?o0000ohfQ
h_n=XN800_n=XN82oh^UiP;oTikK1OnBYN85oi2/jAKooooo00?o0000ooooooooool0?_ooool004co
oooo0_l00005ooooo`03o`000?oooooooooo073ooooo0_lQ0003oad00003oaP00?n^Xlco[jG>00Co
[jG>0onaZ<l4ol3Pk`03ol7Mk_nPmNCoX?GT00;oUIKC1?nCV]L2oi6Mf`;oUHK11OnDRLD4oi><b@Co
TY3>1?n@U=<4ohnHf0;oSYcM00?oU9;>o`000?nDV=D00onDV=D5oi>Nf`GoTZGR0_n@[>T2oib`iQKo
oooo00?o0000ooooooooool0?_ooool004Wooooo0ol0001gooooo`05ob@00?lQ003o8@00ob400?lM
00000_m500L4ojjSc0Go[jG>00?o/JS?ol3Pkoo0h>l00_o0h>l2oi3`f0CoUIKC0_nCV]L2oiJ3_@Go
UHK11?nDRLD4oi><b@GoTY3>1?n@U=<2ohnHf003oiF=b?nDT/koU9;>00;oU9;>00?o0000oiBHeOnD
V=D00_nDV=D5oi>Nf`;oTZGR0_nLZ=h5oib`iQCooooo0ol0000oooooo`008_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^023ooooo0_l0001fooooo`05obD00?lT003o9000ob@00?lQ00000_m700h2odD0
1`03ojbPbon^Xlco[Z?<00?o[Z?<1?n_YLh3okoRl@03ol3Pkon@l=SoT?3H00?oUY?>0_nEU]<00onF
PK[oUX>moiJ3_@03oiJ3_@CoUHK11?nDRLD5oi><b@;oTY3>0_nFQ;h4oiJ8``CoUHg80onDT/h00ol0
003oU9SEoiBHe@03oiBHe@;oTikK0_nLX=L5oibXgPGoW;3V5Oooool00ol0003oooooooooo`0moooo
o`008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo0ol00002ooooo`03o`000?oooooooooo
06oooooo0_lT0002obD00003ob@00?m801CoB00D00CoA`0>1?n/X</5ojjSc003ojnUc_noh_7o_n;a
00;o_n;a0_mni/P00onFSl[oUY?>oiJCcP02oiMn]`CoUX6j1?nFPkd4oiF6`@GoU8W50_nCS<T2oiN1
^PGoUXBn1?nFR<<3oiF=b0?oU9;>00Co0000oiBBc_nDV=GoU9SE0_nLVM05oibPe`GoW:SN0_nL/>H3
ojNfi1Gooooo00?o0000ooooooooool0??ooool002;ooooo00Go410@oooooooooooooooooa0@400K
ooooo`;o0000M?ooool01_lR003o9000ob@00?lT003o9@00odX060CoB00D0_m700h00on[WLWo[:3;
ojbPb`03ojbPb`Co[Z?<0onmiO801?noh_7oO^K8ogkVb?nFSlX2oiMl]0GoUgjg0onFPKX4oiJ3_@Go
UHK10_nDRLD2oiMn]PGoUh6j1?nFQ;h4oiJ8``CoUHg80_nDT/h00ol0003oWI?:oibId004oibId0Co
W:3G1?nLZ=h00onW[]goYkKTojNfi004ojNfi1Gooooo00?o0000ooooooooool0>oooool002;ooooo
00Go0000ooooooooooooooooo`00000Hooooo`?o0000Loooool01?lJ003o8P00ob800?lT0002od`0
70?oBP0H0om801@00om700koZig9oj^Mb@02oj^Mb@Go[:3;00?o[Z?<okgUl_nmiO800_nmiO82of_I
]@03oiMj/OnGO;CoUgbd00;oUgbd1OnGO[L4oiJ1^PCoUX>m0onEQ/400onGNk;oUgjfoiMn]P02oiMn
]PGoUh6j1?nFQ;h4oiJ8``?oUHg800CoWHo4oifCb_nMTl[o00000_nMTlX4oibId0GoW:3G00?oW:SN
ojN^gOnW[]d00_nW[]d4ojNfi003ok6mhooooooooooo01?ooooo00?o0000ooooooooool0>oooool0
02;ooooo00Go0000ooooooooooooooooo`00000Fooooo`?o0000Loooool2oaX00003ob800?m?023o
C00L00?oC00L0_m:01P3odP05003ojZLb?n[WLWoZig900?oZig91?n/X</2okcWl`?o_NGb00CoJmVe
oiMj/OnGN[7oUgZa1OnGO;@4oiMn]`CoUX6j1?nFPkd01?nEQ/7oUg^boiMk/_nGNk85oiMn]PCoUh6j
1OnFQ;h4oiJ8``06oiF=b?nMSlCoWHo4oif?a?nMTl[o00000_nMTlX5oibId0;oW:3G0_nVY]H6ojN^
g@03ojNfi?na_N?o/KgS00;o/KgS5Oooool00ol0003oooooooooo`0jooooo`008_ooool01Ol@413o
oooooooooooooooo410@01?ooooo0ol00002ooooo`03o`000?oooooooooo06kooooo0_l>0002oaX0
00?oC`0P0om<01`3odX06003odP05?nZW<SoZYc800;oZYc81On[WLT00on/X<_o_>OcokcWl`03okcW
l`03okgUl_nFMjkoUWN^00CoUgZa1?nGO;@5oiMn]`CoUX6j0_nFPkd00onGNJooUg^boiMk/P03oiMk
/PCoUgjf1OnGPKX4oiJ4_P;oUXS30_nMR[l4oif?a004oifCb_l0003oWI?:oifCbPCoW9W@00?oYZ3@
ojJVe_nVY]H00onVY]H4ojN^g@03ok6gg_na_N?o/KgS00?o/KgS5_ooool00ol0003oooooooooo`0i
ooooo`008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg013ooooo0ol0001cooooo`Co3P0000?o6P00
oe@08om?02000_m?0204od`07003odX06?m:01ooZI_800GoZYc81?n[WLT2ok[Ym@Co_>Oc1OnFMjh3
oiMj/@CoUgbd1OnGO[L2oiJ1^P;oUgN]0onGNJl5oiMk/PCoUgjf1OnGPKX2oiJ4_P;oWHNk1?nMR[l4
oif?a003oifCb_l0003oWI?:00;oWI?:00?oW9W@ojJPd?nVX=000_nVX=05ojJVeP03ojN^gOna]mko
/KON00;o/KON0ona_N<2okW5i1Cooooo0_l0000kooooo`008_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00kooooo0_l0001cooooo`03o`000?mO02_oFP0W00?oFP0W0omD02<3odl080CoC00L1?nYVlP4
ojZLb0?oZig91?njjOD01?nlio?oU7B/oiAd[?nDM:`4oiIg[P?oUgZa1OnGO;@3oiMn]`03oiQfZonG
MjgoUgN]00;oUgN]1?nGNJl4oiMk/PGoUgjf0onGPKX00onMQ;OoWHNkoif7^`03oif7^`CoWHZo1?nM
Sl@01?l0003oWI?:ojJKb_nVVlX5ojJPd0CoYZKF00?o/K;Iok6gg_na]mh01?na]mh00ona_N?o^LGT
okW5i002okW5i1Gooooo00?o0000ooooooooool0>?ooool003;ooooo1Ol0001`ooooo`;oHP0_0omO
02/4oeX09`;oE00S1?m?02000om<01coC00RojRLb@05ojVKb0GoZYc800?oZig9ok[YmOnjjOD00_nj
jOD00onCLZ[oU7B/oiAd[002oiAd[0CoUWN^1?nGN[44oiMl]004oiMn]onHMZ_oV7J[oiQfZ`GoUgN]
0onGNJl5oiMk/PCoUgjf00CoUh6joif4]onMQ;OoWHBg1OnMQk/4oif:_`?oWHo40_l00004ojJKbPGo
YZ3@00?oYZKFok6bfOna/]T00_na/]T4ok6ggP03okW4honiaNCo^LGT00;o^LGT00?o^l_Voooooooo
ool05?ooool00ol0003oooooooooo`0gooooo`00<?ooool2o`0006kooooo0_mQ0C83of<2<@CoHP0_
0_mO02/4oeX09`?oE00S0_m?02000om?02KoC00RojRLb@03ojRLb@CoZI_81?nZW<P3okKZmP04ok[Y
mOnCLZ[oTg:Zoi=bZPCoU7B/1?nFMjh4oiMj/@;oUgbd0_nHM:T5oiQfZ`CoUgN]0onGNJl5oiMk/P;o
Ugjf0_nMPK@5oif4]`CoWHNk1?nMR[l3o`000003ojJGa_l0003oYY_:00?oYY_:1?nVX=000ona[]Go
/K;Iok6bf@04ok6bf@03ok6gg_nia>?o^LCS00;o^LCS00?o^LGTok_;i_nkbnH00_nkbnHEooooo`03
o`000?oooooooooo03Oooooo000]ooooo`?o0000KOooool00omM037oH@4bof41<P02of41<P?oH`8a
0omR02l3oel0:`CoFP0W0omD02<00om?02KoZIk<ojVNc005ojRLb@GoZI_800?oZYc8okKZm_nfj_H0
0_nfj_H00onBL:WoTg:Zoi=bZP02oi=bZPCoU7B/1OnFMjh2oiMj/@03oiQcZ?nHM:WoV7BY00;oV7BY
1OnHMZ/4oiMg[@CoUgV_0onGNk800onMO[7oWH6doif1]002oif1]0GoWHBg1OnMQk/3o`0000GoYYO6
00?o0000ojJKb_nVVlX00_nVVlX00onVX=3o/JkEok6^e@02ok6^e@Co/K;I00?o^/CRokW4honia><0
0_nia><00onlcnWo^l_Vok_;iP04ok_;iQGooooo00?o0000ooooooooool0=_ooool002cooooo0_l0
001[ooooo`;oE`0_0omM0343of41<P?oH`8a0omR02l4oel0:`CoFP0W00?oE00SojVSconYW/`01?nY
W/`4ojRLb@CoZI_80onaj_P00onfj_KoTW2Yoi9`Z@02oi9`Z@?oTg:Z1OnDM:`4oiIg[P03oiMj/OnH
LjSoV7>X00GoV7BY1?nHMZ/4oiMg[@CoUgV_00CoUg^boien/OnMO[7oWGja1OnMPK@4oif4]`;oWHNk
0ol000001?nMR[ooYY?2ojJC`_nVTl84ojJGaP05ojJKb_l0003oYY_:ojJKb_naZm801_na[]D00ona
/]Wo^/CRok[4hP02ok[4hP;o^LCS0onlcnT4ok_;iP;o^<o[5Oooool00ol0003oooooooooo`0eoooo
o`00;?ooool3o`0006Oooooo00?oD00[oeL0;omG02l00_mG02l2oed0<@CoH@4b0omS0S43of80;`?o
G`0[0_mJ02L2oeP0;`04oe@0:_nYXlooZJ??ojVSc`CoZIk<1OnXW<T00onYVlSo/N[hok7Zn002ok7Z
n0;oTVnX1?nBL:T3oi=bZPGoU7B/0_nFMjh2oiQbYPCoV7>X1?nHM:T4oiQfZ`GoUgN]0_nGNJl00onM
O:ooWGjaoien/@03oien/@CoWH6d0onMQ;L3o`0000;oWHNk00?oYY2nojJC`_nVTl800_nVTl85ojJG
aP03ojJKb_l0003o/J_B00;o/J_B1?na[]D00onkaN;o^/CRok[4hP03ok[4hP03okW4honlcnWo_<oY
00?o_<oY00?o^l_VokS?jonhcn/00onhcn/Dooooo`03o`000?oooooooooo03Gooooo000/ooooo`04
o`000?oooooo0000o`0006Cooooo0om@02/3oeL0;`?oG@0a0omQ0C84of<2<@03of80;omO13[oG00e
00?oG00e0omH02l00on[ZMGoZJ??ojVSc`03ojVSc`CoZIk<0_nXW<T4oj_Yn@03ok7Zn?nBKjSoTVnX
00;oTVnX1?nBL:T4oi=bZP?oU7B/00?oUg2UoiQbY_nHLZH00_nHLZH4oiQcZ0CoV7BY1?nHMZ/5oiMg
[@03oiMi[onMO:ooWGb_00GoWGja1?nMPK@3o`0000;oWHBg00?oWHNkojJ@__nVT;h00_nVT;h3ojJC
`PCoYYO600?o/JS?ok6[d_l000001?naZm800ona[]Go^lGRok_5hP02ok_5hP?o^/CR0_nmeN`4okc?
j@;o^=Wa1?nhcn/00on_cNooooooooooo`0Aooooo`03o`000?oooooo000000Sooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<01Wooooo000/
ooooo`;o00000_ooool00ol0003oooooooooo`1Oooooo`04odT09Om@02_oD00[oe00:`CoE`0_0omM
0343of41<P03of<2<OmQ23ooH@Po00?oG`@j1?mL03D00omH02ooZjWEoj^Ye@02oj^Ye@CoZJ??0onY
W/`4ojCXn`;oZnWi0_nCL:P4oi9_Z0CoTW2Y1?nCLZX01?nDM:coUg2UoiM`YOnGL:D5oiQbYP?oV7>X
1?nHM:T5oiQfZ`?oUgN]00?oWG^]oiel[onMO:l00_nMO:l4oien/@05oif1]?l0003o0000o`000?nM
PK@00onMQ;L00onWS[coYY2nojJ@_P03ojJ@_PCoYY?200?oYYO6ok6XconaZ<l00_naZ<l01OnaZm;o
0000ok6[d_naZm;o_LOR00Ko^lGR00?o^/CRokgEk?nmeN`00_nmeN`00onlcnWo^=WaokSIl@03okSI
l@03okS?jon_cNoo[lg_00;o[lg_5Oooool00ol0003oooooooooo`05ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0Iooooo`00:oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo05gooooo0_m902D3oe00:`?oE`0_0omM0342
of41<P03of8;@_mQ23ooH@Po00;oH@Po0omO13X3oe`0=@03ojbag?n[ZMGoZjWE00?oZjWE1OnYXll0
0onYW/coY>SkojCXn`02ojCXn`;oUW>Y0onCL:P5oi9_Z0?oTW2Y0_nCLZX2oiE^X`GoUg2U1?nHLZH3
oiQcZ0CoV7BY1OnHMZ/01?nGMjgoWG^]oiek[OnMNjd4oiel[`?oWGja0_l00004oif1]003oif4]onW
S[coYhjl00;oYhjl1?nVT;h3ojJC`P03ok:WcOnaZ<oo/JS?00?o/JS?0_naZm801?l0003o_LORokg7
h_nman84ok_5hP03okgLkonmeNco_MG/00;o_MG/0_nfi?H4okSIl@03ojgGm_n_cNoo[lg_00?o[lg_
5Oooool00ol0003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003o
oooooooooooooooo000001Wooooo000[ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0F_ooool00om3023oB@0UodT09@03oe00:`CoE`0_00?oG@0aof<<@omS34<00omR2d83of48?`?o
G`@j0_mL03D4ojbag0GoZjWE0_nYXll4oi_Vo003ojCXnonFLjWoUW>Y00;oUW>Y1?nCL:P4oi9_Z0;o
TW2Y00?oTf^RoiE^XonEKZ<00_nEKZ<5oiM`Y@CoV7:V0onHLjP5oiQdZ@?oV7J[00?oW7Z/oiek[OnM
Njd00onMNjd3oiel[`?o00000_nMO[43oif1]003ojN=^_nWS[coYhjl00?oYhjl1OnVT;h01?nVTl;o
/ZO=ok:WcOnbYld5ok6Xc`03ok6[d_l0003o_LOR00?o_LOR00?o^lGRokgLkonmg>l00_nmg>l00onm
eNco]^CfokKTmP03okKTmP03okSIlOn]eoKo[MOf00;o[MOf0_n_cNl3ojC7lAGooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q
8@0Iooooo`00:oooool3o`0000Gooooo00?o0000ooooooooool0Eoooool3od<080;oB@0U0om@02/0
0omG02ooH`a3of<<@`04of<<@`?oHP]20omQ23l2oel4>P;o[KWR1On//M`4oj^Ye@?oTnCl0_nKi_`3
oiUfZ`GoUW>Y0onCL:P4oi9_Z003oi9`ZOnCJj;oTf^R00CoUFjS1OnGL:D4oiQbYPCoV7>X1?nHM:T0
1?nHMZ_oW7Z/oiaj[?nLNZ`5oiek[@?o00001OnMO[400onMPKCoYhfjojN=^P02ojN=^PCoYhjl1?nV
T;h00oncY/co/ZO=ok:Wc@02ok:Wc@Co/JS?0_nnbn@01Onman;o0000okg7h_nman;o_NCb00Co_Mc_
0on_k_P2okKTmP?oYn;k0_n]eoH3oj7>m`GoY<Oa5Oooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<01Wooooo000[ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0E?ooool01?m001go@`0Pod<08?m30203odT0
9@03oe00:omR2T;oH`a300KoH`a30omR2d83of48?`03ojfmi_n]^N;o[KWR00?o[KWR1On//M`00on[
ZMGoTnCloi?To002oi?To0;oW7Z/1?nIMZ/5oiIcZ@?oTg2X0_nBKjP2oi1XX0?oTf^R1OnEKZ<4oiM`
Y@CoV7:V1?nHLjP2oiQdZ@;oW7V[1OnLNZ`01?nMNjgo0000o`000?l00004oiel[`?oWGja00?oYh^h
ojN=^_nWSKX00onWSKX5ojN>_003ojJ@__ncY/co/jK<00;o/jK<1?nbYld00onaZ<oo_/_Tokk;i003
okk;i003okg7h_l0003o_NCb00;o_NCb00Co_Mc_ojo^n?n_k_So[nkh1?nIj?/2ojORn`;oV]Gl1OnQ
c_L2ojC7l@;oVkka5Oooool00ol0003oooooooooo`03ooooo`05oa0@4?ooooooooooooooool@4100
2oooool00omEEEGoQhN7ooooo`0Kooooo`00:oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo05;ooooo0_m001d2od<080?oB@0U00?oD00[of8:@_mR2T801omS34<3of8;@P03of48?on]
_NKo[KgV00;o[KgV1On]^N82ojbag0CoS^?l00?oTnCloiil[_nLNZ`00_nLNZ`5oiUfZ`CoUW>Y0_nC
L:P00on?IiooT6RPoi1XX002oi1XX0CoTf^R1?nEKZ<4oiM`Y@GoV7:V0_nHLjP00onMNJ[oW7V[oiai
Z`02oiaiZ`?oW7Z/0ol00003oiek[@CoWGb_00?oWGjaojN;^?nWRkP00_nWRkP4ojN=^PCoYhjl00?o
]:O;ok>Vc?ncY/`00oncY/`3ok:Wc@;o`M7W1?nnbn@3okW]m@04o`000?nmi?;oW?7`oical0?oONG^
0_nIj?/2ohoIo`GoV]Gl0_nQc_L3oiS1l`CoVkka4oooool3o`0000Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01_ooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0COooool2o`000003od006om001go@00M00?o@`0P00?oB@0Uoel6?_mO
1Sh00omR2T87of<<@`;oHP]20_n/_NL5ojfmiP;o[KWR1?n=i?/2ohkSo0CoWWb^1?nLNZ`4oiUfZ`;o
UW>Y0_n?IYl3ohmWW`CoT6RP1?nCJj84oiE^X`GoUg2U1?nHLZH00onHLjSoWGVZoieiZP04oiaiZ`?o
00000_nLNZ`5oiek[@;oWGb_00?oYXZgojN;^?nWRkP00onWRkP5ojN=^P;oYhjl0ondYl/5ok>Vc003
ok:WcOo1dNOo`M7W00;o`M7W00?o_/_TokW]mOnikOD00_nikOD00omgi=Go0000oical003oggUkP;o
O]Wm1On?fOl2oi[Eo0?oUL;f1OnH`O<4oi^nlAGooooo00Wo0000ooooooooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410Iooooo`004?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo0ol0000:ooooo`03o`00
0?oooooooooo04Wooooo00?o1@00o`000?l000000om001/2od007@03od<08?mL0SWoG`Hn00?oG`Hn
0_mR2T87of<<@`03ojZii?n/_NOo[;gW00?o[;gW0on]_NH4oi;Wn`;oSNCk0onOOZl5oiil[P?oW7Z/
0_nIMZ/2oi5XW`CoSfJO0on?Iil5oi1XX0?oTf^R1?nEKZ<5oiM`Y@?oV7:V00?oWGVYoieiZ_nMNJX0
0_nMNJX3o`000003oiaiZonLNZcoW7Z/00;oW7Z/1OnMNjd01?nMO:ooYXZgojJ:]onVR[L4ojN;^0Go
Yhfj00?oYhjlokBWbondYl/00_ndYl/4ok>Vc003ol;Jjoo1dNOo`M7W00;o`M7W0on]m?800onikOGo
MnCEogOTe@02oe?@c`04o`000?mZe?SoJ]Chof[Dn0?oO]Wm0_n?fOl3oi72n0GoUL;f0_nH`O<2oiNd
k0CoV;O]5Oooool00ol0003oooooooooo`0_ooooo`002?ooool6o`0000;ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go00001Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
04Gooooo00Go3`00o`D00?l5003o0000od@07003od006`?o@00M0_mL0ST3oel6?P?oHPY21OmS34<4
ojZii0Go[;gW00Co[KgVoi;WnonBio_oT^Ok1?nNO[03oimn[`GoWWb^0_nLNZ`00onBJJ3oTFROoi5X
W`02oi5XW`CoSfJO1?n?Iil4oi1XX0?oTf^R1?nEKZ<5oiM`Y@04oiQbY_nMNJWoWGVYoieiZ@;oWGVZ
0_l00004oiaiZ`GoW7Z/0onMNjd00onVRKKoYXZgojJ:]`02ojJ:]`GoYh^h0onWSKX00oneZ<co]:O;
okBWb`04okBWb`03ok>Vc?o2f^_o`][[00;o`][[00?o`M7Wojgdl_n]m?800_n]m?800ol0003oB<C/
oeK;l003oeK;l004of[Dn?l0003oR[_fohZkmPGoS;oh1?nA`_P2oiG2mP;oU[3Y1OnG]>`4oiRgkAGo
oooo00?o0000ooooooooool0;_ooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`13oooo
o`;o3`0000CoB00Lod@07?m401coA00L0_m001/2od007@04oeP0<omL0SWoG08ioe`2>@?oG`Hn0omR
2T82of<<@`;oZ;;O1_nZ^N@2ojbmi`?oVn[j0onLOK44oiin/0CoWgj_0onNO:h01?nDK:7oTVVPoi9Y
X?nBJJ04oi5XW`CoSfJO1?n?Iil4oi1XX0?oTf^R1OnEKZ<3oiM`Y@04oiehZOnMNJWoWGVYoieiZ@?o
00000_nMNJX4oiaiZ`GoW7Z/00?oWG^]ojJ9]_nVRKH00_nVRKH3ojJ:]`GoYh^h00?oYhfjokFXc?ne
Z<`00_neZ<`4okBWb`;o`NK`0oo2f^/3oi;`h@03ojgdl_n;[>coRjc/00?oRjc/0on9]?800on:^oKo
0000ohZkmP02ohZkmP;oS;oh0_nEXml5oiJZi@CoU[3Y1?nG]>`2oiRgk@?oVkGZ5Oooool00ol0003o
ooooooooo`0]ooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoo
oooo00001_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03oooooo00Co3@00o`l0
0?l?003o3`000_m801`2od@070?o@00K0omH03<2oe`2>@CoG`Hn0_mR2T800onV[=_oZ;;OojRbg`03
ojRbg`CoZ[WT0onSkOT00onKj_[oVG^aoiUk/@03oiam/@GoWWj`0onOOZl01?nNO:koU6bQoiA/XOnD
K:43oi9YX0GoTFRO0on?IYl4ohmWW`CoT6RP0onCJj85oiE^X`;oUg2U0_nMN:T3o`0000;oWGVY0onM
NJX5oiaiZ`?oW7Z/1_nVRKH4ojJ:]`?oYh^h00?o]Z_>okFXc?neZ<`00oneZ<`3okBWb`Co`NK`00?o
`][[oi;`hOnBl>401?n>X^85oh^/k0?oRKCb00CoR[_fo`000?nFW=SoUYcH1OnEXml5oiJZi@?oU[3Y
0_nG]>`3oi^_iPGoVkGZ5?ooool00ol0003oooooooooo`0]ooooo`004?ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool2o`0000oooooo0_l0000looooo`04o`40
0?l=003o3@00o`l000;oB`0L0_m801`3od@07003od006omE02koF00c00;oF00c0omL0ST3oel6?P03
of8:@_nV[=_oYZcK00;oYZcK1OnX/]l01OnZ^NCoXngioj?]nOnSkOWoUWVa00CoVG^a0onLOK45oiin
/0;oWgj_00?oUVfRoiA/XOnDK:400_nDK:44oi9YX0CoTFRO0on?IYl4ohmWW`CoT6RP1?nCJj84oiE^
X`05oiM`YOl0003o0000o`000?nMN:T01?nMNJT3oieiZPGoW7V[00?oW7Z/ojJ9]_nVRKH01_nVRKH4
ojJ:]`03ojN;^?nfZlko]Z_>00;o]Z_>1OneZ<`00ondYl_o`NK`ol7Vl002ol7Vl0CoTISF1On>X^82
oh^/k0;oUhc60onFU<l2oiJLf003o`000?nFW=SoUYcH00GoUJ?O0_nFZ^D2oibSfPCoVjWP1OnK[nH2
oi^ejP;oXKKW5Oooool00ol0003oooooooooo`0/ooooo`004?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?ok^k^odA4A?l000001_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo03Sooooo0_l100000om;01WoB`0Lod/07002od/07003odP07?m401coA00L00;oA00L0_mE02h3
oeP0<`?oG08i0_mO1Sh2ojBXf@CoYZcK1?nX/]l2ojS]n004o`000?nFNK7oUWVaoiIi/@CoVG^a1?nL
OK43oiin/004oiI^XonFKJ;oUVfRoiI]XPGoU6bQ0onBJJ04oi5XW`CoSfJO0on?Iil5oi1XX0?oTf^R
0_nEKZ<3o`0000CoWGRY1?nMNJT4oieiZP?oW7V[00?oYXVgojJ9]_nVRKH02?nVRKH2ojJ:]`03okN_
dOnfZlko]Z_>00?o]Z_>1?neZ<`3ok_bl`03ol7Vl?nDS/_oU8k;00GoTISF0_n>X^82oiR6_PCoUhc6
1?nFU<l2oiJLf003o`000?nFW=SoUYcH00;oUJ?O0_nMWM<4oibSfPGoVjWP0_nK[nH2oj6_h@GoXKKW
4oooool2o`0002kooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000
ooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0=Oooool3o`4000;oB`0I
0om;01`2odP07003od@07?mD02[oE00Z00;oE@0^0omH03<2oe`2>@;oY:OI1OnTZ=T4ojJ/f`04ojRb
gonXkOSoZ>ghojS]n0;oTgJ`0onFNK45oiUk/@?oW7fa00CoWWj`oiI^XonFKZ?oUVjS0onFKJ85oiA/
X@?oTVVP1?nAJ9l4ohmVW`?oSfNO1On@J:02oi=[XP?o00000_nMMjP5oiehZ@CoWGVY1?nMNJX01?nL
NJ_oYXVgojJ9]onVRKL:ojJ9]P04ojJ:]ong[m7o]joAokN_d@Go]Z_>00?o]JS<ok_blonkl_<00_nk
l_<00onGQl3oU8k;oiB>b`02oiB>b`;oTISF0_nJPKL5oiR6_PCoUhc61?nFU<l01?nFW=So0000oijG
cOnNUld5oifMd`CoW:?J0onKZN000onRZM_oXJoQoj6_h@03oj6_h@CoXKKW5Oooool00ol0003ooooo
ooooo`0[ooooo`00:Oooool2o`0001Cooooo00?o0000ooooooooool0<_ooool01?l0003o0@00odL0
4om701<2od/06@?oB`0L00?oB00Loe@0:?mD02X00omD02X2oeD0;P;oF00c00?oXj_LojBWfOnTYmT0
0onTYmT5ojBXf@;oYZcK0onWk?T4oi=f/0?oUWVa1OnINk42oiam/@03oiE^Y?nFKZ?oUVjS00;oUVjS
1?nFKJ84oiA/X@?oTVVP1?nAJ9l4ohmVW`CoSfNO0on@J:03o`000003oi]dYonMMjSoWGNX00?oWGNX
1?nMN:T5oieiZ@?oWGVZ1OnVRKL8ojJ9]P03okRce?ng[m7o]joA00;o]joA1?nfZlh3ojOgj@03ok_b
lonGQl3oUhO000;oUhO00_nDS//00onKOK7oVX6goiZ1]`03oiZ1]`CoV8Jn1?nGS<H2oiJDc`;oWi;6
0_nNUld00ol0003oWYO=oijGc@04oifMd`CoW:?J00?oVjWPoj:YfonRZM/00_nRZM/5oj6_h@;oXKKW
0_nY^nLEooooo`03o`000?oooooooooo02[ooooo000Yooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0;oooool00ol0003o@@0;odL04`03odL04`03od/06Om;01coB`0L00;oB`0L0_mD
02P3oe@0:P;oE@0^00?oF00coj>[g?nSZm`00_nSZm`4ojBWf@CoY:SI0onQj_X00onWk?WoTGB_oi5d
[`04oi=f/0CoUWVa0onINk401?nCKJCoUFjToiE^Y?nEKZ@4oiI^X`CoUVfR1?nDK:43oi9YX0CoTFRO
1?n?IYl4ohmWW`04oi1XX?l0003o0000oiQaY@?oVgBW1OnMMjP4oiehZ@GoWGVY0_nMNJX00onWRkSo
YXVgojJ9]`03ojJ9]`OoYXVf0onh/m@4okN_d@04okJ[c_nWmnWoYoOYojOgj@?oVH6g0onGQl000onM
NjcoVgfaoi]m/@02oi]m/@CoVX6g1?nHQ[h3oiN<aP03oj6>_onOT/KoWi;600?oWi;60_nNUld00ol0
003oWYO=oifMd`04oifMd`;oW:?J00?oXj?Eoj:YfonRZM/01?nRZM/2oj6_h@;oZKKR1OnY^nLDoooo
o`03o`000?oooooooooo02[ooooo000Yooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0:oooool3o`0000;o@@0;0om701<2od/06@03od/07?mE02KoE@0V00;oE00X1?mD02X00omE02ko
Xk3Qoj>`h@04oj>[g0GoY:OI00?oY:SIoj7Zn_nQj_X00_nQj_X01?n@LZgoTGB_oi5d[onAM:l5oi=f
/0?oUWVa00CoVG^aoi=]Y?nCKJCoTffT0onEKZ@4oiI^X`CoUVfR1?nDK:43oi9YX0CoTFRO1?n?IYl2
ohmWW`?o00000onHLJD4oi]dY`CoWGNX1OnMN:T4oieiZ@04oieiZ_nWRkSoYh^hojN;^0CoYXVg1_nV
RKH4okRce0?o]joA0_mjhl@00onJO;3oVH6goiV1]`03oiV1]`04oiN7`?nMNjcoWG^/oiek[0CoVgfa
1?nJPKL5oiR6_P04oiN<a_nQS[ooXHjooj6>_`CoWi;60onNUld01?l0003oWYO=oifMdonMWM<2ojFO
c`CoXj?E1?nRZM/00on[/]koZKKRojVfhP03ojVfhP?oZK_W0_n^`NPDooooo`03o`000?oooooooooo
02Wooooo000Yooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0:Oooool00ol0003o
>@01ocT00@02od402`?oA`0C00?oB`0IoeD09OmE02H00omE02H2oe@0:003oe@0:_nS]nOoXkOW00Go
Xk3Q1?nSZm`2ojBWf@CoU>Kl00CoXN[joi1b[On@LZgoT7:]1?nAM:l4oi=f/0;oUWVa00?oTVbSoi=]
Y?nCKJ@00_nCKJ@4oiE^Y0?oUVjS1?nFKJ84oiA/X@?oTVVP1OnAJ9l2ohmVW`?o000000?oSfNOoiE^
Y?nHLJD01?nHLJD3oi]dY`CoWGNX1OnMN:T3oieiZ@03ojR?^onWRkSoYh^h00;oYh^h1OnVRKL3ojJ9
]P03okVjf_nh/mCo^;?D00Co^;?D00?o]joAog[Sa?nJO;000onJO;03oiV1]`03oimjZOnMNjcoWG^/
00?oWG^/0onKOK45oiZ1]`?oV8Jn00?oXh^joj6>_onQS[l00_nQS[l4oinBaP?oWYO=00?o0000ojNK
b_nUWll01?nUWll4oj>Se@03oj:Yfon[/]koZk;N00;oZk;N1?nY]^800onY^nOo[/7Xojk1j003ojk1
j1Cooooo00?o0000ooooooooool0:?ooool002Wooooo0ol0000Gooooo`03o`000?oooooooooo02Ko
oooo00?o;`00ocT00Oli00400_li00401?m100_oA`0CodL04omD0283oeD09@?oE@0V0_nQ^^X5oj>g
i`GoXk3Q0_nSZm`4ohCPn`;oU>Kl00?oTG6[oi1b[On@LZd00on@LZd3oi5d[`;oTgJ`0_nAJZ83oi9/
X`CoTffT1?nEKZ@4oiI^X`?oUVfR1?nDK:44oi9YX0?oTFRO0ol000000on?IYooSfNOoiE^Y002oiE^
Y0GoV76U0onKM:L4oiegZ0GoWGRY00?oWGVYojR?^onXSk/00_nXSk/3ojN;^0GoYXVg00?oYXVfokVj
f_ni^]X00_ni^]X4okRce003o`000?nKN:_oVgR[00CoVWb`00CoVH6goimjZOnONZWoWgZY1OnMNj`4
oi]m/@CoVX6g00?oV8Jnoj>;^_nSRkX00_nSRkX3oj6>_`GoWi;600GoWYO=ojNKb_nWVl[o0000ojNK
bP04ojFOc`;oXj?E0_n//=X5oj^bgP;oZKKR0on``>H4ojk1j003ok35jOoooooooooo017ooooo0_l0
000Zooooo`00:Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02?ooooo00?o0000
obl00?l_00000oli0042od402`?oE00R0_mE02D00omE02KoX;WZoj2ijP04oj6jjPGoXkOW0_nS/>44
ogWLnP;oQ>3k0_nCLJT4oi5aZ`CoT7:]0_nAM:l00on@JJ7oTFZRoi5ZXP02oi5ZXPCoTVbS0onCKJ@4
oiE^Y0CoUVjS0onFKJ85oiA/X@?oTVVP0ol000001?nAJ9ooSfJOohmVWonBK:<4oiE^Y0GoV76U0onK
M:L5oiegZ0?oWGRY00?oZiBnojR?^onXSk/00onXSk/4ojN;^0?oYXVg00?o^L7QokVjf_ni^]X01?ni
^]X00onh/mCoVgFWoi]hZ`04oi]hZ`;oVWb`00?oXGVWoimjZOnONZT00onONZT4oiek[0CoVgfa0_nJ
PKL2ojF9]PGoXh^j1?nQS[l2oinBaP;oZIW61?nWVlX01Ol0003oYIo?ojFOconUWloo[jkG00Go[;3J
0on[/]h00ona`NGo/<3Vok30iP04ok30iP03ojk1j?n`aNWo/<GY00;o/<GY5?ooool00ol0003ooooo
ooooo`0Wooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
1Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo023ooooo00Co0000obL00?l_003o
;`000oli00400om100_oD@0Moe@08P02oe@08P03oeD09OnO/nOoX;WZ00CoX;WZ1?nQ^^X2oj>gi`Co
M=[h0_mig?X3oiEbZ0CoTg6Y0onALJ/2oi1b[@;oT6RP0on@JJ44oi5ZXPCoTVbS1?nCKJ@3oiE^Y0Co
UVjS1?nFKJ84oiA/X@?o00000_nAJ9l2oi5[X`?oTVbS1OnEKZ@4oiQaY@?oVgBW1OnMMjP00onMN:Wo
ZiBnoj^D_P02oj^D_PCoZ8nk1?nWRkP00onVRKOo^L7QokW1h@02okW1h@Co^K[J0onKMJL5oi]hZ`03
oiYl/?nQNJOoXGVW00GoWgZY1?nMNj`4oi]m/@GoYHVf1?nSRkX3oj6>_`03ojbI`onYVLKoZIW600?o
ZIW60onWVlX00ol0003oYi_:ojFOc`03ojn^e`Go[;3J00CoZk;Nok71iOna`NGo/L7U1?n``>H00ona
b>_o/<GYok35j@03ok35jAGooooo00?o0000ooooooooool09_ooool000kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Nooooo`03o`000?lW003o9`0000;o;`0000?o>@01
od`05_mA01d00_mA01d2oe@08PCoWk?W1OnP^NX2oj6jjPCoNmgi0_mdf_P2oiQcZ0CoUG:X1?nCLJT2
oi5aZ`03oi5XWon@J:3oT6RP00;oT6RP0on@JJ44oi5ZXPCoTVbS1?nCKJ@3oiE^Y0CoUVjS1?nFKJ80
1?nDK:7o0000o`000?l00002oi9YX003oi1[XonAJj?oTF^S00;oTF^S1?nBK:<4oiE^Y0CoV76U1?nK
M:L3oiegZ003ojnI`On[U;koZiBn00?oZiBn1OnXSk/2ojN;^003okS<jOni`N7o^L7Q00Co^L7Q00?o
^K[JoiYbY?nJLZ@00onKMJL4oi]hZ`03oj9iY_nQNJOoXGVW00;oXGVW1?nONZT5oiek[0;oVgfa00?o
YhRcojF9]_nURKH00onURKH5oj>;^P04oj6>_on/VL?o[9W3ojbI``CoZIW61?nWVlX00ol0003o[jkG
ojn^e`03ojn^e`;o[;3J0_nc`nH5ok71i@03ok30i_nab>_o/LS[00;o/LS[0_n`aNT3ojk7k1Cooooo
00?o0000ooooooooool09_ooool000Kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP06ooooo`;o00007Oooool00ol0003oooooooooo`0Kooooo`;o7@00
0_lW00000ol_003oA`0>od`05P02od`05P;oD@0M00CoE00Roif[hOnMZn7oWJ_Q1?nO/nL2oj2ijPCo
Q^;j0_mkgOT3oiUeZ0CoV7>X0onELZP2oi=aZ@;oTfVO0onAJ9l4oi1XX0CoT6VQ0onAJZ84oi9/X`Co
TffT1?nEKZ@3oiI^X`?oUVfR0_l000000onDK:7oTFbToi5/Y003oi1[X`CoTF^S1?nBK:<4oiE^Y0Go
V76U0onKM:L00onMMjSo[iW1ojnI`@02ojnI`@CoZiBn1OnXSk/01?nWRkSo^<cYokS<jOnhc>T4okW1
h@CoVW:T1?nKMJL2oi]hZ`;oXWVV1?nQNJL4oimjZ@GoWG^/00CoVgfaojN8/onWR;?oYhRc1?nURKH4
oj>;^P03ok2K`_n/VL?o[9W300;o[9W31OnYVLH01OnWVl[o/JkEok6^eOna[]Go000000?o[jkG00?o
]lSXok?3i_nc`nH00onc`nH2ok71i@?o//g]0onab>/2ojo=l0Go[/O/5?ooool00ol0003ooooooooo
o`0Uooooo`003_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Oooooo00Co5000oad00?lM003o7@00
0_lW0002odL03P03oiZKe?nKX][oVj;J00;oVj;J1_nMZn42oinci`CoTnKk0_n6h_X2oiYfZPCoVGFX
1?nHLjP2oiEbZ003oiAZWonCJIooTfVO00;oTfVO0onAJ9l4oi1XX0CoT6VQ1?nAJZ83oi9/X`CoTffT
1?nEKZ@3oiI^X`?o000000?oTVfToi5/Y?nAK:@00_nAK:@3oi1[X`GoTF^S0onBK:<4oiE^Y0GoV76U
0_nKM:L00on`W<Co[iW1ojnI`@03ojnI`@GoZiBn0onXSk/2okCJl`Co^<cY00?o^L7Qoi]bX_nKLZ80
1?nJLZ@4oi]eY`03oi]hZonRNJKoXWVV00;oXWVV0onQNJL5oimjZ@?oWG^/00?oZXRbojN8/onWR;<0
0_nWR;<5ojF9]P04oj>;^_n`Vl;o/9_2ok2K`PCo[9W31?nYVLH00one/MGo/JkEok6^e@03ok6^e@03
o`000?ngb>So]lSX00;o]lSX0onc`nH2ok;Cl@Go//g]00?o/LS[ojo=l?n_cO000_n_cO02ojk7k0;o
ZLG^5Oooool00ol0003oooooooooo`0Tooooo`003_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`0Nooooo`;o00005_ooool2oa@000;o
7@0000?o9`00oiRFd?nHU]001?nJVm@4oi^RfPCoWJ_Q0onKio/2oi?Vn`?oVWR/0onJMZX4oiUeZ0Co
V7>X00?oUG:XoiAZWonDJYl01?nCJIl4oi5XW`?oT6RP1?n@JJ44oi5ZXPCoTVbS0onCKJ@4oiE^Y0?o
00001?nBKJ@4oi5/Y0CoT6^S1?nAJj<3oi9/X`CoUFjT1OnHLJD01?nKM:Oo/9c4ok2La?n`W<@4ojnI
`@GoZiBn00?oZ8nkokCJlondf_<00ondf_<2okS<j@CoVg:R1OnJLZ@3oi]eY`GoXWVV0onQNJL5oimj
Z@04oiek[?nZR;;oZXRbojZ8/PCoYhRc1?nURKH00ondWl?o/9_2ok2K`P03ok2K`PCo[9W300?oZIW6
okFaeOne/MD00_ne/MD3ok6^e@03okWAk?l0003o]lSX00Co]lSX00?o/l?Vok;ClOnbdo400_nbdo42
ok;=k@;o[MCd1?n_cO02ojS:l@CoZLG^4oooool2o`0000Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Wooooo000>ooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`;o00008Oooool00ol0003ooooo
ooooo`0Aooooo`05o`T00?lD003o5000oad00?nGTld01OnHU]03oiZKe0GoVj;J00CoWJ_Qoi_WnonK
io_oVnOk1?nJNZh3oiYh[0CoVWJZ0onIMJP2oiQcZ0;oU6^P0onDJYl4oi=YW`CoTFRO1?n@J:03oi1Y
X@CoTFZR1?nBK:<3oi=]Y004oiE^Y?l0003o0000o`0000?oTfjU1?nBKJ@4oi5/Y0CoT6^S1?nAJj<3
oi9/X`GoUFjT0onHLJD00on^VlCo/9c4ok2La002ok2La0Go[iW10_n[U;h4ojk[n@;o]=[c1?nMLZ84
oi]bXPGoVW:T0_nKMJL00onSNJGoXWVVoj9iYP03oj9iYP?oXGVW1?nONZT00on]Rk;oZXRbojZ8/P03
ojZ8/PCoYhRc0_nURKH3okBO``Co/9_20on/VL<00oni^=So]K7EokFae@04okFae@05ok6^eOnidNco
^M7/okWAk?l000000_ngb>P2ok7LmPCo/]?a0_nYg?T4ojgDm003ojo=l?nXb_7oZ<[a00?oZ<[a0_nY
aNh2ojG1kQCooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B402Oooool000kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool2o`0002?ooooo00?o0000oooo
ooooool03oooool00ol9003oUY7=oiJAc@04oiNCc@CoV9K@1?nJVm@2oi^RfP?oWNOl0onKO;04oiYj
[P?oVWR/1?nJMZX2oiUeZ003oiA/X_nDJj3oU6^P00;oU6^P1?nDJYl3oi=YW`CoTFRO1?n@J:03oi1Y
X@CoTFZR1?nBK:<01?nCKJCo0000o`000?l00003oiA_Y@CoTfjU1?nBKJ@3oi5/Y0CoT6^S1?nAJj<4
oi9/X`CoUFjT0_nHLJD3ojjKa0?o/9c41?n_VL43oiSajP;o[^_i1OnOM:83oiebXPCoVg:R1OnJLZ@0
1?nKMJOoXgVUoj=iYOnSNJD4oj9iYPCoXGVW0_nONZT2ojf;/PGoZXRb1?nWR;<00onURKKo]9o3okBO
``02okBO``Co/9_200?o[9W3okVhf?ni^=P00_ni^=P4okFae@03ok[Ol_nidNco^M7/00;o^M7/00?o
Z^Kjo`000?nag?H00onag?H00onbdo7oZMciojWLn@03ojWLn@;o[MCd0onVcoD2ojS:l@;oXlC`1OnU
`NhDooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`00
0?ooooooooooooooool000002Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
00cooooo00?oUI7=oiJAcOnFTLd00onFTLd3oiNCc@GoV9K@0_nJVm@4oi_Vo003oigWo?nLOk?oVgb`
00;oVgb`1?nJNZh4oiYh[0;oVWJZ00CoTffSoiA/X_nDK:;oU6bR1?nDJj04oiAZW`?oTfVO1?nAJ9l4
oi1XX0CoT6VQ0onAJZ82oi9/X`?o00001onDKjD3oi=^Y@CoTVfT1?nAK:@3oi1[X`CoTF^S1?nBK:<4
oiE^Y003oiQaYOn^VlCo[Y_400;o[Y_41?n`W<@01On_VL7oV?7ZoiSaj_nHlN[oUV^N00;oVG2R00?o
XgNRoimdX_nOM:800onOM:83oiebXPGoVg:R0onJLZ@00onRN:CoXgVUoj=iY@02oj=iY@CoXWVV1?nQ
NJL00onONZWo[H^bojf;/P02ojf;/PCoZXRb1?nWR;<5okBO``?o/9_200?o_l?NokVhf?ni^=P01?ni
^=P00one/MGo^]obok[OlP02ok[OlP03okWAk?nZi_[oZ^Kj00;oZ^Kj00?o0000ok7Lm_nOho`00onO
ho`2ojWLn@?oX=;i0_nVcoD2oj75lPGoXlC`0onU`Nh00onR_^goooooooooo`0Booooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S802Oooool002Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`04ooooo`03oi>D
dOnDT/ooU9;?00;oU9;?1?nETLd4oiJAc@?oUi?=1?nHU]03oi?So@;oVnKl00CoWX>foiao/onLOk?o
W7nc0onKO;04oiYj[PCoVWR/00?oVWJZoi=]XonCKJ<00onDK:84oiA[X0CoU6ZO1?nCJIl3oi5XW`Co
T6RP1?n@JJ42oi5ZXP?o00002_nDKjD3oi=^Y@CoTVfT1?nAK:@3oi1[X`GoTF^S0onBK:<2oiE^Y0;o
Z9K31On^Vl@3ok2La0;oL]k01?nFJih00onIL:;oXgNRoj=gXP05oimdXP?oWG:R1OnKLZ82oiYbY0;o
XWRT1?nSNJD5oj9iYP?oXGVW1On]Rk85ojZ8/P;oYhRc0_niYlH5okBO``04ok2K`_no`mko_l?Noko3
gPCo^KSH0_n`l?H2ok[OlPCoUN_g0_nZi_X00on;i?[o0000oh_TnP02oioSo0?oV=Cm0_nPd_T3oik4
l`CoXLGb1?nSa?000onU`NkoX[k]oj:nk@02oj:nkACooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c009ooooo`009oooool2
o`0002Kooooo00Co0000ooooooooooooTYKC1?nCU=44oiBBc`?oUI7=1?nFTLd4oiNCc@03oiRFd?nC
hogoTn?m00;oTn?m1?nNPkH4oiao/`?oVgb`0onJNZh2oiYh[0;oTVfU0onCKJ<4oiA/XP?oU6^P1?nD
JYl4oi=YW`?oTFRO1?n@J:04oi1YX@;o000000?oU6jToiA_YOnDKjD02_nDKjD3oi=^Y@CoTVfT1?nA
K:@4oi1[X`CoTF^S0_nBK:<00onQSL3oZ9K3ojRF``03ojRF``Go[Y_400Co/9c4oi9VVonBIY_oTVJK
1?nFJih4oj=gXPCoWgBR0onMLZ85oi]bXP03oiYbY?nRN:CoXWRT00;oXWRT0onSNJD5oj9iYP;oXGVW
00?o/I2dojf;/_n]Rk800on]Rk85ojZ8/P04ojN8/oniYlKo^JO6okVWaPCo]9o300?o`mOYoko3g_no
`mh00ono`mh01?ni^=So/?3fok3`m_n`l?H3of;If@;oUN_g0omWfN`2oh_TnP04ohkCo_l0003oS]?n
ohkCoP;oV=Cm0_nJ`?85oik4l`?oXLGb0_nSa?03oj6mk@CoX[k]5Oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Wooooo
000Wooooo`03o`000?oooooooooo027ooooo00?oT9WHoi6Ge_nAUmH00_nAUmH4oi:Fd`CoTiCA0onD
T/l3oiFAc@GoUY7=0_nGTld2oh[Oo@04oj>;^onPQ[SoX8Jhoj26^0CoWX>f1?nLOk<3oi]l/0;oVWZ^
00?oTVjWoi9]YOnBKJD00_nBKJD4oi=]X`?oU6bR0onDJj04oiAZW`CoTfVO1?nAJ9l3oi1XX004oi1Y
XOl0003o0000o`0000?oU6jT3?nDKjD3oi=^Y@CoTVfT1?nAK:@4oi1[X`CoTF^S00CoTVbSoj6=`?nQ
SL3oXHg01?nXU/<4ojjKa003oi1RVOnBIY_oTVJK00;oTVJK0onFJih00onUNJ?oXgNRoj=gXP02oj=g
XPCoWgBR1?nMLZ83oi]bXP03oj5hY?nRN:CoXWRT00?oXWRT0onSNJD5oj9iYP04oj5iYonaT;Co/I2d
ok6@]0Go[H^b0onZR;800oo0]Loo^JO6okVWaP03okVWaP03okBO`oo3enWo`mOY00;o`mOY0ono`mh3
oh7Yf@03ok3`m_mRfMWoH]WI00;o?/;D0_moa_h5oh?>o`;oS]?n00?o0000oiRjkonJ`?801?nJ`?82
oik4l`;oWkSZ1?nP^n`5oj6mk@;oX[k]0_nR^n/Booooo`?o00001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000009ooooo`009oooool00ol0003ooooooooo
o`0Kooooo`04ohjMgOn?Vm_oSi_KohnKf`CoT9WH1?nAUmH3oi:Fd`CoTiCA1?nDT/l3oiFAc@;oUY7=
0on0f_h01?nUSkkoXh^koj>;^onSRk/4oj26^0?oWX>f0_nLOk<2oi=aZ@?oTVnX0onBKZL4oi9]Y@Co
TffS0onDK:84oiA[X0?oU6ZO1?nCJIl4oi5XW`04oi1XX?l0003o0000o`0000?oUFjT1?nDKZ@;oiA_
Y@CoTfjU1?nBKJ@3oi5/Y0CoT6^S0_nAJj<2oiZ6_0CoXHg01OnXU/<01?n^VlCoT6:Ioi1RVOn@HYT4
oi9VV`;oUV^N0_nUNJ<4oj=gXPCoWgBR1?nMLZ82oi]bXP;oXGRT1OnRN:@4oj=iY@?oXWVV00?o]iVi
ok6@]?naT;@00_naT;@5ojf;/P04ojZ8/_o0]Loo`;G?ol2ec`Co^JO60_nkl_<4ol?Gj@04oko3g_n1
jMWoPNWIoh7Yf@;oS:WY1?n2^?P4ogo6oP;oPlko0_nF/>T2oiRjk`03o`000?nH^^ooV;[_00;oV/3b
0_nN/nH5oinhjPCoX;_/0_nQ_Nd2oj:hj@GoX[_[5?ooool02Ol0003oooooooooooooooook^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT02Oooool002Kooooo0ol0000E
ooooo`;oRZ3S0on<W^04ohjMg@?oSi_K1?n@VMP3oi6GePCoTYKC1?nCU=42oiBBc`CoLm7n0_mheOh4
ojF?_PCoXh^k0onPQ[P2oij3]P03oiAcZonCLJWoTg6Y00;oTg6Y0onBKjP4oi9^Y`?oTVfU1?nCKJ<3
oiA/XPCoU6^P0onDJYl4oi=YW`;oTFRO0ol00002oiI^X`GoUFjT0onDKZ@<oiA_Y@?oTfjU1?nBKJ@3
oi5/Y0;oT6^S0_nFOkP5oiZ6_0?oXHg01?nXU/<00on>GiKoT6:Ioi1RV@03oi1RV@?oTVJK00?oUV^N
ojEiXonUNJ<00_nUNJ<3oj=gXPGoWgBR0onMLZ800onKLZ;oXGRToj5hY002oj5hY0CoXWRT1?nSNJD2
oj9iYP?o]iVi0onaT;@4ojf;/P03olW?goo0]Loo`;G?00?o`;G?0_niYlH4ok_bl`;o`mOY0onDV]H5
ohbYj@;oP[Sh00?oVYWAoiRUg_nHYMh00onHYMh4oiJ`j@;oV;[_00?o0000oin]hOnN/nH01?nN/nH4
oinhjP;oX;_/0_nR]NH5oj:hj@;oX[_[0_nU_>XEooooo`03o`000?oooooooooo01kooooo000Voooo
o`03o`000?oooooooooo00Wooooo00CoP:S^oh>Vjon3Y^_oPjK[0on6Y>P3ohRRi@GoRZ3S0on<W^03
ohjMg@?oSi_K1On@VMP3oi6GeP;oTYKC1?m_boh3og3>oP;oLm7n1?nXU<44ojF?_PCoXh^k0_nPQ[P0
1?nFMZgoU7>[oiAcZonDLj/4oi=aZ@CoTVnX0onBKZL3oi9]Y@CoTffS0onDK:84oiA[X0CoU6ZO0_nC
JIl3o`0000GoUVjS1OnEKZ@3oiA^Y0coU6nU0onCKZD4oi9]Y0;oTFbT00?oU7bfoiIo^?nFOkP00onF
OkP4oiZ6_0CoXHg000CoZ9K3ohiOU_n>GiKoSUnF1On@HYT3oi9VV`GoYGVS0onSMj85oimdXP;oWG:R
00?oXWVVoj5hY?nQN:@00onQN:@4oj9hY0CoXgVU00?oXWVVokNI^OngVKT00_ngVKT4ok6@]0;o[H^b
0oo9cml4ol2ec`04okVWa_nkl_?o^o;cok_bl`CoWHo51?nDV]H2ohbYj@;oWY761?nJVM45oiRUgP;o
U[3Y00KoXJKJoin]hOnO[N7oWjgQo`000?nO[N44oijciP;oWkSZ0onS/N84oj:eiP;oX[SY0onU^NP4
ojFljQCooooo00?o0000ooooooooool07_ooool001_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06
ooooo`03o`000?ooooooLjkf00;oLjkf0omh[O@3ogb[l@?oP:S^0on3Y^/3ohJTj0?oR:;U1On:X><3
ohbNh0?oSYgM0on?Vm/2oi2If0CoL<Ko1?m_b?l2ofo;oP?o^kWH00Co^KGFojbIa?n/VLCo[9W40onX
U<45ojF?_P;oXh^k00CoV7V_oiIf[OnFMZgoUWJ]1?nDLj/3oi=aZ@CoTVnX0onBKZL4oi9]Y@?oTffS
0onDK:84oiA[X0?oU6ZO0ol00009oiI^X`CoUFjT0onDKZ@<oiA_Y@;oTfjU00?oUGZcoiAj]?nDN[@0
0_nDN[@4oiAl]PCoUWnh1?nJQ[`3oj6=`0;oSEfE0on>GiH5oi1RV@;oTVJK00?oYWZSojEiXonUNJ<0
0onUNJ<3oj=gXPGoWgBR00?oWG:Roj9iY_nRNJH01OnQN:@5oj9hY0?oXgVU1OngVKT4ok6@]003ojf;
/_o9cmoobLoO00?obLoO0_o0]Ll00om`g/;oY8ZiojB:^@02ojB:^@CoWHo50_nDV]H2oj><_0CoWY76
1OnJVM42oiRUgP;oY:7B1?nQY]X3oin]h@04o`000?nO[N7oW[?VoijciP;oXjgN1OnS/N82oj:eiP03
ojJgiOnU^NSoYKWX00CoYKWX0_nU_>X2ojNnjACooooo00?o0000ooooooooool07Oooool001_ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00?oLjkf0omh[O@3ogb[l@?o
P:S^0on3Y^/3ohJTj0?oR:;U0_n:X><3og6lo@?oL[km1Omb`Oh3og74o`;oL<Ko00?o`N;_ol7Ul?nm
_=T00onm_=T3ok^if003ojnOaon/VLCo[9W400;o[9W40onXU<45ojF?_P03oj>;^onHNJooV7V_00Co
UWJ]0onDLj/3oi=aZ@CoTVnX0onBKZL4oi9]Y@?oTffS1?nDK:83oiA[X0?o000000?oU6ZOoi=YWonF
KZ<02OnFKZ<4oiE^Y0?oU6jT2_nDKjD2oiMk/P?oUGZc1OnDN[@3oiAl]PCoUWnh1OnJQ[`01?nQSL3o
SEfEoheMUOn=GID4ohiOUPCoT6:I00?oTVJKojIjXonVNZ<01OnUNJ<4oj=gXP?oWgBR00?oYGnZoj9i
Y_nRNJH00_nRNJH4oj5hY0GoXWRT0_nSNJD2oknW`PGo]iVi0_naT;@2ol;ij`CobLoO0_n@NkP2ojV8
/PCoY8Zi0onMSlD00onXS;OoXhbloj><_003oj><_0CoWY760onJVM400onXWL_oY:7BojBQdP03ojBQ
dPCoXJKJ0_nO[N400ol0003oYJWIoj>]gP04oj>]gP;oXk7R0_nW]>84ojJgi@CoYKWX00?oZ;cXojNn
jOnW_^T00onW_^TCooooo`;o00007_ooool001_ooooo00Go410@oooooooooooooooooa0@4006oooo
o`;o00000_ooool3of^ZmP?oJjgg0om/[oP4offan@?oK[Cj0om_]_/4og2io0?oLKcm0omb__d2og;1
oP?o;[K@1?o1h^l00onn_m_o_KcIokflf@04okflf@04ok^if?n_WlOo[io7ojnOa`?o[9W41?nXU<42
ojF?_P;oVWfb1?nHNJl3oiIf[@?oU7>[1?nCLJT3oi9_Z0?oTVjW1?nBKJD4oi=]X`?oU6bR0ol00002
oiAZW`;oUFnT2onFKZ<4oiE^Y0CoU6jT1_nDKjD00onIOK;oUg^boiMk/P02oiMk/PCoUGZc1?nDN[@3
oiAl]PGoUWnh0onJQ[`00on=GICoSEfEoheMU@02oheMU@CoSUnF0on@HYT00onUNZCoYWZSojIjX`02
ojIjX`CoYGVS1?nSMj82oimdXP;oYGnZ1?nRNJH4oj5hY0GoXWRT00CoXgVUoknW`_noYl;o_jO21Ong
VKT00onaT;Co`_W[ol;ij`02ol;ij`04olW?gonHMjcoV7N/oi1k^0?oZHRb1OnTR[T01?nMSlGoZ8bg
ojR<]onXS;L4oj><_0CoWY7600?oVYWAojRMbonXWL/00_nXWL/4ojBQdP;oXJKJ0_nXY]@3ojFYf@03
o`000?nUZMWoXjgN00;oXjgN00?oZK;OojNdh_nW]>800onW]>84ojJgi@03ojFij?nX_>SoZ;cX00;o
Z;cX0onW_^T00onY`>[oooooooooo`0@ooooo`03o`000?oooooo000001kooooo000Kooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`?oJj[f0om[[OL3ofb_n0Co
KK7i0om^]?X3ofnfn`;oL;Wl1?m?`o@2odK2k0;o9k:m0_n`koL4ol7MkP04ol7Rkonn_m_o_[oKokjo
f`Co_KcI00?o/ZC;ojnOaon_WlL00_n_WlL4ojbIa0;oZ9C100?oWH6eoiYm/_nJOK800_nJOK84oiQi
[`?oUWJ]0onDLj/4oi=aZ@?oTVnX1?nBKZL3oi9]Y@CoTffS00?oU6bRo`000?l000000_nDJj000onC
KZKoUFnToiE_Y002oiE_Y0_oUVjS1OnEKZ@3oiA^Y0GoU6nU0_nIOK85oiMk/P?oUGZc1?nDN[@4oiAl
]PCoUWnh00CoVXJloheMU?n=GICoSEfD1On=GID3ohiOUP;oT6:I0_nUNZ@4ojIjX`CoYGVS1?nSMj80
0onOM:;oYGnZojEoZP02ojEoZP?oXWVV1OnQN:@3oj9hY003ol[0dOnoYl;o_jO200;o_jO21?ngVKT2
o`0000;o`_W[1?nHMj`00on`RjooZHRbojV8/P02ojV8/PCoY8Zi00?o/I6eojR<]onXS;L00_nXS;L5
oj><_0;oWY7600?o[9_6ojRMbonXWL/00onXWL/3ojBQdP03ojbUd?nXY]CoZ:KD00?oZ:KD0onUZMT0
0ol0003oXjgNojVbg`03ojVbg`CoYkCR0_nV]nD3ojVkiPCoZ;cX00?oYkkYojW0j_nY`>X00_nY`>XD
ooooo`03o`000?oooooooooo01_ooooo000Kooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`03ooooo`CoL:gf0om//_X3ofRgo0CoHk_m0omM_od2oeO2nP?oCLS[0omEd=d0
1?n3j>co/>ogok3_mon`koL4ol7MkP03oko1g?nn_m_o_[oK00?o_[oK00?o_KcIok:TbonbY</00_nb
Y</4ojnOa`;o[9W400CoWhJhoif1]OnMPKGoWH6e1?nJOK84oiQi[`?oUWJ]0onDLj/4oi=aZ@CoTVnX
0onBKZL3oi9]Y@;oTffS0ol000000onDK:;oTFjWoi=^YP02oi=^YPGoUFnT2_nFKZ<5oiE^Y0?oU6jT
0_nDKjD2oi]n/PCoVGfb1?nGNk83oiEj/`GoU7Zd0onDO;H2oiIo^0?oSEbC0on=GI@5oheMU@?oSUnF
00CoT6:IojEjY?nUNZCoYGZT1?nVNZ<5ojEiX`?oXgNR1OnUOjX3oj9iYPGoXGRT0_nRN:@2ol[0d@Go
_jO20_ngVKT2ojMlY0CoWgNV0_nHMj`3ok2;[`CoZHRb0_nTR[T3ok6A]@?oZ8bg1?nSS;`00oncW/?o
[9_6ojbKaP02ojbKaPGoZ9g;00CoY:7BojbUd?n/YM3o[:G@1OnXY]@2ojFYf@03o`000?n//]coZK;O
00CoZK;O0_nW]>82oj^ji@GoZK_V0_nX_>P2oj[0j@?oZL3Z00?oZ/;[ooooooooool04oooool00ol0
003oooooooooo`0Jooooo`006oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000oooo
ooooool01Oooool4og2]mP?oK;;j0omX]o`2of>ko@CoJLSn0_mMboP2ofcIl`?oTnSi0oncj?L2ol3I
k0?o`Mg^0ono`M`3okjof`03okBYc_nbY<_o/ZC;00?o/ZC;0on_WlL01?nSS;coWhJhoin6^?nOQ[P4
oif1]@CoVWfb0onHNJl3oiIf[@CoU7>[0onCLJT4oi9_Z0?oTVjW0_nBKJD3o`0000;oSfjY0onAKZL4
oi=^YPCoUFnT2onFKZ<4oiE^Y0;oU6jT00?oWH2coi]n/_nKO[800_nKO[84oiUm/PCoUg^b0onEN[<5
oiAj]0;oU7bf1_n=G9<3oheMU0GoSEfE0on>GiH5ojEjY0?oYWZS1OnUNJ<2oj=gXP03ojn>/onUOj[o
YGnZ00?oYGnZ0onRNJH5oj5hY003oj9hY?o:`=7ob/3A00;ob/3A1?noYl801?ngVKWoYgbTojMlY?nW
O:@4oimgYP03oiQg[?n`Rjoo/8^_00;o/8^_1?nYR;800onTR[Wo/I6eok6A]@02ok6A]@CoZ8bg0_nS
S;`3ok>N``?o[9_61?nXWL/00onbZ<ko[:G@ojbUd002ojbUd0CoZ:KD00Ko/;?Kojbbg?n//]co[;;L
o`000?n//]`2ojVbg`;o[K_T1On[^^D2ojVkiP;oZl3Y1OnZ`>T01?nY`>[oZ/;[oj[2jonZ`^/Doooo
o`03o`000?oooooooooo01[ooooo000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`00
00Oooooo0_m`[OH2ogncm@CoN[_k1?mc`oh2ofW8oP;oOMSn1?nMh_d01?nCj?Wo/nSgok?Xmoncj?L4
ol3Ik003ol7Mk_no`Mco_l7L00?o_l7L00Co_[oKokBYc_ndZLko]:W>1OnbY</01?n_WlOoXhbloj><
_?nSS;`3oin6^0?oWH6e1?nJOK84oiQi[`?oUWJ]0onDLj/3oi=aZ@;oTVnX0_n>Kj/2ohe^Z`?o0000
00?oSFfZohm^ZOn?KZT00_n?KZT4oi5^Y`?oTfjV1?nEKj@;oiI^X`?oUFjT00CoWh>doif0/onMP;?o
WH2c1OnKO[83oiUm/PCoUg^b1?nEN[<3oiAj]0;oSUfC1on=G9<4oheMU0CoSEfE0_n>GiH00onSNJCo
YGZTojEjY003ojEjY0?oYWZS1OnUNJ<01?nSMj;o[hjcojn>/on_S[<4ojEoZPCoXWVV0onQN:@00oo?
j>Sob/3Aol[0d@03ol[0d@?o_jO20_n_Q:H4ojMlY0?oWgNV1On`Rjl4ojV8/PGo/I6e1?nXS;L00onS
S;co/ik3ok>N``02ok>N``Co[9_600?oZ9g;ok:Xc_nbZ<h00_nbZ<h4ojbUd003ojRVe?n`/m_o/;?K
00;o/;?K0on//]`00ol0003o[K_Tojfki003ojfki0;oZk[U0_n/`^T5oj_0j@;oZ/3Y0_n[`n/5oj[2
jaCooooo00?o0000ooooooooool06Oooool001_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`03o`000?oooooooooo00Oooooo1?mo/oD2ogZkn`?oSlGj1?n8d?l00ommf?koWN;moigRo@02oigR
o@?o]Moe0_nodnT3ol3Ik0?o_l?L0ono`M`00ong[]7o]:W>okBYcP02okBYcPCo/ZC;00?oYY70oj><
_?nSS;`00_nSS;`3oin6^0?oWH6e1?nJOK84oiQi[`?oUWJ]0_nDLj/01?n@LJgoSg2/ohm`[?n?L:`3
ohi_Z`?o000000?oSFj[ohe]Z_n=KJX00_n=KJX3ohm^Z@CoTFjW0onCKZH4oiE_Y0_oUVjS00CoUFjT
oin3]?nOPkCoWh>d1?nMP;<4oi]n/P?oVGfb1OnGNk83oiEj/`03oiAj]?n>GI?oSUfC00;oSUfC1on=
G9<4oheMU0CoSEfE00?oSUnFoj=iY?nSNJ@01OnUNZ@4ojIjX`?oYGVS00?o`[79ojn>/on_S[<00_n_
S[<4ojEoZPCoXWVV0_nQN:@3oloXj0Cob/3A00?o_jO2ojn4Y_n_Q:H00_n_Q:H4ojMlY0;oWgNV00?o
]I2`ok2;[on`Rjl01?n`Rjl2ojV8/P;o^Ybi1OnaTKD2ojR<]`03okVTa?ncW/?o/ik300?o/ik30on/
VlH00onh[m7o/ZS>ok:XcP03ok:XcP;o[:G@0onc]m`4ok2cf`05ojbbg?n__^Go[kkUojnniOl00000
0on]^n@00on]aN_o[<;Yojc2j@03ojc2j@;oZl3Y0on[aNd4oj_3j`;oZ/;[0_nY`^/Dooooo`03o`00
0?oooooooooo01Wooooo000Uooooo`03o`000?oooooooooo00Sooooo0_mo/oD3oi:jlPCoSlGj0_n8
d?l3oj;GnP?o]MGa00?o]MoeokoCjOnodnT00onodnT00oo0fNco_l?Loko3g003oko3g004oko1g?ng
[]7o]jkAokN^d@Co]:W>00Co/ZC;ojJA`?nVTL3oYY701?nSS;`3oin6^0CoWH6e0onJOK82oiQi[`;o
TWJ`0onALjh3oi1a[@?oSg2/0ol000000on>Kj_oSFj[ohe^Z`02ohe^Z`?oSFfZ0on?KZT4oi5^Y`?o
TfjV1?nEKj@:oiI^X`03oj66]onOPkCoWh>d00;oWh>d1?nMP;<4oi]n/PCoVGfb1?nGNk82oiEj/`Ko
SUfC1on=G9<4oheMU0?oSEfE00?oXGNUoj=iY?nSNJ@00_nSNJ@4ojEjY0CoYWZS0_nUNJ<3ol:ab@?o
[hjc1OnUOjX3oj9iYP03oj5hY?o?j>SocnSX00?ocnSX0_o:`=400onWOZOo[hBVojn4YP03ojn4YPCo
YgbT00CoWgNVokF@/?neT;3o]I2`1On`Rjl01?nYR;;o^YbiokZL^OnjW;T5ok6A]@04ojR<]oniY<Co
^JC4okVTa0Go/ik300Co[9_6okR_dOnh[m7o^:oA0onbZ<h00onh`>3o/kOLok>gg004ok>gg0;o/;?K
0_ncaNP3ojnni@03o`000?n__^Go[K_T00?o[LG[0on/`^T2oj_7kPGoZlG]0_n[`n/2oj[4k0CoZL;[
4_ooool00ol0003oooooo`00000Jooooo`009Oooool00ol0003oooooooooo`0:ooooo`CoT[[b0_n?
aOX4ojC;m004oj;Gn_neeO7o]MGaokGEl@?o_LkW0onodnT2oko3g@Co_l?L00?o^K?CokN^dOng[]40
0ong[]42okBYcP03ojVHa?nVTL3oYY7000?oYY701?nSS;`3oin6^0?oWH6e0_nJOK800onCN;;oTWJ`
oi9f/002oi9f/0?oTG>^0on@LJd3o`000004ohm`[?n>Kj_oSVn[ohi_Z`CoSFj[0on=KJX4ohm^Z@?o
TFjW0onCKZH5oiE_Y0SoUVjS0_nQQ[L4oin3]0CoWH2c1OnKO[83oiUm/P;oUg^b0on?GY@7ohiMT`Oo
SEbC1?n=GI@2oheMU@;oXGNU1?nSNJ@4ojEjY0CoYWZS00?oYGVSol:abOo2/LT00_o2/LT3ojn>/`Go
YGnZ0_nRNJH3ohKZbP;ocnSX0_nXOJD2ojMnY`;o^i>^1?n_Q:H4ojMlY0Co]I2`1On`Rjl4okZL^@Co
/I6e00?o`[C=okVTa?niY<@00_niY<@4ok>N``03ol70fOnh[m7o^:oA00?o^:oA00Co/ZS>okS0h?nh
`>3o^<3P1?nc]m`00oncc^ko/lGXok?5j003ok?5j0;o[kkU00?o[/W^o`000?n]aN/01?n]aN/00on/
`^WoZlO^oj_7kP02oj_7kP;oZlG]0_nYaNh5oj[4k0;oZL;[0_nX`^`Dooooo`03o`000?oooooooooo
01Oooooo000Uooooo`;o00003?ooool2oi:jlP?oYKo/0_nTbo@4okC;k003okGElOnmc^Oo_LkW00?o
_LkW00?o_m?Yoko3gOno`md00_no`md00ono`mco^K?CokVcd`02okVcd`?o]jkA00?o[Ik8ojVHa?nY
V<@00_nYV<@4ojJA`0CoXhbl0onOQ[P2oif1]@04oiEl]OnCN;;oTgRboi=h/PCoTWJ`1?nALjh2o`00
0004oi1a[On?L:coSg2/ohm`[0CoSVn[0on=KZ/3ohe]ZPCoSfjY0onAKZL4oi=^YPCoUFnT1OnFKZ<2
oj::^`CoXHJg1?nOPk@4oif0/`CoVgjb0_nIOK83oi1PU@?oSejD1on>GI<7oheLT`CoSEfD00CoSEfE
oj5gYOnQMjGoXGNU1?nSNJ@5ojEjY0?oYWZS1Oo2/LT3ojn>/`GoYGnZ00CoXWVVohKZb_n6j/[oQ^[:
1OnXOJD01?nWOZOo^i>^ok^C[_nkTjh5ojn4YP?oYgbT1?neT;04ok2;[`;obkO61?njW;T2ok6A]@?o
`[C=1?niY<@00oncW/?o`L3Iol70f@02ol70f@?o^:oA00?o^LgYokS0h?nh`>000onh`>000onc]mco
/lk^ok?>kP02ok?>kP?o/lGX00?o[Lobojk9k_n^bNh00_n^bNh00ol0003o[LG[ojg5j`03oj_;l@;o
ZlO^0_nXao05ojW5kP;oZ/C/0_nX`nd5ojS2k1?ooooo00?o0000ooooooooool05oooool002Cooooo
00?o0000ooooooooool03Oooool3ojFok0?o//;V0ondbn`2okc9i0Co_LkW0_noa=h3oko3g@;o^kSF
1Oni/m<01?ng[]7o[Ik8ojfNb?n]W/P3ojVHa0CoYY700_nSS;`2oiZ5^`?oUh2h0onEO;D4oi=h/P?o
TWJ`00CoTG>^o`000?l0003o00000on@LJd3ohm`[0CoSVn[0on=KZ/3ohe]ZPCoSfjY1?nAKZL3oi=^
YPCoUFnT0_nFKZ<00onPSL3oXXZkoj::^`02oj::^`CoXHJg1?nOPk@4oif0/`;oVgjb00?oDlk3oi5R
UonAHYL01?n@H9D3ohmNU0OoSUfC1on=G9<3oheMU003oiieYOnQMjGoXGNU00;oXGNU1?nSNJ@5ojEj
Y0;oYWZS0_o=om`5ol:ab@?o[hjc0onUOjX2ojZ1Z0?oZGjU1OnXOJD4ok^C[PGo[hBV0_nWO:@2okbL
]`Co]I2`0_n`Rjl3ol^gaPCo^Ybi00?o/I6eol:dcOo2]<d00_o2]<d3okVTa003olGMjoo1`=Wo`L3I
00?o`L3I00?o^:oAokW=jOnicNT00_nicNT3okS0h0;o/=cf1?ncc^h00oncaNSo[Lobojg?lP02ojg?
lP;o[/W^0_nXco@01?l0003oZl_aoj_;lOn[bo42ojO9lPCoZ<O`0_nYaNh3ojO4kPCoZ<?]0_nX`^`2
ojO1k1Cooooo00?o0000ooooooooool05_ooool002Cooooo00?o0000ooooooooool03_ooool00onU
_nco//;Vok;2iP03ok;2iP03okC;k?nlbNCo_<WT00;o_<WT00?o_LkWoko4g_noa=h00onoa=h00ono
`mgo^kSFok^heP02ok^heP?o^K?C00?o/:G=ojfNb?n]W/P00_n]W/P3ojVHa0?oYY7000?oWHZooiZ5
^onJQK/00_nJQK/4oiN0^0?oUGbe0onCN;801?nBM[3o0000o`000?l00003oi5c[P?oT76]0on?L:`4
ohi_Z`?oSFj[1?n=KJX3ohm^Z@CoTFjW0onCKZH2oiE_Y0;oW9361?nPSL03oj::^`CoXHJg1?nOPk@3
oif0/`;oBLJc00CoTV>Ioi5RUonAHYOoTF:G1?n@H9D3ohmNU0OoSUfC1on=G9<01?n=GICoWWFUoiie
YOnNMJD4oj5gY@CoXgVT1OnUNZ@00onVNZ?ocOoLolgog002olgog0Co`[790on_S[<00onUOj[oZX6X
ojZ1Z002ojZ1Z0?oZGjU1OnXOJD4ok^C[PGo[hBV00CoYgbTokbL]onlW;Oo_9bg1?neT;000on`Rjoo
bkO6ol^gaP02ol^gaP?o^Ybi00?oam;Rol:dcOo2]<d01?o2]<d01?niY<CoaMg[olGMjoo5gN/3ol70
f@;o/^;g1OnicNT00onh`>3o/=cfok3LmP02ok3LmP;o/lk^0onWe_P2ojg?lP;oY=;h0onXco@00ol0
003oZ<odoj_;l@04ojO9lP;oZ<O`0_nVaNl5ojO4kP;oZ<?]1_nW`N`Dooooo`03o`000?oooooooooo
01Gooooo000Tooooo`?o00003oooool4ok;2iP;o^/?Q0onlbN@6oko4gP03okblfOnk^=Ko^kSF00Co
^kSF00Co^K?Cok2UcOn`YLgo/:G=0on]W/P4ojVHa004ojJA`?nMR[ooWHZooif:_`CoVXFk0onGP;P3
oiEl]@04oi=h/_l0003o0000o`0000?oTWJ`0onALjh3oi1a[@CoSg2/0on>Kj/4ohe^Z`?oSFfZ0on?
KZT4oi5^Y`;oTfjV00?oUHo;oib@a_nLT<H00onLT<H3oj2=`0CoXXZk1?nQQ[L3oin3]003oif0/om9
a[?oTVFK00?oTV>I0onAHYL4oi1PU@?oSejD1on>GI<6oheLT`03oi]cYOnNMJGoWWFU00?oWWFU1?nQ
MjD4oj=iY0?oYGZT0_nQMJ84oj1bW`CoWW2M0_nLKI`00onYQ:goZX6XojZ1Z003ojZ1Z0CoZGjU0onX
OJD2olfa_`?o^i>^1?n_Q:H00oo4/l[o_9bgokbL]`02okbL]`Co]I2`1_o;]lH01?njW;Woam;RolOB
h_o7d^84ol:dc@03oi_cj?o5gN_oaMg[00?oaMg[00?o`L3Iok;Rmonbh_L00_nbh_L2okW=j@?oW>Kl
0_n`g?H3oi[Jo@;oYmKh0_nLdo/5ojCBn0;oZ<od00?oY<[do`000?nTb_@00_nWbO82ojC5l0GoY/G_
0_nWa>h2ojK1k@OoYl7/0_nV_n`Booooo`;o00002Oooool4o`000003oa0@4?oooooooooo00Oooooo
000Tooooo`03o`000?oooooooooo013ooooo00?o//;Vok[3hOnj`n400onj`n400onlbNCo_lCNoko4
gP04oko4gP?o_;cI1?nk^=H00onc[=7o/:G=ok2Uc@02ok2Uc@Co[Ik80_nYV<@00onPT<?oWHZooif:
_`02oif:_`CoVXFk0onGP;P01?nEO;Go0000o`000?l00002oi=h/PCoTWJ`1?nALjh3oi1a[@?oSg2/
0on>Kj/4ohe^Z`?oSFfZ0_n?KZT00on<Q/SoSh_<ohn;c002ohn;c0CoUHo;1?nLT<H3oj2=`0CoXXZk
1?nQQ[L2oin3]004oi5XW_nBII_oTVFKoi9UV`?oTV>I1?nAHYL3oi1PU@?oSejD1on>GI<5oheLT`;o
Vg>U1OnNMJD4oj5gY@CoXgVT0_nUNZ@3oj5eXPCoX7:O1?nNL9d01?nLKIcoZHB]ojV4[OnYQ:d4ojZ1
Z0CoZGjU0_nXOJD3olfa_`Co^i>^0_n_Q:H2olBcbPGo_9bg0_neT;02omW^h@CobkO600?oVO7]olOB
h_o7d^800oo7d^800oo2]<goVo?Xoi_cj002oi_cj0;oaMg[0on3iO<2ok;Rm`?oJm[_0_nLi_`4ohGI
o`;oV][m0_nAdOd4oicCn`;oY=;h0onOb_H2ojC:m003oj;4lOl0003oX/Ca00CoY<G`0_nVaNl2ojG1
k@GoY/7]0_nW`N`7ojJok1?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09oooo
o`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0
003oooooooooo`0Booooo`?o^/?Q1_noa=h2okk0f`Co_;cI00?o^kSFok>/dOnc[=400_nc[=44ok2U
c@;o[Ik800?oY9O8oj2@`onPT<<00_nPT<<3oif:_`CoVXFk00CoUh2ho`000?l0003o00000onEO;D3
oi=h/P?oTWJ`1?nALjh3oi1a[@;oSg2/00CoSWbjohim_?n>OKcoSWfl1?n=Okl3oh^1a0CoS8K81?n?
Rl`3oiF?b`CoW9361?nPSL03oj::^`;oXHJg00?oP5nRoi5XW_nAJ9h00_nAJ9h3oi9UV`?oTV>I1?nA
HYL3oi1PU@?oSejD1on>GI<2oheLT`;oV76U1?nKLjD4oiieY@CoXGNU1?nSNJ@00onUNZCoX7NToj5e
XP02oj5eXPCoX7:O0onNL9d00onZRkCoZHB]ojV4[@02ojV4[@CoZX6X1?nYOZD00onXOJGocK6oolfa
_`02olfa_`Co^i>^00?o[hBVolBcb_o4/lX00_o4/lX4okbL]`03okF@/?oIk^7ofNkQ00;ofNkQ00?o
bkO6oiWakOnIlNd00_nIlNd2olOBhP?oJjWf0_leZo42ohb_k@GoM;Wk0omXaOh4ofg>o@;oQMWo0on:
b_d4oi7Ao@;oW=?k0onKb?L2oio:mP;oX<;`0_nRa?400ol0003oX/Caoj;4l@02ojC5l0;oY<3]1?nU
`Nd2ojK1k@WoY[o/0_nV_n/Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Ooo
ool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Kooooo00?o0000ooooooooool04oooool00onj`n7o_lCNoko4gP03oko4gPGo_/3K
0_nl_=T00ong]=Ko/jcAok>/d@04ok>/d@;o/:G=00?oYik=ojBGb?nTUlP00_nTUlP3oj2@``CoWHZo
00CoVXFko`000?l0003o00000onGP;P3oiEl]@?oTgRb0_nBM[05ohik^P?oSg^j1?n>O;X3ohim_0Co
SGno0on;PL@3ohb6b0CoSh_<0onESl/5oib@aP?oX8g00_nRR[/01?n2H:;oP5nRoh1OX_n0Gj83ogmO
X`04oi5XW_nBII_oTVFKoi9UV`?oTV>I1?nAHYL3oi1PU@?oSejD1_n>GI<00onEL:GoV76UoiQaY@02
oiQaY@CoVg>U1?nNMJD4oj5gY@?oXgVT0onPMj@4oj5eXP?oX7:O00CoWW2MojZ;]?nZRkCoZX^d1?nY
Q:d5ojZ1Z0?oZGjU1_o=/Kl2ok^C[P03okkYloo4/l[oa;?:00?oa;?:0onlW;L3o`0000;ofNkQ0onP
VLd3ohfNg`03ojNOc_nMYM_oWJGK00?oWJGK1?n<[nd2ogBin`;oVJWR1?n?]>l4ohRon@;oR/[m0onH
_O44oiO3m@;oVlSg0_nO_^l5oj32l0;oX/Ca00?o0000oj>nkOnT`>d01?nT`>d2ojG1k@;oYKk[1_nV
_n`3ojJnj`CoY[o[4oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo0009
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oo
oooooooo01Gooooo1_noa=h3okk0f`03okVkfong]=Ko]kCF00;o]kCF1?nc[=400on[Ym;oYik=ojNN
c@02ojNNc@?oY9O80onPT<<3oif:_`;o00000onJQK/2oiN0^004oi21_on?O[goSgjmohmn_@?oSWfl
1on>NkX4ohmk^P?oSWbj0on>OK`4oheo_`?oRh740on<Q/P4ohn;c0CoUHo;1?nLT<H2oj2=`004ohIS
X_n2H:;oPV2Roh9PXP?oP5nR1?moGj<3oh5QY0?oTV>I1?nAHYL3oi1PU@?oSejD0_n>GI<2oi9^Y@?o
UG2U1OnHLJD3oi]cY@CoWWFU1?nQMjD2oj=iY0CoX7NT1?nQMJ82oj1bW`03ojZC_onZRkCoZX^d00?o
ZX^d0onYQ:d5ojZ1Z0;oZGjU0_oLm]d5olfa_`04ok^C[_nnjO?o_^WcokkYl`Coa;?:00?o_9bgojBJ
bon`V;h01OnYU/<4oj2Ic@04ohfNgonWWlkoYio>ojNOcPGoWJGK0_n<[nd00onRXmKoVJWRoiVYhP03
oiVYhPCoSkC_0_n8_oT2oiZdjPGoV;ga0_nG`oD2oijhj`CoWkk_0_nP`_02oj>lj`?oXkk]00Co0000
oj>nkOnT`>goY<3]0_nU_NX5ojFnj`;oY[o/0_nV_^X5ojJnj`;oY[o[0_nW_n/Cooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02Oooool000Wooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0ol0000Fooooo`Ko_lCN00Co_/3KokVkfoni^m_o^K_K
1?ng]=H00onc[=7oZjOBoj^WdP02oj^WdP?oYik=1?nTUlP2oj2@``?o000000?oU8W5oi:5`_nBQL80
0_nBQL84oi21_`?oSgjm0on>OK`6ohik^PCoSg^j0on>O;X3ohim_0CoSGno1?n;PL@3ohb6b0CoSh_<
0_nESl/2oheYY0?oRVFS0on6Hj84oh9PXP;oP5nR1?moGj<3oh5QY0?oQ6>U1?nAHYL3oi1PU@;oSejD
00?oSfbVoi9^YOnBKZD00_nBKZD3oiE`Y@GoV76U0onKLjD5oiieY@?oXGNU00?oXgVToiigYonPMj@0
0onPMj@4oj5eXP03oj1bWonZTkooZY>o00GoZX^d0onYQ:d5ojZ1Z003ojUnYOoLm]gog?KM00;og?KM
0_o=/Kl00onVSK_oX8o2ojjD_004okkYl`;oa;?:00?oZYG1ojBJbon`V;h00_n`V;h4ojVF``;oX9W=
0_n_W/H5ojNOcP;oWJGK0_n/X/d4oj:SeP?oVJWR00?oYjWHoj6^hOnQ[^400_nQ[^45oiZdjP;oV;ga
0_nQ/nD5oijhj`;oWkk_0_nS^NP4oj>lj`;oXkk]00?oYK_Yo`000?nU^nT01?nU_NX2ojFnj`;oY[gZ
1OnV_^X2ojJnj`;oYkkZ1OnW_n/Aooooo`?o00001oooool00ol0003oooooooooo`09ooooo`002Ooo
ool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01?ooool00ol0003ooooo
ooooo`0Hooooo`?o_lCN00?o^lCQokVkfoni^m/00oni^m/2okNdeP;o[ZoH1?n[Ym84ojNNc@;oY9O8
0ol000000onGSlWoU8W5oiB9a@02oiB9a@?oTXG21?n@PKl3ohmn_@?oSWfl1on>NkX3ohmk^PCoSWbj
0on>OK`4oheo_`;oRh740_m]do/01?nFNK7oTW:[oi9bZonBLZ/3oi1]Y`?oSFVT1?n:IJ<2ohISXPCo
PV2R0on0Gj83ogmOX`?oPF6T0on4HjD4ohQVY@?oS6VV0on?K:H4oi9^Y@CoUG2U1?nHLJD3oi]cY@Go
WWFU0_nQMjD4oiigY`?oX7NT0onQMJ800onZWlcoZY>oojZC_`02ojZC_`CoZX^d1?nYQ:d3ojZ1Z003
oj^>]onYSKSoZHfh00;oZHfh1?nVSK/5ojjD_0?oZYG100?o]9^ook2H__n`V;h00_n`V;h4ojVF``Go
[ik60onWWlh00onaXlWo[:;=ojbRc@03ojbRc@CoXZ?F00CoVJWRojNYf?nWZMSoYjWH1?nQ[^42oiZd
jP?oY:oO1?nQ/nD2oijhj`;oY;KU1OnS^NP2oj>lj`;oYKWW0_nU^nT00ol0003oYK_YojFkj@02ojFm
jP;oY[cY1?nV_NX2ojJnjP;oYkgZ1OnW_^X4ojNoj`kooooo1?l000000ooooooo0000ooooo`06oooo
o`03o`000?oooooooooo00Wooooo0009ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo00Co_lCNok_4hOnka>7o^lCQ0oni^m/0
0ona^=oo[ZoHojj_f003ojj_f0CoZjOB0_nWW/d3o`0000;oVYG=0onGSlT3oiB9a@CoTXG20on@PKl3
ohmn_@?oSWfl1on>NkX4ohmk^P?oSWbj0on>OK`2oheo_`CoR/gn00?oKM?koiIi/OnFNK400onBLZ/3
oi1]Y`?oSFVT1?n:IJ<3ohISXP?oPV2R0on0Gj83ogmOX`CoPF6T0_n4HjD4ohQVY@?oS6VV0on?K:H5
oi9^Y@?oUG2U1?nHLJD4oi]cY@CoWWFU00?oXGNUoi]gZ?nNMjL00onNMjL3oj1gY003oj5eX_nZWlco
ZYo<00;oZYo<0onZTkl4ojZ;]0CoZHB]00CoZX6Xoj^>]on[S[OoZhjg1OnYSKP2ojJ=^`;o/9Jl1?n^
U;`2ojZE`@?o]9^o0on`V;h3ojVF``;o]9o41On_W/H01?nWWlko/J?9ok6SbOnaXlT4ojbRc@;oXZ?F
0_n]Z=85ojNYf0;oXJkQ0_nY[=T5ojB_g`;oXK?U00?oYk?QojBfiOnT]^D00onT]^D2oj>ij0;oYkOU
1OnU^NL2ojFkj@03o`000?nW^^OoY[cY00CoY[cY0_nV_NX2ojNmj@CoYkgZ1?nW_^X5ojNoj`[ooooo
0ol00005ooooo`03o`000?oooooooooo00?ooooo00?oEEEEofIVI_l000002oooool000Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool2o`0001_o
oooo1?nka>401?ni^m_o/KSOok6hgona^=l5ojj_f0;oZjOB0ol00002oijLdP?oVYG=0onGSlT3oiB9
a@CoTXG21?n@PKl3ohmn_@?oSWfl1_n>NkX4ohmk^P;oSWbj0_nA/nh5oi?0mP;oR/gn00CoVh:goiIi
/OnFNK7oUWVa0onBLZ/3oi1]Y`?oSFVT1?n:IJ<3ohISXP?oPV2R0on0Gj83ogmOX`CoPF6T0on4HjD3
ohQVY@CoS6VV0on?K:H4oi9^Y@?oUG2U1?nHLJD4oi]cY@?oWWFU0onKMjP4oiigY`;oX7NT00?oZJgJ
ojZOc?nZWl`00onZWl`3ojZC_`GoZX^d0_nYQ:d2oj^?^@CoZhjg1?nYSKP01?nVSK_o/9Jlok2F_?n`
U[`4ojjD_003ojZE`OndVkoo]9^o00;o]9^o1?n`V;h01?nYU/?o]9o4okBOa?ndWl@4ojnNaP03okRX
bOnaXlWo/J?900;o/J?90on/X/d00oncZ/oo[JSBojfXdP03ojfXdP?oYjWH00?o[jgFojV/fOnY[=T0
0onY[=T2ojB_g`;oZk7M1?nW/n43ojBfi@03ojReh_nW]nGoYkOU00?oYkOU0onU^NL01_nX^NKoYk[W
ojNjionW^^Oo0000ojNji`?oY[cY00?oYkcXojNmjOnW_NT00onW_NT2ojNmjP;oZ;kY1?nW_^X2ojNo
j`;oZ;o[1_ooool4o`0000Sooooo00?o0000ooooooooool04Oooool000Wooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`0K
ooooo`;o^lCQ0_nc`^D4ok6hg`;o[ZoH00CoY:gNo`000?l0003o00000_nQY=P3oijLdP?oVYG=0onG
SlT4oiB9a@?oTXG21?n@PKl3ohmn_@?oSWfl1On>NkX2oh^QhPCoSZWX1?nA/nh2oi?0mP;oXXfn0onK
P[L3oiIi/@CoTW:[0on@KJL3oheYY0?oRVFS0on6Hj83oh9PXP?oP5nR1?moGj<3oh5QY0?oQ6>U0on8
IZD4ohaYYP?oSfbV1?nBKZD3oiE`Y@GoV76U0onKLjD00onNMJGoV7BYoiQdZ@03oi]gZ0;oWWNW0_nX
^ND4ojV]fPCoZYo<1?nZTkl4ojZ;]004ojV4[On[SkWoZhnioj^?^@CoZhjg0onYSKP00on`V;go/9Jl
ok2F_002ok2F_0?o[YBl00?o]j72okBK_ondVkl00ondVkl3ok2H_P03okNTaOndWlCo]9o400?o]9o4
00Co[ik6okRXbOnhZ<Wo^:S91OnaXlT01?n/X/go/j[?ok>ZconcZ/l4ojfXdP03ojNYf?n_[MKo[jgF
00;o[jgF0onY[=T00on^/][oZk7Moj^ag@03oj^ag@CoYk?Q00CoY;KUojReh_nX]N;oZ;GR1?nW]nD0
0onU^NOoZ;WVojRiiP02ojRiiP;oYk[W00?o0000ojNjionV_>T01?nW_>P3ojNmj@03ojRmjOnX_^Wo
Z;kY00?oZ;kY0_nW_^X2ojRojPCoZ;o[0_ooool3o`0000cooooo00?o0000ooooooooool04Oooool0
02;ooooo00?o0000ooooooooool07Oooool4ok?2i@;o/KSO00CoY[KTo`000?l0003o00000_nT[Mh3
oj6Tf0CoWYcB0onJULd3oiN?b@;oU8W500CoS9GGohZCe_n:TmKoRY?F1?n9T]L3ohRCf0?oR9KJ0on9
V]h5oh^QhPCoSZWX0_nA/nh00onZV/GoU7Vaohia[@02ohia[@?oRVbZ0on6IjP4oi9bZ`?oT6fW0on=
JJ@3ohYUX`?oQV>R1?n2H:82oh1OXPCoOenS0on1HJ@3ohASY@?oR6JU1?n<JJH3ohm/YPCoTVjU0onE
L:D5oiQaY@;oVg>U00CoTg2WoiQdZOnHM:WoV7BY0_nKMjP00onW_n_oZ;WUojRii@03ojRii@?oZJgJ
1OnZWl`3ojZC_`;oZX^d0onZT;X3oj^?^@CoZhjg00?oZHfhok2H_On`V;d00_n`V;d4ok2F_004ojjD
_?ngXL;o]j72okNQ`PGo]9^o00Co/9RnokNTaOngY<Go]jC51?ndWl@5okRXb@?o/J?900?o]jk@ok>Z
concZ/l00oncZ/l2ojfXdP03ok>_e?n_[MKo[jgF00Co[jgF00CoZJcIojjbf_n^/][o[[;J1?n[/Md2
ojNch@;oZkGP1OnX]N82ojNgi@;oZKWT1?nX^NH2ojNji`03ojRkiol0003oZ;_W00CoYkcX00?oYkgY
ojRmjOnX_NT00_nX_NT3ojRnj@KoZ;oZ0_nX_n/2ojS0j`03o`000?oooooooooo00kooooo00?o0000
ooooooooool04?ooool002;ooooo00?o0000ooooooooool07_ooool2ok?2i@;oYl3[0_l00002ojJf
i0CoY:gN0onQY=P2oijLdP04oi>Qg_n@W=_oT9cKoi2Lf`?oSYSI1?n<UML3ohZCePCoRI;G0on8TmP3
ohRFfP?oRI[N1On;XN82ohjYj003ok:WcOnKPKOoU7Va00;oU7Va0on>LJd3ohY/ZP?oQVNX1?n5IJL3
ohEUYP?oSFVT0on:IJ<3ohISXPCoPV2R0on0Gj83ogmOX`?oPF6T0on4HjD4ohQVY@?oS6VV0on?K:H4
oi9^Y@CoUG2U1?nHLJD00onKLjGoTg2Woi=`Y`02oiQdZ@GoYko[1OnX^ND3ojV]fP;oZYo<0_nSRk/2
ojB=_003ojR@_OnZT;[oZY2j00?oZY2j1?n[SkT2oj^>]`03ok2J`On`V;go/9Rm00?o/9Rm1?n`U[`4
okNQ`PCo]9^o00?o^J[:okNTaOngY<D00_ngY<D3okBOa0;o^jk=1?nhZ<T00onaXlWo]jk@okN^d002
okN^d0?o/j[?00?o^;CFok>_e?nc[m@00_nc[m@4ojn]eP03ok>df_n^/][o[[;J00?o[[;J0_n[/Md2
ojjfgPCoZkGP0_nX]N82oj^hh`GoZKWT0_nX^NH2ojVkiP?oZ;_W00Co0000ojRkionW_>SoYkcX0_nX
_NP4ojRmj@03ojRnjOnX_n[oZ;oZ00CoZ;oZ0_nX`>X5ojS0ja3ooooo00?o0000ooooooooool04?oo
ool002;ooooo0_l0000Pooooo`?o00000_nW`>/3ojJfi0;oY:gN00CoUjkVoiFWh_nEYn;oUJOR1?nC
XMh3oi2Lf`?oSYSI0on<UML3ohZCePCoRI;G1?n8TmP3ohRFfP?oRI[N0_n;XN82okRce004oj6;_?nK
PKOoVh6goi^1]`CoU7Va0on>LJd3ohY/ZP;oQVNX1?n5IJL3ohEUYP?oQVFU0on7IZD3ohIVY`CoPV2R
0on0Gj83ogmOX`CoPF6T0_n4HjD4ohQVY@?oS6VV0on?K:H5oi9^Y@?oUG2U0onHLJD2oi=`Y`?oYkSU
1onW_n/2ojRii@03oin8^onQRK_oXHVk00;oXHVk1?nSRk/01?nTSKcoZ92mojR@_OnXT;d4ojZ@^PCo
Zhni00CoZhjgok2J`On`V/7o/9[11?n`V;d3ok2F_0;o^:O81?ngXL801?ndVkoo^J[:okVZb_niZ/X5
okNTa@04okBOa?nk[/go^jk=ok^^c@?o^:S900?o^[CDokN^d?ng[]001?ng[]001?ncZ/oo^;CFokRd
e_nh]=H4ok>_e003ojn]e_nc]=[o/kCJ00;o/kCJ0on^/]X00ona^=ko[[KNojjfgP03ojjfgP;oZkGP
0_n]^N84oj^hh`;oZKWT0_n[^nD5ojVkiP;oZ;_W00?oZKgXo`000?nX_NP01?nX_NP2ojRmj@;oZKkY
0onX_nX00onY`>[oZ<3ZojS0jP03ojS0jP;oZ<3[0_nY`>/@ooooo`03o`000?oooooooooo013ooooo
000Rooooo`03o`000?oooooooooo01cooooo0ol000000oooooooYl3[ojO0j`02oiVll0CoV;C[0onG
[^H3oiFWhPCoTj7N0on@W=/3ohjHf@?oS9GG0on:TmH4ohVBe`;oR9?H0_m7`Nh2oko6h0Co_KkK00Co
YiG3oj6;_?nQRkcoXH^l1?nKPKL3oiAi/@?oSW6]0on:K:X3ohIWZ0?oQFFW0on5IJH3ohIUY@?oQfJU
0on6IZL4ohAY[0?oOW2i0omoGj<4oh5QY0?oQ6>U0on8IZD4ohaYYP?oSfbV1?nBKZD3oiE`Y@03oiQa
YOn>JZGoYJ_K00KoYkSU0_nW_n/01?nKQkgoWHNloif7_?nMQk`3oin8^`GoXHVk0_nSRk/00onVTKoo
Z92mojR@_@02ojR@_@GoZY2j0_n[SkT00on_WLGo/9[1ok2J`@02ok2J`@Go/9Rm00Co/9JlokRWb?nh
YlSo^:O80ongXL800oni/];o^J[:okVZbP03okVZbP?o]jC500?o_;OEok^^cOnk[/d00onk[/d01?nh
Z<Wo^[CDokZde?nj]=@4okN^d003okVkfonh]=Ko^;CF00?o^;CF0_nc[m@2okFhf`Co/kCJ00?o[[;J
ok6hg_na^=h00_na^=h3ojjfgP03ojnkh_n]^N;o[KWR00?o[KWR0_n[^><2ojbli@CoZk_U0_nY^nH2
ojZmi`?oZKgX00Co0000ojVmj?nX_NSoZ;gX1onY_^T01?nX_n[oZL3ZojW0j_nY`>X3ojS0jPKoZL3[
3oooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0Iooooo`?o00001_oo
ool3oiVll0CoV;C[0onG[^H3oiFWhP;oTj7N0_n3/O<3oh2bm0?oNkCg1Omf^?/3offnoP;oGl?l0_no
c>@4oko6h004okfnfonWUL?oYiG3ojNE``?oXH^l1?nKPKL3oiAi/@?oSW6]0on:K:X3ohIWZ0?oQFFW
0on5IJH4ohIUY@?oQfJU0_n6IZL5ohAY[0;oOW2i0omUQMh4oh5QY0?oQ6>U0on8IZD4ohaYYP?oSfbV
1?nBKZD2oiE`Y@03ohYUX_n>JZGoYJ_K00;oYJ_K1?nW^>D4oi^7_@?oWHNl1?nOR;/3oj69^`03oj>@
`?nVTKooYY6o00;oYY6o0onXT;d5ojZ@^P04oj^?^On_WLGo[ig5ojnMa@?o/9[11?n`V;d00onh[m3o
^:O8okRWb003okRWb004okNQ`_ni/];o^K;BokVbdPCo^J[:00?o]jC5okbgeOnl]mD00_nl]mD3ok^^
c@03okZmfonj]=Co^[CD00?o^[CD00?o]jk@okVkfoni^m/00_ni^m/3okRdeP03okNngone^=_o]KSK
00?o]KSK0_nc]=X2ok>lh0Co/KSN00?o[[KNojnkh_n_^n800_n_^n83ojfihP03ojjmiOn/_>Go[;cU
00?o[;cU0_n[^nD2oj^ni`CoZ[gW0_nY_NP00onZ_nWo0000ojVnj@06ojVnj@OoZL3Z00?oZ<3ZojW0
jonY`>/01?nY`>/00onY`N_oooooooooo`0=ooooo`03o`000?oooooooooo013ooooo000Rooooo`03
o`000?oooooooooo01Kooooo0ol0000:ooooo`?oVKc`0_nH]>/2oh^flP?oRKCb0on7/_84oh>al`?o
P;;d0omk]?L2ogJhn`?oB<KU00?oN^GLokS`m?nhl?@01?noc>@2oko6h003ojfObOnWUL?oYiG300?o
YiG30onQRk`3oi^1]`?oU7Va0on>LJd3ohY/ZP?oQVNX0on5IJL3ohEUYPCoQVFU0on7IZD3ohIVY`Co
Q6V/0omnL;T3ofF5gP?oOF2V0on0HjL3ohQVY@CoS6VV0on?K:H2oi9^Y@03oiZ;`_nPVlooX9_?00?o
X9_?1?nUZm/00onW^>GoVXS0oiZ8`004oi^7_@CoWHNl0onOR;/01?nQRK_oXi30oj>@`?nST<04ojJA
_`CoZ92m0_nZT;X2ojjQbPCo[ig51?n`V/400on`V;go^:o@okR_d002okR_d0?o^:O800?o^;_LokVb
d_ni/]800_ni/]83okVZbP03ok_1gonl]mGo_;OE00Co_;OE00Co^jk=okZmfonj_M_o^[gK0onj]=@2
okS3hPCo^K_K00?o^;CFokNngong_]l00_ng_]l3okFhf`03okC1i?nc_>3o/kcP00?o/kcP0_na^=h2
ok6ni0Co[k_R00?o[KWRojjmiOn^_ND00_n^_ND2ojbli@;o[;oX1On[_^L2ojZmi`;oZkoY0onZ_nT0
0ol0003oZKkYojVnj@09ojW0jPGoZL3[1_nY`N/>ooooo`03o`000?oooooooooo013ooooo000Roooo
o`;o00005?ooool3o`0000kooooo0on<^?<4oh^flP?oRKCb0on7/_82oh>al`?oM/Cn1?m/bOh2oeg;
n0;oQnW`0_nej_L2okk>i`?o_lcT00?o/JS?ojfObOn]WlT00_n]WlT4ojNE``?oXH^l1?nKPKL3oiAi
/@;oSW6]0on:K:X3ohIWZ0CoQFFW0_n5IJH4ohIUY@?oQfJU0on6IZL4ohAY[0CoOW2i00?oIHGNogeQ
Z?mmHJP00_mmH:H3oh1SY`CoQVVZ0on<LK02ohENW@03oi=m^?nJRl;oVX_200;oVX_21OnPVll2ojF[
f`04oiZ<a?nJR<3oVXS0oiZ8`0GoVhNm0onMQk`2oin8^`03oj2>`OnST<3oXi3000?oXi300onVTKl3
ojR@_@03ojbSc_n^XL[o[Z7:00;o[Z7:1On_WLD2ok2J`@03okJgf_nh[m3o^:o@00?o^:o@00?o^:O8
okRkg?nh^m`00_nh^m`4okVbdP04okVZb_nk`Moo^l7Ook_1g`Co_;OE00?o]/GUokZmfonj_M/00onj
_M/00onj]=Co^<?RokS3hP02okS3hP;o^K_K0_nea>H4okNng`03okFhfond`NCo]<7T00;o]<7T0_nc
_>02ok72iPGo/KkT0_n_^n82ojo0i`?o[[gU00?o[L7Xojboj?n/_nP00on/_nP2oj^ni`;oZl3Y1On[
_nT2ojZoj@03oj[0j_l0003oZL3Z00GoZL3Z0_nY`N/4ojW0j`[oZL7[3Oooool00ol0003ooooooooo
o`0@ooooo`008Oooool2o`0001;ooooo0ol0000Booooo`?oS;Sc0_n;]_82ohJim`?oP[cj1?mm`?`4
ogK4oP;oK<Wn00?oEm3UohOYl?n7jO000onej_L4okk>i`04oko<i?naZ<oo/JS?ok6Xc`?o[Io91?nW
UL<3oj6;_0CoVh6g0onDNK43ohia[@?oRVbZ0_n6IjP4ohEUY`?oQFFV0on6IJD3ohMVY@?oQVJW1On4
JJ`2ogi`^@04oh5Y[_mmHJSoOF6XogeQZ0?oOF2V0_n0HjL4ohIYZP?oS76`1?nCOKP3oiZ;`PCoX9_?
00CoW9C:oiZ<a?nJS<CoVXc41?nJR<04oi^7_@;oWHNl00?oWHc1oj2>`OnPS/400_nPS/44oj>@`0Co
YY6o00CoZ92mojbSc_n/Xlko[:?>1?n^XLX3ojnMa@03ok>nhonf]m[o][OJ00;o][OJ0onh[m000onc
a>Oo^;_LokRkg004okRkg0;o^K;B0_ndb^/4ok_1g`03okbgeOnfaNGo]/GU00;o]/GU0_nj_M/2okC;
j`Co^<?R00?o/<[]okG4i_nea>H00onea>H2okNng`;o//KY0ond`N@00on`a^[o/L;Vok72iP03ok72
iP;o/KkT0_n_`nT5ojo0i`04ojjmiOn]`NSo[L7Xojg1j0?o[;oX0_n[`^X4oj_0j@;oZkoY0_nZ`NX3
oj[0jP04o`000?nZ`>[oZL3ZojW0jPKoZL7[00?oZL3[ojW1jonY`N/02onY`N/<ooooo`03o`000?oo
oooooooo013ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l0
00000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00oooooo0_l0000Fooooo`?oRKOd1?n6
^OL3oh:lnP;oOL3l1?mldOl2ofgEn@;oTNGk0onbhoL2okc?j0?o_/kW00?o];3Eok6XconaZ<l00_na
Z<l4ojfOb@;oYiG300CoV8S1oi:1_OnBPKgoTX6m1?n<N[T3ohMd]`?oPg6f0on:K:X3ohIWZ0?oQFFW
0on5IJH3ohIUY@?oQfJU0on6IZL5ohAY[003ogi`^On1JJkoPFV^00?oOF6X0ommH:H3oh1SY`?oQVVZ
1?n<LK03oi=m^0CoVX_200?oX9_?oibDb_nLU<X00_nLU<X3oiZ<a0;oVXS000?oUXBnoiV8`?nIR<00
0_nIR<04oif<`@?oX8k11?nST<02ojJA_`;oZZGB1?n/Xlh4ojjQbP03ojnMaOnc_^?o/kkS00;o/kkS
1?nf]mX01?nh[m3o/lCWok?4ionca>L4okRkg003ojcBm?ndb^_o]<[[00?o]<[[0_nk`Ml2ok3=k`?o
]/GU0_n[d?<4okC;j`03okS3h_n`b^go/<[]00;o/<[]0_nea>H2ojk;kPGo//KY00Co]<7Tok36j_n`
a^[o/<KZ0ona`^H2ojk6k0Co[l?Y0_n_`>L2ojg3jPGo[L7X00?o[;oXoj_2j_n[`^X00_n[`^X2oj_0
j@;oZ/;[1?nZ`NX2oj[0jP03ojW1jol0003oZL7[01?oZL7[0_nX`N/=ooooo`03o`000?oooooooooo
00oooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0<ooooo`?o00006Oooool3ohVgm0;oQ[Wg1?n<`OT3ohG9
oP;oO=7o0_nGg?h3ojoKmP03ok;SmonlcnSo_<oX00?o_<oX00Co_/kWokB`eOnd/=Go];3E1?naZ<l2
ojfOb@03oijAa_nHR<7oV8S100;oV8S10onBPKd3ohaj^@?oQgBg0on3LKH3ogm_]`?oNVnk0on5IJL3
ohEUYPCoQVFU0on7IZD3ohIVY`?oQ6V/00CoMe^UofiHZ?m^F:SoPFV^0ommHJP3ogePYP?oP6>W0on6
JJX4ohaa/0?oTgfh0onJRl82ohmm_0CoT7jl0onBPKd4oiJ4_P?oVHS01?nMS<44oj2>`@;oXi3000?o
Z:GDojZUd_nZYM800onZYM84ojbScP;o[Z7:0_n_aNX5ok>nh`;o][OJ0_n]c?04ok?4i`03okRkg?n/
d_Co[=;d00;o[=;d0_ndb^/2ojKBm`Go/<g_00?o]/GUoj_@lon[d?<00_n[d?<2okC;j`;oZLkc0on`
b^d2ojO=l`Co[/_^0_nba^T2ojc9kPGo/<KZ00?o/L;Vojk6k?n^a^`00_n^a^`2ojo3j@;o[<G/1?n]
`nX2ojg1j0?oZl?[0_n[`^X2oj[3k0GoZ/;[0_nZ`NX2ojW2j`?oZL7[00?o0000ojW1jonY`N/03_nY
`N/6ojS1j`cooooo00?o0000ooooooooool03oooool000Oooooo00Go410@oooooooooooooooooa0@
400;ooooo`Go00001Oooool2o`0000[ooooo0ol0000Mooooo`GoT;Wb0_n<`OT2oic7mP?oV];k0on]
d_<2ojoKmPCo^LgY0_nlcnP2okJgf@Co];3E0_naZ<l00onTV/_oWY76oijAaP02oijAaP?oV8S10onB
PKd3ohaj^@?oQgBg1?n3LKH3ogm_]`;oNVnk0omfM<<3ohEUYPCoQVFU0on7IZD3ohIVY`04ohAY[?n0
HZKoMe^UogMKY@?oKURX0ommHJP3ogePYP?oP6>W1?n6JJX3ohaa/0CoTgfh00?oVX_2oi61__n?OK`0
0_n?OK`3oi1n_0CoTX6m0onFQ;h4oiV8`0CoWHc10_nPS/400onUY=CoZ:GDojRUe002ojRUe0GoZZGB
0_n/Xlh2oj_9k`Co[lGZ0_nc_^<2ojOAmPGo[Lc`0_nca>L3oj;FnP;o[=;d0onMe?/3ojKBm`;o/<g_
0onRd_T2oj_@l`;oXLoh1OnYc_<00on`b^goYlgcojO=l`02ojO=l`;o[/_^0_nXbo84ojc9kP;o/<KZ
0on[b>l2ojk6k0;oZ/K^1On/aN`2ojg3jP;oZlC/0on[`n/2ojW4k@CoZ/?/0_nZ`^/2ojW3k0GoZL;[
0_nY`N/00ol0003oZL;/ojW1j`0:ojW1j`_oZ<7[2oooool00ol0003oooooooooo`0?ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001_ooool00ol0003o
ooooooooo`06ooooo`?o00008Oooool2oi2ilP?oW[g_1?nLaoH01?nJd__o[M;cojgBlon]d_<2okK:
j@Co^LgY00?o]k_MokJgfOnf]mT00onf]mT2okB`e@03ojVSd?nTV/_oY9[;00;oY9[;0onNTLH3oiR8
`@?oTX6m1?n<N[T3ohMd]`?oPg6f0omoKkL3ogY_^`;oMWC30om_Om<4ohIUY@?oQfJU0_n6IZL3oh1R
YP?oMe^U0_m^F:P2ofMO]P;oOF6X0_mmH:H3oh1SY`CoQVVZ1?n<LK02oi=m^0?oTH6n0on?OK`4oi1n
_0?oTX6m0onFQ;h4oiV8`0;oWHc10_nRX]@4ojFTe0CoZ:GD0_nZYM82ojS<l`GoZlW_0_n_aNX3oj;E
nP?oYm7f0_n]c?03oi[Go@;oX]Kj0onGe?d2oigDn`?oU]7l1?nJd_/2oj;Bn@?oVloj0onQcoP2ojW>
l`?oXLgg0_nWcO<2oj;;m@GoZ<_b0_n/bNh3ojO9l@;oZlS_0_nWao04oj[6kP;o[<G/0_nYa^h5oj_4
k003oj_3jonYa>goZLC]00;oZLC]0_nZ`n`2ojW3k@CoZL?/0_nY`^/5ojW2k004o`000?nY`^coZL7[
ojW1j`;oZL;/0onY`N/2ojS1k0goZ<7[2_ooool00ol0003oooooooooo`0?ooooo`001oooool01Ol0
003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003ooooooooo
o`03ooooo`?o00009_ooool4oijmk`;oW<Of0on[bNl00on]d_?o]/[YokK:j@02okK:j@03okW=jOng
^mgo]k_M00;o]k_M0onf]mT00on]ZmGoZJ?@ojVSd002ojVSd0?oY9[;0onNTLH4oiR8`@?oTX6m0on<
N[T3ohMd]`?oPg6f0omoKkL3ogY_^`?oMWC30om_Om<5ofZJk003oec3non>L:coSW2/00?oP6:V0omg
FjD2ofiHZ0CoIenf0ommH:H2oh1SY`CoQVVZ1?n<LK000onCOKSoV8_4oi61_P02oi61_P?oSgfl1?n@
O[`3oi:1_@CoUXBn0_nIR<000onOWM;oXZ;Doj:Re003oj:Re0?oYJCD0onXYM@2ojK=m0CoZ<cc0_n[
bNl4oioGn`;oX]Gj0onFf?h3oiOHoP;oV]Om0onEe?d2oiODo@?oU]3l1?nFdO`2oi[Bn`?oVLkj0_nK
coX2oi_;n0CoWLch0_nQcOL2oio:mPCoX/_e0_nXbo83ojC9l`;oYlWa0_nUao85ojO7l0;oZ/K^0_nW
a^l4ojW6kP;oZlC/0onYa>h2ojW4k@;oZ<C]1OnY`nd4ojW3k0KoZL;/00?oZ<;/o`000?nY`^`01?nY
`^`00onY`N_oZ<7/ojS1k002ojS1k0[oZ<7[0_nX`>/:ooooo`03o`000?oooooooooo00oooooo0007
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000005ooooo`04o`000?oo
ooooooooooooo`?o0000:_ooool2oijmk`?oZ/7Z0_n[bNl2okC6i`?o]/[Y0ong_n04okNkg@04okJg
fOn]ZmGo[J_Eojf[e@?oZJ?@1?nTV//3oijAaP?oV8S10onBPKd3ohaj^@?oQgBg1?n3LKH3ogm_]`;o
NVnk0omfM<<4ofmod`;oJY[/0onNQ;L3ohi`[0;oP6:V0omgFjD3ofiHZ0?oIenf0_mMO=T01?mmH:Ko
P6>Woh1SYon0HjL3ohIYZP;oS76`0_nUWLh3oiR;a0?oTH6n0on?OK`3oi1n_0CoTX6m0_nFQ;h00onK
V<ooWigBoinMdP02oinMdPCoXZ;D1?nUY=@00onXYMCoY/gdojK=m002ojK=m0;oZ<cc0onMfO`2oioG
n`?oUmWn0_nFf?h2oiSDo0GoU]Cm0_nEe?d3oiS?n`;oU]3l0_nKboP4oiW<n@;oVLkj0_nKbOL5oi_;
n0;oWLch0_nMbOH4oio:mP;oX/_e0onQb?@2ojC9l`;oXlOb1?nUao82ojO7l0;oY/K`1OnWa^l2ojW6
kP;oZ<G_0onYa>h2ojS4kPCoZ<C]0_nY`nd2ojS3k@GoZL?/0_nY`^`5ojS2k003o`000?nY`^coZL;/
00OoZ<7/2?nX`N/5ojS0j`Wooooo00?o0000ooooooooool03oooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Gooooo1?l0000^ooooo`?oZ/7Z0_nb`^H4okC6
i`03okK:jOng_n3o]koP00?o]koP0_ng^md00on`/]Wo[J_Eojf[e@02ojf[e@CoZJ?@0_nTV//01?nI
U<koThk;oi>>bonCS//3ohb8b@?oQXG:0on0Q<d3og^8e@CoPg6f0omoKkL3ogY_^`?oMWC30_m_Om<2
ohYj_0?oNf^f00CoWXBgohi`[?n>L:coSW2/0on0HZH2ogMKY@?oKURX0omWGkH3oeelf@?oP6>W0_n6
JJX00onGTlkoSHG6ohf5aP02ohf5aP?oRh730onAPKh3ohmm_0;oT7jl00?oTh_8oiNAc?nGTL`00_nG
TL`4oi^Hc`?oWigB1OnRX]@2ojFTe0?oYLgd0_nVcO@3oikJo0;oWMWl0onIfOd2oiOIoP?oVmCl0onH
e?`2oiKDo@?oVlki0_nHco/2oig:m`GoVl_h0_nIc?T2oig8mPCoVlWg0_nKboP3oig7m@CoWLWf0_nO
b_H3oio7m0;oXLSd0_nQa_84oj?7lP;oYLOb0_nTa_44ojK6l0;oYlK_0_nVaNl5ojS5k`03ojW4k_nX
a>koZ<C^00;oZ<C^0_nXa>d6ojS3k@;oZL?/0_nX`^d7ojS2k003o`000?nX`NcoZ<7/00SoZ<7/2?nX
`N/4ojS0j`Wooooo00?o0000ooooooooool03oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00Cooooo0_l0000aooooo`03oj[1j_nb`^Ko//;V00;o//;V0_nd
a^L2okK1hPCo]koP00?o/[SMok2bfOn`/]T00_n`/]T4ojf[e@;oZJ?@00?oWicAoiVDc_nIU<h00_nI
U<h3oi>>b`?oS8S90on6QLX3oh24c@;oNhSE1OmeU><4ofB/n003oaNUcOn[Y=7oZjCA00?oVHk60on:
N[`3og][]P?oMFJd0on0HZH2ogMKY@?oKURX1?mWGkH3oeelf@03om;]ionUZ][oUi?>00?oUi?>0on=
QLH3oh^1``?oS8730on>QLD4oi>;b0CoUi7<0onKV<l4oinMdP;oXZ;D0onUbo@2ojG=m0?oWm[l0_nN
f_`4oicJo@;oVMWm0onNe?/2oi_Do0;oX<gg1?nNcOP2oi_>n@;oWlWe1?nMb_L2oi_;n0?oWlOd1?nM
b?H2oi_9m`?oWlKd0_nMaoD2oj34lPCoWlKc0_nOao@2oj75lPGoXLKb0_nSao82oj?5l@CoY<Ka0_nV
a_02ojG5l0CoY/G_0_nXaNl3ojO4k`;oZ<C^0_nW`nh9ojS3k@CoZ<;]1onX`^`00ol0003oZ<7/ojS1
k007ojS1k0WoZ<7[1?nX`>/8ooooo`03o`000?oooooooooo00oooooo000Rooooo`03o`000?oooooo
oooo02oooooo0onb`^H2okK3i0Co]/7R00?o]koPok:hgOnb^=d00_nb^=d4ok2bf@;o[J_E00?oY:CE
oinLdOnOW=400_nOW=43oiVDcP?oThk;0on<R<T3ohJ5bP?oP8C=0omkR=D5ogFDh`;oI:ch00Co^K_K
oj^TdOn[Y=7oZjCA0onIS/H3ohYj_0?oNf^f0omeI[@3og=X]`?oMe^U0om^F:P3ofMO]P03oeelfOnM
hOgoYJ[J00?oYJ[J0onGTlh4ohf5aP?oRh730on<PL<3ohj5a@?oTh_81?nGTL`4oi^Hc`;oWigB0onT
ao82ojG;m0?oXM[k0_nOf_`3oioKo0;oW=[m0onPe?X2oikDn`;oX/gf1OnPcOL2oik=n0?oX/Sd0onO
bOD2oig:m`?oXLKb0_nOao@2oj;4l@CoX<Gb0_nOa_@2oj;3l@GoX<Cb0_nOa_<2oj;4l@CoXLGb0_nQ
a_82oj;4l@GoXlGa0_nTa_400onTa?3oYLG`ojG5l003ojG5l0;oY/G_0onVa>l2ojO4k`;oY/?^1?nW
`nh2ojS3k@;oYl?]1OnX`nd2ojS2k@SoZ<;/00?oZ<7/o`000?nX`N`02?nX`N`9ojS1j`?oZ<3[2Ooo
ool00ol0003oooooooooo`0>ooooo`008oooool00ol0003oooooooooo`0_ooooo`03ok;2i_nf`nCo
]/?T00;o]/?T0_nf`N83ok>mh@Co/[SM0_n`/]T00onXZm[oY:CEojBTe@02ojBTe@?oWicA0onIU<h4
oi>>b`?oS8S90on6QLX3oh24c@?oNhSE0_meU><2ol3=i0?o^K_K1?n[Y=43oiV>aP;oRWZl0omkJkH3
ogEV]0?oLfRg0omjMl@3ofiHZ0;oIenf0_nMhOd2okg>i`?oYJ[J0onGTlh4ohf5aP?oRh730on<PL<3
ohj5a@CoTh_81?nGTL`2oi^Hc`?oX/7_0_nTao83oj?HnP;oXM[k0onQg?`2oioKo0?oX]Gj0_nPe?X2
ojC=m@CoX/gf0_nPcOL3oj?8l`;oX/Sd0_nTaO05oj?5l@;oXLKb0_nS`o04oj;4l@;oX<Gb0_nS`o04
oj;3l@;oX<Cb0_nR`o05oj;4l@;oXLGb0_nS`o04oj;4l@;oXlGa0onT`o03ojC4l0;oYLG`0onU`nl2
ojK4k`OoY/?^0_nW`nh6ojO3k@;oZ<?]0_nW`^d9ojS2k0;oZ<7/00?o0000ojS1k?nX`N`02?nX`N`6
ojS1j`KoZ<3[2?ooool00ol0003oooooooooo`0>ooooo`009?ooool00ol0003oooooooooo`0_oooo
o`?o]/?T0_nd`^D5ok>mh@;o/[SM00?oZk?NojR[f_nXZmX00_nXZmX4ojBTe@?oWicA0onIU<h2oi>>
b`03oh^Oh_n4X^OoQ:;W00;oQ:;W0omn[?44og>mo@03oeO;lonjnnSo`<gT00?o`<gT0oni^m/2oj^T
d@04oi22_on1M;coPGBloh5d_0?oRWZl0omkJkH2ogEV]0CoLfRg0_mjMl@5ohjMg@03oigQoOo<lN_o
_LkW00;o_LkW0onUZ]X3oiNCcP?oSHG61?n;PL<3ohb1``?oSXG50_nCRlP2oiZ]i0CoWkSZ0_nR`Nl4
ojGFn@;oXmSj0onTgO/2oj7Lo0?oY=Ki0_nReOX2ojG=m@CoY<ge0_nRcOH3ojC8lP;oXlSc0_nUa>l4
ojC5l0;oXlGa0_nU`nl5oj?3l0;oX/Ca0_nT`^l4oj?3l0;oX/?a0_nT`^l4oj;3l0;oX/Ca0_nS`^l5
oj?3l0;oX/Ca0onT`nl2ojC3l0;oY<;^1?nT`nl2ojG3k`;oYL;^1_nV`nh2ojK2kPOoYl?]1_nW`^d2
ojS2k0?oYl;/0_nX`^`2ojO1k0;oZ<7/00?o0000ojS1k?nX`N`02?nX`N`2ojS1j`[oZ<3[1oooool0
0ol0003oooooooooo`0>ooooo`009Oooool2o`00033ooooo00?o]/?TokC2iOnd`^D00_nd`^D2ok>m
h@;o[K[S1?n[/mh4ojR[fP;oY:CE00CoVZSPoiJTgonFY=ooUZCO1?n@X=l3oh^OhPCoQ:;W0omn[?42
og>mo@03ojghk?o3fN[o`mWZ00?o`<gT00CoZ:3>oif@a_nMT<KoWI361?n@P[l2oh5d_0?oMVjl0omk
JkH3ogEV]0?oLfRg0omjMl@3ohjMg@03olcajon[[=SoZjcH00?oVYK>0on<QlP3ohJ1a`?oQH;81?n8
RLd3ohjCe0CoU:3L1?nJ[N@2oinhjP;oYM7g1?nUe_T2ojGMn`;oY=gk0onVf?T2ojCFn@;oYlkd1OnU
cOD2ojC=m@?oYLSa0_nTb?82ojK4k`CoYLC_0_nTaO02ojG3kPCoYL?_0_nS`o02ojG2kPGoY<;_0_nS
`o02ojG2kPCoY<;_0_nR`o03ojC2kP?oXl;_0_nS`o03ojC2kP;oY<?_0_nU`^h5ojC2kP;oY<?_1_nU
`^h2ojK3kP;oY/;]1?nV`^h2ojO3k@WoYl;]1?nW`^`7ojO1k0;oZ<7/00?o0000ojS1k?nX`N`01OnX
`N`2ojS1j`goZ<3[1_ooool00ol0003oooooooooo`0>ooooo`009oooool00ol0003oooooooooo`0^
ooooo`?o]<;U0on^`NP3ojfjh`CoZk?N0_nXZmX00onO[^;oVZSPoiZXh002oiZXh0?oUZCO1?n@X=l3
oh^OhP;oQ:;W0_mSdOH01?moin;o[OS/ojghk?n]n>`4ol?IjP04ol3=i?nXX<koZ:3>ojRPcP?oWI36
0on@P[l3oh5d_0;oMVjl0omXK/D3ogEV]0?oLfRg1?mjMl@00on>WMgoZjcHoj^/f002oj^/f0CoVYK>
0on<QlP3ohJ1a`?oQH;80on8RLd4ohjCe0CoU:3L0_nJ[N@2ojC9l`CoYM7g00CoYMKiojGMnonUgO_o
YMgk0_nXfOT3ojKHn@;oZ<od1?nWc_@2ojG=m@?oY/Sa0_nUb?47ojK4k`;oYLC_0_nV`^h4ojG3kP;o
YL?_0_nV`Nd4ojG2kP;oY<;_0_nU`Nd5ojG2kP;oY<;_0onU`Nd2ojC2kP03ojG1kOnU`NkoYL7^00?o
YL7^0_nT`^h2ojG1k@CoYL;^0_nT`^h2ojG1k@KoYL;^1onV`^d2ojK2kP;oY/;]2?nW`^d3ojO2k0[o
Yl7/0onX`N`00ol0003oZ<7/ojS1k002ojS1k0GoZ<7[3?nX`>/6ooooo`03o`000?oooooooooo00ko
oooo000Xooooo`03o`000?oooooooooo02kooooo00?o]<;Uojk1j?n^`NP00on^`NP3ojfjh`;oZk?N
0_nR]>D3oin^hPCoVZSP0onFY=l2oi2Pg`?oQL7k0_mjbol2ohKUm`?oXo;b0onng_02ol?IjP03ok6_
e_nXX<koZ:3>00;oZ:3>0onMT<H3oi22_`?oPGBl0omfK[`2ofQ^a@?oGXGQ1?mcJ;L2ogYga0?o`<[R
1?n[[=P3oiZFcP?oS8O80on6PLL3ohF2b0CoR8W=1?n>Tm@2oiBPg0;oX;k^1?nTbO<2ojGAm`?oYmgj
00?oYMgkojSInOnXfOT00_nXfOT00onVf?WoZ<odojS?m002ojS?m0;oYlkd0onWbO42ojK8l@;oYlC^
1_nVa>l2ojK2k@GoY/;^0_nU`nh6ojK1k@;oYL;^0_nV`Nd4ojG1k@;oYL;^0onV`Nd2ojG1k@;oY/7]
1?nU`Nd2ojG1kP;oY/7]1OnU`Nd2ojG2kPKoYL7]0_nU`^h2ojK1k@KoY/;]0_nV`Nd5ojK2k@;oYl;]
0_nW`Nd4ojO2k@03ojO2k?nW`NcoYl7/00[oYl7/0_nX`N`00ol0003oYl7/ojS1k003ojS1k0;oZ<7[
3onX`>/5ooooo`03o`000?oooooooooo00kooooo000Yooooo`03o`000?oooooooooo02oooooo0_n^
`NP3ojJok0?oYK[X1?nR]>D3oin^hP;oVZSP0_nB^?44ohfkm@;oQL7k0on<g?l00on6iOOoXo;boj?b
lP04okkNl003okJkg_na[mKo/JoF00;o/JoF0onXX<h3oif@aPCoT8:o0_n1M;`3ogI^_0?oJ6k51?mN
QN401?m2^_7o0000okgneOo>i^P4ol3:hP?oZjcH1?nJU/h3ohb7b0?oQX770on5P/P3ohR9c@;oSY?D
0_nK/NL5oj2nkP;oY<Wc0onXfoT2ojOMnP?oZ][h0_nXfOT3ojWAm@;oZ<od0onXbO42ojO9l@;oYlG^
1?nWa>h2ojK4k`;oYl;]1?nV`^d2ojK2kP;oYl7/1onV`Nd2ojK1k0CoY/7]0_nU`Nd3ojK1k0;oY/7]
0_nV`>`4ojK1k@;oYL7]0_nV`N`4ojK1k@;oYL7]0_nV`Nd7ojG1k@KoY/7]0_nV`^d6ojK1k@;oY/;]
1onW`Nd2ojO2kA7oYl7/00Co0000ojO1k?nX`NcoZ<7/0_nW`>/6ojS0j`;oYl3[1onX`>/2ojO0j`Co
oooo00?o0000ooooooooool03_ooool002[ooooo0_l0000aooooo`CoY[o/0onU^^P2oj:di@;oV[W^
1?nG^>h3oi:hl@;oSK_e0on@d_h2ohcLo`;oWn_j0onig_<00onng_3o][_NokJkgP02okJkgPCo/JoF
0onXX<h3oif@aP?oT8:o0on1M;`2ogI^_0CoJ6k50_mNQN400onAkNoo_OkEokgne@03olkVj0;o`<[R
00CoXjSJoi>EdonCUM?oTiGC1?n;S<l3ohJ8cP?oQhcA0on=U]L4oi>Rg`CoVk7W0_nP_^h3ojOGn0;o
Z=_i1?n[foP2oj[Jn0?oZm?e0_nYdOD3ojW;l@;oZ<Wa0_nXaNh4ojO5kP;oYlC^1_nW`^d2ojK2k@Ko
Yl7/0_nV`Nd2ojO1k0GoY/7/0_nV`Nd2ojO0k0;oY/7/0_nW`>`5ojK0k0;oY/7]0_nV`>`4ojK1k0;o
Y/7]0_nV`>`4ojK1k@;oYL7]0_nV`N`7ojK1k@03ojK1k?nV`NgoY/7]00GoY/7]0onV`N`5ojO1kAGo
Yl7/00?oYl3/o`000?nW`>/01?nW`>/2ojS0j`KoYl3[0_nX`>/7ojO0j`?ooooo00?o0000oooooooo
ool03_ooool002cooooo00?o0000ooooooooool0;oooool2ojJok0;oW[g^0onM^nh4oiZikP;oUkS^
0_nFa?H4oi?9nP;oT=;n0_nMh_d3ok;Km@;o^Mkc0_nha>@5okJkgP;o/JoF00CoWioDoiJDconFU<oo
UYC?0on9RLd3oh:4c@?oNXGB0omfK[`2ofQ^a@;oS/7h00?oK=FUokgneOnmo]D00oo>i^P00onb_^;o
XjSJoj>XfP02oj>XfP?oTiGC0on;S<l4ohJ8cP?oQhcA0on=U]L4oi>Rg`;oVk7W0onUd?H2ojOGn0?o
[=[h0_n[foP3ojcEm@;oZm?e0_nZc?84ojW;l@03ojW6konXaNkoZ<G^00?oZ<G^0_nWaNh00onW`ngo
Yl;]ojO2k@05ojO2k@koYl7/0_nV`N`;ojO0k0;oY/3/0_nW`>`5ojK0k0;oY/7/1_nV`>`2ojK1k@;o
Y/3/1?nV`N`2ojK1k@KoY/7/0_nV`Nd5ojK1k1WoYl7/1OnW`>`00ol0003oYl3[ojO0j`0DojO0j`?o
oooo00?o0000ooooooooool03Oooool002gooooo00?o0000ooooooooool0;oooool4oijmkP?oWK_^
0_nJ^Nh2oiS0l`CoU/Cf0_nCbOX3oicHo004oigRoOnbfoGo/]_eok;Km@;o]/WX1?nha>@2okJkgP;o
YjWH0onOWm@4oiJDc`?oRHW=0on2Q<d3ogZ5dPCoOYOQ00?oS/7hojojh?n_n^000_o<m^X2ol3Cj0?o
/[kR1?nSZ=X2oi>Ed`CoRhc?0on6R<h4ohN<d@?oSIKG0_nCX]l3oio4lP;oYM3f0on[f?L2ojcJn0?o
[MOe0_n/eOD2ojc>lPCoZ/cb00?oZL_aojW6konYa^l00_nYa^l2ojS5kP;oZ<?]1?nW`nd2ojO2kA7o
Yl7/4onW`>`2ojK0k0;oYl3/1onV`>`00onW`>coY/3/ojK0k003ojK0k0;oY/7/0_nV`>`6ojK1k0?o
Yl7/0_nV`N`2ojO0k1OoYl7/2?nW`>`00ol0003oYl3[ojO0j`0DojO0j`?ooooo00?o0000oooooooo
ool03Oooool002kooooo00?o0000ooooooooool0;oooool2oijmkP;oW;g_1?nJ__43oiS0l`;oU/Cf
0onLcoX2oicHo0?o[MGe00?o/]_eokK9j?nfbNP00_nfbNP2okS4i003ojfbg?nWZMSoYjWH00?oYjWH
0onOWm@3oiJDc`?oRHW=0on2Q<d4ogZ5dP;oOYOQ00?oKmoTojojh?n_n^000_o<m^X4ol3Cj0?o/[kR
0_nSZ=X01?nBU]CoR8oCohR?don8Sm<3oh^<c`CoQXS>0_n7S=42ohnUi0?oV;G/0onOa?82ojWBmP?o
ZmSg0on^f?H2ojgGm@;o[M3c1?n/c_82oj[<lP?oZLO_0_nYa^l6ojS3k@;oYl?]3OnW`N`2ojO0j`Oo
Yl3/00?oYl3[ojO0k?nW`>`01OnW`>`2ojO0j`coYl3/0_nV`>`6ojO0k0;oY/3/0_nW`>`5ojK0k0;o
Y/7/0_nW`>`2ojO1k0OoYl3/0_nW`N`2ojO0k0KoYl7/0_nW`>`6ojO1k0SoYl3/1OnW`>/00ol0003o
Yl3[ojO0j`0DojO0j`;ooooo00?o0000ooooooooool03Oooool002oooooo00?o0000ooooooooool0
;oooool4oibmk`;oV[ka0_nM`_84oic8mP;oW<oj0onYco@2ojgEm@?o/l[[0_nfbNP2ojnih@?o[K;L
1?nWZMP3oinOe0CoUYC?0on9RLd3oh:4c@;oNXGB0_mkaoh2oj_bm0;o`O[[0oo6h^d2ol3Cj004oj^a
gOnLXMSoW:7HoibQf0CoTYKD0_n8Sm<3ohJ@ePCoRISL1On?YN@3oiRek003oio4l_nYd_KoZM;f00;o
ZM;f00CoZmSgojkHm_n^f?Ko[]Sf0_n^d_<4ojg@l`;o[<kb0on[bNl2ojW7k`;oZLC]1_nX`nd2ojS2
k0_oYl7/1_nW`>/2ojO0k0KoYl3[0_nW`>`7ojO0j`;oYl3/0_nW`>/DojO0k0;oY/3/5?nW`>`2ojO1
k0KoYl3/0_nW`N`8ojO0k0WoYl3[00?o0000ojO0jonW`>/04onW`>/2ooooo`03o`000?oooooooooo
00gooooo000`ooooo`;o0000<?ooool2oibmk`;oW[g^1?nM`_82oic8mP?oY/Wb0_nYco@2ok39k0?o
/l[[0_n`_^@4ojnih@?o[K;L0_nWZMP01?nLXMOoTi[Goi>JeonCV]L4ohbGf@CoPIOO1?mmYnh00omk
aokoZo;doj_bm002ol7jj`?oa^;]00?o]/;Soj^agOn[/Md00_n[/Md3oibQf0?oTYKD0on8Sm<3ohJ@
ePCoRISL0_n?YN@2oifmk`GoY<[c0_nYd_H3ojkGmP03ojkHm_n^d_?o[];c00;o[];c0_n]d?<3ojc;
l0;oZlW_0_nYaNh4ojW4k@;oZ<?]1_nX`^`7ojO1k1ooYl3[0_nW`>`00onW`>_oYl3/ojO0k005ojO0
k0;oYl3[;?nW`>`<ojO0j`03o`000?nW`>_oYl3[01CoYl3[00?oooooo`000?ooool03_ooool003;o
oooo00?o0000ooooooooool0;_ooool4oijmkP;oWL;b0onUa>l2ojK9lP;o[LK/1?n`bN`00oncb^_o
/;kTok2ni002ok2ni0;o[kWQ00CoYjkLoj>Xf_nSZ=[oXjSJ1?nLXML3oi>Je`CoS9OI1?n1Uml2ogfW
kP;oW=_m0_n^m?<3ol7Xl@04olKRkOnf`^?o]/;SokK2h`CoZk7M0onLXMP3oi:Fe0?oR8oC0on6T=H2
ohVHg0;oUZoY1?nM_Nl2ojC:l`?oZmCf0_n^eoH3ojoDl`;o[];c0on]cO02ojc;l0;oZ/O^1OnYaNh2
ojW4k@SoZ<;/1OnW`N`VojO0j`;oYl3/1onW`>/2ojO0k0;oYl3[0_nW`>`2ojO0j`OoYl3/00?oYl3[
ojO0k?nW`>`03OnW`>`2ojO0j`KoYl3/4OnW`>/00ol0003oYl3[ojO0j`0CojO0j`03ooooool0003o
oooo00kooooo000cooooo`03o`000?oooooooooo02kooooo0_nN_Nh3ojFok0;oYLC_0_n[`n/4ojg6
k0;o/<W/0_n``>H3ok2ni003oj^dgonW[]coYjkL00;oYjkL0onSZ=X4oibQe`?oTi[G0_n<UmT2oi2b
k@GoT/7f00?oW=_mojkdlon^m?<00oo1j?42okc?j@Co]/;S0_n[/Md01?nLYMcoTYcJoi:Lf_nBW=X3
ohfHfPCoRi[M0on>X^84oiJ_j@;oWKg_0onWc_@2oj_DmP?o[]Cd0_n_e?<3ojk?l@;o[Lg`0_n[b>l4
oj[7kP;oZLG^0_nY`nd6ojS2k0?oZ<7/0_nW`N`lojO0j`;oYl3/1_nW`>/2ojO0k0;oYl3[1onW`>`6
ojO0j`;oYl3/5OnW`>/00ol0003oYl3[ojO0j`0CojO0j`03o`000?oooooooooo00gooooo000doooo
o`03o`000?oooooooooo02kooooo0onU_n`2oj[1jPCoZl?[0_n]a^`2ojo1i`Co/<3V00Co/;kToj^d
gon[]=ooZkCO1?nW[]`3oj>XfP;oW:7G0_nGZN<3oi6Zi`CoT;;]0_nB`OH3ojCWn`?o^^Od00?o`NSa
okc?jOnlcnT00_nlcnT2okK2h`03ojJ`gonLYMcoW:GL00;oW:GL0onBW=X3ohfHfPCoRi[M0on>X^82
oiJ_j@?oXLGb0_nWc_@3ojcBm0;o[]Cd0_n^d?83ojk?l@;o[<[_1?n[b>l2oj[7kP;oZLC]1?nY`nd2
ojS2k0GoZ<7/C?nW`>/2ojO0k2;oYl3[00?o0000ojO0jonW`>/04OnW`>/00ooooooo0000ooooo`0>
ooooo`00=Oooool2o`0002oooooo00?oYKo/oj[1j_nZ`NX00_nZ`NX2oj_3j`;o[/7X1?n_`NL2ok30
iP;o[;WR1?n[]=l2ojN^g003oj6_h_nL[>;oW:cR00;oW:cR1?nGZN<3oi6Zi`;oT;;]0onJe_`01?nT
io_o^^Odok[Wm?njio@3okgIk@;o_<oY0_n__><4ojJ`g`CoW:GL0onBW=X3ohfHfP;oRi[M0_nB[NP4
oiRhkP;oXLGb0_nYc_<3ojcBm0;o[]7b1?n^d?800on^co7o[<[_ojc:k`02ojc:k`;oZlS_0_nZaNd4
ojW4k@;oZL?]0onX`^`4ojS1k77oYl3[00?o0000ojO0jonW`>/03OnW`>/6ooooo`03o`000?oooooo
oooo00cooooo000gooooo`03o`000?oooooooooo02kooooo0_nZ`NX2ojg1j@Co[/7X0_n_`NL2ojfl
i@Co[;WR0_n[]=l2ojFch`?oXJoR1?nL[>82oiNYh`;oV;ca1?nFaOL2oi[Fo0;o[moh0onhfo82okgI
k@;o]<KW1?n__><2ojJ`g`03oi^Wg_nEX]goUJ;M00;oUJ;M0on?X=l4ohnTh`CoTZgX0_nH^>h2oj?6
lPCoZLkc00?o[=;dojkAl_n^dO800_n^dO82ojk@lP?o[Lc`0_n/b^l2oj_6kPCoZ/G]0_nYa>d5ojS2
k0KoZ<7/LOnW`>/00ol0003oYl3[ojO0j`09ojO0j`Wooooo00?o0000ooooooooool03?ooool003So
oooo00?o0000ooooooooool0;_ooool4ojg1j@;o[/7X0_n]_nL4ojfli@;o[;WR0_nW]n@4ojFch`?o
XJoR0_nL[>82oiVgk@CoV;ca0_nFaOL3ojOEn004ojoOn?nhfo;o^=_bokSKlP;o]Lc[1?nda^L2ojnl
h`03ojB_gonKYmkoVjON00;oVjON1?nEX]d3ohnPg`CoSjCS0_nB[NP2oiflk`CoXlKb0_nYc_<3ojg@
l`;o[]7b0on^c_02ojg<l0;o[<S^1?n[a^h2oj[5k@?oZL?/0_nX`^`8ojS1k7?oYl3[00?o0000ojO0
jonW`>/01OnW`>/<ooooo`03o`000?oooooooooo00cooooo000iooooo`03o`000?oooooooooo02ko
oooo1?n]`NT4ojfoi`;o[KcU0_nY^nH4ojNgi0;oYK?S0_nQ]nP3oijfj@CoVKO]0_nH_?43oj;<mP;o
YmGh0onafO@00onhfo;o]Lc[okG<j`02okG<j`;o]<KW0_nZ]n83ojB_g`CoVjON0onEX]d2ohnPg`03
oiB/i_nG/n_oUk?[00;oUk?[1OnM_>l2oj?6lP;oZLgc0_n]d?<3ojg>l@;o[/k`0_n]b^l5ojc8kP;o
ZlK^0_nZa>d2ojW3k0;oZ<;/1_nX`N`2ojS1jgKoYl3[00?o0000ojO0jonW`>/04?ooool00ol0003o
ooooooooo`0<ooooo`00>_ooool2o`0002oooooo1?n]`NT2ojfoi`;oZ[kX1?nY^nH2ojNgi0;oY;WX
1?nQ]nP3oijfj@;oVKO]0onOa?<2oj;<mP?oZ]Cf0_nafO@3okC?kP;o]Lc[0_n__^D4ojZghP?oY:oO
0_nKYmh00onHZN;oUJSSoiFXh`02oiFXh`?oU:cV1?nG/n/2oiflk`?oYLOb0_nYcO<3ojc=l@;o[Lka
0_n]bnl4ojg:k`;o[<S^0on[aNd2oj[4k@;oZL;/1?nX`^`2ojS1k0KoZ<7[MOnW`>/00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00cooooo000looooo`03o`000?oooooooooo02gooooo0_n]
`NT2oj[1jPCoZ[kX0_nY^nH2ojFkj@CoY;WX0_nQ]nP2oj2nkPCoWl3`0_nOa?<3ojK>m@;oZ]Cf0on`
co02okC?kP;o/LCX1?n__^D2ojZghP03oj>ahonN[N;oWZgR00;oWZgR0onHZN84oiFXh`?oU:cV0_nG
/n/3oik0l0;oYLOb0_nYbo43ojc=l@;o[Lc`1?n]bnl2ojg:k`?oZlO^0_n[aNd2ojW3k0CoZL;/0_nX
`^`2ojS1k0KoZ<7[L_nW`>/5ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03?oo
ool003gooooo00?o0000ooooooooool0;Oooool4oj[1jP;oZ[kX0_nW_^X4ojFkj@;oY;WX0_nR_Nd4
oj2nkP;oWl3`0onSb?<2ojK>m@;o[<ca0on`co02ok36j`Co/LCX0_n__^D2ojRgi0?oXk7S1?nN[N83
oiRYhP;oUJSS0_nH/^X4oiZhk@;oW/3`0_nUa_44ojW;l@03ojc=lOn]c?3o[Lc`00;o[Lc`0_n]bnl3
ojc8kP;oZlO^0_nZa>d4ojW3k0;oZL;/1_nX`N`2ojS1j`;oZ<3[L?nW`>/9ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03?ooool003kooooo00?o0000ooooooooool0;Oooool2oj[1
jP?oYl3[0onW_^X2ojFkj@;oXkk/1?nR_Nd2oj2nkP?oX/Ga0_nSb?<2ojW9l@Co[<ca00?o/<o`ok36
jon`a^/00_n`a^/2ok74j0;oZkcV1?nX]n@3oj>ah`;oWZgR0_nK[nD3oiR_i`CoV;;Z0_nJ^>d2oj71
k`CoYLKa0_nYbo43oj_;l@;o[Lc`0on/bNl2ojc8kP;oZlG]1?nZa>d2ojW3k0;oZL;/1_nX`N`2ojS1
j`CoZ<3[J?nW`>/@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool003oo
oooo0_l0000_ooooo`;oYl3[0_nU_n`4ojBnk0?oXkk/0_nR_Nd3oj;2k`;oX/Ga0_nVa_04ojW9l@;o
[<ca0on^b>d2ok36j`;o[;oW1?n[_>H2ojRgi003oj>ci?nO/>CoWk3T00;oWk3T1?nK[nD3oiR_i`;o
V;;Z0_nM^nd4oj71k`;oYLKa0onXbO42oj_;l@Go[<W_0_n[anh4oj_5k@;oZ/C]0_nY`n`4ojW2k0;o
Z<7/1_nX`N/2ojS0jfKoYl3[5?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_o
oooo0011ooooo`03o`000?oooooooooo02gooooo1?nU_n`2ojBnk0;oXko]1?nS`Nh2oj;2k`;oYLC_
1?nVa_02ojW9l@?o[<O^0_n^b>d2ojg2j@Co[;oW0_n[_>H2ojJgi@?oXk?T1?nO/>@2oi^_i@;oW;CY
1?nL]n/3oifkk@;oXL7_0onVa_02ojS9l@;oZ/W`1On/bNl4oj_7kP;oZlG]00?oZ/C]ojW3k?nY`n`0
0onY`n`2ojW2k0;oZ<7/1_nX`N/2ojS0jfCoYl3[6?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00_ooooo0012ooooo`03o`000?oooooooooo02gooooo0_nU_n`2ojBok@CoXko]0_nS
`Nh2ojG2kPCoYLC_0_nVa_03ojW6kP;o[<O^0_n/`n/4ojg2j@;o[;oW0_nY^^H4ojJgi@?oXk?T0_nO
/>@2oijdi`CoW;CY0_nL]n/2oj2nkPCoX/;_0_nVa_02ojS7l0CoZ/W`0_n/bNl4oj_7kP;oZ/G]1?nZ
a>d2ojW3k0?oZL;/0_nX`N`6ojS1j`;oZ<3[HOnW`>/Mooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02oooool004?ooooo00?o0000ooooooooool0;Oooool4ojBok@;oXko]0_nT`>d4
ojG2kP;oYLC_0onXa>h2ojW6kP;oZl?[1?n/`n/2ojg2j@;oZ[gW1?nY^^H2ojJgi@;oXkOV0onQ]NH4
oijdi`;oW;CY00?oWk_/oj2nk_nP_^h00onP_^h2oj;2k`03ojK5l?nXao3oZ<O`00?oZ<O`0_nZbO02
oj_8k`;oZlO^1_nZaNd2oj[4k@GoZL;/0_nX`N`6ojS1j`;oZ<3[GonW`>/Pooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool004Cooooo00?o0000ooooooooool0;Oooool2ojBo
k@;oYKo/1?nT`>d2ojG2kP?oYl?]0_nXa>h2ojW2k0CoZl?[0_n/`n/2ojZnj0CoZ[gW0_nY^^H2ojJi
i`CoXkOV0onQ]NH2oijdi`03oinijonO^ncoWk_/00;oWk_/0_nP_^h2ojC2k`CoY/G`0_nXao03ojW7
k`;oZlS_0_nZa^h6oj[5k@?oZL?/0_nY`^`2ojS2k0CoZ<7/0_nX`N/6ojS0je_oYl3[9?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0015ooooo`;o0000;oooool3ojFok0;o
Y<3]0onV`N`2ojO3k@KoZL;/0_n[`n/2oj[0j@CoZ[kX0_nZ_NL00onW^nOoY[WWojJii`03ojJii`;o
XkOV00?oX[SXoj6hjOnQ^>T00_nQ^>T3oinij`;oWk_/0_nR_nh4ojC2k`;oY/G`0onXa^l2ojW7k`Ko
Z/K^0_nZaNd3oj[4k@;oZL?/0_nY`^`4ojS2k0;oZ<7/0_nX`N/6ojS0jeSoYl3[:Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo0017ooooo`03o`000?oooooooooo02gooooo
1?nV_n`2ojK1k0;oZ<7[1_nY`^`2oj[0jPCoZ/3Y0_nZ_^P00onX_>SoYk_WojNki`02ojNki`;oY[WW
0_nT^NP4oj:hj0;oXKSY0_nR_>/4oj6mk@?oX[o^0_nT`^l3ojK4k`;oZ<K_0_nYa^h6oj[6kPGoZ/C]
0_nY`n`4ojW2k0;oZ<;/0_nX`N`4ojS1j`?oZ<3[EonW`>//ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool004Sooooo00?o0000ooooooooool0;Oooool2ojJok0;oZ<3[1?nX
`N/2ojW2k0;oZL7Z1?nZ`>X2oj[0j@03ojVnjOnX_>SoZ;cX00;oZ;cX0_nW^nL2ojFjj0CoY;WX0_nR
^>P2oj:kj`CoX[c[0_nQ_Nd2oj?0kPCoY<;_0_nVa>l2ojO5k`CoZLK^0_nZa^h3ojW5k@;oZ/C]1_nY
`n`2ojW2k0KoZ<7/0_nX`N/5ojS0je?oYl3[<?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00_ooooo0019ooooo`03o`000?oooooooooo02gooooo1?nX`>/2ojS1j`;oZL3[1?nY`NX2
oj[0jP;oZKoY0onY_^T2ojRlj0;oYkcX1?nU^^P2ojBij0;oXk_Z1?nR^n/2oj:lj`;oXko]1?nS`>h2
ojC2k`;oY/C^1?nWaNl2ojW6kP?oZLG^0_nYaNd2ojW4k@KoZL?/00?oZ<;/ojS1k?nX`N`01?nX`N`3
ojS1j`CoZ<3[D_nW`>/dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
04[ooooo0_l0000^ooooo`CoZ<3[1?nY`>/2ojW1jP?oZKoZ0onY_nT01?nY_^WoZ;gYojRmjOnX_NT3
ojNlj0;oYK[X0_nT^nT4oj>kjP;oX[_[0_nS_^`4oj>ok@;oXl3^0_nU`^h4ojK4kP;oYlG_0onXaNh2
ojW5kPKoZLC]0_nY`n`00onY`^coZ<;/ojS2k002ojS2k0;oZ<7/1OnX`N/6ojS0jdgoYl3[>Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo001<ooooo`03o`000?oooooooooo
02cooooo1?nX`>/2ojW0j`?oZL3Z0_nY_nX00onX_n[oZ;kYojRnj@02ojRnj@;oZ;gY0_nV_NT4ojJl
j@?oY;_Y0_nS^nX3ojBmj`?oXkk/0_nS_nd3ojC1kP?oYL;^0_nVa>h3ojO4kP;oZ<G^00?oZ<C]ojW4
kOnYa>d01?nYa>d3ojW3k0?oZL;/0_nX`^`3ojS1k0CoZ<7[1_nX`>];ojO0jccooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0:ooooo`00COooool00ol0003oooooooooo`0/ooooo`;o
Z<3[0onY`>/2ojW0jPGoZ;oZ0_nX_^T2ojNnjPCoY[gY0_nV_>T2ojFmj`KoY;g[0_nT_n`4ojC0k@;o
Y<7^0_nV`^h4ojK3kP;oYlC^1OnXa>d2ojW4k@?oZL?]0_nY`n`6ojS2k0;oZ<7/1_nX`N/4ojS0jdKo
Yl3[@oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo001>ooooo`03o`00
0?oooooooooo02gooooo0_nY`>/00onX`>_oZ;oZojRojP04ojRojPKoYkkZ0_nV_NT2ojJmj`CoYKg[
0_nT_N/2ojBnk0CoY;o/0_nT`>d2ojG1k@CoY/;^0_nV`nh00onW`nkoZ<C]ojS4k@04ojS4k@?oZ<?]
0_nY`nd8ojS2k0;oZ<7/1_nX`N/6ojS0jd;oYl3[Aoooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00[ooooo001?ooooo`;o0000;_ooool3ojS0j`;oZ;oZ0_nW_n/6ojNnjP;oY[k[1?nV
_N/2ojFmj`;oYKk/1?nT_^`2ojBok0;oYL3]1?nU`Nd2ojK2kP03ojK2kOnW`nkoYl?^00;oYl?^0_nX
a>d5ojS3k@SoZ<;/1_nX`N`2ojS1j`SoZ<3[?onW`>]<ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02_ooool0057ooooo00?o0000ooooooooool0;?ooool3ojS0j`CoYko[0_nW_^X2
ojNoj`CoY[k[0_nV_N/2ojFnj`CoYKk/0_nT_^`6ojG0k@;oYL7]1OnV`^d2ojO3kP?oYl?]0_nX`nd2
ojS2k@KoZ<;/2?nX`N`2ojS1j`GoZ<3[@?nW`>]?ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02_ooool005;ooooo00?o0000ooooooooool0:oooool4ojS0j`SoYko[0_nV_^/3ojJo
j`?oYKk[0_nU_^`3ojFok0GoYL3]0_nV`Nd2ojK2k@KoYl;]0_nW`nd6ojS2k@CoZ<;/2?nX`N`2ojS1
j`KoZ<3[?OnW`>]Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool005?o
oooo00?o0000ooooooooool0:oooool2ojS0j`?oYl3[0_nW_n/8ojJoj`SoYKo/00?oYL3]ojG1kOnU
`Nd00_nU`Nd2ojK1k@;oY/;]2?nW`^d6ojS2k@KoZ<;/1_nX`N`2ojS1j`KoZ<3[>onW`>]Gooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool005Cooooo0_l0000]ooooo`;oYl3[
0_nV_n`6ojJoj`;oY[o/1_nU_n`00onU`>coYL3]ojG0k@02ojG0k@;oYL7]0_nV`Nd4ojK2k@SoYl;]
0_nX`^d5ojS2k0OoZ<7/1_nX`N/2ojS0jc_oYl3[F_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Wooooo001Fooooo`03o`000?oooooooooo02_ooooo1?nV_n`2ojJoj`KoY[o/0_nU
_n`2ojK0k0?oYL3/0_nU`>d6ojK1k@;oY/;]0onW`Nd5ojO2k@?oYl;/0_nX`^`9ojS1k0KoZ<7[0_nX
`>/iojO0jekooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`00Eoooool0
0ol0003oooooooooo`0[ooooo`goY[o/0onV`>`01?nU`>coY/3/ojK0k?nV`>`8ojK1k@;oYl7]0_nW
`N`6ojO2k003ojO1k?nX`NcoZ<7/00[oZ<7/0_nX`N/6ojS0jc7oYl3[I_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Wooooo001Hooooo`03o`000?oooooooooo02cooooo2_nV_n`7
ojK0k0KoY/7/0_nV`Nd6ojO1k0;oYl;/1OnW`N`:ojS1k0?oZ<7[0_nX`>/bojO0jf[ooooo00Go0000
ooooooooooooooooo`00000;ooooo`00FOooool00ol0003oooooooooo`0/ooooo`OoY[o/2?nV`>`6
ojK1k1;oYl7/2?nX`N`2ojS1jc;oYl3[KOooool01Ol0003ooooooooooooooooo000000_ooooo001J
ooooo`;o0000;Oooool7ojJok0SoY/3/1?nV`N`DojO1k0KoZ<7/<_nW`>]aooooo`04o`000?oooooo
ooooo`0000_ooooo001Looooo`03o`000?oooooooooo02_ooooo1OnV_n`;ojK0k0?oY/7/5?nW`N`2
ojS1k3;oYl3[MOooool00ol0003oooooo`00000;ooooo`00GOooool00ol0003oooooooooo`0[oooo
o`CoY[o/2_nV`>`2ojO0k1GoYl7/<_nW`>]hooooo`04o`000?ooooooooooo`0000[ooooo001Noooo
o`03o`000?oooooooooo02_ooooo1?nV_n`8ojK0k0CoYl3/0_nW`N`00onW`>coYl7/ojO1k00<ojO1
k0;oYl3/<?nW`>]looooo`03o`000?oooooo000000[ooooo001Oooooo`;o0000;?ooool4ojJok0So
Y/3/1onW`>`2ojO1k0?oYl3/1OnW`N`4ojO0k2_oYl3[Poooool2o`0000[ooooo001Qooooo`03o`00
0?oooooooooo02[ooooo0_nV_n`8ojK0k1CoYl3/:_nW`>^5ooooo`?o00002_ooool006;ooooo00?o
0000ooooooooool0:oooool2ojK0k0;oYl3[5OnW`>`ZojO0jhCooooo1?l0000=ooooo`00Hoooool0
0ol0003oooooooooo`0[ooooo`CoYl3[0_nW`>`00onW`>_oYl3/ojO0k00<ojO0k2[oYl3[Poooool4
o`00017ooooo001Tooooo`;o0000;?ooool7ojO0j`;oYl3/0onW`>/5ojO0k2[oYl3[Poooool3o`00
01Gooooo001Vooooo`03o`000?oooooooooo02_ooooo<onW`>^5ooooo`Co00006?ooool006Oooooo
00?o0000ooooooooool0:_ooool`ojO0jhCooooo1?l0000Looooo`00J?ooool00ol0003ooooooooo
o`0ZooooobcoYl3[Poooool4o`00023ooooo001Yooooo`;o0000;?oooolWojO0jh;ooooo1?l0000T
ooooo`00Joooool00ol0003oooooooooo`0Zooooob?oYl3[P_ooool3o`0002Sooooo001/ooooo`03
o`000?oooooooooo02[ooooo7OnW`>^3ooooo`Co0000:oooool006gooooo00?o0000ooooooooool0
:ooooolHojO0jh;ooooo1?l0000_ooooo`00K_ooool00ol0003oooooooooo`0ZoooooaGoYl3[POoo
ool4o`0003?ooooo001_ooooo`;o0000:ooooolAojO0jh3ooooo1?l0000gooooo`00LOooool00ol0
003oooooooooo`0Zooooo`WoYl3[P_ooool4o`0003_ooooo001booooo`03o`000?oooooooooo02[o
oooo1OnW`>^2ooooo`?o0000?oooool007?ooooo00?o0000ooooooooool0:_ooool00onW`>_ooooo
ooooo`1oooooo`Co0000@_ooool007Cooooo0_l0000Zooooo`03o`000?oooooooooo07_ooooo1?l0
0016ooooo`00M_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07Sooooo1?l0001:
ooooo`00Moooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07Cooooo1?l0001>oooo
o`00N?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo077ooooo0ol0001Booooo`00
NOooool2o`0002Cooooo00?o0000ooooooooool0KOooool4o`0005Gooooo001kooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0JOooool4o`0005Wooooo001looooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0IOooool4o`0005gooooo001mooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0HOooool4o`00067ooooo001nooooo`;o00007oooool00ol0003o
ooooooooo`1Mooooo`Co0000IOooool0083ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1Jooooo`?o0000JOooool0087ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`1Fooooo`Co0000K?ooool008;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1B
ooooo`Co0000L?ooool008?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1>oooo
o`Co0000M?ooool008Cooooo0_l0000Iooooo`03o`000?oooooooooo04[ooooo1?l0001hooooo`00
Q_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Kooooo1?l0001looooo`00Qooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04?ooooo0ol00020ooooo`00R?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03oooooo1?l00023ooooo`00ROooool2o`00
01Cooooo00?o0000ooooooooool0>oooool4o`0008Oooooo002;ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0=oooool4o`0008_ooooo002<ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0<oooool4o`0008oooooo002=ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0<?ooool3o`0009?ooooo002>ooooo`;o00003oooool00ol0003oooooooooo`0/
ooooo`Co0000U_ooool0093ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Xoooo
o`Co0000V_ooool0097ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Tooooo`Co
0000W_ooool009;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`Co0000
X_ooool009?ooooo0_l00009ooooo`03o`000?oooooooooo01gooooo1?l0002Vooooo`00UOooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo0ol0002Zooooo`00U_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo1?l0002]ooooo`00Uoooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01;ooooo1?l0002aooooo`00V?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0002eooooo`00VOooool2o`0000?ooooo00?o
0000ooooooooool02_ooool4o`000;Wooooo002Kooooo`04o`000?ooooooooooo`0000Wooooo0ol0
002mooooo`00W?ooool00ol0003oooooo`000005ooooo`Co0000`?ooool009gooooo0_l000000ooo
oooo0000o`000002o`000<Cooooo002Nooooo`;o0000b?ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00:[ooooo00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`Co000000So410@ooooooooooooV9RH
oa0@4?l0003o<S8bolc<c0Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0Toooool0
0:[ooooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`Ko00001?ooool00ol0003oooooooooo`02
ooooo`05oa0@4?nj^[[oooooogMgMolb<S801Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RH
ob4Q8@2Cooooo`00Z_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000009?ooooo002Zooooo`03o`000?oo
oooooooo00Cooooo1_l00004ooooo`03o`000?oooooooooo00Gooooo00?oZJVYoa0@4?ooool02_oo
ool01Ol0003oV9RHoooooonHV9So8B4Q09?ooooo002Zooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool01?ooool00ol@413o0000okZj^P0;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
Toooool00:Sooooo00?o410@o`000?l000000ol0000=ooooo`03o`000?oooooooooo00Gooooo00?o
^[Zjob4Q8Oooool02_ooool00omEEEGoQhN7ooooo`2Eooooo`00Z_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00;ooooo00Go410@oiRHV?oooooo^[Zjo`00000;ooooo`03omgMgOl@
413oV9RH09Gooooo002Zooooo`03o`000?oooooooooo00cooooo00?oEEEEofIVI_l000001?ooool0
1OnYZJWo410@o`000?l@413oZJVY00cooooo00Coc<c<odA4A?l0003o410@Toooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -20 0 ]
[.5 .82364 20 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14.4) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69468 Mtetra
.655 .752 .921 r
.4053 .69468 .41061 .69934 .41957 .69681 .41427 .69214 Mtetra
.41427 .69214 .41957 .69681 .42855 .69428 .42327 .6896 Mtetra
.656 .752 .921 r
.42327 .6896 .42855 .69428 .43756 .69174 .4323 .68705 Mtetra
.4323 .68705 .43756 .69174 .4466 .68919 .44137 .68449 Mtetra
.44137 .68449 .4466 .68919 .45567 .68663 .45046 .68192 Mtetra
.45046 .68192 .45567 .68663 .46478 .68407 .45958 .67933 Mtetra
.656 .753 .921 r
.45958 .67933 .46478 .68407 .47391 .68149 .46873 .67674 Mtetra
.46873 .67674 .47391 .68149 .48307 .67891 .47792 .67414 Mtetra
.47792 .67414 .48307 .67891 .49227 .67632 .48713 .67153 Mtetra
.656 .752 .921 r
.48713 .67153 .49227 .67632 .50149 .67371 .49638 .66891 Mtetra
.49638 .66891 .50149 .67371 .51075 .6711 .50565 .66628 Mtetra
.50565 .66628 .51075 .6711 .52004 .66849 .51496 .66365 Mtetra
.51496 .66365 .52004 .66849 .52936 .66586 .5243 .661 Mtetra
.5243 .661 .52936 .66586 .53871 .66322 .53367 .65834 Mtetra
.53367 .65834 .53871 .66322 .54809 .66058 .54308 .65568 Mtetra
.656 .752 .92 r
.54308 .65568 .54809 .66058 .55751 .65792 .55251 .653 Mtetra
.55251 .653 .55751 .65792 .56695 .65526 .56198 .65032 Mtetra
.56198 .65032 .56695 .65526 .57643 .65259 .57148 .64763 Mtetra
.57148 .64763 .57643 .65259 .58595 .6499 .58102 .64493 Mtetra
.656 .751 .92 r
.58102 .64493 .58595 .6499 .59549 .64721 .59058 .64222 Mtetra
.59058 .64222 .59549 .64721 .60507 .64451 .60018 .6395 Mtetra
.60018 .6395 .60507 .64451 .61468 .6418 .60982 .63678 Mtetra
.60982 .63678 .61468 .6418 .62432 .63908 .61948 .63404 Mtetra
.61948 .63404 .62432 .63908 .634 .63636 .62918 .63129 Mtetra
.62918 .63129 .634 .63636 .64371 .63362 .63892 .62854 Mtetra
.63892 .62854 .64371 .63362 .65345 .63087 .64868 .62577 Mtetra
.64868 .62577 .65345 .63087 .66323 .62811 .65848 .623 Mtetra
.65848 .623 .66323 .62811 .67304 .62535 .66832 .62022 Mtetra
.66832 .62022 .67304 .62535 .68289 .62257 .67819 .61742 Mtetra
.67819 .61742 .68289 .62257 .69277 .61979 .68809 .61462 Mtetra
.68809 .61462 .69277 .61979 .70269 .61699 .69803 .6118 Mtetra
.69803 .6118 .70269 .61699 .71264 .61418 .70801 .60898 Mtetra
.70801 .60898 .71264 .61418 .72262 .61137 .71802 .60615 Mtetra
.71802 .60615 .72262 .61137 .73264 .60854 .72806 .6033 Mtetra
.72806 .6033 .73264 .60854 .7427 .60571 .73814 .60045 Mtetra
.73814 .60045 .7427 .60571 .75279 .60286 .74826 .59759 Mtetra
.74826 .59759 .75279 .60286 .76291 .60001 .75841 .59471 Mtetra
.75841 .59471 .76291 .60001 .77308 .59714 .7686 .59183 Mtetra
.7686 .59183 .77308 .59714 .78328 .59427 .77882 .58894 Mtetra
.77882 .58894 .78328 .59427 .79351 .59138 .78908 .58603 Mtetra
.656 .752 .92 r
.78908 .58603 .79351 .59138 .80378 .58849 .79938 .58312 Mtetra
.79938 .58312 .80378 .58849 .81409 .58558 .80971 .5802 Mtetra
.656 .752 .921 r
.80971 .5802 .81409 .58558 .82443 .58267 .82009 .57726 Mtetra
.82009 .57726 .82443 .58267 .83482 .57974 .83049 .57432 Mtetra
.83049 .57432 .83482 .57974 .84523 .5768 .84094 .57137 Mtetra
.84094 .57137 .84523 .5768 .85569 .57385 .85142 .5684 Mtetra
.85142 .5684 .85569 .57385 .86618 .57089 .86195 .56543 Mtetra
.86195 .56543 .86618 .57089 .87672 .56792 .87251 .56244 Mtetra
.87251 .56244 .87672 .56792 .88729 .56494 .8831 .55944 Mtetra
.656 .753 .921 r
.8831 .55944 .88729 .56494 .89789 .56195 .89374 .55643 Mtetra
.89374 .55643 .89789 .56195 .90854 .55895 .90441 .55341 Mtetra
.90441 .55341 .90854 .55895 .91923 .55594 .91513 .55038 Mtetra
.91513 .55038 .91923 .55594 .92995 .55292 .92588 .54733 Mtetra
.656 .752 .921 r
.92588 .54733 .92995 .55292 .94071 .54988 .93667 .54427 Mtetra
.93667 .54427 .94071 .54988 .95152 .54684 .9475 .5412 Mtetra
.9475 .5412 .95152 .54684 .96236 .54378 .95837 .53812 Mtetra
.95837 .53812 .96236 .54378 .97324 .54071 .96929 .53502 Mtetra
.656 .752 .92 r
.96929 .53502 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.655 .751 .921 r
.391 .69252 .39636 .6972 .4053 .69468 .39996 .68999 Mtetra
.655 .752 .921 r
.39996 .68999 .4053 .69468 .41427 .69214 .40895 .68745 Mtetra
.40895 .68745 .41427 .69214 .42327 .6896 .41797 .68489 Mtetra
.41797 .68489 .42327 .6896 .4323 .68705 .42702 .68233 Mtetra
.42702 .68233 .4323 .68705 .44137 .68449 .4361 .67976 Mtetra
.4361 .67976 .44137 .68449 .45046 .68192 .44521 .67717 Mtetra
.656 .753 .921 r
.44521 .67717 .45046 .68192 .45958 .67933 .45435 .67458 Mtetra
.45435 .67458 .45958 .67933 .46873 .67674 .46352 .67197 Mtetra
.46352 .67197 .46873 .67674 .47792 .67414 .47273 .66935 Mtetra
.47273 .66935 .47792 .67414 .48713 .67153 .48196 .66672 Mtetra
.48196 .66672 .48713 .67153 .49638 .66891 .49123 .66408 Mtetra
.49123 .66408 .49638 .66891 .50565 .66628 .50053 .66144 Mtetra
.656 .752 .921 r
.50053 .66144 .50565 .66628 .51496 .66365 .50985 .65878 Mtetra
.50985 .65878 .51496 .66365 .5243 .661 .51922 .65611 Mtetra
.51922 .65611 .5243 .661 .53367 .65834 .52861 .65343 Mtetra
.52861 .65343 .53367 .65834 .54308 .65568 .53803 .65075 Mtetra
.656 .752 .92 r
.53803 .65075 .54308 .65568 .55251 .653 .54749 .64805 Mtetra
.54749 .64805 .55251 .653 .56198 .65032 .55698 .64535 Mtetra
.55698 .64535 .56198 .65032 .57148 .64763 .5665 .64264 Mtetra
.5665 .64264 .57148 .64763 .58102 .64493 .57606 .63993 Mtetra
.656 .751 .92 r
.57606 .63993 .58102 .64493 .59058 .64222 .58565 .6372 Mtetra
.58565 .6372 .59058 .64222 .60018 .6395 .59527 .63446 Mtetra
.59527 .63446 .60018 .6395 .60982 .63678 .60493 .63172 Mtetra
.60493 .63172 .60982 .63678 .61948 .63404 .61461 .62896 Mtetra
.61461 .62896 .61948 .63404 .62918 .63129 .62434 .6262 Mtetra
.62434 .6262 .62918 .63129 .63892 .62854 .63409 .62343 Mtetra
.63409 .62343 .63892 .62854 .64868 .62577 .64388 .62064 Mtetra
.64388 .62064 .64868 .62577 .65848 .623 .65371 .61785 Mtetra
.65371 .61785 .65848 .623 .66832 .62022 .66357 .61505 Mtetra
.66357 .61505 .66832 .62022 .67819 .61742 .67346 .61224 Mtetra
.67346 .61224 .67819 .61742 .68809 .61462 .68339 .60942 Mtetra
.68339 .60942 .68809 .61462 .69803 .6118 .69335 .60658 Mtetra
.69335 .60658 .69803 .6118 .70801 .60898 .70335 .60374 Mtetra
.70335 .60374 .70801 .60898 .71802 .60615 .71338 .60089 Mtetra
.71338 .60089 .71802 .60615 .72806 .6033 .72345 .59803 Mtetra
.72345 .59803 .72806 .6033 .73814 .60045 .73356 .59516 Mtetra
.73356 .59516 .73814 .60045 .74826 .59759 .7437 .59227 Mtetra
.7437 .59227 .74826 .59759 .75841 .59471 .75388 .58938 Mtetra
.75388 .58938 .75841 .59471 .7686 .59183 .76409 .58648 Mtetra
.76409 .58648 .7686 .59183 .77882 .58894 .77434 .58357 Mtetra
.77434 .58357 .77882 .58894 .78908 .58603 .78463 .58065 Mtetra
.656 .752 .92 r
.78463 .58065 .78908 .58603 .79938 .58312 .79495 .57772 Mtetra
.656 .752 .921 r
.79495 .57772 .79938 .58312 .80971 .5802 .80531 .57478 Mtetra
.80531 .57478 .80971 .5802 .82009 .57726 .81571 .57183 Mtetra
.655 .752 .921 r
.81571 .57183 .82009 .57726 .83049 .57432 .82614 .56887 Mtetra
.82614 .56887 .83049 .57432 .84094 .57137 .83662 .5659 Mtetra
.83662 .5659 .84094 .57137 .85142 .5684 .84713 .56292 Mtetra
.84713 .56292 .85142 .5684 .86195 .56543 .85768 .55993 Mtetra
.85768 .55993 .86195 .56543 .87251 .56244 .86827 .55693 Mtetra
.656 .753 .921 r
.86827 .55693 .87251 .56244 .8831 .55944 .87889 .55391 Mtetra
.87889 .55391 .8831 .55944 .89374 .55643 .88956 .55088 Mtetra
.88956 .55088 .89374 .55643 .90441 .55341 .90026 .54784 Mtetra
.90026 .54784 .90441 .55341 .91513 .55038 .911 .54478 Mtetra
.911 .54478 .91513 .55038 .92588 .54733 .92178 .54171 Mtetra
.92178 .54171 .92588 .54733 .93667 .54427 .9326 .53863 Mtetra
.9326 .53863 .93667 .54427 .9475 .5412 .94346 .53553 Mtetra
.656 .752 .921 r
.94346 .53553 .9475 .5412 .95837 .53812 .95436 .53242 Mtetra
.95436 .53242 .95837 .53812 .96929 .53502 .9653 .5293 Mtetra
.656 .752 .92 r
.9653 .5293 .96929 .53502 .98024 .53192 .97628 .52616 Mtetra
.655 .751 .921 r
.38561 .68781 .391 .69252 .39996 .68999 .39458 .68527 Mtetra
.39458 .68527 .39996 .68999 .40895 .68745 .40359 .68272 Mtetra
.655 .752 .921 r
.40359 .68272 .40895 .68745 .41797 .68489 .41263 .68016 Mtetra
.41263 .68016 .41797 .68489 .42702 .68233 .4217 .67759 Mtetra
.4217 .67759 .42702 .68233 .4361 .67976 .4308 .675 Mtetra
.655 .753 .921 r
.4308 .675 .4361 .67976 .44521 .67717 .43993 .67241 Mtetra
.655 .753 .922 r
.43993 .67241 .44521 .67717 .45435 .67458 .44909 .6698 Mtetra
.656 .753 .922 r
.44909 .6698 .45435 .67458 .46352 .67197 .45828 .66717 Mtetra
.656 .753 .921 r
.45828 .66717 .46352 .67197 .47273 .66935 .46751 .66454 Mtetra
.46751 .66454 .47273 .66935 .48196 .66672 .47676 .66189 Mtetra
.47676 .66189 .48196 .66672 .49123 .66408 .48605 .65923 Mtetra
.48605 .65923 .49123 .66408 .50053 .66144 .49537 .65656 Mtetra
.49537 .65656 .50053 .66144 .50985 .65878 .50472 .65388 Mtetra
.50472 .65388 .50985 .65878 .51922 .65611 .5141 .65119 Mtetra
.656 .752 .921 r
.5141 .65119 .51922 .65611 .52861 .65343 .52351 .6485 Mtetra
.52351 .6485 .52861 .65343 .53803 .65075 .53296 .64579 Mtetra
.53296 .64579 .53803 .65075 .54749 .64805 .54244 .64308 Mtetra
.656 .752 .92 r
.54244 .64308 .54749 .64805 .55698 .64535 .55195 .64036 Mtetra
.55195 .64036 .55698 .64535 .5665 .64264 .56149 .63763 Mtetra
.56149 .63763 .5665 .64264 .57606 .63993 .57107 .63489 Mtetra
.57107 .63489 .57606 .63993 .58565 .6372 .58068 .63214 Mtetra
.656 .751 .92 r
.58068 .63214 .58565 .6372 .59527 .63446 .59032 .62939 Mtetra
.59032 .62939 .59527 .63446 .60493 .63172 .6 .62663 Mtetra
.6 .62663 .60493 .63172 .61461 .62896 .60971 .62385 Mtetra
.60971 .62385 .61461 .62896 .62434 .6262 .61946 .62107 Mtetra
.61946 .62107 .62434 .6262 .63409 .62343 .62924 .61828 Mtetra
.62924 .61828 .63409 .62343 .64388 .62064 .63905 .61548 Mtetra
.63905 .61548 .64388 .62064 .65371 .61785 .6489 .61267 Mtetra
.6489 .61267 .65371 .61785 .66357 .61505 .65878 .60985 Mtetra
.65878 .60985 .66357 .61505 .67346 .61224 .6687 .60702 Mtetra
.6687 .60702 .67346 .61224 .68339 .60942 .67865 .60418 Mtetra
.67865 .60418 .68339 .60942 .69335 .60658 .68864 .60133 Mtetra
.68864 .60133 .69335 .60658 .70335 .60374 .69866 .59847 Mtetra
.69866 .59847 .70335 .60374 .71338 .60089 .70872 .5956 Mtetra
.70872 .5956 .71338 .60089 .72345 .59803 .71881 .59272 Mtetra
.71881 .59272 .72345 .59803 .73356 .59516 .72894 .58983 Mtetra
.72894 .58983 .73356 .59516 .7437 .59227 .73911 .58693 Mtetra
.73911 .58693 .7437 .59227 .75388 .58938 .74931 .58402 Mtetra
.74931 .58402 .75388 .58938 .76409 .58648 .75955 .5811 Mtetra
.75955 .5811 .76409 .58648 .77434 .58357 .76983 .57817 Mtetra
.76983 .57817 .77434 .58357 .78463 .58065 .78014 .57523 Mtetra
.655 .752 .921 r
.78014 .57523 .78463 .58065 .79495 .57772 .79049 .57228 Mtetra
.79049 .57228 .79495 .57772 .80531 .57478 .80088 .56933 Mtetra
.80088 .56933 .80531 .57478 .81571 .57183 .8113 .56636 Mtetra
.8113 .56636 .81571 .57183 .82614 .56887 .82176 .56339 Mtetra
.82176 .56339 .82614 .56887 .83662 .5659 .83227 .5604 Mtetra
.83227 .5604 .83662 .5659 .84713 .56292 .8428 .55741 Mtetra
.8428 .55741 .84713 .56292 .85768 .55993 .85338 .5544 Mtetra
.655 .753 .921 r
.85338 .5544 .85768 .55993 .86827 .55693 .864 .55138 Mtetra
.864 .55138 .86827 .55693 .87889 .55391 .87465 .54835 Mtetra
.656 .753 .922 r
.87465 .54835 .87889 .55391 .88956 .55088 .88535 .5453 Mtetra
.88535 .5453 .88956 .55088 .90026 .54784 .89608 .54223 Mtetra
.656 .753 .921 r
.89608 .54223 .90026 .54784 .911 .54478 .90685 .53915 Mtetra
.90685 .53915 .911 .54478 .92178 .54171 .91766 .53606 Mtetra
.91766 .53606 .92178 .54171 .9326 .53863 .92851 .53295 Mtetra
.92851 .53295 .9326 .53863 .94346 .53553 .9394 .52983 Mtetra
.9394 .52983 .94346 .53553 .95436 .53242 .95032 .52669 Mtetra
.657 .752 .921 r
.95032 .52669 .95436 .53242 .9653 .5293 .96129 .52353 Mtetra
.657 .752 .92 r
.96129 .52353 .9653 .5293 .97628 .52616 .9723 .52037 Mtetra
.654 .751 .921 r
.38018 .68308 .38561 .68781 .39458 .68527 .38918 .68053 Mtetra
.38918 .68053 .39458 .68527 .40359 .68272 .3982 .67797 Mtetra
.655 .752 .921 r
.3982 .67797 .40359 .68272 .41263 .68016 .40726 .6754 Mtetra
.655 .752 .922 r
.40726 .6754 .41263 .68016 .4217 .67759 .41635 .67282 Mtetra
.655 .753 .922 r
.41635 .67282 .4217 .67759 .4308 .675 .42546 .67023 Mtetra
.42546 .67023 .4308 .675 .43993 .67241 .43461 .66762 Mtetra
.43461 .66762 .43993 .67241 .44909 .6698 .44379 .665 Mtetra
.44379 .665 .44909 .6698 .45828 .66717 .45301 .66236 Mtetra
.656 .753 .922 r
.45301 .66236 .45828 .66717 .46751 .66454 .46225 .65971 Mtetra
.46225 .65971 .46751 .66454 .47676 .66189 .47153 .65704 Mtetra
.47153 .65704 .47676 .66189 .48605 .65923 .48083 .65436 Mtetra
.656 .753 .921 r
.48083 .65436 .48605 .65923 .49537 .65656 .49017 .65167 Mtetra
.49017 .65167 .49537 .65656 .50472 .65388 .49954 .64897 Mtetra
.49954 .64897 .50472 .65388 .5141 .65119 .50895 .64626 Mtetra
.50895 .64626 .5141 .65119 .52351 .6485 .51838 .64353 Mtetra
.656 .752 .921 r
.51838 .64353 .52351 .6485 .53296 .64579 .52785 .64081 Mtetra
.52785 .64081 .53296 .64579 .54244 .64308 .53735 .63807 Mtetra
.53735 .63807 .54244 .64308 .55195 .64036 .54688 .63533 Mtetra
.656 .752 .92 r
.54688 .63533 .55195 .64036 .56149 .63763 .55645 .63258 Mtetra
.55645 .63258 .56149 .63763 .57107 .63489 .56605 .62982 Mtetra
.56605 .62982 .57107 .63489 .58068 .63214 .57568 .62706 Mtetra
.57568 .62706 .58068 .63214 .59032 .62939 .58535 .62429 Mtetra
.656 .751 .92 r
.58535 .62429 .59032 .62939 .6 .62663 .59505 .6215 Mtetra
.59505 .6215 .6 .62663 .60971 .62385 .60478 .61871 Mtetra
.60478 .61871 .60971 .62385 .61946 .62107 .61455 .61591 Mtetra
.61455 .61591 .61946 .62107 .62924 .61828 .62435 .6131 Mtetra
.62435 .6131 .62924 .61828 .63905 .61548 .63419 .61028 Mtetra
.63419 .61028 .63905 .61548 .6489 .61267 .64406 .60746 Mtetra
.64406 .60746 .6489 .61267 .65878 .60985 .65396 .60462 Mtetra
.65396 .60462 .65878 .60985 .6687 .60702 .66391 .60177 Mtetra
.66391 .60177 .6687 .60702 .67865 .60418 .67388 .59891 Mtetra
.67388 .59891 .67865 .60418 .68864 .60133 .68389 .59604 Mtetra
.68389 .59604 .68864 .60133 .69866 .59847 .69394 .59316 Mtetra
.69394 .59316 .69866 .59847 .70872 .5956 .70402 .59027 Mtetra
.70402 .59027 .70872 .5956 .71881 .59272 .71414 .58737 Mtetra
.71414 .58737 .71881 .59272 .72894 .58983 .7243 .58446 Mtetra
.7243 .58446 .72894 .58983 .73911 .58693 .73449 .58155 Mtetra
.73449 .58155 .73911 .58693 .74931 .58402 .74472 .57862 Mtetra
.74472 .57862 .74931 .58402 .75955 .5811 .75498 .57568 Mtetra
.75498 .57568 .75955 .5811 .76983 .57817 .76528 .57273 Mtetra
.655 .752 .921 r
.76528 .57273 .76983 .57817 .78014 .57523 .77562 .56978 Mtetra
.77562 .56978 .78014 .57523 .79049 .57228 .786 .56682 Mtetra
.786 .56682 .79049 .57228 .80088 .56933 .79641 .56384 Mtetra
.79641 .56384 .80088 .56933 .8113 .56636 .80687 .56087 Mtetra
.80687 .56087 .8113 .56636 .82176 .56339 .81736 .55788 Mtetra
.81736 .55788 .82176 .56339 .83227 .5604 .82789 .55488 Mtetra
.655 .752 .922 r
.82789 .55488 .83227 .5604 .8428 .55741 .83845 .55187 Mtetra
.655 .753 .922 r
.83845 .55187 .8428 .55741 .85338 .5544 .84906 .54885 Mtetra
.84906 .54885 .85338 .5544 .864 .55138 .8597 .54581 Mtetra
.8597 .54581 .864 .55138 .87465 .54835 .87039 .54276 Mtetra
.87039 .54276 .87465 .54835 .88535 .5453 .88111 .53969 Mtetra
.656 .753 .922 r
.88111 .53969 .88535 .5453 .89608 .54223 .89187 .5366 Mtetra
.89187 .5366 .89608 .54223 .90685 .53915 .90267 .5335 Mtetra
.90267 .5335 .90685 .53915 .91766 .53606 .91351 .53038 Mtetra
.656 .753 .921 r
.91351 .53038 .91766 .53606 .92851 .53295 .92438 .52724 Mtetra
.657 .753 .921 r
.92438 .52724 .92851 .53295 .9394 .52983 .9353 .52409 Mtetra
.9353 .52409 .9394 .52983 .95032 .52669 .94626 .52092 Mtetra
.94626 .52092 .95032 .52669 .96129 .52353 .95726 .51773 Mtetra
.657 .752 .92 r
.95726 .51773 .96129 .52353 .9723 .52037 .96829 .51454 Mtetra
.654 .751 .921 r
.37472 .67831 .38018 .68308 .38918 .68053 .38373 .67576 Mtetra
.38373 .67576 .38918 .68053 .3982 .67797 .39278 .67319 Mtetra
.654 .752 .922 r
.39278 .67319 .3982 .67797 .40726 .6754 .40185 .67062 Mtetra
.40185 .67062 .40726 .6754 .41635 .67282 .41096 .66803 Mtetra
.654 .753 .922 r
.41096 .66803 .41635 .67282 .42546 .67023 .4201 .66543 Mtetra
.655 .753 .922 r
.4201 .66543 .42546 .67023 .43461 .66762 .42927 .66281 Mtetra
.655 .754 .922 r
.42927 .66281 .43461 .66762 .44379 .665 .43847 .66018 Mtetra
.43847 .66018 .44379 .665 .45301 .66236 .4477 .65753 Mtetra
.656 .754 .922 r
.4477 .65753 .45301 .66236 .46225 .65971 .45696 .65486 Mtetra
.45696 .65486 .46225 .65971 .47153 .65704 .46626 .65218 Mtetra
.46626 .65218 .47153 .65704 .48083 .65436 .47559 .64948 Mtetra
.47559 .64948 .48083 .65436 .49017 .65167 .48495 .64676 Mtetra
.657 .754 .922 r
.48495 .64676 .49017 .65167 .49954 .64897 .49434 .64403 Mtetra
.657 .754 .921 r
.49434 .64403 .49954 .64897 .50895 .64626 .50376 .6413 Mtetra
.657 .753 .921 r
.50376 .6413 .50895 .64626 .51838 .64353 .51322 .63855 Mtetra
.51322 .63855 .51838 .64353 .52785 .64081 .52271 .6358 Mtetra
.656 .753 .921 r
.52271 .6358 .52785 .64081 .53735 .63807 .53223 .63304 Mtetra
.656 .752 .921 r
.53223 .63304 .53735 .63807 .54688 .63533 .54178 .63027 Mtetra
.656 .752 .92 r
.54178 .63027 .54688 .63533 .55645 .63258 .55137 .6275 Mtetra
.55137 .6275 .55645 .63258 .56605 .62982 .56099 .62473 Mtetra
.56099 .62473 .56605 .62982 .57568 .62706 .57065 .62194 Mtetra
.57065 .62194 .57568 .62706 .58535 .62429 .58034 .61915 Mtetra
.58034 .61915 .58535 .62429 .59505 .6215 .59006 .61635 Mtetra
.656 .751 .92 r
.59006 .61635 .59505 .6215 .60478 .61871 .59982 .61354 Mtetra
.59982 .61354 .60478 .61871 .61455 .61591 .60961 .61072 Mtetra
.60961 .61072 .61455 .61591 .62435 .6131 .61943 .60789 Mtetra
.61943 .60789 .62435 .6131 .63419 .61028 .62929 .60505 Mtetra
.62929 .60505 .63419 .61028 .64406 .60746 .63919 .60221 Mtetra
.63919 .60221 .64406 .60746 .65396 .60462 .64912 .59935 Mtetra
.64912 .59935 .65396 .60462 .66391 .60177 .65908 .59648 Mtetra
.65908 .59648 .66391 .60177 .67388 .59891 .66908 .5936 Mtetra
.66908 .5936 .67388 .59891 .68389 .59604 .67912 .59072 Mtetra
.67912 .59072 .68389 .59604 .69394 .59316 .68919 .58782 Mtetra
.68919 .58782 .69394 .59316 .70402 .59027 .6993 .58491 Mtetra
.6993 .58491 .70402 .59027 .71414 .58737 .70944 .58199 Mtetra
.70944 .58199 .71414 .58737 .7243 .58446 .71962 .57907 Mtetra
.71962 .57907 .7243 .58446 .73449 .58155 .72984 .57613 Mtetra
.72984 .57613 .73449 .58155 .74472 .57862 .74009 .57318 Mtetra
.74009 .57318 .74472 .57862 .75498 .57568 .75038 .57023 Mtetra
.655 .752 .921 r
.75038 .57023 .75498 .57568 .76528 .57273 .76071 .56726 Mtetra
.76071 .56726 .76528 .57273 .77562 .56978 .77108 .56429 Mtetra
.77108 .56429 .77562 .56978 .786 .56682 .78148 .56132 Mtetra
.78148 .56132 .786 .56682 .79641 .56384 .79192 .55833 Mtetra
.79192 .55833 .79641 .56384 .80687 .56087 .8024 .55534 Mtetra
.655 .752 .922 r
.8024 .55534 .80687 .56087 .81736 .55788 .81292 .55234 Mtetra
.655 .753 .922 r
.81292 .55234 .81736 .55788 .82789 .55488 .82348 .54933 Mtetra
.82348 .54933 .82789 .55488 .83845 .55187 .83407 .54631 Mtetra
.83407 .54631 .83845 .55187 .84906 .54885 .84471 .54327 Mtetra
.655 .754 .922 r
.84471 .54327 .84906 .54885 .8597 .54581 .85538 .54022 Mtetra
.85538 .54022 .8597 .54581 .87039 .54276 .86609 .53715 Mtetra
.86609 .53715 .87039 .54276 .88111 .53969 .87684 .53406 Mtetra
.656 .754 .922 r
.87684 .53406 .88111 .53969 .89187 .5366 .88763 .53095 Mtetra
.88763 .53095 .89187 .5366 .90267 .5335 .89846 .52782 Mtetra
.89846 .52782 .90267 .5335 .91351 .53038 .90933 .52467 Mtetra
.657 .754 .922 r
.90933 .52467 .91351 .53038 .92438 .52724 .92023 .5215 Mtetra
.657 .754 .921 r
.92023 .5215 .92438 .52724 .9353 .52409 .93118 .51831 Mtetra
.657 .753 .921 r
.93118 .51831 .9353 .52409 .94626 .52092 .94217 .51511 Mtetra
.94217 .51511 .94626 .52092 .95726 .51773 .95319 .51189 Mtetra
.657 .753 .92 r
.95319 .51189 .95726 .51773 .96829 .51454 .96426 .50866 Mtetra
.653 .751 .921 r
.36922 .67351 .37472 .67831 .38373 .67576 .37825 .67096 Mtetra
.653 .751 .922 r
.37825 .67096 .38373 .67576 .39278 .67319 .38732 .66839 Mtetra
.653 .752 .922 r
.38732 .66839 .39278 .67319 .40185 .67062 .39641 .66581 Mtetra
.654 .752 .922 r
.39641 .66581 .40185 .67062 .41096 .66803 .40554 .66322 Mtetra
.654 .753 .923 r
.40554 .66322 .41096 .66803 .4201 .66543 .41469 .66061 Mtetra
.41469 .66061 .4201 .66543 .42927 .66281 .42388 .65799 Mtetra
.655 .754 .923 r
.42388 .65799 .42927 .66281 .43847 .66018 .4331 .65535 Mtetra
.4331 .65535 .43847 .66018 .4477 .65753 .44236 .65269 Mtetra
.655 .755 .923 r
.44236 .65269 .4477 .65753 .45696 .65486 .45164 .65 Mtetra
.656 .755 .923 r
.45164 .65 .45696 .65486 .46626 .65218 .46096 .6473 Mtetra
.46096 .6473 .46626 .65218 .47559 .64948 .47031 .64458 Mtetra
.657 .755 .922 r
.47031 .64458 .47559 .64948 .48495 .64676 .47969 .64184 Mtetra
.47969 .64184 .48495 .64676 .49434 .64403 .4891 .63909 Mtetra
.657 .754 .922 r
.4891 .63909 .49434 .64403 .50376 .6413 .49854 .63632 Mtetra
.657 .754 .921 r
.49854 .63632 .50376 .6413 .51322 .63855 .50802 .63355 Mtetra
.50802 .63355 .51322 .63855 .52271 .6358 .51753 .63077 Mtetra
.657 .753 .921 r
.51753 .63077 .52271 .6358 .53223 .63304 .52708 .62798 Mtetra
.52708 .62798 .53223 .63304 .54178 .63027 .53665 .62519 Mtetra
.656 .752 .921 r
.53665 .62519 .54178 .63027 .55137 .6275 .54626 .6224 Mtetra
.656 .752 .92 r
.54626 .6224 .55137 .6275 .56099 .62473 .55591 .6196 Mtetra
.55591 .6196 .56099 .62473 .57065 .62194 .56558 .61679 Mtetra
.56558 .61679 .57065 .62194 .58034 .61915 .57529 .61398 Mtetra
.57529 .61398 .58034 .61915 .59006 .61635 .58504 .61116 Mtetra
.58504 .61116 .59006 .61635 .59982 .61354 .59482 .60833 Mtetra
.656 .751 .92 r
.59482 .60833 .59982 .61354 .60961 .61072 .60463 .60549 Mtetra
.60463 .60549 .60961 .61072 .61943 .60789 .61448 .60265 Mtetra
.61448 .60265 .61943 .60789 .62929 .60505 .62437 .59979 Mtetra
.62437 .59979 .62929 .60505 .63919 .60221 .63428 .59692 Mtetra
.63428 .59692 .63919 .60221 .64912 .59935 .64424 .59405 Mtetra
.64424 .59405 .64912 .59935 .65908 .59648 .65423 .59116 Mtetra
.65423 .59116 .65908 .59648 .66908 .5936 .66425 .58827 Mtetra
.66425 .58827 .66908 .5936 .67912 .59072 .67431 .58536 Mtetra
.67431 .58536 .67912 .59072 .68919 .58782 .68441 .58244 Mtetra
.68441 .58244 .68919 .58782 .6993 .58491 .69454 .57952 Mtetra
.69454 .57952 .6993 .58491 .70944 .58199 .70471 .57658 Mtetra
.70471 .57658 .70944 .58199 .71962 .57907 .71491 .57363 Mtetra
.71491 .57363 .71962 .57907 .72984 .57613 .72516 .57068 Mtetra
.655 .751 .92 r
.72516 .57068 .72984 .57613 .74009 .57318 .73544 .56771 Mtetra
.655 .752 .921 r
.73544 .56771 .74009 .57318 .75038 .57023 .74575 .56474 Mtetra
.74575 .56474 .75038 .57023 .76071 .56726 .75611 .56176 Mtetra
.75611 .56176 .76071 .56726 .77108 .56429 .7665 .55878 Mtetra
.7665 .55878 .77108 .56429 .78148 .56132 .77693 .55579 Mtetra
.655 .752 .922 r
.77693 .55579 .78148 .56132 .79192 .55833 .7874 .5528 Mtetra
.654 .752 .922 r
.7874 .5528 .79192 .55833 .8024 .55534 .79791 .54979 Mtetra
.654 .753 .922 r
.79791 .54979 .8024 .55534 .81292 .55234 .80846 .54678 Mtetra
.654 .753 .923 r
.80846 .54678 .81292 .55234 .82348 .54933 .81904 .54376 Mtetra
.654 .754 .923 r
.81904 .54376 .82348 .54933 .83407 .54631 .82967 .54073 Mtetra
.82967 .54073 .83407 .54631 .84471 .54327 .84033 .53768 Mtetra
.655 .754 .923 r
.84033 .53768 .84471 .54327 .85538 .54022 .85103 .53461 Mtetra
.655 .755 .923 r
.85103 .53461 .85538 .54022 .86609 .53715 .86177 .53152 Mtetra
.86177 .53152 .86609 .53715 .87684 .53406 .87255 .5284 Mtetra
.656 .755 .923 r
.87255 .5284 .87684 .53406 .88763 .53095 .88337 .52527 Mtetra
.656 .755 .922 r
.88337 .52527 .88763 .53095 .89846 .52782 .89423 .52211 Mtetra
.657 .755 .922 r
.89423 .52211 .89846 .52782 .90933 .52467 .90512 .51893 Mtetra
.657 .754 .922 r
.90512 .51893 .90933 .52467 .92023 .5215 .91606 .51573 Mtetra
.657 .754 .921 r
.91606 .51573 .92023 .5215 .93118 .51831 .92703 .51251 Mtetra
.658 .754 .921 r
.92703 .51251 .93118 .51831 .94217 .51511 .93804 .50927 Mtetra
.658 .753 .92 r
.93804 .50927 .94217 .51511 .95319 .51189 .9491 .50602 Mtetra
.9491 .50602 .95319 .51189 .96426 .50866 .9602 .50275 Mtetra
.653 .751 .922 r
.36369 .66869 .36922 .67351 .37825 .67096 .37274 .66613 Mtetra
.37274 .66613 .37825 .67096 .38732 .66839 .38182 .66356 Mtetra
.653 .752 .922 r
.38182 .66356 .38732 .66839 .39641 .66581 .39094 .66098 Mtetra
.653 .753 .923 r
.39094 .66098 .39641 .66581 .40554 .66322 .40008 .65839 Mtetra
.40008 .65839 .40554 .66322 .41469 .66061 .40926 .65578 Mtetra
.654 .754 .923 r
.40926 .65578 .41469 .66061 .42388 .65799 .41847 .65315 Mtetra
.654 .754 .924 r
.41847 .65315 .42388 .65799 .4331 .65535 .42771 .65051 Mtetra
.655 .755 .924 r
.42771 .65051 .4331 .65535 .44236 .65269 .43698 .64784 Mtetra
.655 .756 .924 r
.43698 .64784 .44236 .65269 .45164 .65 .44628 .64514 Mtetra
.656 .756 .924 r
.44628 .64514 .45164 .65 .46096 .6473 .45562 .64242 Mtetra
.656 .756 .923 r
.45562 .64242 .46096 .6473 .47031 .64458 .46499 .63968 Mtetra
.657 .756 .923 r
.46499 .63968 .47031 .64458 .47969 .64184 .47439 .63692 Mtetra
.47439 .63692 .47969 .64184 .4891 .63909 .48383 .63414 Mtetra
.658 .756 .922 r
.48383 .63414 .4891 .63909 .49854 .63632 .49329 .63134 Mtetra
.658 .755 .922 r
.49329 .63134 .49854 .63632 .50802 .63355 .50279 .62854 Mtetra
.50279 .62854 .50802 .63355 .51753 .63077 .51233 .62573 Mtetra
.657 .754 .921 r
.51233 .62573 .51753 .63077 .52708 .62798 .52189 .62291 Mtetra
.657 .753 .921 r
.52189 .62291 .52708 .62798 .53665 .62519 .53149 .62009 Mtetra
.53149 .62009 .53665 .62519 .54626 .6224 .54112 .61727 Mtetra
.657 .752 .921 r
.54112 .61727 .54626 .6224 .55591 .6196 .55079 .61444 Mtetra
.656 .752 .92 r
.55079 .61444 .55591 .6196 .56558 .61679 .56049 .61161 Mtetra
.56049 .61161 .56558 .61679 .57529 .61398 .57022 .60878 Mtetra
.57022 .60878 .57529 .61398 .58504 .61116 .57999 .60594 Mtetra
.57999 .60594 .58504 .61116 .59482 .60833 .58979 .60309 Mtetra
.58979 .60309 .59482 .60833 .60463 .60549 .59963 .60023 Mtetra
.656 .751 .92 r
.59963 .60023 .60463 .60549 .61448 .60265 .6095 .59737 Mtetra
.6095 .59737 .61448 .60265 .62437 .59979 .61941 .59449 Mtetra
.61941 .59449 .62437 .59979 .63428 .59692 .62935 .59161 Mtetra
.62935 .59161 .63428 .59692 .64424 .59405 .63933 .58871 Mtetra
.63933 .58871 .64424 .59405 .65423 .59116 .64934 .58581 Mtetra
.64934 .58581 .65423 .59116 .66425 .58827 .65939 .58289 Mtetra
.65939 .58289 .66425 .58827 .67431 .58536 .66947 .57997 Mtetra
.66947 .57997 .67431 .58536 .68441 .58244 .67959 .57703 Mtetra
.67959 .57703 .68441 .58244 .69454 .57952 .68975 .57408 Mtetra
.68975 .57408 .69454 .57952 .70471 .57658 .69995 .57113 Mtetra
.69995 .57113 .70471 .57658 .71491 .57363 .71018 .56816 Mtetra
.71018 .56816 .71491 .57363 .72516 .57068 .72044 .56519 Mtetra
.655 .751 .921 r
.72044 .56519 .72516 .57068 .73544 .56771 .73075 .56221 Mtetra
.655 .752 .921 r
.73075 .56221 .73544 .56771 .74575 .56474 .74109 .55923 Mtetra
.74109 .55923 .74575 .56474 .75611 .56176 .75147 .55623 Mtetra
.75147 .55623 .75611 .56176 .7665 .55878 .76189 .55324 Mtetra
.654 .752 .922 r
.76189 .55324 .7665 .55878 .77693 .55579 .77235 .55024 Mtetra
.77235 .55024 .77693 .55579 .7874 .5528 .78285 .54724 Mtetra
.654 .753 .922 r
.78285 .54724 .7874 .5528 .79791 .54979 .79339 .54423 Mtetra
.654 .753 .923 r
.79339 .54423 .79791 .54979 .80846 .54678 .80396 .54122 Mtetra
.653 .754 .923 r
.80396 .54122 .80846 .54678 .81904 .54376 .81458 .53819 Mtetra
.654 .754 .924 r
.81458 .53819 .81904 .54376 .82967 .54073 .82523 .53514 Mtetra
.654 .755 .924 r
.82523 .53514 .82967 .54073 .84033 .53768 .83592 .53208 Mtetra
.83592 .53208 .84033 .53768 .85103 .53461 .84665 .52899 Mtetra
.655 .756 .924 r
.84665 .52899 .85103 .53461 .86177 .53152 .85742 .52588 Mtetra
.656 .756 .924 r
.85742 .52588 .86177 .53152 .87255 .5284 .86823 .52274 Mtetra
.656 .756 .923 r
.86823 .52274 .87255 .5284 .88337 .52527 .87908 .51957 Mtetra
.657 .756 .923 r
.87908 .51957 .88337 .52527 .89423 .52211 .88996 .51638 Mtetra
.657 .756 .922 r
.88996 .51638 .89423 .52211 .90512 .51893 .90089 .51316 Mtetra
.658 .755 .922 r
.90089 .51316 .90512 .51893 .91606 .51573 .91185 .50992 Mtetra
.658 .755 .921 r
.91185 .50992 .91606 .51573 .92703 .51251 .92285 .50666 Mtetra
.658 .754 .921 r
.92285 .50666 .92703 .51251 .93804 .50927 .9339 .50339 Mtetra
.658 .754 .92 r
.9339 .50339 .93804 .50927 .9491 .50602 .94498 .5001 Mtetra
.658 .753 .92 r
.94498 .5001 .9491 .50602 .9602 .50275 .9561 .4968 Mtetra
.652 .75 .922 r
.35813 .66383 .36369 .66869 .37274 .66613 .3672 .66127 Mtetra
.652 .751 .922 r
.3672 .66127 .37274 .66613 .38182 .66356 .3763 .6587 Mtetra
.652 .752 .923 r
.3763 .6587 .38182 .66356 .39094 .66098 .38543 .65612 Mtetra
.38543 .65612 .39094 .66098 .40008 .65839 .39459 .65353 Mtetra
.652 .753 .924 r
.39459 .65353 .40008 .65839 .40926 .65578 .40379 .65092 Mtetra
.653 .754 .924 r
.40379 .65092 .40926 .65578 .41847 .65315 .41301 .6483 Mtetra
.653 .755 .924 r
.41301 .6483 .41847 .65315 .42771 .65051 .42227 .64565 Mtetra
.654 .756 .924 r
.42227 .64565 .42771 .65051 .43698 .64784 .43157 .64297 Mtetra
.655 .756 .925 r
.43157 .64297 .43698 .64784 .44628 .64514 .44089 .64027 Mtetra
.655 .757 .924 r
.44089 .64027 .44628 .64514 .45562 .64242 .45025 .63754 Mtetra
.656 .757 .924 r
.45025 .63754 .45562 .64242 .46499 .63968 .45964 .63479 Mtetra
.657 .758 .924 r
.45964 .63479 .46499 .63968 .47439 .63692 .46906 .632 Mtetra
.658 .758 .924 r
.46906 .632 .47439 .63692 .48383 .63414 .47852 .62919 Mtetra
.658 .757 .923 r
.47852 .62919 .48383 .63414 .49329 .63134 .48801 .62636 Mtetra
.48801 .62636 .49329 .63134 .50279 .62854 .49753 .62352 Mtetra
.658 .756 .922 r
.49753 .62352 .50279 .62854 .51233 .62573 .50708 .62067 Mtetra
.658 .755 .922 r
.50708 .62067 .51233 .62573 .52189 .62291 .51667 .61782 Mtetra
.658 .754 .921 r
.51667 .61782 .52189 .62291 .53149 .62009 .52629 .61497 Mtetra
.657 .754 .921 r
.52629 .61497 .53149 .62009 .54112 .61727 .53595 .61212 Mtetra
.657 .753 .921 r
.53595 .61212 .54112 .61727 .55079 .61444 .54563 .60926 Mtetra
.54563 .60926 .55079 .61444 .56049 .61161 .55536 .60641 Mtetra
.656 .752 .92 r
.55536 .60641 .56049 .61161 .57022 .60878 .56511 .60355 Mtetra
.56511 .60355 .57022 .60878 .57999 .60594 .5749 .60069 Mtetra
.5749 .60069 .57999 .60594 .58979 .60309 .58473 .59782 Mtetra
.58473 .59782 .58979 .60309 .59963 .60023 .59459 .59494 Mtetra
.59459 .59494 .59963 .60023 .6095 .59737 .60448 .59205 Mtetra
.656 .751 .92 r
.60448 .59205 .6095 .59737 .61941 .59449 .61441 .58916 Mtetra
.61441 .58916 .61941 .59449 .62935 .59161 .62438 .58626 Mtetra
.62438 .58626 .62935 .59161 .63933 .58871 .63438 .58334 Mtetra
.63438 .58334 .63933 .58871 .64934 .58581 .64442 .58042 Mtetra
.64442 .58042 .64934 .58581 .65939 .58289 .65449 .57748 Mtetra
.65449 .57748 .65939 .58289 .66947 .57997 .6646 .57454 Mtetra
.6646 .57454 .66947 .57997 .67959 .57703 .67475 .57158 Mtetra
.67475 .57158 .67959 .57703 .68975 .57408 .68493 .56862 Mtetra
.68493 .56862 .68975 .57408 .69995 .57113 .69515 .56564 Mtetra
.69515 .56564 .69995 .57113 .71018 .56816 .70541 .56266 Mtetra
.655 .751 .921 r
.70541 .56266 .71018 .56816 .72044 .56519 .7157 .55967 Mtetra
.655 .752 .921 r
.7157 .55967 .72044 .56519 .73075 .56221 .72603 .55668 Mtetra
.72603 .55668 .73075 .56221 .74109 .55923 .7364 .55368 Mtetra
.654 .752 .921 r
.7364 .55368 .74109 .55923 .75147 .55623 .74681 .55068 Mtetra
.654 .752 .922 r
.74681 .55068 .75147 .55623 .76189 .55324 .75726 .54768 Mtetra
.75726 .54768 .76189 .55324 .77235 .55024 .76774 .54467 Mtetra
.653 .753 .923 r
.76774 .54467 .77235 .55024 .78285 .54724 .77827 .54167 Mtetra
.77827 .54167 .78285 .54724 .79339 .54423 .78884 .53866 Mtetra
.653 .754 .924 r
.78884 .53866 .79339 .54423 .80396 .54122 .79944 .53564 Mtetra
.653 .755 .925 r
.79944 .53564 .80396 .54122 .81458 .53819 .81009 .53261 Mtetra
.653 .756 .925 r
.81009 .53261 .81458 .53819 .82523 .53514 .82077 .52956 Mtetra
.654 .756 .925 r
.82077 .52956 .82523 .53514 .83592 .53208 .83149 .52648 Mtetra
.654 .757 .925 r
.83149 .52648 .83592 .53208 .84665 .52899 .84225 .52337 Mtetra
.655 .757 .925 r
.84225 .52337 .84665 .52899 .85742 .52588 .85305 .52023 Mtetra
.656 .757 .924 r
.85305 .52023 .85742 .52588 .86823 .52274 .86388 .51705 Mtetra
.657 .757 .924 r
.86388 .51705 .86823 .52274 .87908 .51957 .87476 .51385 Mtetra
.657 .757 .923 r
.87476 .51385 .87908 .51957 .88996 .51638 .88567 .51062 Mtetra
.658 .756 .923 r
.88567 .51062 .88996 .51638 .90089 .51316 .89662 .50736 Mtetra
.658 .756 .922 r
.89662 .50736 .90089 .51316 .91185 .50992 .90761 .50408 Mtetra
.659 .755 .921 r
.90761 .50408 .91185 .50992 .92285 .50666 .91865 .50079 Mtetra
.91865 .50079 .92285 .50666 .9339 .50339 .92972 .49747 Mtetra
.659 .754 .92 r
.92972 .49747 .9339 .50339 .94498 .5001 .94083 .49414 Mtetra
.659 .753 .92 r
.94083 .49414 .94498 .5001 .9561 .4968 .95198 .4908 Mtetra
.651 .75 .922 r
.35253 .65894 .35813 .66383 .3672 .66127 .36162 .65638 Mtetra
.651 .751 .923 r
.36162 .65638 .3672 .66127 .3763 .6587 .37073 .65381 Mtetra
.37073 .65381 .3763 .6587 .38543 .65612 .37988 .65124 Mtetra
.651 .752 .923 r
.37988 .65124 .38543 .65612 .39459 .65353 .38907 .64864 Mtetra
.651 .753 .924 r
.38907 .64864 .39459 .65353 .40379 .65092 .39828 .64604 Mtetra
.652 .754 .924 r
.39828 .64604 .40379 .65092 .41301 .6483 .40753 .64342 Mtetra
.652 .755 .925 r
.40753 .64342 .41301 .6483 .42227 .64565 .41681 .64077 Mtetra
.653 .756 .925 r
.41681 .64077 .42227 .64565 .43157 .64297 .42612 .63811 Mtetra
.654 .757 .925 r
.42612 .63811 .43157 .64297 .44089 .64027 .43546 .6354 Mtetra
.655 .758 .926 r
.43546 .6354 .44089 .64027 .45025 .63754 .44484 .63267 Mtetra
.656 .759 .925 r
.44484 .63267 .45025 .63754 .45964 .63479 .45425 .6299 Mtetra
.657 .759 .925 r
.45425 .6299 .45964 .63479 .46906 .632 .4637 .62709 Mtetra
.658 .759 .925 r
.4637 .62709 .46906 .632 .47852 .62919 .47318 .62425 Mtetra
.659 .759 .924 r
.47318 .62425 .47852 .62919 .48801 .62636 .48269 .62139 Mtetra
.659 .759 .923 r
.48269 .62139 .48801 .62636 .49753 .62352 .49223 .61851 Mtetra
.659 .758 .923 r
.49223 .61851 .49753 .62352 .50708 .62067 .50181 .61562 Mtetra
.659 .757 .922 r
.50181 .61562 .50708 .62067 .51667 .61782 .51142 .61273 Mtetra
.659 .756 .922 r
.51142 .61273 .51667 .61782 .52629 .61497 .52106 .60983 Mtetra
.658 .755 .921 r
.52106 .60983 .52629 .61497 .53595 .61212 .53074 .60694 Mtetra
.658 .754 .921 r
.53074 .60694 .53595 .61212 .54563 .60926 .54045 .60406 Mtetra
.657 .753 .921 r
.54045 .60406 .54563 .60926 .55536 .60641 .55019 .60117 Mtetra
.55019 .60117 .55536 .60641 .56511 .60355 .55997 .59829 Mtetra
.656 .752 .92 r
.55997 .59829 .56511 .60355 .5749 .60069 .56978 .5954 Mtetra
.56978 .5954 .5749 .60069 .58473 .59782 .57963 .59251 Mtetra
.57963 .59251 .58473 .59782 .59459 .59494 .58952 .58961 Mtetra
.58952 .58961 .59459 .59494 .60448 .59205 .59944 .58671 Mtetra
.59944 .58671 .60448 .59205 .61441 .58916 .60939 .58379 Mtetra
.656 .751 .92 r
.60939 .58379 .61441 .58916 .62438 .58626 .61938 .58087 Mtetra
.61938 .58087 .62438 .58626 .63438 .58334 .62941 .57793 Mtetra
.62941 .57793 .63438 .58334 .64442 .58042 .63947 .57499 Mtetra
.63947 .57499 .64442 .58042 .65449 .57748 .64957 .57204 Mtetra
.64957 .57204 .65449 .57748 .6646 .57454 .6597 .56907 Mtetra
.6597 .56907 .6646 .57454 .67475 .57158 .66987 .5661 Mtetra
.66987 .5661 .67475 .57158 .68493 .56862 .68008 .56312 Mtetra
.68008 .56312 .68493 .56862 .69515 .56564 .69032 .56012 Mtetra
.655 .751 .921 r
.69032 .56012 .69515 .56564 .70541 .56266 .70061 .55713 Mtetra
.655 .752 .921 r
.70061 .55713 .70541 .56266 .7157 .55967 .71093 .55412 Mtetra
.71093 .55412 .7157 .55967 .72603 .55668 .72128 .55112 Mtetra
.654 .752 .921 r
.72128 .55112 .72603 .55668 .7364 .55368 .73168 .54811 Mtetra
.654 .752 .922 r
.73168 .54811 .7364 .55368 .74681 .55068 .74212 .5451 Mtetra
.653 .752 .922 r
.74212 .5451 .74681 .55068 .75726 .54768 .75259 .5421 Mtetra
.653 .753 .923 r
.75259 .5421 .75726 .54768 .76774 .54467 .76311 .5391 Mtetra
.652 .753 .924 r
.76311 .5391 .76774 .54467 .77827 .54167 .77366 .53609 Mtetra
.652 .754 .925 r
.77366 .53609 .77827 .54167 .78884 .53866 .78426 .53309 Mtetra
.652 .755 .925 r
.78426 .53309 .78884 .53866 .79944 .53564 .79489 .53007 Mtetra
.652 .756 .926 r
.79489 .53007 .79944 .53564 .81009 .53261 .80557 .52704 Mtetra
.652 .757 .926 r
.80557 .52704 .81009 .53261 .82077 .52956 .81628 .52397 Mtetra
.653 .758 .926 r
.81628 .52397 .82077 .52956 .83149 .52648 .82703 .52088 Mtetra
.654 .758 .926 r
.82703 .52088 .83149 .52648 .84225 .52337 .83782 .51774 Mtetra
.655 .759 .926 r
.83782 .51774 .84225 .52337 .85305 .52023 .84864 .51457 Mtetra
.656 .759 .925 r
.84864 .51457 .85305 .52023 .86388 .51705 .85951 .51135 Mtetra
.657 .758 .924 r
.85951 .51135 .86388 .51705 .87476 .51385 .87041 .50811 Mtetra
.658 .758 .923 r
.87041 .50811 .87476 .51385 .88567 .51062 .88135 .50483 Mtetra
.659 .757 .923 r
.88135 .50483 .88567 .51062 .89662 .50736 .89233 .50153 Mtetra
.659 .756 .922 r
.89233 .50153 .89662 .50736 .90761 .50408 .90335 .49821 Mtetra
.659 .756 .921 r
.90335 .49821 .90761 .50408 .91865 .50079 .91441 .49487 Mtetra
.659 .755 .921 r
.91441 .49487 .91865 .50079 .92972 .49747 .92551 .49151 Mtetra
.66 .754 .92 r
.92551 .49151 .92972 .49747 .94083 .49414 .93665 .48814 Mtetra
.93665 .48814 .94083 .49414 .95198 .4908 .94784 .48476 Mtetra
.651 .75 .922 r
.34689 .65403 .35253 .65894 .36162 .65638 .356 .65146 Mtetra
.651 .751 .923 r
.356 .65146 .36162 .65638 .37073 .65381 .36514 .64889 Mtetra
.36514 .64889 .37073 .65381 .37988 .65124 .3743 .6463 Mtetra
.651 .752 .924 r
.3743 .6463 .37988 .65124 .38907 .64864 .3835 .64371 Mtetra
.65 .752 .924 r
.3835 .64371 .38907 .64864 .39828 .64604 .39274 .64112 Mtetra
.651 .753 .925 r
.39274 .64112 .39828 .64604 .40753 .64342 .402 .6385 Mtetra
.651 .754 .925 r
.402 .6385 .40753 .64342 .41681 .64077 .4113 .63587 Mtetra
.652 .756 .926 r
.4113 .63587 .41681 .64077 .42612 .63811 .42063 .63321 Mtetra
.652 .757 .926 r
.42063 .63321 .42612 .63811 .43546 .6354 .43 .63052 Mtetra
.654 .758 .927 r
.43 .63052 .43546 .6354 .44484 .63267 .4394 .62779 Mtetra
.655 .76 .927 r
.4394 .62779 .44484 .63267 .45425 .6299 .44883 .62502 Mtetra
.657 .761 .926 r
.44883 .62502 .45425 .6299 .4637 .62709 .4583 .6222 Mtetra
.658 .761 .926 r
.4583 .6222 .4637 .62709 .47318 .62425 .4678 .61934 Mtetra
.659 .761 .925 r
.4678 .61934 .47318 .62425 .48269 .62139 .47733 .61644 Mtetra
.66 .761 .925 r
.47733 .61644 .48269 .62139 .49223 .61851 .4869 .61352 Mtetra
.66 .76 .924 r
.4869 .61352 .49223 .61851 .50181 .61562 .4965 .61058 Mtetra
.66 .759 .923 r
.4965 .61058 .50181 .61562 .51142 .61273 .50613 .60764 Mtetra
.66 .758 .922 r
.50613 .60764 .51142 .61273 .52106 .60983 .51579 .6047 Mtetra
.659 .756 .922 r
.51579 .6047 .52106 .60983 .53074 .60694 .52549 .60176 Mtetra
.658 .755 .921 r
.52549 .60176 .53074 .60694 .54045 .60406 .53523 .59884 Mtetra
.658 .754 .921 r
.53523 .59884 .54045 .60406 .55019 .60117 .54499 .59592 Mtetra
.657 .753 .921 r
.54499 .59592 .55019 .60117 .55997 .59829 .5548 .593 Mtetra
.5548 .593 .55997 .59829 .56978 .5954 .56463 .59009 Mtetra
.656 .752 .92 r
.56463 .59009 .56978 .5954 .57963 .59251 .5745 .58718 Mtetra
.5745 .58718 .57963 .59251 .58952 .58961 .58441 .58425 Mtetra
.58441 .58425 .58952 .58961 .59944 .58671 .59435 .58133 Mtetra
.59435 .58133 .59944 .58671 .60939 .58379 .60433 .57839 Mtetra
.60433 .57839 .60939 .58379 .61938 .58087 .61435 .57545 Mtetra
.61435 .57545 .61938 .58087 .62941 .57793 .6244 .57249 Mtetra
.656 .751 .92 r
.6244 .57249 .62941 .57793 .63947 .57499 .63448 .56953 Mtetra
.63448 .56953 .63947 .57499 .64957 .57204 .6446 .56656 Mtetra
.6446 .56656 .64957 .57204 .6597 .56907 .65476 .56357 Mtetra
.65476 .56357 .6597 .56907 .66987 .5661 .66496 .56058 Mtetra
.66496 .56058 .66987 .5661 .68008 .56312 .67519 .55758 Mtetra
.655 .752 .921 r
.67519 .55758 .68008 .56312 .69032 .56012 .68546 .55457 Mtetra
.68546 .55457 .69032 .56012 .70061 .55713 .69577 .55156 Mtetra
.69577 .55156 .70061 .55713 .71093 .55412 .70612 .54854 Mtetra
.654 .752 .921 r
.70612 .54854 .71093 .55412 .72128 .55112 .7165 .54553 Mtetra
.654 .752 .922 r
.7165 .54553 .72128 .55112 .73168 .54811 .72693 .54252 Mtetra
.653 .752 .923 r
.72693 .54252 .73168 .54811 .74212 .5451 .73739 .53951 Mtetra
.652 .753 .924 r
.73739 .53951 .74212 .5451 .75259 .5421 .7479 .53651 Mtetra
.651 .754 .925 r
.7479 .53651 .75259 .5421 .76311 .5391 .75844 .53352 Mtetra
.651 .755 .926 r
.75844 .53352 .76311 .5391 .77366 .53609 .76903 .53053 Mtetra
.65 .756 .927 r
.76903 .53053 .77366 .53609 .78426 .53309 .77965 .52753 Mtetra
.65 .757 .927 r
.77965 .52753 .78426 .53309 .79489 .53007 .79032 .52452 Mtetra
.651 .758 .928 r
.79032 .52452 .79489 .53007 .80557 .52704 .80102 .52148 Mtetra
.652 .759 .928 r
.80102 .52148 .80557 .52704 .81628 .52397 .81176 .5184 Mtetra
.653 .76 .928 r
.81176 .5184 .81628 .52397 .82703 .52088 .82254 .51528 Mtetra
.655 .76 .927 r
.82254 .51528 .82703 .52088 .83782 .51774 .83336 .51211 Mtetra
.656 .76 .926 r
.83336 .51211 .83782 .51774 .84864 .51457 .84421 .50888 Mtetra
.657 .76 .925 r
.84421 .50888 .84864 .51457 .85951 .51135 .8551 .50562 Mtetra
.659 .759 .924 r
.8551 .50562 .85951 .51135 .87041 .50811 .86603 .50232 Mtetra
.659 .758 .923 r
.86603 .50232 .87041 .50811 .88135 .50483 .877 .49899 Mtetra
.66 .757 .922 r
.877 .49899 .88135 .50483 .89233 .50153 .88801 .49564 Mtetra
.66 .756 .921 r
.88801 .49564 .89233 .50153 .90335 .49821 .89906 .49228 Mtetra
.66 .755 .921 r
.89906 .49228 .90335 .49821 .91441 .49487 .91014 .48889 Mtetra
.66 .755 .92 r
.91014 .48889 .91441 .49487 .92551 .49151 .92127 .4855 Mtetra
.66 .754 .92 r
.92127 .4855 .92551 .49151 .93665 .48814 .93244 .4821 Mtetra
.66 .754 .919 r
.93244 .4821 .93665 .48814 .94784 .48476 .94366 .47868 Mtetra
.651 .75 .922 r
.34122 .64908 .34689 .65403 .356 .65146 .35035 .6465 Mtetra
.65 .75 .923 r
.35035 .6465 .356 .65146 .36514 .64889 .3595 .64391 Mtetra
.3595 .64391 .36514 .64889 .3743 .6463 .36869 .64133 Mtetra
.65 .751 .923 r
.36869 .64133 .3743 .6463 .3835 .64371 .37791 .63873 Mtetra
.65 .751 .924 r
.37791 .63873 .3835 .64371 .39274 .64112 .38716 .63614 Mtetra
.649 .752 .924 r
.38716 .63614 .39274 .64112 .402 .6385 .39645 .63354 Mtetra
.649 .753 .925 r
.39645 .63354 .402 .6385 .4113 .63587 .40576 .63092 Mtetra
.65 .755 .926 r
.40576 .63092 .4113 .63587 .42063 .63321 .41512 .62828 Mtetra
.651 .756 .927 r
.41512 .62828 .42063 .63321 .43 .63052 .4245 .62562 Mtetra
.652 .758 .928 r
.4245 .62562 .43 .63052 .4394 .62779 .43392 .62291 Mtetra
.654 .76 .928 r
.43392 .62291 .4394 .62779 .44883 .62502 .44337 .62015 Mtetra
.656 .762 .928 r
.44337 .62015 .44883 .62502 .4583 .6222 .45286 .61733 Mtetra
.658 .763 .928 r
.45286 .61733 .4583 .6222 .4678 .61934 .46238 .61445 Mtetra
.659 .764 .927 r
.46238 .61445 .4678 .61934 .47733 .61644 .47194 .61153 Mtetra
.661 .764 .926 r
.47194 .61153 .47733 .61644 .4869 .61352 .48153 .60856 Mtetra
.661 .763 .925 r
.48153 .60856 .4869 .61352 .4965 .61058 .49115 .60557 Mtetra
.662 .762 .924 r
.49115 .60557 .4965 .61058 .50613 .60764 .50081 .60257 Mtetra
.661 .76 .923 r
.50081 .60257 .50613 .60764 .51579 .6047 .51049 .59957 Mtetra
.66 .758 .922 r
.51049 .59957 .51579 .6047 .52549 .60176 .52022 .59658 Mtetra
.659 .757 .922 r
.52022 .59658 .52549 .60176 .53523 .59884 .52997 .59361 Mtetra
.659 .755 .921 r
.52997 .59361 .53523 .59884 .54499 .59592 .53976 .59065 Mtetra
.658 .754 .921 r
.53976 .59065 .54499 .59592 .5548 .593 .54959 .5877 Mtetra
.657 .753 .921 r
.54959 .5877 .5548 .593 .56463 .59009 .55945 .58475 Mtetra
.55945 .58475 .56463 .59009 .5745 .58718 .56934 .58181 Mtetra
.656 .752 .921 r
.56934 .58181 .5745 .58718 .58441 .58425 .57927 .57886 Mtetra
.656 .752 .92 r
.57927 .57886 .58441 .58425 .59435 .58133 .58924 .57591 Mtetra
.58924 .57591 .59435 .58133 .60433 .57839 .59924 .57296 Mtetra
.59924 .57296 .60433 .57839 .61435 .57545 .60928 .56999 Mtetra
.60928 .56999 .61435 .57545 .6244 .57249 .61935 .56702 Mtetra
.61935 .56702 .6244 .57249 .63448 .56953 .62946 .56404 Mtetra
.62946 .56404 .63448 .56953 .6446 .56656 .63961 .56104 Mtetra
.63961 .56104 .6446 .56656 .65476 .56357 .6498 .55804 Mtetra
.656 .752 .921 r
.6498 .55804 .65476 .56357 .66496 .56058 .66002 .55503 Mtetra
.655 .752 .921 r
.66002 .55503 .66496 .56058 .67519 .55758 .67028 .55201 Mtetra
.67028 .55201 .67519 .55758 .68546 .55457 .68057 .54899 Mtetra
.68057 .54899 .68546 .55457 .69577 .55156 .69091 .54596 Mtetra
.654 .752 .921 r
.69091 .54596 .69577 .55156 .70612 .54854 .70128 .54294 Mtetra
.654 .752 .922 r
.70128 .54294 .70612 .54854 .7165 .54553 .71169 .53992 Mtetra
.653 .752 .923 r
.71169 .53992 .7165 .54553 .72693 .54252 .72214 .53691 Mtetra
.652 .753 .924 r
.72214 .53691 .72693 .54252 .73739 .53951 .73264 .53391 Mtetra
.651 .754 .925 r
.73264 .53391 .73739 .53951 .7479 .53651 .74317 .53093 Mtetra
.649 .755 .926 r
.74317 .53093 .7479 .53651 .75844 .53352 .75375 .52796 Mtetra
.649 .756 .928 r
.75375 .52796 .75844 .53352 .76903 .53053 .76436 .52499 Mtetra
.649 .757 .929 r
.76436 .52499 .76903 .53053 .77965 .52753 .77502 .52201 Mtetra
.649 .759 .93 r
.77502 .52201 .77965 .52753 .79032 .52452 .78571 .519 Mtetra
.65 .76 .93 r
.78571 .519 .79032 .52452 .80102 .52148 .79645 .51595 Mtetra
.652 .762 .93 r
.79645 .51595 .80102 .52148 .81176 .5184 .80722 .51285 Mtetra
.654 .762 .929 r
.80722 .51285 .81176 .5184 .82254 .51528 .81803 .50968 Mtetra
.656 .762 .928 r
.81803 .50968 .82254 .51528 .83336 .51211 .82887 .50646 Mtetra
.658 .762 .927 r
.82887 .50646 .83336 .51211 .84421 .50888 .83975 .50318 Mtetra
.659 .761 .925 r
.83975 .50318 .84421 .50888 .8551 .50562 .85067 .49985 Mtetra
.66 .759 .924 r
.85067 .49985 .8551 .50562 .86603 .50232 .86162 .49649 Mtetra
.661 .758 .922 r
.86162 .49649 .86603 .50232 .877 .49899 .87262 .4931 Mtetra
.661 .757 .921 r
.87262 .4931 .877 .49899 .88801 .49564 .88365 .4897 Mtetra
.661 .756 .92 r
.88365 .4897 .88801 .49564 .89906 .49228 .89473 .48628 Mtetra
.661 .755 .92 r
.89473 .48628 .89906 .49228 .91014 .48889 .90584 .48286 Mtetra
.661 .754 .919 r
.90584 .48286 .91014 .48889 .92127 .4855 .917 .47943 Mtetra
.66 .754 .919 r
.917 .47943 .92127 .4855 .93244 .4821 .92821 .476 Mtetra
.66 .753 .919 r
.92821 .476 .93244 .4821 .94366 .47868 .93945 .47256 Mtetra
.651 .75 .922 r
.33552 .6441 .34122 .64908 .35035 .6465 .34466 .64149 Mtetra
.34466 .64149 .35035 .6465 .3595 .64391 .35383 .63889 Mtetra
.65 .75 .922 r
.35383 .63889 .3595 .64391 .36869 .64133 .36304 .63628 Mtetra
.36304 .63628 .36869 .64133 .37791 .63873 .37228 .63368 Mtetra
.649 .75 .923 r
.37228 .63368 .37791 .63873 .38716 .63614 .38155 .63108 Mtetra
.649 .75 .924 r
.38155 .63108 .38716 .63614 .39645 .63354 .39085 .62849 Mtetra
.648 .751 .924 r
.39085 .62849 .39645 .63354 .40576 .63092 .40019 .62589 Mtetra
.648 .752 .926 r
.40019 .62589 .40576 .63092 .41512 .62828 .40956 .62329 Mtetra
.648 .754 .927 r
.40956 .62329 .41512 .62828 .4245 .62562 .41897 .62066 Mtetra
.649 .757 .928 r
.41897 .62066 .4245 .62562 .43392 .62291 .4284 .61799 Mtetra
.651 .759 .929 r
.4284 .61799 .43392 .62291 .44337 .62015 .43788 .61526 Mtetra
.654 .762 .929 r
.43788 .61526 .44337 .62015 .45286 .61733 .44739 .61247 Mtetra
.656 .765 .929 r
.44739 .61247 .45286 .61733 .46238 .61445 .45693 .6096 Mtetra
.659 .766 .929 r
.45693 .6096 .46238 .61445 .47194 .61153 .46651 .60666 Mtetra
.661 .767 .928 r
.46651 .60666 .47194 .61153 .48153 .60856 .47612 .60365 Mtetra
.663 .766 .927 r
.47612 .60365 .48153 .60856 .49115 .60557 .48577 .60061 Mtetra
.663 .765 .926 r
.48577 .60061 .49115 .60557 .50081 .60257 .49545 .59754 Mtetra
.663 .763 .925 r
.49545 .59754 .50081 .60257 .51049 .59957 .50516 .59447 Mtetra
.662 .761 .924 r
.50516 .59447 .51049 .59957 .52022 .59658 .5149 .59142 Mtetra
.661 .759 .923 r
.5149 .59142 .52022 .59658 .52997 .59361 .52468 .58838 Mtetra
.66 .757 .922 r
.52468 .58838 .52997 .59361 .53976 .59065 .5345 .58537 Mtetra
.659 .755 .922 r
.5345 .58537 .53976 .59065 .54959 .5877 .54434 .58238 Mtetra
.658 .754 .921 r
.54434 .58238 .54959 .5877 .55945 .58475 .55423 .57939 Mtetra
.657 .753 .921 r
.55423 .57939 .55945 .58475 .56934 .58181 .56415 .57642 Mtetra
.56415 .57642 .56934 .58181 .57927 .57886 .5741 .57345 Mtetra
.656 .752 .921 r
.5741 .57345 .57927 .57886 .58924 .57591 .58409 .57047 Mtetra
.58409 .57047 .58924 .57591 .59924 .57296 .59412 .56749 Mtetra
.59412 .56749 .59924 .57296 .60928 .56999 .60418 .56451 Mtetra
.656 .752 .92 r
.60418 .56451 .60928 .56999 .61935 .56702 .61428 .56151 Mtetra
.656 .752 .921 r
.61428 .56151 .61935 .56702 .62946 .56404 .62441 .55851 Mtetra
.62441 .55851 .62946 .56404 .63961 .56104 .63458 .5555 Mtetra
.63458 .5555 .63961 .56104 .6498 .55804 .64479 .55248 Mtetra
.655 .752 .921 r
.64479 .55248 .6498 .55804 .66002 .55503 .65504 .54945 Mtetra
.65504 .54945 .66002 .55503 .67028 .55201 .66533 .54641 Mtetra
.66533 .54641 .67028 .55201 .68057 .54899 .67565 .54338 Mtetra
.654 .752 .922 r
.67565 .54338 .68057 .54899 .69091 .54596 .68601 .54035 Mtetra
.68601 .54035 .69091 .54596 .70128 .54294 .69641 .53732 Mtetra
.652 .752 .923 r
.69641 .53732 .70128 .54294 .71169 .53992 .70685 .53431 Mtetra
.651 .753 .924 r
.70685 .53431 .71169 .53992 .72214 .53691 .71733 .53131 Mtetra
.65 .754 .926 r
.71733 .53131 .72214 .53691 .73264 .53391 .72785 .52833 Mtetra
.648 .755 .927 r
.72785 .52833 .73264 .53391 .74317 .53093 .73842 .52538 Mtetra
.647 .756 .929 r
.73842 .52538 .74317 .53093 .75375 .52796 .74902 .52244 Mtetra
.646 .758 .93 r
.74902 .52244 .75375 .52796 .76436 .52499 .75967 .51949 Mtetra
.647 .76 .932 r
.75967 .51949 .76436 .52499 .77502 .52201 .77036 .51653 Mtetra
.648 .762 .932 r
.77036 .51653 .77502 .52201 .78571 .519 .78108 .51352 Mtetra
.65 .763 .932 r
.78108 .51352 .78571 .519 .79645 .51595 .79185 .51044 Mtetra
.652 .764 .931 r
.79185 .51044 .79645 .51595 .80722 .51285 .80265 .50729 Mtetra
.655 .764 .93 r
.80265 .50729 .80722 .51285 .81803 .50968 .81348 .50406 Mtetra
.658 .764 .928 r
.81348 .50406 .81803 .50968 .82887 .50646 .82435 .50076 Mtetra
.66 .762 .926 r
.82435 .50076 .82887 .50646 .83975 .50318 .83525 .4974 Mtetra
.661 .761 .924 r
.83525 .4974 .83975 .50318 .85067 .49985 .8462 .49399 Mtetra
.662 .759 .922 r
.8462 .49399 .85067 .49985 .86162 .49649 .85718 .49056 Mtetra
.662 .757 .92 r
.85718 .49056 .86162 .49649 .87262 .4931 .8682 .48711 Mtetra
.662 .755 .92 r
.8682 .48711 .87262 .4931 .88365 .4897 .87926 .48366 Mtetra
.662 .754 .919 r
.87926 .48366 .88365 .4897 .89473 .48628 .89036 .48021 Mtetra
.661 .753 .919 r
.89036 .48021 .89473 .48628 .90584 .48286 .90151 .47676 Mtetra
.90151 .47676 .90584 .48286 .917 .47943 .9127 .4733 Mtetra
.66 .753 .919 r
.9127 .4733 .917 .47943 .92821 .476 .92394 .46985 Mtetra
.92394 .46985 .92821 .476 .93945 .47256 .93521 .46639 Mtetra
.652 .75 .922 r
.32977 .63908 .33552 .6441 .34466 .64149 .33894 .63644 Mtetra
.652 .75 .921 r
.33894 .63644 .34466 .64149 .35383 .63889 .34813 .6338 Mtetra
.651 .749 .921 r
.34813 .6338 .35383 .63889 .36304 .63628 .35736 .63117 Mtetra
.65 .748 .921 r
.35736 .63117 .36304 .63628 .37228 .63368 .36662 .62854 Mtetra
.649 .747 .921 r
.36662 .62854 .37228 .63368 .38155 .63108 .37591 .62593 Mtetra
.648 .747 .922 r
.37591 .62593 .38155 .63108 .39085 .62849 .38523 .62334 Mtetra
.647 .748 .923 r
.38523 .62334 .39085 .62849 .40019 .62589 .39458 .62076 Mtetra
.646 .749 .924 r
.39458 .62076 .40019 .62589 .40956 .62329 .40397 .61819 Mtetra
.646 .751 .926 r
.40397 .61819 .40956 .62329 .41897 .62066 .4134 .61561 Mtetra
.646 .754 .927 r
.4134 .61561 .41897 .62066 .4284 .61799 .42285 .613 Mtetra
.648 .757 .929 r
.42285 .613 .4284 .61799 .43788 .61526 .43235 .61034 Mtetra
.65 .761 .93 r
.43235 .61034 .43788 .61526 .44739 .61247 .44188 .6076 Mtetra
.654 .765 .931 r
.44188 .6076 .44739 .61247 .45693 .6096 .45144 .60476 Mtetra
.658 .768 .931 r
.45144 .60476 .45693 .6096 .46651 .60666 .46104 .60183 Mtetra
.661 .77 .93 r
.46104 .60183 .46651 .60666 .47612 .60365 .47068 .5988 Mtetra
.664 .771 .929 r
.47068 .5988 .47612 .60365 .48577 .60061 .48035 .59571 Mtetra
.665 .77 .928 r
.48035 .59571 .48577 .60061 .49545 .59754 .49005 .59257 Mtetra
.665 .768 .926 r
.49005 .59257 .49545 .59754 .50516 .59447 .49979 .58942 Mtetra
.664 .765 .925 r
.49979 .58942 .50516 .59447 .5149 .59142 .50955 .58629 Mtetra
.663 .762 .924 r
.50955 .58629 .5149 .59142 .52468 .58838 .51936 .58318 Mtetra
.662 .76 .923 r
.51936 .58318 .52468 .58838 .5345 .58537 .52919 .5801 Mtetra
.66 .758 .922 r
.52919 .5801 .5345 .58537 .54434 .58238 .53907 .57705 Mtetra
.659 .756 .922 r
.53907 .57705 .54434 .58238 .55423 .57939 .54897 .57402 Mtetra
.658 .754 .921 r
.54897 .57402 .55423 .57939 .56415 .57642 .55891 .57101 Mtetra
.657 .753 .921 r
.55891 .57101 .56415 .57642 .5741 .57345 .56889 .568 Mtetra
.56889 .568 .5741 .57345 .58409 .57047 .57891 .565 Mtetra
.656 .752 .921 r
.57891 .565 .58409 .57047 .59412 .56749 .58896 .562 Mtetra
.58896 .562 .59412 .56749 .60418 .56451 .59904 .55899 Mtetra
.59904 .55899 .60418 .56451 .61428 .56151 .60917 .55597 Mtetra
.60917 .55597 .61428 .56151 .62441 .55851 .61933 .55295 Mtetra
.61933 .55295 .62441 .55851 .63458 .5555 .62952 .54992 Mtetra
.655 .752 .921 r
.62952 .54992 .63458 .5555 .64479 .55248 .63976 .54688 Mtetra
.63976 .54688 .64479 .55248 .65504 .54945 .65003 .54384 Mtetra
.65003 .54384 .65504 .54945 .66533 .54641 .66034 .54079 Mtetra
.654 .752 .922 r
.66034 .54079 .66533 .54641 .67565 .54338 .67069 .53775 Mtetra
.653 .752 .922 r
.67069 .53775 .67565 .54338 .68601 .54035 .68108 .53471 Mtetra
.652 .753 .923 r
.68108 .53471 .68601 .54035 .69641 .53732 .69151 .53169 Mtetra
.651 .753 .924 r
.69151 .53169 .69641 .53732 .70685 .53431 .70198 .52869 Mtetra
.649 .754 .926 r
.70198 .52869 .70685 .53431 .71733 .53131 .71249 .52572 Mtetra
.647 .755 .928 r
.71249 .52572 .71733 .53131 .72785 .52833 .72304 .52279 Mtetra
.645 .757 .93 r
.72304 .52279 .72785 .52833 .73842 .52538 .73364 .51987 Mtetra
.644 .759 .932 r
.73364 .51987 .73842 .52538 .74902 .52244 .74427 .51697 Mtetra
.644 .761 .934 r
.74427 .51697 .74902 .52244 .75967 .51949 .75495 .51406 Mtetra
.645 .763 .935 r
.75495 .51406 .75967 .51949 .77036 .51653 .76567 .5111 Mtetra
.647 .765 .935 r
.76567 .5111 .77036 .51653 .78108 .51352 .77643 .50808 Mtetra
.651 .767 .934 r
.77643 .50808 .78108 .51352 .79185 .51044 .78722 .50495 Mtetra
.654 .767 .932 r
.78722 .50495 .79185 .51044 .80265 .50729 .79804 .50173 Mtetra
.658 .767 .93 r
.79804 .50173 .80265 .50729 .81348 .50406 .8089 .4984 Mtetra
.661 .765 .927 r
.8089 .4984 .81348 .50406 .82435 .50076 .81979 .49499 Mtetra
.663 .762 .924 r
.81979 .49499 .82435 .50076 .83525 .4974 .83072 .49152 Mtetra
.664 .76 .921 r
.83072 .49152 .83525 .4974 .8462 .49399 .84169 .48802 Mtetra
.664 .757 .919 r
.84169 .48802 .8462 .49399 .85718 .49056 .85269 .48451 Mtetra
.664 .755 .918 r
.85269 .48451 .85718 .49056 .8682 .48711 .86374 .481 Mtetra
.663 .753 .917 r
.86374 .481 .8682 .48711 .87926 .48366 .87483 .47751 Mtetra
.662 .752 .917 r
.87483 .47751 .87926 .48366 .89036 .48021 .88596 .47403 Mtetra
.661 .751 .917 r
.88596 .47403 .89036 .48021 .90151 .47676 .89714 .47056 Mtetra
.66 .751 .918 r
.89714 .47056 .90151 .47676 .9127 .4733 .90837 .4671 Mtetra
.66 .752 .918 r
.90837 .4671 .9127 .4733 .92394 .46985 .91963 .46364 Mtetra
.659 .752 .919 r
.91963 .46364 .92394 .46985 .93521 .46639 .93095 .46018 Mtetra
.653 .751 .921 r
.32399 .63404 .32977 .63908 .33894 .63644 .33318 .63135 Mtetra
.653 .749 .921 r
.33318 .63135 .33894 .63644 .34813 .6338 .34239 .62866 Mtetra
.652 .748 .92 r
.34239 .62866 .34813 .6338 .35736 .63117 .35164 .62598 Mtetra
.651 .747 .919 r
.35164 .62598 .35736 .63117 .36662 .62854 .36092 .62331 Mtetra
.65 .745 .919 r
.36092 .62331 .36662 .62854 .37591 .62593 .37023 .62067 Mtetra
.648 .744 .92 r
.37023 .62067 .37591 .62593 .38523 .62334 .37957 .61805 Mtetra
.646 .744 .92 r
.37957 .61805 .38523 .62334 .39458 .62076 .38895 .61548 Mtetra
.645 .744 .922 r
.38895 .61548 .39458 .62076 .40397 .61819 .39835 .61293 Mtetra
.643 .745 .923 r
.39835 .61293 .40397 .61819 .4134 .61561 .40779 .61041 Mtetra
.643 .748 .926 r
.40779 .61041 .4134 .61561 .42285 .613 .41727 .60787 Mtetra
.643 .752 .928 r
.41727 .60787 .42285 .613 .43235 .61034 .42678 .6053 Mtetra
.646 .757 .93 r
.42678 .6053 .43235 .61034 .44188 .6076 .43633 .60266 Mtetra
.65 .762 .932 r
.43633 .60266 .44188 .6076 .45144 .60476 .44591 .59991 Mtetra
.654 .768 .933 r
.44591 .59991 .45144 .60476 .46104 .60183 .45554 .59703 Mtetra
.66 .772 .932 r
.45554 .59703 .46104 .60183 .47068 .5988 .46519 .59401 Mtetra
.664 .774 .932 r
.46519 .59401 .47068 .5988 .48035 .59571 .47489 .59089 Mtetra
.667 .775 .93 r
.47489 .59089 .48035 .59571 .49005 .59257 .48461 .58769 Mtetra
.668 .773 .929 r
.48461 .58769 .49005 .59257 .49979 .58942 .49438 .58446 Mtetra
.667 .771 .927 r
.49438 .58446 .49979 .58942 .50955 .58629 .50417 .58123 Mtetra
.666 .767 .926 r
.50417 .58123 .50955 .58629 .51936 .58318 .514 .57803 Mtetra
.664 .764 .924 r
.514 .57803 .51936 .58318 .52919 .5801 .52386 .57487 Mtetra
.662 .761 .923 r
.52386 .57487 .52919 .5801 .53907 .57705 .53375 .57174 Mtetra
.66 .758 .923 r
.53375 .57174 .53907 .57705 .54897 .57402 .54368 .56866 Mtetra
.659 .756 .922 r
.54368 .56866 .54897 .57402 .55891 .57101 .55365 .56559 Mtetra
.658 .755 .922 r
.55365 .56559 .55891 .57101 .56889 .568 .56365 .56255 Mtetra
.657 .754 .921 r
.56365 .56255 .56889 .568 .57891 .565 .57369 .55951 Mtetra
.657 .753 .921 r
.57369 .55951 .57891 .565 .58896 .562 .58376 .55648 Mtetra
.656 .753 .921 r
.58376 .55648 .58896 .562 .59904 .55899 .59387 .55345 Mtetra
.59387 .55345 .59904 .55899 .60917 .55597 .60402 .55041 Mtetra
.656 .752 .921 r
.60402 .55041 .60917 .55597 .61933 .55295 .61421 .54736 Mtetra
.655 .752 .921 r
.61421 .54736 .61933 .55295 .62952 .54992 .62443 .54431 Mtetra
.62443 .54431 .62952 .54992 .63976 .54688 .63469 .54126 Mtetra
.655 .752 .922 r
.63469 .54126 .63976 .54688 .65003 .54384 .64499 .53821 Mtetra
.654 .752 .922 r
.64499 .53821 .65003 .54384 .66034 .54079 .65532 .53515 Mtetra
.653 .753 .923 r
.65532 .53515 .66034 .54079 .67069 .53775 .6657 .53211 Mtetra
.652 .753 .924 r
.6657 .53211 .67069 .53775 .68108 .53471 .67612 .52908 Mtetra
.651 .754 .925 r
.67612 .52908 .68108 .53471 .69151 .53169 .68657 .52608 Mtetra
.648 .754 .927 r
.68657 .52608 .69151 .53169 .70198 .52869 .69707 .52312 Mtetra
.646 .756 .929 r
.69707 .52312 .70198 .52869 .71249 .52572 .70761 .52019 Mtetra
.644 .757 .931 r
.70761 .52019 .71249 .52572 .72304 .52279 .7182 .51731 Mtetra
.642 .759 .934 r
.7182 .51731 .72304 .52279 .73364 .51987 .72883 .51445 Mtetra
.64 .762 .936 r
.72883 .51445 .73364 .51987 .74427 .51697 .7395 .51159 Mtetra
.641 .765 .938 r
.7395 .51159 .74427 .51697 .75495 .51406 .75021 .50871 Mtetra
.644 .768 .938 r
.75021 .50871 .75495 .51406 .76567 .5111 .76096 .50573 Mtetra
.648 .769 .937 r
.76096 .50573 .76567 .5111 .77643 .50808 .77174 .50266 Mtetra
.653 .77 .935 r
.77174 .50266 .77643 .50808 .78722 .50495 .78256 .49944 Mtetra
.658 .769 .931 r
.78256 .49944 .78722 .50495 .79804 .50173 .79341 .49609 Mtetra
.663 .767 .927 r
.79341 .49609 .79804 .50173 .8089 .4984 .80428 .49262 Mtetra
.666 .764 .923 r
.80428 .49262 .8089 .4984 .81979 .49499 .81519 .48907 Mtetra
.667 .76 .919 r
.81519 .48907 .81979 .49499 .83072 .49152 .82614 .48549 Mtetra
.667 .756 .917 r
.82614 .48549 .83072 .49152 .84169 .48802 .83713 .48189 Mtetra
.666 .753 .915 r
.83713 .48189 .84169 .48802 .85269 .48451 .84816 .47831 Mtetra
.665 .751 .914 r
.84816 .47831 .85269 .48451 .86374 .481 .85924 .47475 Mtetra
.663 .749 .914 r
.85924 .47475 .86374 .481 .87483 .47751 .87036 .47124 Mtetra
.661 .749 .915 r
.87036 .47124 .87483 .47751 .88596 .47403 .88153 .46775 Mtetra
.66 .749 .916 r
.88153 .46775 .88596 .47403 .89714 .47056 .89274 .46428 Mtetra
.659 .749 .917 r
.89274 .46428 .89714 .47056 .90837 .4671 .904 .46083 Mtetra
.658 .75 .918 r
.904 .46083 .90837 .4671 .91963 .46364 .9153 .45738 Mtetra
.658 .751 .919 r
.9153 .45738 .91963 .46364 .93095 .46018 .92665 .45393 Mtetra
.655 .751 .92 r
.31818 .62896 .32399 .63404 .33318 .63135 .32738 .62621 Mtetra
.655 .75 .919 r
.32738 .62621 .33318 .63135 .34239 .62866 .33662 .62346 Mtetra
.655 .748 .918 r
.33662 .62346 .34239 .62866 .35164 .62598 .34589 .62071 Mtetra
.653 .746 .917 r
.34589 .62071 .35164 .62598 .36092 .62331 .35519 .61798 Mtetra
.652 .743 .917 r
.35519 .61798 .36092 .62331 .37023 .62067 .36452 .61527 Mtetra
.65 .741 .916 r
.36452 .61527 .37023 .62067 .37957 .61805 .37389 .61262 Mtetra
.647 .74 .917 r
.37389 .61262 .37957 .61805 .38895 .61548 .38328 .61002 Mtetra
.644 .739 .918 r
.38328 .61002 .38895 .61548 .39835 .61293 .3927 .60748 Mtetra
.641 .738 .92 r
.3927 .60748 .39835 .61293 .40779 .61041 .40216 .605 Mtetra
.639 .74 .922 r
.40216 .605 .40779 .61041 .41727 .60787 .41165 .60255 Mtetra
.638 .744 .925 r
.41165 .60255 .41727 .60787 .42678 .6053 .42118 .6001 Mtetra
.639 .75 .929 r
.42118 .6001 .42678 .6053 .43633 .60266 .43075 .5976 Mtetra
.643 .757 .932 r
.43075 .5976 .43633 .60266 .44591 .59991 .44035 .59499 Mtetra
.648 .765 .934 r
.44035 .59499 .44591 .59991 .45554 .59703 .44999 .59223 Mtetra
.656 .772 .935 r
.44999 .59223 .45554 .59703 .46519 .59401 .45967 .58928 Mtetra
.662 .777 .935 r
.45967 .58928 .46519 .59401 .47489 .59089 .46939 .58617 Mtetra
.667 .78 .933 r
.46939 .58617 .47489 .59089 .48461 .58769 .47914 .58293 Mtetra
.67 .78 .932 r
.47914 .58293 .48461 .58769 .49438 .58446 .48893 .57961 Mtetra
.67 .777 .93 r
.48893 .57961 .49438 .58446 .50417 .58123 .49875 .57627 Mtetra
.669 .774 .928 r
.49875 .57627 .50417 .58123 .514 .57803 .5086 .57296 Mtetra
.667 .769 .926 r
.5086 .57296 .514 .57803 .52386 .57487 .51848 .56969 Mtetra
.665 .765 .925 r
.51848 .56969 .52386 .57487 .53375 .57174 .5284 .56647 Mtetra
.662 .762 .924 r
.5284 .56647 .53375 .57174 .54368 .56866 .53836 .56331 Mtetra
.66 .759 .923 r
.53836 .56331 .54368 .56866 .55365 .56559 .54835 .56019 Mtetra
.659 .757 .922 r
.54835 .56019 .55365 .56559 .56365 .56255 .55837 .55709 Mtetra
.658 .755 .922 r
.55837 .55709 .56365 .56255 .57369 .55951 .56844 .55402 Mtetra
.657 .754 .922 r
.56844 .55402 .57369 .55951 .58376 .55648 .57853 .55095 Mtetra
.656 .754 .922 r
.57853 .55095 .58376 .55648 .59387 .55345 .58867 .54789 Mtetra
.656 .753 .922 r
.58867 .54789 .59387 .55345 .60402 .55041 .59884 .54483 Mtetra
.59884 .54483 .60402 .55041 .61421 .54736 .60905 .54176 Mtetra
.655 .753 .922 r
.60905 .54176 .61421 .54736 .62443 .54431 .6193 .53869 Mtetra
.6193 .53869 .62443 .54431 .63469 .54126 .62959 .53563 Mtetra
.654 .753 .922 r
.62959 .53563 .63469 .54126 .64499 .53821 .63991 .53257 Mtetra
.653 .753 .923 r
.63991 .53257 .64499 .53821 .65532 .53515 .65028 .52951 Mtetra
.652 .754 .924 r
.65028 .52951 .65532 .53515 .6657 .53211 .66068 .52648 Mtetra
.65 .754 .925 r
.66068 .52648 .6657 .53211 .67612 .52908 .67112 .52347 Mtetra
.648 .755 .927 r
.67112 .52347 .67612 .52908 .68657 .52608 .68161 .52051 Mtetra
.645 .756 .93 r
.68161 .52051 .68657 .52608 .69707 .52312 .69214 .51759 Mtetra
.642 .758 .933 r
.69214 .51759 .69707 .52312 .70761 .52019 .70271 .51473 Mtetra
.639 .76 .936 r
.70271 .51473 .70761 .52019 .7182 .51731 .71333 .51192 Mtetra
.637 .763 .939 r
.71333 .51192 .7182 .51731 .72883 .51445 .72399 .50914 Mtetra
.636 .767 .942 r
.72399 .50914 .72883 .51445 .7395 .51159 .7347 .50632 Mtetra
.639 .77 .943 r
.7347 .50632 .7395 .51159 .75021 .50871 .74544 .50344 Mtetra
.644 .773 .942 r
.74544 .50344 .75021 .50871 .76096 .50573 .75622 .50042 Mtetra
.651 .774 .939 r
.75622 .50042 .76096 .50573 .77174 .50266 .76703 .49723 Mtetra
.659 .774 .934 r
.76703 .49723 .77174 .50266 .78256 .49944 .77786 .49385 Mtetra
.665 .77 .928 r
.77786 .49385 .78256 .49944 .79341 .49609 .78873 .49031 Mtetra
.669 .766 .922 r
.78873 .49031 .79341 .49609 .80428 .49262 .79962 .48666 Mtetra
.671 .76 .917 r
.79962 .48666 .80428 .49262 .81519 .48907 .81055 .48294 Mtetra
.671 .755 .914 r
.81055 .48294 .81519 .48907 .82614 .48549 .82152 .47922 Mtetra
.67 .751 .911 r
.82152 .47922 .82614 .48549 .83713 .48189 .83253 .47553 Mtetra
.667 .747 .91 r
.83253 .47553 .83713 .48189 .84816 .47831 .84359 .47191 Mtetra
.665 .745 .91 r
.84359 .47191 .84816 .47831 .85924 .47475 .85469 .46833 Mtetra
.662 .744 .911 r
.85469 .46833 .85924 .47475 .87036 .47124 .86585 .46482 Mtetra
.66 .745 .913 r
.86585 .46482 .87036 .47124 .88153 .46775 .87705 .46135 Mtetra
.659 .746 .914 r
.87705 .46135 .88153 .46775 .89274 .46428 .8883 .45791 Mtetra
.657 .747 .916 r
.8883 .45791 .89274 .46428 .904 .46083 .89959 .45448 Mtetra
.657 .748 .917 r
.89959 .45448 .904 .46083 .9153 .45738 .91094 .45106 Mtetra
.656 .75 .919 r
.91094 .45106 .9153 .45738 .92665 .45393 .92232 .44763 Mtetra
.657 .752 .92 r
.31232 .62385 .31818 .62896 .32738 .62621 .32155 .62104 Mtetra
.657 .75 .918 r
.32155 .62104 .32738 .62621 .33662 .62346 .33081 .61821 Mtetra
.657 .748 .917 r
.33081 .61821 .33662 .62346 .34589 .62071 .3401 .61539 Mtetra
.656 .746 .916 r
.3401 .61539 .34589 .62071 .35519 .61798 .34943 .61258 Mtetra
.655 .743 .915 r
.34943 .61258 .35519 .61798 .36452 .61527 .35878 .6098 Mtetra
.652 .74 .914 r
.35878 .6098 .36452 .61527 .37389 .61262 .36817 .60706 Mtetra
.649 .737 .913 r
.36817 .60706 .37389 .61262 .38328 .61002 .37758 .60439 Mtetra
.645 .734 .914 r
.37758 .60439 .38328 .61002 .3927 .60748 .38703 .60181 Mtetra
.64 .732 .915 r
.38703 .60181 .3927 .60748 .40216 .605 .3965 .59934 Mtetra
.636 .731 .917 r
.3965 .59934 .40216 .605 .41165 .60255 .40601 .59694 Mtetra
.632 .733 .92 r
.40601 .59694 .41165 .60255 .42118 .6001 .41555 .59462 Mtetra
.632 .738 .924 r
.41555 .59462 .42118 .6001 .43075 .5976 .42513 .59229 Mtetra
.634 .746 .929 r
.42513 .59229 .43075 .5976 .44035 .59499 .43475 .58988 Mtetra
.639 .756 .933 r
.43475 .58988 .44035 .59499 .44999 .59223 .44441 .58731 Mtetra
.648 .767 .936 r
.44441 .58731 .44999 .59223 .45967 .58928 .45411 .58452 Mtetra
.657 .776 .937 r
.45411 .58452 .45967 .58928 .46939 .58617 .46385 .5815 Mtetra
.666 .783 .936 r
.46385 .5815 .46939 .58617 .47914 .58293 .47363 .57827 Mtetra
.671 .786 .935 r
.47363 .57827 .47914 .58293 .48893 .57961 .48344 .5749 Mtetra
.673 .785 .933 r
.48344 .5749 .48893 .57961 .49875 .57627 .49328 .57147 Mtetra
.673 .782 .931 r
.49328 .57147 .49875 .57627 .5086 .57296 .50316 .56803 Mtetra
.671 .777 .929 r
.50316 .56803 .5086 .57296 .51848 .56969 .51307 .56463 Mtetra
.669 .772 .927 r
.51307 .56463 .51848 .56969 .5284 .56647 .52302 .5613 Mtetra
.665 .767 .926 r
.52302 .5613 .5284 .56647 .53836 .56331 .533 .55803 Mtetra
.663 .764 .925 r
.533 .55803 .53836 .56331 .54835 .56019 .54301 .55483 Mtetra
.661 .761 .924 r
.54301 .55483 .54835 .56019 .55837 .55709 .55306 .55167 Mtetra
.659 .758 .923 r
.55306 .55167 .55837 .55709 .56844 .55402 .56315 .54854 Mtetra
.658 .757 .923 r
.56315 .54854 .56844 .55402 .57853 .55095 .57327 .54543 Mtetra
.657 .756 .923 r
.57327 .54543 .57853 .55095 .58867 .54789 .58343 .54233 Mtetra
.656 .755 .923 r
.58343 .54233 .58867 .54789 .59884 .54483 .59363 .53925 Mtetra
.59363 .53925 .59884 .54483 .60905 .54176 .60386 .53616 Mtetra
.655 .754 .923 r
.60386 .53616 .60905 .54176 .6193 .53869 .61414 .53308 Mtetra
.654 .754 .923 r
.61414 .53308 .6193 .53869 .62959 .53563 .62445 .53 Mtetra
.653 .754 .924 r
.62445 .53 .62959 .53563 .63991 .53257 .6348 .52694 Mtetra
.652 .755 .925 r
.6348 .52694 .63991 .53257 .65028 .52951 .64519 .5239 Mtetra
.65 .755 .927 r
.64519 .5239 .65028 .52951 .66068 .52648 .65562 .52089 Mtetra
.647 .756 .929 r
.65562 .52089 .66068 .52648 .67112 .52347 .6661 .51793 Mtetra
.644 .758 .931 r
.6661 .51793 .67112 .52347 .68161 .52051 .67662 .51502 Mtetra
.64 .759 .935 r
.67662 .51502 .68161 .52051 .69214 .51759 .68718 .51219 Mtetra
.636 .762 .939 r
.68718 .51219 .69214 .51759 .70271 .51473 .69779 .50942 Mtetra
.633 .765 .942 r
.69779 .50942 .70271 .51473 .71333 .51192 .70844 .50669 Mtetra
.631 .769 .946 r
.70844 .50669 .71333 .51192 .72399 .50914 .71914 .50397 Mtetra
.633 .773 .947 r
.71914 .50397 .72399 .50914 .7347 .50632 .72987 .50117 Mtetra
.639 .776 .946 r
.72987 .50117 .7347 .50632 .74544 .50344 .74064 .49823 Mtetra
.649 .778 .943 r
.74064 .49823 .74544 .50344 .75622 .50042 .75144 .49507 Mtetra
.658 .777 .937 r
.75144 .49507 .75622 .50042 .76703 .49723 .76227 .49168 Mtetra
.668 .774 .929 r
.76227 .49168 .76703 .49723 .77786 .49385 .77312 .48806 Mtetra
.674 .767 .921 r
.77312 .48806 .77786 .49385 .78873 .49031 .784 .48427 Mtetra
.677 .76 .914 r
.784 .48427 .78873 .49031 .79962 .48666 .7949 .4804 Mtetra
.677 .753 .909 r
.7949 .4804 .79962 .48666 .81055 .48294 .80585 .47651 Mtetra
.674 .747 .906 r
.80585 .47651 .81055 .48294 .82152 .47922 .81684 .47269 Mtetra
.67 .743 .905 r
.81684 .47269 .82152 .47922 .83253 .47553 .82788 .46895 Mtetra
.666 .74 .905 r
.82788 .46895 .83253 .47553 .84359 .47191 .83897 .46532 Mtetra
.663 .74 .907 r
.83897 .46532 .84359 .47191 .85469 .46833 .85011 .46178 Mtetra
.66 .74 .909 r
.85011 .46178 .85469 .46833 .86585 .46482 .8613 .4583 Mtetra
.658 .742 .912 r
.8613 .4583 .86585 .46482 .87705 .46135 .87254 .45488 Mtetra
.656 .744 .914 r
.87254 .45488 .87705 .46135 .8883 .45791 .88383 .45147 Mtetra
.655 .745 .916 r
.88383 .45147 .8883 .45791 .89959 .45448 .89516 .44808 Mtetra
.655 .747 .918 r
.89516 .44808 .89959 .45448 .91094 .45106 .90654 .44469 Mtetra
.655 .749 .919 r
.90654 .44469 .91094 .45106 .92232 .44763 .91796 .44128 Mtetra
.659 .752 .919 r
.30643 .61871 .31232 .62385 .32155 .62104 .31568 .61584 Mtetra
.659 .751 .918 r
.31568 .61584 .32155 .62104 .33081 .61821 .32496 .61296 Mtetra
.659 .749 .917 r
.32496 .61296 .33081 .61821 .3401 .61539 .33428 .61006 Mtetra
.659 .747 .915 r
.33428 .61006 .3401 .61539 .34943 .61258 .34362 .60716 Mtetra
.659 .744 .913 r
.34362 .60716 .34943 .61258 .35878 .6098 .353 .60426 Mtetra
.657 .74 .912 r
.353 .60426 .35878 .6098 .36817 .60706 .36241 .6014 Mtetra
.654 .736 .91 r
.36241 .6014 .36817 .60706 .37758 .60439 .37185 .59861 Mtetra
.649 .731 .909 r
.37185 .59861 .37758 .60439 .38703 .60181 .38132 .59592 Mtetra
.643 .726 .909 r
.38132 .59592 .38703 .60181 .3965 .59934 .39082 .59338 Mtetra
.636 .722 .91 r
.39082 .59338 .3965 .59934 .40601 .59694 .40034 .59099 Mtetra
.629 .721 .913 r
.40034 .59099 .40601 .59694 .41555 .59462 .4099 .58876 Mtetra
.625 .723 .917 r
.4099 .58876 .41555 .59462 .42513 .59229 .41949 .5866 Mtetra
.623 .73 .923 r
.41949 .5866 .42513 .59229 .43475 .58988 .42912 .58446 Mtetra
.627 .742 .93 r
.42912 .58446 .43475 .58988 .44441 .58731 .43879 .58218 Mtetra
.636 .756 .935 r
.43879 .58218 .44441 .58731 .45411 .58452 .44851 .57966 Mtetra
.647 .771 .939 r
.44851 .57966 .45411 .58452 .46385 .5815 .45827 .57685 Mtetra
.66 .784 .94 r
.45827 .57685 .46385 .5815 .47363 .57827 .46807 .57372 Mtetra
.669 .791 .939 r
.46807 .57372 .47363 .57827 .48344 .5749 .47791 .57036 Mtetra
.675 .793 .938 r
.47791 .57036 .48344 .5749 .49328 .57147 .48778 .56685 Mtetra
.677 .792 .935 r
.48778 .56685 .49328 .57147 .50316 .56803 .49769 .56328 Mtetra
.676 .787 .933 r
.49769 .56328 .50316 .56803 .51307 .56463 .50762 .55974 Mtetra
.673 .781 .931 r
.50762 .55974 .51307 .56463 .52302 .5613 .5176 .55626 Mtetra
.669 .775 .929 r
.5176 .55626 .52302 .5613 .533 .55803 .5276 .55287 Mtetra
.666 .77 .928 r
.5276 .55287 .533 .55803 .54301 .55483 .53764 .54955 Mtetra
.663 .766 .926 r
.53764 .54955 .54301 .55483 .55306 .55167 .54771 .5463 Mtetra
.661 .763 .925 r
.54771 .5463 .55306 .55167 .56315 .54854 .55782 .54311 Mtetra
.659 .76 .925 r
.55782 .54311 .56315 .54854 .57327 .54543 .56797 .53995 Mtetra
.657 .759 .924 r
.56797 .53995 .57327 .54543 .58343 .54233 .57816 .53681 Mtetra
.656 .758 .924 r
.57816 .53681 .58343 .54233 .59363 .53925 .58838 .53369 Mtetra
.655 .757 .924 r
.58838 .53369 .59363 .53925 .60386 .53616 .59864 .53058 Mtetra
.654 .757 .925 r
.59864 .53058 .60386 .53616 .61414 .53308 .60894 .52749 Mtetra
.653 .756 .925 r
.60894 .52749 .61414 .53308 .62445 .53 .61928 .52442 Mtetra
.652 .757 .927 r
.61928 .52442 .62445 .53 .6348 .52694 .62966 .52136 Mtetra
.649 .757 .928 r
.62966 .52136 .6348 .52694 .64519 .5239 .64008 .51835 Mtetra
.647 .758 .93 r
.64008 .51835 .64519 .5239 .65562 .52089 .65054 .51538 Mtetra
.643 .759 .933 r
.65054 .51538 .65562 .52089 .6661 .51793 .66105 .51249 Mtetra
.639 .761 .937 r
.66105 .51249 .6661 .51793 .67662 .51502 .6716 .50967 Mtetra
.633 .764 .941 r
.6716 .50967 .67662 .51502 .68718 .51219 .68219 .50695 Mtetra
.629 .767 .946 r
.68219 .50695 .68718 .51219 .69779 .50942 .69283 .50428 Mtetra
.626 .771 .95 r
.69283 .50428 .69779 .50942 .70844 .50669 .70352 .50165 Mtetra
.626 .776 .953 r
.70352 .50165 .70844 .50669 .71914 .50397 .71425 .49896 Mtetra
.633 .781 .952 r
.71425 .49896 .71914 .50397 .72987 .50117 .72502 .49611 Mtetra
.643 .783 .949 r
.72502 .49611 .72987 .50117 .74064 .49823 .73581 .49303 Mtetra
.658 .784 .941 r
.73581 .49303 .74064 .49823 .75144 .49507 .74663 .48961 Mtetra
.67 .779 .931 r
.74663 .48961 .75144 .49507 .76227 .49168 .75747 .48591 Mtetra
.68 .771 .919 r
.75747 .48591 .76227 .49168 .77312 .48806 .76832 .48194 Mtetra
.684 .761 .909 r
.76832 .48194 .77312 .48806 .784 .48427 .7792 .47784 Mtetra
.683 .75 .902 r
.7792 .47784 .784 .48427 .7949 .4804 .79013 .47374 Mtetra
.68 .742 .898 r
.79013 .47374 .7949 .4804 .80585 .47651 .80109 .46971 Mtetra
.674 .736 .897 r
.80109 .46971 .80585 .47651 .81684 .47269 .81211 .46585 Mtetra
.668 .733 .898 r
.81211 .46585 .81684 .47269 .82788 .46895 .82318 .46213 Mtetra
.663 .733 .901 r
.82318 .46213 .82788 .46895 .83897 .46532 .83431 .45857 Mtetra
.659 .734 .905 r
.83431 .45857 .83897 .46532 .85011 .46178 .84549 .45511 Mtetra
.656 .737 .909 r
.84549 .45511 .85011 .46178 .8613 .4583 .85672 .45172 Mtetra
.654 .74 .912 r
.85672 .45172 .8613 .4583 .87254 .45488 .868 .44837 Mtetra
.654 .743 .915 r
.868 .44837 .87254 .45488 .88383 .45147 .87932 .44501 Mtetra
.653 .745 .917 r
.87932 .44501 .88383 .45147 .89516 .44808 .89069 .44166 Mtetra
.653 .747 .919 r
.89069 .44166 .89516 .44808 .90654 .44469 .90211 .43829 Mtetra
.653 .749 .92 r
.90211 .43829 .90654 .44469 .91796 .44128 .91357 .43489 Mtetra
.659 .752 .919 r
.3005 .61354 .30643 .61871 .31568 .61584 .30977 .61064 Mtetra
.66 .752 .918 r
.30977 .61064 .31568 .61584 .32496 .61296 .31907 .60772 Mtetra
.661 .752 .918 r
.31907 .60772 .32496 .61296 .33428 .61006 .32841 .60477 Mtetra
.661 .751 .916 r
.32841 .60477 .33428 .61006 .34362 .60716 .33778 .6018 Mtetra
.662 .749 .915 r
.33778 .6018 .34362 .60716 .353 .60426 .34718 .59879 Mtetra
.661 .745 .912 r
.34718 .59879 .353 .60426 .36241 .6014 .35662 .5958 Mtetra
.66 .741 .91 r
.35662 .5958 .36241 .6014 .37185 .59861 .36608 .59283 Mtetra
.656 .734 .907 r
.36608 .59283 .37185 .59861 .38132 .59592 .37558 .58996 Mtetra
.649 .727 .905 r
.37558 .58996 .38132 .59592 .39082 .59338 .3851 .58725 Mtetra
.641 .719 .904 r
.3851 .58725 .39082 .59338 .40034 .59099 .39465 .58473 Mtetra
.63 .712 .905 r
.39465 .58473 .40034 .59099 .4099 .58876 .40422 .58248 Mtetra
.621 .709 .908 r
.40422 .58248 .4099 .58876 .41949 .5866 .41383 .58042 Mtetra
.613 .71 .914 r
.41383 .58042 .41949 .5866 .42912 .58446 .42347 .57852 Mtetra
.613 .719 .921 r
.42347 .57852 .42912 .58446 .43879 .58218 .43315 .57658 Mtetra
.619 .735 .929 r
.43315 .57658 .43879 .58218 .44851 .57966 .44288 .57446 Mtetra
.631 .754 .936 r
.44288 .57446 .44851 .57966 .45827 .57685 .45265 .57201 Mtetra
.648 .774 .94 r
.45265 .57201 .45827 .57685 .46807 .57372 .46247 .56914 Mtetra
.661 .789 .943 r
.46247 .56914 .46807 .57372 .47791 .57036 .47234 .56593 Mtetra
.673 .799 .942 r
.47234 .56593 .47791 .57036 .48778 .56685 .48223 .56242 Mtetra
.679 .801 .94 r
.48223 .56242 .48778 .56685 .49769 .56328 .49217 .55877 Mtetra
.68 .799 .938 r
.49217 .55877 .49769 .56328 .50762 .55974 .50213 .55509 Mtetra
.678 .794 .936 r
.50213 .55509 .50762 .55974 .5176 .55626 .51213 .55144 Mtetra
.674 .787 .934 r
.51213 .55144 .5176 .55626 .5276 .55287 .52216 .5479 Mtetra
.67 .781 .932 r
.52216 .5479 .5276 .55287 .53764 .54955 .53223 .54444 Mtetra
.666 .775 .931 r
.53223 .54444 .53764 .54955 .54771 .5463 .54233 .54108 Mtetra
.663 .77 .929 r
.54233 .54108 .54771 .5463 .55782 .54311 .55247 .53779 Mtetra
.66 .767 .928 r
.55247 .53779 .55782 .54311 .56797 .53995 .56264 .53456 Mtetra
.658 .764 .928 r
.56264 .53456 .56797 .53995 .57816 .53681 .57285 .53137 Mtetra
.657 .762 .928 r
.57285 .53137 .57816 .53681 .58838 .53369 .5831 .52822 Mtetra
.655 .761 .928 r
.5831 .52822 .58838 .53369 .59864 .53058 .59339 .52509 Mtetra
.653 .761 .928 r
.59339 .52509 .59864 .53058 .60894 .52749 .60371 .52199 Mtetra
.651 .761 .93 r
.60371 .52199 .60894 .52749 .61928 .52442 .61408 .51893 Mtetra
.649 .761 .931 r
.61408 .51893 .61928 .52442 .62966 .52136 .62449 .5159 Mtetra
.646 .762 .933 r
.62449 .5159 .62966 .52136 .64008 .51835 .63493 .51294 Mtetra
.642 .763 .937 r
.63493 .51294 .64008 .51835 .65054 .51538 .64543 .51005 Mtetra
.636 .765 .941 r
.64543 .51005 .65054 .51538 .66105 .51249 .65596 .50725 Mtetra
.63 .768 .946 r
.65596 .50725 .66105 .51249 .6716 .50967 .66655 .50455 Mtetra
.624 .771 .951 r
.66655 .50455 .6716 .50967 .68219 .50695 .67718 .50195 Mtetra
.62 .776 .955 r
.67718 .50195 .68219 .50695 .69283 .50428 .68786 .49939 Mtetra
.619 .781 .959 r
.68786 .49939 .69283 .50428 .70352 .50165 .69858 .49679 Mtetra
.625 .785 .959 r
.69858 .49679 .70352 .50165 .71425 .49896 .70934 .49406 Mtetra
.639 .789 .954 r
.70934 .49406 .71425 .49896 .72502 .49611 .72013 .49102 Mtetra
.656 .788 .945 r
.72013 .49102 .72502 .49611 .73581 .49303 .73094 .48763 Mtetra
.675 .783 .931 r
.73094 .48763 .73581 .49303 .74663 .48961 .74176 .4838 Mtetra
.687 .772 .917 r
.74176 .4838 .74663 .48961 .75747 .48591 .7526 .47965 Mtetra
.692 .759 .903 r
.7526 .47965 .75747 .48591 .76832 .48194 .76345 .47529 Mtetra
.692 .747 .893 r
.76345 .47529 .76832 .48194 .7792 .47784 .77435 .47088 Mtetra
.686 .735 .889 r
.77435 .47088 .7792 .47784 .79013 .47374 .78528 .46664 Mtetra
.679 .729 .888 r
.78528 .46664 .79013 .47374 .80109 .46971 .79628 .46259 Mtetra
.67 .726 .891 r
.79628 .46259 .80109 .46971 .81211 .46585 .80733 .45881 Mtetra
.663 .726 .896 r
.80733 .45881 .81211 .46585 .82318 .46213 .81845 .45523 Mtetra
.657 .729 .902 r
.81845 .45523 .82318 .46213 .83431 .45857 .82962 .45181 Mtetra
.653 .733 .908 r
.82962 .45181 .83431 .45857 .84549 .45511 .84084 .44849 Mtetra
.652 .738 .913 r
.84084 .44849 .84549 .45511 .85672 .45172 .85212 .4452 Mtetra
.651 .742 .916 r
.85212 .4452 .85672 .45172 .868 .44837 .86344 .44191 Mtetra
.651 .745 .918 r
.86344 .44191 .868 .44837 .87932 .44501 .8748 .43859 Mtetra
.652 .747 .92 r
.8748 .43859 .87932 .44501 .89069 .44166 .8862 .43524 Mtetra
.652 .749 .921 r
.8862 .43524 .89069 .44166 .90211 .43829 .89765 .43187 Mtetra
.653 .75 .921 r
.89765 .43187 .90211 .43829 .91357 .43489 .90915 .42846 Mtetra
.658 .752 .919 r
.29453 .60833 .3005 .61354 .30977 .61064 .30382 .60545 Mtetra
.659 .753 .92 r
.30382 .60545 .30977 .61064 .31907 .60772 .31314 .60253 Mtetra
.66 .755 .92 r
.31314 .60253 .31907 .60772 .32841 .60477 .3225 .59958 Mtetra
.662 .756 .92 r
.3225 .59958 .32841 .60477 .33778 .6018 .33189 .59656 Mtetra
.664 .755 .918 r
.33189 .59656 .33778 .6018 .34718 .59879 .34132 .59348 Mtetra
.666 .753 .916 r
.34132 .59348 .34718 .59879 .35662 .5958 .35078 .59035 Mtetra
.667 .75 .912 r
.35078 .59035 .35662 .5958 .36608 .59283 .36027 .58718 Mtetra
.665 .742 .908 r
.36027 .58718 .36608 .59283 .37558 .58996 .3698 .58405 Mtetra
.66 .733 .903 r
.3698 .58405 .37558 .58996 .3851 .58725 .37935 .58103 Mtetra
.651 .721 .899 r
.37935 .58103 .3851 .58725 .39465 .58473 .38893 .57824 Mtetra
.638 .708 .897 r
.38893 .57824 .39465 .58473 .40422 .58248 .39853 .57579 Mtetra
.624 .697 .897 r
.39853 .57579 .40422 .58248 .41383 .58042 .40815 .57367 Mtetra
.608 .69 .901 r
.40815 .57367 .41383 .58042 .42347 .57852 .4178 .57194 Mtetra
.6 .694 .908 r
.4178 .57194 .42347 .57852 .43315 .57658 .42749 .57034 Mtetra
.599 .705 .918 r
.42749 .57034 .43315 .57658 .44288 .57446 .43722 .56871 Mtetra
.608 .727 .93 r
.43722 .56871 .44288 .57446 .45265 .57201 .44701 .5668 Mtetra
.627 .755 .938 r
.44701 .5668 .45265 .57201 .46247 .56914 .45684 .56439 Mtetra
.646 .779 .945 r
.45684 .56439 .46247 .56914 .47234 .56593 .46672 .56151 Mtetra
.665 .799 .946 r
.46672 .56151 .47234 .56593 .48223 .56242 .47664 .55815 Mtetra
.676 .809 .946 r
.47664 .55815 .48223 .56242 .49217 .55877 .48661 .55451 Mtetra
.682 .811 .944 r
.48661 .55451 .49217 .55877 .50213 .55509 .4966 .55073 Mtetra
.683 .808 .942 r
.4966 .55073 .50213 .55509 .51213 .55144 .50663 .54693 Mtetra
.68 .802 .94 r
.50663 .54693 .51213 .55144 .52216 .5479 .51669 .5432 Mtetra
.675 .794 .938 r
.51669 .5432 .52216 .5479 .53223 .54444 .52678 .53958 Mtetra
.67 .787 .936 r
.52678 .53958 .53223 .54444 .54233 .54108 .53691 .53607 Mtetra
.666 .781 .935 r
.53691 .53607 .54233 .54108 .55247 .53779 .54707 .53266 Mtetra
.662 .776 .934 r
.54707 .53266 .55247 .53779 .56264 .53456 .55727 .52934 Mtetra
.659 .772 .933 r
.55727 .52934 .56264 .53456 .57285 .53137 .56751 .52609 Mtetra
.657 .77 .933 r
.56751 .52609 .57285 .53137 .5831 .52822 .57778 .52289 Mtetra
.654 .768 .933 r
.57778 .52289 .5831 .52822 .59339 .52509 .5881 .51974 Mtetra
.652 .767 .934 r
.5881 .51974 .59339 .52509 .60371 .52199 .59845 .51665 Mtetra
.649 .767 .935 r
.59845 .51665 .60371 .52199 .61408 .51893 .60885 .5136 Mtetra
.645 .768 .938 r
.60885 .5136 .61408 .51893 .62449 .5159 .61928 .51063 Mtetra
.64 .769 .941 r
.61928 .51063 .62449 .5159 .63493 .51294 .62976 .50774 Mtetra
.634 .771 .945 r
.62976 .50774 .63493 .51294 .64543 .51005 .64029 .50495 Mtetra
.627 .773 .951 r
.64029 .50495 .64543 .51005 .65596 .50725 .65086 .50229 Mtetra
.619 .777 .956 r
.65086 .50229 .65596 .50725 .66655 .50455 .66148 .49973 Mtetra
.613 .781 .962 r
.66148 .49973 .66655 .50455 .67718 .50195 .67215 .49725 Mtetra
.611 .786 .965 r
.67215 .49725 .67718 .50195 .68786 .49939 .68286 .49475 Mtetra
.617 .792 .966 r
.68286 .49475 .68786 .49939 .69858 .49679 .69361 .4921 Mtetra
.631 .796 .962 r
.69361 .4921 .69858 .49679 .70934 .49406 .7044 .48917 Mtetra
.655 .797 .95 r
.7044 .48917 .70934 .49406 .72013 .49102 .71519 .48575 Mtetra
.677 .789 .934 r
.71519 .48575 .72013 .49102 .73094 .48763 .726 .48184 Mtetra
.695 .777 .914 r
.726 .48184 .73094 .48763 .74176 .4838 .73682 .47743 Mtetra
.703 .759 .896 r
.73682 .47743 .74176 .4838 .7526 .47965 .74765 .47271 Mtetra
.701 .741 .883 r
.74765 .47271 .7526 .47965 .76345 .47529 .75851 .46796 Mtetra
.695 .728 .876 r
.75851 .46796 .76345 .47529 .77435 .47088 .76941 .46334 Mtetra
.682 .718 .876 r
.76941 .46334 .77435 .47088 .78528 .46664 .78038 .45911 Mtetra
.672 .714 .88 r
.78038 .45911 .78528 .46664 .79628 .46259 .79142 .45522 Mtetra
.661 .716 .889 r
.79142 .45522 .79628 .46259 .80733 .45881 .80252 .45168 Mtetra
.653 .721 .898 r
.80252 .45168 .80733 .45881 .81845 .45523 .81369 .44837 Mtetra
.649 .728 .907 r
.81369 .44837 .81845 .45523 .82962 .45181 .82491 .44518 Mtetra
.646 .736 .914 r
.82491 .44518 .82962 .45181 .84084 .44849 .83618 .44203 Mtetra
.647 .743 .919 r
.83618 .44203 .84084 .44849 .85212 .4452 .8475 .43883 Mtetra
.648 .748 .922 r
.8475 .43883 .85212 .4452 .86344 .44191 .85886 .43558 Mtetra
.65 .751 .923 r
.85886 .43558 .86344 .44191 .8748 .43859 .87025 .43226 Mtetra
.652 .752 .923 r
.87025 .43226 .8748 .43859 .8862 .43524 .88169 .42888 Mtetra
.653 .752 .923 r
.88169 .42888 .8862 .43524 .89765 .43187 .89317 .42544 Mtetra
.654 .752 .922 r
.89317 .42544 .89765 .43187 .90915 .42846 .90469 .42197 Mtetra
.655 .751 .921 r
.28853 .60308 .29453 .60833 .30382 .60545 .29783 .60026 Mtetra
.655 .754 .922 r
.29783 .60026 .30382 .60545 .31314 .60253 .30717 .5974 Mtetra
.657 .757 .924 r
.30717 .5974 .31314 .60253 .3225 .59958 .31654 .59449 Mtetra
.66 .76 .924 r
.31654 .59449 .3225 .59958 .33189 .59656 .32595 .5915 Mtetra
.664 .763 .924 r
.32595 .5915 .33189 .59656 .34132 .59348 .3354 .58842 Mtetra
.668 .764 .923 r
.3354 .58842 .34132 .59348 .35078 .59035 .34488 .58522 Mtetra
.672 .764 .919 r
.34488 .58522 .35078 .59035 .36027 .58718 .3544 .58189 Mtetra
.674 .759 .915 r
.3544 .58189 .36027 .58718 .3698 .58405 .36396 .57852 Mtetra
.674 .751 .909 r
.36396 .57852 .3698 .58405 .37935 .58103 .37355 .57513 Mtetra
.667 .737 .902 r
.37355 .57513 .37935 .58103 .38893 .57824 .38317 .57191 Mtetra
.654 .72 .896 r
.38317 .57191 .38893 .57824 .39853 .57579 .3928 .56901 Mtetra
.637 .7 .892 r
.3928 .56901 .39853 .57579 .40815 .57367 .40245 .56656 Mtetra
.614 .682 .891 r
.40245 .56656 .40815 .57367 .4178 .57194 .41212 .56469 Mtetra
.597 .672 .893 r
.41212 .56469 .4178 .57194 .42749 .57034 .42182 .56323 Mtetra
.583 .672 .9 r
.42182 .56323 .42749 .57034 .43722 .56871 .43156 .56205 Mtetra
.585 .688 .912 r
.43156 .56205 .43722 .56871 .44701 .5668 .44134 .56075 Mtetra
.6 .715 .925 r
.44134 .56075 .44701 .5668 .45684 .56439 .45118 .55902 Mtetra
.62 .749 .938 r
.45118 .55902 .45684 .56439 .46672 .56151 .46107 .55675 Mtetra
.647 .782 .946 r
.46107 .55675 .46672 .56151 .47664 .55815 .47101 .55381 Mtetra
.665 .804 .95 r
.47101 .55381 .47664 .55815 .48661 .55451 .481 .55041 Mtetra
.679 .818 .95 r
.481 .55041 .48661 .55451 .4966 .55073 .49102 .54666 Mtetra
.684 .822 .949 r
.49102 .54666 .4966 .55073 .50663 .54693 .50108 .54277 Mtetra
.683 .819 .948 r
.50108 .54277 .50663 .54693 .51669 .5432 .51117 .5389 Mtetra
.68 .813 .946 r
.51117 .5389 .51669 .5432 .52678 .53958 .52129 .5351 Mtetra
.675 .805 .945 r
.52129 .5351 .52678 .53958 .53691 .53607 .53145 .53143 Mtetra
.67 .798 .943 r
.53145 .53143 .53691 .53607 .54707 .53266 .54164 .52787 Mtetra
.665 .792 .942 r
.54164 .52787 .54707 .53266 .55727 .52934 .55187 .52444 Mtetra
.66 .787 .942 r
.55187 .52444 .55727 .52934 .56751 .52609 .56213 .5211 Mtetra
.656 .783 .941 r
.56213 .5211 .56751 .52609 .57778 .52289 .57243 .51786 Mtetra
.652 .781 .942 r
.57243 .51786 .57778 .52289 .5881 .51974 .58278 .51469 Mtetra
.648 .779 .943 r
.58278 .51469 .5881 .51974 .59845 .51665 .59316 .5116 Mtetra
.644 .779 .946 r
.59316 .5116 .59845 .51665 .60885 .5136 .60358 .5086 Mtetra
.638 .78 .949 r
.60358 .5086 .60885 .5136 .61928 .51063 .61405 .50569 Mtetra
.631 .781 .953 r
.61405 .50569 .61928 .51063 .62976 .50774 .62456 .50291 Mtetra
.623 .783 .959 r
.62456 .50291 .62976 .50774 .64029 .50495 .63512 .50025 Mtetra
.613 .786 .964 r
.63512 .50025 .64029 .50495 .65086 .50229 .64573 .49772 Mtetra
.606 .79 .969 r
.64573 .49772 .65086 .50229 .66148 .49973 .65639 .49527 Mtetra
.602 .795 .973 r
.65639 .49527 .66148 .49973 .67215 .49725 .66709 .49283 Mtetra
.608 .799 .973 r
.66709 .49283 .67215 .49725 .68286 .49475 .67783 .49025 Mtetra
.627 .804 .967 r
.67783 .49025 .68286 .49475 .69361 .4921 .6886 .48733 Mtetra
.653 .801 .954 r
.6886 .48733 .69361 .4921 .7044 .48917 .6994 .48393 Mtetra
.683 .793 .933 r
.6994 .48393 .7044 .48917 .71519 .48575 .71019 .47985 Mtetra
.703 .775 .908 r
.71019 .47985 .71519 .48575 .726 .48184 .72099 .4752 Mtetra
.712 .754 .885 r
.72099 .4752 .726 .48184 .73682 .47743 .73179 .4701 Mtetra
.712 .734 .869 r
.73179 .4701 .73682 .47743 .74765 .47271 .74261 .46488 Mtetra
.701 .716 .861 r
.74261 .46488 .74765 .47271 .75851 .46796 .75349 .45994 Mtetra
.688 .707 .862 r
.75349 .45994 .75851 .46796 .76941 .46334 .76443 .45541 Mtetra
.671 .704 .871 r
.76443 .45541 .76941 .46334 .78038 .45911 .77544 .45148 Mtetra
.658 .707 .884 r
.77544 .45148 .78038 .45911 .79142 .45522 .78654 .44801 Mtetra
.647 .716 .899 r
.78654 .44801 .79142 .45522 .80252 .45168 .79771 .44487 Mtetra
.64 .727 .912 r
.79771 .44487 .80252 .45168 .81369 .44837 .80893 .4419 Mtetra
.639 .739 .921 r
.80893 .4419 .81369 .44837 .82491 .44518 .82021 .43892 Mtetra
.639 .748 .927 r
.82021 .43892 .82491 .44518 .83618 .44203 .83153 .43588 Mtetra
.643 .755 .93 r
.83153 .43588 .83618 .44203 .8475 .43883 .84288 .43271 Mtetra
.647 .758 .93 r
.84288 .43271 .8475 .43883 .85886 .43558 .85427 .42943 Mtetra
.651 .759 .929 r
.85427 .42943 .85886 .43558 .87025 .43226 .86569 .42603 Mtetra
.654 .759 .927 r
.86569 .42603 .87025 .43226 .88169 .42888 .87716 .42255 Mtetra
.656 .757 .924 r
.87716 .42255 .88169 .42888 .89317 .42544 .88866 .41901 Mtetra
.657 .754 .922 r
.88866 .41901 .89317 .42544 .90469 .42197 .90021 .41544 Mtetra
.65 .75 .923 r
.28248 .59781 .28853 .60308 .29783 .60026 .29179 .59506 Mtetra
.65 .754 .925 r
.29179 .59506 .29783 .60026 .30717 .5974 .30114 .5923 Mtetra
.651 .758 .928 r
.30114 .5923 .30717 .5974 .31654 .59449 .31053 .5895 Mtetra
.654 .764 .93 r
.31053 .5895 .31654 .59449 .32595 .5915 .31995 .58661 Mtetra
.658 .769 .932 r
.31995 .58661 .32595 .5915 .3354 .58842 .32942 .58362 Mtetra
.664 .775 .932 r
.32942 .58362 .3354 .58842 .34488 .58522 .33892 .58047 Mtetra
.673 .78 .93 r
.33892 .58047 .34488 .58522 .3544 .58189 .34847 .57711 Mtetra
.68 .781 .926 r
.34847 .57711 .3544 .58189 .36396 .57852 .35806 .57356 Mtetra
.688 .776 .919 r
.35806 .57356 .36396 .57852 .37355 .57513 .36769 .5698 Mtetra
.686 .763 .91 r
.36769 .5698 .37355 .57513 .38317 .57191 .37734 .56606 Mtetra
.68 .744 .899 r
.37734 .56606 .38317 .57191 .3928 .56901 .38703 .56246 Mtetra
.661 .717 .889 r
.38703 .56246 .3928 .56901 .40245 .56656 .39672 .55933 Mtetra
.634 .687 .883 r
.39672 .55933 .40245 .56656 .41212 .56469 .40642 .55693 Mtetra
.607 .662 .878 r
.40642 .55693 .41212 .56469 .42182 .56323 .41614 .55524 Mtetra
.577 .644 .88 r
.41614 .55524 .42182 .56323 .43156 .56205 .42588 .55429 Mtetra
.566 .647 .889 r
.42588 .55429 .43156 .56205 .44134 .56075 .43567 .55356 Mtetra
.567 .665 .904 r
.43567 .55356 .44134 .56075 .45118 .55902 .4455 .55269 Mtetra
.584 .701 .923 r
.4455 .55269 .45118 .55902 .46107 .55675 .45539 .5513 Mtetra
.615 .746 .939 r
.45539 .5513 .46107 .55675 .47101 .55381 .46535 .5491 Mtetra
.641 .784 .95 r
.46535 .5491 .47101 .55381 .481 .55041 .47535 .54624 Mtetra
.665 .814 .955 r
.47535 .54624 .481 .55041 .49102 .54666 .4854 .54276 Mtetra
.678 .829 .956 r
.4854 .54276 .49102 .54666 .50108 .54277 .49549 .53895 Mtetra
.683 .834 .956 r
.49549 .53895 .50108 .54277 .51117 .5389 .50561 .53501 Mtetra
.682 .832 .955 r
.50561 .53501 .51117 .5389 .52129 .5351 .51576 .53107 Mtetra
.678 .826 .955 r
.51576 .53107 .52129 .5351 .53145 .53143 .52595 .52723 Mtetra
.673 .819 .953 r
.52595 .52723 .53145 .53143 .54164 .52787 .53617 .52352 Mtetra
.666 .812 .953 r
.53617 .52352 .54164 .52787 .55187 .52444 .54643 .51996 Mtetra
.661 .805 .952 r
.54643 .51996 .55187 .52444 .56213 .5211 .55672 .51653 Mtetra
.655 .801 .953 r
.55672 .51653 .56213 .5211 .57243 .51786 .56705 .51322 Mtetra
.649 .797 .954 r
.56705 .51322 .57243 .51786 .58278 .51469 .57742 .51003 Mtetra
.643 .796 .956 r
.57742 .51003 .58278 .51469 .59316 .5116 .58783 .50696 Mtetra
.636 .795 .959 r
.58783 .50696 .59316 .5116 .60358 .5086 .59829 .50401 Mtetra
.628 .795 .963 r
.59829 .50401 .60358 .5086 .61405 .50569 .60879 .5012 Mtetra
.618 .797 .968 r
.60879 .5012 .61405 .50569 .62456 .50291 .61934 .49853 Mtetra
.608 .799 .973 r
.61934 .49853 .62456 .50291 .63512 .50025 .62993 .49599 Mtetra
.598 .802 .978 r
.62993 .49599 .63512 .50025 .64573 .49772 .64058 .49357 Mtetra
.594 .806 .981 r
.64058 .49357 .64573 .49772 .65639 .49527 .65127 .49114 Mtetra
.601 .81 .98 r
.65127 .49114 .65639 .49527 .66709 .49283 .662 .48858 Mtetra
.621 .813 .974 r
.662 .48858 .66709 .49283 .67783 .49025 .67276 .48569 Mtetra
.655 .812 .958 r
.67276 .48569 .67783 .49025 .6886 .48733 .68354 .48218 Mtetra
.687 .799 .934 r
.68354 .48218 .6886 .48733 .6994 .48393 .69432 .47798 Mtetra
.714 .778 .902 r
.69432 .47798 .6994 .48393 .71019 .47985 .70509 .47295 Mtetra
.724 .75 .873 r
.70509 .47295 .71019 .47985 .72099 .4752 .71587 .46738 Mtetra
.721 .724 .853 r
.71587 .46738 .72099 .4752 .73179 .4701 .72666 .46165 Mtetra
.71 .705 .843 r
.72666 .46165 .73179 .4701 .74261 .46488 .73749 .45614 Mtetra
.69 .69 .845 r
.73749 .45614 .74261 .46488 .75349 .45994 .7484 .45139 Mtetra
.671 .688 .857 r
.7484 .45139 .75349 .45994 .76443 .45541 .7594 .44736 Mtetra
.651 .693 .876 r
.7594 .44736 .76443 .45541 .77544 .45148 .7705 .44408 Mtetra
.634 .706 .898 r
.7705 .44408 .77544 .45148 .78654 .44801 .78167 .44129 Mtetra
.626 .725 .918 r
.78167 .44129 .78654 .44801 .79771 .44487 .79291 .43864 Mtetra
.623 .742 .933 r
.79291 .43864 .79771 .44487 .80893 .4419 .8042 .43601 Mtetra
.629 .758 .94 r
.8042 .43601 .80893 .4419 .82021 .43892 .81552 .43317 Mtetra
.635 .767 .943 r
.81552 .43317 .82021 .43892 .83153 .43588 .82688 .43013 Mtetra
.644 .772 .941 r
.82688 .43013 .83153 .43588 .84288 .43271 .83826 .42686 Mtetra
.65 .772 .937 r
.83826 .42686 .84288 .43271 .85427 .42943 .84967 .42343 Mtetra
.655 .769 .933 r
.84967 .42343 .85427 .42943 .86569 .42603 .86111 .41988 Mtetra
.658 .765 .929 r
.86111 .41988 .86569 .42603 .87716 .42255 .8726 .41625 Mtetra
.66 .761 .925 r
.8726 .41625 .87716 .42255 .88866 .41901 .88412 .41256 Mtetra
.66 .757 .922 r
.88412 .41256 .88866 .41901 .90021 .41544 .89569 .40886 Mtetra
.647 .749 .924 r
.27639 .59249 .28248 .59781 .29179 .59506 .28572 .5898 Mtetra
.646 .752 .926 r
.28572 .5898 .29179 .59506 .30114 .5923 .29509 .58712 Mtetra
.646 .755 .929 r
.29509 .58712 .30114 .5923 .31053 .5895 .30448 .58443 Mtetra
.647 .761 .932 r
.30448 .58443 .31053 .5895 .31995 .58661 .31392 .58169 Mtetra
.649 .767 .935 r
.31392 .58169 .31995 .58661 .32942 .58362 .32339 .57888 Mtetra
.654 .776 .938 r
.32339 .57888 .32942 .58362 .33892 .58047 .33291 .57591 Mtetra
.663 .787 .94 r
.33291 .57591 .33892 .58047 .34847 .57711 .34247 .57272 Mtetra
.675 .797 .939 r
.34247 .57272 .34847 .57711 .35806 .57356 .35208 .56923 Mtetra
.691 .803 .934 r
.35208 .56923 .35806 .57356 .36769 .5698 .36174 .56536 Mtetra
.7 .801 .927 r
.36174 .56536 .36769 .5698 .37734 .56606 .37144 .56124 Mtetra
.706 .788 .915 r
.37144 .56124 .37734 .56606 .38703 .56246 .38117 .55694 Mtetra
.695 .761 .903 r
.38117 .55694 .38703 .56246 .39672 .55933 .39093 .55291 Mtetra
.671 .726 .89 r
.39093 .55291 .39672 .55933 .40642 .55693 .40068 .54948 Mtetra
.637 .684 .877 r
.40068 .54948 .40642 .55693 .41614 .55524 .41045 .54695 Mtetra
.594 .644 .87 r
.41045 .54695 .41614 .55524 .42588 .55429 .42021 .54559 Mtetra
.567 .622 .867 r
.42021 .54559 .42588 .55429 .43567 .55356 .43 .54495 Mtetra
.547 .616 .873 r
.43 .54495 .43567 .55356 .4455 .55269 .43982 .54475 Mtetra
.551 .637 .889 r
.43982 .54475 .4455 .55269 .45539 .5513 .44971 .54432 Mtetra
.575 .678 .91 r
.44971 .54432 .45539 .5513 .46535 .5491 .45966 .54319 Mtetra
.603 .727 .932 r
.45966 .54319 .46535 .5491 .47535 .54624 .46967 .54129 Mtetra
.637 .776 .947 r
.46967 .54129 .47535 .54624 .4854 .54276 .47974 .5385 Mtetra
.659 .81 .956 r
.47974 .5385 .4854 .54276 .49549 .53895 .48985 .53513 Mtetra
.672 .833 .961 r
.48985 .53513 .49549 .53895 .50561 .53501 .5 .53138 Mtetra
.677 .843 .963 r
.5 .53138 .50561 .53501 .51576 .53107 .51019 .52747 Mtetra
.675 .845 .964 r
.51019 .52747 .51576 .53107 .52595 .52723 .52041 .52357 Mtetra
.671 .842 .965 r
.52041 .52357 .52595 .52723 .53617 .52352 .53066 .51975 Mtetra
.664 .837 .966 r
.53066 .51975 .53617 .52352 .54643 .51996 .54095 .51608 Mtetra
.657 .831 .967 r
.54095 .51608 .54643 .51996 .55672 .51653 .55127 .51256 Mtetra
.65 .826 .968 r
.55127 .51256 .55672 .51653 .56705 .51322 .56163 .50919 Mtetra
.641 .822 .97 r
.56163 .50919 .56705 .51322 .57742 .51003 .57204 .50598 Mtetra
.632 .82 .972 r
.57204 .50598 .57742 .51003 .58783 .50696 .58248 .50293 Mtetra
.622 .818 .976 r
.58248 .50293 .58783 .50696 .59829 .50401 .59297 .50003 Mtetra
.612 .818 .979 r
.59297 .50003 .59829 .50401 .60879 .5012 .60351 .49729 Mtetra
.6 .817 .983 r
.60351 .49729 .60879 .5012 .61934 .49853 .61409 .49469 Mtetra
.592 .818 .986 r
.61409 .49469 .61934 .49853 .62993 .49599 .62472 .49217 Mtetra
.59 .819 .987 r
.62472 .49217 .62993 .49599 .64058 .49357 .63539 .48968 Mtetra
.6 .821 .984 r
.63539 .48968 .64058 .49357 .65127 .49114 .64611 .48702 Mtetra
.626 .821 .975 r
.64611 .48702 .65127 .49114 .662 .48858 .65685 .48397 Mtetra
.661 .812 .956 r
.65685 .48397 .662 .48858 .67276 .48569 .66762 .48034 Mtetra
.699 .795 .924 r
.66762 .48034 .67276 .48569 .68354 .48218 .67838 .4758 Mtetra
.721 .766 .888 r
.67838 .4758 .68354 .48218 .69432 .47798 .68914 .47046 Mtetra
.731 .735 .855 r
.68914 .47046 .69432 .47798 .70509 .47295 .69988 .4644 Mtetra
.727 .709 .833 r
.69988 .4644 .70509 .47295 .71587 .46738 .71064 .45809 Mtetra
.712 .687 .824 r
.71064 .45809 .71587 .46738 .72666 .46165 .72145 .45223 Mtetra
.694 .677 .829 r
.72145 .45223 .72666 .46165 .73749 .45614 .73232 .44709 Mtetra
.667 .674 .848 r
.73232 .44709 .73749 .45614 .7484 .45139 .74331 .44315 Mtetra
.642 .685 .875 r
.74331 .44315 .7484 .45139 .7594 .44736 .75441 .44014 Mtetra
.619 .705 .907 r
.75441 .44014 .7594 .44736 .7705 .44408 .7656 .43775 Mtetra
.601 .729 .934 r
.7656 .43775 .7705 .44408 .78167 .44129 .77686 .43563 Mtetra
.602 .756 .952 r
.77686 .43563 .78167 .44129 .79291 .43864 .78816 .43333 Mtetra
.609 .774 .959 r
.78816 .43333 .79291 .43864 .8042 .43601 .79949 .43077 Mtetra
.626 .785 .958 r
.79949 .43077 .8042 .43601 .81552 .43317 .81084 .42782 Mtetra
.64 .787 .952 r
.81084 .42782 .81552 .43317 .82688 .43013 .82221 .42456 Mtetra
.651 .784 .945 r
.82221 .42456 .82688 .43013 .83826 .42686 .8336 .42106 Mtetra
.658 .778 .937 r
.8336 .42106 .83826 .42686 .84967 .42343 .84503 .41739 Mtetra
.662 .771 .931 r
.84503 .41739 .84967 .42343 .86111 .41988 .85649 .41365 Mtetra
.663 .766 .926 r
.85649 .41365 .86111 .41988 .8726 .41625 .868 .40986 Mtetra
.664 .761 .923 r
.868 .40986 .8726 .41625 .88412 .41256 .87954 .40604 Mtetra
.663 .757 .92 r
.87954 .40604 .88412 .41256 .89569 .40886 .89113 .40224 Mtetra
.646 .749 .924 r
.27027 .58715 .27639 .59249 .28572 .5898 .27961 .58445 Mtetra
.644 .749 .926 r
.27961 .58445 .28572 .5898 .29509 .58712 .28899 .5818 Mtetra
.642 .75 .927 r
.28899 .5818 .29509 .58712 .30448 .58443 .29841 .57917 Mtetra
.64 .753 .93 r
.29841 .57917 .30448 .58443 .31392 .58169 .30785 .57656 Mtetra
.638 .758 .935 r
.30785 .57656 .31392 .58169 .32339 .57888 .31733 .57398 Mtetra
.639 .768 .941 r
.31733 .57398 .32339 .57888 .33291 .57591 .32685 .57132 Mtetra
.644 .782 .948 r
.32685 .57132 .33291 .57591 .34247 .57272 .33641 .56852 Mtetra
.656 .802 .953 r
.33641 .56852 .34247 .57272 .35208 .56923 .34603 .5654 Mtetra
.676 .822 .953 r
.34603 .5654 .35208 .56923 .36174 .56536 .3557 .56178 Mtetra
.699 .837 .949 r
.3557 .56178 .36174 .56536 .37144 .56124 .36543 .55763 Mtetra
.724 .839 .936 r
.36543 .55763 .37144 .56124 .38117 .55694 .37522 .55285 Mtetra
.73 .821 .921 r
.37522 .55285 .38117 .55694 .39093 .55291 .38503 .54788 Mtetra
.722 .786 .903 r
.38503 .54788 .39093 .55291 .40068 .54948 .39487 .54304 Mtetra
.689 .732 .883 r
.39487 .54304 .40068 .54948 .41045 .54695 .4047 .53904 Mtetra
.638 .673 .867 r
.4047 .53904 .41045 .54695 .42021 .54559 .41452 .53644 Mtetra
.593 .624 .852 r
.41452 .53644 .42021 .54559 .43 .54495 .42434 .53513 Mtetra
.547 .588 .846 r
.42434 .53513 .43 .54495 .43982 .54475 .43416 .53509 Mtetra
.531 .584 .853 r
.43416 .53509 .43982 .54475 .44971 .54432 .44404 .53542 Mtetra
.534 .605 .87 r
.44404 .53542 .44971 .54432 .45966 .54319 .45397 .53552 Mtetra
.555 .649 .898 r
.45397 .53552 .45966 .54319 .46967 .54129 .46397 .53493 Mtetra
.593 .709 .924 r
.46397 .53493 .46967 .54129 .47974 .5385 .47404 .53328 Mtetra
.623 .763 .946 r
.47404 .53328 .47974 .5385 .48985 .53513 .48417 .53081 Mtetra
.649 .808 .959 r
.48417 .53081 .48985 .53513 .5 .53138 .49435 .52761 Mtetra
.662 .835 .966 r
.49435 .52761 .5 .53138 .51019 .52747 .50456 .52401 Mtetra
.666 .85 .97 r
.50456 .52401 .51019 .52747 .52041 .52357 .51482 .52024 Mtetra
.664 .856 .973 r
.51482 .52024 .52041 .52357 .53066 .51975 .5251 .51643 Mtetra
.658 .856 .975 r
.5251 .51643 .53066 .51975 .54095 .51608 .53542 .51272 Mtetra
.65 .853 .978 r
.53542 .51272 .54095 .51608 .55127 .51256 .54578 .50915 Mtetra
.64 .849 .98 r
.54578 .50915 .55127 .51256 .56163 .50919 .55618 .50574 Mtetra
.63 .845 .982 r
.55618 .50574 .56163 .50919 .57204 .50598 .56661 .50251 Mtetra
.619 .842 .985 r
.56661 .50251 .57204 .50598 .58248 .50293 .57709 .49946 Mtetra
.607 .839 .988 r
.57709 .49946 .58248 .50293 .59297 .50003 .58762 .49658 Mtetra
.597 .837 .99 r
.58762 .49658 .59297 .50003 .60351 .49729 .59819 .49383 Mtetra
.589 .835 .991 r
.59819 .49383 .60351 .49729 .61409 .49469 .6088 .49117 Mtetra
.591 .834 .991 r
.6088 .49117 .61409 .49469 .62472 .49217 .61946 .4885 Mtetra
.606 .833 .986 r
.61946 .4885 .62472 .49217 .63539 .48968 .63016 .48564 Mtetra
.635 .828 .975 r
.63016 .48564 .63539 .48968 .64611 .48702 .64089 .48238 Mtetra
.676 .816 .95 r
.64089 .48238 .64611 .48702 .65685 .48397 .65163 .47839 Mtetra
.709 .789 .914 r
.65163 .47839 .65685 .48397 .66762 .48034 .66238 .47354 Mtetra
.733 .757 .871 r
.66238 .47354 .66762 .48034 .67838 .4758 .67311 .46762 Mtetra
.738 .721 .836 r
.67311 .46762 .67838 .4758 .68914 .47046 .68382 .46098 Mtetra
.731 .69 .811 r
.68382 .46098 .68914 .47046 .69988 .4644 .69455 .45409 Mtetra
.717 .669 .802 r
.69455 .45409 .69988 .4644 .71064 .45809 .70532 .44757 Mtetra
.689 .653 .809 r
.70532 .44757 .71064 .45809 .72145 .45223 .71618 .44234 Mtetra
.662 .654 .832 r
.71618 .44234 .72145 .45223 .73232 .44709 .72716 .43842 Mtetra
.624 .666 .87 r
.72716 .43842 .73232 .44709 .74331 .44315 .73827 .43595 Mtetra
.586 .692 .915 r
.73827 .43595 .74331 .44315 .75441 .44014 .74949 .43434 Mtetra
.563 .734 .956 r
.74949 .43434 .75441 .44014 .7656 .43775 .76077 .43287 Mtetra
.552 .768 .978 r
.76077 .43287 .7656 .43775 .77686 .43563 .77211 .43121 Mtetra
.578 .8 .984 r
.77211 .43121 .77686 .43563 .78816 .43333 .78344 .4289 Mtetra
.607 .813 .979 r
.78344 .4289 .78816 .43333 .79949 .43077 .79479 .42604 Mtetra
.637 .812 .967 r
.79479 .42604 .79949 .43077 .81084 .42782 .80614 .42267 Mtetra
.657 .803 .953 r
.80614 .42267 .81084 .42782 .82221 .42456 .81751 .41896 Mtetra
.665 .789 .941 r
.81751 .41896 .82221 .42456 .8336 .42106 .82891 .41509 Mtetra
.669 .778 .931 r
.82891 .41509 .8336 .42106 .84503 .41739 .84034 .41114 Mtetra
.668 .768 .925 r
.84034 .41114 .84503 .41739 .85649 .41365 .85182 .40721 Mtetra
.667 .762 .921 r
.85182 .40721 .85649 .41365 .868 .40986 .86335 .4033 Mtetra
.666 .758 .919 r
.86335 .4033 .868 .40986 .87954 .40604 .87492 .39941 Mtetra
.664 .755 .918 r
.87492 .39941 .87954 .40604 .89113 .40224 .88655 .39556 Mtetra
.65 .75 .923 r
.2641 .58177 .27027 .58715 .27961 .58445 .27347 .57897 Mtetra
.648 .746 .921 r
.27347 .57897 .27961 .58445 .28899 .5818 .28288 .57621 Mtetra
.645 .743 .92 r
.28288 .57621 .28899 .5818 .29841 .57917 .29231 .57352 Mtetra
.641 .74 .921 r
.29231 .57352 .29841 .57917 .30785 .57656 .30178 .57092 Mtetra
.634 .739 .924 r
.30178 .57092 .30785 .57656 .31733 .57398 .31127 .56846 Mtetra
.63 .743 .929 r
.31127 .56846 .31733 .57398 .32685 .57132 .32079 .56605 Mtetra
.626 .752 .937 r
.32079 .56605 .32685 .57132 .33641 .56852 .33035 .56368 Mtetra
.631 .771 .947 r
.33035 .56368 .33641 .56852 .34603 .5654 .33995 .56113 Mtetra
.644 .798 .957 r
.33995 .56113 .34603 .5654 .3557 .56178 .34962 .55821 Mtetra
.669 .834 .962 r
.34962 .55821 .3557 .56178 .36543 .55763 .35934 .55465 Mtetra
.708 .865 .956 r
.35934 .55465 .36543 .55763 .37522 .55285 .36915 .55016 Mtetra
.737 .88 .946 r
.36915 .55016 .37522 .55285 .38503 .54788 .37901 .54494 Mtetra
.762 .872 .928 r
.37901 .54494 .38503 .54788 .39487 .54304 .38892 .53905 Mtetra
.75 .83 .914 r
.38892 .53905 .39487 .54304 .4047 .53904 .39884 .53345 Mtetra
.712 .767 .896 r
.39884 .53345 .4047 .53904 .41452 .53644 .40875 .52882 Mtetra
.655 .689 .869 r
.40875 .52882 .41452 .53644 .42434 .53513 .41864 .52569 Mtetra
.588 .616 .848 r
.41864 .52569 .42434 .53513 .43416 .53509 .4285 .52451 Mtetra
.548 .573 .832 r
.4285 .52451 .43416 .53509 .44404 .53542 .43839 .52452 Mtetra
.523 .554 .829 r
.43839 .52452 .44404 .53542 .45397 .53552 .44831 .52524 Mtetra
.525 .569 .842 r
.44831 .52524 .45397 .53552 .46397 .53493 .45829 .5258 Mtetra
.549 .608 .865 r
.45829 .5258 .46397 .53493 .47404 .53328 .46835 .52557 Mtetra
.576 .66 .894 r
.46835 .52557 .47404 .53328 .48417 .53081 .47848 .52447 Mtetra
.611 .719 .922 r
.47848 .52447 .48417 .53081 .49435 .52761 .48866 .52238 Mtetra
.634 .768 .944 r
.48866 .52238 .49435 .52761 .50456 .52401 .4989 .51962 Mtetra
.649 .807 .959 r
.4989 .51962 .50456 .52401 .51482 .52024 .50918 .51638 Mtetra
.653 .832 .969 r
.50918 .51638 .51482 .52024 .5251 .51643 .5195 .51292 Mtetra
.65 .847 .976 r
.5195 .51292 .5251 .51643 .53542 .51272 .52985 .50939 Mtetra
.643 .853 .98 r
.52985 .50939 .53542 .51272 .54578 .50915 .54025 .5059 Mtetra
.634 .855 .984 r
.54025 .5059 .54578 .50915 .55618 .50574 .55068 .50251 Mtetra
.624 .854 .986 r
.55068 .50251 .55618 .50574 .56661 .50251 .56115 .49926 Mtetra
.615 .851 .988 r
.56115 .49926 .56661 .50251 .57709 .49946 .57166 .49615 Mtetra
.608 .847 .989 r
.57166 .49615 .57709 .49946 .58762 .49658 .58222 .49314 Mtetra
.608 .843 .988 r
.58222 .49314 .58762 .49658 .59819 .49383 .59282 .49017 Mtetra
.616 .837 .984 r
.59282 .49017 .59819 .49383 .6088 .49117 .60346 .48714 Mtetra
.636 .828 .974 r
.60346 .48714 .6088 .49117 .61946 .4885 .61414 .48387 Mtetra
.666 .813 .954 r
.61414 .48387 .61946 .4885 .63016 .48564 .62484 .48012 Mtetra
.695 .787 .922 r
.62484 .48012 .63016 .48564 .64089 .48238 .63556 .47569 Mtetra
.721 .756 .88 r
.63556 .47569 .64089 .48238 .65163 .47839 .64628 .47026 Mtetra
.732 .72 .84 r
.64628 .47026 .65163 .47839 .66238 .47354 .65699 .46392 Mtetra
.734 .688 .807 r
.65699 .46392 .66238 .47354 .67311 .46762 .66769 .45678 Mtetra
.727 .664 .788 r
.66769 .45678 .67311 .46762 .68382 .46098 .67839 .44945 Mtetra
.708 .645 .784 r
.67839 .44945 .68382 .46098 .69455 .45409 .68915 .44284 Mtetra
.688 .64 .797 r
.68915 .44284 .69455 .45409 .70532 .44757 .69999 .43742 Mtetra
.648 .643 .831 r
.69999 .43742 .70532 .44757 .71618 .44234 .71098 .434 Mtetra
.602 .665 .884 r
.71098 .434 .71618 .44234 .72716 .43842 .7221 .43213 Mtetra
.539 .704 .946 r
.7221 .43213 .72716 .43842 .73827 .43595 .73335 .43126 Mtetra
.476 .741 .986 r
.73335 .43126 .73827 .43595 .74949 .43434 .74467 .43069 Mtetra
.479 .789 .999 r
.74467 .43069 .74949 .43434 .76077 .43287 .75602 .42944 Mtetra
.522 .821 .999 r
.75602 .42944 .76077 .43287 .77211 .43121 .76736 .42744 Mtetra
.596 .838 .99 r
.76736 .42744 .77211 .43121 .78344 .4289 .77869 .42448 Mtetra
.645 .829 .971 r
.77869 .42448 .78344 .4289 .79479 .42604 .79001 .42085 Mtetra
.669 .807 .949 r
.79001 .42085 .79479 .42604 .80614 .42267 .80135 .41684 Mtetra
.679 .786 .931 r
.80135 .41684 .80614 .42267 .81751 .41896 .81271 .41262 Mtetra
.677 .768 .919 r
.81271 .41262 .81751 .41896 .82891 .41509 .82411 .40845 Mtetra
.674 .757 .913 r
.82411 .40845 .82891 .41509 .84034 .41114 .83557 .40433 Mtetra
.669 .75 .911 r
.83557 .40433 .84034 .41114 .85182 .40721 .84708 .40035 Mtetra
.666 .748 .912 r
.84708 .40035 .85182 .40721 .86335 .4033 .85864 .39646 Mtetra
.663 .748 .914 r
.85864 .39646 .86335 .4033 .87492 .39941 .87026 .39263 Mtetra
.661 .75 .917 r
.87026 .39263 .87492 .39941 .88655 .39556 .88193 .38884 Mtetra
.658 .752 .919 r
.25789 .57635 .2641 .58177 .27347 .57897 .2673 .57334 Mtetra
.657 .745 .915 r
.2673 .57334 .27347 .57897 .28288 .57621 .27674 .57036 Mtetra
.654 .737 .911 r
.27674 .57036 .28288 .57621 .29231 .57352 .28621 .56745 Mtetra
.648 .728 .908 r
.28621 .56745 .29231 .57352 .30178 .57092 .2957 .56469 Mtetra
.639 .721 .907 r
.2957 .56469 .30178 .57092 .31127 .56846 .30521 .56213 Mtetra
.629 .715 .909 r
.30521 .56213 .31127 .56846 .32079 .56605 .31474 .5598 Mtetra
.615 .714 .916 r
.31474 .5598 .32079 .56605 .33035 .56368 .3243 .55776 Mtetra
.607 .724 .928 r
.3243 .55776 .33035 .56368 .33995 .56113 .33389 .55583 Mtetra
.6 .746 .946 r
.33389 .55583 .33995 .56113 .34962 .55821 .34352 .55392 Mtetra
.613 .791 .967 r
.34352 .55392 .34962 .55821 .35934 .55465 .35321 .55153 Mtetra
.644 .849 .979 r
.35321 .55153 .35934 .55465 .36915 .55016 .36299 .54826 Mtetra
.688 .908 .972 r
.36299 .54826 .36915 .55016 .37901 .54494 .37285 .54377 Mtetra
.754 .94 .945 r
.37285 .54377 .37901 .54494 .38892 .53905 .38281 .53771 Mtetra
.785 .934 .929 r
.38281 .53771 .38892 .53905 .39884 .53345 .39282 .5309 Mtetra
.795 .889 .912 r
.39282 .5309 .39884 .53345 .40875 .52882 .40285 .52389 Mtetra
.751 .799 .891 r
.40285 .52389 .40875 .52882 .41864 .52569 .41285 .51804 Mtetra
.673 .696 .863 r
.41285 .51804 .41864 .52569 .4285 .52451 .42281 .51431 Mtetra
.606 .61 .829 r
.42281 .51431 .4285 .52451 .43839 .52452 .43274 .51257 Mtetra
.544 .547 .808 r
.43274 .51257 .43839 .52452 .44831 .52524 .44268 .5128 Mtetra
.52 .527 .803 r
.44268 .5128 .44831 .52524 .45829 .5258 .45265 .51382 Mtetra
.517 .533 .812 r
.45265 .51382 .45829 .5258 .46835 .52557 .46268 .51485 Mtetra
.531 .565 .835 r
.46268 .51485 .46835 .52557 .47848 .52447 .47279 .5153 Mtetra
.561 .615 .864 r
.47279 .5153 .47848 .52447 .48866 .52238 .48297 .51472 Mtetra
.588 .67 .895 r
.48297 .51472 .48866 .52238 .4989 .51962 .49321 .51328 Mtetra
.616 .724 .923 r
.49321 .51328 .4989 .51962 .50918 .51638 .50351 .51103 Mtetra
.632 .766 .944 r
.50351 .51103 .50918 .51638 .5195 .51292 .51385 .50828 Mtetra
.64 .798 .958 r
.51385 .50828 .5195 .51292 .52985 .50939 .52424 .5052 Mtetra
.642 .818 .968 r
.52424 .5052 .52985 .50939 .54025 .5059 .53466 .50197 Mtetra
.639 .829 .974 r
.53466 .50197 .54025 .5059 .55068 .50251 .54513 .4987 Mtetra
.636 .834 .977 r
.54513 .4987 .55068 .50251 .56115 .49926 .55563 .49543 Mtetra
.635 .834 .977 r
.55563 .49543 .56115 .49926 .57166 .49615 .56618 .49216 Mtetra
.639 .829 .974 r
.56618 .49216 .57166 .49615 .58222 .49314 .57676 .48884 Mtetra
.651 .821 .965 r
.57676 .48884 .58222 .49314 .59282 .49017 .58738 .48538 Mtetra
.669 .807 .949 r
.58738 .48538 .59282 .49017 .60346 .48714 .59804 .48159 Mtetra
.691 .785 .922 r
.59804 .48159 .60346 .48714 .61414 .48387 .60872 .47728 Mtetra
.713 .756 .886 r
.60872 .47728 .61414 .48387 .62484 .48012 .61941 .47215 Mtetra
.726 .722 .846 r
.61941 .47215 .62484 .48012 .63556 .47569 .63011 .46613 Mtetra
.733 .689 .808 r
.63011 .46613 .63556 .47569 .64628 .47026 .64079 .45907 Mtetra
.729 .659 .78 r
.64079 .45907 .64628 .47026 .65699 .46392 .65146 .4514 Mtetra
.718 .635 .764 r
.65146 .4514 .65699 .46392 .66769 .45678 .66215 .44373 Mtetra
.702 .621 .763 r
.66215 .44373 .66769 .45678 .67839 .44945 .67289 .43684 Mtetra
.669 .611 .781 r
.67289 .43684 .67839 .44945 .68915 .44284 .68375 .43196 Mtetra
.631 .621 .822 r
.68375 .43196 .68915 .44284 .69999 .43742 .69474 .42911 Mtetra
.555 .644 .893 r
.69474 .42911 .69999 .43742 .71098 .434 .70591 .42844 Mtetra
.434 .682 .968 r
.70591 .42844 .71098 .434 .7221 .43213 .7172 .42896 Mtetra
.308 .718 .976 r
.7172 .42896 .7221 .43213 .73335 .43126 .72856 .42929 Mtetra
.273 .743 .943 r
.72856 .42929 .73335 .43126 .74467 .43069 .73994 .42887 Mtetra
.42 .834 .97 r
.73994 .42887 .74467 .43069 .75602 .42944 .75127 .42682 Mtetra
.573 .878 .993 r
.75127 .42682 .75602 .42944 .76736 .42744 .76257 .42352 Mtetra
.665 .858 .973 r
.76257 .42352 .76736 .42744 .77869 .42448 .77384 .4193 Mtetra
.696 .817 .94 r
.77384 .4193 .77869 .42448 .79001 .42085 .78512 .41458 Mtetra
.696 .777 .914 r
.78512 .41458 .79001 .42085 .80135 .41684 .79643 .40987 Mtetra
.69 .752 .899 r
.79643 .40987 .80135 .41684 .81271 .41262 .80779 .40526 Mtetra
.679 .736 .894 r
.80779 .40526 .81271 .41262 .82411 .40845 .81921 .40096 Mtetra
.671 .73 .894 r
.81921 .40096 .82411 .40845 .83557 .40433 .83071 .39689 Mtetra
.664 .729 .898 r
.83071 .39689 .83557 .40433 .84708 .40035 .84226 .39303 Mtetra
.659 .732 .904 r
.84226 .39303 .84708 .40035 .85864 .39646 .85388 .38932 Mtetra
.655 .737 .91 r
.85388 .38932 .85864 .39646 .87026 .39263 .86555 .38568 Mtetra
.654 .744 .916 r
.86555 .38568 .87026 .39263 .88193 .38884 .87727 .38207 Mtetra
.666 .754 .916 r
.25164 .57089 .25789 .57635 .2673 .57334 .26109 .56767 Mtetra
.667 .747 .91 r
.26109 .56767 .2673 .57334 .27674 .57036 .27056 .56442 Mtetra
.665 .738 .905 r
.27056 .56442 .27674 .57036 .28621 .56745 .28007 .56121 Mtetra
.66 .727 .899 r
.28007 .56121 .28621 .56745 .2957 .56469 .2896 .55812 Mtetra
.652 .715 .894 r
.2896 .55812 .2957 .56469 .30521 .56213 .29915 .5552 Mtetra
.64 .701 .89 r
.29915 .5552 .30521 .56213 .31474 .5598 .30872 .55258 Mtetra
.623 .687 .889 r
.30872 .55258 .31474 .5598 .3243 .55776 .3183 .55039 Mtetra
.607 .677 .891 r
.3183 .55039 .3243 .55776 .33389 .55583 .32789 .5486 Mtetra
.584 .674 .901 r
.32789 .5486 .33389 .55583 .34352 .55392 .3375 .54729 Mtetra
.578 .692 .919 r
.3375 .54729 .34352 .55392 .35321 .55153 .34716 .546 Mtetra
.581 .733 .947 r
.34716 .546 .35321 .55153 .36299 .54826 .35687 .54443 Mtetra
.617 .815 .976 r
.35687 .54443 .36299 .54826 .37285 .54377 .36668 .54178 Mtetra
.684 .905 .974 r
.36668 .54178 .37285 .54377 .38281 .53771 .3766 .53736 Mtetra
.73 .964 .939 r
.3766 .53736 .38281 .53771 .39282 .5309 .38662 .53127 Mtetra
.791 .983 .9 r
.38662 .53127 .39282 .5309 .40285 .52389 .39673 .52346 Mtetra
.811 .963 .907 r
.39673 .52346 .40285 .52389 .41285 .51804 .40685 .51556 Mtetra
.792 .896 .917 r
.40685 .51556 .41285 .51804 .42281 .51431 .41694 .50864 Mtetra
.721 .772 .892 r
.41694 .50864 .42281 .51431 .43274 .51257 .42699 .50362 Mtetra
.627 .649 .852 r
.42699 .50362 .43274 .51257 .44268 .5128 .437 .50121 Mtetra
.571 .569 .812 r
.437 .50121 .44268 .5128 .45265 .51382 .44701 .50056 Mtetra
.535 .523 .789 r
.44701 .50056 .45265 .51382 .46268 .51485 .45705 .50121 Mtetra
.528 .514 .785 r
.45705 .50121 .46268 .51485 .47279 .5153 .46714 .50213 Mtetra
.538 .528 .792 r
.46714 .50213 .47279 .5153 .48297 .51472 .4773 .50265 Mtetra
.555 .555 .808 r
.4773 .50265 .48297 .51472 .49321 .51328 .48753 .50251 Mtetra
.58 .592 .829 r
.48753 .50251 .49321 .51328 .50351 .51103 .49783 .50149 Mtetra
.601 .628 .85 r
.49783 .50149 .50351 .51103 .51385 .50828 .50818 .49979 Mtetra
.621 .663 .869 r
.50818 .49979 .51385 .50828 .52424 .5052 .51858 .49748 Mtetra
.635 .691 .884 r
.51858 .49748 .52424 .5052 .53466 .50197 .52903 .49476 Mtetra
.646 .711 .894 r
.52903 .49476 .53466 .50197 .54513 .4987 .53952 .49172 Mtetra
.655 .722 .898 r
.53952 .49172 .54513 .4987 .55563 .49543 .55004 .48842 Mtetra
.664 .725 .895 r
.55004 .48842 .55563 .49543 .56618 .49216 .56061 .48487 Mtetra
.673 .72 .884 r
.56061 .48487 .56618 .49216 .57676 .48884 .57121 .481 Mtetra
.683 .709 .867 r
.57121 .481 .57676 .48884 .58738 .48538 .58184 .47671 Mtetra
.694 .692 .844 r
.58184 .47671 .58738 .48538 .59804 .48159 .59249 .47181 Mtetra
.703 .672 .817 r
.59249 .47181 .59804 .48159 .60872 .47728 .60316 .4662 Mtetra
.71 .652 .79 r
.60316 .4662 .60872 .47728 .61941 .47215 .61383 .4597 Mtetra
.711 .632 .768 r
.61383 .4597 .61941 .47215 .63011 .46613 .6245 .45253 Mtetra
.709 .617 .753 r
.6245 .45253 .63011 .46613 .64079 .45907 .63518 .44492 Mtetra
.701 .607 .749 r
.63518 .44492 .64079 .45907 .65146 .4514 .64587 .43758 Mtetra
.682 .602 .759 r
.64587 .43758 .65146 .4514 .66215 .44373 .65664 .43154 Mtetra
.658 .612 .791 r
.65664 .43154 .66215 .44373 .67289 .43684 .66751 .4273 Mtetra
.594 .631 .858 r
.66751 .4273 .67289 .43684 .68375 .43196 .67854 .42572 Mtetra
.465 .671 .953 r
.67854 .42572 .68375 .43196 .69474 .42911 .68973 .42609 Mtetra
.183 .646 .938 r
.68973 .42609 .69474 .42911 .70591 .42844 .70105 .42748 Mtetra
0 .542 .757 r
.70105 .42748 .70591 .42844 .7172 .42896 .71243 .42878 Mtetra
.071 .633 .758 r
.71243 .42878 .7172 .42896 .72856 .42929 .72379 .42834 Mtetra
.348 .815 .915 r
.72379 .42834 .72856 .42929 .73994 .42887 .7351 .42618 Mtetra
.62 .894 .988 r
.7351 .42618 .73994 .42887 .75127 .42682 .74635 .4222 Mtetra
.71 .843 .946 r
.74635 .4222 .75127 .42682 .76257 .42352 .75756 .41709 Mtetra
.717 .778 .901 r
.75756 .41709 .76257 .42352 .77384 .4193 .76877 .41169 Mtetra
.71 .74 .874 r
.76877 .41169 .77384 .4193 .78512 .41458 .78003 .40629 Mtetra
.693 .715 .866 r
.78003 .40629 .78512 .41458 .79643 .40987 .79135 .40138 Mtetra
.68 .705 .866 r
.79135 .40138 .79643 .40987 .80779 .40526 .80275 .39689 Mtetra
.667 .703 .874 r
.80275 .39689 .80779 .40526 .81921 .40096 .81423 .39284 Mtetra
.658 .707 .883 r
.81423 .39284 .81921 .40096 .83071 .39689 .82578 .38909 Mtetra
.653 .715 .894 r
.82578 .38909 .83071 .39689 .84226 .39303 .8374 .38553 Mtetra
.648 .723 .903 r
.8374 .38553 .84226 .39303 .85388 .38932 .84907 .38208 Mtetra
.646 .732 .911 r
.84907 .38208 .85388 .38932 .86555 .38568 .86081 .37868 Mtetra
.646 .74 .918 r
.86081 .37868 .86555 .38568 .87727 .38207 .87259 .37524 Mtetra
.672 .755 .913 r
.24535 .5654 .25164 .57089 .26109 .56767 .25483 .56202 Mtetra
.675 .751 .908 r
.25483 .56202 .26109 .56767 .27056 .56442 .26434 .55855 Mtetra
.675 .744 .903 r
.26434 .55855 .27056 .56442 .28007 .56121 .27389 .55504 Mtetra
.674 .735 .896 r
.27389 .55504 .28007 .56121 .2896 .55812 .28347 .55154 Mtetra
.672 .722 .887 r
.28347 .55154 .2896 .55812 .29915 .5552 .29307 .54807 Mtetra
.662 .703 .877 r
.29307 .54807 .29915 .5552 .30872 .55258 .3027 .54481 Mtetra
.648 .681 .868 r
.3027 .54481 .30872 .55258 .3183 .55039 .31233 .54192 Mtetra
.626 .656 .859 r
.31233 .54192 .3183 .55039 .32789 .5486 .32197 .53962 Mtetra
.595 .631 .857 r
.32197 .53962 .32789 .5486 .3375 .54729 .33159 .53816 Mtetra
.567 .616 .86 r
.33159 .53816 .3375 .54729 .34716 .546 .34122 .53743 Mtetra
.53 .613 .881 r
.34122 .53743 .34716 .546 .35687 .54443 .35086 .53745 Mtetra
.522 .66 .922 r
.35086 .53745 .35687 .54443 .36668 .54178 .36057 .53723 Mtetra
.533 .759 .98 r
.36057 .53723 .36668 .54178 .3766 .53736 .37037 .53604 Mtetra
.568 .9 .982 r
.37037 .53604 .3766 .53736 .38662 .53127 .38031 .53276 Mtetra
.634 .964 .861 r
.38031 .53276 .38662 .53127 .39673 .52346 .39041 .5265 Mtetra
.664 .964 .768 r
.39041 .5265 .39673 .52346 .40685 .51556 .4006 .51824 Mtetra
.773 .995 .798 r
.4006 .51824 .40685 .51556 .41694 .50864 .41084 .5086 Mtetra
.835 .972 .885 r
.41084 .5086 .41694 .50864 .42699 .50362 .42106 .49969 Mtetra
.781 .843 .899 r
.42106 .49969 .42699 .50362 .437 .50121 .43122 .49292 Mtetra
.687 .689 .846 r
.43122 .49292 .437 .50121 .44701 .50056 .44133 .48853 Mtetra
.602 .578 .8 r
.44133 .48853 .44701 .50056 .45705 .50121 .45142 .48679 Mtetra
.562 .524 .771 r
.45142 .48679 .45705 .50121 .46714 .50213 .46152 .48654 Mtetra
.543 .5 .758 r
.46152 .48654 .46714 .50213 .4773 .50265 .47167 .48708 Mtetra
.543 .501 .759 r
.47167 .48708 .4773 .50265 .48753 .50251 .48188 .48762 Mtetra
.556 .516 .767 r
.48188 .48762 .48753 .50251 .49783 .50149 .49216 .48761 Mtetra
.572 .538 .779 r
.49216 .48761 .49783 .50149 .50818 .49979 .50251 .48695 Mtetra
.592 .564 .792 r
.50251 .48695 .50818 .49979 .51858 .49748 .51291 .4855 Mtetra
.61 .587 .803 r
.51291 .4855 .51858 .49748 .52903 .49476 .52336 .48339 Mtetra
.628 .607 .81 r
.52336 .48339 .52903 .49476 .53952 .49172 .53386 .48064 Mtetra
.643 .62 .811 r
.53386 .48064 .53952 .49172 .55004 .48842 .5444 .47732 Mtetra
.657 .626 .807 r
.5444 .47732 .55004 .48842 .56061 .48487 .55497 .47342 Mtetra
.669 .626 .798 r
.55497 .47342 .56061 .48487 .57121 .481 .56557 .46888 Mtetra
.679 .621 .784 r
.56557 .46888 .57121 .481 .58184 .47671 .5762 .46366 Mtetra
.687 .613 .767 r
.5762 .46366 .58184 .47671 .59249 .47181 .58684 .45765 Mtetra
.691 .602 .751 r
.58684 .45765 .59249 .47181 .60316 .4662 .59749 .45096 Mtetra
.693 .592 .738 r
.59749 .45096 .60316 .4662 .61383 .4597 .60814 .44371 Mtetra
.688 .582 .732 r
.60814 .44371 .61383 .4597 .6245 .45253 .61881 .43645 Mtetra
.676 .575 .734 r
.61881 .43645 .6245 .45253 .63518 .44492 .62953 .42997 Mtetra
.658 .577 .752 r
.62953 .42997 .63518 .44492 .64587 .43758 .64031 .425 Mtetra
.611 .583 .797 r
.64031 .425 .64587 .43758 .65664 .43154 .65124 .42272 Mtetra
.522 .615 .886 r
.65124 .42272 .65664 .43154 .66751 .4273 .66232 .42288 Mtetra
.206 .602 .948 r
.66232 .42288 .66751 .4273 .67854 .42572 .67356 .42523 Mtetra
.273 0 0 r
.67356 .42523 .67854 .42572 .68973 .42609 .68493 .42835 Mtetra
.35 0 0 r
.68493 .42835 .68973 .42609 .70105 .42748 .69632 .43007 Mtetra
.214 0 0 r
.69632 .43007 .70105 .42748 .71243 .42878 .70767 .42976 Mtetra
.258 .763 .739 r
.70767 .42976 .71243 .42878 .72379 .42834 .71891 .42638 Mtetra
.684 .94 .964 r
.71891 .42638 .72379 .42834 .7351 .42618 .73006 .42085 Mtetra
.756 .827 .907 r
.73006 .42085 .7351 .42618 .74635 .4222 .74117 .41431 Mtetra
.743 .743 .852 r
.74117 .41431 .74635 .4222 .75756 .41709 .75229 .40751 Mtetra
.711 .691 .829 r
.75229 .40751 .75756 .41709 .76877 .41169 .76348 .40147 Mtetra
.69 .669 .825 r
.76348 .40147 .76877 .41169 .78003 .40629 .77477 .39617 Mtetra
.67 .662 .834 r
.77477 .39617 .78003 .40629 .79135 .40138 .78615 .39174 Mtetra
.656 .667 .849 r
.78615 .39174 .79135 .40138 .80275 .39689 .79763 .38793 Mtetra
.647 .68 .867 r
.79763 .38793 .80275 .39689 .81423 .39284 .8092 .38449 Mtetra
.64 .694 .884 r
.8092 .38449 .81423 .39284 .82578 .38909 .82083 .38127 Mtetra
.639 .71 .898 r
.82083 .38127 .82578 .38909 .8374 .38553 .83251 .37809 Mtetra
.638 .722 .909 r
.83251 .37809 .8374 .38553 .84907 .38208 .84425 .3749 Mtetra
.639 .732 .916 r
.84425 .3749 .84907 .38208 .86081 .37868 .85603 .37168 Mtetra
.641 .74 .921 r
.85603 .37168 .86081 .37868 .87259 .37524 .86786 .36837 Mtetra
.67 .755 .914 r
.23902 .55988 .24535 .5654 .25483 .56202 .24851 .55653 Mtetra
.674 .757 .914 r
.24851 .55653 .25483 .56202 .26434 .55855 .25804 .55307 Mtetra
.678 .759 .913 r
.25804 .55307 .26434 .55855 .27389 .55504 .26762 .54949 Mtetra
.682 .759 .909 r
.26762 .54949 .27389 .55504 .28347 .55154 .27723 .54578 Mtetra
.687 .753 .902 r
.27723 .54578 .28347 .55154 .29307 .54807 .28688 .5419 Mtetra
.686 .74 .892 r
.28688 .5419 .29307 .54807 .3027 .54481 .29657 .53802 Mtetra
.681 .72 .879 r
.29657 .53802 .3027 .54481 .31233 .54192 .30628 .5342 Mtetra
.663 .69 .865 r
.30628 .5342 .31233 .54192 .32197 .53962 .316 .53082 Mtetra
.636 .653 .85 r
.316 .53082 .32197 .53962 .33159 .53816 .3257 .52817 Mtetra
.601 .612 .835 r
.3257 .52817 .33159 .53816 .34122 .53743 .33539 .52656 Mtetra
.553 .572 .827 r
.33539 .52656 .34122 .53743 .35086 .53745 .34504 .52634 Mtetra
.521 .551 .827 r
.34504 .52634 .35086 .53745 .36057 .53723 .3547 .52698 Mtetra
.488 .553 .849 r
.3547 .52698 .36057 .53723 .37037 .53604 .36439 .52821 Mtetra
.51 .629 .904 r
.36439 .52821 .37037 .53604 .38031 .53276 .37419 .52838 Mtetra
.586 .787 .975 r
.37419 .52838 .38031 .53276 .39041 .5265 .38415 .52629 Mtetra
.633 .949 .945 r
.38415 .52629 .39041 .5265 .4006 .51824 .39425 .52141 Mtetra
.638 .952 .753 r
.39425 .52141 .4006 .51824 .41084 .5086 .4045 .51327 Mtetra
.604 .91 .643 r
.4045 .51327 .41084 .5086 .42106 .49969 .4148 .50376 Mtetra
.667 .947 .695 r
.4148 .50376 .42106 .49969 .43122 .49292 .42511 .49407 Mtetra
.775 .995 .868 r
.42511 .49407 .43122 .49292 .44133 .48853 .43538 .48572 Mtetra
.757 .89 .938 r
.43538 .48572 .44133 .48853 .45142 .48679 .4456 .47973 Mtetra
.681 .723 .882 r
.4456 .47973 .45142 .48679 .46152 .48654 .4558 .47574 Mtetra
.613 .607 .821 r
.4558 .47574 .46152 .48654 .47167 .48708 .466 .47361 Mtetra
.585 .55 .782 r
.466 .47361 .47167 .48708 .48188 .48762 .47623 .4724 Mtetra
.575 .524 .76 r
.47623 .4724 .48188 .48762 .49216 .48761 .48651 .47155 Mtetra
.578 .517 .751 r
.48651 .47155 .49216 .48761 .50251 .48695 .49684 .47059 Mtetra
.588 .52 .746 r
.49684 .47059 .50251 .48695 .51291 .4855 .50724 .46915 Mtetra
.599 .527 .745 r
.50724 .46915 .51291 .4855 .52336 .48339 .51768 .46714 Mtetra
.612 .536 .745 r
.51768 .46714 .52336 .48339 .53386 .48064 .52817 .46446 Mtetra
.625 .544 .743 r
.52817 .46446 .53386 .48064 .5444 .47732 .5387 .4611 Mtetra
.637 .551 .741 r
.5387 .4611 .5444 .47732 .55497 .47342 .54927 .45707 Mtetra
.648 .556 .737 r
.54927 .45707 .55497 .47342 .56557 .46888 .55987 .45236 Mtetra
.656 .56 .734 r
.55987 .45236 .56557 .46888 .5762 .46366 .57049 .44707 Mtetra
.663 .563 .732 r
.57049 .44707 .5762 .46366 .58684 .45765 .58113 .4413 Mtetra
.666 .567 .734 r
.58113 .4413 .58684 .45765 .59749 .45096 .5918 .4354 Mtetra
.665 .574 .743 r
.5918 .4354 .59749 .45096 .60814 .44371 .6025 .42985 Mtetra
.657 .588 .767 r
.6025 .42985 .60814 .44371 .61881 .43645 .61325 .42524 Mtetra
.626 .613 .818 r
.61325 .42524 .61881 .43645 .62953 .42997 .62409 .4225 Mtetra
.544 .667 .917 r
.62409 .4225 .62953 .42997 .64031 .425 .63506 .4218 Mtetra
.156 .622 .93 r
.63506 .4218 .64031 .425 .65124 .42272 .64617 .42351 Mtetra
.372 0 0 r
.64617 .42351 .65124 .42272 .66232 .42288 .65742 .42661 Mtetra
.477 0 0 r
.65742 .42661 .66232 .42288 .67356 .42523 .66875 .42955 Mtetra
.421 0 0 r
.66875 .42955 .67356 .42523 .68493 .42835 .6801 .4311 Mtetra
.096 0 0 r
.6801 .4311 .68493 .42835 .69632 .43007 .69136 .42933 Mtetra
.56 .927 .935 r
.69136 .42933 .69632 .43007 .70767 .42976 .70252 .42469 Mtetra
.77 .839 .904 r
.70252 .42469 .70767 .42976 .71891 .42638 .71359 .41771 Mtetra
.761 .729 .823 r
.71359 .41771 .71891 .42638 .73006 .42085 .72461 .40963 Mtetra
.726 .666 .791 r
.72461 .40963 .73006 .42085 .74117 .41431 .73568 .40214 Mtetra
.702 .64 .784 r
.73568 .40214 .74117 .41431 .75229 .40751 .74683 .39553 Mtetra
.676 .631 .797 r
.74683 .39553 .75229 .40751 .76348 .40147 .7581 .39035 Mtetra
.657 .637 .819 r
.7581 .39035 .76348 .40147 .77477 .39617 .7695 .38623 Mtetra
.642 .655 .847 r
.7695 .38623 .77477 .39617 .78615 .39174 .78099 .38288 Mtetra
.63 .676 .875 r
.78099 .38288 .78615 .39174 .79763 .38793 .79258 .37997 Mtetra
.627 .701 .898 r
.79258 .37997 .79763 .38793 .8092 .38449 .80422 .37714 Mtetra
.625 .719 .914 r
.80422 .37714 .8092 .38449 .82083 .38127 .81592 .3743 Mtetra
.63 .735 .923 r
.81592 .3743 .82083 .38127 .83251 .37809 .82765 .37128 Mtetra
.634 .743 .927 r
.82765 .37128 .83251 .37809 .84425 .3749 .83943 .36812 Mtetra
.638 .747 .927 r
.83943 .36812 .84425 .3749 .85603 .37168 .85125 .36484 Mtetra
.643 .748 .925 r
.85125 .36484 .85603 .37168 .86786 .36837 .8631 .36144 Mtetra
.659 .752 .919 r
.23264 .55431 .23902 .55988 .24851 .55653 .24213 .55121 Mtetra
.662 .762 .924 r
.24213 .55121 .24851 .55653 .25804 .55307 .25167 .54801 Mtetra
.668 .774 .929 r
.25167 .54801 .25804 .55307 .26762 .54949 .26124 .54465 Mtetra
.678 .785 .931 r
.26124 .54465 .26762 .54949 .27723 .54578 .27087 .54104 Mtetra
.691 .792 .927 r
.27087 .54104 .27723 .54578 .28688 .5419 .28056 .53709 Mtetra
.702 .792 .92 r
.28056 .53709 .28688 .5419 .29657 .53802 .29029 .53282 Mtetra
.714 .781 .905 r
.29029 .53282 .29657 .53802 .30628 .5342 .30008 .52818 Mtetra
.711 .753 .885 r
.30008 .52818 .30628 .5342 .316 .53082 .3099 .52349 Mtetra
.699 .713 .859 r
.3099 .52349 .316 .53082 .3257 .52817 .31974 .51893 Mtetra
.666 .656 .83 r
.31974 .51893 .3257 .52817 .33539 .52656 .32956 .51515 Mtetra
.622 .597 .804 r
.32956 .51515 .33539 .52656 .34504 .52634 .33933 .51271 Mtetra
.57 .537 .779 r
.33933 .51271 .34504 .52634 .3547 .52698 .34905 .51207 Mtetra
.505 .484 .768 r
.34905 .51207 .3547 .52698 .36439 .52821 .35871 .51373 Mtetra
.463 .466 .776 r
.35871 .51373 .36439 .52821 .37419 .52838 .36838 .51653 Mtetra
.415 .481 .82 r
.36838 .51653 .37419 .52838 .38415 .52629 .3781 .51972 Mtetra
.407 .626 .943 r
.3781 .51972 .38415 .52629 .39425 .52141 .38798 .52095 Mtetra
.394 .843 .921 r
.38798 .52095 .39425 .52141 .4045 .51327 .39806 .51853 Mtetra
0 0 0 r
.39806 .51853 .4045 .51327 .4148 .50376 .40831 .51254 Mtetra
.40831 .51254 .4148 .50376 .42511 .49407 .41869 .50296 Mtetra
.41869 .50296 .42511 .49407 .43538 .48572 .42911 .49216 Mtetra
.42911 .49216 .43538 .48572 .4456 .47973 .43951 .48165 Mtetra
.766 .996 .827 r
.43951 .48165 .4456 .47973 .4558 .47574 .44988 .4726 Mtetra
.782 .881 .918 r
.44988 .4726 .4558 .47574 .466 .47361 .4602 .46581 Mtetra
.705 .713 .855 r
.4602 .46581 .466 .47361 .47623 .4724 .47051 .46079 Mtetra
.646 .61 .799 r
.47051 .46079 .47623 .4724 .48651 .47155 .48083 .45728 Mtetra
.619 .56 .766 r
.48083 .45728 .48651 .47155 .49684 .47059 .49118 .45452 Mtetra
.608 .535 .747 r
.49118 .45452 .49684 .47059 .50724 .46915 .50157 .45205 Mtetra
.608 .526 .736 r
.50157 .45205 .50724 .46915 .51768 .46714 .512 .44947 Mtetra
.613 .524 .73 r
.512 .44947 .51768 .46714 .52817 .46446 .52248 .44654 Mtetra
.62 .526 .727 r
.52248 .44654 .52817 .46446 .5387 .4611 .533 .44315 Mtetra
.627 .531 .725 r
.533 .44315 .5387 .4611 .54927 .45707 .54356 .4393 Mtetra
.634 .536 .726 r
.54356 .4393 .54927 .45707 .55987 .45236 .55415 .43509 Mtetra
.637 .542 .731 r
.55415 .43509 .55987 .45236 .57049 .44707 .56478 .43078 Mtetra
.636 .551 .741 r
.56478 .43078 .57049 .44707 .58113 .4413 .57545 .42675 Mtetra
.627 .564 .764 r
.57545 .42675 .58113 .4413 .5918 .4354 .58617 .42348 Mtetra
.598 .586 .811 r
.58617 .42348 .5918 .4354 .6025 .42985 .59697 .42173 Mtetra
.515 .633 .905 r
.59697 .42173 .6025 .42985 .61325 .42524 .60786 .42178 Mtetra
.104 .577 .911 r
.60786 .42178 .61325 .42524 .62409 .4225 .61889 .42414 Mtetra
.468 0 0 r
.61889 .42414 .62409 .4225 .63506 .4218 .63005 .428 Mtetra
.559 .085 .085 r
.63005 .428 .63506 .4218 .64617 .42351 .64132 .43218 Mtetra
.535 .098 .157 r
.64132 .43218 .64617 .42351 .65742 .42661 .65263 .43515 Mtetra
.409 0 .09 r
.65263 .43515 .65742 .42661 .66875 .42955 .66388 .43447 Mtetra
.045 0 0 r
.66388 .43447 .66875 .42955 .6801 .4311 .67503 .43013 Mtetra
.777 .981 .908 r
.67503 .43013 .6801 .4311 .69136 .42933 .68602 .42205 Mtetra
.811 .776 .82 r
.68602 .42205 .69136 .42933 .70252 .42469 .69693 .41193 Mtetra
.747 .652 .756 r
.69693 .41193 .70252 .42469 .71359 .41771 .70785 .40219 Mtetra
.709 .603 .736 r
.70785 .40219 .71359 .41771 .72461 .40963 .71885 .3936 Mtetra
.671 .578 .742 r
.71885 .3936 .72461 .40963 .73568 .40214 .73 .38737 Mtetra
.646 .578 .764 r
.73 .38737 .73568 .40214 .74683 .39553 .74131 .38299 Mtetra
.625 .597 .802 r
.74131 .38299 .74683 .39553 .7581 .39035 .75276 .37999 Mtetra
.607 .629 .847 r
.75276 .37999 .7581 .39035 .7695 .38623 .76432 .37782 Mtetra
.6 .674 .893 r
.76432 .37782 .7695 .38623 .78099 .38288 .77594 .37577 Mtetra
.595 .714 .927 r
.77594 .37577 .78099 .38288 .79258 .37997 .78763 .37367 Mtetra
.604 .747 .946 r
.78763 .37367 .79258 .37997 .80422 .37714 .79934 .37119 Mtetra
.614 .766 .952 r
.79934 .37119 .80422 .37714 .81592 .3743 .81108 .36838 Mtetra
.629 .775 .95 r
.81108 .36838 .81592 .3743 .82765 .37128 .82284 .36521 Mtetra
.64 .774 .945 r
.82284 .36521 .82765 .37128 .83943 .36812 .83462 .36178 Mtetra
.648 .769 .937 r
.83462 .36178 .83943 .36812 .85125 .36484 .84645 .35817 Mtetra
.652 .76 .928 r
.84645 .35817 .85125 .36484 .8631 .36144 .85831 .35446 Mtetra
.643 .748 .926 r
.22623 .54871 .23264 .55431 .24213 .55121 .2357 .54596 Mtetra
.642 .762 .935 r
.2357 .54596 .24213 .55121 .25167 .54801 .24522 .54318 Mtetra
.646 .779 .945 r
.24522 .54318 .25167 .54801 .26124 .54465 .25479 .54026 Mtetra
.654 .799 .952 r
.25479 .54026 .26124 .54465 .27087 .54104 .2644 .5371 Mtetra
.667 .82 .957 r
.2644 .5371 .27087 .54104 .28056 .53709 .27408 .53359 Mtetra
.686 .842 .958 r
.27408 .53359 .28056 .53709 .29029 .53282 .28382 .52961 Mtetra
.712 .858 .951 r
.28382 .52961 .29029 .53282 .30008 .52818 .29364 .52501 Mtetra
.733 .861 .941 r
.29364 .52501 .30008 .52818 .3099 .52349 .30352 .51988 Mtetra
.752 .846 .921 r
.30352 .51988 .3099 .52349 .31974 .51893 .31346 .51419 Mtetra
.746 .805 .899 r
.31346 .51419 .31974 .51893 .32956 .51515 .32341 .50854 Mtetra
.72 .741 .868 r
.32341 .50854 .32956 .51515 .33933 .51271 .33337 .50333 Mtetra
.665 .655 .831 r
.33337 .50333 .33933 .51271 .34905 .51207 .34326 .49957 Mtetra
.593 .566 .794 r
.34326 .49957 .34905 .51207 .35871 .51373 .35308 .49809 Mtetra
.529 .491 .757 r
.35308 .49809 .35871 .51373 .36838 .51653 .36282 .49897 Mtetra
.464 .431 .737 r
.36282 .49897 .36838 .51653 .3781 .51972 .37251 .5024 Mtetra
.447 .424 .74 r
.37251 .5024 .3781 .51972 .38798 .52095 .38225 .50634 Mtetra
.456 .462 .776 r
.38225 .50634 .38798 .52095 .39806 .51853 .39211 .50935 Mtetra
.514 .598 .875 r
.39211 .50935 .39806 .51853 .40831 .51254 .40214 .50969 Mtetra
.639 .871 .985 r
.40214 .50969 .40831 .51254 .41869 .50296 .41237 .50611 Mtetra
.472 .871 .699 r
.41237 .50611 .41869 .50296 .42911 .49216 .42272 .4996 Mtetra
0 0 0 r
.42272 .4996 .42911 .49216 .43951 .48165 .43316 .49075 Mtetra
.43316 .49075 .43951 .48165 .44988 .4726 .44361 .48132 Mtetra
.44361 .48132 .44988 .4726 .4602 .46581 .45406 .47242 Mtetra
.45406 .47242 .4602 .46581 .47051 .46079 .46449 .46455 Mtetra
.46449 .46455 .47051 .46079 .48083 .45728 .4749 .45808 Mtetra
.57 .94 .876 r
.4749 .45808 .48083 .45728 .49118 .45452 .48533 .45268 Mtetra
.657 .919 .977 r
.48533 .45268 .49118 .45452 .50157 .45205 .49578 .44818 Mtetra
.67 .844 .967 r
.49578 .44818 .50157 .45205 .512 .44947 .50625 .44422 Mtetra
.664 .788 .941 r
.50625 .44422 .512 .44947 .52248 .44654 .51676 .4406 Mtetra
.656 .761 .927 r
.51676 .4406 .52248 .44654 .533 .44315 .52731 .43718 Mtetra
.647 .758 .93 r
.52731 .43718 .533 .44315 .54356 .4393 .5379 .43398 Mtetra
.627 .777 .953 r
.5379 .43398 .54356 .4393 .55415 .43509 .54853 .43112 Mtetra
.572 .813 .99 r
.54853 .43112 .55415 .43509 .56478 .43078 .55922 .4288 Mtetra
.385 .807 .972 r
.55922 .4288 .56478 .43078 .57545 .42675 .56997 .42738 Mtetra
.031 0 0 r
.56997 .42738 .57545 .42675 .58617 .42348 .58079 .42706 Mtetra
.373 0 0 r
.58079 .42706 .58617 .42348 .59697 .42173 .5917 .42817 Mtetra
.492 .017 .055 r
.5917 .42817 .59697 .42173 .60786 .42178 .60272 .43033 Mtetra
.528 .09 .151 r
.60272 .43033 .60786 .42178 .61889 .42414 .61383 .43306 Mtetra
.512 .078 .152 r
.61383 .43306 .61889 .42414 .63005 .428 .625 .43521 Mtetra
.401 0 .032 r
.625 .43521 .63005 .428 .64132 .43218 .63619 .435 Mtetra
0 0 0 r
.63619 .435 .64132 .43218 .65263 .43515 .64732 .43181 Mtetra
.78 .903 .927 r
.64732 .43181 .65263 .43515 .66388 .43447 .65834 .42461 Mtetra
.778 .709 .787 r
.65834 .42461 .66388 .43447 .67503 .43013 .66925 .41466 Mtetra
.739 .618 .725 r
.66925 .41466 .67503 .43013 .68602 .42205 .68012 .40373 Mtetra
.713 .582 .706 r
.68012 .40373 .68602 .42205 .69693 .41193 .69101 .39329 Mtetra
.68 .561 .713 r
.69101 .39329 .69693 .41193 .70785 .40219 .70204 .38546 Mtetra
.655 .562 .738 r
.70204 .38546 .70785 .40219 .71885 .3936 .71322 .38005 Mtetra
.623 .581 .786 r
.71322 .38005 .71885 .3936 .73 .38737 .72459 .37698 Mtetra
.588 .619 .85 r
.72459 .37698 .73 .38737 .74131 .38299 .7361 .37541 Mtetra
.556 .679 .921 r
.7361 .37541 .74131 .38299 .75276 .37999 .74771 .3743 Mtetra
.522 .733 .97 r
.74771 .3743 .75276 .37999 .76432 .37782 .75939 .37325 Mtetra
.524 .782 .991 r
.75939 .37325 .76432 .37782 .77594 .37577 .77109 .37161 Mtetra
.544 .809 .995 r
.77109 .37161 .77594 .37577 .78763 .37367 .78281 .36943 Mtetra
.584 .825 .99 r
.78281 .36943 .78763 .37367 .79934 .37119 .79453 .3666 Mtetra
.617 .825 .98 r
.79453 .3666 .79934 .37119 .81108 .36838 .80627 .36328 Mtetra
.642 .815 .966 r
.80627 .36328 .81108 .36838 .82284 .36521 .81802 .3596 Mtetra
.657 .801 .952 r
.81802 .3596 .82284 .36521 .83462 .36178 .8298 .35565 Mtetra
.665 .785 .938 r
.8298 .35565 .83462 .36178 .84645 .35817 .84162 .35156 Mtetra
.667 .769 .927 r
.84162 .35156 .84645 .35817 .85831 .35446 .85348 .34743 Mtetra
.626 .744 .932 r
.21976 .54307 .22623 .54871 .2357 .54596 .22923 .54065 Mtetra
.62 .755 .942 r
.22923 .54065 .2357 .54596 .24522 .54318 .23873 .53829 Mtetra
.617 .771 .954 r
.23873 .53829 .24522 .54318 .25479 .54026 .24827 .5359 Mtetra
.617 .793 .966 r
.24827 .5359 .25479 .54026 .2644 .5371 .25786 .5334 Mtetra
.615 .82 .979 r
.25786 .5334 .2644 .5371 .27408 .53359 .2675 .53072 Mtetra
.622 .856 .987 r
.2675 .53072 .27408 .53359 .28382 .52961 .27721 .52764 Mtetra
.636 .894 .986 r
.27721 .52764 .28382 .52961 .29364 .52501 .28699 .52398 Mtetra
.658 .931 .971 r
.28699 .52398 .29364 .52501 .30352 .51988 .29686 .5195 Mtetra
.702 .957 .949 r
.29686 .5195 .30352 .51988 .31346 .51419 .30683 .51397 Mtetra
.749 .966 .933 r
.30683 .51397 .31346 .51419 .32341 .50854 .31688 .5075 Mtetra
.802 .941 .918 r
.31688 .5075 .32341 .50854 .33337 .50333 .32701 .50007 Mtetra
.802 .861 .893 r
.32701 .50007 .33337 .50333 .34326 .49957 .33715 .49256 Mtetra
.756 .74 .837 r
.33715 .49256 .34326 .49957 .35308 .49809 .34727 .48561 Mtetra
.671 .606 .774 r
.34727 .48561 .35308 .49809 .36282 .49897 .3573 .48074 Mtetra
.586 .501 .725 r
.3573 .48074 .36282 .49897 .37251 .5024 .3672 .47917 Mtetra
.521 .427 .69 r
.3672 .47917 .37251 .5024 .38225 .50634 .37699 .48102 Mtetra
.454 .373 .674 r
.37699 .48102 .38225 .50634 .39211 .50935 .3867 .48644 Mtetra
.419 .363 .688 r
.3867 .48644 .39211 .50935 .40214 .50969 .39647 .49281 Mtetra
.387 .393 .744 r
.39647 .49281 .40214 .50969 .41237 .50611 .40636 .49833 Mtetra
.332 .549 .912 r
.40636 .49833 .41237 .50611 .42272 .4996 .41643 .50104 Mtetra
0 0 0 r
.41643 .50104 .42272 .4996 .43316 .49075 .42671 .49961 Mtetra
.193 0 0 r
.42671 .49961 .43316 .49075 .44361 .48132 .43712 .49498 Mtetra
.215 0 .12 r
.43712 .49498 .44361 .48132 .45406 .47242 .44762 .48771 Mtetra
.216 0 .152 r
.44762 .48771 .45406 .47242 .46449 .46455 .45816 .47942 Mtetra
.207 0 .142 r
.45816 .47942 .46449 .46455 .4749 .45808 .46871 .47113 Mtetra
.185 0 .096 r
.46871 .47113 .4749 .45808 .48533 .45268 .47925 .46347 Mtetra
.163 0 .029 r
.47925 .46347 .48533 .45268 .49578 .44818 .4898 .45688 Mtetra
.139 0 0 r
.4898 .45688 .49578 .44818 .50625 .44422 .50036 .45133 Mtetra
.136 0 0 r
.50036 .45133 .50625 .44422 .51676 .4406 .51094 .44688 Mtetra
.17 0 0 r
.51094 .44688 .51676 .4406 .52731 .43718 .52156 .44346 Mtetra
.245 0 0 r
.52156 .44346 .52731 .43718 .5379 .43398 .53222 .44105 Mtetra
.342 0 0 r
.53222 .44105 .5379 .43398 .54853 .43112 .54293 .43976 Mtetra
.425 0 .1 r
.54293 .43976 .54853 .43112 .55922 .4288 .55371 .43952 Mtetra
.485 .076 .189 r
.55371 .43952 .55922 .4288 .56997 .42738 .56457 .44038 Mtetra
.513 .128 .247 r
.56457 .44038 .56997 .42738 .58079 .42706 .57551 .44188 Mtetra
.519 .149 .278 r
.57551 .44188 .58079 .42706 .5917 .42817 .58652 .4434 Mtetra
.498 .131 .274 r
.58652 .4434 .5917 .42817 .60272 .43033 .59759 .4439 Mtetra
.419 .043 .216 r
.59759 .4439 .60272 .43033 .61383 .43306 .60866 .44174 Mtetra
.173 0 0 r
.60866 .44174 .61383 .43306 .625 .43521 .6197 .43632 Mtetra
.766 .996 .822 r
.6197 .43632 .625 .43521 .63619 .435 .63062 .42668 Mtetra
.829 .752 .778 r
.63062 .42668 .63619 .435 .64732 .43181 .64144 .41414 Mtetra
.748 .605 .699 r
.64144 .41414 .64732 .43181 .65834 .42461 .65221 .40071 Mtetra
.703 .545 .671 r
.65221 .40071 .65834 .42461 .66925 .41466 .663 .38821 Mtetra
.658 .507 .667 r
.663 .38821 .66925 .41466 .68012 .40373 .67394 .37934 Mtetra
.627 .496 .683 r
.67394 .37934 .68012 .40373 .69101 .39329 .68506 .37397 Mtetra
.59 .503 .725 r
.68506 .37397 .69101 .39329 .70204 .38546 .69639 .37198 Mtetra
.542 .538 .8 r
.69639 .37198 .70204 .38546 .71322 .38005 .70791 .37215 Mtetra
.471 .626 .92 r
.70791 .37215 .71322 .38005 .72459 .37698 .71953 .3729 Mtetra
.325 .697 .981 r
.71953 .3729 .72459 .37698 .7361 .37541 .73123 .37359 Mtetra
.229 .722 .919 r
.73123 .37359 .7361 .37541 .74771 .3743 .74295 .37329 Mtetra
.244 .75 .883 r
.74295 .37329 .74771 .3743 .75939 .37325 .75466 .37203 Mtetra
.372 .826 .928 r
.75466 .37203 .75939 .37325 .77109 .37161 .76636 .36967 Mtetra
.502 .878 .975 r
.76636 .36967 .77109 .37161 .78281 .36943 .77805 .36648 Mtetra
.598 .885 .991 r
.77805 .36648 .78281 .36943 .79453 .3666 .78974 .36267 Mtetra
.649 .866 .981 r
.78974 .36267 .79453 .3666 .80627 .36328 .80145 .35843 Mtetra
.67 .837 .963 r
.80145 .35843 .80627 .36328 .81802 .3596 .81318 .35401 Mtetra
.68 .812 .946 r
.81318 .35401 .81802 .3596 .8298 .35565 .82495 .34946 Mtetra
.682 .791 .932 r
.82495 .34946 .8298 .35565 .84162 .35156 .83675 .34488 Mtetra
.68 .774 .922 r
.83675 .34488 .84162 .35156 .85348 .34743 .84861 .34035 Mtetra
.623 .743 .933 r
.21326 .53739 .21976 .54307 .22923 .54065 .22274 .53501 Mtetra
.616 .743 .936 r
.22274 .53501 .22923 .54065 .23873 .53829 .23225 .53276 Mtetra
.61 .746 .941 r
.23225 .53276 .23873 .53829 .24827 .5359 .24179 .53059 Mtetra
.603 .753 .949 r
.24179 .53059 .24827 .5359 .25786 .5334 .25136 .5285 Mtetra
.592 .766 .963 r
.25136 .5285 .25786 .5334 .2675 .53072 .26097 .52651 Mtetra
.586 .793 .978 r
.26097 .52651 .2675 .53072 .27721 .52764 .27063 .52439 Mtetra
.579 .831 .993 r
.27063 .52439 .27721 .52764 .28699 .52398 .28035 .52203 Mtetra
.578 .881 .993 r
.28035 .52203 .28699 .52398 .29686 .5195 .29015 .51904 Mtetra
.579 .924 .959 r
.29015 .51904 .29686 .5195 .30683 .51397 .30005 .51512 Mtetra
.578 .942 .884 r
.30005 .51512 .30683 .51397 .31688 .5075 .31006 .50995 Mtetra
.614 .954 .813 r
.31006 .50995 .31688 .5075 .32701 .50007 .3202 .50319 Mtetra
.661 .965 .781 r
.3202 .50319 .32701 .50007 .33715 .49256 .33042 .49517 Mtetra
.766 .996 .818 r
.33042 .49517 .33715 .49256 .34727 .48561 .34072 .48601 Mtetra
.825 .979 .886 r
.34072 .48601 .34727 .48561 .3573 .48074 .351 .4772 Mtetra
.796 .857 .895 r
.351 .4772 .3573 .48074 .3672 .47917 .36122 .46985 Mtetra
.681 .666 .829 r
.36122 .46985 .3672 .47917 .37699 .48102 .37131 .46539 Mtetra
.562 .512 .757 r
.37131 .46539 .37699 .48102 .3867 .48644 .38125 .46493 Mtetra
.501 .425 .703 r
.38125 .46493 .3867 .48644 .39647 .49281 .39113 .46748 Mtetra
.464 .38 .676 r
.39113 .46748 .39647 .49281 .40636 .49833 .40099 .4724 Mtetra
.465 .378 .673 r
.40099 .4724 .40636 .49833 .41643 .50104 .41094 .47741 Mtetra
.486 .405 .689 r
.41094 .47741 .41643 .50104 .42671 .49961 .42102 .48099 Mtetra
.52 .461 .73 r
.42102 .48099 .42671 .49961 .43712 .49498 .43125 .48243 Mtetra
.581 .567 .803 r
.43125 .48243 .43712 .49498 .44762 .48771 .44161 .48121 Mtetra
.643 .738 .918 r
.44161 .48121 .44762 .48771 .45816 .47942 .45207 .47816 Mtetra
.623 .927 .971 r
.45207 .47816 .45816 .47942 .46871 .47113 .46259 .47375 Mtetra
.33 .793 .673 r
.46259 .47375 .46871 .47113 .47925 .46347 .47316 .46879 Mtetra
0 0 0 r
.47316 .46879 .47925 .46347 .4898 .45688 .48375 .46383 Mtetra
.106 0 0 r
.48375 .46383 .4898 .45688 .50036 .45133 .49438 .4592 Mtetra
.196 0 0 r
.49438 .4592 .50036 .45133 .51094 .44688 .50503 .45513 Mtetra
.252 0 0 r
.50503 .45513 .51094 .44688 .52156 .44346 .51572 .45169 Mtetra
.289 0 .007 r
.51572 .45169 .52156 .44346 .53222 .44105 .52645 .44888 Mtetra
.309 0 .002 r
.52645 .44888 .53222 .44105 .54293 .43976 .53724 .44665 Mtetra
.298 0 0 r
.53724 .44665 .54293 .43976 .55371 .43952 .54807 .44474 Mtetra
.229 0 0 r
.54807 .44474 .55371 .43952 .56457 .44038 .55896 .44284 Mtetra
0 0 0 r
.55896 .44284 .56457 .44038 .57551 .44188 .56989 .44039 Mtetra
.562 .907 .973 r
.56989 .44039 .57551 .44188 .58652 .4434 .58085 .43657 Mtetra
.724 .764 .885 r
.58085 .43657 .58652 .4434 .59759 .4439 .59181 .43089 Mtetra
.725 .638 .761 r
.59181 .43089 .59759 .4439 .60866 .44174 .60274 .4225 Mtetra
.709 .573 .7 r
.60274 .4225 .60866 .44174 .6197 .43632 .61362 .41192 Mtetra
.696 .539 .67 r
.61362 .41192 .6197 .43632 .63062 .42668 .62445 .39985 Mtetra
.685 .523 .66 r
.62445 .39985 .63062 .42668 .64144 .41414 .63527 .38785 Mtetra
.666 .512 .666 r
.63527 .38785 .64144 .41414 .65221 .40071 .64616 .37824 Mtetra
.647 .517 .691 r
.64616 .37824 .65221 .40071 .663 .38821 .65718 .37169 Mtetra
.603 .535 .751 r
.65718 .37169 .663 .38821 .67394 .37934 .66841 .36922 Mtetra
.511 .585 .866 r
.66841 .36922 .67394 .37934 .68506 .37397 .67984 .36974 Mtetra
.21 .619 .951 r
.67984 .36974 .68506 .37397 .69639 .37198 .69142 .37176 Mtetra
.218 0 0 r
.69142 .37176 .69639 .37198 .70791 .37215 .70311 .37416 Mtetra
.286 0 0 r
.70311 .37416 .70791 .37215 .71953 .3729 .71483 .37541 Mtetra
.218 0 0 r
.71483 .37541 .71953 .3729 .73123 .37359 .72654 .37537 Mtetra
.014 0 0 r
.72654 .37537 .73123 .37359 .74295 .37329 .73822 .37369 Mtetra
.265 .772 .788 r
.73822 .37369 .74295 .37329 .75466 .37203 .74988 .37072 Mtetra
.518 .901 .951 r
.74988 .37072 .75466 .37203 .76636 .36967 .76151 .36677 Mtetra
.643 .904 .983 r
.76151 .36677 .76636 .36967 .77805 .36648 .77314 .36217 Mtetra
.684 .863 .967 r
.77314 .36217 .77805 .36648 .78974 .36267 .78479 .35731 Mtetra
.696 .826 .945 r
.78479 .35731 .78974 .36267 .80145 .35843 .79648 .35231 Mtetra
.694 .798 .93 r
.79648 .35231 .80145 .35843 .81318 .35401 .80821 .34741 Mtetra
.69 .781 .92 r
.80821 .34741 .81318 .35401 .82495 .34946 .81999 .34257 Mtetra
.686 .77 .915 r
.81999 .34257 .82495 .34946 .83675 .34488 .83182 .33783 Mtetra
.682 .764 .914 r
.83182 .33783 .83675 .34488 .84861 .34035 .8437 .33321 Mtetra
.636 .746 .928 r
.20671 .53168 .21326 .53739 .22274 .53501 .21623 .529 Mtetra
.631 .735 .923 r
.21623 .529 .22274 .53501 .23225 .53276 .22579 .52646 Mtetra
.623 .724 .919 r
.22579 .52646 .23225 .53276 .24179 .53059 .23536 .5241 Mtetra
.611 .714 .918 r
.23536 .5241 .24179 .53059 .25136 .5285 .24495 .52201 Mtetra
.593 .709 .924 r
.24495 .52201 .25136 .5285 .26097 .52651 .25455 .52027 Mtetra
.576 .712 .936 r
.25455 .52027 .26097 .52651 .27063 .52439 .26417 .5188 Mtetra
.549 .728 .957 r
.26417 .5188 .27063 .52439 .28035 .52203 .27382 .51761 Mtetra
.524 .766 .985 r
.27382 .51761 .28035 .52203 .29015 .51904 .28352 .51637 Mtetra
.47 .816 .998 r
.28352 .51637 .29015 .51904 .30005 .51512 .29328 .51487 Mtetra
.367 .83 .906 r
.29328 .51487 .30005 .51512 .31006 .50995 .30315 .51259 Mtetra
0 0 0 r
.30315 .51259 .31006 .50995 .3202 .50319 .31313 .50909 Mtetra
.31313 .50909 .3202 .50319 .33042 .49517 .32325 .50392 Mtetra
.32325 .50392 .33042 .49517 .34072 .48601 .33352 .49661 Mtetra
.33352 .49661 .34072 .48601 .351 .4772 .34391 .48724 Mtetra
.34391 .48724 .351 .4772 .36122 .46985 .35441 .47583 Mtetra
.688 .929 .619 r
.35441 .47583 .36122 .46985 .37131 .46539 .36493 .4639 Mtetra
.882 .908 .841 r
.36493 .4639 .37131 .46539 .38125 .46493 .3754 .45257 Mtetra
.732 .639 .755 r
.3754 .45257 .38125 .46493 .39113 .46748 .38574 .44402 Mtetra
.617 .489 .684 r
.38574 .44402 .39113 .46748 .40099 .4724 .39592 .43972 Mtetra
.554 .414 .645 r
.39592 .43972 .40099 .4724 .41094 .47741 .40599 .43945 Mtetra
.51 .371 .628 r
.40599 .43945 .41094 .47741 .42102 .48099 .41598 .44304 Mtetra
.489 .357 .627 r
.41598 .44304 .42102 .48099 .43125 .48243 .42601 .44832 Mtetra
.478 .359 .638 r
.42601 .44832 .43125 .48243 .44161 .48121 .43612 .45387 Mtetra
.478 .382 .668 r
.43612 .45387 .44161 .48121 .45207 .47816 .44635 .45842 Mtetra
.492 .436 .722 r
.44635 .45842 .45207 .47816 .46259 .47375 .45671 .46109 Mtetra
.51 .529 .812 r
.45671 .46109 .46259 .47375 .47316 .46879 .46718 .46206 Mtetra
.528 .689 .941 r
.46718 .46206 .47316 .46879 .48375 .46383 .47775 .46137 Mtetra
.464 .83 .993 r
.47775 .46137 .48375 .46383 .49438 .4592 .48838 .45951 Mtetra
.316 .806 .838 r
.48838 .45951 .49438 .4592 .50503 .45513 .49908 .45675 Mtetra
.25 .754 .711 r
.49908 .45675 .50503 .45513 .51572 .45169 .50982 .4533 Mtetra
.33 .807 .745 r
.50982 .4533 .51572 .45169 .52645 .44888 .52061 .44914 Mtetra
.555 .932 .897 r
.52061 .44914 .52645 .44888 .53724 .44665 .53143 .44407 Mtetra
.745 .918 .95 r
.53143 .44407 .53724 .44665 .54807 .44474 .54228 .43784 Mtetra
.775 .772 .849 r
.54228 .43784 .54807 .44474 .55896 .44284 .55314 .42991 Mtetra
.743 .646 .753 r
.55314 .42991 .55896 .44284 .56989 .44039 .56399 .42024 Mtetra
.714 .57 .691 r
.56399 .42024 .56989 .44039 .58085 .43657 .57481 .40866 Mtetra
.686 .519 .655 r
.57481 .40866 .58085 .43657 .59181 .43089 .58561 .39603 Mtetra
.661 .485 .635 r
.58561 .39603 .59181 .43089 .60274 .4225 .59639 .38365 Mtetra
.639 .462 .627 r
.59639 .38365 .60274 .4225 .61362 .41192 .60719 .37295 Mtetra
.61 .441 .629 r
.60719 .37295 .61362 .41192 .62445 .39985 .61811 .36617 Mtetra
.58 .432 .646 r
.61811 .36617 .62445 .39985 .63527 .38785 .62918 .36348 Mtetra
.525 .431 .69 r
.62918 .36348 .63527 .38785 .64616 .37824 .64046 .36513 Mtetra
.387 .454 .807 r
.64046 .36513 .64616 .37824 .65718 .37169 .65193 .36963 Mtetra
.312 0 0 r
.65193 .36963 .65718 .37169 .66841 .36922 .66354 .3748 Mtetra
.558 .063 .037 r
.66354 .3748 .66841 .36922 .67984 .36974 .67523 .37945 Mtetra
.519 .088 .161 r
.67523 .37945 .67984 .36974 .69142 .37176 .68693 .38203 Mtetra
.461 .039 .151 r
.68693 .38203 .69142 .37176 .70311 .37416 .6986 .3825 Mtetra
.352 0 .04 r
.6986 .3825 .70311 .37416 .71483 .37541 .71022 .38079 Mtetra
.143 0 0 r
.71022 .38079 .71483 .37541 .72654 .37537 .7218 .37734 Mtetra
0 0 0 r
.7218 .37734 .72654 .37537 .73822 .37369 .73335 .37263 Mtetra
.617 .947 .938 r
.73335 .37263 .73822 .37369 .74988 .37072 .74488 .36709 Mtetra
.717 .898 .961 r
.74488 .36709 .74988 .37072 .76151 .36677 .75643 .36129 Mtetra
.728 .83 .928 r
.75643 .36129 .76151 .36677 .77314 .36217 .768 .35542 Mtetra
.715 .783 .905 r
.768 .35542 .77314 .36217 .78479 .35731 .77964 .34983 Mtetra
.703 .756 .893 r
.77964 .34983 .78479 .35731 .79648 .35231 .79133 .34451 Mtetra
.69 .743 .891 r
.79133 .34451 .79648 .35231 .80821 .34741 .80309 .33956 Mtetra
.682 .739 .894 r
.80309 .33956 .80821 .34741 .81999 .34257 .81492 .33487 Mtetra
.676 .742 .9 r
.81492 .33487 .81999 .34257 .83182 .33783 .82681 .33038 Mtetra
.671 .749 .908 r
.82681 .33038 .83182 .33783 .8437 .33321 .83876 .32602 Mtetra
.661 .753 .918 r
.20012 .52592 .20671 .53168 .21623 .529 .20971 .52265 Mtetra
.658 .733 .905 r
.20971 .52265 .21623 .529 .22579 .52646 .21934 .51945 Mtetra
.65 .711 .892 r
.21934 .51945 .22579 .52646 .23536 .5241 .22898 .51644 Mtetra
.637 .688 .881 r
.22898 .51644 .23536 .5241 .24495 .52201 .23864 .51374 Mtetra
.62 .666 .873 r
.23864 .51374 .24495 .52201 .25455 .52027 .24829 .51147 Mtetra
.601 .645 .867 r
.24829 .51147 .25455 .52027 .26417 .5188 .25795 .50969 Mtetra
.576 .628 .866 r
.25795 .50969 .26417 .5188 .27382 .51761 .2676 .50854 Mtetra
.555 .62 .872 r
.2676 .50854 .27382 .51761 .28352 .51637 .27726 .50788 Mtetra
.528 .625 .891 r
.27726 .50788 .28352 .51637 .29328 .51487 .28695 .50769 Mtetra
.509 .658 .927 r
.28695 .50769 .29328 .51487 .30315 .51259 .29668 .50752 Mtetra
.478 .725 .979 r
.29668 .50752 .30315 .51259 .31313 .50909 .30649 .50706 Mtetra
.42 .818 .983 r
.30649 .50706 .31313 .50909 .32325 .50392 .31641 .50556 Mtetra
.268 .77 .741 r
.31641 .50556 .32325 .50392 .33352 .49661 .32649 .50242 Mtetra
0 0 0 r
.32649 .50242 .33352 .49661 .34391 .48724 .33673 .49693 Mtetra
.33673 .49693 .34391 .48724 .35441 .47583 .34715 .48852 Mtetra
.34715 .48852 .35441 .47583 .36493 .4639 .3577 .47781 Mtetra
.3577 .47781 .36493 .4639 .3754 .45257 .36833 .46524 Mtetra
.36833 .46524 .3754 .45257 .38574 .44402 .37893 .45298 Mtetra
.37893 .45298 .38574 .44402 .39592 .43972 .38944 .44252 Mtetra
.621 .95 .773 r
.38944 .44252 .39592 .43972 .40599 .43945 .39983 .43487 Mtetra
.685 .817 .946 r
.39983 .43487 .40599 .43945 .41598 .44304 .41012 .43074 Mtetra
.592 .576 .804 r
.41012 .43074 .41598 .44304 .42601 .44832 .42035 .42913 Mtetra
.544 .471 .723 r
.42035 .42913 .42601 .44832 .43612 .45387 .43058 .4294 Mtetra
.535 .432 .685 r
.43058 .4294 .43612 .45387 .44635 .45842 .44086 .43033 Mtetra
.539 .42 .666 r
.44086 .43033 .44635 .45842 .45671 .46109 .45121 .4311 Mtetra
.548 .42 .657 r
.45121 .4311 .45671 .46109 .46718 .46206 .46164 .43126 Mtetra
.56 .425 .654 r
.46164 .43126 .46718 .46206 .47775 .46137 .47215 .43047 Mtetra
.571 .433 .654 r
.47215 .43047 .47775 .46137 .48838 .45951 .48272 .42878 Mtetra
.582 .441 .655 r
.48272 .42878 .48838 .45951 .49908 .45675 .49336 .42616 Mtetra
.592 .448 .655 r
.49336 .42616 .49908 .45675 .50982 .4533 .50405 .42266 Mtetra
.601 .455 .655 r
.50405 .42266 .50982 .4533 .52061 .44914 .51479 .41827 Mtetra
.611 .46 .653 r
.51479 .41827 .52061 .44914 .53143 .44407 .52556 .41295 Mtetra
.619 .466 .652 r
.52556 .41295 .53143 .44407 .54228 .43784 .53636 .4067 Mtetra
.628 .472 .651 r
.53636 .4067 .54228 .43784 .55314 .42991 .54718 .3995 Mtetra
.636 .479 .653 r
.54718 .3995 .55314 .42991 .56399 .42024 .55801 .39167 Mtetra
.643 .489 .659 r
.55801 .39167 .56399 .42024 .57481 .40866 .56885 .38366 Mtetra
.647 .505 .675 r
.56885 .38366 .57481 .40866 .58561 .39603 .57971 .3763 Mtetra
.642 .53 .711 r
.57971 .3763 .58561 .39603 .59639 .38365 .59063 .37084 Mtetra
.621 .59 .797 r
.59063 .37084 .59639 .38365 .60719 .37295 .60165 .36793 Mtetra
.374 .685 .979 r
.60165 .36793 .60719 .37295 .61811 .36617 .61281 .3686 Mtetra
.465 0 0 r
.61281 .3686 .61811 .36617 .62918 .36348 .62414 .37216 Mtetra
.591 .15 .171 r
.62414 .37216 .62918 .36348 .64046 .36513 .63562 .37758 Mtetra
.594 .195 .255 r
.63562 .37758 .64046 .36513 .65193 .36963 .64723 .38334 Mtetra
.558 .169 .26 r
.64723 .38334 .65193 .36963 .66354 .3748 .65888 .38724 Mtetra
.503 .104 .216 r
.65888 .38724 .66354 .3748 .67523 .37945 .67052 .3888 Mtetra
.38 0 .084 r
.67052 .3888 .67523 .37945 .68693 .38203 .6821 .38736 Mtetra
.104 0 0 r
.6821 .38736 .68693 .38203 .6986 .3825 .69361 .38351 Mtetra
.457 .883 .795 r
.69361 .38351 .6986 .3825 .71022 .38079 .70508 .37795 Mtetra
.743 .93 .951 r
.70508 .37795 .71022 .38079 .7218 .37734 .71652 .37132 Mtetra
.758 .817 .899 r
.71652 .37132 .7218 .37734 .73335 .37263 .72796 .36437 Mtetra
.74 .745 .856 r
.72796 .36437 .73335 .37263 .74488 .36709 .73943 .35743 Mtetra
.718 .703 .836 r
.73943 .35743 .74488 .36709 .75643 .36129 .75096 .35096 Mtetra
.701 .683 .829 r
.75096 .35096 .75643 .36129 .768 .35542 .76256 .34499 Mtetra
.686 .675 .833 r
.76256 .34499 .768 .35542 .77964 .34983 .77423 .33966 Mtetra
.675 .676 .843 r
.77423 .33966 .77964 .34983 .79133 .34451 .78599 .33484 Mtetra
.665 .684 .858 r
.78599 .33484 .79133 .34451 .80309 .33956 .79784 .33047 Mtetra
.658 .696 .874 r
.79784 .33047 .80309 .33956 .81492 .33487 .80975 .32642 Mtetra
.653 .711 .89 r
.80975 .32642 .81492 .33487 .82681 .33038 .82174 .32256 Mtetra
.651 .73 .907 r
.82174 .32256 .82681 .33038 .83876 .32602 .83378 .31877 Mtetra
.687 .758 .906 r
.19348 .52013 .20012 .52592 .20971 .52265 .20316 .51616 Mtetra
.686 .736 .889 r
.20316 .51616 .20971 .52265 .21934 .51945 .21288 .51216 Mtetra
.679 .712 .873 r
.21288 .51216 .21934 .51945 .22898 .51644 .22262 .50824 Mtetra
.668 .685 .857 r
.22262 .50824 .22898 .51644 .23864 .51374 .23237 .50454 Mtetra
.654 .657 .841 r
.23237 .50454 .23864 .51374 .24829 .51147 .24213 .50114 Mtetra
.635 .626 .825 r
.24213 .50114 .24829 .51147 .25795 .50969 .25188 .49824 Mtetra
.612 .596 .81 r
.25188 .49824 .25795 .50969 .2676 .50854 .26162 .49603 Mtetra
.587 .566 .798 r
.26162 .49603 .2676 .50854 .27726 .50788 .27134 .49462 Mtetra
.557 .54 .791 r
.27134 .49462 .27726 .50788 .28695 .50769 .28103 .49418 Mtetra
.531 .523 .791 r
.28103 .49418 .28695 .50769 .29668 .50752 .29072 .49456 Mtetra
.501 .515 .803 r
.29072 .49456 .29668 .50752 .30649 .50706 .30041 .49571 Mtetra
.475 .532 .836 r
.30041 .49571 .30649 .50706 .31641 .50556 .31015 .49716 Mtetra
.431 .585 .904 r
.31015 .49716 .31641 .50556 .32649 .50242 .31996 .49855 Mtetra
.284 .682 .972 r
.31996 .49855 .32649 .50242 .33673 .49693 .32986 .49932 Mtetra
.176 0 0 r
.32986 .49932 .33673 .49693 .34715 .48852 .3399 .49896 Mtetra
.355 0 .102 r
.3399 .49896 .34715 .48852 .3577 .47781 .35009 .49675 Mtetra
.378 .04 .26 r
.35009 .49675 .3577 .47781 .36833 .46524 .36045 .49206 Mtetra
.369 .069 .319 r
.36045 .49206 .36833 .46524 .37893 .45298 .37098 .48427 Mtetra
.333 .052 .329 r
.37098 .48427 .37893 .45298 .38944 .44252 .38167 .47305 Mtetra
.28 .005 .305 r
.38167 .47305 .38944 .44252 .39983 .43487 .39245 .45956 Mtetra
.16 0 .22 r
.39245 .45956 .39983 .43487 .41012 .43074 .40325 .4447 Mtetra
0 0 0 r
.40325 .4447 .41012 .43074 .42035 .42913 .414 .43044 Mtetra
.891 .982 .811 r
.414 .43044 .42035 .42913 .43058 .4294 .42467 .41802 Mtetra
.762 .668 .758 r
.42467 .41802 .43058 .4294 .44086 .43033 .43525 .40788 Mtetra
.66 .523 .685 r
.43525 .40788 .44086 .43033 .45121 .4311 .44577 .4003 Mtetra
.615 .462 .651 r
.44577 .4003 .45121 .4311 .46164 .43126 .45627 .39452 Mtetra
.592 .432 .633 r
.45627 .39452 .46164 .43126 .47215 .43047 .46676 .39008 Mtetra
.582 .418 .625 r
.46676 .39008 .47215 .43047 .48272 .42878 .47728 .38629 Mtetra
.578 .412 .62 r
.47728 .38629 .48272 .42878 .49336 .42616 .48784 .38273 Mtetra
.578 .41 .618 r
.48784 .38273 .49336 .42616 .50405 .42266 .49844 .37917 Mtetra
.577 .41 .618 r
.49844 .37917 .50405 .42266 .51479 .41827 .50908 .37561 Mtetra
.576 .41 .62 r
.50908 .37561 .51479 .41827 .52556 .41295 .51975 .37229 Mtetra
.572 .411 .625 r
.51975 .37229 .52556 .41295 .53636 .4067 .53048 .36961 Mtetra
.561 .411 .634 r
.53048 .36961 .53636 .4067 .54718 .3995 .54126 .36828 Mtetra
.542 .413 .654 r
.54126 .36828 .54718 .3995 .55801 .39167 .55211 .36879 Mtetra
.492 .416 .699 r
.55211 .36879 .55801 .39167 .56885 .38366 .56306 .37189 Mtetra
.3 .427 .823 r
.56306 .37189 .56885 .38366 .57971 .3763 .57414 .37733 Mtetra
.612 .056 0 r
.57414 .37733 .57971 .3763 .59063 .37084 .58537 .38467 Mtetra
.63 .243 .293 r
.58537 .38467 .59063 .37084 .60165 .36793 .59672 .39264 Mtetra
.589 .258 .377 r
.59672 .39264 .60165 .36793 .61281 .3686 .60817 .39928 Mtetra
.559 .248 .397 r
.60817 .39928 .61281 .3686 .62414 .37216 .61967 .40363 Mtetra
.522 .217 .392 r
.61967 .40363 .62414 .37216 .63562 .37758 .63116 .4045 Mtetra
.476 .164 .358 r
.63116 .4045 .63562 .37758 .64723 .38334 .64261 .40221 Mtetra
.39 .053 .269 r
.64261 .40221 .64723 .38334 .65888 .38724 .65402 .39737 Mtetra
.158 0 .009 r
.65402 .39737 .65888 .38724 .67052 .3888 .66538 .39063 Mtetra
.576 .93 .755 r
.66538 .39063 .67052 .3888 .6821 .38736 .67672 .38271 Mtetra
.808 .871 .893 r
.67672 .38271 .6821 .38736 .69361 .38351 .68803 .37414 Mtetra
.764 .725 .817 r
.68803 .37414 .69361 .38351 .70508 .37795 .69936 .36548 Mtetra
.729 .656 .777 r
.69936 .36548 .70508 .37795 .71652 .37132 .71071 .35711 Mtetra
.703 .621 .762 r
.71071 .35711 .71652 .37132 .72796 .36437 .72213 .34953 Mtetra
.685 .604 .76 r
.72213 .34953 .72796 .36437 .73943 .35743 .73363 .34279 Mtetra
.669 .598 .768 r
.73363 .34279 .73943 .35743 .75096 .35096 .74521 .33704 Mtetra
.657 .602 .781 r
.74521 .33704 .75096 .35096 .76256 .34499 .7569 .33211 Mtetra
.647 .612 .801 r
.7569 .33211 .76256 .34499 .77423 .33966 .76868 .32789 Mtetra
.639 .628 .823 r
.76868 .32789 .77423 .33966 .78599 .33484 .78055 .32419 Mtetra
.634 .648 .847 r
.78055 .32419 .78599 .33484 .79784 .33047 .7925 .32081 Mtetra
.629 .669 .869 r
.7925 .32081 .79784 .33047 .80975 .32642 .80453 .31764 Mtetra
.626 .692 .891 r
.80453 .31764 .80975 .32642 .82174 .32256 .81662 .31457 Mtetra
.626 .715 .911 r
.81662 .31457 .82174 .32256 .83378 .31877 .82876 .31146 Mtetra
.7 .761 .899 r
.18679 .51429 .19348 .52013 .20316 .51616 .19653 .50993 Mtetra
.702 .749 .889 r
.19653 .50993 .20316 .51616 .21288 .51216 .20632 .50545 Mtetra
.7 .735 .878 r
.20632 .50545 .21288 .51216 .22262 .50824 .21614 .50091 Mtetra
.696 .717 .865 r
.21614 .50091 .22262 .50824 .23237 .50454 .22598 .49638 Mtetra
.69 .695 .849 r
.22598 .49638 .23237 .50454 .24213 .50114 .23585 .49188 Mtetra
.676 .666 .832 r
.23585 .49188 .24213 .50114 .25188 .49824 .24572 .48763 Mtetra
.659 .632 .812 r
.24572 .48763 .25188 .49824 .26162 .49603 .2556 .48378 Mtetra
.635 .595 .792 r
.2556 .48378 .26162 .49603 .27134 .49462 .26545 .48058 Mtetra
.607 .556 .772 r
.26545 .48058 .27134 .49462 .28103 .49418 .27528 .47826 Mtetra
.579 .519 .752 r
.27528 .47826 .28103 .49418 .29072 .49456 .28507 .47697 Mtetra
.549 .486 .737 r
.28507 .47697 .29072 .49456 .30041 .49571 .29483 .4769 Mtetra
.523 .46 .727 r
.29483 .4769 .30041 .49571 .31015 .49716 .30457 .47795 Mtetra
.496 .44 .724 r
.30457 .47795 .31015 .49716 .31996 .49855 .3143 .48007 Mtetra
.474 .433 .732 r
.3143 .48007 .31996 .49855 .32986 .49932 .32406 .48293 Mtetra
.447 .439 .757 r
.32406 .48293 .32986 .49932 .3399 .49896 .33387 .4862 Mtetra
.434 .485 .813 r
.33387 .4862 .3399 .49896 .35009 .49675 .34379 .48887 Mtetra
.427 .603 .92 r
.34379 .48887 .35009 .49675 .36045 .49206 .35387 .49009 Mtetra
.392 .81 .974 r
.35387 .49009 .36045 .49206 .37098 .48427 .36414 .48866 Mtetra
0 0 0 r
.36414 .48866 .37098 .48427 .38167 .47305 .37462 .48373 Mtetra
.029 0 0 r
.37462 .48373 .38167 .47305 .39245 .45956 .38525 .47584 Mtetra
.117 0 .099 r
.38525 .47584 .39245 .45956 .40325 .4447 .396 .46544 Mtetra
.199 0 .198 r
.396 .46544 .40325 .4447 .414 .43044 .40677 .4542 Mtetra
.261 0 .254 r
.40677 .4542 .414 .43044 .42467 .41802 .41753 .44322 Mtetra
.308 .01 .285 r
.41753 .44322 .42467 .41802 .43525 .40788 .42824 .43328 Mtetra
.347 .045 .303 r
.42824 .43328 .43525 .40788 .44577 .4003 .43892 .42488 Mtetra
.372 .064 .307 r
.43892 .42488 .44577 .4003 .45627 .39452 .44957 .41783 Mtetra
.391 .075 .305 r
.44957 .41783 .45627 .39452 .46676 .39008 .46022 .41203 Mtetra
.402 .079 .299 r
.46022 .41203 .46676 .39008 .47728 .38629 .47088 .40715 Mtetra
.411 .082 .294 r
.47088 .40715 .47728 .38629 .48784 .38273 .48156 .40299 Mtetra
.421 .088 .292 r
.48156 .40299 .48784 .38273 .49844 .37917 .49227 .39943 Mtetra
.435 .1 .297 r
.49227 .39943 .49844 .37917 .50908 .37561 .50302 .39646 Mtetra
.453 .12 .309 r
.50302 .39646 .50908 .37561 .51975 .37229 .51381 .39423 Mtetra
.475 .145 .326 r
.51381 .39423 .51975 .37229 .53048 .36961 .52466 .39291 Mtetra
.5 .173 .344 r
.52466 .39291 .53048 .36961 .54126 .36828 .53557 .39287 Mtetra
.522 .198 .359 r
.53557 .39287 .54126 .36828 .55211 .36879 .54655 .3942 Mtetra
.544 .22 .369 r
.54655 .3942 .55211 .36879 .56306 .37189 .55763 .39712 Mtetra
.557 .231 .371 r
.55763 .39712 .56306 .37189 .57414 .37733 .56882 .4011 Mtetra
.561 .228 .362 r
.56882 .4011 .57414 .37733 .58537 .38467 .5801 .40537 Mtetra
.55 .205 .336 r
.5801 .40537 .58537 .38467 .59672 .39264 .59147 .40883 Mtetra
.499 .13 .271 r
.59147 .40883 .59672 .39264 .60817 .39928 .60288 .40974 Mtetra
.367 0 .103 r
.60288 .40974 .60817 .39928 .61967 .40363 .61428 .40765 Mtetra
0 0 0 r
.61428 .40765 .61967 .40363 .63116 .4045 .62563 .40199 Mtetra
.805 .941 .916 r
.62563 .40199 .63116 .4045 .64261 .40221 .63691 .39359 Mtetra
.792 .748 .813 r
.63691 .39359 .64261 .40221 .65402 .39737 .64815 .38369 Mtetra
.75 .648 .749 r
.64815 .38369 .65402 .39737 .66538 .39063 .65937 .37315 Mtetra
.715 .593 .719 r
.65937 .37315 .66538 .39063 .67672 .38271 .6706 .36302 Mtetra
.693 .564 .706 r
.6706 .36302 .67672 .38271 .68803 .37414 .68187 .35361 Mtetra
.675 .549 .703 r
.68187 .35361 .68803 .37414 .69936 .36548 .69321 .3453 Mtetra
.662 .544 .709 r
.69321 .3453 .69936 .36548 .71071 .35711 .70462 .33813 Mtetra
.65 .545 .723 r
.70462 .33813 .71071 .35711 .72213 .34953 .71614 .3322 Mtetra
.64 .554 .742 r
.71614 .3322 .72213 .34953 .73363 .34279 .72775 .32733 Mtetra
.631 .569 .766 r
.72775 .32733 .73363 .34279 .74521 .33704 .73947 .32337 Mtetra
.623 .588 .794 r
.73947 .32337 .74521 .33704 .7569 .33211 .75129 .32009 Mtetra
.617 .612 .824 r
.75129 .32009 .7569 .33211 .76868 .32789 .76319 .31722 Mtetra
.611 .637 .852 r
.76319 .31722 .76868 .32789 .78055 .32419 .77517 .31461 Mtetra
.61 .663 .876 r
.77517 .31461 .78055 .32419 .7925 .32081 .78722 .31204 Mtetra
.608 .684 .896 r
.78722 .31204 .7925 .32081 .80453 .31764 .79932 .30947 Mtetra
.608 .702 .911 r
.79932 .30947 .80453 .31764 .81662 .31457 .81149 .30685 Mtetra
.611 .719 .922 r
.81149 .30685 .81662 .31457 .82876 .31146 .82371 .3041 Mtetra
.698 .76 .9 r
.18006 .50842 .18679 .51429 .19653 .50993 .18982 .50409 Mtetra
.704 .763 .898 r
.18982 .50409 .19653 .50993 .20632 .50545 .19963 .49958 Mtetra
.709 .764 .895 r
.19963 .49958 .20632 .50545 .21614 .50091 .20948 .49488 Mtetra
.715 .761 .889 r
.20948 .49488 .21614 .50091 .22598 .49638 .21938 .48996 Mtetra
.72 .751 .876 r
.21938 .48996 .22598 .49638 .23585 .49188 .22934 .48476 Mtetra
.719 .731 .86 r
.22934 .48476 .23585 .49188 .24572 .48763 .23933 .47941 Mtetra
.713 .702 .839 r
.23933 .47941 .24572 .48763 .2556 .48378 .24935 .47396 Mtetra
.697 .663 .813 r
.24935 .47396 .2556 .48378 .26545 .48058 .25938 .46867 Mtetra
.675 .62 .786 r
.25938 .46867 .26545 .48058 .27528 .47826 .26941 .46373 Mtetra
.647 .572 .757 r
.26941 .46373 .27528 .47826 .28507 .47697 .27942 .45948 Mtetra
.616 .526 .73 r
.27942 .45948 .28507 .47697 .29483 .4769 .28938 .45623 Mtetra
.586 .485 .706 r
.28938 .45623 .29483 .4769 .30457 .47795 .2993 .45419 Mtetra
.557 .449 .686 r
.2993 .45419 .30457 .47795 .3143 .48007 .30917 .45362 Mtetra
.536 .422 .671 r
.30917 .45362 .3143 .48007 .32406 .48293 .31902 .45428 Mtetra
.519 .402 .66 r
.31902 .45428 .32406 .48293 .33387 .4862 .32886 .45606 Mtetra
.509 .391 .654 r
.32886 .45606 .33387 .4862 .34379 .48887 .33873 .45856 Mtetra
.503 .386 .653 r
.33873 .45856 .34379 .48887 .35387 .49009 .34865 .46148 Mtetra
.49 .384 .661 r
.34865 .46148 .35387 .49009 .36414 .48866 .35862 .46501 Mtetra
.464 .391 .689 r
.35862 .46501 .36414 .48866 .37462 .48373 .36864 .46912 Mtetra
.382 .427 .783 r
.36864 .46912 .37462 .48373 .38525 .47584 .37874 .47354 Mtetra
.319 0 0 r
.37874 .47354 .38525 .47584 .396 .46544 .38893 .47789 Mtetra
.548 .153 .245 r
.38893 .47789 .396 .46544 .40677 .4542 .39925 .4811 Mtetra
.524 .207 .372 r
.39925 .4811 .40677 .4542 .41753 .44322 .40972 .4825 Mtetra
.509 .221 .412 r
.40972 .4825 .41753 .44322 .42824 .43328 .42033 .48186 Mtetra
.497 .223 .428 r
.42033 .48186 .42824 .43328 .43892 .42488 .43106 .47918 Mtetra
.491 .224 .436 r
.43106 .47918 .43892 .42488 .44957 .41783 .44186 .47522 Mtetra
.489 .224 .439 r
.44186 .47522 .44957 .41783 .46022 .41203 .45272 .47054 Mtetra
.49 .226 .441 r
.45272 .47054 .46022 .41203 .47088 .40715 .46362 .46587 Mtetra
.493 .229 .442 r
.46362 .46587 .47088 .40715 .48156 .40299 .47454 .46165 Mtetra
.498 .233 .443 r
.47454 .46165 .48156 .40299 .49227 .39943 .4855 .45812 Mtetra
.503 .237 .444 r
.4855 .45812 .49227 .39943 .50302 .39646 .49649 .45528 Mtetra
.506 .24 .445 r
.49649 .45528 .50302 .39646 .51381 .39423 .50753 .4529 Mtetra
.50753 .4529 .51381 .39423 .52466 .39291 .51862 .45052 Mtetra
.501 .234 .442 r
.51862 .45052 .52466 .39291 .53557 .39287 .52977 .44743 Mtetra
.489 .222 .435 r
.52977 .44743 .53557 .39287 .54655 .3942 .54096 .44305 Mtetra
.466 .196 .421 r
.54096 .44305 .54655 .3942 .55763 .39712 .55217 .4366 Mtetra
.424 .148 .389 r
.55217 .4366 .55763 .39712 .56882 .4011 .56338 .42807 Mtetra
.329 .037 .307 r
.56338 .42807 .56882 .4011 .5801 .40537 .57457 .41768 Mtetra
0 0 0 r
.57457 .41768 .5801 .40537 .59147 .40883 .58575 .4061 Mtetra
.878 .919 .849 r
.58575 .4061 .59147 .40883 .60288 .40974 .59691 .39443 Mtetra
.746 .628 .729 r
.59691 .39443 .60288 .40974 .61428 .40765 .60806 .38303 Mtetra
.683 .532 .674 r
.60806 .38303 .61428 .40765 .62563 .40199 .61923 .37222 Mtetra
.658 .496 .654 r
.61923 .37222 .62563 .40199 .63691 .39359 .63041 .36199 Mtetra
.648 .485 .648 r
.63041 .36199 .63691 .39359 .64815 .38369 .64161 .35218 Mtetra
.642 .481 .649 r
.64161 .35218 .64815 .38369 .65937 .37315 .65284 .34308 Mtetra
.635 .481 .656 r
.65284 .34308 .65937 .37315 .6706 .36302 .66413 .33512 Mtetra
.629 .484 .666 r
.66413 .33512 .6706 .36302 .68187 .35361 .67549 .32841 Mtetra
.619 .489 .682 r
.67549 .32841 .68187 .35361 .69321 .3453 .68696 .32319 Mtetra
.61 .5 .703 r
.68696 .32319 .69321 .3453 .70462 .33813 .69854 .31923 Mtetra
.601 .518 .732 r
.69854 .31923 .70462 .33813 .71614 .3322 .71022 .3163 Mtetra
.593 .543 .767 r
.71022 .3163 .71614 .3322 .72775 .32733 .72201 .31408 Mtetra
.588 .576 .807 r
.72201 .31408 .72775 .32733 .73947 .32337 .73388 .31223 Mtetra
.583 .612 .847 r
.73388 .31223 .73947 .32337 .75129 .32009 .74583 .31056 Mtetra
.583 .65 .882 r
.74583 .31056 .75129 .32009 .76319 .31722 .75784 .30878 Mtetra
.584 .682 .908 r
.75784 .30878 .76319 .31722 .77517 .31461 .7699 .30685 Mtetra
.591 .707 .924 r
.7699 .30685 .77517 .31461 .78722 .31204 .78201 .30463 Mtetra
.597 .722 .932 r
.78201 .30463 .78722 .31204 .79932 .30947 .79417 .30218 Mtetra
.604 .73 .934 r
.79417 .30218 .79932 .30947 .81149 .30685 .80636 .29952 Mtetra
.611 .733 .933 r
.80636 .29952 .81149 .30685 .82371 .3041 .81861 .29669 Mtetra
.677 .756 .911 r
.17328 .5025 .18006 .50842 .18982 .50409 .183 .49875 Mtetra
.683 .778 .923 r
.183 .49875 .18982 .50409 .19963 .49958 .19278 .49485 Mtetra
.692 .802 .933 r
.19278 .49485 .19963 .49958 .20948 .49488 .2026 .49069 Mtetra
.705 .824 .939 r
.2026 .49069 .20948 .49488 .21938 .48996 .21249 .4862 Mtetra
.721 .843 .939 r
.21249 .4862 .21938 .48996 .22934 .48476 .22245 .48127 Mtetra
.737 .855 .936 r
.22245 .48127 .22934 .48476 .23933 .47941 .23247 .47591 Mtetra
.753 .856 .926 r
.23247 .47591 .23933 .47941 .24935 .47396 .24256 .47007 Mtetra
.761 .843 .913 r
.24256 .47007 .24935 .47396 .25938 .46867 .25269 .46392 Mtetra
.762 .814 .893 r
.25269 .46392 .25938 .46867 .26941 .46373 .26287 .45754 Mtetra
.749 .767 .868 r
.26287 .45754 .26941 .46373 .27942 .45948 .27305 .45124 Mtetra
.724 .708 .836 r
.27305 .45124 .27942 .45948 .28938 .45623 .28324 .44526 Mtetra
.689 .642 .798 r
.28324 .44526 .28938 .45623 .2993 .45419 .29339 .43993 Mtetra
.65 .578 .761 r
.29339 .43993 .2993 .45419 .30917 .45362 .30351 .43554 Mtetra
.616 .522 .726 r
.30351 .43554 .30917 .45362 .31902 .45428 .3136 .43216 Mtetra
.586 .477 .696 r
.3136 .43216 .31902 .45428 .32886 .45606 .32365 .42992 Mtetra
.561 .441 .673 r
.32365 .42992 .32886 .45606 .33873 .45856 .33367 .42897 Mtetra
.538 .412 .657 r
.33367 .42897 .33873 .45856 .34865 .46148 .34367 .42943 Mtetra
.514 .388 .646 r
.34367 .42943 .34865 .46148 .35862 .46501 .35364 .43163 Mtetra
.489 .367 .64 r
.35364 .43163 .35862 .46501 .36864 .46912 .36359 .43566 Mtetra
.473 .356 .639 r
.36359 .43566 .36864 .46912 .37874 .47354 .37358 .44078 Mtetra
.464 .352 .642 r
.37358 .44078 .37874 .47354 .38893 .47789 .38364 .44634 Mtetra
.475 .364 .648 r
.38364 .44634 .38893 .47789 .39925 .4811 .39383 .45107 Mtetra
.5 .387 .657 r
.39383 .45107 .39925 .4811 .40972 .4825 .40418 .45414 Mtetra
.527 .412 .666 r
.40418 .45414 .40972 .4825 .42033 .48186 .41468 .45534 Mtetra
.557 .44 .676 r
.41468 .45534 .42033 .48186 .43106 .47918 .4253 .4546 Mtetra
.579 .464 .686 r
.4253 .4546 .43106 .47918 .44186 .47522 .43603 .45252 Mtetra
.596 .485 .698 r
.43603 .45252 .44186 .47522 .45272 .47054 .44682 .44951 Mtetra
.607 .502 .709 r
.44682 .44951 .45272 .47054 .46362 .46587 .45768 .44606 Mtetra
.612 .514 .719 r
.45768 .44606 .46362 .46587 .47454 .46165 .46857 .44247 Mtetra
.613 .52 .724 r
.46857 .44247 .47454 .46165 .4855 .45812 .47952 .4389 Mtetra
.613 .519 .724 r
.47952 .4389 .4855 .45812 .49649 .45528 .4905 .43535 Mtetra
.613 .514 .718 r
.4905 .43535 .49649 .45528 .50753 .4529 .50153 .43166 Mtetra
.616 .508 .708 r
.50153 .43166 .50753 .4529 .51862 .45052 .51261 .42754 Mtetra
.624 .503 .694 r
.51261 .42754 .51862 .45052 .52977 .44743 .52373 .42246 Mtetra
.635 .5 .68 r
.52373 .42246 .52977 .44743 .54096 .44305 .53488 .41604 Mtetra
.65 .501 .667 r
.53488 .41604 .54096 .44305 .55217 .4366 .54604 .40763 Mtetra
.662 .501 .657 r
.54604 .40763 .55217 .4366 .56338 .42807 .55719 .39732 Mtetra
.67 .501 .648 r
.55719 .39732 .56338 .42807 .57457 .41768 .56833 .38529 Mtetra
.672 .498 .642 r
.56833 .38529 .57457 .41768 .58575 .4061 .57943 .37239 Mtetra
.664 .489 .638 r
.57943 .37239 .58575 .4061 .59691 .39443 .59053 .35991 Mtetra
.653 .48 .637 r
.59053 .35991 .59691 .39443 .60806 .38303 .60163 .3485 Mtetra
.638 .47 .639 r
.60163 .3485 .60806 .38303 .61923 .37222 .61278 .33895 Mtetra
.626 .464 .644 r
.61278 .33895 .61923 .37222 .63041 .36199 .62398 .33115 Mtetra
.617 .466 .654 r
.62398 .33115 .63041 .36199 .64161 .35218 .63526 .32478 Mtetra
.611 .474 .67 r
.63526 .32478 .64161 .35218 .65284 .34308 .64661 .31972 Mtetra
.605 .489 .694 r
.64661 .31972 .65284 .34308 .66413 .33512 .65805 .31583 Mtetra
.599 .512 .728 r
.65805 .31583 .66413 .33512 .67549 .32841 .66959 .31298 Mtetra
.586 .544 .774 r
.66959 .31298 .67549 .32841 .68696 .32319 .68123 .3111 Mtetra
.57 .585 .83 r
.68123 .3111 .68696 .32319 .69854 .31923 .69297 .3099 Mtetra
.548 .636 .89 r
.69297 .3099 .69854 .31923 .71022 .3163 .70479 .30903 Mtetra
.521 .687 .943 r
.70479 .30903 .71022 .3163 .72201 .31408 .7167 .30825 Mtetra
.503 .733 .976 r
.7167 .30825 .72201 .31408 .73388 .31223 .72866 .30725 Mtetra
.498 .765 .991 r
.72866 .30725 .73388 .31223 .74583 .31056 .74068 .30592 Mtetra
.516 .789 .995 r
.74068 .30592 .74583 .31056 .75784 .30878 .75273 .3041 Mtetra
.544 .802 .993 r
.75273 .3041 .75784 .30878 .7699 .30685 .76481 .30184 Mtetra
.577 .804 .986 r
.76481 .30184 .7699 .30685 .78201 .30463 .77693 .29912 Mtetra
.603 .797 .974 r
.77693 .29912 .78201 .30463 .79417 .30218 .78907 .29605 Mtetra
.622 .782 .958 r
.78907 .29605 .79417 .30218 .80636 .29952 .80125 .29271 Mtetra
.633 .763 .941 r
.80125 .29271 .80636 .29952 .81861 .29669 .81347 .28921 Mtetra
.638 .747 .927 r
.16646 .49655 .17328 .5025 .183 .49875 .1761 .49372 Mtetra
.637 .78 .95 r
.1761 .49372 .183 .49875 .19278 .49485 .1858 .49079 Mtetra
.638 .819 .97 r
.1858 .49079 .19278 .49485 .2026 .49069 .19555 .48767 Mtetra
.64 .86 .983 r
.19555 .48767 .2026 .49069 .21249 .4862 .20537 .48422 Mtetra
.642 .898 .984 r
.20537 .48422 .21249 .4862 .22245 .48127 .21526 .48034 Mtetra
.641 .93 .971 r
.21526 .48034 .22245 .48127 .23247 .47591 .22524 .47592 Mtetra
.645 .952 .945 r
.22524 .47592 .23247 .47591 .24256 .47007 .2353 .47087 Mtetra
.651 .964 .915 r
.2353 .47087 .24256 .47007 .25269 .46392 .24544 .46517 Mtetra
.675 .975 .895 r
.24544 .46517 .25269 .46392 .26287 .45754 .25566 .45878 Mtetra
.712 .983 .894 r
.25566 .45878 .26287 .45754 .27305 .45124 .26595 .45183 Mtetra
.764 .983 .908 r
.26595 .45183 .27305 .45124 .28324 .44526 .27629 .44437 Mtetra
.802 .949 .917 r
.27629 .44437 .28324 .44526 .29339 .43993 .28666 .43666 Mtetra
.805 .869 .895 r
.28666 .43666 .29339 .43993 .30351 .43554 .29705 .42888 Mtetra
.768 .761 .846 r
.29705 .42888 .30351 .43554 .3136 .43216 .30743 .42145 Mtetra
.718 .66 .792 r
.30743 .42145 .3136 .43216 .32365 .42992 .31778 .4147 Mtetra
.667 .578 .746 r
.31778 .4147 .32365 .42992 .33367 .42897 .32808 .40906 Mtetra
.623 .514 .709 r
.32808 .40906 .33367 .42897 .34367 .42943 .33831 .40484 Mtetra
.596 .471 .68 r
.33831 .40484 .34367 .42943 .35364 .43163 .34854 .40157 Mtetra
.579 .439 .654 r
.34854 .40157 .35364 .43163 .36359 .43566 .35877 .39893 Mtetra
.573 .417 .632 r
.35877 .39893 .36359 .43566 .37358 .44078 .36905 .39614 Mtetra
.572 .402 .613 r
.36905 .39614 .37358 .44078 .38364 .44634 .3794 .39277 Mtetra
.567 .388 .599 r
.3794 .39277 .38364 .44634 .39383 .45107 .3898 .38919 Mtetra
.563 .378 .589 r
.3898 .38919 .39383 .45107 .40418 .45414 .40024 .3856 Mtetra
.557 .369 .582 r
.40024 .3856 .40418 .45414 .41468 .45534 .41071 .38252 Mtetra
.552 .363 .578 r
.41071 .38252 .41468 .45534 .4253 .4546 .42119 .38012 Mtetra
.549 .36 .577 r
.42119 .38012 .4253 .4546 .43603 .45252 .43171 .37815 Mtetra
.548 .359 .577 r
.43171 .37815 .43603 .45252 .44682 .44951 .44228 .37635 Mtetra
.55 .361 .578 r
.44228 .37635 .44682 .44951 .45768 .44606 .45291 .37421 Mtetra
.554 .365 .58 r
.45291 .37421 .45768 .44606 .46857 .44247 .4636 .37142 Mtetra
.559 .369 .581 r
.4636 .37142 .46857 .44247 .47952 .4389 .47436 .36777 Mtetra
.564 .373 .581 r
.47436 .36777 .47952 .4389 .4905 .43535 .48517 .36325 Mtetra
.566 .374 .58 r
.48517 .36325 .4905 .43535 .50153 .43166 .49602 .35809 Mtetra
.568 .374 .579 r
.49602 .35809 .50153 .43166 .51261 .42754 .5069 .35257 Mtetra
.566 .373 .578 r
.5069 .35257 .51261 .42754 .52373 .42246 .51782 .34722 Mtetra
.564 .371 .578 r
.51782 .34722 .52373 .42246 .53488 .41604 .52877 .34229 Mtetra
.561 .369 .579 r
.52877 .34229 .53488 .41604 .54604 .40763 .53976 .33805 Mtetra
.56 .371 .582 r
.53976 .33805 .54604 .40763 .55719 .39732 .55079 .33432 Mtetra
.562 .378 .589 r
.55079 .33432 .55719 .39732 .56833 .38529 .56187 .33058 Mtetra
.568 .389 .599 r
.56187 .33058 .56833 .38529 .57943 .37239 .57299 .32662 Mtetra
.579 .407 .613 r
.57299 .32662 .57943 .37239 .59053 .35991 .58414 .32207 Mtetra
.589 .428 .632 r
.58414 .32207 .59053 .35991 .60163 .3485 .59533 .31737 Mtetra
.592 .448 .654 r
.59533 .31737 .60163 .3485 .61278 .33895 .60657 .31332 Mtetra
.589 .467 .681 r
.60657 .31332 .61278 .33895 .62398 .33115 .61789 .31021 Mtetra
.574 .484 .715 r
.61789 .31021 .62398 .33115 .63526 .32478 .6293 .30857 Mtetra
.553 .515 .767 r
.6293 .30857 .63526 .32478 .64661 .31972 .64083 .30807 Mtetra
.521 .567 .843 r
.64083 .30807 .64661 .31972 .65805 .31583 .65245 .30829 Mtetra
.453 .642 .938 r
.65245 .30829 .65805 .31583 .66959 .31298 .66417 .30887 Mtetra
.315 .7 .979 r
.66417 .30887 .66959 .31298 .68123 .3111 .67597 .3094 Mtetra
.141 .666 .875 r
.67597 .3094 .68123 .3111 .69297 .3099 .68784 .30968 Mtetra
.045 .613 .746 r
.68784 .30968 .69297 .3099 .70479 .30903 .69976 .30945 Mtetra
0 0 0 r
.69976 .30945 .70479 .30903 .7167 .30825 .71172 .30864 Mtetra
.114 .666 .732 r
.71172 .30864 .7167 .30825 .72866 .30725 .72371 .30712 Mtetra
.231 .75 .816 r
.72371 .30712 .72866 .30725 .74068 .30592 .73573 .30493 Mtetra
.375 .834 .91 r
.73573 .30493 .74068 .30592 .75273 .3041 .74776 .30208 Mtetra
.499 .879 .972 r
.74776 .30208 .75273 .3041 .76481 .30184 .75982 .29868 Mtetra
.587 .883 .992 r
.75982 .29868 .76481 .30184 .77693 .29912 .77189 .29482 Mtetra
.637 .86 .984 r
.77189 .29482 .77693 .29912 .78907 .29605 .78399 .29062 Mtetra
.661 .826 .963 r
.78399 .29062 .78907 .29605 .80125 .29271 .79612 .2862 Mtetra
.67 .791 .939 r
.79612 .2862 .80125 .29271 .81347 .28921 .8083 .28168 Mtetra
.594 .734 .942 r
.15958 .49055 .16646 .49655 .1761 .49372 .16916 .48857 Mtetra
.583 .763 .964 r
.16916 .48857 .1761 .49372 .1858 .49079 .17877 .4866 Mtetra
.571 .797 .985 r
.17877 .4866 .1858 .49079 .19555 .48767 .18844 .48452 Mtetra
.554 .833 .997 r
.18844 .48452 .19555 .48767 .20537 .48422 .19817 .48227 Mtetra
.526 .865 .993 r
.19817 .48227 .20537 .48422 .21526 .48034 .20796 .47974 Mtetra
.48 .881 .952 r
.20796 .47974 .21526 .48034 .22524 .47592 .21784 .4768 Mtetra
.416 .864 .864 r
.21784 .4768 .22524 .47592 .2353 .47087 .22781 .47332 Mtetra
.336 .808 .731 r
.22781 .47332 .2353 .47087 .24544 .46517 .23786 .4692 Mtetra
0 0 0 r
.23786 .4692 .24544 .46517 .25566 .45878 .24802 .4643 Mtetra
.24802 .4643 .25566 .45878 .26595 .45183 .25827 .4586 Mtetra
.25827 .4586 .26595 .45183 .27629 .44437 .2686 .45204 Mtetra
.2686 .45204 .27629 .44437 .28666 .43666 .27902 .44476 Mtetra
.27902 .44476 .28666 .43666 .29705 .42888 .28949 .43684 Mtetra
.28949 .43684 .29705 .42888 .30743 .42145 .29999 .42865 Mtetra
.29999 .42865 .30743 .42145 .31778 .4147 .31051 .4205 Mtetra
.31051 .4205 .31778 .4147 .32808 .40906 .32101 .41264 Mtetra
.545 .909 .723 r
.32101 .41264 .32808 .40906 .33831 .40484 .33149 .40529 Mtetra
.743 .983 .908 r
.33149 .40529 .33831 .40484 .34854 .40157 .34198 .39802 Mtetra
.792 .869 .905 r
.34198 .39802 .34854 .40157 .35877 .39893 .3525 .39063 Mtetra
.753 .724 .825 r
.3525 .39063 .35877 .39893 .36905 .39614 .36303 .38314 Mtetra
.712 .628 .762 r
.36303 .38314 .36905 .39614 .3794 .39277 .37358 .37562 Mtetra
.673 .566 .725 r
.37358 .37562 .3794 .39277 .3898 .38919 .38411 .36886 Mtetra
.641 .524 .704 r
.38411 .36886 .3898 .38919 .40024 .3856 .39462 .36326 Mtetra
.615 .496 .694 r
.39462 .36326 .40024 .3856 .41071 .38252 .4051 .35896 Mtetra
.593 .475 .688 r
.4051 .35896 .41071 .38252 .42119 .38012 .41557 .35592 Mtetra
.582 .465 .685 r
.41557 .35592 .42119 .38012 .43171 .37815 .42607 .35355 Mtetra
.577 .46 .683 r
.42607 .35355 .43171 .37815 .44228 .37635 .43661 .35143 Mtetra
.581 .461 .681 r
.43661 .35143 .44228 .37635 .45291 .37421 .44721 .34906 Mtetra
.589 .466 .68 r
.44721 .34906 .45291 .37421 .4636 .37142 .45787 .3461 Mtetra
.599 .471 .678 r
.45787 .3461 .4636 .37142 .47436 .36777 .46859 .34241 Mtetra
.608 .478 .677 r
.46859 .34241 .47436 .36777 .48517 .36325 .47936 .33798 Mtetra
.616 .483 .677 r
.47936 .33798 .48517 .36325 .49602 .35809 .49018 .33296 Mtetra
.62 .486 .678 r
.49018 .33296 .49602 .35809 .5069 .35257 .50103 .32768 Mtetra
.617 .486 .68 r
.50103 .32768 .5069 .35257 .51782 .34722 .51192 .32265 Mtetra
.609 .482 .683 r
.51192 .32265 .51782 .34722 .52877 .34229 .52284 .31828 Mtetra
.592 .475 .688 r
.52284 .31828 .52877 .34229 .53976 .33805 .5338 .3152 Mtetra
.574 .47 .698 r
.5338 .3152 .53976 .33805 .55079 .33432 .54481 .31342 Mtetra
.554 .47 .715 r
.54481 .31342 .55079 .33432 .56187 .33058 .5559 .31283 Mtetra
.537 .487 .747 r
.5559 .31283 .56187 .33058 .57299 .32662 .56707 .31301 Mtetra
.529 .535 .805 r
.56707 .31301 .57299 .32662 .58414 .32207 .57831 .31319 Mtetra
.502 .623 .903 r
.57831 .31319 .58414 .32207 .59533 .31737 .58962 .31326 Mtetra
.364 .727 .988 r
.58962 .31326 .59533 .31737 .60657 .31332 .60101 .31323 Mtetra
.001 .578 .714 r
.60101 .31323 .60657 .31332 .61789 .31021 .61247 .31329 Mtetra
.284 0 0 r
.61247 .31329 .61789 .31021 .6293 .30857 .62402 .31389 Mtetra
.384 0 0 r
.62402 .31389 .6293 .30857 .64083 .30807 .63567 .31481 Mtetra
.416 0 0 r
.63567 .31481 .64083 .30807 .65245 .30829 .6474 .31576 Mtetra
.417 0 .013 r
.6474 .31576 .65245 .30829 .66417 .30887 .6592 .31647 Mtetra
.392 0 .004 r
.6592 .31647 .66417 .30887 .67597 .3094 .67106 .31652 Mtetra
.348 0 0 r
.67106 .31652 .67597 .3094 .68784 .30968 .68296 .31584 Mtetra
.275 0 0 r
.68296 .31584 .68784 .30968 .69976 .30945 .69489 .31428 Mtetra
.165 0 0 r
.69489 .31428 .69976 .30945 .71172 .30864 .70684 .31189 Mtetra
0 0 0 r
.70684 .31189 .71172 .30864 .72371 .30712 .7188 .3087 Mtetra
.218 .727 .673 r
.7188 .3087 .72371 .30712 .73573 .30493 .73078 .30483 Mtetra
.433 .874 .864 r
.73078 .30483 .73573 .30493 .74776 .30208 .74277 .3004 Mtetra
.581 .925 .958 r
.74277 .3004 .74776 .30208 .75982 .29868 .75477 .29554 Mtetra
.658 .911 .979 r
.75477 .29554 .75982 .29868 .77189 .29482 .7668 .29038 Mtetra
.691 .875 .968 r
.7668 .29038 .77189 .29482 .78399 .29062 .77886 .28503 Mtetra
.702 .837 .947 r
.77886 .28503 .78399 .29062 .79612 .2862 .79095 .27956 Mtetra
.703 .801 .926 r
.79095 .27956 .79612 .2862 .8083 .28168 .80308 .27409 Mtetra
.56 .723 .95 r
.15266 .48451 .15958 .49055 .16916 .48857 .16219 .48308 Mtetra
.545 .739 .965 r
.16219 .48308 .16916 .48857 .17877 .4866 .17175 .48174 Mtetra
.528 .758 .981 r
.17175 .48174 .17877 .4866 .18844 .48452 .18136 .48044 Mtetra
.503 .78 .994 r
.18136 .48044 .18844 .48452 .19817 .48227 .19102 .47915 Mtetra
.461 .801 .999 r
.19102 .47915 .19817 .48227 .20796 .47974 .20072 .47784 Mtetra
.399 .813 .975 r
.20072 .47784 .20796 .47974 .21784 .4768 .21049 .47638 Mtetra
.3 .789 .89 r
.21049 .47638 .21784 .4768 .22781 .47332 .22032 .47468 Mtetra
.17 .704 .721 r
.22032 .47468 .22781 .47332 .23786 .4692 .23024 .47259 Mtetra
0 0 0 r
.23024 .47259 .23786 .4692 .24802 .4643 .24026 .46995 Mtetra
.065 0 0 r
.24026 .46995 .24802 .4643 .25827 .4586 .25036 .46666 Mtetra
.135 0 0 r
.25036 .46666 .25827 .4586 .2686 .45204 .26057 .4626 Mtetra
.186 0 0 r
.26057 .4626 .2686 .45204 .27902 .44476 .27088 .4578 Mtetra
.22 0 .066 r
.27088 .4578 .27902 .44476 .28949 .43684 .28126 .45223 Mtetra
.246 0 .126 r
.28126 .45223 .28949 .43684 .29999 .42865 .29173 .44599 Mtetra
.26 0 .164 r
.29173 .44599 .29999 .42865 .31051 .4205 .30225 .43915 Mtetra
.257 0 .181 r
.30225 .43915 .31051 .4205 .32101 .41264 .31285 .43157 Mtetra
.236 0 .175 r
.31285 .43157 .32101 .41264 .33149 .40529 .3235 .42325 Mtetra
.197 0 .144 r
.3235 .42325 .33149 .40529 .34198 .39802 .33419 .41439 Mtetra
.148 0 .097 r
.33419 .41439 .34198 .39802 .3525 .39063 .34491 .40526 Mtetra
.133 0 .061 r
.34491 .40526 .3525 .39063 .36303 .38314 .35559 .39685 Mtetra
.175 0 .065 r
.35559 .39685 .36303 .38314 .37358 .37562 .36622 .38975 Mtetra
.259 0 .117 r
.36622 .38975 .37358 .37562 .38411 .36886 .37679 .38413 Mtetra
.341 0 .179 r
.37679 .38413 .38411 .36886 .39462 .36326 .38733 .38003 Mtetra
.383 .021 .221 r
.38733 .38003 .39462 .36326 .4051 .35896 .39788 .37666 Mtetra
.399 .043 .241 r
.39788 .37666 .4051 .35896 .41557 .35592 .40846 .37356 Mtetra
.396 .039 .238 r
.40846 .37356 .41557 .35592 .42607 .35355 .41909 .37034 Mtetra
.379 .018 .22 r
.41909 .37034 .42607 .35355 .43661 .35143 .42977 .3668 Mtetra
.36 0 .19 r
.42977 .3668 .43661 .35143 .44721 .34906 .4405 .36312 Mtetra
.34 0 .159 r
.4405 .36312 .44721 .34906 .45787 .3461 .45127 .35936 Mtetra
.33 0 .139 r
.45127 .35936 .45787 .3461 .46859 .34241 .46209 .35565 Mtetra
.333 0 .14 r
.46209 .35565 .46859 .34241 .47936 .33798 .47294 .35201 Mtetra
.343 0 .16 r
.47294 .35201 .47936 .33798 .49018 .33296 .48385 .34828 Mtetra
.356 0 .189 r
.48385 .34828 .49018 .33296 .50103 .32768 .49479 .34441 Mtetra
.363 .003 .213 r
.49479 .34441 .50103 .32768 .51192 .32265 .50578 .34022 Mtetra
.369 .015 .227 r
.50578 .34022 .51192 .32265 .52284 .31828 .51682 .3359 Mtetra
.378 .023 .231 r
.51682 .3359 .52284 .31828 .5338 .3152 .52789 .33186 Mtetra
.389 .027 .223 r
.52789 .33186 .5338 .3152 .54481 .31342 .53901 .32855 Mtetra
.419 .041 .212 r
.53901 .32855 .54481 .31342 .5559 .31283 .55019 .32678 Mtetra
.452 .061 .206 r
.55019 .32678 .5559 .31283 .56707 .31301 .56145 .32653 Mtetra
.484 .087 .211 r
.56145 .32653 .56707 .31301 .57831 .31319 .5728 .32762 Mtetra
.505 .115 .234 r
.5728 .32762 .57831 .31319 .58962 .31326 .58425 .32945 Mtetra
.504 .126 .258 r
.58425 .32945 .58962 .31326 .60101 .31323 .59578 .33103 Mtetra
.497 .13 .274 r
.59578 .33103 .60101 .31323 .61247 .31329 .60738 .33208 Mtetra
.484 .125 .281 r
.60738 .33208 .61247 .31329 .62402 .31389 .61905 .33238 Mtetra
.469 .109 .271 r
.61905 .33238 .62402 .31389 .63567 .31481 .63077 .33194 Mtetra
.449 .082 .248 r
.63077 .33194 .63567 .31481 .6474 .31576 .64254 .33088 Mtetra
.42 .039 .208 r
.64254 .33088 .6474 .31576 .6592 .31647 .65436 .32914 Mtetra
.372 0 .143 r
.65436 .32914 .6592 .31647 .67106 .31652 .6662 .32662 Mtetra
.3 0 .046 r
.6662 .32662 .67106 .31652 .68296 .31584 .67807 .32333 Mtetra
.181 0 0 r
.67807 .32333 .68296 .31584 .69489 .31428 .68996 .31924 Mtetra
0 0 0 r
.68996 .31924 .69489 .31428 .70684 .31189 .70185 .31447 Mtetra
.70185 .31447 .70684 .31189 .7188 .3087 .71376 .30913 Mtetra
.497 .906 .837 r
.71376 .30913 .7188 .3087 .73078 .30483 .72568 .30337 Mtetra
.644 .952 .944 r
.72568 .30337 .73078 .30483 .74277 .3004 .73762 .29735 Mtetra
.706 .929 .964 r
.73762 .29735 .74277 .3004 .75477 .29554 .74959 .29116 Mtetra
.725 .888 .955 r
.74959 .29116 .75477 .29554 .7668 .29038 .76159 .28495 Mtetra
.728 .851 .939 r
.76159 .28495 .7668 .29038 .77886 .28503 .77363 .27873 Mtetra
.726 .821 .924 r
.77363 .27873 .77886 .28503 .79095 .27956 .7857 .27254 Mtetra
.721 .796 .911 r
.7857 .27254 .79095 .27956 .80308 .27409 .79782 .26643 Mtetra
.567 .726 .948 r
.14569 .47843 .15266 .48451 .16219 .48308 .15525 .47687 Mtetra
.56 .719 .947 r
.15525 .47687 .16219 .48308 .17175 .48174 .16484 .47544 Mtetra
.552 .714 .947 r
.16484 .47544 .17175 .48174 .18136 .48044 .17446 .47415 Mtetra
.541 .711 .95 r
.17446 .47415 .18136 .48044 .19102 .47915 .18411 .47302 Mtetra
.525 .712 .957 r
.18411 .47302 .19102 .47915 .20072 .47784 .19379 .47209 Mtetra
.508 .72 .968 r
.19379 .47209 .20072 .47784 .21049 .47638 .20351 .47128 Mtetra
.483 .736 .982 r
.20351 .47128 .21049 .47638 .22032 .47468 .21328 .47054 Mtetra
.451 .761 .995 r
.21328 .47054 .22032 .47468 .23024 .47259 .2231 .46976 Mtetra
.395 .784 .989 r
.2231 .46976 .23024 .47259 .24026 .46995 .23299 .46881 Mtetra
.296 .777 .92 r
.23299 .46881 .24026 .46995 .25036 .46666 .24296 .46757 Mtetra
.149 .691 .738 r
.24296 .46757 .25036 .46666 .26057 .4626 .25302 .4659 Mtetra
.012 0 0 r
.25302 .4659 .26057 .4626 .27088 .4578 .26316 .46371 Mtetra
.131 0 0 r
.26316 .46371 .27088 .4578 .28126 .45223 .2734 .46091 Mtetra
.203 0 0 r
.2734 .46091 .28126 .45223 .29173 .44599 .28374 .45739 Mtetra
.241 0 .035 r
.28374 .45739 .29173 .44599 .30225 .43915 .29418 .45306 Mtetra
.257 0 .102 r
.29418 .45306 .30225 .43915 .31285 .43157 .30471 .44781 Mtetra
.264 0 .146 r
.30471 .44781 .31285 .43157 .3235 .42325 .31533 .44159 Mtetra
.285 0 .187 r
.31533 .44159 .3235 .42325 .33419 .41439 .326 .43494 Mtetra
.315 0 .227 r
.326 .43494 .33419 .41439 .34491 .40526 .3367 .42824 Mtetra
.358 .032 .269 r
.3367 .42824 .34491 .40526 .35559 .39685 .34738 .42219 Mtetra
.399 .08 .304 r
.34738 .42219 .35559 .39685 .36622 .38975 .35803 .41715 Mtetra
.422 .108 .326 r
.35803 .41715 .36622 .38975 .37679 .38413 .36869 .41271 Mtetra
.433 .122 .336 r
.36869 .41271 .37679 .38413 .38733 .38003 .37937 .40861 Mtetra
.428 .118 .335 r
.37937 .40861 .38733 .38003 .39788 .37666 .3901 .40424 Mtetra
.415 .103 .324 r
.3901 .40424 .39788 .37666 .40846 .37356 .40088 .39935 Mtetra
.4 .083 .308 r
.40088 .39935 .40846 .37356 .41909 .37034 .41171 .39413 Mtetra
.385 .061 .288 r
.41171 .39413 .41909 .37034 .42977 .3668 .42258 .38875 Mtetra
.38 .048 .272 r
.42258 .38875 .42977 .3668 .4405 .36312 .43347 .3837 Mtetra
.384 .045 .261 r
.43347 .3837 .4405 .36312 .45127 .35936 .44438 .37922 Mtetra
.398 .053 .26 r
.44438 .37922 .45127 .35936 .46209 .35565 .45531 .37551 Mtetra
.417 .071 .267 r
.45531 .37551 .46209 .35565 .47294 .35201 .46628 .37257 Mtetra
.435 .09 .281 r
.46628 .37257 .47294 .35201 .48385 .34828 .47728 .37022 Mtetra
.448 .109 .298 r
.47728 .37022 .48385 .34828 .49479 .34441 .48833 .36819 Mtetra
.452 .121 .313 r
.48833 .36819 .49479 .34441 .50578 .34022 .49944 .36601 Mtetra
.453 .13 .327 r
.49944 .36601 .50578 .34022 .51682 .3359 .51061 .3635 Mtetra
.45 .134 .337 r
.51061 .3635 .51682 .3359 .52789 .33186 .52184 .36047 Mtetra
.449 .136 .342 r
.52184 .36047 .52789 .33186 .53901 .32855 .53311 .35717 Mtetra
.455 .141 .344 r
.53311 .35717 .53901 .32855 .55019 .32678 .54444 .35422 Mtetra
.461 .142 .339 r
.54444 .35422 .55019 .32678 .56145 .32653 .55583 .35186 Mtetra
.472 .144 .329 r
.55583 .35186 .56145 .32653 .5728 .32762 .56729 .35056 Mtetra
.476 .138 .313 r
.56729 .35056 .5728 .32762 .58425 .32945 .57882 .34991 Mtetra
.468 .119 .289 r
.57882 .34991 .58425 .32945 .59578 .33103 .59043 .34923 Mtetra
.451 .089 .258 r
.59043 .34923 .59578 .33103 .60738 .33208 .6021 .34811 Mtetra
.414 .04 .216 r
.6021 .34811 .60738 .33208 .61905 .33238 .61381 .34601 Mtetra
.364 0 .155 r
.61381 .34601 .61905 .33238 .63077 .33194 .62555 .34297 Mtetra
.29 0 .063 r
.62555 .34297 .63077 .33194 .64254 .33088 .63732 .33909 Mtetra
.171 0 0 r
.63732 .33909 .64254 .33088 .65436 .32914 .64911 .33448 Mtetra
0 0 0 r
.64911 .33448 .65436 .32914 .6662 .32662 .66092 .32922 Mtetra
.66092 .32922 .6662 .32662 .67807 .32333 .67274 .32341 Mtetra
.574 .941 .874 r
.67274 .32341 .67807 .32333 .68996 .31924 .68458 .31716 Mtetra
.703 .953 .952 r
.68458 .31716 .68996 .31924 .70185 .31447 .69644 .31059 Mtetra
.743 .906 .95 r
.69644 .31059 .70185 .31447 .71376 .30913 .70831 .30383 Mtetra
.749 .858 .929 r
.70831 .30383 .71376 .30913 .72568 .30337 .72022 .29702 Mtetra
.744 .821 .912 r
.72022 .29702 .72568 .30337 .73762 .29735 .73216 .29027 Mtetra
.737 .797 .9 r
.73216 .29027 .73762 .29735 .74959 .29116 .74414 .28363 Mtetra
.728 .781 .895 r
.74414 .28363 .74959 .29116 .76159 .28495 .75616 .27719 Mtetra
.722 .773 .893 r
.75616 .27719 .76159 .28495 .77363 .27873 .76823 .2709 Mtetra
.718 .77 .894 r
.76823 .2709 .77363 .27873 .7857 .27254 .78035 .26475 Mtetra
.714 .771 .897 r
.78035 .26475 .7857 .27254 .79782 .26643 .79252 .25872 Mtetra
.606 .738 .938 r
.13868 .4723 .14569 .47843 .15525 .47687 .14833 .47004 Mtetra
.603 .714 .923 r
.14833 .47004 .15525 .47687 .16484 .47544 .15801 .4679 Mtetra
.596 .69 .908 r
.15801 .4679 .16484 .47544 .17446 .47415 .16771 .46596 Mtetra
.586 .668 .895 r
.16771 .46596 .17446 .47415 .18411 .47302 .17743 .46426 Mtetra
.573 .647 .886 r
.17743 .46426 .18411 .47302 .19379 .47209 .18716 .46289 Mtetra
.56 .631 .879 r
.18716 .46289 .19379 .47209 .20351 .47128 .19691 .46184 Mtetra
.545 .619 .877 r
.19691 .46184 .20351 .47128 .21328 .47054 .20667 .46114 Mtetra
.531 .615 .881 r
.20667 .46114 .21328 .47054 .2231 .46976 .21647 .46071 Mtetra
.516 .618 .892 r
.21647 .46071 .2231 .46976 .23299 .46881 .2263 .46051 Mtetra
.501 .634 .912 r
.2263 .46051 .23299 .46881 .24296 .46757 .23618 .46043 Mtetra
.481 .663 .942 r
.23618 .46043 .24296 .46757 .25302 .4659 .24611 .46035 Mtetra
.45 .709 .978 r
.24611 .46035 .25302 .4659 .26316 .46371 .25612 .46011 Mtetra
.391 .757 .992 r
.25612 .46011 .26316 .46371 .2734 .46091 .26622 .45956 Mtetra
.277 .762 .919 r
.26622 .45956 .2734 .46091 .28374 .45739 .2764 .45854 Mtetra
.114 .663 .701 r
.2764 .45854 .28374 .45739 .29418 .45306 .28669 .4569 Mtetra
.064 0 0 r
.28669 .4569 .29418 .45306 .30471 .44781 .29706 .45476 Mtetra
.203 0 0 r
.29706 .45476 .30471 .44781 .31533 .44159 .30751 .4522 Mtetra
.317 0 .055 r
.30751 .4522 .31533 .44159 .326 .43494 .31801 .44968 Mtetra
.39 .006 .184 r
.31801 .44968 .326 .43494 .3367 .42824 .32853 .44746 Mtetra
.424 .07 .259 r
.32853 .44746 .3367 .42824 .34738 .42219 .33911 .44518 Mtetra
.436 .101 .298 r
.33911 .44518 .34738 .42219 .35803 .41715 .34976 .44261 Mtetra
.426 .102 .311 r
.34976 .44261 .35803 .41715 .36869 .41271 .3605 .43898 Mtetra
.402 .083 .307 r
.3605 .43898 .36869 .41271 .37937 .40861 .37136 .43394 Mtetra
.373 .054 .289 r
.37136 .43394 .37937 .40861 .3901 .40424 .3823 .42779 Mtetra
.34 .017 .263 r
.3823 .42779 .3901 .40424 .40088 .39935 .3933 .42081 Mtetra
.319 0 .236 r
.3933 .42081 .40088 .39935 .41171 .39413 .40432 .41377 Mtetra
.311 0 .214 r
.40432 .41377 .41171 .39413 .42258 .38875 .41535 .40717 Mtetra
.321 0 .205 r
.41535 .40717 .42258 .38875 .43347 .3837 .42637 .40136 Mtetra
.344 0 .206 r
.42637 .40136 .43347 .3837 .44438 .37922 .4374 .39657 Mtetra
.374 .012 .215 r
.4374 .39657 .44438 .37922 .45531 .37551 .44845 .39285 Mtetra
.404 .04 .228 r
.44845 .39285 .45531 .37551 .46628 .37257 .45951 .39021 Mtetra
.433 .068 .244 r
.45951 .39021 .46628 .37257 .47728 .37022 .47061 .38861 Mtetra
.456 .094 .262 r
.47061 .38861 .47728 .37022 .48833 .36819 .48176 .3878 Mtetra
.47 .115 .28 r
.48176 .3878 .48833 .36819 .49944 .36601 .49297 .38745 Mtetra
.475 .128 .298 r
.49297 .38745 .49944 .36601 .51061 .3635 .50426 .38705 Mtetra
.465 .129 .311 r
.50426 .38705 .51061 .3635 .52184 .36047 .51561 .38581 Mtetra
.452 .124 .319 r
.51561 .38581 .52184 .36047 .53311 .35717 .52703 .38346 Mtetra
.431 .109 .318 r
.52703 .38346 .53311 .35717 .54444 .35422 .53851 .37969 Mtetra
.408 .087 .305 r
.53851 .37969 .54444 .35422 .55583 .35186 .55002 .37484 Mtetra
.388 .058 .28 r
.55002 .37484 .55583 .35186 .56729 .35056 .56157 .36967 Mtetra
.357 .009 .231 r
.56157 .36967 .56729 .35056 .57882 .34991 .57316 .36446 Mtetra
.309 0 .145 r
.57316 .36446 .57882 .34991 .59043 .34923 .58479 .35952 Mtetra
.218 0 .002 r
.58479 .35952 .59043 .34923 .6021 .34811 .59646 .35464 Mtetra
.029 0 0 r
.59646 .35464 .6021 .34811 .61381 .34601 .60817 .34931 Mtetra
0 0 0 r
.60817 .34931 .61381 .34601 .62555 .34297 .6199 .34347 Mtetra
.575 .942 .858 r
.6199 .34347 .62555 .34297 .63732 .33909 .63165 .33698 Mtetra
.73 .954 .947 r
.63165 .33698 .63732 .33909 .64911 .33448 .64341 .32999 Mtetra
.767 .884 .93 r
.64341 .32999 .64911 .33448 .66092 .32922 .65518 .32266 Mtetra
.764 .815 .893 r
.65518 .32266 .66092 .32922 .67274 .32341 .66697 .31516 Mtetra
.75 .763 .863 r
.66697 .31516 .67274 .32341 .68458 .31716 .67878 .30765 Mtetra
.737 .728 .843 r
.67878 .30765 .68458 .31716 .69644 .31059 .69062 .30023 Mtetra
.725 .705 .832 r
.69062 .30023 .69644 .31059 .70831 .30383 .70251 .29305 Mtetra
.715 .693 .828 r
.70251 .29305 .70831 .30383 .72022 .29702 .71443 .28614 Mtetra
.707 .688 .83 r
.71443 .28614 .72022 .29702 .73216 .29027 .72641 .27958 Mtetra
.701 .69 .836 r
.72641 .27958 .73216 .29027 .74414 .28363 .73845 .27333 Mtetra
.696 .697 .847 r
.73845 .27333 .74414 .28363 .75616 .27719 .75055 .26742 Mtetra
.693 .709 .861 r
.75055 .26742 .75616 .27719 .76823 .2709 .7627 .26176 Mtetra
.691 .725 .876 r
.7627 .26176 .76823 .2709 .78035 .26475 .77492 .25629 Mtetra
.69 .744 .893 r
.77492 .25629 .78035 .26475 .79252 .25872 .78718 .25095 Mtetra
.658 .752 .92 r
.13161 .46613 .13868 .4723 .14833 .47004 .14141 .46273 Mtetra
.652 .716 .895 r
.14141 .46273 .14833 .47004 .15801 .4679 .15123 .45942 Mtetra
.643 .681 .871 r
.15123 .45942 .15801 .4679 .16771 .46596 .16108 .45627 Mtetra
.631 .648 .849 r
.16108 .45627 .16771 .46596 .17743 .46426 .17093 .45337 Mtetra
.617 .618 .829 r
.17093 .45337 .17743 .46426 .18716 .46289 .18079 .4508 Mtetra
.602 .59 .811 r
.18079 .4508 .18716 .46289 .19691 .46184 .19065 .44861 Mtetra
.587 .564 .795 r
.19065 .44861 .19691 .46184 .20667 .46114 .20052 .44685 Mtetra
.573 .542 .782 r
.20052 .44685 .20667 .46114 .21647 .46071 .21039 .44551 Mtetra
.56 .524 .771 r
.21039 .44551 .21647 .46071 .2263 .46051 .22028 .4446 Mtetra
.551 .51 .763 r
.22028 .4446 .2263 .46051 .23618 .46043 .23018 .44404 Mtetra
.543 .5 .759 r
.23018 .44404 .23618 .46043 .24611 .46035 .24012 .44376 Mtetra
.539 .497 .757 r
.24012 .44376 .24611 .46035 .25612 .46011 .2501 .44363 Mtetra
.538 .498 .759 r
.2501 .44363 .25612 .46011 .26622 .45956 .26014 .44353 Mtetra
.54 .505 .765 r
.26014 .44353 .26622 .45956 .2764 .45854 .27025 .44333 Mtetra
.545 .518 .777 r
.27025 .44333 .2764 .45854 .28669 .4569 .28044 .44294 Mtetra
.546 .537 .796 r
.28044 .44294 .28669 .4569 .29706 .45476 .29069 .44247 Mtetra
.543 .564 .826 r
.29069 .44247 .29706 .45476 .30751 .4522 .301 .44199 Mtetra
.532 .603 .87 r
.301 .44199 .30751 .4522 .31801 .44968 .31137 .44156 Mtetra
.512 .652 .921 r
.31137 .44156 .31801 .44968 .32853 .44746 .3218 .44114 Mtetra
.523 .718 .962 r
.3218 .44114 .32853 .44746 .33911 .44518 .33233 .44006 Mtetra
.565 .779 .979 r
.33233 .44006 .33911 .44518 .34976 .44261 .34297 .43794 Mtetra
.631 .818 .972 r
.34297 .43794 .34976 .44261 .3605 .43898 .35374 .43454 Mtetra
.691 .842 .955 r
.35374 .43454 .3605 .43898 .37136 .43394 .36462 .42981 Mtetra
.714 .858 .95 r
.36462 .42981 .37136 .43394 .3823 .42779 .37556 .42447 Mtetra
.716 .888 .96 r
.37556 .42447 .3823 .42779 .3933 .42081 .38654 .41895 Mtetra
.675 .929 .971 r
.38654 .41895 .3933 .42081 .40432 .41377 .39754 .4137 Mtetra
.55 .926 .922 r
.39754 .4137 .40432 .41377 .41535 .40717 .40855 .40895 Mtetra
.348 .819 .758 r
.40855 .40895 .41535 .40717 .42637 .40136 .4196 .40461 Mtetra
0 0 0 r
.4196 .40461 .42637 .40136 .4374 .39657 .43067 .40063 Mtetra
.43067 .40063 .4374 .39657 .44845 .39285 .44177 .3969 Mtetra
.44177 .3969 .44845 .39285 .45951 .39021 .45292 .39341 Mtetra
.45292 .39341 .45951 .39021 .47061 .38861 .46411 .39029 Mtetra
.46411 .39029 .47061 .38861 .48176 .3878 .47534 .38757 Mtetra
.28 .781 .856 r
.47534 .38757 .48176 .3878 .49297 .38745 .48662 .38537 Mtetra
.402 .822 .969 r
.48662 .38537 .49297 .38745 .50426 .38705 .49796 .38345 Mtetra
.501 .821 1 r
.49796 .38345 .50426 .38705 .51561 .38581 .50936 .38134 Mtetra
.571 .818 .992 r
.50936 .38134 .51561 .38581 .52703 .38346 .52082 .37863 Mtetra
.649 .833 .971 r
.52082 .37863 .52703 .38346 .53851 .37969 .53233 .37457 Mtetra
.706 .839 .946 r
.53233 .37457 .53851 .37969 .55002 .37484 .54388 .3692 Mtetra
.741 .831 .92 r
.54388 .3692 .55002 .37484 .56157 .36967 .55545 .36276 Mtetra
.752 .793 .886 r
.55545 .36276 .56157 .36967 .57316 .36446 .56705 .35565 Mtetra
.737 .738 .852 r
.56705 .35565 .57316 .36446 .58479 .35952 .57868 .34853 Mtetra
.718 .685 .817 r
.57868 .34853 .58479 .35952 .59646 .35464 .59033 .34145 Mtetra
.701 .641 .786 r
.59033 .34145 .59646 .35464 .60817 .34931 .60201 .33434 Mtetra
.69 .612 .764 r
.60201 .33434 .60817 .34931 .6199 .34347 .61371 .32715 Mtetra
.685 .594 .749 r
.61371 .32715 .6199 .34347 .63165 .33698 .62543 .31973 Mtetra
.68 .583 .74 r
.62543 .31973 .63165 .33698 .64341 .32999 .63717 .31221 Mtetra
.677 .576 .735 r
.63717 .31221 .64341 .32999 .65518 .32266 .64894 .3047 Mtetra
.674 .573 .734 r
.64894 .3047 .65518 .32266 .66697 .31516 .66073 .29732 Mtetra
.67 .573 .737 r
.66073 .29732 .66697 .31516 .67878 .30765 .67257 .29023 Mtetra
.667 .575 .742 r
.67257 .29023 .67878 .30765 .69062 .30023 .68445 .28349 Mtetra
.663 .58 .751 r
.68445 .28349 .69062 .30023 .70251 .29305 .69639 .27718 Mtetra
.661 .589 .764 r
.69639 .27718 .70251 .29305 .71443 .28614 .70839 .27129 Mtetra
.658 .6 .779 r
.70839 .27129 .71443 .28614 .72641 .27958 .72045 .26585 Mtetra
.656 .616 .797 r
.72045 .26585 .72641 .27958 .73845 .27333 .73258 .26079 Mtetra
.654 .635 .818 r
.73258 .26079 .73845 .27333 .75055 .26742 .74479 .25608 Mtetra
.653 .658 .842 r
.74479 .25608 .75055 .26742 .7627 .26176 .75706 .25162 Mtetra
.653 .685 .867 r
.75706 .25162 .7627 .26176 .77492 .25629 .7694 .24732 Mtetra
.653 .716 .894 r
.7694 .24732 .77492 .25629 .78718 .25095 .7818 .24311 Mtetra
.702 .761 .898 r
.12449 .45992 .13161 .46613 .14141 .46273 .13446 .45526 Mtetra
.694 .724 .872 r
.13446 .45526 .14141 .46273 .15123 .45942 .14445 .45064 Mtetra
.683 .688 .848 r
.14445 .45064 .15123 .45942 .16108 .45627 .15446 .44611 Mtetra
.67 .654 .826 r
.15446 .44611 .16108 .45627 .17093 .45337 .16448 .44175 Mtetra
.655 .622 .804 r
.16448 .44175 .17093 .45337 .18079 .4508 .17451 .43765 Mtetra
.64 .592 .784 r
.17451 .43765 .18079 .4508 .19065 .44861 .18454 .43385 Mtetra
.624 .563 .766 r
.18454 .43385 .19065 .44861 .20052 .44685 .19456 .43045 Mtetra
.609 .537 .748 r
.19456 .43045 .20052 .44685 .21039 .44551 .20458 .42746 Mtetra
.594 .513 .733 r
.20458 .42746 .21039 .44551 .22028 .4446 .2146 .42493 Mtetra
.582 .493 .719 r
.2146 .42493 .22028 .4446 .23018 .44404 .22462 .42282 Mtetra
.571 .475 .707 r
.22462 .42282 .23018 .44404 .24012 .44376 .23465 .42112 Mtetra
.563 .461 .697 r
.23465 .42112 .24012 .44376 .2501 .44363 .24471 .41978 Mtetra
.556 .45 .689 r
.24471 .41978 .2501 .44363 .26014 .44353 .25479 .41873 Mtetra
.55 .442 .683 r
.25479 .41873 .26014 .44353 .27025 .44333 .2649 .41796 Mtetra
.546 .436 .68 r
.2649 .41796 .27025 .44333 .28044 .44294 .27505 .41742 Mtetra
.542 .433 .68 r
.27505 .41742 .28044 .44294 .29069 .44247 .28525 .41712 Mtetra
.538 .432 .681 r
.28525 .41712 .29069 .44247 .301 .44199 .29549 .417 Mtetra
.542 .437 .684 r
.29549 .417 .301 .44199 .31137 .44156 .30581 .41666 Mtetra
.552 .444 .685 r
.30581 .41666 .31137 .44156 .3218 .44114 .31623 .41581 Mtetra
.567 .452 .682 r
.31623 .41581 .3218 .44114 .33233 .44006 .32676 .41403 Mtetra
.583 .459 .677 r
.32676 .41403 .33233 .44006 .34297 .43794 .33741 .41112 Mtetra
.589 .46 .673 r
.33741 .41112 .34297 .43794 .35374 .43454 .34814 .40769 Mtetra
.591 .461 .673 r
.34814 .40769 .35374 .43454 .36462 .42981 .35892 .40412 Mtetra
.586 .464 .68 r
.35892 .40412 .36462 .42981 .37556 .42447 .36972 .40104 Mtetra
.578 .47 .696 r
.36972 .40104 .37556 .42447 .38654 .41895 .38053 .39873 Mtetra
.574 .49 .722 r
.38053 .39873 .38654 .41895 .39754 .4137 .39137 .39687 Mtetra
.575 .522 .758 r
.39137 .39687 .39754 .4137 .40855 .40895 .40227 .39521 Mtetra
.589 .57 .8 r
.40227 .39521 .40855 .40895 .4196 .40461 .41324 .39315 Mtetra
.614 .622 .836 r
.41324 .39315 .4196 .40461 .43067 .40063 .42428 .39036 Mtetra
.646 .662 .851 r
.42428 .39036 .43067 .40063 .44177 .3969 .43541 .3866 Mtetra
.672 .672 .842 r
.43541 .3866 .44177 .3969 .45292 .39341 .4466 .38186 Mtetra
.682 .653 .815 r
.4466 .38186 .45292 .39341 .46411 .39029 .45785 .37637 Mtetra
.675 .613 .779 r
.45785 .37637 .46411 .39029 .47534 .38757 .46914 .37049 Mtetra
.653 .566 .744 r
.46914 .37049 .47534 .38757 .48662 .38537 .48046 .36479 Mtetra
.631 .524 .714 r
.48046 .36479 .48662 .38537 .49796 .38345 .49181 .35954 Mtetra
.609 .49 .693 r
.49181 .35954 .49796 .38345 .50936 .38134 .50319 .35506 Mtetra
.596 .47 .679 r
.50319 .35506 .50936 .38134 .52082 .37863 .51461 .35108 Mtetra
.595 .464 .673 r
.51461 .35108 .52082 .37863 .53233 .37457 .52608 .34696 Mtetra
.601 .468 .672 r
.52608 .34696 .53233 .37457 .54388 .3692 .5376 .3423 Mtetra
.617 .482 .674 r
.5376 .3423 .54388 .3692 .55545 .36276 .54915 .33649 Mtetra
.631 .493 .676 r
.54915 .33649 .55545 .36276 .56705 .35565 .56072 .32973 Mtetra
.638 .499 .677 r
.56072 .32973 .56705 .35565 .57868 .34853 .57231 .32242 Mtetra
.64 .5 .676 r
.57231 .32242 .57868 .34853 .59033 .34145 .58392 .31488 Mtetra
.636 .496 .674 r
.58392 .31488 .59033 .34145 .60201 .33434 .59556 .30752 Mtetra
.633 .492 .673 r
.59556 .30752 .60201 .33434 .61371 .32715 .60723 .30038 Mtetra
.63 .491 .674 r
.60723 .30038 .61371 .32715 .62543 .31973 .61893 .29347 Mtetra
.628 .492 .677 r
.61893 .29347 .62543 .31973 .63717 .31221 .63067 .28683 Mtetra
.627 .496 .683 r
.63067 .28683 .63717 .31221 .64894 .3047 .64246 .28049 Mtetra
.626 .501 .69 r
.64246 .28049 .64894 .3047 .66073 .29732 .65429 .2745 Mtetra
.625 .509 .701 r
.65429 .2745 .66073 .29732 .67257 .29023 .66617 .26893 Mtetra
.624 .518 .713 r
.66617 .26893 .67257 .29023 .68445 .28349 .67812 .26378 Mtetra
.622 .53 .728 r
.67812 .26378 .68445 .28349 .69639 .27718 .69014 .25911 Mtetra
.621 .544 .746 r
.69014 .25911 .69639 .27718 .70839 .27129 .70223 .25486 Mtetra
.618 .56 .767 r
.70223 .25486 .70839 .27129 .72045 .26585 .7144 .25102 Mtetra
.617 .58 .79 r
.7144 .25102 .72045 .26585 .73258 .26079 .72664 .24749 Mtetra
.615 .603 .815 r
.72664 .24749 .73258 .26079 .74479 .25608 .73896 .24423 Mtetra
.613 .629 .843 r
.73896 .24423 .74479 .25608 .75706 .25162 .75136 .24114 Mtetra
.612 .659 .872 r
.75136 .24114 .75706 .25162 .7694 .24732 .76383 .23816 Mtetra
.61 .692 .902 r
.76383 .23816 .7694 .24732 .7818 .24311 .77637 .23521 Mtetra
.729 .765 .882 r
.11732 .45366 .12449 .45992 .13446 .45526 .12742 .44807 Mtetra
.723 .738 .864 r
.12742 .44807 .13446 .45526 .14445 .45064 .13755 .44244 Mtetra
.714 .712 .846 r
.13755 .44244 .14445 .45064 .15446 .44611 .14771 .43683 Mtetra
.704 .685 .829 r
.14771 .43683 .15446 .44611 .16448 .44175 .15787 .4313 Mtetra
.693 .659 .812 r
.15787 .4313 .16448 .44175 .17451 .43765 .16805 .42587 Mtetra
.68 .631 .794 r
.16805 .42587 .17451 .43765 .18454 .43385 .17824 .42063 Mtetra
.665 .604 .777 r
.17824 .42063 .18454 .43385 .19456 .43045 .18843 .41564 Mtetra
.65 .577 .759 r
.18843 .41564 .19456 .43045 .20458 .42746 .19861 .41095 Mtetra
.635 .551 .743 r
.19861 .41095 .20458 .42746 .2146 .42493 .2088 .40663 Mtetra
.621 .527 .727 r
.2088 .40663 .2146 .42493 .22462 .42282 .21897 .40269 Mtetra
.607 .505 .712 r
.21897 .40269 .22462 .42282 .23465 .42112 .22915 .39915 Mtetra
.595 .485 .699 r
.22915 .39915 .23465 .42112 .24471 .41978 .23933 .39601 Mtetra
.584 .469 .687 r
.23933 .39601 .24471 .41978 .25479 .41873 .24952 .39328 Mtetra
.575 .454 .678 r
.24952 .39328 .25479 .41873 .2649 .41796 .25972 .39093 Mtetra
.567 .442 .669 r
.25972 .39093 .2649 .41796 .27505 .41742 .26994 .38896 Mtetra
.561 .433 .662 r
.26994 .38896 .27505 .41742 .28525 .41712 .28019 .38722 Mtetra
.558 .425 .656 r
.28019 .38722 .28525 .41712 .29549 .417 .29048 .38563 Mtetra
.56 .422 .65 r
.29048 .38563 .29549 .417 .30581 .41666 .30084 .38378 Mtetra
.565 .421 .644 r
.30084 .38378 .30581 .41666 .31623 .41581 .31129 .38144 Mtetra
.569 .419 .639 r
.31129 .38144 .31623 .41581 .32676 .41403 .32182 .37864 Mtetra
.571 .419 .636 r
.32182 .37864 .32676 .41403 .33741 .41112 .33242 .37548 Mtetra
.567 .416 .635 r
.33242 .37548 .33741 .41112 .34814 .40769 .34304 .37265 Mtetra
.56 .412 .637 r
.34304 .37265 .34814 .40769 .35892 .40412 .35367 .37052 Mtetra
.551 .41 .643 r
.35367 .37052 .35892 .40412 .36972 .40104 .36432 .36918 Mtetra
.543 .41 .65 r
.36432 .36918 .36972 .40104 .38053 .39873 .37499 .36855 Mtetra
.542 .416 .657 r
.37499 .36855 .38053 .39873 .39137 .39687 .38572 .36802 Mtetra
.547 .425 .664 r
.38572 .36802 .39137 .39687 .40227 .39521 .39653 .36717 Mtetra
.559 .436 .669 r
.39653 .36717 .40227 .39521 .41324 .39315 .40744 .36555 Mtetra
.575 .449 .671 r
.40744 .36555 .41324 .39315 .42428 .39036 .41843 .36289 Mtetra
.591 .46 .671 r
.41843 .36289 .42428 .39036 .43541 .3866 .42952 .35908 Mtetra
.606 .47 .67 r
.42952 .35908 .43541 .3866 .4466 .38186 .44068 .35411 Mtetra
.618 .477 .668 r
.44068 .35411 .4466 .38186 .45785 .37637 .4519 .34809 Mtetra
.625 .48 .664 r
.4519 .34809 .45785 .37637 .46914 .37049 .46317 .3413 Mtetra
.626 .477 .66 r
.46317 .3413 .46914 .37049 .48046 .36479 .47447 .33417 Mtetra
.621 .469 .654 r
.47447 .33417 .48046 .36479 .49181 .35954 .48579 .32712 Mtetra
.609 .455 .648 r
.48579 .32712 .49181 .35954 .50319 .35506 .49713 .32079 Mtetra
.597 .442 .642 r
.49713 .32079 .50319 .35506 .51461 .35108 .50849 .31524 Mtetra
.587 .431 .637 r
.50849 .31524 .51461 .35108 .52608 .34696 .51989 .3104 Mtetra
.582 .426 .635 r
.51989 .3104 .52608 .34696 .5376 .3423 .53133 .3059 Mtetra
.586 .429 .635 r
.53133 .3059 .5376 .3423 .54915 .33649 .54281 .30101 Mtetra
.592 .436 .638 r
.54281 .30101 .54915 .33649 .56072 .32973 .55433 .29567 Mtetra
.6 .445 .643 r
.55433 .29567 .56072 .32973 .57231 .32242 .56588 .28981 Mtetra
.606 .453 .648 r
.56588 .28981 .57231 .32242 .58392 .31488 .57746 .28368 Mtetra
.607 .458 .654 r
.57746 .28368 .58392 .31488 .59556 .30752 .58908 .27768 Mtetra
.608 .463 .66 r
.58908 .27768 .59556 .30752 .60723 .30038 .60073 .27193 Mtetra
.606 .468 .667 r
.60073 .27193 .60723 .30038 .61893 .29347 .61244 .26655 Mtetra
.605 .474 .675 r
.61244 .26655 .61893 .29347 .63067 .28683 .6242 .26155 Mtetra
.604 .481 .686 r
.6242 .26155 .63067 .28683 .64246 .28049 .63601 .25697 Mtetra
.603 .49 .698 r
.63601 .25697 .64246 .28049 .65429 .2745 .6479 .2528 Mtetra
.601 .501 .713 r
.6479 .2528 .65429 .2745 .66617 .26893 .65984 .24904 Mtetra
.599 .514 .73 r
.65984 .24904 .66617 .26893 .67812 .26378 .67187 .24568 Mtetra
.596 .529 .75 r
.67187 .24568 .67812 .26378 .69014 .25911 .68397 .24269 Mtetra
.593 .546 .771 r
.68397 .24269 .69014 .25911 .70223 .25486 .69615 .24002 Mtetra
.59 .565 .794 r
.69615 .24002 .70223 .25486 .7144 .25102 .70841 .23761 Mtetra
.587 .586 .819 r
.70841 .23761 .7144 .25102 .72664 .24749 .72076 .23539 Mtetra
.584 .609 .843 r
.72076 .23539 .72664 .24749 .73896 .24423 .73318 .23329 Mtetra
.58 .633 .868 r
.73318 .23329 .73896 .24423 .75136 .24114 .74568 .23127 Mtetra
.577 .658 .892 r
.74568 .23127 .75136 .24114 .76383 .23816 .75825 .22928 Mtetra
.573 .684 .916 r
.75825 .22928 .76383 .23816 .77637 .23521 .7709 .22725 Mtetra
.74 .766 .874 r
.1101 .44736 .11732 .45366 .12742 .44807 .12029 .44129 Mtetra
.738 .754 .865 r
.12029 .44129 .12742 .44807 .13755 .44244 .1305 .43514 Mtetra
.735 .74 .855 r
.1305 .43514 .13755 .44244 .14771 .43683 .14075 .42893 Mtetra
.731 .724 .844 r
.14075 .42893 .14771 .43683 .15787 .4313 .15102 .42267 Mtetra
.726 .707 .833 r
.15102 .42267 .15787 .4313 .16805 .42587 .16131 .41639 Mtetra
.718 .687 .82 r
.16131 .41639 .16805 .42587 .17824 .42063 .17162 .41013 Mtetra
.708 .665 .806 r
.17162 .41013 .17824 .42063 .18843 .41564 .18195 .40394 Mtetra
.696 .641 .79 r
.18195 .40394 .18843 .41564 .19861 .41095 .19228 .3979 Mtetra
.682 .615 .775 r
.19228 .3979 .19861 .41095 .2088 .40663 .20262 .39206 Mtetra
.668 .59 .758 r
.20262 .39206 .2088 .40663 .21897 .40269 .21295 .38648 Mtetra
.653 .565 .743 r
.21295 .38648 .21897 .40269 .22915 .39915 .22328 .38121 Mtetra
.639 .541 .728 r
.22328 .38121 .22915 .39915 .23933 .39601 .23361 .37628 Mtetra
.625 .519 .713 r
.23361 .37628 .23933 .39601 .24952 .39328 .24394 .37172 Mtetra
.613 .5 .7 r
.24394 .37172 .24952 .39328 .25972 .39093 .25427 .36749 Mtetra
.603 .482 .688 r
.25427 .36749 .25972 .39093 .26994 .38896 .26462 .36357 Mtetra
.596 .468 .677 r
.26462 .36357 .26994 .38896 .28019 .38722 .27499 .35976 Mtetra
.591 .456 .666 r
.27499 .35976 .28019 .38722 .29048 .38563 .2854 .35596 Mtetra
.588 .446 .656 r
.2854 .35596 .29048 .38563 .30084 .38378 .29586 .35204 Mtetra
.587 .438 .647 r
.29586 .35204 .30084 .38378 .31129 .38144 .30637 .34796 Mtetra
.58 .429 .641 r
.30637 .34796 .31129 .38144 .32182 .37864 .31689 .34418 Mtetra
.572 .421 .638 r
.31689 .34418 .32182 .37864 .33242 .37548 .32742 .34099 Mtetra
.561 .413 .638 r
.32742 .34099 .33242 .37548 .34304 .37265 .33795 .33874 Mtetra
.548 .406 .64 r
.33795 .33874 .34304 .37265 .35367 .37052 .34846 .33753 Mtetra
.542 .405 .644 r
.34846 .33753 .35367 .37052 .36432 .36918 .35901 .33681 Mtetra
.541 .406 .646 r
.35901 .33681 .36432 .36918 .37499 .36855 .36961 .3362 Mtetra
.547 .411 .647 r
.36961 .3362 .37499 .36855 .38572 .36802 .3803 .33516 Mtetra
.556 .416 .645 r
.3803 .33516 .38572 .36802 .39653 .36717 .39108 .33337 Mtetra
.564 .419 .642 r
.39108 .33337 .39653 .36717 .40744 .36555 .40195 .33087 Mtetra
.571 .422 .639 r
.40195 .33087 .40744 .36555 .41843 .36289 .4129 .32762 Mtetra
.577 .424 .637 r
.4129 .32762 .41843 .36289 .42952 .35908 .42392 .32376 Mtetra
.584 .429 .637 r
.42392 .32376 .42952 .35908 .44068 .35411 .43499 .31927 Mtetra
.593 .436 .638 r
.43499 .31927 .44068 .35411 .4519 .34809 .44613 .31404 Mtetra
.601 .444 .641 r
.44613 .31404 .4519 .34809 .46317 .3413 .45732 .30808 Mtetra
.611 .453 .643 r
.45732 .30808 .46317 .3413 .47447 .33417 .46856 .30137 Mtetra
.616 .458 .645 r
.46856 .30137 .47447 .33417 .48579 .32712 .47982 .29421 Mtetra
.615 .457 .644 r
.47982 .29421 .48579 .32712 .49713 .32079 .49111 .28715 Mtetra
.608 .45 .642 r
.49111 .28715 .49713 .32079 .50849 .31524 .50242 .28057 Mtetra
.595 .439 .639 r
.50242 .28057 .50849 .31524 .51989 .3104 .51375 .27504 Mtetra
.584 .429 .637 r
.51375 .27504 .51989 .3104 .53133 .3059 .52512 .27045 Mtetra
.578 .425 .638 r
.52512 .27045 .53133 .3059 .54281 .30101 .53654 .26647 Mtetra
.575 .426 .641 r
.53654 .26647 .54281 .30101 .55433 .29567 .548 .26279 Mtetra
.579 .434 .647 r
.548 .26279 .55433 .29567 .56588 .28981 .55952 .25894 Mtetra
.584 .443 .656 r
.55952 .25894 .56588 .28981 .57746 .28368 .57108 .25498 Mtetra
.588 .454 .666 r
.57108 .25498 .57746 .28368 .58908 .27768 .58269 .25101 Mtetra
.59 .465 .677 r
.58269 .25101 .58908 .27768 .60073 .27193 .59436 .24716 Mtetra
.59 .474 .69 r
.59436 .24716 .60073 .27193 .61244 .26655 .60608 .24363 Mtetra
.588 .484 .703 r
.60608 .24363 .61244 .26655 .6242 .26155 .61787 .24043 Mtetra
.586 .495 .719 r
.61787 .24043 .6242 .26155 .63601 .25697 .62973 .23761 Mtetra
.583 .508 .737 r
.62973 .23761 .63601 .25697 .6479 .2528 .64167 .23515 Mtetra
.579 .523 .756 r
.64167 .23515 .6479 .2528 .65984 .24904 .65368 .23301 Mtetra
.575 .54 .778 r
.65368 .23301 .65984 .24904 .67187 .24568 .66577 .23115 Mtetra
.571 .559 .801 r
.66577 .23115 .67187 .24568 .68397 .24269 .67795 .22949 Mtetra
.566 .578 .825 r
.67795 .22949 .68397 .24269 .69615 .24002 .69021 .22799 Mtetra
.562 .599 .848 r
.69021 .22799 .69615 .24002 .70841 .23761 .70254 .22657 Mtetra
.558 .619 .869 r
.70254 .22657 .70841 .23761 .72076 .23539 .71496 .22519 Mtetra
.556 .638 .888 r
.71496 .22519 .72076 .23539 .73318 .23329 .72746 .22377 Mtetra
.553 .656 .904 r
.72746 .22377 .73318 .23329 .74568 .23127 .74002 .22232 Mtetra
.551 .672 .918 r
.74002 .22232 .74568 .23127 .75825 .22928 .75267 .22081 Mtetra
.55 .687 .93 r
.75267 .22081 .75825 .22928 .7709 .22725 .76539 .21923 Mtetra
.734 .766 .879 r
.10283 .44102 .1101 .44736 .12029 .44129 .11301 .43519 Mtetra
.738 .774 .882 r
.11301 .43519 .12029 .44129 .1305 .43514 .12322 .42925 Mtetra
.742 .782 .885 r
.12322 .42925 .1305 .43514 .14075 .42893 .13348 .42321 Mtetra
.746 .788 .887 r
.13348 .42321 .14075 .42893 .15102 .42267 .14376 .41704 Mtetra
.75 .792 .887 r
.14376 .41704 .15102 .42267 .16131 .41639 .15409 .41074 Mtetra
.753 .793 .886 r
.15409 .41074 .16131 .41639 .17162 .41013 .16444 .40434 Mtetra
.753 .789 .882 r
.16444 .40434 .17162 .41013 .18195 .40394 .17483 .39786 Mtetra
.751 .781 .878 r
.17483 .39786 .18195 .40394 .19228 .3979 .18524 .39138 Mtetra
.746 .769 .871 r
.18524 .39138 .19228 .3979 .20262 .39206 .19566 .38494 Mtetra
.739 .752 .863 r
.19566 .38494 .20262 .39206 .21295 .38648 .20609 .3786 Mtetra
.729 .731 .852 r
.20609 .3786 .21295 .38648 .22328 .38121 .21653 .37243 Mtetra
.717 .707 .84 r
.21653 .37243 .22328 .38121 .23361 .37628 .22698 .36646 Mtetra
.703 .681 .825 r
.22698 .36646 .23361 .37628 .24394 .37172 .23742 .36072 Mtetra
.69 .654 .809 r
.23742 .36072 .24394 .37172 .25427 .36749 .24788 .35518 Mtetra
.677 .627 .792 r
.24788 .35518 .25427 .36749 .26462 .36357 .25835 .34982 Mtetra
.666 .602 .774 r
.25835 .34982 .26462 .36357 .27499 .35976 .26884 .34454 Mtetra
.657 .579 .756 r
.26884 .34454 .27499 .35976 .2854 .35596 .27936 .33929 Mtetra
.647 .559 .742 r
.27936 .33929 .2854 .35596 .29586 .35204 .2899 .33415 Mtetra
.638 .543 .731 r
.2899 .33415 .29586 .35204 .30637 .34796 .30046 .3292 Mtetra
.623 .528 .725 r
.30046 .3292 .30637 .34796 .31689 .34418 .31101 .32486 Mtetra
.607 .513 .723 r
.31101 .32486 .31689 .34418 .32742 .34099 .32155 .32132 Mtetra
.593 .502 .721 r
.32155 .32132 .32742 .34099 .33795 .33874 .33208 .31846 Mtetra
.581 .491 .717 r
.33208 .31846 .33795 .33874 .34846 .33753 .34264 .31611 Mtetra
.581 .483 .708 r
.34264 .31611 .34846 .33753 .35901 .33681 .35325 .31364 Mtetra
.585 .475 .694 r
.35325 .31364 .35901 .33681 .36961 .3362 .36394 .31071 Mtetra
.589 .465 .679 r
.36394 .31071 .36961 .3362 .3803 .33516 .3747 .30722 Mtetra
.591 .456 .666 r
.3747 .30722 .3803 .33516 .39108 .33337 .38554 .30318 Mtetra
.589 .446 .655 r
.38554 .30318 .39108 .33337 .40195 .33087 .39642 .29898 Mtetra
.585 .438 .648 r
.39642 .29898 .40195 .33087 .4129 .32762 .40734 .29482 Mtetra
.581 .433 .645 r
.40734 .29482 .4129 .32762 .42392 .32376 .4183 .29091 Mtetra
.578 .43 .645 r
.4183 .29091 .42392 .32376 .43499 .31927 .42929 .28724 Mtetra
.578 .434 .648 r
.42929 .28724 .43499 .31927 .44613 .31404 .44033 .28361 Mtetra
.583 .442 .655 r
.44033 .28361 .44613 .31404 .45732 .30808 .45142 .27983 Mtetra
.594 .458 .665 r
.45142 .27983 .45732 .30808 .46856 .30137 .46256 .27548 Mtetra
.607 .477 .678 r
.46256 .27548 .46856 .30137 .47982 .29421 .47376 .27058 Mtetra
.62 .497 .691 r
.47376 .27058 .47982 .29421 .49111 .28715 .48501 .2652 Mtetra
.628 .512 .702 r
.48501 .2652 .49111 .28715 .50242 .28057 .49629 .25969 Mtetra
.623 .517 .712 r
.49629 .25969 .50242 .28057 .51375 .27504 .5076 .2547 Mtetra
.614 .515 .719 r
.5076 .2547 .51375 .27504 .52512 .27045 .51896 .2504 Mtetra
.601 .51 .723 r
.51896 .2504 .52512 .27045 .53654 .26647 .53036 .2469 Mtetra
.591 .508 .73 r
.53036 .2469 .53654 .26647 .548 .26279 .54181 .24402 Mtetra
.588 .514 .739 r
.54181 .24402 .548 .26279 .55952 .25894 .55332 .24134 Mtetra
.588 .526 .752 r
.55332 .24134 .55952 .25894 .57108 .25498 .5649 .23878 Mtetra
.591 .543 .77 r
.5649 .23878 .57108 .25498 .58269 .25101 .57654 .23625 Mtetra
.591 .563 .791 r
.57654 .23625 .58269 .25101 .59436 .24716 .58823 .2338 Mtetra
.589 .584 .815 r
.58823 .2338 .59436 .24716 .60608 .24363 .6 .23155 Mtetra
.583 .605 .84 r
.6 .23155 .60608 .24363 .61787 .24043 .61184 .22949 Mtetra
.574 .625 .865 r
.61184 .22949 .61787 .24043 .62973 .23761 .62375 .22769 Mtetra
.563 .645 .889 r
.62375 .22769 .62973 .23761 .64167 .23515 .63574 .22609 Mtetra
.551 .663 .911 r
.63574 .22609 .64167 .23515 .65368 .23301 .64781 .22467 Mtetra
.54 .68 .929 r
.64781 .22467 .65368 .23301 .66577 .23115 .65996 .22336 Mtetra
.53 .694 .944 r
.65996 .22336 .66577 .23115 .67795 .22949 .67219 .2221 Mtetra
.524 .705 .953 r
.67219 .2221 .67795 .22949 .69021 .22799 .68449 .22084 Mtetra
.523 .714 .959 r
.68449 .22084 .69021 .22799 .70254 .22657 .69687 .21951 Mtetra
.525 .72 .962 r
.69687 .21951 .70254 .22657 .71496 .22519 .70932 .21809 Mtetra
.532 .723 .961 r
.70932 .21809 .71496 .22519 .72746 .22377 .72184 .21652 Mtetra
.54 .722 .958 r
.72184 .21652 .72746 .22377 .74002 .22232 .73443 .21484 Mtetra
.547 .719 .952 r
.73443 .21484 .74002 .22232 .75267 .22081 .7471 .21304 Mtetra
.555 .714 .946 r
.7471 .21304 .75267 .22081 .76539 .21923 .75983 .21113 Mtetra
.711 .762 .893 r
.09551 .43462 .10283 .44102 .11301 .43519 .10561 .42959 Mtetra
.718 .789 .908 r
.10561 .42959 .11301 .43519 .12322 .42925 .11575 .42445 Mtetra
.725 .817 .922 r
.11575 .42445 .12322 .42925 .13348 .42321 .12594 .41917 Mtetra
.731 .845 .934 r
.12594 .41917 .13348 .42321 .14376 .41704 .13617 .41372 Mtetra
.738 .871 .942 r
.13617 .41372 .14376 .41704 .15409 .41074 .14645 .40807 Mtetra
.742 .894 .948 r
.14645 .40807 .15409 .41074 .16444 .40434 .15678 .40223 Mtetra
.744 .914 .95 r
.15678 .40223 .16444 .40434 .17483 .39786 .16716 .39621 Mtetra
.744 .928 .95 r
.16716 .39621 .17483 .39786 .18524 .39138 .17757 .39005 Mtetra
.743 .939 .949 r
.17757 .39005 .18524 .39138 .19566 .38494 .18802 .38379 Mtetra
.741 .944 .948 r
.18802 .38379 .19566 .38494 .20609 .3786 .19849 .37748 Mtetra
.739 .946 .949 r
.19849 .37748 .20609 .3786 .21653 .37243 .20899 .37118 Mtetra
.739 .943 .95 r
.20899 .37118 .21653 .37243 .22698 .36646 .21951 .3649 Mtetra
.74 .936 .951 r
.21951 .3649 .22698 .36646 .23742 .36072 .23004 .35867 Mtetra
.744 .923 .951 r
.23004 .35867 .23742 .36072 .24788 .35518 .2406 .3525 Mtetra
.746 .903 .948 r
.2406 .3525 .24788 .35518 .25835 .34982 .25117 .34638 Mtetra
.746 .879 .941 r
.25117 .34638 .25835 .34982 .26884 .34454 .26176 .34034 Mtetra
.742 .853 .932 r
.26176 .34034 .26884 .34454 .27936 .33929 .27237 .33442 Mtetra
.729 .83 .927 r
.27237 .33442 .27936 .33929 .2899 .33415 .28298 .32881 Mtetra
.712 .812 .927 r
.28298 .32881 .2899 .33415 .30046 .3292 .29358 .32365 Mtetra
.691 .802 .934 r
.29358 .32365 .30046 .3292 .31101 .32486 .30418 .31905 Mtetra
.669 .789 .938 r
.30418 .31905 .31101 .32486 .32155 .32132 .31478 .31498 Mtetra
.669 .772 .927 r
.31478 .31498 .32155 .32132 .33208 .31846 .32542 .31092 Mtetra
.677 .738 .896 r
.32542 .31092 .33208 .31846 .34264 .31611 .33611 .30654 Mtetra
.687 .689 .847 r
.33611 .30654 .34264 .31611 .35325 .31364 .34689 .30145 Mtetra
.687 .639 .796 r
.34689 .30145 .35325 .31364 .36394 .31071 .35774 .29555 Mtetra
.674 .593 .757 r
.35774 .29555 .36394 .31071 .3747 .30722 .36864 .28926 Mtetra
.659 .557 .729 r
.36864 .28926 .3747 .30722 .38554 .30318 .37958 .28293 Mtetra
.64 .528 .711 r
.37958 .28293 .38554 .30318 .39642 .29898 .39051 .27711 Mtetra
.621 .506 .701 r
.39051 .27711 .39642 .29898 .40734 .29482 .40144 .27212 Mtetra
.602 .489 .698 r
.40144 .27212 .40734 .29482 .4183 .29091 .41237 .26817 Mtetra
.584 .478 .699 r
.41237 .26817 .4183 .29091 .42929 .28724 .42331 .26525 Mtetra
.571 .475 .707 r
.42331 .26525 .42929 .28724 .44033 .28361 .43428 .26316 Mtetra
.563 .482 .721 r
.43428 .26316 .44033 .28361 .45142 .27983 .44529 .2616 Mtetra
.567 .504 .744 r
.44529 .2616 .45142 .27983 .46256 .27548 .45637 .26 Mtetra
.579 .543 .778 r
.45637 .26 .46256 .27548 .47376 .27058 .46752 .25801 Mtetra
.607 .602 .82 r
.46752 .25801 .47376 .27058 .48501 .2652 .47873 .25521 Mtetra
.635 .669 .865 r
.47873 .25521 .48501 .2652 .49629 .25969 .49002 .2517 Mtetra
.65 .729 .907 r
.49002 .2517 .49629 .25969 .5076 .2547 .50135 .24787 Mtetra
.648 .765 .934 r
.50135 .24787 .5076 .2547 .51896 .2504 .51274 .24404 Mtetra
.622 .773 .953 r
.51274 .24404 .51896 .2504 .53036 .2469 .52417 .24075 Mtetra
.592 .77 .965 r
.52417 .24075 .53036 .2469 .54181 .24402 .53566 .23803 Mtetra
.564 .765 .973 r
.53566 .23803 .54181 .24402 .55332 .24134 .54721 .23577 Mtetra
.536 .77 .984 r
.54721 .23577 .55332 .24134 .5649 .23878 .55883 .23384 Mtetra
.511 .783 .994 r
.55883 .23384 .5649 .23878 .57654 .23625 .57052 .23203 Mtetra
.478 .796 .999 r
.57052 .23203 .57654 .23625 .58823 .2338 .58227 .2303 Mtetra
.439 .804 .995 r
.58227 .2303 .58823 .2338 .6 .23155 .5941 .22864 Mtetra
.398 .803 .982 r
.5941 .22864 .6 .23155 .61184 .22949 .606 .22704 Mtetra
.361 .796 .965 r
.606 .22704 .61184 .22949 .62375 .22769 .61797 .2255 Mtetra
.338 .789 .952 r
.61797 .2255 .62375 .22769 .63574 .22609 .63002 .22399 Mtetra
.328 .786 .946 r
.63002 .22399 .63574 .22609 .64781 .22467 .64214 .22249 Mtetra
.336 .789 .95 r
.64214 .22249 .64781 .22467 .65996 .22336 .65433 .22094 Mtetra
.361 .798 .962 r
.65433 .22094 .65996 .22336 .67219 .2221 .66659 .21929 Mtetra
.396 .808 .978 r
.66659 .21929 .67219 .2221 .68449 .22084 .67892 .21751 Mtetra
.439 .815 .992 r
.67892 .21751 .68449 .22084 .69687 .21951 .69132 .21554 Mtetra
.482 .816 .999 r
.69132 .21554 .69687 .21951 .70932 .21809 .70378 .21338 Mtetra
.521 .809 .998 r
.70378 .21338 .70932 .21809 .72184 .21652 .7163 .21101 Mtetra
.552 .793 .989 r
.7163 .21101 .72184 .21652 .73443 .21484 .72888 .20846 Mtetra
.573 .773 .973 r
.72888 .20846 .73443 .21484 .7471 .21304 .74152 .20578 Mtetra
.588 .749 .954 r
.74152 .20578 .7471 .21304 .75983 .21113 .75422 .20298 Mtetra
.668 .754 .915 r
.08813 .42819 .09551 .43462 .10561 .42959 .09809 .42438 Mtetra
.671 .796 .942 r
.09809 .42438 .10561 .42959 .11575 .42445 .1081 .42049 Mtetra
.67 .841 .965 r
.1081 .42049 .11575 .42445 .12594 .41917 .11816 .41646 Mtetra
.663 .884 .979 r
.11816 .41646 .12594 .41917 .13617 .41372 .12827 .41226 Mtetra
.646 .919 .978 r
.12827 .41226 .13617 .41372 .14645 .40807 .13845 .40782 Mtetra
.612 .938 .954 r
.13845 .40782 .14645 .40807 .15678 .40223 .14869 .40317 Mtetra
.563 .935 .904 r
.14869 .40317 .15678 .40223 .16716 .39621 .15899 .39827 Mtetra
.499 .907 .832 r
.15899 .39827 .16716 .39621 .17757 .39005 .16934 .39315 Mtetra
.428 .86 .746 r
.16934 .39315 .17757 .39005 .18802 .38379 .17974 .38784 Mtetra
.356 .803 .658 r
.17974 .38784 .18802 .38379 .19849 .37748 .19019 .38237 Mtetra
0 0 0 r
.19019 .38237 .19849 .37748 .20899 .37118 .20067 .37677 Mtetra
.20067 .37677 .20899 .37118 .21951 .3649 .2112 .37109 Mtetra
.2112 .37109 .21951 .3649 .23004 .35867 .22175 .36535 Mtetra
.22175 .36535 .23004 .35867 .2406 .3525 .23234 .35959 Mtetra
.23234 .35959 .2406 .3525 .25117 .34638 .24295 .35384 Mtetra
.24295 .35384 .25117 .34638 .26176 .34034 .25358 .34817 Mtetra
.25358 .34817 .26176 .34034 .27237 .33442 .26423 .34266 Mtetra
.021 0 0 r
.26423 .34266 .27237 .33442 .28298 .32881 .27489 .33742 Mtetra
.07 0 0 r
.27489 .33742 .28298 .32881 .29358 .32365 .28555 .33251 Mtetra
.098 0 0 r
.28555 .33251 .29358 .32365 .30418 .31905 .29624 .32777 Mtetra
.095 0 0 r
.29624 .32777 .30418 .31905 .31478 .31498 .30696 .32304 Mtetra
.025 0 0 r
.30696 .32304 .31478 .31498 .32542 .31092 .31775 .31782 Mtetra
0 0 0 r
.31775 .31782 .32542 .31092 .33611 .30654 .32862 .31182 Mtetra
.32862 .31182 .33611 .30654 .34689 .30145 .33956 .30509 Mtetra
.505 .888 .707 r
.33956 .30509 .34689 .30145 .35774 .29555 .35056 .29776 Mtetra
.612 .953 .814 r
.35056 .29776 .35774 .29555 .36864 .28926 .36158 .29044 Mtetra
.646 .968 .871 r
.36158 .29044 .36864 .28926 .37958 .28293 .3726 .28352 Mtetra
.619 .957 .896 r
.3726 .28352 .37958 .28293 .39051 .27711 .3836 .27739 Mtetra
.551 .93 .903 r
.3836 .27739 .39051 .27711 .40144 .27212 .3946 .2723 Mtetra
.451 .882 .889 r
.3946 .2723 .40144 .27212 .41237 .26817 .40558 .26832 Mtetra
.33 .814 .854 r
.40558 .26832 .41237 .26817 .42331 .26525 .41657 .26545 Mtetra
.2 .729 .798 r
.41657 .26545 .42331 .26525 .43428 .26316 .42758 .26363 Mtetra
.079 .639 .722 r
.42758 .26363 .43428 .26316 .44529 .2616 .43863 .26261 Mtetra
.017 0 0 r
.43863 .26261 .44529 .2616 .45637 .26 .44973 .262 Mtetra
.096 0 0 r
.44973 .262 .45637 .26 .46752 .25801 .46091 .26141 Mtetra
.132 0 0 r
.46091 .26141 .46752 .25801 .47873 .25521 .47217 .26023 Mtetra
.161 0 0 r
.47217 .26023 .47873 .25521 .49002 .2517 .4835 .25832 Mtetra
.179 0 0 r
.4835 .25832 .49002 .2517 .50135 .24787 .49491 .25563 Mtetra
.193 0 0 r
.49491 .25563 .50135 .24787 .51274 .24404 .50638 .25243 Mtetra
.216 0 0 r
.50638 .25243 .51274 .24404 .52417 .24075 .5179 .24924 Mtetra
.231 0 0 r
.5179 .24924 .52417 .24075 .53566 .23803 .52948 .24623 Mtetra
.241 0 0 r
.52948 .24623 .53566 .23803 .54721 .23577 .54112 .24356 Mtetra
.245 0 0 r
.54112 .24356 .54721 .23577 .55883 .23384 .55282 .24118 Mtetra
.24 0 0 r
.55282 .24118 .55883 .23384 .57052 .23203 .56458 .23895 Mtetra
.232 0 0 r
.56458 .23895 .57052 .23203 .58227 .2303 .57642 .23681 Mtetra
.219 0 0 r
.57642 .23681 .58227 .2303 .5941 .22864 .58832 .23469 Mtetra
.2 0 0 r
.58832 .23469 .5941 .22864 .606 .22704 .60029 .23254 Mtetra
.175 0 0 r
.60029 .23254 .606 .22704 .61797 .2255 .61233 .23035 Mtetra
.138 0 0 r
.61233 .23035 .61797 .2255 .63002 .22399 .62443 .22807 Mtetra
.087 0 0 r
.62443 .22807 .63002 .22399 .64214 .22249 .63659 .22566 Mtetra
.016 0 0 r
.63659 .22566 .64214 .22249 .65433 .22094 .64882 .22309 Mtetra
0 0 0 r
.64882 .22309 .65433 .22094 .66659 .21929 .66111 .22032 Mtetra
.194 .72 .72 r
.66111 .22032 .66659 .21929 .67892 .21751 .67345 .21732 Mtetra
.322 .809 .845 r
.67345 .21732 .67892 .21751 .69132 .21554 .68584 .21407 Mtetra
.44 .865 .937 r
.68584 .21407 .69132 .21554 .70378 .21338 .69829 .21059 Mtetra
.533 .881 .985 r
.69829 .21059 .70378 .21338 .7163 .21101 .71079 .20687 Mtetra
.592 .864 .994 r
.71079 .20687 .7163 .21101 .72888 .20846 .72333 .20296 Mtetra
.626 .829 .979 r
.72333 .20296 .72888 .20846 .74152 .20578 .73592 .19891 Mtetra
.641 .788 .952 r
.73592 .19891 .74152 .20578 .75422 .20298 .74857 .19475 Mtetra
.605 .738 .939 r
.0807 .4217 .08813 .42819 .09809 .42438 .0905 .41927 Mtetra
.596 .784 .97 r
.0905 .41927 .09809 .42438 .1081 .42049 .10034 .41677 Mtetra
.577 .83 .993 r
.10034 .41677 .1081 .42049 .11816 .41646 .11025 .41417 Mtetra
.542 .866 .995 r
.11025 .41417 .11816 .41646 .12827 .41226 .12022 .41141 Mtetra
.484 .88 .96 r
.12022 .41141 .12827 .41226 .13845 .40782 .13026 .40844 Mtetra
.4 .854 .877 r
.13026 .40844 .13845 .40782 .14869 .40317 .14036 .40524 Mtetra
.3 .791 .754 r
.14036 .40524 .14869 .40317 .15899 .39827 .15054 .40178 Mtetra
0 0 0 r
.15054 .40178 .15899 .39827 .16934 .39315 .16079 .39808 Mtetra
.16079 .39808 .16934 .39315 .17974 .38784 .1711 .39412 Mtetra
.1711 .39412 .17974 .38784 .19019 .38237 .18147 .38994 Mtetra
.034 0 0 r
.18147 .38994 .19019 .38237 .20067 .37677 .19191 .38555 Mtetra
.085 0 0 r
.19191 .38555 .20067 .37677 .2112 .37109 .20239 .38101 Mtetra
.127 0 0 r
.20239 .38101 .2112 .37109 .22175 .36535 .21292 .37634 Mtetra
.163 0 0 r
.21292 .37634 .22175 .36535 .23234 .35959 .22349 .37162 Mtetra
.197 0 0 r
.22349 .37162 .23234 .35959 .24295 .35384 .2341 .36689 Mtetra
.228 0 .036 r
.2341 .36689 .24295 .35384 .25358 .34817 .24473 .36223 Mtetra
.258 0 .074 r
.24473 .36223 .25358 .34817 .26423 .34266 .25539 .3577 Mtetra
.282 0 .105 r
.25539 .3577 .26423 .34266 .27489 .33742 .26608 .35327 Mtetra
.298 0 .128 r
.26608 .35327 .27489 .33742 .28555 .33251 .27681 .34889 Mtetra
.296 0 .135 r
.27681 .34889 .28555 .33251 .29624 .32777 .28759 .34424 Mtetra
.279 0 .129 r
.28759 .34424 .29624 .32777 .30696 .32304 .29844 .3391 Mtetra
.243 0 .104 r
.29844 .3391 .30696 .32304 .31775 .31782 .30938 .33321 Mtetra
.195 0 .069 r
.30938 .33321 .31775 .31782 .32862 .31182 .3204 .32651 Mtetra
.161 0 .04 r
.3204 .32651 .32862 .31182 .33956 .30509 .33147 .31943 Mtetra
.151 0 .029 r
.33147 .31943 .33956 .30509 .35056 .29776 .34256 .31228 Mtetra
.178 0 .047 r
.34256 .31228 .35056 .29776 .36158 .29044 .35366 .30555 Mtetra
.225 0 .083 r
.35366 .30555 .36158 .29044 .3726 .28352 .36474 .2995 Mtetra
.272 0 .121 r
.36474 .2995 .3726 .28352 .3836 .27739 .37582 .29415 Mtetra
.311 0 .153 r
.37582 .29415 .3836 .27739 .3946 .2723 .38691 .28953 Mtetra
.338 0 .172 r
.38691 .28953 .3946 .2723 .40558 .26832 .39801 .28553 Mtetra
.359 0 .182 r
.39801 .28553 .40558 .26832 .41657 .26545 .40913 .28218 Mtetra
.377 0 .183 r
.40913 .28218 .41657 .26545 .42758 .26363 .42027 .27955 Mtetra
.391 .003 .177 r
.42027 .27955 .42758 .26363 .43863 .26261 .43145 .27763 Mtetra
.405 .008 .169 r
.43145 .27763 .43863 .26261 .44973 .262 .44268 .27641 Mtetra
.413 .01 .162 r
.44268 .27641 .44973 .262 .46091 .26141 .45396 .27561 Mtetra
.409 .004 .156 r
.45396 .27561 .46091 .26141 .47217 .26023 .46531 .27476 Mtetra
.401 0 .157 r
.46531 .27476 .47217 .26023 .4835 .25832 .47674 .27353 Mtetra
.382 0 .16 r
.47674 .27353 .4835 .25832 .49491 .25563 .48825 .27148 Mtetra
.365 0 .163 r
.48825 .27148 .49491 .25563 .50638 .25243 .49983 .26868 Mtetra
.355 0 .165 r
.49983 .26868 .50638 .25243 .5179 .24924 .51148 .26538 Mtetra
.346 0 .159 r
.51148 .26538 .5179 .24924 .52948 .24623 .52318 .26181 Mtetra
.341 0 .148 r
.52318 .26181 .52948 .24623 .54112 .24356 .53493 .25829 Mtetra
.335 0 .131 r
.53493 .25829 .54112 .24356 .55282 .24118 .54674 .25487 Mtetra
.326 0 .107 r
.54674 .25487 .55282 .24118 .56458 .23895 .55861 .25159 Mtetra
.313 0 .079 r
.55861 .25159 .56458 .23895 .57642 .23681 .57054 .24837 Mtetra
.295 0 .044 r
.57054 .24837 .57642 .23681 .58832 .23469 .58252 .24516 Mtetra
.271 0 .003 r
.58252 .24516 .58832 .23469 .60029 .23254 .59457 .24188 Mtetra
.238 0 0 r
.59457 .24188 .60029 .23254 .61233 .23035 .60667 .23848 Mtetra
.193 0 0 r
.60667 .23848 .61233 .23035 .62443 .22807 .61883 .23491 Mtetra
.132 0 0 r
.61883 .23491 .62443 .22807 .63659 .22566 .63104 .23113 Mtetra
.05 0 0 r
.63104 .23113 .63659 .22566 .64882 .22309 .6433 .22712 Mtetra
0 0 0 r
.6433 .22712 .64882 .22309 .66111 .22032 .65561 .22284 Mtetra
.65561 .22284 .66111 .22032 .67345 .21732 .66796 .2183 Mtetra
.357 .826 .774 r
.66796 .2183 .67345 .21732 .68584 .21407 .68035 .21348 Mtetra
.499 .906 .898 r
.68035 .21348 .68584 .21407 .69829 .21059 .69278 .20843 Mtetra
.603 .928 .964 r
.69278 .20843 .69829 .21059 .71079 .20687 .70524 .20314 Mtetra
.662 .906 .979 r
.70524 .20314 .71079 .20687 .72333 .20296 .71774 .19769 Mtetra
.688 .863 .965 r
.71774 .19769 .72333 .20296 .73592 .19891 .73029 .19212 Mtetra
.696 .814 .938 r
.73029 .19212 .73592 .19891 .74857 .19475 .74288 .18646 Mtetra
.535 .714 .955 r
.07322 .41517 .0807 .4217 .0905 .41927 .08287 .41391 Mtetra
.514 .75 .981 r
.08287 .41391 .0905 .41927 .10034 .41677 .09257 .41262 Mtetra
.484 .783 .997 r
.09257 .41262 .10034 .41677 .11025 .41417 .10234 .41126 Mtetra
.44 .808 .995 r
.10234 .41126 .11025 .41417 .12022 .41141 .11217 .40977 Mtetra
.379 .814 .96 r
.11217 .40977 .12022 .41141 .13026 .40844 .12208 .40812 Mtetra
.298 .789 .884 r
.12208 .40812 .13026 .40844 .14036 .40524 .13206 .40627 Mtetra
.207 .733 .77 r
.13206 .40627 .14036 .40524 .15054 .40178 .14212 .40419 Mtetra
0 0 0 r
.14212 .40419 .15054 .40178 .16079 .39808 .15225 .40188 Mtetra
.15225 .40188 .16079 .39808 .1711 .39412 .16246 .3993 Mtetra
.041 0 0 r
.16246 .3993 .1711 .39412 .18147 .38994 .17274 .39649 Mtetra
.099 0 0 r
.17274 .39649 .18147 .38994 .19191 .38555 .1831 .39344 Mtetra
.146 0 0 r
.1831 .39344 .19191 .38555 .20239 .38101 .19352 .3902 Mtetra
.186 0 0 r
.19352 .3902 .20239 .38101 .21292 .37634 .204 .3868 Mtetra
.219 0 0 r
.204 .3868 .21292 .37634 .22349 .37162 .21453 .38329 Mtetra
.248 0 .009 r
.21453 .38329 .22349 .37162 .2341 .36689 .22511 .37972 Mtetra
.272 0 .051 r
.22511 .37972 .2341 .36689 .24473 .36223 .23574 .37611 Mtetra
.293 0 .084 r
.23574 .37611 .24473 .36223 .25539 .3577 .24641 .3725 Mtetra
.305 0 .108 r
.24641 .3725 .25539 .3577 .26608 .35327 .25713 .36882 Mtetra
.312 0 .125 r
.25713 .36882 .26608 .35327 .27681 .34889 .26791 .36502 Mtetra
.308 0 .133 r
.26791 .36502 .27681 .34889 .28759 .34424 .27875 .3609 Mtetra
.301 0 .137 r
.27875 .3609 .28759 .34424 .29844 .3391 .28967 .35638 Mtetra
.3 0 .146 r
.28967 .35638 .29844 .3391 .30938 .33321 .30064 .35156 Mtetra
.309 0 .165 r
.30064 .35156 .30938 .33321 .3204 .32651 .31166 .3466 Mtetra
.34 0 .201 r
.31166 .3466 .3204 .32651 .33147 .31943 .3227 .34198 Mtetra
.376 .028 .241 r
.3227 .34198 .33147 .31943 .34256 .31228 .33374 .33795 Mtetra
.407 .071 .279 r
.33374 .33795 .34256 .31228 .35366 .30555 .34479 .33455 Mtetra
.429 .103 .308 r
.34479 .33455 .35366 .30555 .36474 .2995 .35586 .33165 Mtetra
.437 .119 .327 r
.35586 .33165 .36474 .2995 .37582 .29415 .36699 .3287 Mtetra
.438 .126 .337 r
.36699 .3287 .37582 .29415 .38691 .28953 .37819 .32539 Mtetra
.431 .123 .34 r
.37819 .32539 .38691 .28953 .39801 .28553 .38946 .32141 Mtetra
.422 .115 .337 r
.38946 .32141 .39801 .28553 .40913 .28218 .40082 .31674 Mtetra
.413 .104 .328 r
.40082 .31674 .40913 .28218 .42027 .27955 .41222 .3117 Mtetra
.405 .09 .315 r
.41222 .3117 .42027 .27955 .43145 .27763 .42367 .30662 Mtetra
.401 .078 .298 r
.42367 .30662 .43145 .27763 .44268 .27641 .43515 .30204 Mtetra
.399 .063 .276 r
.43515 .30204 .44268 .27641 .45396 .27561 .44665 .29809 Mtetra
.395 .045 .249 r
.44665 .29809 .45396 .27561 .46531 .27476 .45819 .29473 Mtetra
.389 .025 .222 r
.45819 .29473 .46531 .27476 .47674 .27353 .46978 .29173 Mtetra
.372 0 .194 r
.46978 .29173 .47674 .27353 .48825 .27148 .48143 .28858 Mtetra
.354 0 .171 r
.48143 .28858 .48825 .27148 .49983 .26868 .49314 .28513 Mtetra
.336 0 .154 r
.49314 .28513 .49983 .26868 .51148 .26538 .50491 .28127 Mtetra
.319 0 .138 r
.50491 .28127 .51148 .26538 .52318 .26181 .51673 .27709 Mtetra
.308 0 .123 r
.51673 .27709 .52318 .26181 .53493 .25829 .5286 .27278 Mtetra
.294 0 .103 r
.5286 .27278 .53493 .25829 .54674 .25487 .54052 .26839 Mtetra
.279 0 .077 r
.54052 .26839 .54674 .25487 .55861 .25159 .5525 .264 Mtetra
.258 0 .043 r
.5525 .264 .55861 .25159 .57054 .24837 .56452 .25957 Mtetra
.229 0 0 r
.56452 .25957 .57054 .24837 .58252 .24516 .5766 .25508 Mtetra
.189 0 0 r
.5766 .25508 .58252 .24516 .59457 .24188 .58872 .25046 Mtetra
.137 0 0 r
.58872 .25046 .59457 .24188 .60667 .23848 .60089 .24568 Mtetra
.067 0 0 r
.60089 .24568 .60667 .23848 .61883 .23491 .6131 .24069 Mtetra
0 0 0 r
.6131 .24069 .61883 .23491 .63104 .23113 .62536 .23546 Mtetra
.62536 .23546 .63104 .23113 .6433 .22712 .63765 .22997 Mtetra
.63765 .22997 .6433 .22712 .65561 .22284 .64998 .2242 Mtetra
.427 .863 .765 r
.64998 .2242 .65561 .22284 .66796 .2183 .66234 .21818 Mtetra
.555 .933 .876 r
.66234 .21818 .66796 .2183 .68035 .21348 .67473 .21191 Mtetra
.647 .955 .939 r
.67473 .21191 .68035 .21348 .69278 .20843 .68715 .20543 Mtetra
.702 .94 .961 r
.68715 .20543 .69278 .20843 .70524 .20314 .6996 .19876 Mtetra
.729 .905 .957 r
.6996 .19876 .70524 .20314 .71774 .19769 .71208 .19195 Mtetra
.738 .863 .939 r
.71208 .19195 .71774 .19769 .73029 .19212 .72459 .18505 Mtetra
.736 .82 .917 r
.72459 .18505 .73029 .19212 .74288 .18646 .73713 .1781 Mtetra
.474 .69 .962 r
.06568 .40859 .07322 .41517 .08287 .41391 .07523 .40815 Mtetra
.452 .712 .978 r
.07523 .40815 .08287 .41391 .09257 .41262 .08483 .4077 Mtetra
.426 .732 .99 r
.08483 .4077 .09257 .41262 .10234 .41126 .0945 .40722 Mtetra
.393 .75 .993 r
.0945 .40722 .10234 .41126 .11217 .40977 .10423 .40666 Mtetra
.353 .762 .982 r
.10423 .40666 .11217 .40977 .12208 .40812 .11404 .40599 Mtetra
.303 .762 .95 r
.11404 .40599 .12208 .40812 .13206 .40627 .12392 .40517 Mtetra
.244 .747 .894 r
.12392 .40517 .13206 .40627 .14212 .40419 .13388 .40417 Mtetra
.176 .711 .812 r
.13388 .40417 .14212 .40419 .15225 .40188 .14392 .40297 Mtetra
.106 .658 .71 r
.14392 .40297 .15225 .40188 .16246 .3993 .15404 .40154 Mtetra
0 0 0 r
.15404 .40154 .16246 .3993 .17274 .39649 .16424 .3999 Mtetra
.028 0 0 r
.16424 .3999 .17274 .39649 .1831 .39344 .17452 .39804 Mtetra
.085 0 0 r
.17452 .39804 .1831 .39344 .19352 .3902 .18487 .39598 Mtetra
.134 0 0 r
.18487 .39598 .19352 .3902 .204 .3868 .19529 .39375 Mtetra
.175 0 0 r
.19529 .39375 .204 .3868 .21453 .38329 .20577 .39137 Mtetra
.208 0 0 r
.20577 .39137 .21453 .38329 .22511 .37972 .21632 .38886 Mtetra
.233 0 0 r
.21632 .38886 .22511 .37972 .23574 .37611 .22694 .3862 Mtetra
.25 0 0 r
.22694 .3862 .23574 .37611 .24641 .3725 .23762 .38339 Mtetra
.259 0 0 r
.23762 .38339 .24641 .3725 .25713 .36882 .24836 .38037 Mtetra
.262 0 .009 r
.24836 .38037 .25713 .36882 .26791 .36502 .25918 .37712 Mtetra
.264 0 .024 r
.25918 .37712 .26791 .36502 .27875 .3609 .27006 .37367 Mtetra
.274 0 .045 r
.27006 .37367 .27875 .3609 .28967 .35638 .28099 .37011 Mtetra
.305 0 .083 r
.28099 .37011 .28967 .35638 .30064 .35156 .29195 .36686 Mtetra
.35 0 .136 r
.29195 .36686 .30064 .35156 .31166 .3466 .30291 .36421 Mtetra
.402 .02 .196 r
.30291 .36421 .31166 .3466 .3227 .34198 .31386 .36254 Mtetra
.444 .078 .248 r
.31386 .36254 .3227 .34198 .33374 .33795 .32481 .36192 Mtetra
.465 .115 .286 r
.32481 .36192 .33374 .33795 .34479 .33455 .33579 .3619 Mtetra
.473 .135 .311 r
.33579 .3619 .34479 .33455 .35586 .33165 .34684 .36201 Mtetra
.465 .136 .324 r
.34684 .36201 .35586 .33165 .36699 .3287 .35801 .36129 Mtetra
.448 .127 .328 r
.35801 .36129 .36699 .3287 .37819 .32539 .36932 .35917 Mtetra
.423 .107 .324 r
.36932 .35917 .37819 .32539 .38946 .32141 .38077 .35518 Mtetra
.394 .082 .313 r
.38077 .35518 .38946 .32141 .40082 .31674 .39235 .34934 Mtetra
.365 .054 .298 r
.39235 .34934 .40082 .31674 .41222 .3117 .40401 .34207 Mtetra
.338 .024 .277 r
.40401 .34207 .41222 .3117 .42367 .30662 .41574 .33397 Mtetra
.32 0 .252 r
.41574 .33397 .42367 .30662 .43515 .30204 .42747 .32597 Mtetra
.306 0 .221 r
.42747 .32597 .43515 .30204 .44665 .29809 .43922 .31857 Mtetra
.299 0 .185 r
.43922 .31857 .44665 .29809 .45819 .29473 .45096 .31222 Mtetra
.294 0 .145 r
.45096 .31222 .45819 .29473 .46978 .29173 .46272 .30685 Mtetra
.281 0 .101 r
.46272 .30685 .46978 .29173 .48143 .28858 .47451 .30208 Mtetra
.266 0 .063 r
.47451 .30208 .48143 .28858 .49314 .28513 .48634 .29762 Mtetra
.243 0 .03 r
.48634 .29762 .49314 .28513 .50491 .28127 .49822 .29305 Mtetra
.218 0 .001 r
.49822 .29305 .50491 .28127 .51673 .27709 .51016 .28828 Mtetra
.193 0 0 r
.51016 .28828 .51673 .27709 .5286 .27278 .52214 .28326 Mtetra
.163 0 0 r
.52214 .28326 .5286 .27278 .54052 .26839 .53416 .27803 Mtetra
.128 0 0 r
.53416 .27803 .54052 .26839 .5525 .264 .54623 .27263 Mtetra
.082 0 0 r
.54623 .27263 .5525 .264 .56452 .25957 .55834 .26708 Mtetra
.023 0 0 r
.55834 .26708 .56452 .25957 .5766 .25508 .57049 .26139 Mtetra
0 0 0 r
.57049 .26139 .5766 .25508 .58872 .25046 .58269 .25553 Mtetra
.58269 .25553 .58872 .25046 .60089 .24568 .59492 .24948 Mtetra
.59492 .24948 .60089 .24568 .6131 .24069 .60718 .24322 Mtetra
.38 .821 .681 r
.60718 .24322 .6131 .24069 .62536 .23546 .61948 .23673 Mtetra
.498 .902 .791 r
.61948 .23673 .62536 .23546 .63765 .22997 .63181 .23 Mtetra
.598 .951 .873 r
.63181 .23 .63765 .22997 .64998 .2242 .64417 .22302 Mtetra
.672 .968 .923 r
.64417 .22302 .64998 .2242 .66234 .21818 .65655 .21583 Mtetra
.72 .96 .945 r
.65655 .21583 .66234 .21818 .67473 .21191 .66895 .20843 Mtetra
.748 .937 .948 r
.66895 .20843 .67473 .21191 .68715 .20543 .68138 .20087 Mtetra
.761 .907 .94 r
.68138 .20087 .68715 .20543 .6996 .19876 .69383 .19317 Mtetra
.765 .876 .927 r
.69383 .19317 .6996 .19876 .71208 .19195 .70631 .18539 Mtetra
.764 .845 .913 r
.70631 .18539 .71208 .19195 .72459 .18505 .71881 .17754 Mtetra
.759 .815 .897 r
.71881 .17754 .72459 .18505 .73713 .1781 .73134 .16968 Mtetra
.458 .683 .963 r
.05808 .40196 .06568 .40859 .07523 .40815 .06761 .40171 Mtetra
.451 .688 .967 r
.06761 .40171 .07523 .40815 .08483 .4077 .0772 .40146 Mtetra
.446 .694 .971 r
.0772 .40146 .08483 .4077 .0945 .40722 .08685 .40121 Mtetra
.442 .701 .976 r
.08685 .40121 .0945 .40722 .10423 .40666 .09656 .40091 Mtetra
.439 .71 .98 r
.09656 .40091 .10423 .40666 .11404 .40599 .10634 .40054 Mtetra
.437 .721 .985 r
.10634 .40054 .11404 .40599 .12392 .40517 .11619 .40008 Mtetra
.436 .735 .99 r
.11619 .40008 .12392 .40517 .13388 .40417 .12612 .39949 Mtetra
.434 .749 .994 r
.12612 .39949 .13388 .40417 .14392 .40297 .13613 .39874 Mtetra
.431 .764 .996 r
.13613 .39874 .14392 .40297 .15404 .40154 .14621 .39782 Mtetra
.423 .779 .996 r
.14621 .39782 .15404 .40154 .16424 .3999 .15637 .39674 Mtetra
.412 .793 .992 r
.15637 .39674 .16424 .3999 .17452 .39804 .16661 .39547 Mtetra
.394 .802 .981 r
.16661 .39547 .17452 .39804 .18487 .39598 .17692 .39405 Mtetra
.37 .805 .962 r
.17692 .39405 .18487 .39598 .19529 .39375 .18731 .39247 Mtetra
.339 .802 .933 r
.18731 .39247 .19529 .39375 .20577 .39137 .19777 .39074 Mtetra
.305 .791 .895 r
.19777 .39074 .20577 .39137 .21632 .38886 .2083 .38886 Mtetra
.274 .777 .853 r
.2083 .38886 .21632 .38886 .22694 .3862 .2189 .38678 Mtetra
.249 .763 .81 r
.2189 .38678 .22694 .3862 .23762 .38339 .22957 .38449 Mtetra
.236 .752 .774 r
.22957 .38449 .23762 .38339 .24836 .38037 .24033 .38193 Mtetra
.229 .745 .743 r
.24033 .38193 .24836 .38037 .25918 .37712 .25116 .37908 Mtetra
.217 .733 .712 r
.25116 .37908 .25918 .37712 .27006 .37367 .26206 .37602 Mtetra
0 0 0 r
.26206 .37602 .27006 .37367 .28099 .37011 .27302 .37285 Mtetra
.27302 .37285 .28099 .37011 .29195 .36686 .28401 .36991 Mtetra
.28401 .36991 .29195 .36686 .30291 .36421 .29502 .36743 Mtetra
.025 0 0 r
.29502 .36743 .30291 .36421 .31386 .36254 .30604 .36553 Mtetra
.071 0 0 r
.30604 .36553 .31386 .36254 .32481 .36192 .31709 .3642 Mtetra
.039 0 0 r
.31709 .3642 .32481 .36192 .33579 .3619 .3282 .36302 Mtetra
0 0 0 r
.3282 .36302 .33579 .3619 .34684 .36201 .33938 .36168 Mtetra
.264 .77 .858 r
.33938 .36168 .34684 .36201 .35801 .36129 .35066 .35969 Mtetra
.452 .86 .962 r
.35066 .35969 .35801 .36129 .36932 .35917 .36205 .35677 Mtetra
.58 .896 .986 r
.36205 .35677 .36932 .35917 .38077 .35518 .37355 .35276 Mtetra
.649 .918 .978 r
.37355 .35276 .38077 .35518 .39235 .34934 .38515 .34765 Mtetra
.68 .945 .961 r
.38515 .34765 .39235 .34934 .40401 .34207 .39682 .34161 Mtetra
.672 .965 .929 r
.39682 .34161 .40401 .34207 .41574 .33397 .40856 .33492 Mtetra
.608 .955 .868 r
.40856 .33492 .41574 .33397 .42747 .32597 .42033 .32804 Mtetra
.516 .91 .791 r
.42033 .32804 .42747 .32597 .43922 .31857 .43213 .32131 Mtetra
.409 .845 .718 r
.43213 .32131 .43922 .31857 .45096 .31222 .44394 .31514 Mtetra
.335 .796 .678 r
.44394 .31514 .45096 .31222 .46272 .30685 .45578 .30956 Mtetra
.306 .78 .678 r
.45578 .30956 .46272 .30685 .47451 .30208 .46765 .30443 Mtetra
.31 .787 .701 r
.46765 .30443 .47451 .30208 .48634 .29762 .47956 .29953 Mtetra
.353 .82 .743 r
.47956 .29953 .48634 .29762 .49822 .29305 .49151 .29452 Mtetra
.406 .855 .786 r
.49151 .29452 .49822 .29305 .51016 .28828 .50352 .28929 Mtetra
.464 .889 .826 r
.50352 .28929 .51016 .28828 .52214 .28326 .51557 .28376 Mtetra
.521 .918 .864 r
.51557 .28376 .52214 .28326 .53416 .27803 .52766 .27794 Mtetra
.573 .939 .897 r
.52766 .27794 .53416 .27803 .54623 .27263 .5398 .27189 Mtetra
.619 .952 .925 r
.5398 .27189 .54623 .27263 .55834 .26708 .55197 .26563 Mtetra
.658 .955 .945 r
.55197 .26563 .55834 .26708 .57049 .26139 .56418 .25922 Mtetra
.689 .95 .956 r
.56418 .25922 .57049 .26139 .58269 .25553 .57642 .25263 Mtetra
.713 .938 .959 r
.57642 .25263 .58269 .25553 .59492 .24948 .5887 .24588 Mtetra
.731 .923 .957 r
.5887 .24588 .59492 .24948 .60718 .24322 .601 .23895 Mtetra
.743 .905 .95 r
.601 .23895 .60718 .24322 .61948 .23673 .61334 .23182 Mtetra
.752 .888 .94 r
.61334 .23182 .61948 .23673 .63181 .23 .62571 .22451 Mtetra
.758 .871 .93 r
.62571 .22451 .63181 .23 .64417 .22302 .6381 .217 Mtetra
.762 .856 .92 r
.6381 .217 .64417 .22302 .65655 .21583 .65051 .20932 Mtetra
.764 .843 .911 r
.65051 .20932 .65655 .21583 .66895 .20843 .66295 .20149 Mtetra
.764 .831 .903 r
.66295 .20149 .66895 .20843 .68138 .20087 .67541 .19354 Mtetra
.764 .82 .897 r
.67541 .19354 .68138 .20087 .69383 .19317 .68789 .18551 Mtetra
.763 .811 .891 r
.68789 .18551 .69383 .19317 .70631 .18539 .7004 .17742 Mtetra
.762 .804 .887 r
.7004 .17742 .70631 .18539 .71881 .17754 .71294 .1693 Mtetra
.759 .796 .883 r
.71294 .1693 .71881 .17754 .73134 .16968 .7255 .16118 Mtetra
.484 .694 .961 r
.05043 .39529 .05808 .40196 .06761 .40171 .06003 .39467 Mtetra
.489 .685 .953 r
.06003 .39467 .06761 .40171 .0772 .40146 .06967 .39408 Mtetra
.494 .676 .946 r
.06967 .39408 .0772 .40146 .08685 .40121 .07937 .39349 Mtetra
.5 .668 .938 r
.07937 .39349 .08685 .40121 .09656 .40091 .08913 .39288 Mtetra
.505 .661 .931 r
.08913 .39288 .09656 .40091 .10634 .40054 .09896 .39225 Mtetra
.511 .656 .925 r
.09896 .39225 .10634 .40054 .11619 .40008 .10884 .39156 Mtetra
.518 .653 .919 r
.10884 .39156 .11619 .40008 .12612 .39949 .1188 .39079 Mtetra
.525 .652 .915 r
.1188 .39079 .12612 .39949 .13613 .39874 .12883 .38992 Mtetra
.531 .652 .912 r
.12883 .38992 .13613 .39874 .14621 .39782 .13893 .38894 Mtetra
.538 .653 .91 r
.13893 .38894 .14621 .39782 .15637 .39674 .1491 .38784 Mtetra
.544 .656 .909 r
.1491 .38784 .15637 .39674 .16661 .39547 .15934 .38661 Mtetra
.549 .66 .91 r
.15934 .38661 .16661 .39547 .17692 .39405 .16965 .38526 Mtetra
.554 .665 .911 r
.16965 .38526 .17692 .39405 .18731 .39247 .18004 .38379 Mtetra
.559 .672 .913 r
.18004 .38379 .18731 .39247 .19777 .39074 .19049 .3822 Mtetra
.564 .679 .916 r
.19049 .3822 .19777 .39074 .2083 .38886 .20102 .38046 Mtetra
.572 .687 .918 r
.20102 .38046 .2083 .38886 .2189 .38678 .21162 .37854 Mtetra
.581 .695 .92 r
.21162 .37854 .2189 .38678 .22957 .38449 .2223 .37641 Mtetra
.591 .705 .922 r
.2223 .37641 .22957 .38449 .24033 .38193 .23305 .37402 Mtetra
.602 .715 .924 r
.23305 .37402 .24033 .38193 .25116 .37908 .24388 .37138 Mtetra
.609 .725 .927 r
.24388 .37138 .25116 .37908 .26206 .37602 .25479 .36853 Mtetra
.615 .734 .931 r
.25479 .36853 .26206 .37602 .27302 .37285 .26576 .36551 Mtetra
.616 .74 .934 r
.26576 .36551 .27302 .37285 .28401 .36991 .27678 .36244 Mtetra
.617 .737 .932 r
.27678 .36244 .28401 .36991 .29502 .36743 .28786 .35936 Mtetra
.623 .722 .918 r
.28786 .35936 .29502 .36743 .30604 .36553 .29899 .35614 Mtetra
.63 .69 .887 r
.29899 .35614 .30604 .36553 .31709 .3642 .3102 .35269 Mtetra
.636 .645 .842 r
.3102 .35269 .31709 .3642 .3282 .36302 .32148 .34885 Mtetra
.634 .599 .796 r
.32148 .34885 .3282 .36302 .33938 .36168 .33283 .34461 Mtetra
.624 .557 .759 r
.33283 .34461 .33938 .36168 .35066 .35969 .34424 .34024 Mtetra
.614 .529 .734 r
.34424 .34024 .35066 .35969 .36205 .35677 .35569 .33591 Mtetra
.604 .511 .722 r
.35569 .33591 .36205 .35677 .37355 .35276 .36717 .33186 Mtetra
.598 .508 .723 r
.36717 .33186 .37355 .35276 .38515 .34765 .37869 .32808 Mtetra
.602 .521 .736 r
.37869 .32808 .38515 .34765 .39682 .34161 .39026 .32434 Mtetra
.612 .551 .761 r
.39026 .32434 .39682 .34161 .40856 .33492 .40188 .32048 Mtetra
.632 .598 .797 r
.40188 .32048 .40856 .33492 .42033 .32804 .41358 .31621 Mtetra
.654 .653 .837 r
.41358 .31621 .42033 .32804 .43213 .32131 .42533 .31155 Mtetra
.67 .705 .873 r
.42533 .31155 .43213 .32131 .44394 .31514 .43714 .30665 Mtetra
.68 .742 .898 r
.43714 .30665 .44394 .31514 .45578 .30956 .44899 .30161 Mtetra
.682 .759 .91 r
.44899 .30161 .45578 .30956 .46765 .30443 .46089 .29654 Mtetra
.683 .762 .912 r
.46089 .29654 .46765 .30443 .47956 .29953 .47284 .29143 Mtetra
.687 .758 .906 r
.47284 .29143 .47956 .29953 .49151 .29452 .48483 .28614 Mtetra
.692 .753 .898 r
.48483 .28614 .49151 .29452 .50352 .28929 .49687 .28063 Mtetra
.699 .749 .89 r
.49687 .28063 .50352 .28929 .51557 .28376 .50896 .27485 Mtetra
.704 .745 .883 r
.50896 .27485 .51557 .28376 .52766 .27794 .52109 .2688 Mtetra
.709 .742 .877 r
.52109 .2688 .52766 .27794 .5398 .27189 .53326 .26253 Mtetra
.712 .738 .872 r
.53326 .26253 .5398 .27189 .55197 .26563 .54546 .25606 Mtetra
.714 .735 .867 r
.54546 .25606 .55197 .26563 .56418 .25922 .5577 .24944 Mtetra
.716 .731 .863 r
.5577 .24944 .56418 .25922 .57642 .25263 .56998 .24267 Mtetra
.718 .728 .859 r
.56998 .24267 .57642 .25263 .5887 .24588 .58228 .23577 Mtetra
.72 .727 .856 r
.58228 .23577 .5887 .24588 .601 .23895 .59462 .22873 Mtetra
.722 .726 .853 r
.59462 .22873 .601 .23895 .61334 .23182 .607 .22155 Mtetra
.725 .727 .852 r
.607 .22155 .61334 .23182 .62571 .22451 .6194 .21424 Mtetra
.728 .729 .851 r
.6194 .21424 .62571 .22451 .6381 .217 .63183 .20679 Mtetra
.731 .732 .852 r
.63183 .20679 .6381 .217 .65051 .20932 .64428 .19923 Mtetra
.734 .737 .853 r
.64428 .19923 .65051 .20932 .66295 .20149 .65677 .19156 Mtetra
.737 .742 .856 r
.65677 .19156 .66295 .20149 .67541 .19354 .66928 .18383 Mtetra
.739 .749 .86 r
.66928 .18383 .67541 .19354 .68789 .18551 .68182 .17605 Mtetra
.742 .758 .865 r
.68182 .17605 .68789 .18551 .7004 .17742 .69438 .16824 Mtetra
.744 .767 .871 r
.69438 .16824 .7004 .17742 .71294 .1693 .70698 .16042 Mtetra
.746 .776 .877 r
.70698 .16042 .71294 .1693 .7255 .16118 .71961 .15261 Mtetra
.547 .719 .952 r
.04273 .38856 .05043 .39529 .06003 .39467 .05247 .38701 Mtetra
.554 .692 .931 r
.05247 .38701 .06003 .39467 .06967 .39408 .06225 .38549 Mtetra
.559 .666 .909 r
.06225 .38549 .06967 .39408 .07937 .39349 .07209 .38398 Mtetra
.562 .643 .888 r
.07209 .38398 .07937 .39349 .08913 .39288 .08198 .38247 Mtetra
.564 .622 .869 r
.08198 .38247 .08913 .39288 .09896 .39225 .09192 .38097 Mtetra
.565 .604 .851 r
.09192 .38097 .09896 .39225 .10884 .39156 .10191 .37944 Mtetra
.567 .588 .834 r
.10191 .37944 .10884 .39156 .1188 .39079 .11197 .37787 Mtetra
.568 .575 .82 r
.11197 .37787 .1188 .39079 .12883 .38992 .12208 .37624 Mtetra
.57 .564 .807 r
.12208 .37624 .12883 .38992 .13893 .38894 .13226 .37453 Mtetra
.572 .554 .796 r
.13226 .37453 .13893 .38894 .1491 .38784 .14251 .37274 Mtetra
.573 .545 .785 r
.14251 .37274 .1491 .38784 .15934 .38661 .15282 .37085 Mtetra
.575 .538 .776 r
.15282 .37085 .15934 .38661 .16965 .38526 .16319 .36885 Mtetra
.576 .531 .768 r
.16319 .36885 .16965 .38526 .18004 .38379 .17363 .36675 Mtetra
.578 .525 .76 r
.17363 .36675 .18004 .38379 .19049 .3822 .18414 .36453 Mtetra
.579 .519 .752 r
.18414 .36453 .19049 .3822 .20102 .38046 .19471 .3622 Mtetra
.58 .514 .746 r
.19471 .3622 .20102 .38046 .21162 .37854 .20534 .35976 Mtetra
.581 .51 .74 r
.20534 .35976 .21162 .37854 .2223 .37641 .21604 .35722 Mtetra
.581 .507 .736 r
.21604 .35722 .2223 .37641 .23305 .37402 .2268 .3546 Mtetra
.581 .506 .734 r
.2268 .3546 .23305 .37402 .24388 .37138 .23761 .35194 Mtetra
.581 .506 .735 r
.23761 .35194 .24388 .37138 .25479 .36853 .24848 .34928 Mtetra
.582 .508 .737 r
.24848 .34928 .25479 .36853 .26576 .36551 .2594 .34661 Mtetra
.584 .514 .741 r
.2594 .34661 .26576 .36551 .27678 .36244 .27038 .34386 Mtetra
.589 .52 .745 r
.27038 .34386 .27678 .36244 .28786 .35936 .28144 .3409 Mtetra
.601 .528 .745 r
.28144 .3409 .28786 .35936 .29899 .35614 .29258 .3374 Mtetra
.614 .533 .74 r
.29258 .3374 .29899 .35614 .3102 .35269 .30382 .3332 Mtetra
.625 .533 .731 r
.30382 .3332 .3102 .35269 .32148 .34885 .31516 .32827 Mtetra
.63 .528 .72 r
.31516 .32827 .32148 .34885 .33283 .34461 .32658 .32278 Mtetra
.623 .515 .71 r
.32658 .32278 .33283 .34461 .34424 .34024 .33802 .31734 Mtetra
.612 .501 .703 r
.33802 .31734 .34424 .34024 .35569 .33591 .34949 .31236 Mtetra
.596 .487 .7 r
.34949 .31236 .35569 .33591 .36717 .33186 .36094 .30826 Mtetra
.58 .477 .702 r
.36094 .30826 .36717 .33186 .37869 .32808 .3724 .30505 Mtetra
.573 .477 .707 r
.3724 .30505 .37869 .32808 .39026 .32434 .3839 .30229 Mtetra
.574 .485 .716 r
.3839 .30229 .39026 .32434 .40188 .32048 .39545 .2996 Mtetra
.587 .503 .726 r
.39545 .2996 .40188 .32048 .41358 .31621 .40709 .29634 Mtetra
.604 .521 .734 r
.40709 .29634 .41358 .31621 .42533 .31155 .41881 .29234 Mtetra
.62 .537 .739 r
.41881 .29234 .42533 .31155 .43714 .30665 .4306 .28764 Mtetra
.63 .545 .74 r
.4306 .28764 .43714 .30665 .44899 .30161 .44245 .28239 Mtetra
.633 .545 .737 r
.44245 .28239 .44899 .30161 .46089 .29654 .45435 .27693 Mtetra
.633 .542 .733 r
.45435 .27693 .46089 .29654 .47284 .29143 .46629 .27137 Mtetra
.631 .537 .73 r
.46629 .27137 .47284 .29143 .48483 .28614 .47828 .2658 Mtetra
.63 .534 .728 r
.47828 .2658 .48483 .28614 .49687 .28063 .49031 .26022 Mtetra
.63 .534 .727 r
.49031 .26022 .49687 .28063 .50896 .27485 .50239 .25459 Mtetra
.632 .537 .729 r
.50239 .25459 .50896 .27485 .52109 .2688 .5145 .24888 Mtetra
.635 .542 .732 r
.5145 .24888 .52109 .2688 .53326 .26253 .52666 .24306 Mtetra
.639 .548 .736 r
.52666 .24306 .53326 .26253 .54546 .25606 .53886 .23711 Mtetra
.643 .556 .741 r
.53886 .23711 .54546 .25606 .5577 .24944 .55111 .23104 Mtetra
.648 .564 .747 r
.55111 .23104 .5577 .24944 .56998 .24267 .56339 .22485 Mtetra
.653 .573 .753 r
.56339 .22485 .56998 .24267 .58228 .23577 .57571 .21853 Mtetra
.658 .583 .759 r
.57571 .21853 .58228 .23577 .59462 .22873 .58807 .2121 Mtetra
.664 .593 .766 r
.58807 .2121 .59462 .22873 .607 .22155 .60046 .20556 Mtetra
.669 .604 .774 r
.60046 .20556 .607 .22155 .6194 .21424 .6129 .19892 Mtetra
.675 .617 .782 r
.6129 .19892 .6194 .21424 .63183 .20679 .62536 .19218 Mtetra
.681 .63 .792 r
.62536 .19218 .63183 .20679 .64428 .19923 .63787 .18538 Mtetra
.687 .645 .803 r
.63787 .18538 .64428 .19923 .65677 .19156 .65041 .17851 Mtetra
.693 .662 .815 r
.65041 .17851 .65677 .19156 .66928 .18383 .66299 .17161 Mtetra
.7 .681 .829 r
.66299 .17161 .66928 .18383 .68182 .17605 .6756 .1647 Mtetra
.706 .702 .844 r
.6756 .1647 .68182 .17605 .69438 .16824 .68825 .15779 Mtetra
.712 .725 .86 r
.68825 .15779 .69438 .16824 .70698 .16042 .70094 .15087 Mtetra
.718 .751 .878 r
.70094 .15087 .70698 .16042 .71961 .15261 .71368 .14397 Mtetra
.617 .741 .935 r
.03496 .38178 .04273 .38856 .05247 .38701 .04491 .37896 Mtetra
.617 .703 .906 r
.04491 .37896 .05247 .38701 .06225 .38549 .05489 .37616 Mtetra
.615 .669 .879 r
.05489 .37616 .06225 .38549 .07209 .38398 .06491 .37338 Mtetra
.611 .639 .853 r
.06491 .37338 .07209 .38398 .08198 .38247 .07498 .37062 Mtetra
.607 .612 .83 r
.07498 .37062 .08198 .38247 .09192 .38097 .08508 .36789 Mtetra
.603 .589 .809 r
.08508 .36789 .09192 .38097 .10191 .37944 .09524 .36515 Mtetra
.599 .569 .791 r
.09524 .36515 .10191 .37944 .11197 .37787 .10544 .36241 Mtetra
.596 .551 .775 r
.10544 .36241 .11197 .37787 .12208 .37624 .11569 .35965 Mtetra
.593 .537 .76 r
.11569 .35965 .12208 .37624 .13226 .37453 .12599 .35684 Mtetra
.591 .524 .748 r
.12599 .35684 .13226 .37453 .14251 .37274 .13635 .35398 Mtetra
.59 .513 .736 r
.13635 .35398 .14251 .37274 .15282 .37085 .14676 .35105 Mtetra
.588 .503 .726 r
.14676 .35105 .15282 .37085 .16319 .36885 .15723 .34804 Mtetra
.587 .495 .717 r
.15723 .34804 .16319 .36885 .17363 .36675 .16775 .34493 Mtetra
.586 .487 .709 r
.16775 .34493 .17363 .36675 .18414 .36453 .17834 .34175 Mtetra
.584 .48 .701 r
.17834 .34175 .18414 .36453 .19471 .3622 .18897 .33849 Mtetra
.582 .473 .694 r
.18897 .33849 .19471 .3622 .20534 .35976 .19966 .33521 Mtetra
.58 .467 .689 r
.19966 .33521 .20534 .35976 .21604 .35722 .21039 .33195 Mtetra
.576 .461 .684 r
.21039 .33195 .21604 .35722 .2268 .3546 .22116 .3288 Mtetra
.572 .455 .681 r
.22116 .3288 .2268 .3546 .23761 .35194 .23196 .32582 Mtetra
.568 .451 .68 r
.23196 .32582 .23761 .35194 .24848 .34928 .2428 .32303 Mtetra
.565 .449 .68 r
.2428 .32303 .24848 .34928 .2594 .34661 .25367 .32042 Mtetra
.566 .45 .68 r
.25367 .32042 .2594 .34661 .27038 .34386 .26461 .31775 Mtetra
.57 .454 .681 r
.26461 .31775 .27038 .34386 .28144 .3409 .27561 .31484 Mtetra
.581 .461 .681 r
.27561 .31484 .28144 .3409 .29258 .3374 .28673 .31126 Mtetra
.594 .469 .68 r
.28673 .31126 .29258 .3374 .30382 .3332 .29795 .30682 Mtetra
.605 .476 .678 r
.29795 .30682 .30382 .3332 .31516 .32827 .30927 .30156 Mtetra
.612 .479 .675 r
.30927 .30156 .31516 .32827 .32658 .32278 .32067 .29571 Mtetra
.609 .475 .674 r
.32067 .29571 .32658 .32278 .33802 .31734 .3321 .28997 Mtetra
.6 .468 .673 r
.3321 .28997 .33802 .31734 .34949 .31236 .34353 .2848 Mtetra
.585 .458 .673 r
.34353 .2848 .34949 .31236 .36094 .30826 .35495 .28065 Mtetra
.569 .447 .674 r
.35495 .28065 .36094 .30826 .3724 .30505 .36636 .27753 Mtetra
.561 .442 .675 r
.36636 .27753 .3724 .30505 .3839 .30229 .3778 .27497 Mtetra
.559 .443 .677 r
.3778 .27497 .3839 .30229 .39545 .2996 .38929 .27255 Mtetra
.569 .451 .679 r
.38929 .27255 .39545 .2996 .40709 .29634 .40088 .26952 Mtetra
.582 .461 .68 r
.40088 .26952 .40709 .29634 .41881 .29234 .41255 .26567 Mtetra
.595 .47 .68 r
.41255 .26567 .41881 .29234 .4306 .28764 .4243 .26095 Mtetra
.604 .476 .679 r
.4243 .26095 .4306 .28764 .44245 .28239 .43612 .25556 Mtetra
.607 .478 .678 r
.43612 .25556 .44245 .28239 .45435 .27693 .44799 .24991 Mtetra
.607 .477 .677 r
.44799 .24991 .45435 .27693 .46629 .27137 .4599 .2442 Mtetra
.604 .474 .677 r
.4599 .2442 .46629 .27137 .47828 .2658 .47185 .23866 Mtetra
.602 .473 .678 r
.47185 .23866 .47828 .2658 .49031 .26022 .48384 .23331 Mtetra
.6 .473 .68 r
.48384 .23331 .49031 .26022 .50239 .25459 .49587 .22813 Mtetra
.599 .475 .683 r
.49587 .22813 .50239 .25459 .5145 .24888 .50795 .22305 Mtetra
.601 .48 .687 r
.50795 .22305 .5145 .24888 .52666 .24306 .52007 .218 Mtetra
.603 .486 .692 r
.52007 .218 .52666 .24306 .53886 .23711 .53225 .21291 Mtetra
.607 .494 .699 r
.53225 .21291 .53886 .23711 .55111 .23104 .54447 .20774 Mtetra
.611 .503 .706 r
.54447 .20774 .55111 .23104 .56339 .22485 .55674 .20249 Mtetra
.616 .512 .713 r
.55674 .20249 .56339 .22485 .57571 .21853 .56906 .19714 Mtetra
.621 .523 .722 r
.56906 .19714 .57571 .21853 .58807 .2121 .58142 .19169 Mtetra
.626 .534 .731 r
.58142 .19169 .58807 .2121 .60046 .20556 .59384 .18617 Mtetra
.631 .547 .741 r
.59384 .18617 .60046 .20556 .6129 .19892 .60629 .18058 Mtetra
.637 .561 .752 r
.60629 .18058 .6129 .19892 .62536 .19218 .6188 .17494 Mtetra
.643 .577 .765 r
.6188 .17494 .62536 .19218 .63787 .18538 .63135 .16927 Mtetra
.649 .594 .78 r
.63135 .16927 .63787 .18538 .65041 .17851 .64395 .16358 Mtetra
.655 .614 .796 r
.64395 .16358 .65041 .17851 .66299 .17161 .65659 .15788 Mtetra
.662 .637 .815 r
.65659 .15788 .66299 .17161 .6756 .1647 .66929 .15221 Mtetra
.668 .663 .836 r
.66929 .15221 .6756 .1647 .68825 .15779 .68204 .14654 Mtetra
.675 .693 .859 r
.68204 .14654 .68825 .15779 .70094 .15087 .69484 .14089 Mtetra
.68 .726 .884 r
.69484 .14089 .70094 .15087 .71368 .14397 .70769 .13525 Mtetra
.677 .756 .911 r
.02714 .37496 .03496 .38178 .04491 .37896 .03732 .37069 Mtetra
.67 .715 .882 r
.03732 .37069 .04491 .37896 .05489 .37616 .04753 .36645 Mtetra
.661 .678 .855 r
.04753 .36645 .05489 .37616 .06491 .37338 .05777 .36225 Mtetra
.652 .645 .83 r
.05777 .36225 .06491 .37338 .07498 .37062 .06804 .35808 Mtetra
.644 .617 .808 r
.06804 .35808 .07498 .37062 .08508 .36789 .07834 .35395 Mtetra
.636 .592 .788 r
.07834 .35395 .08508 .36789 .09524 .36515 .08868 .34985 Mtetra
.628 .57 .77 r
.08868 .34985 .09524 .36515 .10544 .36241 .09905 .34577 Mtetra
.622 .551 .754 r
.09905 .34577 .10544 .36241 .11569 .35965 .10946 .3417 Mtetra
.616 .535 .74 r
.10946 .3417 .11569 .35965 .12599 .35684 .1199 .33763 Mtetra
.611 .521 .728 r
.1199 .33763 .12599 .35684 .13635 .35398 .13039 .33355 Mtetra
.607 .509 .717 r
.13039 .33355 .13635 .35398 .14676 .35105 .14092 .32944 Mtetra
.604 .499 .707 r
.14092 .32944 .14676 .35105 .15723 .34804 .1515 .3253 Mtetra
.6 .489 .699 r
.1515 .3253 .15723 .34804 .16775 .34493 .16212 .32111 Mtetra
.597 .481 .691 r
.16212 .32111 .16775 .34493 .17834 .34175 .17278 .3169 Mtetra
.595 .474 .685 r
.17278 .3169 .17834 .34175 .18897 .33849 .18349 .31267 Mtetra
.591 .466 .679 r
.18349 .31267 .18897 .33849 .19966 .33521 .19423 .30848 Mtetra
.587 .459 .673 r
.19423 .30848 .19966 .33521 .21039 .33195 .20501 .30438 Mtetra
.582 .452 .669 r
.20501 .30438 .21039 .33195 .22116 .3288 .21581 .30047 Mtetra
.577 .446 .665 r
.21581 .30047 .22116 .3288 .23196 .32582 .22663 .2968 Mtetra
.571 .439 .662 r
.22663 .2968 .23196 .32582 .2428 .32303 .23747 .29338 Mtetra
.567 .434 .659 r
.23747 .29338 .2428 .32303 .25367 .32042 .24834 .29018 Mtetra
.566 .431 .656 r
.24834 .29018 .25367 .32042 .26461 .31775 .25926 .28699 Mtetra
.567 .43 .654 r
.25926 .28699 .26461 .31775 .27561 .31484 .27024 .28365 Mtetra
.573 .432 .652 r
.27024 .28365 .27561 .31484 .28673 .31126 .28132 .27981 Mtetra
.581 .437 .651 r
.28132 .27981 .28673 .31126 .29795 .30682 .29249 .27534 Mtetra
.588 .442 .651 r
.29249 .27534 .29795 .30682 .30927 .30156 .30374 .27029 Mtetra
.593 .447 .652 r
.30374 .27029 .30927 .30156 .32067 .29571 .31506 .26483 Mtetra
.593 .448 .654 r
.31506 .26483 .32067 .29571 .3321 .28997 .32641 .25946 Mtetra
.588 .446 .656 r
.32641 .25946 .3321 .28997 .34353 .2848 .33778 .25452 Mtetra
.579 .441 .658 r
.33778 .25452 .34353 .2848 .35495 .28065 .34915 .25032 Mtetra
.568 .434 .658 r
.34915 .25032 .35495 .28065 .36636 .27753 .36052 .24687 Mtetra
.562 .428 .657 r
.36052 .24687 .36636 .27753 .3778 .27497 .37192 .24383 Mtetra
.559 .425 .655 r
.37192 .24383 .3778 .27497 .38929 .27255 .38338 .24091 Mtetra
.564 .427 .653 r
.38338 .24091 .38929 .27255 .40088 .26952 .39492 .23757 Mtetra
.571 .431 .651 r
.39492 .23757 .40088 .26952 .41255 .26567 .40653 .23365 Mtetra
.579 .436 .651 r
.40653 .23365 .41255 .26567 .4243 .26095 .41822 .22908 Mtetra
.585 .441 .652 r
.41822 .22908 .4243 .26095 .43612 .25556 .42997 .22402 Mtetra
.588 .444 .653 r
.42997 .22402 .43612 .25556 .44799 .24991 .44177 .2188 Mtetra
.589 .446 .655 r
.44177 .2188 .44799 .24991 .4599 .2442 .45362 .21358 Mtetra
.587 .447 .658 r
.45362 .21358 .4599 .2442 .47185 .23866 .4655 .20858 Mtetra
.585 .448 .661 r
.4655 .20858 .47185 .23866 .48384 .23331 .47743 .20383 Mtetra
.583 .45 .665 r
.47743 .20383 .48384 .23331 .49587 .22813 .48941 .19933 Mtetra
.582 .452 .669 r
.48941 .19933 .49587 .22813 .50795 .22305 .50143 .19501 Mtetra
.582 .456 .674 r
.50143 .19501 .50795 .22305 .52007 .218 .51351 .19079 Mtetra
.583 .461 .679 r
.51351 .19079 .52007 .218 .53225 .21291 .52565 .1866 Mtetra
.585 .468 .685 r
.52565 .1866 .53225 .21291 .54447 .20774 .53784 .1824 Mtetra
.588 .475 .692 r
.53784 .1824 .54447 .20774 .55674 .20249 .55009 .17816 Mtetra
.592 .484 .7 r
.55009 .17816 .55674 .20249 .56906 .19714 .56239 .17388 Mtetra
.595 .493 .708 r
.56239 .17388 .56906 .19714 .58142 .19169 .57475 .16956 Mtetra
.599 .504 .718 r
.57475 .16956 .58142 .19169 .59384 .18617 .58717 .1652 Mtetra
.603 .516 .729 r
.58717 .1652 .59384 .18617 .60629 .18058 .59964 .16083 Mtetra
.607 .53 .742 r
.59964 .16083 .60629 .18058 .6188 .17494 .61218 .15646 Mtetra
.611 .545 .756 r
.61218 .15646 .6188 .17494 .63135 .16927 .62477 .15209 Mtetra
.615 .563 .773 r
.62477 .15209 .63135 .16927 .64395 .16358 .63743 .14775 Mtetra
.62 .584 .791 r
.63743 .14775 .64395 .16358 .65659 .15788 .65014 .14342 Mtetra
.624 .607 .813 r
.65014 .14342 .65659 .15788 .66929 .15221 .66292 .13914 Mtetra
.629 .634 .837 r
.66292 .13914 .66929 .15221 .68204 .14654 .67577 .13488 Mtetra
.632 .666 .864 r
.67577 .13488 .68204 .14654 .69484 .14089 .68868 .13066 Mtetra
.634 .701 .894 r
.68868 .13066 .69484 .14089 .70769 .13525 .70165 .12647 Mtetra
.722 .764 .886 r
.01926 .36808 .02714 .37496 .03732 .37069 .02968 .36238 Mtetra
.71 .725 .862 r
.02968 .36238 .03732 .37069 .04753 .36645 .04012 .35672 Mtetra
.698 .69 .839 r
.04012 .35672 .04753 .36645 .05777 .36225 .05058 .35112 Mtetra
.687 .659 .817 r
.05058 .35112 .05777 .36225 .06804 .35808 .06106 .34557 Mtetra
.676 .632 .798 r
.06106 .34557 .06804 .35808 .07834 .35395 .07156 .34007 Mtetra
.666 .607 .78 r
.07156 .34007 .07834 .35395 .08868 .34985 .08209 .33462 Mtetra
.656 .586 .764 r
.08209 .33462 .08868 .34985 .09905 .34577 .09263 .32922 Mtetra
.648 .567 .75 r
.09263 .32922 .09905 .34577 .10946 .3417 .1032 .32387 Mtetra
.64 .55 .737 r
.1032 .32387 .10946 .3417 .1199 .33763 .1138 .31857 Mtetra
.633 .535 .726 r
.1138 .31857 .1199 .33763 .13039 .33355 .12442 .31333 Mtetra
.627 .523 .716 r
.12442 .31333 .13039 .33355 .14092 .32944 .13507 .30813 Mtetra
.621 .511 .707 r
.13507 .30813 .14092 .32944 .1515 .3253 .14574 .30298 Mtetra
.616 .502 .7 r
.14574 .30298 .1515 .3253 .16212 .32111 .15644 .29789 Mtetra
.612 .494 .694 r
.15644 .29789 .16212 .32111 .17278 .3169 .16717 .29284 Mtetra
.608 .486 .688 r
.16717 .29284 .17278 .3169 .18349 .31267 .17793 .28784 Mtetra
.605 .48 .683 r
.17793 .28784 .18349 .31267 .19423 .30848 .18872 .2829 Mtetra
.602 .474 .679 r
.18872 .2829 .19423 .30848 .20501 .30438 .19954 .278 Mtetra
.598 .468 .674 r
.19954 .278 .20501 .30438 .21581 .30047 .21039 .27315 Mtetra
.595 .462 .669 r
.21039 .27315 .21581 .30047 .22663 .2968 .22128 .26836 Mtetra
.591 .454 .663 r
.22128 .26836 .22663 .2968 .23747 .29338 .2322 .26361 Mtetra
.587 .446 .657 r
.2322 .26361 .23747 .29338 .24834 .29018 .24315 .25891 Mtetra
.583 .438 .65 r
.24315 .25891 .24834 .29018 .25926 .28699 .25414 .25426 Mtetra
.579 .43 .644 r
.25414 .25426 .25926 .28699 .27024 .28365 .26517 .24966 Mtetra
.576 .424 .639 r
.26517 .24966 .27024 .28365 .28132 .27981 .27623 .24512 Mtetra
.574 .421 .636 r
.27623 .24512 .28132 .27981 .29249 .27534 .28734 .24062 Mtetra
.573 .42 .636 r
.28734 .24062 .29249 .27534 .30374 .27029 .29848 .23617 Mtetra
.573 .422 .639 r
.29848 .23617 .30374 .27029 .31506 .26483 .30966 .23177 Mtetra
.574 .427 .643 r
.30966 .23177 .31506 .26483 .32641 .25946 .32089 .22742 Mtetra
.575 .431 .648 r
.32089 .22742 .32641 .25946 .33778 .25452 .33215 .22312 Mtetra
.576 .434 .651 r
.33215 .22312 .33778 .25452 .34915 .25032 .34346 .21887 Mtetra
.575 .433 .651 r
.34346 .21887 .34915 .25032 .36052 .24687 .35482 .21467 Mtetra
.573 .429 .648 r
.35482 .21467 .36052 .24687 .37192 .24383 .36622 .21051 Mtetra
.57 .424 .643 r
.36622 .21051 .37192 .24383 .38338 .24091 .37766 .20641 Mtetra
.567 .418 .639 r
.37766 .20641 .38338 .24091 .39492 .23757 .38916 .20236 Mtetra
.565 .415 .636 r
.38916 .20236 .39492 .23757 .40653 .23365 .4007 .19836 Mtetra
.564 .414 .636 r
.4007 .19836 .40653 .23365 .41822 .22908 .41229 .19441 Mtetra
.565 .417 .639 r
.41229 .19441 .41822 .22908 .42997 .22402 .42394 .19051 Mtetra
.566 .421 .644 r
.42394 .19051 .42997 .22402 .44177 .2188 .43563 .18666 Mtetra
.567 .427 .65 r
.43563 .18666 .44177 .2188 .45362 .21358 .44738 .18286 Mtetra
.569 .434 .657 r
.44738 .18286 .45362 .21358 .4655 .20858 .45919 .1791 Mtetra
.571 .441 .664 r
.45919 .1791 .4655 .20858 .47743 .20383 .47105 .1754 Mtetra
.572 .446 .671 r
.47105 .1754 .47743 .20383 .48941 .19933 .48296 .17176 Mtetra
.573 .451 .676 r
.48296 .17176 .48941 .19933 .50143 .19501 .49494 .16816 Mtetra
.573 .456 .681 r
.49494 .16816 .50143 .19501 .51351 .19079 .50697 .16461 Mtetra
.574 .46 .686 r
.50697 .16461 .51351 .19079 .52565 .1866 .51907 .16111 Mtetra
.574 .465 .691 r
.51907 .16111 .52565 .1866 .53784 .1824 .53123 .15767 Mtetra
.575 .47 .697 r
.53123 .15767 .53784 .1824 .55009 .17816 .54345 .15427 Mtetra
.576 .477 .704 r
.54345 .15427 .55009 .17816 .56239 .17388 .55573 .15093 Mtetra
.577 .484 .713 r
.55573 .15093 .56239 .17388 .57475 .16956 .56809 .14764 Mtetra
.578 .493 .722 r
.56809 .14764 .57475 .16956 .58717 .1652 .5805 .1444 Mtetra
.58 .504 .734 r
.5805 .1444 .58717 .1652 .59964 .16083 .59299 .14121 Mtetra
.582 .517 .747 r
.59299 .14121 .59964 .16083 .61218 .15646 .60555 .13807 Mtetra
.584 .531 .762 r
.60555 .13807 .61218 .15646 .62477 .15209 .61818 .13499 Mtetra
.585 .548 .779 r
.61818 .13499 .62477 .15209 .63743 .14775 .63089 .13196 Mtetra
.587 .567 .799 r
.63089 .13196 .63743 .14775 .65014 .14342 .64367 .12898 Mtetra
.588 .589 .821 r
.64367 .12898 .65014 .14342 .66292 .13914 .65652 .12606 Mtetra
.588 .615 .846 r
.65652 .12606 .66292 .13914 .67577 .13488 .66946 .12319 Mtetra
.587 .644 .874 r
.66946 .12319 .67577 .13488 .68868 .13066 .68247 .12037 Mtetra
.583 .677 .905 r
.68247 .12037 .68868 .13066 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Nooooo`;oUZCO1?nE[NL00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo057ooooo001Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool07Oooool3o`0000;ooooo00?o0000ooooooooool0F?oo
ool2oiJMf0GoUZCO0onE[NL00ol0003oUJgWooooo`0Eooooo`03o`000?oooooooooo053ooooo001P
ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0001cooooo0_l0001Kooooo`;oUYKB1_nF
WMP4oiJTg`?oUJgW00?o0000oj:ci?ooool05?ooool00ol0003oooooo`00001Aooooo`00H?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00006_ooool3o`0005Wooooo
0_nFTL`5oiJFdPGoUYgH1OnFY=l00onE[NOoX[?To`000002oj:ci1Kooooo00?o0000ooooooooool0
Coooool0063ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0001So
oooo0_l0001Hooooo`;oUHc71OnFTL`4oiJFdPKoUYgH0_nFY=l2oj6Zg@;oX[?T00Co0000oj:ci?nR
/nCoX[?T5_ooool00ol0003oooooooooo`1>ooooo`00H?ooool01Ol@413ooooooooooooooooo410@
00cooooo00?oMgMgolc<c?l000005Oooool3o`0000;ooooo00?o0000ooooooooool0DOooool2oiF7
``GoUHc71?nFTL`5oiJFdP?oUYgH0_nQX]H5oj6Zg@05oj:ci?l0003oX[?Toj:ci?n^^N805_ooool0
0ol0003oooooooooo`1>ooooo`00H?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000004oooool2o`0005Gooooo0_nDQ;l5oiF7``CoUHc71?nFTL`4oiJFdP03oinKd?nQX]Ko
XJ;F00CoXJ;F1OnQZ]d00ol0003o[[WRojjihP02ojjihQKooooo00?o0000ooooooooool0COooool0
063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00oooooo0ol0001C
ooooo`;oU86k1OnDQ;l4oiF7``CoUHc71OnFTL`00onFU];oWi_@oinKd002oinKd0GoXJ;F1?nQZ]d0
0on//M_o0000ojjihP04ojjihQKooooo00?o0000ooooooooool0C?ooool008;ooooo0_l0001Boooo
o`;oTgjh1OnDPK/4oiB4_`CoUHO31OnES<L2oiJAc0;oWYG:1_nOVm05oj6ReP05oj6ZgOn//M_o[;7K
ojbafol000001?n^^N800ong`>3oooooooooo`0Dooooo`03o`000?oooooooooo04cooooo001ooooo
o`?o00000_ooool00ol0003oooooooooo`1;ooooo`;oTg^f1?nCO[P5oiB1^`CoU8Bo1OnEQl<3oiF<
a`03oif@aOnNUL[oWYG:00?oWYG:1OnOVm04oj6ReP03oj^Ye_n//M_o[;7K00;o[;7K00?o0000ojba
fon^^N801?ng`>0Dooooo`?o0000COooool007cooooo0ol0001@ooooo`03oi=j]?nCNkKoTg^f00?o
Tg^f1?nCO[P4oiB1^`GoU8Bo1?nEQl<00onES<OoWI35oif@a@02oif@a@CoWYG:1_nOVm000onQX]Ko
ZjWFoj^YeP02oj^YeP?o[;7K00?o0000okJig?ng`>001?ng`>0Gooooo`03o`000?oooooooooo04[o
oooo001jooooo`;o0000Coooool2oi=h/PCoTgZd1?nCNkH4oi=n^0GoU86k1?nDQ;l2oiF7``;oW8_1
1OnMT<D5oijEbP?oWi_@0_nYXm06oj^YeP05ojbafonf^Mco][WLo`000?nf^M`00ong`>02okk6h1Ko
oooo00?o0000ooooooooool0B_ooool007Oooooo0ol0001=ooooo`;oTWN`1?nCN;84oi=j]0GoTg^f
0onCO[P5oiB1^`;oU8Bo0_nKQkd5oib;`@CoWI351?nNULX00onWWL_oZJ?@ojVSd004ojVSd0CoZjWF
00Oo];?HokJig?nf^Mco][WLo`000?nf^Mco]l3P00Go_/KP5_ooool00ol0003oooooooooo`19oooo
o`00MOooool2o`0000;ooooo00?o0000ooooooooool0Aoooool2oi9e[`CoTWN`1OnCN;84oi=j]0Co
Tg^f1?nCO[P3oiB1^`03oiZ4^_nKQkgoVhNm00?oVhNm1?nLRl45oif@a@03oijEb_nWWL_oYig;00;o
Yig;1OnYXm03oj^YeP;o];?H0onf^M`00ol0003o_/CNokk6h004okk6h003ol;;h_oooooooooo01Go
oooo00?o0000ooooooooool0B?ooool007;ooooo0ol00005ooooo`03o`000?oooooooooo04?ooooo
00?oTWB^oi9e[onBMJl00_nBMJl5oi9g/0CoTgRb1?nCN[@4oi=k]PCoTgjh00?oU86koiZ4^_nJQ;X0
0_nJQ;X4oi^7_@CoW8_11?nMT<D00onVV<OoYig;ojNMb`04ojNMb`GoZJ?@00?oZjWFokBcf?nd/mP0
0_nd/mP2okJig003o`000?nna=ko_/CN00?o_/KP0oo2bn8Fooooo`03o`000?oooooooooo04Sooooo
001`ooooo`;o0000C?ooool3oi9d[PGoTWF_1?nBMk04oi=h/PCoTgZd1OnCNkH2oi=n^003oiV1]onJ
Q;[oVXBj00?oVXBj1?nKQkd5oib;`@03oif@aOnVV<OoYYS700;oYYS71OnWWL/4ojVSd003ok>^e?nd
/mSo];?H00?o];?H00?o][WLokk4g_l000000onna=h00onna^3o`/_Rol;;hP03ol;;hQKooooo00?o
0000ooooooooool0Aoooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`00023ooooo0ol0001;ooooo`;oTW>]1OnBM:h4oi9e[`CoTWN`1?nCN;85oi=j]0;oTg^f0_nH
O[D4oiV1]`GoVXBj1?nKQkd3oib;`@03ojBC`onVV<OoYYS700CoYYS71OnWWL/00onYXm3o/jkDok>^
e002ok>^e0?o];?H00Co_L;Mokk4g_nna=ko00000_nna=h00oo3cN?o`/_Rol;;hP03ol;;hP03ol;@
iOoooooooooo01?ooooo0ol00018ooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@07_ooool2o`0000?ooooo00?o0000oooooooo
ool0AOooool00onBLZ_oTW>]oi9c[@02oi9c[@GoTWB^1?nBMJl4oi9g/0GoTgRb0onCN[@00onGNk?o
V7jeoiQn]@02oiQn]@CoVH6g1OnJQ;X4oi^7_@03oib;`OnTTl?oY9?300;oY9?31OnVV<L4ojNMb`03
ok6Yd?nc[]Co/jkD00?o/jkD00?o];?Hokg2gOnm`]d00_nm`]d00onna=ko0000okk4gP03ol?=h`?o
`/_R0oo2d>DFooooo`03o`000?oooooooooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo02Wooooo000hooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00onHV9So8B4Qonk^kP0Looooo`?o0000BOooool2oi9`Z@?oTW:[1OnBLjd4oi9d
[PCoTWF_1OnBMk04oi=h/P04oi=j]?nGNk?oUg^coiMk/`GoV7je1?nIPKL4oiZ4^P?oVhNm00?oXho0
ojBC`onTTl<01?nTTl<5ojJHa`03ojNMbonaZM3o/JW@00;o/JW@1?nc[]@6okg2g@03o`000?o3cN?o
`lgS00?o`lgS00?o`/_Rol;@iOo2d>D00oo2d>DFooooo`03o`000?oooooooooo00Gooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Zooooo`00>?ooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h06?ooool3o`0004Sooooo0_nA
KjP4oi9`Z@CoTW:[1?nBLjd4oi9d[PGoTWF_1?nBMk02oi=h/P;oUWVa1OnGNk<4oiQn]@CoVH6g1OnJ
Q;X01?nKQkgoXho0oj>?`?nSSl05ojBC``CoYYS700?o[jG=ok6Yd?naZM000onaZM03ok>^e0;o_KoL
1?nm`]d00oo3cnCo0000ol?=h`03ol?=h`;o`mSY1?o2d>D2okcAjQKooooo00?o0000ooooooooool0
1?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000[ooooo`00>?ooool01Ol0003ooooo
oooooooooooo000000kooooo00?oMgMgofIVI_ooool05Oooool3o`0004Kooooo0_nAKJH4oi5_Z0Go
TW2Y0onBLZ/4oi9c[@CoTWB^1OnBMJl2oi9g/0;oUGN_1?nFNK45oiMk/`CoV7je1OnIPKL2oiZ4^P;o
XHbm1OnSSl05ojBC``03ojJHaon_YLgo[jG=00;o[jG=1OnaZM000onc[]Co_KoLokfog002okfog007
okg2gOo3cnCo`loTol??i?l0003o`loTol?=h`05ol?Hj@03ol;@iOnldN[o_=7Z00?o_=7Z5Oooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMoooo
ool0000/ooooo`00>?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
4Oooool3o`0000?ooooo00?o0000ooooooooool0@?ooool00on@JjCoTFfVoi5]YP02oi5]YPGoTFnX
1?nBL:T3oi9bZ`CoTW>]1OnBM:h3oi9e[`03oiEf[OnEMjooUGN_00;oUGN_1OnFNK44oiMk/`GoV7je
0onIPKL00onPR;_oXHbmoj6<_@03oj6<_@CoXho01?nTTl<00on^XL[o[jG=ojnUc@03ojnUc@Co/JW@
00?o_;gKokfog?nm_m`00_nm_m`00oo3dNGo`loTol??i002ol??i003o`000?o3h>go`n3]00Co`mSY
0_nlg?04okcAjP03ok;@l?oooooooooo01Cooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000_ooooo00CogMgMoeEEEOoooooo0000;?ooool003Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41004Oooool2o`0004Sooooo0_n@Jj@5
oi5]YPCoTFnX1?nBL:T3oi9bZ`GoTW>]1?nBM:h01?nBMJooUGJ]oiEf[OnEMZd5oiEg[`CoUWVa1?nG
Nk<5oiQn]@03oiV1]onPR;_oX8Rk00;oX8Rk1?nQS;d5oj>?`003ojBC`on^XL[o[Z7:00;o[Z7:1On_
YLd00onaZM3o_;gKokbmf`02okbmf`;o_KoL0oo3dND3ol??i005o`000?o3h>go`n3]ol?PkOo3f>T0
1Onlg?000onldN[o/]3`ok;@l002ok;@l1Kooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oMgMgolc<c?l00000;?ooool003Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03_ooool3o`0004Oooooo0_n@JZ<3oi1[
Y0GoTFfV1?nAKjP4oi9`Z@?oTW:[1OnBLjd2oi9d[P;oU7B/1OnEMZd4oiEg[`CoUWVa1OnGNk<3oiQn
]@03oij5^?nPR;_oX8Rk00?oX8Rk1?nQS;d4oj>?`003ojbMb?n^XL[o[Z7:00?o[Z7:1?n_YLd00onk
_=[o_;gKokbmf`03okbmf`03okfog?o3dNGo`m7U00?o`m7U00?o`loTol?PkOl000000_o3h>d2ok[W
m0Co_=c`0_n`g?L5ok;@l1Cooooo0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0oo^k^koA4A4o`00000/ooooo`00FOooool3o`0004Gooooo0_n@JJ84oi1ZX`CoT6^T1?nAKJH4oi5_
Z0CoTW2Y1?nBLZ/3oi9c[@03oiAcZonDM:coU7B/00;oU7B/1OnEMZd4oiEg[`CoUWVa1OnGNk<01?nH
O[GoWXFhoij5^?nNQKP5oj28^`GoXHbm00?oXho0ojbMb?n/WLP00_n/WLP5ojjQbP03ojnUcOnk_=[o
^kcJ00;o^kcJ0onl_M/2ol?Di`Co`m7U0oo2j?000ol0003o^^Odok[Wm003ok[Wm003okcLl?n`g?Oo
/=cg00?o/=cg0_nbd?02ojC9la?ooooo00Co0000oooooooooooo00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0:oooool005Kooooo0ol00003ooooo`03o`000?oo
oooooooo03oooooo00?oT6ZRoi1YX_n@JJ800_n@JJ85oi1ZX`?oT6^T1?nAKJH4oi5_Z0GoTW2Y0onB
LZ/01?nBLjgoU7>[oiAcZonDLj/5oiAd[0CoUGJ]1?nEMjl5oiIi/@?oUg^c00?oWH>foij5^?nNQKP0
0onNQKP5oj28^`?oXHbm00?oZi[6ojbMb?n/WLP00on/WLP4ojjQbP03ok^kf_nk_=[o^kcJ00Co^kcJ
00?o_;gKol?Dioo3e>L00_o3e>L00oo3dNGo`^S`ol;Xl002ol;Xl003ok?`m_l0003o^^Od00?o^^Od
0_nYioX4ok3Lm`03oj3Dn_nTbO?oY<Wc00?oY<Wc5_ooool00ol0003oooooooooo`10ooooo`00E?oo
ool2o`0004Gooooo00CoTF^Soi1ZX_n@JZ;oT6ZR1?n@JJ85oi1ZX`?oT6^T1?nAKJH5oi5_Z0CoTW2Y
0_nBLZ/00onELj[oU7>[oiAcZ`03oiAcZ`CoU7B/1?nEMZd5oiEg[`CoUWVa00CoUg^coif3]_nMPkKo
WH>f1OnNQKP5oj28^`03oj6<_On[V/KoZi[600;oZi[61?n/WLP3ojjQbP?o^k_J1?nk_=X00oo3enWo
`mCWol?Di`02ol?Di`?o_nob00Oo`^S`ok?`m_ncl?Ko/o3fo`000?ncl?Ko^^Od00GoZNOj00?o/=cg
oj3Dn_nPe?X00_nPe?X4ojC9laKooooo00?o0000ooooooooool0@?ooool0057ooooo0ol00015oooo
o`?oTF^S0on@JZ85oi1YXPCoT6ZS0on@Jj@5oi5]YPCoTFnX0_nBL:T2oiEbZ@CoUG>Z1?nDLj/4oiAd
[0CoUGJ]1OnEMjl2oiIi/@;oW82d1OnMPkH4oij5^0CoX8Rk00?oZIO4oj^Ja_n[V/H00on[V/H5ojbM
b003ojjQb_nk^m[o^k_J00;o^k_J0onk_=X3ol?Gj@03ol?Dionoko;o_nob00;o_nob0onUm?02ok?`
mP04o`000?nJkOKoV^gfoi[]mP;oZNOj0onGgOh4oj3DnP;oY<Wc0onF_o@Fooooo`03o`000?oooooo
oooo03oooooo001>ooooo`Go0000@oooool2oi5/Y0CoTF^S1?n@JZ84oi1YXPCoT6ZS0on@Jj@5oi5]
YP?oTFnX00?oUW:XoiEbZOnELZT00_nELZT4oiEcZPCoU7>[1?nDM:`5oiEf[@?oUGN_00?oVgjboib0
]?nLP;@00_nLP;@5oif3]PGoWXFh0_nPR;/3ojVGa0CoZi[61?n/WLP00onj^]Wo^k_Jok^kfP04ok^k
fP04ok^lf_o3enWo`mOYol?Gj@?o^?Ga00?o_nobojGdl?nUm?000_nUm?03ogoWi@03o`000?nJkOKo
R>7l00;oR>7l0_nGgOh3ohg;o@CoT/Gi1OnF_o@Fooooo`03o`000?oooooooooo03kooooo001<oooo
o`;o00001Oooool00ol0003oooooooooo`0mooooo`03oi9]YOnAK:CoTFbT00;oTFbT1OnAJj<3oi1Z
XPCoT6VR1?n@JZ<4oi1[Y0CoTFfV00CoTFnXoiIbZ?nFLZSoUW:X1OnELZT3oiEcZPCoU7>[1OnDM:`4
oiEf[@04oiEg[onKO[;oVgjboi]n/PGoW82d1?nMPkH5oij5^003oj28^onYUlCoZIO400;oZIO41On[
V/H00on/WLSo^[[IokZjf@02okZjf@Co^k_J00Co`m_[ol?GjOo3enWo`mOY0onhmO43ohk^h004ojGd
l?moinGoOnOUogoWi@;oL=g_00?o0000ohSQo?n8hO`00on5col5ohg;o@CoT/Gi0_nF_o@2ohjflQKo
oooo00?o0000ooooooooool0?_ooool004Wooooo0ol00014ooooo`04oi=^Y_nBKJGoTVfUoi9]Y@Co
TFbT1OnAJj<3oi1ZXPCoT6VR1On@JZ<3oi1[Y0?oTFfV00?oUW:WoiIbZ?nFLZP00onFLZP4oiEbZ@Co
UG>Z0onDLj/5oiAd[0;oUGJ]0_nJO;45oi]n/PCoW82d1OnMPkH3oij5^003ojRE`_nYUlCoZIO400?o
ZIO41?n[V/H00oni^][o^[[IokZjf@04okZjf@03ok^kf_o3fn_o`m_[00;o`m_[00?o`mOYokSelOnh
mO401?n>k^001?mKdlKoD/oHoe;?f?mBcmP2og3Mk`;oNm3o00?o0000og_@oon5col00on5col2ohg;
o@;oR[Se1On<^?<4ohjflQCooooo0ol0000oooooo`008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
023ooooo0_l00015ooooo`?oTfjV0onBKJD5oi5/Y0CoTF^S0on@JZ84oi1YXPGoT6ZS0on@Jj@01?nA
KJKoUW:WoiIbYonFLZL5oiIbZ0CoUG:Y1?nELjX4oiAcZ`?oU7B/00?oVGZ_oiYl/OnJO;400_nJO;45
oi]n/PCoW82d1OnMPkH00onNQKSoZ9G2ojRE`P02ojRE`PGoZIO40_n[V/H3okVjfPCo^[[I0_o2g^h3
ol?Kj`;o[?O/0om]g<<00on>k^3o<KRhofG>nP02ofG>nPCoL=3m0_mkd?l00ol0003oQ[SfohRimP04
ohRimPCoR[Se1On<^?<4ohjflQGooooo00?o0000ooooooooool0?Oooool002;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Mooooo`?o00000_ooool00ol0003oooooooooo`10ooooo`03oi=_Y_nCKZKo
TfjV00;oTfjV1?nBKJD4oi5/Y0CoTF^S0on@JZ85oi1YXPCoT6ZS0_n@Jj@00onFLJOoUW:WoiIbY`03
oiIbY`CoUW:X1?nELZT4oiEcZPCoU7>[00CoU7B/oiUj[onINZooVGZ_1OnJO;44oi]n/PGoW82d0onM
PkH00onWT/3oZ9G2ojRE`P03ojRE`PGoZIO400?oZi[6okVjf_ni^]X00oni^]X00onj^]Wo`]k^ol;N
kP03ol;NkP03ol?Kjon/mncoKMc300;oKMc30omLc?H2ofG>nP;oQ[Cc1On5]_D01?n6^?Ko0000ohJh
m_n6^?H5ohRimPCoR[Se0_n<^?<2ohf/j`GoS:o^5Oooool00ol0003oooooooooo`0looooo`008_oo
ool01Ol@413ooooooooooooooooo410@01_ooooo0_l00014ooooo`;oTfjU0onCKjH5oi=^YP?oTVfU
1?nAK:@4oi5[X`CoT6ZR1?n@JJ83oi1ZX`04oiE`Y_nFLJOoUW6WoiIaY`GoUW:W1?nFLZP4oiEbZ@Go
UG>Z0_nDLj/00onINJkoVGZ_oiUj[`03oiUj[`CoVWba1?nKO[85oib0]003oif3]_nWT/3oYi;000;o
Yi;01?nXUL84ojVGa003okRif_ni^][o^K[J00?o^K[J0_o0ho04ol;NkP04oiWcgol0003oE/WcoeK9
l`;oRZk]1?n7/O44ohJdl`GoQKKe00Co0000ohJhm_n6^?KoQ[Sf0_n8^OH2ohjSh`CoSJOW1On=[>/5
ohb_kQGooooo00?o0000ooooooooool0>oooool002;ooooo00Go0000ooooooooooooooooo`00000H
ooooo`?o0000@oooool00onBKJCoTfjUoi=^Y@02oi=^Y@CoTfnV1?nCKZH3oi9]Y@CoTFbT1?nAJj<4
oi1ZXPCoT6VR00CoT6ZSoiE`Y_nEL:KoUG2V1?nFLJL4oiIbY`CoUW:X1OnELZT4oiEcZP03oiAcZonI
NJkoVGV^00GoVGZ_1?nJO;45oi]n/P?oW82d00?oYI2oojNB`?nWT/000onWT/05ojRE`P03ojVGa?nh
^M[o^;WJ00;o^;WJ0oni^]X4ol3Sl003ol;Nk_nIlmooSJWY00?oSJWY1?n:[^d4ohNal@CoQ[Cc0_n5
]_D2ohnIf@04o`000?n>W]koSYkNohjNgPGoSZ?S1?n=YnL5ohf/j`;oS:o^0_nB[nXEooooo`03o`00
0?oooooooooo03_ooooo000Rooooo`05o`000?ooooooooooooooool000005_ooool3o`0004?ooooo
0onBKJ@4oi=^Y@CoTfnV1?nCKZH3oi9]Y@CoTFbT1OnAJj<3oi1ZXP;oT6VR0_nDKjH5oiE`YP?oUW6W
1?nFLZL5oiIbZ0CoUG:Y0_nELjX6oiUi[PCoVGZ_1OnJO;44oi]n/P03oib0]?nUT;ooYI2o00;oYI2o
1?nWT/04ojRE`P03okRjfonh^M[o^;WJ00Co^;WJ00?o^K[Jol3Sl?o0ho000_o0ho000omoi/[oT:GS
oi2Uh`05ohfYj@?oRZk]0_n7/O42oi:?c@CoT9?C1?n?VMT00ol0003oSYkNohjNgP02ohjNgPGoSZ?S
1?n=YnL2ohf/j`;oTjST1OnB[nXEooooo`03o`000?oooooooooo03[ooooo000Rooooo`05oa0@4?oo
ooooooooooooool@41004oooool3o`0000;ooooo00?o0000ooooooooool0?oooool00onBK:?oTVfT
oi9]Y002oi9]Y0CoTfjU1?nCKjH4oi=^YP?oTVfU1OnAK:@4oi5[X`;oT6ZR00?oTVjVoiA_Y_nDKjH0
0_nDKjH5oiE`YP?oUW6W1?nFLZL5oiIbZ0?oUG:Y00?oVWV]oiUi[_nINJh01_nINJh4oiUj[`GoVWba
0_nKO[82ojB>_@GoYI2o1OnWT/000onXUL;o^;[KokRjf`02okRjf`Co^;WJ0onnio<00oo0ho3oOnK:
ogoVbP04oi2Uh`;oSJWY0_nDQL43oi>:a`GoTXo=1?n@Tm<3ohnIf@03o`000?n>W]koSYkN00?oSYkN
0_n>Xn<2oiFKe`CoU:;N1OnCZ>@4oi:_jQKooooo00?o0000ooooooooool0>Oooool002;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0@ooooo`?o0000A?ooool01?nBJj;oTVbSoi9/XonBK:<5oi9]Y0?o
TfjU1?nCKjH4oi=^YPCoTVfU1?nAK:@4oi5[X`03oi1ZX_nBKZKoTVjV00GoU6nV1?nEL:H3oiIaY`Go
UW:W1?nFLZP01?nELZWoVWV]oiYi[OnJNJd8oiUi[PGoVGZ_0onJO;400onSS;coY8jmojB>_@03ojB>
_@CoYI2o1?nWT/000ong^]_o^;[KokRjf`04okRjf`03okRif_nnio?o_^Oc00;o_^Oc0_mQdZh2oi:O
g@;oT:GS0_nEP[`5oiB5`@?oTh[71?nBSld5oi2Cd`;oSiWI00Co0000ohnIfOn>W]koSYkN0_nFU]45
oiFKe`CoU:;N1?nCZ>@2oi:_jP?oW;7V5?ooool2o`0003_ooooo000Rooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03_ooool2o`0004Gooooo0onBJj84oi9/X`CoTVfT1?nCKZD3oi=_YPGoTfjV0onBKJD4
oi5/Y0;oTF^S0_n@KJL3oi9^YPGoU6nV1?nEL:H3oiIaY`GoUW:W0onFLZP6oiYi[@OoVGV^1OnINZl0
0onJO;7oXhbloj><_002oj><_0CoY8jm1OnUT;l00onWT/3o]k[KokNjf`02okNjf`Co^;[K0onkk?@0
0onnio?oHM:^of7B[P02oi:Og@;oUWjh1OnEP[`4oiB5`@?oTh[71OnBSld2oi2Cd`;oUh_50_nGT</0
0ol0003oUi3;oiJFd@04oiJFd@CoUI_G1OnDX]h2oi>Xi003oibXgonL/NKoW;7V00CoW;7V5Oooool0
0ol0003oooooooooo`0hooooo`00<_ooool5o`0004?ooooo1OnBJj84oi9/X`CoTVfT1?nCKZD4oi=_
YPCoTfjV0onBKJD2oi5/Y0;oSfbW1?n@KJL4oi9^YPCoU6nV1?nEL:H4oiIaY`CoUW:W00?oUW:XoiYi
[OnJNJd01_nJNJd8oiUi[P?oVGZ_00?oXXZkoj><_?nSS;`00onSS;`4ojB>_@CoYI2o00?o]k_LokNj
fong^]/01?ng^]/00onh^]_o^ncdok_/m002ok_/m004o`000?nEV]OoUW^coiIk/`GoUWjh1?nEP[`4
oiB5`@CoTh[70_nBSld2oiR7_`GoUh_50_l00002oiN@b`CoUYKA1OnEVmL2oiBRgP;oW:7G1?nLZ=l4
oibaiP03ojNgi?oooooooooo01Cooooo00?o0000ooooooooool0=oooool0033ooooo0_l00014oooo
o`;oTfbS2?nBJj83oi9/X`CoTVfT1?nCKZD4oi=_YPCoTfjV0_nBKJD00on?KJSoSfbWohm/Y`02ohm/
Y`CoT6fW1?nBKZH4oiA_YPGoUG2V0onFLJL3oiIbY`03oi]j[OnJNJgoVWV]00OoVWV]2?nINJh01?nI
NZooXXZkoj::^onRR[/5oj><_0GoY8jm00?oYI2ookNkg?ng^m`00_ng^m`4okNjf`?o]_3e00?o^ncd
oiJEd?nGNK001OnFNk<4oiIn^0CoUH:l1OnDQL42oi>:a`03oiV3^_nHQkooV8No00?oV8No00KoUh_5
o`000?l0003o0000oiN@bol00002oiN@b`GoUYKA0_nEVmL2oifJd0GoW:7G1?nLZ=l00onL/NKoYkOT
ojNgi002ojNgi1Gooooo00?o0000ooooooooool0=oooool002gooooo0ol00013ooooo`03oiA^Y?nC
K:?oTfbS00;oTfbS2?nBJj83oi9/X`CoTVfT1?nCKZD4oi=_YP;oTfjV0_nAKjP3ohm]Z0GoSfbW0on@
KJL4oi9^YPCoU6nV1OnEL:H3oiIaY`04oiIbYonKNZgoVgZ]oi]j[@WoVWV]1onINJh00onQRK[oXXZk
oj::^`03oj::^`GoXhbl0onTS[d00onf_=go]k_LokNkg004okNkg003okNjfonfl?Go]_3e00;o]_3e
00CoUgN]oiMi/?nGNK3oUgV`1OnFNk<4oiIn^0GoUH:l0_nDQL42oiV0]PCoVH>j0_nHQkl3o`0000?o
Uh_50_nGT</00ol0003oUi3;oiN@b`02oiJFd@;oWIC:1?nMV]05oibQe`;oW:SO0_nW[md6ojNgi1Go
oooo00?o0000ooooooooool0=_ooool002cooooo0_l00014ooooo`;oU6jT1?nCK:<8oi9[XP?oTVbS
1OnBKJ@3oi=^Y@;oTfnV0_nDL:P4oi5_Z0CoSffX1?n?K:L3oi1]Y`CoTVjV1OnDKjH4oiE`YP;oUW6W
1_nKNZd8oiYi[@KoVGV^0onQRKX4oj::^`GoXhbl00?oY8jmokJlgOnf_=d00_nf_=d4okNkg0?o/??d
00Co]_3eoiMg[OnGMjgoUgN]1?nGNK04oiIk/`GoUWjh0onEP[`00onJOK;oVH2foiV0]P02oiV0]P?o
VH>j0ol00002oiR7_`GoUh_50_nGT</00ol0003oWXo4oifDbP04oifDbPCoWI[@0onLXML00onWZ=Oo
YjoMojN_g@03ojN_g@CoYkOT0_n`_^@Eooooo`03o`000?oooooooooo03Gooooo000/ooooo`?o0000
@?ooool2oiE`YP?oU6jT1?nCK:<8oi9[XPCoTVbS1?nBKJ@2oi=^Y@03oiIbYonDL:SoU72X00;oU72X
1?nAKjP4ohm]Z0CoSfbW1?n@KJL3oi9^YPGoU6nV0onEL:H00onJNJgoVgZ]oi]j[@06oi]j[@WoVWV]
0onINJh00onQR;[oXHVjoj69^P02oj69^PCoXXZk1?nSS;`00onf_=oo][cMokJlg@03okJlg@?o]k_L
0on`lo@00onFM:[oUgN]oiMg[@03oiMg[@?oUgV`1OnFNk<4oiIn^004oiF2_?nJOK;oVWfboiYm/PCo
VH2f0ol000000onIPk[oV8NooiR7_`03oiR7_`;oUh_50_nNRkh3oij?a003o`000?nNSlCoWIC:00?o
WIC:1?nMV]000onLXMOoYjSGojNXe`02ojNXe`GoYjoM00?oYkOTok2ni?n`_^@00on`_^@Dooooo`03
o`000?oooooooooo03Gooooo000/ooooo`04o`000?oooooo0000o`0003cooooo00?oUW:XoiE`Y_nE
L:H00_nEL:H4oiA^Y0?oTfbS2?nBJj84oi9/X`CoTVfT00?oTfjUoiIbYonFLZL01OnDL:P3oi5_Z0Co
SffX1?n?K:L4oi1]Y`CoTVjV1?nDKjH01?nEL:KoVWV]oiYi[OnJNJd8oi]j[@WoVWV]00?oVGV^oj68
^_nQR;X00_nQR;X4oj69^PCoXXZk0_nSS;`3okJlg`Go][cM00?o]k_Lok3cm?n`lo@01?nFM:X4oiMg
[@?oUgV`1OnFNk<2oiIn^0;oVW^_1OnJOK83o`000003oiV0]_nIPk[oVH>j00;oVH>j0onHQkl00onO
Qk[oWX^noij;_P03oij;_P;oWXo400?o0000oij?a?nMU<X01?nMU<X2oifJd003ojNRdOnWZ=OoYjSG
00CoYjSG0_nW[md3ok2ih0Co/;kT00?o]/GUooooooooool04Oooool00ol0003oooooo`000008oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<
c00Iooooo`00;?ooool2o`0000;ooooo00?o0000ooooooooool0>?ooool2oiIbZ0CoUG2V1?nDKZ@4
oi=/X`SoTV^R0onBK:<2oi9]Y0;oUg:W1?nFLZL4oiA`Z0CoTFnX0on?KJP4ohm/Y`CoT6fW1?nBKZH3
oiA_YP03oiQh[_nJNJgoVWV]00?oVWV]1onKNZd8oiYi[@KoXHRj1?nQRKX4oj::^`03oj><_?nf_=oo
][cO00;o][cO1?nf_=d2ojSdl@;oUG6W1?nFM:X4oiMg[@CoUgV`0onFNk<00onJNJcoVW^_oiYk[`02
oiYk[`;oVWfb0ol00004oiV0]PCoVH>j00?oV8Nooin7^_nOQkX00_nOQkX4oij;_P?oWXo400?o0000
oifDb_nMU<X00_nMU<X00onWWLcoYj;AojNRd@02ojNRd@CoYjSG00?o/KGLok2ih?n`^N001?n`^N00
0on`_^Co]/GUokK5i@02okK5iAGooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B406Oooool002_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0dooooo`;oUgBY1?nFLZP3oiE`YPCoU6jT1?nC
K:<8oi9[XP;oTVbS00?oUg:VoiMbYonGLZL00_nGLZL4oiIbY`CoU72X1?nAKjP3ohm]Z0GoSfbW0on@
KJL4oi9^YP04oiA_Y_nHN:koV7R^oiQh[PGoVWV]2?nKNZd5oiYi[@SoXHRj1?nQRKX3oj::^`03okFm
h?nf_=oo][cO00Co][cO00Co][cMojSdlOnXm?7oU6nU0onELJL4oiIdZPCoUgN]1?nGNK001?nFNk?o
VWV/oiYi[?nJNJ`4oiYk[`;o00000onJOK85oiV0]P;oVH>j00?oWhBfoin7^_nOQkX00onOQkX4oij;
_PCoWXo400?o0000oifDb_nWWL`00_nWWL`5ojNRd@03ojNXeona]Mco/KGL00;o/KGL1?n`^N000ong
aNCo]/GUokK5i@03okK5iAGooooo00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go0000ooooooooooooooooo`00000Iooooo`00:oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo033ooooo00?oV7J[oiMdZOnGM:T00_nGM:T4oiIbZ0?oUG2V1?nDKZ@4
oi=/X`SoTV^R00?oTVbSoiMbY_nGLZH01OnGLZL3oiIbY`CoU72X1?nAKjP4ohm]Z0CoSfbW0on@KJL2
oi9^YP;oU7J^1OnHN:h4oiYi[@SoVgZ]0_nJNJd2oj69^P[oXHRj1?nQRKX01?nRR[_o]KgPokFmh?ne
_N04okJlg`;oW_?/0onDKjD3oiEaY`CoUWBZ1OnGMjd2oiMi/003oi]gZ_nJNJcoVWV/00?oVWV/0ol0
00000onJNjooVWfboiYm/P03oiYm/PCoVH2f00CoVH>join4]_nOQ;KoWhBf1?nOQkX5oij;_P;oWXo4
00?oZ9W7o`000?nWWL`01?nWWL`3ojNRd@03ok:bf?na]Mco/KGL00Co/KGL00?o/;WPokO5i?ngaN@0
0_ngaN@3okK5i@;o^<_Y5Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00002oooool01Ol0003oV9RHoooooonHV9So8B4Q01Wooooo000[ooooo`?o00001Oooool00ol0003o
ooooooooo`0^ooooo`;oV7J[1OnGM:T3oiIbZ0CoUG2V0onDKZ@4oi=/X`OoTV^R00?oUW6VoiMbY_nG
LZH00_nGLZH4oiMbY`?oUW:W1?nDL:P4oi5_Z0CoSffX1?n?K:L2oi1]Y`03oi5c[OnDMZkoU7J^00;o
U7J^1OnHN:h4oiYi[@OoVgZ]00?oXXZkoj69^_nQRKX00onQRKX9oj68^P;oXHVj0ond_^84okFmh004
okJlgonNlncoW_?/oi=]Y0CoU6nU0onELJL5oiIdZPCoUgN]00GoUgV`oi]gZ_nKMj[oVgNZoiYi[003
o`0000CoVW^_1OnJOK82oiV0]P;oWh:c1?nOQ;H5oin7^P?oWX^n00?oZIK3ojRIaonXVLL00_nXVLL0
0ol0003oYig<ojNMc002ojNMc003ojNRdOnb/]So/[;H00;o/[;H1?na]M`00onhaNCo]lGTokO5i003
okO5i003okK5iOnhbnWo^<_Y00?o^<_Y5Oooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<01Wooooo000[ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0:oooool00onIMjcoV7J[oiQfZ`02oiQfZ`CoUgBY0onF
LZP4oiE`YPCoU6jT0onCK:<5oi9[XP?oUW6V1?nGLZH4oiMbY`?oUW:W1OnDL:P3oi5_Z0;oSffX0_n?
LJ`4ohma[@?oTG>]1OnDMZh4oiQh[PCoVWV]1OnKNZd3oj::^`GoXHVj2?nQR;X00onb_n?o];kRokBn
hP04okBnhP;o]KgP0_nBl>D3oi=]Y0CoU6nU0onELJL5oiIdZP;oUgN]0_nKMZP2oi]gZP?o00000onJ
NJ`5oiYk[`?oVWfb00?oX82`oin2/onOP[<00onOP[<3oin4]PGoWhNj00?oWX^nojVF`onYU/<00_nY
U/<4ojRIa`04o`000?nWWLcoYig<ok>`ePKo/[;H00?o/KGLokS5i?nhaN@00_nhaN@3okO5i0;o^M;/
1?nhbnT00onccNgoooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`03oeEEEOn7QhOooooo01_ooooo000[ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool09oooool01?nJNJgoVGN/oiUg[?nIMj`4oiQfZ`CoUgBY0onFLZP4oiE`YPCo
U6jT0onCK:<2oi9[XP;oU6nV1?nFLJH4oiMbYPCoUg:W1?nFLZL4oiA`Z0;oTFnX00?oTG:/ohma[?n?
LJ`00_n?LJ`4ohma[@CoTG>]1?nDMZh4oiQh[PGoVWV]0_nKNZd00onRRkcoXXZkoj::^`03oj::^`Co
XHVj1_nQR;X4ok:oh`Co];kR0_n5jmd2oi=/X`CoTffT1?nDKjD4oiEaY`?oUWBZ00CoVgFWoi]fZ?nK
MZSoVgJX0ol00002oi]gZPCoVWV/1OnJNjl01?nJOK;oX82`oj20/?nPP;05oin2/`CoWhBf0onOQkX0
0onYU<3oZIK3ojVF``03ojVF``GoZ9W700Co0000ok>`e_nc/=Ko/k3F1?nb/]P00onjanGo^<GTokS5
i004okS5i003okO5i?nid^co^M;/00;o^M;/00?o^<_Yok?=kOnccNd00_nccNdCooooo`?o00001?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P06oooool0013ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Tooooo`?oVWV]1?nIMj`3oiQfZ`CoUgBY
1?nFLZP3oiE`YPCoU6jT0_nCK:<00onBKZKoU6nVoiA_YP02oiA_YPCoUW6V1?nGLZH4oiMbY`CoUW:W
0onDL:P01?nEMJcoTG:/oi5b[?nALZ`5ohma[0CoSg6]0onALjd4oiAf[PCoV7R^1OnJNJd01?nKNZgo
XX^loj:;_?nRRk`4oj::^`GoXHVj0onQR;X00ona`>Go/[oSok:oh`04ok:oh`04okBnh_n5jmgoQN_M
oiE]X`?oTfbS1?nCKJ@5oiA_Y@?oUG6W00CoUWBZoi]eYonKMJOoVgFW0ol00002oi]fZ0CoVgNZ1?nJ
NJ`3oiYk[`03oj1n[_nPP;3oX82`00?oX82`1?nOP[<4oin4]P03oin7^_nYU<3oZIC000;oZIC01?nY
U/<4ojRIa`03okB`e?l0003o/k3F00?o/k3F00?o/[;Hok[7iOnjanD00_njanD4okS5i003ok[Il?ni
d^co^M;/00;o^M;/0_nce_85ok?=kAGooooo00Wo0000ooooooooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410Iooooo`004?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo0ol0000:ooooo`03o`000?oooooo
oooo027ooooo00?oVWZ^oiYi[OnJNJd00_nJNJd4oiUg[0?oV7J[1?nGM:T4oiIbZ0?oUG2V0_nDKZ@2
oi5^Y`?oTVjV1OnDKjH3oiIaYPCoUg:V1OnGLZL3oiIbY`04oiA`Z?nEMJcoUGF/oiEe[0CoTG:/1?n?
LJ`4ohma[@?oTG>]1?nDMZh5oiQh[P?oVWV]00?oXH^moj:;_?nRRk`00_nRRk`4oj::^`GoXHVj00?o
XHRjok70iOna`>D00_na`>D4ok:oh`;oM^?C0onEKJ<3oi=/X`CoTffT1OnDKjD2oiEaY`03oi]cYOnK
MJOo000000;o000000?oVgFWoi]fZ?nKMZP00_nKMZP4oi]gZPCoVWV/00CoVW^_oj1n[_nPOZkoX7j^
1OnPP;05oin2/`;oWhBf00?oZY>mojVD`?nYU<000onYU<05ojVF``03ojRIaond/=Co];3D00;o];3D
00Co0000ok>`e_nc/=Ko_<cV1_njanD00onhaNCo^]W`ok[Il002ok[Il003okWBk?nce_;o/mKb00?o
/mKb0_nccNd2oj_:l1Gooooo00?o0000ooooooooool0;oooool000Sooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Oooooo`;oVWZ^1?nJNJd4oiUg[0?oV7J[1OnGM:T3oiIbZ0;oUG2V00?oT6jWoi5^YonA
KZL00_nAKZL4oi9^YPCoU6nV1?nFLJH4oiMbYPCoUg:W0_nFLZL00onIMjcoUGF/oiEe[003oiEe[0?o
TG:/1?n?LJ`4ohma[@?oTG>]1OnDMZh4oiQh[P03oiYi[OnQRkgoXH^m00;oXH^m0onRRk`5oj::^`?o
XHVj00?o[l;Wok70iOna`>D01?na`>D01?nb_n?oM^?CogKSdonHL:<4oiE]X`?oTfbS1OnCKJ@4oiA_
Y@04oiEaYonKLjGo0000o`0000CoVgFW1?nKMZP4oi]gZP?oVWV/00?oX7f]oj1n[_nPOZh00onPOZh4
oj20/0GoWh:c00CoWhBfojZC_OnZTkgoZY>m1?nYU<04ojVF``03okNadond/=Co];3D00?o];3D00?o
/k3Fo`000?nlc>H00_nlc>H4ok[7i@;o^N?d0_njfO04ok3Om`;o/mKb0_nYdoH5oj_:l1Gooooo00?o
0000ooooooooool0;_ooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oM
gMgoooooo`0000Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Kooooo`;oVgb`
1?nJNZh4oiYi[@?oVGN/1?nHMZ/4oiMdZ@;oUW:X00CoTFnXoi1^Yon@KZOoT6jW1OnAKZL3oi9^YPCo
U6nV1?nFLJH4oiMbYP?oUg:W00CoVgV/oiUg[?nIMjcoVGN/1OnEMJ`3oi5b[0CoSg6/1?n?LJd4oi5c
[@CoU7J^0_nHN:h2oij9_@GoXH^m1?nRRk`4oj::^`03oj69^_n_`^Oo[l;W00;o[l;W1?na`>D00omW
f/WoVg>ToiQ`X`02oiQ`X`CoUFfS0onCK:<5oi=]Y0?oU6nU0ol00002oi]cY@CoVgFW1?nKMZP5oi]g
ZP03oiYi[?nPOJgoX7f]00GoX7j^1?nPP;04oin2/`03oj^B_?nZTkgoZY>m00;oZY>m1OnYU<000onY
U/?o]k7CokNad`02okNad`?o];3D00?o_];Yokc<i_l000001?nlc>H01?njanGo^N?dokWSm?niho@2
ojSYnPCo/=og00?oXmckojWCm_nYdoH00onYdoH2oj_:l0?oX/?`5Oooool00ol0003oooooooooo`0]
ooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Oooooo00?oW7jaoi]l/?nKO;000_nK
O;04oiYj[PCoVWV]0onIMj`4oiQfZ`;oUgBY0_nBL:T3oi5_Z0CoT6jW1?nAKZL3oi9^YPCoU6nV1?nF
LJH4oiMbYP04oiMbYonKNJcoVgV/oi]i[0CoVGN/1?nEMJ`3oi5b[0CoSg6/1On?LJd3oi5c[@;oU7J^
0_nJQK/5oij9_@CoXH^m1?nRRk`2oj::^`?o[/?Y1On_`^L00ona`>GoVg>Toi]cY002oi]cY0?oV72S
1?nEKJ<4oi=/X`CoTffT0ol000000onILJCoVg>Uoi]cY@02oi]cY@CoVgFW1?nKMZP4oi]gZP03oj5m
[?nPOJgoX7f]00;oX7f]1?nPOZh5oj20/0;oWh:c0on[T[`3ojZC_@CoZIC000?o^KCDokNadong/M<0
1?ng/M<01_nd/=Co_];YokkBjOnnd^Wo_<cVo`0000;o_<cV0ondkOH00onihoCoZ>WjojSYnP02ojSY
nP03ok3OmonSg?_oXmck00;oXmck0_nYdoH3oio8m@GoX/?`5?ooool00ol0003oooooooooo`0]oooo
o`004?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool2o`00
00oooooo0_l0000Fooooo`;oW7ja1?nKO;04oiYj[PCoVWV]1?nIMj`2oiQfZ`03oi=bZ_nBL:WoTW2Y
00;oTW2Y1?nAKjP3oi1^Y`CoTFjW0onBKZH4oiA_YPCoUW6V0onGLZH00onLNZcoVgV/oi]i[002oi]i
[0CoVGN/1?nEMJ`3oi5b[0GoSg6/1?n?LJd2oi5c[@03oiJ0^OnJQK_oVXFk00?oVXFk1?nNRKd5oj6;
_@;oXX^l0_n^`^P5ojk3j@;o[l;W00?oF]6noiedY?nMM:@01?nKLj@3oiQ`X`GoUFfS0onCK:<01?nC
KJCo0000o`000?l00004oiUaY0CoVg>U1?nKMJL5oi]fZ0;oVgNZ0_nQOJ`4oj1m[@CoX7j^1OnPP;00
0onOP[?oZi:loj^B_002oj^B_0CoZY>m0_nYU<03okVde0Co]k7C00?o_m_]okkBjOnnd^T00onnd^T0
0onlc>Ko0000okC]mP02okC]mP;oU>ce0_nXjOX4oiKRo@;oXmck0_nJc?T5oio8m@;oX/?`0_nL^nhE
ooooo`03o`000?oooooooooo02cooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0oo^k^koA4A4o`000006ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool2
oif0/`CoW7ja1?nKO;03oiYj[PCoVWV]1?nIMj`00onHMZ_oTg:Zoi=bZP04oi9`Z@CoTFnX0on@KZL4
oi5^Y`?oTVjV1OnDKjH3oiIaYP04oiMbY_nLNZcoW7Z/oiaj[0CoVgV/1?nIMj`4oiEe[0CoTG:/1?n?
LJ`2ohma[@;oTWbg0onFP;T5oiZ5^`CoWXVm1OnQRkd00onRRkco[/;Xojk2j002ojk2j0?o[/?Y0_m?
bK<4oiedY0CoVg>T0onHL:<5oiE]X`04oi=/Xol0003o0000o`0000?oUfnS1OnILJ@3oi]cY@GoVgFW
1?nKMZP00onKMj[oXGf/oj5m[002oj5m[0?oX7f]1OnPOZh3oj20/003ojbB^on[T[coZi:l00?oZi:l
1?nZTkd00onYU<3o^KCDokVde002okVde0?o]k7C0onofnd3okkBj@?oY??a00?o0000oiC/mOnDk?D0
1?mohOP2oiKRo@;oTlgl1OnJc?T2oio8m@;oV[[_1OnL^nhCooooo`;o0000;_ooool0013ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0<ooooo`03oij2]?nMP;?oWH2c00;oWH2c1?nLO[44oi]l/0CoVWZ^
0onJNJd2oiUg[0;oU7>[1?nCLZX3oi9`Z@CoTFnX0on@KZL4oi5^Y`CoTVjV1?nDKjH2oiIaYP03oiYi
[OnLNZcoW7Z/00?oW7Z/1?nKNJ`3oiUg[0GoUGF/0onALZ`2ohma[0;oTWZd1?nBO;L4oiJ0^@CoVXFk
1OnNRKd3oj6;_@;o[[gU1On^`^P01?n^`nWoWGFUoieeYOnMMJD4oiedY0CoVg>T1?nHL:<2oiE]X`?o
000000?oTfbSoiI]X_nGKj<00onGKj<5oiUaY0?oVg>U1OnKMJL3oi]fZ003oj9m[?nQOJcoXGf/00?o
XGf/0onPOJd5oj1n[P03oj20/?n/T[_o[9:k00;o[9:k1On[T[`2ojZC_@03okbjeoni]=Co^KCD00Co
^KCD00?o]k7CokoKkOnofnd00_nofnd01?nnd^WoY??aojCclOnTlo42ofkOg@03o`000?mOeNSoGmGX
00;oOn7h0_n;cOh5oi?=o0;oV/ci0onH^>h4oiZjk`CoW;_^5Oooool00ol0003oooooooooo`0[oooo
o`00:Oooool2o`0001Cooooo00?o0000ooooooooool02_ooool2oij2]0GoWH2c0onLO[44oi]l/0Co
VWZ^0_nJNJd00onFMJcoU7>[oiAcZ`02oiAcZ`CoTg:Z0onBL:T4oi5_Z0?oT6jW1OnAKZL3oi9^YPCo
U6nV00?oUW6VoiYi[OnJNJd01OnLNZ`4oi]i[0CoVGN/1?nEMJ`2oi5b[003oiAj/onBN[CoTWZd00;o
TWZd1OnBO;L3oiJ0^@GoVXFk1?nNRKd00onQRkgo[[gUojjmi@03ojjmi@;o[/;X00?oC/N]oiacY?nM
MJD00onMMJD4oiedY0GoVg>T0_nHL:<3o`000003oiE]XonDKJ;oUVfR00;oUVfR1OnGKj<4oiUaY0Co
Vg>U1?nKMJL01?nKMZSoXWf/oj9m[?nROJ`5oj5m[0CoX7f]0onPOZh00on]Tkco[9:kojbB^`03ojbB
^`GoZi:l00CoZY>mokbjeonl^]Oo_;[G1?ni]=@3okkWl`;o_m_]00CoOnOFocNj[?lg^Zco>ko@0omo
`od00on4bOko0000ohC9oP02ohC9oP?oRlgn0_nCcO`3oiNdk0GoV;S^1?nJ^^l2oibkkP;oW;S/5Ooo
ool00ol0003oooooooooo`0Zooooo`00:Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00Oooooo00?oX8Fgoij2]?nNP[@00_nNP[@4oif0/`?oW7ja1?nKO;02oiYj[P;oUgN]0onFMJ`4
oiAcZ`CoTg:Z1?nBL:T3oi5_Z0CoT6jW1?nAKZL3oi9^YP;oU6nV0_nHN:h4oiYi[@CoW7Z/1?nKNJ`4
oiUg[0;oUGF/0_nHO;<3oiAj/`GoTWZd1?nBO;L3oiJ0^@GoVXFk0_nNRKd3oj^dg`Co[[gU00?oEL^]
oiacY?nLLj@00onLLj@3oieeY@CoWGBT1OnKLj@2o`000003oiQ`XonEKJ?oU6fR00;oU6fR0onFKJ85
oiM_X`CoVG6T1?nKLjD3oi]eY`03oj9n[?nROJcoXWf/00?oXWf/1?nQOJ`4oj1m[@03oj1n[_n]Tkco
[I>l00;o[I>l1?n/T[/4oj^B_003oko3g?nl^]Oo_;[G00?o_;[G00?o^KCDokkWlonnio<00_nnio<2
ohF_l@GoP;_i1?mo`od01?n4bOko0000oiFVhOnEY^44oiF^j0GoUkC/0_nH^>h2oi^_i@CoVk?Y1OnL
^>`Dooooo`03o`000?oooooooooo02[ooooo000Yooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool01Oooool2oj25]`CoWX:d1?nMP;<4oian/@;oVgb`00?oV7V_oiMg[OnGMjd00_nGMjd4
oiIe[0?oU7>[1?nCLZX4oi9`Z@CoTFnX0on@KZL4oi5^Y`;oTVjV00?oU7J^oiQh[_nHN:h00_nHN:h4
oiYi[@CoW7Z/1?nKNJ`3oiUg[003oib0/onHO;?oV7bc00;oV7bc1?nDN[<4oi9j]0CoTWbg1?nFP;T3
oiZ5^`03ojNWe_n[]=ooZkCO00CoZkCO00Co[[gUoiEaYonILJCoVG6T1OnLLj@3oieeY@GoWGBT00Co
Vg>To`000?l0003o00000_nHL:<00onFKZ?oU6fRoiA]XP02oiA]XPCoUVfR1?nGKj<4oiUaY0CoVg>U
00CoVgFWoj9n[?nROZcoXWj/1OnROJ`4oj5m[0CoX7f]1On]Tk`5ojbB^`03oj^B_?no`mco_l?L00;o
_l?L0onl^]L3ok?cl`03okkWlon<X^?oQJoa00?oQJoa0_n0^oT2oiJCcPCoUIcH0_nEY^400ol0003o
UJKQoiFVh@04oiF^j0;oUkC/0_nLZN05oi^_i@CoVk?Y0_nL^>`3oj2gjACooooo00?o0000oooooooo
ool0:Oooool002Wooooo00?o0000ooooooooool05_ooool01?l0003oooooooooooooool2oj:8^@Co
X8Fg0onNP[@5oif0/`?oW7ja00?oVgb`oiQi[onHNJl01OnGMjd3oiIe[0CoU7>[0onCLZX4oi9`Z@Co
TFnX0on@KZL2oi5^Y`;oTGB^0onDMZh5oiQh[P?oVWV]1?nLNZ`4oi]i[004oiUg[?nLP;?oW82coib0
/`GoV7bc0onDN[<4oi9j]0GoTWbg0onFP;T00onJQK_oYjOFojNWeP02ojNWePCoZkCO00?oJ=RgoiM_
XonILJ@00_nILJ@5oiacY0?oWGFU0onMM:@3o`0000;oVg>T00CoV76ToiI^XonFKZ?oUVjS1OnDKJ83
oiI]XPCoUfnS1OnILJ@3oi]cY@GoXWj/1?nROJ`5oj5m[0;oX7f]0_n^UKd4ojfC_0Co[9:k00?o`m3T
oko3g?no`m`00ono`m`00onl^]Oo/o?cok?cl`02ok?cl`?oS:;S0_n5[o42oiN;a0GoUY?>1?nEW=P0
1?nEY^7o0000oiFVhOnEY^42oiF^j0;oW:?J1OnLZN04oi^_i@;oVk?Y0_nP/N@6oj2gjACooooo00?o
0000ooooooooool0:?ooool002Wooooo0ol0000Gooooo`03oj><_?nRR;WoXXRi00?oXXRi0onPQKL4
oij2]0CoWH2c0_nLO[400onHNk3oV7V_oiQi[`02oiQi[`CoUgN]0onFMJ`4oiAcZ`CoTg:Z0onBL:T4
oi5_Z0;oT6jW00?oT7>^oi5d[_nAM:h00_nAM:h4oiAf[PCoV7R^0onJNJd5oiaj[0;oVgV/00?oWh>e
oib0/onLP;<00onLP;<4oiQl/`?oU7Zc1OnBN[@4oi9l]`;oUX2i0_nQVL`5ojNWeP03oj^dgomXf;Oo
UfnS00;oUfnS1?nILJ@4oiacY0?oWGFU0ol00002oiedY004oi]cY?nHLJCoV76ToiQaY0?oUVjS1OnD
KJ83oiI]XPCoUfnS1OnILJ@2oi]cY@03oj=o[OnROZcoXWj/00?oXWj/1?nROJ`5oj5m[004oj1m[On^
UKgo[YFmojjE_@Go[I>l0_n/T[/3ol?@i0?o_l?L0onBl=l00onclo?oTIGDoi6Ee002ohbRh`03oiV4
^onGRlCoUh_400?oUh_41?nFTlh5oiFLf003oiFVhOl0003oWIcB00GoW:?J1OnLZN02oi^_i@03oj6[
g_nP/NCoX;7T00?oX;7T1?nP]nT00onV^^Soooooooooo`0Aooooo`;o0000:_ooool002Wooooo00?o
0000ooooooooool05_ooool3oj><_0CoXXRi0onPQKL4oij2]0;oWH2c0_nIOK83oiQk/0CoV7V_1?nG
Mjd3oiIe[0CoU7>[1?nCLZX3oi9`Z@;oTFnX0_n@LZh3oi1c[PGoTGB^0onDMZh4oiQh[PCoVWV]1?nL
NZ`00onKNJcoWh>eoin3]@05oib0/`CoV7bc1?nDN[<4oi9j]0;oTWbg0_nLSL85oj6Ic0?oYjOF0_n4
j<X4oiM_X`CoVG6T1?nLLj@3o`000005oieeYOnMM:CoWGBToiedY?nKM:D01?nHLJ@4oiI^X`CoU6fR
0onFKJ85oiM_X`CoVG6T00CoVg>Uoj=o[OnSOjgoXgn]1?nROZ`5oj9m[0?oXGf/00?o[iRoojjE_On^
UKd00_n^UKd5ojfC_003ojbB^oo3d>Co`m3T00?o`m3T00Co_l?Loi;`gonBl=ooUX_60_nAUM@2oiao
/`CoVHBk1?nGRl@5oiJCcP;oUIcH0_nOU//2oifLdP03o`000?nMW=;oW:?J00CoW:?J0_nLZN02oj:U
f0CoXJ_N1OnP/N@00onP]nWoY[[XojJjj002ojJjj1Cooooo00?o0000ooooooooool09oooool000ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000oooo
ooooool05Oooool00onUTKooXhbloj><_002oj><_0CoXXRi1?nPQKL2oij2]003oiYo]?nIOK;oVGfb
00;oVGfb1?nHNk03oiQi[`CoUgN]0onFMJ`4oiAcZ`CoTg:Z0_nBL:T00onALjkoT7:^oi1b[P02oi1b
[PCoT7>^1?nAM:h3oiAf[PCoV7R^1?nJNJd2oiaj[0;oXHNh1?nOPkD4oib0/`CoV7bc1?nDN[<2oi9j
]0;oVXFl1OnLSL85oj6Ic004ojNWe_n4j<[oQ>S:oiE]X`GoUfnS0onILJ@01OnLLjCo0000o`000?l0
003oW7>T00?oWGFU00CoWGBToi]dYOnKM:GoVgBU1?nHLJ@4oiI^X`CoU6fR0onFKJ85oiM_X`?oVG6T
1OnSOjd4oj9n[0GoXWf/00?oXGf/ojnH_on_V;l00_n_V;l4ojjE_@?o[I>l0_o4h^h4ol?@i003o`00
0?nFRlKoUX_600;oWWf^1OnLOk<3oiV4^`GoUh_40_nFTlh2oj6Aa0CoWiK;0_nMW=800ol0003oWIcB
oifLdP02oibSfP;oXj3B1OnRYMP4oj6[gP;oX;7T0_nW]^<5ojJjj1Gooooo00?o0000ooooooooool0
9_ooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Gooooo00?o0000ooooooooool05?ooool3ojFA_`?oXhbl1OnRR;T3oj25]`03
oij2]?nJOkCoVWnd00CoVGfb1?nHNk03oiQi[`CoUgN]1?nFMJ`3oiAcZ`;oTg:Z0_nBM:h3oi5c[PGo
T7:^0on@Ljh4oi5d[P?oU7J^1OnHN:h2oiYi[@03oin8^onQQkSoXHNh00;oXHNh1?nOPkD4oib0/`Go
V7bc0_nDN[<00onIP[WoVXFloiZ5_003oiZ5_0CoW8g21?nQVL`2oi_dgP?oUFfS1OnGKj<01?nILJCo
0000o`000?l00004oiacY0;oWGFU00?oWWRWoi]dYOnKM:D00_nKM:D4oiQaY0CoUVjS1?nDKJ84oiI]
XPCoUfnS00?oVG6Toj=o[OnSOjd01OnSOjd5oj9n[0?oXWf/00?o/9c3ojnH_on_V;l00on_V;l4ojjE
_@03ojfC_?o4h^koa>;^00?oa>;^00Co`m3ToiV3^_nIPk[oVH>j1?nNOJh5oiao/`?oVHBk1?nGRl@0
0onSSKgoXI74oj6Aa003oj6Aa0CoWiK;0_nMW=800ol0003oYIc=oj>PdP04oj>PdPCoXZGH0_nQZmh3
ojRbg`CoYkKS0_nV^^P3oj^oj1Cooooo00?o0000ooooooooool09_ooool000Kooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP06ooooo`;o00004_ooool2
ojNF``CoYI6o1?nSS;`4oj:8^@;oX8Fg00?oVh:goiYo]?nJOk@00_nJOk@3oiUm/PCoV7^`0onHNJl5
oiMg[@?oUWF/0_nDLj/00onCMZooTWB^oi9d[P02oi9d[PCoTG>^1?n@LZh3oi1c[PCoTGB^1?nDMZh4
oiQh[P03oiYi[OnOR;_oWhRk00GoXHNh0onOPkD5oib0/`CoV7bc00?oU7ZcoiV2^OnIP[T01OnJQK`4
oib=`P?oXIW<00?oVoCNoi=/XonCK:<01?nEKJ<3oiM_X`;o00000_nILJ@5oiacY003oieeYOnNN:Oo
WWRW00GoVgBU0onHLJ@4oiI^X`CoU6fR1?nFKJ83oiM_X`03oj5n[OnSOjgoXgn]00KoXgn]1OnROZ`0
0onROJco/9c3ok2L``02ok2L``Co[iRo0on^UKd3ok[dlP;oa>;^0onJOK42oiV3^P;oXG^Z1?nNOJh4
oiao/`CoVHBk00?oUh_4oj>=_OnSSKd00_nSSKd4oj6Aa0CoWiK;00GoWIcBojFLcOnUW<go0000ojFL
c@05oj>PdP;oXZGH00?oZZoKojRbgonX/]l01?nX/]l2ojNfh`;o[KgV1On[_nPDooooo`03o`000?oo
oooooooo02Gooooo000>ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP05ooooo`03o`000?oooooooooo00kooooo00?oZY_7ojNF`onWU/<00onWU/<3ojFA_`CoXhbl0_nR
R;T2oib5^P?oVh:g1?nJOk@4oiUm/P?oV7^`1?nHNJl4oiMg[@;oUWF/00CoU7N`oi=f[onCMZooTgJ_
1OnBM:h3oi5c[PCoT7:^0on@Ljh5oi5d[P?oU7J^0_nHN:h2oif8_@CoWhRk1?nQQkP4oin3]@CoW82c
0_nHO;<2oiZ2^0CoVH:i1?nJQK`5oib=`P03oj6Ic?nCK:?oTfbS00;oTfbS1?nEKJ<3o`000003oiM_
XonILJCoVG6T00;oVG6T0onLLj@00onPNZSoWWRWoiihY`02oiihY`CoVgBU1?nHLJ@3oiI^X`GoU6fR
0onFKJ801?nGKj?oXGj]oj5n[OnQOZd8oj=o[@CoXWj/00?o/jC9ok2L`on`W<<00on`W<<5ojnH_`05
ojjE_Onjm?;o^_Cbok[dl_nLNJ/01OnJOK401?nIPk[oXG^Zoj5kZ_nQNjX4oiim[PGoW7nc0_nIQ;/0
0onVRkWoXhfmoj>=_@03oj>=_@GoXI740_nOU//00onXV/OoYIc=ojFLc@02ojFLc@03o`000?nSX=;o
Xj3B00;oXj3B00?o[:gGojZ_fonZ[m/00_nZ[m/4ojRbg`03ojjmi?n]_NKo[KgV00?o[KgV0_n[_nP2
ojk3jAGooooo00?o0000ooooooooool09?ooool000kooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool03Oooool3ojZKa`CoYiK31?nUTKl2
oj><_003oif8_OnLQK[oW8Fj00;oW8Fj1?nKP[L3oiYo]0CoVGfb1?nHNk03oiQi[`;oUgN]0_nDNK43
oiAg/0CoTgJ_1?nBM:h3oi5c[PCoT7:^1?n@Ljh4oi5d[P;oU7J^00?oVHNnoif8_OnMR;d00onMR;d3
oin8^`CoXHNh1?nOPkD2oib0/`;oWHNk1OnJP[P3oiV2^@GoVXFl0onLSL800on/mngoTVbSoi9/X`03
oi=/X`04oiE]Xol0003o0000o`0000CoUfnS1?nILJ@2oiacY0;oX7ZX1?nNN:L4oi]dY@CoV76T1?nF
KZ<4oiA]XP;oUVfR00?oWG^/oj5n[OnQOZd00onQOZd8oj=o[@;oXWj/0oncY<T4ok2L``Co[iRo0_nC
lM/00onjm?;oW7V[oiaiZ`02oiaiZ`?oVWfa00?oXW^Woj5kZ_nQNjX00_nQNjX4oiim[PGoW7nc00Co
VHBkojJ;^OnVRkWoYX^i1?nSSKd4oj6Aa003oj^Ia?nXV/OoZ9[700;oZ9[70onUW<d00ol0003oYIc=
oj>PdP03ojb]e`GoZZoK00?oZ;;Oojjmi?n^_N@00_n^_N@3ojfmiP03ojo5j_n^`nWo[/?Y00?o[/?Y
4oooool2o`0000Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co
8B4Qo`000?lQ8B7oc<c<00Wooooo000>ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0
003oooooooooo`03ooooo`;o00003?ooool00on]XLcoZY_7ojZKa`02ojZKa`CoYiK31?nUTKl01?nS
S;coWHRmoif8_OnMR;d3oib5^PCoVh:g0onJOk@4oiUm/PCoV7^`0_nHNJl00onEN[?oU7VaoiAi/@02
oiAi/@CoU7N`0onCMZl4oi9d[P?oTG>^1On@LZh3oi1c[P;oTGB^0_nFQKh4oiV7_PCoWHRm0onOR;/5
oj67^0;oWh>e00?oWhk2oif7^onMQk/00onMQk/4oiZ2^0?oVH:i1OnJQK`00onLSL;o[?O]ojcgk@03
oi9/X`04oi=/Xol0003o0000o`0000?oUFfS1OnGKj<3oiUaY003oiacY?nPNZSoX7ZX00;oX7ZX0onN
N:L4oi]dY@CoV76T1?nFKZ<4oiA]XP03oiI]X_nMNjcoWG^/00GoXGj]2?nSOjd00onROZco/jC9ok>T
b@02ok>Tb@Go/9c300Co[iRooi?afonClM_oTo7K0_nMMjL4oiaiZ`04oiYm/OnRNjOoXW^Woj9kY`Go
XG^Z1?nNOJh3oiao/`03ojV;]OnVRkWoYX^i00;oYX^i1OnSSKd01?nQTLCoZiW4oj^Ia?n[VL@4ojRJ
a`CoYIc=00?o0000ojb]eon/[ML00on/[ML3ojZ_f`;o/;kT1?n^_N@00on]_NKo[lGZojo5jP02ojo5
jP?o[/?Y0_n^a^`Dooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Wooooo000>ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo0_l0000<ooooo`?o[J7<
0onZVlL5ojNF``;oYI6o00?oWhg1oif8_OnMR;d00_nMR;d4oib5^P?oVh:g1?nJOk@3oiUm/P;oV7^`
0_nFO;D3oiEj/`CoU7Va1?nDMk03oi=f[`CoTWB^1?nALjh4oi1b[P;oT7>^00?oUH>moiJ5__nFQKh0
0onFQKh3oiV7_PCoWHRm1?nOR;/4oj67^004oin3]OnOS/;oWhk2oin>`PCoWHNk1?nJP[P4oiV2^@?o
VXFl0_n^lOH00on@JjCoTVbSoi9/X`03o`0000?oTfbS0onEKJ<5oiM_X`;oVG6T00?oWgZYoj1jZ?nP
NZP00onPNZP3oiihY`CoVgBU1?nHLJ@4oiI^X`;oU6fR0_nIMj`4oiek[0CoXGj]1onSOjd00ong[m7o
/jC9ok>Tb@03ok>Tb@Co/9c300?o0000oj1fY?nPMZ@01?nMMjL4oiaiZ`GoXW^W1?nQNjX4oiim[P03
oiao/onYRkGoZH^e00;oZH^e0onVRkT4oj>=_@03ojnJ`_n[VLCoZiW400?oZiW41?nXV/L01OnUW<go
[jcEojn/eOn_[=Go000000Co[:gG00?oZZoKok2ni?n`_^@00on`_^@2ojjmi0;o/<O[1On_aNX00on^
`nWo[/K/ojk6k002ojk6k1Cooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go0000ooooooooooooooooo`000009ooooo`003_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`03o`000?oooooooooo00Wooooo
00?o[jSAojfQc?n]XL`00_n]XL`4ojZKa`;oYiK30_nPTLD4oin=`@?oWHRm1?nLQKX4oi^2]`?oVWnd
0_nIOK800onFO[OoUWbeoiIl]@02oiIl]@CoUGZc1?nDNK43oiAg/0?oTgJ_1OnBM:h3oi5c[P;oT7:^
0_nDP[`4oiF3_@CoUXFn0onIQkh5oif8_@?oWhRk0_nQQkP2oj:Ib`CoWhk21?nMQk/5oiZ2^0?oVH:i
00GoVXFlojkam_n^lOKo[_7foi1[Y003o`0000;oTVbS1?nCK:<4oiE]X`CoUfnS00?oVG6ToimjZOnO
NZT01OnPNZP3oiihY`GoVgBU0onHLJ@3oiI^X`03oiQf[?nIMjcoVGN/00;oVGN/1?nMNj`4oj5n[@Ko
Xgn]0ong[m45ok>Tb@03ok2L`onSN:?oXgRS00?oX7JT1OnMMjL2oiaiZ`03ojAkY_nRNjOoXW^W00?o
XW^W1?nQNjX3oiim[P03ojb</onYRkGoZH^e00?oZH^e1?nVRkT00onSSKgo[i[2ojnJ`P02ojnJ`PCo
ZiW40onXV/L00onc[]Co[jcEojn/e@03ojn/e@03o`000?n/[MOo[:gG00;o/l7T1?n`_^@00onac>ko
/<O[ok37j`03ok37j`;o[lGZ0_n^b^h4ojk6k003oj[4kOoooooooooo01;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P09
ooooo`009oooool00ol0003oooooooooo`07ooooo`Co[jSA0on]XL`3ojZKa`03oj:GbOnPTLGoX975
00?oX9750onOSL44oif8_@?oW8Fj1?nKP[L2oiYo]004oiJ0^OnFO[OoUWjgoiIn]`GoUWbe0onEN[<4
oiAi/@?oU7N`1?nCMZl4oi9d[P;oTG>^00?oU86loiB2_?nDP[`00onDP[`3oiF3_@CoUXFn1?nIQkh4
oif8_@;oWhRk00?oXZGGoj:IbonRVL/00onRVL/3oin>`PGoWHNk1?nJP[P2oiV2^@?oY^_j0ol00002
oi1[Y0?oTVbS1?nCK:<4oiE]X`?oUfnS00?oWWZ[oimjZOnONZT00_nONZT4oj1jZ0CoWWRW1?nKM:D3
oiQaY004oiI^XonHMZcoV7J/oiQf[0GoVGN/0onMNj`5oj5n[@?oXgn]00?o_;cJokN_dOng[m400_ng
[m44ok>Tb@CoXgRS0onPMZ@5oiegY`04oiaiZonTNjKoY7^VojAkYPCoXW^W1OnQNjX01?nNOJko[8bc
ojb</on/S;<4ojV;]@CoYX^i1On_V/84oj^Ia003ojRJaonc[]Co/jkD00;o/jkD1?n_[=D00ol0003o
/l7Tok?1i003ok?1i003ok2ni?nac>ko/Lc^00;o/Lc^0on`an/00on^co;o[/[^ojk:kP03ojk:kP03
ojk6k?nZa>goZ/C]00;oZ/C]5?ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Wooooo000Wooooo`;o00001_ooool2ok:`
ePCo[jSA1?n]XL`01?nZVlOoXYO9oj:GbOnRUlT4oj2Aa@?oWhg11?nMR;d3oib5^P;oVh:g0_nGPk`4
oiJ0^@?oUWjg1?nFO;D3oiEj/`CoU7Va1?nDMk03oi=f[`;oTWB^0_nDPK/4oiB1_0CoU8:l0onEPkd5
oiJ5_P?oVHNn0_nMR;d2oj6`h`CoXZGG1?nRVL/4oin>`PCoWHNk0_nJP[P4oiCUo004ojK[n_l0003o
0000ohiZY@CoT6^T1?nBK:<3oi=/X`CoUFfS00CoUfnSoiijZonNNZ_oWWZ[1?nONZT4oj1jZ0CoWWRW
1?nKM:D2oiQaY003oiQh[OnHMZcoV7J/00?oV7J/1?nIMj`3oiek[0GoXGj]00?oXgn]okblf_nl_=X0
0_nl_=X4okN_d@03ok>TbOnWNZ?oXgRS00CoXgRS1?nPMZ@3oiegY`03ojElYOnTNjKoY7^V00;oY7^V
1?nRNjL4oj5kZP03ok6@]?n/S;?o[8bc00;o[8bc1OnYRkD2ojJ;^@;o/ik31?n_V/83oj^Ia003okNc
e_nc[]Co/jkD00Co/jkD00Go[jcEokO8iongb>Oo]lSWo`000003ok?1i003ok;ClOnac>ko/Lc^00?o
/Lc^00?o/<O[ojk?l_n^co800_n^co82ojk:kP?oZ/S`1?nZa>dEooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41002Oooool0
02Oooooo00?o0000ooooooooool00_ooool00one^Mco/[3Fok:`eP03ok:`ePCo[jSA0_n]XL`00onT
WLkoXYO9oj:Gb@02oj:Gb@CoX9751?nOSL42oif8_@04oiN9`_nGQ[ooUhJooiN6_`GoUh>l0onFP;T3
oiIn]`CoUWbe1?nEN[<3oiAi/@CoU7N`0_nCMZl00onDPKcoU86koiB1^`03oiB1^`?oU86l1?nDP[`4
oiF3_@CoUXFn0_nIQkh00onO^>_oXK3Soj6`h`03oj6`h`?oXZGG1?nRVL/4oin>`P;oWHNk1?mcg?H2
oiCUo0?o00000on>JZD4oi1[Y0CoTVbS0onCK:<2oiE]X`;oVgR[1?nNNZ/4oimjZ@GoX7ZX0onNN:L2
oi]dY@;oVgfa0onHN:d5oiQf[0CoVGN/1?nMNj`3oj5n[@03ol3;h_nl_=[o_;cJ00Co_;cJ0_ng[m40
0onFKJ7oYgZSojMjX`05oj=hX`CoX7JT0_nMMjL2ojElY@CoY7^V1OnRNjL2oj5kZP;o/I2d1?n/S;<5
ojV;]@04ojJ;^OncW/?o/ik3ok>N``Go[i[200CoZiW4okNce_ng/mKo]k?F1?nc[]@00onje>go]lSW
okO8i`03okO8i`03o`000?nbdo7o/]?a00;o/]?a0_nac>h4oj_FmP;o[/ob0_nXcO<5oj[8l0;oZ/C]
0_nV`^dBooooo`?o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
oooo^[Zjo`000009ooooo`009oooool01?l0003oooooooooooooool3okFig0Go/[3F0_n_Z=400onV
YMCoY9g>ojBMcP02ojBMcP?oXYO91OnPTLD2oin=`@03oiR=a_nGRL;oUhW200;oUhW20onGQ[l4oiN3
_0?oUX2i0onFO[L5oiIl]@?oUGZc0_nDNK400onDPkkoU8:moiB2_@02oiB2_@CoU86l1?nDPK/3oiB1
_0GoU8:l0onEPkd2oiJ5_P;oWKc^1?nO^>/4oj6`h`CoXZGG1?nRVL/2oin>`PCo@lGK0_mcg?H3o`00
00CoS6VU0on>JZD3oi1[Y0CoTVbS0_nCK:<00onGMJ_oVgR[oi]hZ`02oi]hZ`CoWWZ[1?nONZT5oj1j
Z0;oWWRW00?oXHJfoi]m/OnKOK400_nKOK44oiQh[@CoV7J/1?nIMj`4oiek[003oj5n[Oo0bn;o`<_R
00;o`<_R1?nl_=X3oiAXW0CoYgZS1?nSN:<4oj1fY003oiegYonUO:GoYGbU00;oYGbU0onTNjH5oj9k
Y`04oj5kZ_naT;Co/I2dok6@]0Go[8bc0onYRkD00onjYlKo/ik3ok>N``02ok>N``Co[i[200?o_KkK
okNce_ng/mH00ong/mH00onc[]Co^]C]ok[Dk@02ok[Dk@;o]lSW0_n_g?L01?l0003o[mcgok;ClOnb
do42ojKMn`CoZmKf00?oY=3gojS=lonXcO<00onXcO<2oj[8l0;oYLC_1OnV`^dDooooo`09o`000?oo
ooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@09
ooooo`009_ooool3o`000003okS3h_ne^Mco]KWL00;o]KWL1?nb/=H00onY[M[oYZGDojJUe002ojJU
e0?oY9g>1?nRUlT2oj2Aa@;oVI7:1?nHSLH3oiN9`P?oUhJo1?nGPk`4oiJ0^@?oUWjg1?nFO;D2oiEj
/`03oiB4`?nDPkkoU8>n00;oU8>n1?nDP[d3oiB1_0CoU86k1?nDPK`4oiB2_0;oUH>m00?oWKg_oifl
k_nM_>h00onM_>h4oinhj`CoXK3S0_nRYML2oi9[X`CoSfVS0on<Ij<01?n:IjCo0000o`000?l00003
ohYWY@CoS6VU0on>JZD3oi1[Y0;oTVbS0_nCLZ/3oiMeZ`GoVgR[1?nNNZ/3oimjZ@GoX7ZX00?oWWRW
oj66]_nQQ[H01OnKOK43oiQh[@CoV7J/1OnIMj`2oiek[003okgDjoo0bn;o`<_R00Co`<_R00?o_;cJ
oi5SVOnDJ9`00_nDJ9`00onYOJ?oYgZSojMjX`02ojMjX`GoXgRS0onPMZ@5ojElY@?oY7^V1OnRNjL5
ok6@]0Co[8bc00CoZH^eokZWa_njYlKo^ZO61OncW/<00on_V/;o_KkKokfnf`02okfnf`?o]k?F0_ng
iOH3ok[Dk@;oY>Ok1?n_g?L00ol0003oY]gkojKMn`03ojKMn`03oj_Fm_nTd?OoY=3g00;oY=3g0_nX
cO<2oj?6l@GoYLC_0_nV`^d2ojBok1Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000
okS3h_nh`n800_nh`n84okFig003ok:`e_nY[M[oZJgJ00;oZJgJ0onVYM@4ojBMcP;oXYO900?oVYK?
oiVAb_nITLX00onITLX3oiR=aP?oUhW20onGQ[l5oiN3_0?oUX2i0onFO[L2oiIl]@;oThK21?nDQ<03
oiB3_PCoU8:m0onDPK`5oiB1^`?oU86l0_nDP[`2oifkkPCoWKg_1OnM_>h2oinhj`;oUW2U1?nDKJ@4
oi9[X`?oSfVS00CoS6NSo`000?l0003o00000on:Ij@3ohYWY@CoS6VU0on>JZD2oi1[Y003ohm_ZonC
LZ_oTg:[00;oTg:[1?nGMJ/4oi]hZ`CoWWZ[1?nONZT3oj1jZ003ojN@__nQQ[KoXHJf00;oXHJf1?nK
OK43oiQh[@CoV7J/1OnIMj`01?nMNjco_MC[okgDjonme>/4ol3;hP?oTF>I0_nDJ9`2ojUmX`CoYgZS
1OnSN:<2oj1fY003ojQnYonUO:GoYGbU00?oYGbU1?nTNjH3oj9kY`03okNG^?naT;Co/I2d00?o/I2d
0on/S;<00oo3^M7o^ZO6okZWaP03okZWaP?o/ik30_o2dNH4okfnf`03okNce_ngiOKo]nGf00?o]nGf
00?o^]C]ojCWnonTio/00_nTio/01On_g?OoVN;moiWRoOnIh_go000000;oY]gk0onMdoX2ojC@m`?o
XLKc1?nSa_42ojG4k`?oXko]1?nT_n`Dooooo`03o`000?oooooooooo01kooooo000Kooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooookS3hP03okS3hP;o]KWL0_n[]n44ojV]fPCo
YZGD0_nTWLh00onKW=CoVYK?oiZFc`02oiZFc`CoVI7:0onHSLH4oiN9`P?oUhJo1?nGPk`2oiJ0^@04
oi>9a_nCQlCoThO4oi>7a0GoThK20onDQ<03oiB3_PCoU8:m1?nDPK`4oiB1^`;oU86l00?oVkW]oifk
k_nM^nh00onM^nh4oifmk`;oWKc^0onFLZL3oiI`Y@CoU6fT1?nBJj<01?n?JJ?o0000o`000?l00002
ohaWX`;oRVNT0_n=J:@3oh]XYPCoRVZX0on<K:T3ohm_Z`GoTg:[0onGMJ/4oi]hZ`CoWWZ[1?nONZT0
1?nPNZSoYi2nojN@__nWT;h4oj66]PCoVgfa0onHN:d5oiQf[0?oVGN/0_nde_84okgDj`03ol3;h_nA
HiWoTF>I00?oTF>I00?oU6RLojUmXonYOJ<00_nYOJ<3ojMjX`GoXgRS00CoX7JTojQnYonXOZOoZ7jW
1?nUO:D4ojAkYP;oXW^W0ongUkP4ok6@]0;o[8bc0oo3^M44okZWaP03ok>N`oo2dNKo`]7V00?o`]7V
0_nm_]/3oigbl0;o]nGf0on4i_<2ojCWn`;oP>3i0_n;coh3oiGCo@04o`000?nEdogoWM?joigCnP;o
WLCc1OnQa_<2oj?6l@;oX[k]1OnS_nd2ojBok0;oY;g[5?ooool00ol0003oooooooooo`0Mooooo`00
6oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool00_nh`n83ojg1j@?o
ZkOQ1?nY[MX2ojJUe003oibSf_nKW=CoVicD00;oVicD1?nJU/l3oiVAbPCoV8g60onGRL83oiN6_`;o
Uh>l0_nBRlP4oi>9aP?oThO41?nCQ/83oiB4`0CoU8>n1?nDP[d3oiB1_0;oU86k0_nJ]n`4oi^ik@Go
WK_^0_nM_Nl3oiMdZP?oUW:W1?nFL:D3oiA]Y0;oTV^S0ol000000on?JJ?oTFZRohmYX`02ohmYX`Co
SFRT0on;J:H4ohYZZ0?oS6bY1?n?Kj/4oi=bZ`?oUgF[1?nKN:/4oiijZ`?oWgZY00?o[9c7ojN@__nW
T;h00onWT;h3oj66]PCoVgfa1?nHN:d4oiQf[003oiUg[?nde_;o]=Kb00?o]=Kb0_nme>/3ohmPUPCo
TF>I1OnYOJ<3ojMjX`GoXgRS1?nXOZL4ojElY@CoY7^V00?oXW^WokNG^?ngUkP00_ngUkP4ok6@]003
ojb</oo3^M7o`kWA00;o`kWA0onjYlH2okk^l`Co`]7V0_l00002oigbl0;o@lG90oln_n82oeoCk@?o
Q/Sm1?n;coh2oiGCo@03o`000?nJ_o;oWLCc00CoWLCc0_nQa_<2oj6lk0GoX[k]0_nS_nd2oj>kjPGo
Y;g[4oooool2o`0001kooooo000Kooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0000;o
oooo1On]`NT3oj^gh@;oZJgJ00?oWJ_QoibSf_nLXmX00_nLXmX3oi^Le0CoVYK?1?nITLX3oiR=aP;o
UhW200CoTI3>oi:=bonBSL_oTXg;1OnBRlP3oi>9aP?oThO41?nCQ/84oiB4`0?oU8>n1?nDP[d2oiB1
_0;oUkC/1?nJ]n`4oi^ik@;oWK_^0onHMjd4oiMdZPCoUW:W0onFL:D2oiA]Y0?o00000_nBJj83oi5Z
XP?oSfVS1On=J:@3oh]XYP?oRVZX1?n<K:T3ohm_Z`CoTg:[0onGMJ/5oi]hZ`?oWWZ[00?oWgZYojbL
aon/W<L00_n/W<L4ojN@_P?oXHJf1OnKOK43oiQh[@;oV7J/0onVeOP4okCFlP;oSejD1?n?H9H3oi5S
V@03ojaoY?nYOJ?oZGfS00?oZGfS1?nWNZ<3oj=hX`03ojj8[?nXOZOoZ7jW00;oZ7jW1OnUO:D3ojAk
YPGo]iNh1?naT;@6ol>id@03okZWa_nnk_?o_^kc00;o_^kc00?o`]7Voe>bnomC/_/00_nFW]T4ohj]
j`GoQK_h0_n6b?d00onI[>CoV;K]oiRfk@03oiRfk@;oV[ob00Co0000oiZol_nMa??oWLCc0onO^>T4
oj6lk0;oX[k]0onS^>P4oj>kjP;oY;g[0_nU_N/Booooo`03o`000?oooooo000001kooooo000Koooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`;o[L7Y0_nM_Nl3
oifci`CoWJ_Q0onLXmX4oi^Le0CoVYK?0_nITLX01?nAU]GoTI?Aoi6CdOnATm44oi6@cP?oTXg;1?nB
RlP3oi>9aP?oThO41OnCQ/83oiB4`0;oU8>n0_nB[n/4oiBaj`CoUkC/1?nJ]n`2oi^ik@?oVW^`0onH
Mjd4oiMdZPCoUW:W0onFL:D2o`000003oi5[XonBJj;oTV^R00;oTV^R0onAJZ84ohmYX`CoSFRT0on;
J:H3ohYZZ0CoS6bY0on?Kj/4oi=bZ`?oUgF[1OnKN:/2oiijZ`03ojjWd?n/W<Oo[9c700?o[9c71?nW
T;h4oj66]PCoVgfa0_nHN:d2oi;Ao@GoY]Gh00?o]=KbohmNU?n?GY@00_n?GY@4ohmPUP;oTF>I0_n/
Oj@5ojUmX`CoYgZS0_nSN:<3ojj8[0?oZ7jW1OnUO:D2ojAkYP;o_jFo1OngUkP2ok6@]0;oc]kT1?o3
^M42ogCRb`;o_^kc00?oN:3[oinDbOnOU<T01OnFW]T4ohj]j`;oQK_h0_nKXMP4oiV/i0GoV;K]0_nJ
_o800ol0003oX;?Uoinhj@04oinhj@;oXKc/00?oXkGUoj>hj?nS^>P01?nS^>P2oj>kjP03ojFkjOnU
_N_oYKg[00?oYKg[5?ooool00ol0003oooooooooo`0Kooooo`006oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool00oooool4oifmk`?oWK?W1?nMZn43oibSfP;oVicD00?o
T9oNoi2JfOn@V]T00_n@V]T4oi6Fe@?oTI?A0onAT<h4oi:=b`?oTX_81?nCRLH3oi>7a0CoThK20_nD
Q<000on@[N[oTZo[oi:_j`03oi:_j`CoU;7[0_nG]>`3occ0aP04oin4]_nLOk?oW7ncoiao/`?oVW^`
1?nHMjd3oiMdZPCoUW:W0ol00003oi5[X`CoTV^R1?nAJZ83ohmYX`CoSFRT0on;J:H4ohYZZ0?oS6bY
0on?Kj/4oi=bZ`CoUgF[0onKN:/00on/[=Oo[ZO@ojjWd002ojjWd0Co[9c71OnWT;h3oj66]P;oVgfa
0on0d_l4oi;Ao@;oY]Gh2?n?GY@3ohmPUP03oi5SVOn/OjCo[7nT00;o[7nT1?nYOJ<4ojMjX`03oj=h
Xon^R:co[XR/00;o[XR/0onXOZL5ojElY@04ojAkY_noYKoo_jFooknU_`Go]iNh00?o/I2dolkNi?o>
g^@00_o>g^@01_o3^M7oM>;;ogCRbomdh/_oRXW<ojN?_0GoWiC91?nFW]T2ohj]j`;oWiS=1OnKXMP4
oiV/i0;oV;K]0_nQ[Ml2oj2ci@03o`000?nP/nGoX;?U00;oWkSY0_nS/N84oj>ei@CoXkSX00?oYKWW
ojFkjOnU^nT00_nU^nT3ojFmj`03ojNnj_oooooooooo01?ooooo00?o0000ooooooooool06_ooool0
01_ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo00Gooooo1?nM_Nl3
oifci`;oWJ_Q00?oSj[XohnThon?Y><00_n?Y><3oi2OgPCoT9[I0onAU]D3oi6Cd@?oTI3>1OnBSL/3
oi:;b0;oThW600?oS:SXohfZjOn=Z^T00_n=Z^T4ohn/j@?oT:gZ1OnB[n/2oiBaj`;o?l??00?oXhZj
oin4]_nOQ;H00_nOQ;H4oiao/`?oVW^`0onHMjd3oiMdZP04oiIbYol0003o0000o`0000?oT6^T0onA
Jj<4oi9[XPCoTFZR0on?JJ<4oheXY0?oRfRV1?n:JZP3oha/Z@?oSfn[1OnCLZ/3oiMeZ`03oi]hZon/
[=Oo[:cG00;o[:cG0on^Ym05ojbLa`CoYi2n0_nQQ[H3ofKBn0CoP=;o0_nBdOd3oi1NT`SoSejD0on?
H9H5ojaoY0GoZGfS0onWNZ<5ojj8[0CoZ7jW0onUO:D00oo:_m3o_jFooknU_`02oknU_`Co]iNh0onC
k/42olkNi0CoUh2i00CoRXW<ojN?_?nWSkcoYhnl1OnOU<T2oiJNf@03ojFC`onOV<goWiS=00?oWiS=
1?nKXMP2oiV/i0;oY:OH1OnQ[Ml2oj2ci@03o`000?nU[]goXk7R00CoXk7R1?nS]ND00onS^>SoYKWW
ojFii`02ojFii`CoYK_Y00CoYKg[ojNnj_nW_^[oYkkZ5?ooool00ol0003oooooooooo`0Jooooo`00
6oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00007ooooo`;oWKg_0_n<^?<3ohfakP?o
Sj[X1?n?Y><3oi2OgPCoT9[I0onAU]D3oi6Cd@?oTI3>0_nBSL/2ohVWj0?oRjOX1?n<Z>P4ohfZj@Co
SjcY0on@[NX2oi:_j`?oA/KJ00CoYi2noj>:^_nSR[[oXhZj1?nOQ;H4oiao/`?oVW^`0_nHMjd00on?
KZWoSVbWo`000002o`0000?oSfbV0on@Jj@4oi5[X`?oTV^R1?nAJZ83ohmYX`CoSFRT0on;J:H4ohYZ
Z0?oS6bY1?n?Kj/4oi=bZ`;oUgF[00?oYJWIojb/eon/[=L00on/[=L4ojjWd0;o[9c70ol00006oi1O
U0CoTEnD0on@Gi<4oi1NT`SoSejD0on?H9H5ojaoY0GoZGfS0_nWNZ<00onnX;[o[XR/ojj8[003ojj8
[0CoZ7jW0_nUO:D3olZod0Co_jFo00Co]iNhoi?^`OnCk/7oTnk11?nPOZh3oiN0^@03ojj?]_nWSkco
Yhnl00;oYhnl1?nOU<T00on[TkgoYI?3ojFC``02ojFC``GoWiS=0_nKXMP00onXXm7oY:OHojBWf003
ojBWf0?oXJgO00KoYj[IojF^gOnU[]goYJkMo`000?nU[]d4oj>ahP;oXkGU0_nW]n@5ojFii`;oYK_Y
0_nW_>P5ojNnjQCooooo00?o0000ooooooooool06Oooool001_ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`03o`000?oooooooooo00Oooooo1?n<^?<3ohfakP?oSj[X1?n?Y><3oi2OgP;oT9[I
00CoPZO/ohBWjon4Yn_oQ:O[0on6Y^X5ohNVj@?oRJOX0on;YnP4ohbXj0CoSJ[Y0_n?[>T2oeK=kP03
okk4g_nm`=coZiO200;oZiO20onWT;h4oj>:^P?oWhBf0_nLOk<2oi=d[@?oTG6[00CoSfjYo`000?l0
003o00000_n>K:L4ohm/YPCoT6^T0onAJj<3oi9[XPCoTFZR0on?JJ<5oheXY0?oRfRV0on:JZP4oha/
Z@?oSfn[0_nCLZ/2oifOePCoYJWI1On/[=L2ojjWd0;oSEfD0on?GY@7oi1OU0CoTEnD0on@Gi<4oi1N
T`SoSejD0_n?H9H00on[P:Go[7nTojaoY003ojaoY0GoZGfS00CoYgZSokjP^_nnX;[o_Z2j1?n^R:`4
ojQnY`03ojElYOo:_m3ob[o@00;ob[o@0onoYKl00oncRj_oZ86ZojR1ZP02ojR1ZPCoX7j^00?oUh2i
ojj?]_n^SkH00_n^SkH4ojN?_003oinDbOn[TkgoZi>m00;oZi>m0onUTl<4oinHc@03ojfQc?nXXm7o
Z:?A00;oZ:?A1OnTYmP01?nQ[MooYj[IojNZfOnWZ]T3ojF^g@03o`000?nS/N;oXk7R00?oZ;CR1?nW
]n@2ojFii`?oZ;_W1?nW_>P2ojNnjP;oZKoZ5?ooool00ol0003oooooooooo`0Iooooo`009Oooool0
0ol0003oooooooooo`08ooooo`;oS;Sc0_mk/OH3ogf_l`?oOZgb1?moZo03oh6YkP?oPZO/0on4Yn/3
ohJVjPGoQjKY0on9YnP3oh^Wj0;oS:SX1?mTcO/2oek>mP;o_/CN0_n^WLH4oj^G`PCoYi2n0onSR[X2
oin4]P03oiEh[onCM:goTgB]00;oTgB]00CoTG6[o`000?l0003o00000on?KZT3ohi/Y`?oSfbV1?n@
Jj@3oi5[X`CoTV^R0onAJZ84ohmYX`CoSFRT0on;J:H3ohYZZ0CoS6bY0_n?Kj/00onFTLcoWIoFoifO
eP03oifOePCoYJWI0_n/[=L2ohaLT`CoSEfD0on?GY@8oi1OU0?oTEnD0on@Gi<4oi1NT`SoSejD00Co
Sf2Foj^0YOn[P:GoZh2U1?n/Oj@5ojUmX`Co_Z2j1On^R:`3ojQnY`Kob[o@00?o_jFook>;ZoncRj/0
1?nXPJX4oj1n[PGo[Xnf1?nWSk`5oj^C_@CoYI?300CoWiS=ojfQc?n]XLco[J7<1OnXXm42ojBWf0;o
ZjWE1OnWZ]T2ojF^g@03o`000?nZ/mooZ;CR00CoZ;CR0_nW]n@2ojVji@GoZ;_W0_nW_>P2ojVoj@Co
ZKoZ4_ooool00ol0003oooooo`00000Jooooo`009Oooool00ol0003oooooooooo`0:ooooo`?oNk7f
0omm[o<3ogj]lPCoOj_`0on1ZNh3oh:Wk0?oQ:O[0on6Y^X2ohNVj@?oK/?n1?m/aoh4ofW;o@;oI<gk
0_o0an000onbY<[o[Yg6ojjMaP02ojjMaPCoZiO21?nWT;h2oj>:^P04oiQl/_nEN:ooUGR_oiEh[`;o
TgB]0ol00002oi5aZ`CoSfjY0on>K:L3ohm/YPCoT6^T0onAJj<4oi9[XP?oTFZR1?n?JJ<4oheXY0?o
RfRV0_n:JZP00onBOKSoThG2oi>5`P02oi>5`PCoUY7<1OnMWmH2ojFYf@;oS5^C0on<G9<4oheMU0?o
SejD2?n@Gi@3oi5OU0?oT5nC1On@GY<7ohmNU0CoZh2U1On/Oj@3ojUmX`03on3[fOnnX;[o_Z2j00;o
_Z2j1On^R:`2ojQnY`;oc_3Z1?o:_m001?nUQ;3o/h^[ok>;ZoncRj/5ojR1ZP;oX7j^0_nfU;@4ojj?
]P?oYhnl0_neV[`4oj^C_@?oYI?300?o/j?8ojfQc?n]XL`00on]XL`3ojRSd@03ok2[don[ZMGoZjWE
00?oZjWE0onWZ]T01_n^]=goZ[?OojZcgonZ/moo0000ojZcg`;oZ;CR0_n[^^@5ojVji@;oZ;_W0_nZ
_nT5ojVoj@;oZKoZ0_nY`N/Dooooo`03o`000?oooooooooo01Oooooo000Uooooo`;o00003?ooool3
og^amP?oOJoc0omn[O82ogn[l0;oLK?i0om`]OX4ofnho0CoKkcm0om__oh3ofk3oP;oK<On0onnjO<4
ol39h@04ol37h?nbY<[o/ZC:ok:TbPCo[Yg61?n[Ul82ojN@_P04oi^1]_nHO;;oV7bboiQl/P?oUGR_
0_l00002oi=d[@?oTG6[1?n?KZT3ohi/Y`CoSfbV0on@Jj@3oi5[X`CoTV^R1?nAJZ83ohmYX`;oSFRT
0_nFMZh3oi=h/PCoTWfh1?nCQL83oiJAc0CoWIoF0_n<G9<3ohaKT`?oS5bC1?n=GI@3ohmNU0SoT5nD
0onAGi@3oi1OT`GoT5jC1_n?GY@00onYP:SoZh2Uoj^0Y@02oj^0Y@Go[7nT0_nYOJ<3on3[f@?o_Z2j
1On^R:`00onXOZOoc_3Zolk`jP02olk`jP03olZod?nZPj[oZX>Z00Go/h^[1?nXPJX01?nPOZko]YBd
okJD]?nfU;@5ojj?]P04ojN?_?neV[co]IZlokFJ_0GoZi>m00CoYI?3ok>Sb?ncXlSo/j?81?n]XL`0
0onXXm7o/:_Cok2[d`02ok2[d`CoZjWE00?oYj[IojjdgOn^]=d00_n^]=d3ojZcg`03o`000?n[^^Co
Zk[T00?oZk[T0onY^^D00on[_nWoZ[oYojZoj@03ojZoj@;oZKoY0_nZ`^/5ojW1ja?ooooo00?o0000
ooooooooool05oooool002Cooooo00?o0000ooooooooool03Oooool3ogF^mP?oLk3g1?mb/OP3og6c
n@?oL;Gj1?m_^?`2ofnlo@;o?[oT0old^lD2oic`m0?o_NCb00?o_^Wcol39hOo0bN400_o0bN400one
Z/ko/ZC:ok:TbP02ok:TbPCo[Yg60_n[Ul82oij6^P?oVh6f0onHO;83o`000003oiEh[onCM:goTgB]
00;oTgB]0onALJ/3ohm^Z@?oSVbW1?n?K:H3oi1[Y0?oTF^S1?nBJj84oi5ZXP;oSfVS00?oUgJ/oiIf
[_nFMZh00_nFMZh4oi=h/P?oTWfh1?nCQL84oiJAc003oifOe_n<G9?oS5bC00;oS5bC0on<Fi<3ohaL
T`CoSEfD1?n?GY@7oi1OU0?oTEnD1?n@Gi<4oi1NT`GoSejD0onYP:P3oj^0Y@Go[7nT00?oZGfSon3[
fOoPjmT00_oPjmT4okjP^P?o[XR/0_n_QJP2olk`jP03ojn5Z?nZPj[oZX>Z00;oZX>Z1OncRj/4ojR1
ZPCo]YBd1?n^SkH00onoY/7o]IZlokFJ_002okFJ_0CoZi>m00?o^J[:ok>Sb?ncXlP00_ncXlP3ojfQ
c003okJ`e?n`Zm?o/:_C00Co/:_C0_n[ZMD2ok6gg@Co[[CM00GoZ[?Oojfli?n]_>Co[KcTo`000004
oj^ji003ojVjiOn[_nWoZkoY00;oZkoY0_nZ_nT3oj[3j`CoZ/;[1?nY`N/Dooooo`03o`000?oooooo
oooo01Kooooo000Tooooo`03o`000?oooooooooo00kooooo0ome[_H3og>`m`;oL[7h0om]^od4ofBo
oP?oF/?k0_m=`o<3odc9hP04ofKJh?nLl?CoW?3doic`m0?o_NCb1?o0bn801?o0bN7o]J[>okFZc_ne
Z/h3ok:TbP?o[Yg600?oXXfnoij6^_nNQ[X00_nNQ[X3oi^1]P?o000000CoV7bboiEh[onEN:ooUGR_
1?nCM:d3oi5aZ`?oSfjY0on>K:L4ohm/YPCoT6^T0onAJj<3oi9[XPCoTFZR00?oSfVSoiMf[?nGMZ`0
1?nFMZh4oi=h/P?oTWfh1OnCQL82oiJAc0;oSEbC1?n<G9<3ohaKT`?oS5bC1?n=GI@4ohmNU0OoT5nD
0onAGi@4oi1OT`CoT5jC1?n?GY@4ojV0Z0?oZh2U1On/Oj@00on_Q:Oo0000on3[f@02on3[f@Co_Z2j
00Co[XR/oia`XOnbRJ_o/XV[1?n_QJP3ojZ3ZP;o_iZb1?ncRj/3ojR1ZP;o_Iji1?nfU;@2ojj?]P?o
_jK11?neV[`01?n[Tkgo^J[:okVZb_niZ/X5ok>Sb004ojfQc?nf/=Co][3DokJ`e0Co/:_C00?o]KgO
ok6ggOna]md00ona]md2ojjdg@;o/<3V0on]_>@01?l0003o[KcToj^ji?n[^^@2ojc1j@?oZkoY0_n[
a>`5oj[3j`;oZ/;[0_nY`^`4ojW1jaCooooo00?o0000ooooooooool05Oooool002Cooooo0ol0000?
ooooo`CoNK3f1?mc]_X3offko@;oI;on0om`c_h2of7@m@?oNn7e0_nUjoX4okcNl@03okgTl_o0bn;o
`<_R00;o`<_R00?o]joAokFZc_neZ/h00_neZ/h4ok:TbP04ojjMa_nRSKkoXXfnoj:=_P?oWXJj0ol0
00001?nKPKKoV7bboiQl/_nHO;83oiEh[`CoTgB]0onALJ/4ohm^Z@?oSVbW0on?K:H4oi1[Y0?oTF^S
0onBJj82oi5ZXP;oUWF/1?nGMZ`3oiIf[PCoTgRb1?nBOKP2oi>5`P;oS>g/00CoSUjDoheLTon=G9?o
SEbC1?n<G9<3ohaKT`CoS5bC0on=GI@4ohmNU0OoT5nD1?nAGi@3oi1OT`CoT5jC0_n?GY@00onVP:[o
ZH2XojV0Z003ojV0Z0CoZh2U0on/Oj@2ojn4Y`?oZGbR1OnSMZ001?nLL:7o/XV[ok:9ZonbRJ/5ojn5
Z004ojZ3Z_noV[;o_iZboknJ/PCo/h^[0_nXPJX3okfN^@Co]YBd00?o[XnfoknV`OnoY/400_noY/44
okFJ_0Go^J[:0oncXlP00onn_][o][3DokJ`e003okJ`e003ok2[done_Moo]KgO00;o]KgO0ona]md0
0onba^Wo/<3Vok30iP03ok30iP;o[KcT00?o[LC[o`000?n/`NT01?n/`NT00on[_nWoZlC/oj_4k002
oj_4k0;oZ/?[0_nYa>d5ojW2k0;oZL7[0_nX`N`Booooo`;o00002Oooool4o`000003oa0@4?oooooo
oooo00Oooooo000Tooooo`03o`000?oooooooooo013ooooo1?mi/?H2og>fnP?oPkok0omkb?l2og3>
oP?oR]gn0_nYh_X3ok_Hk`?o_=ka0onob^<00oo0bn;o]joAokN_d@02okN_d@Co]J[>0_nbY<X00onV
Tl;oXXfnoj:=_P02oj:=_P?o000000CoWXJjoi^1]_nKPKKoVh6f1?nHO;83oiEh[`?oTgB]0onALJ/4
ohm^Z@?oSVbW0on?K:H4oi1[Y0?oTF^S0_nBJj800onEMJgoUWF/oiIe[002oiIe[0CoUgJ/1?nFMZh4
oi=h/P;oTWfh0on/kOP00on<kNcoSUjDohiNU003oheLT`CoS5bC1?n<Fi<3ohaLT`?oSEfD1?n?GY@7
oi1OU0CoTEnD0on@Gi<4oi1NT`03ohmNU?nVP:[oYX2Z00GoZH2X1?n[P:D2ojaoY0?o[hBW1?nYO:83
oj=fX003okFB/onbRJ_o/XV[00;o/XV[1On_QJP01?nZPj[o_iZboknJ/_noV[84ok>;Z`03ojR1Z_nm
W[Wo_Iji00;o_Iji1?nfU;@5oknV`@?o]IZl0_o2^]84okVZbP03ok>Sb?nn_][o_[kJ00;o_[kJ0onf
/=@2okO7iPCo]KgO00?o/KOMok;6jOnba^T00_nba^T2ok30iP?o[LW^0on]a>/00ol0003o[<7Yojc1
j@02oj_7kPCoZlC/00?oZLG^ojW4kOnYa>d00onYa>d2ojW2k0;oZ<;/1OnX`N`Cooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02Oooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool04_ooool4ohRfm0;oPkok0onH
b?P3oi?DoP?oZmOg00?oZN;jok_Hkonkf>l00onkf>l01?nlg_7o_l[Soko:honob^<2okVde@Co]joA
0oneZ/h00onZV/KoYY?2ojJC`P02ojJC`P?o00001?nNQ[X4oi^1]P?oV7bb0onEN:l3oi=d[@?oTG6[
1?n?KZT3ohi/Y`;oSfbV00?oRVn_ohea[on=LJl00_n=LJl3oi5c[P?oUGF]1?nFMJ`4oiMf[0CoUWJ^
1?nCN;801?nBOKSo[>ghojc]n?n/kOP4ohiNU0CoSEbC0on<G9<4ohaKT`?oS5bC0on=GI@4ohmNU0Oo
T5nD1?nAGi@3oi1OT`?oT5jC00?oXWn^ojJ0Z_nVP:X00_nVP:X4ojV0Z0CoZh2U00?o[7nTojn4Yon_
Q:L00_n_Q:L4ojUlXP;oXgJP0_neT[<4ok:9Z`Go[hFX1?noV[84ok>;Z`Ko_Iji0_nfU;@2olo6d@Go
_jK100Co]IZlol:jd_o2^];o`[[B0oniZ/X2ol7Cj0Go_[kJ00?o][3DokO7i_nganH00_nganH2okFm
g`;o/]7`0onba^T2oj_>lPGo[LW^0_n]a>/00ol0003oZ/W`oj_7kP03oj_7kP03oj_4k?nYaNkoZLG^
00;oZLG^0_nYa>d2ojS3k@GoZ<;/1?nX`N`Dooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02Oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool04oooool2ohRfm0;oV[c`1OnHb?P0
1?nCe?koZmOgoj_Gmon[eoL3okWAk0?o^mS_0onnbN<00onob^?o^KCEokVde@02okVde@Co]joA00Co
]J[>ojZJa_nZV/KoZY[60ol00004oj:=_P?oWXJj1?nKPKH2oiQl/P04oi1f/_n>Lk3oSW>`ohic/0?o
S76^0on;Kjh4ohY^[P?oRFj^0on:Kjl4ohea[`?oTG>^1?nEMJd3oiIe[0CoUgJ/1?nFMZh3oi=h/P?o
]n?e00?o[>ghoi1PU_n@H9H01?n>GY@3oheLT`?oS5bC1?n<Fi<3ohaLT`?oSEfD1?n?GY@7oi1OU0Co
TEnD0on@Gi<01?n@GY?oXWn^oj9o[_nROjh4ojJ0ZPGoZH2X0on[P:D00onfTK3o[hBWojn4Y`02ojn4
Y`CoZGbR00?oXgJPokFB/oneT[<00_neT[<3ok:9Z`Co[hFX0_oD`<L4oknJ/P;o/h^[0_o7]LT5okfN
^@04okJD]?o?a]7oclKAolo6d@Co_jK100?oaMKWol:jd_o2^]800oo2^]800oniZ/[o`M?Xol7Cj002
ol7Cj0;o_[kJ0_neeo84okO7iP03oj[KnOnbdO3o/]7`00?o/]7`00?o//KYoj_>l_n[c_800_n[c_82
ojg9kP;oZ<gc0onZbO001?l0003oZ/W`oj_7k_n[anh2ojS7k`?oZLG^0_nWa>h4ojS3k@;oZ<;/0onW
`N`4ojS1k1?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`002Oooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003ooooooooo
o`0Eooooo`CoV[c`0_nHb?P4oj_;l@03oj_GmonidNco^M7/00?o^M7/00Go^mS_okk9honnbN?o_/WS
ok^if006okVde@;o]joA00?o[Z7;ojZJa_nZV/H00_l00003ojJC`PCoXXfn0_nNQ[X00onDO[SoTWVd
oi9i]002oi9i]0?oT7Jb0on>Lk03ohaa[P?oRfn^1?n:KZh3ohU^[PCoRVn_0on=LJl4oi5c[P?oUGF]
1?nFMJ`3oiMf[0CoUWJ^00?oTgRbokOSmOnghoD00_nghoD01?nAHiWoT62Foi1PU_n@H9H4ohiNU0?o
SEbC0on<G9<4ohaKT`?oS5bC0on=GI@4ohmNU0OoT5nD1?nAGi@2oi1OT`03oin0/OnROjkoXWn^00?o
XWn^0onVP:X5ojV0Z0;oZh2U0onfTK04ojn4Y`?oZGbR1OneT[<4ok:9Z`;o[hFX0ooD`<L4oknJ/P04
ok>;Zoo7]LWoakG9olNeb@Co_Iji0_o6nnP4olo6d@03oknV`Oo5e^OoaMKW00;oaMKW0oo2^]82ojo`
mP;o`M?X0onNi?`4okGGlP03okO7i_nZfoWoZ]_i00;oZ]_i0_nbdO03ojGDn0;oZlkb0_nScoL5ojS=
l`;oZ/W`00?oY/Sao`000?nXanl01?nXanl00onYaNkoYlC^ojO4kP02ojO4kP;oZ<?]0_nW`^d5ojO1
k0;oZ<7/0_nW`>`Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool000Wo
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0ol0000Foooo
o`;oV[c`0on[`NX3oj_;l@?o]lWX0_nidN`4okg8hP04okk9honk^MSo^kWHok^if0Co^KCE00?o/JS?
ojjQbon^XL/00ol00002ojZJaPCoYY?20_nRSKh01?nHPk_oU7jhoiAn^?nDO[P4oi9i]0CoT7Jb0on>
Lk03ohaa[P?oRfn^0on:KZh4ohU^[P?oRVn_0on=LJl4oi5c[P?oUGF]1?nFMJ`4oiMf[0;oUWJ^0onf
fo<01?nghoGoTF>Ioi5SVOnAHiT3oi1PUPCoSUjD0on=G9<3ohaLT`CoS5^C0on<G9<4oheMU0?oSejD
1on@Gi@4oi5OU003oi1OTonOP;7oWh2a00GoXWn^0onVP:X5ojV0Z003oj^0YOnfTK3o]Y6`00;o]Y6`
1?n_Q:L2ojUlXP;o^J?21?neT[<4ok:9Z`03ojn5Z?oD`<Ooe<3700;oe<370onoV[800oo7ingoakG9
olNeb@02olNeb@?o_Iji1?o6nnP2olo6d@;oSng_1?o5e^L01?o2^];o[o3fojo`m_n_l?H3oeW@jPCo
W^Cl0_neeo83oi;PoP;oZ]_i0onHe_d2ojGDn0;oVm3j1?nScoL2ojS=l`;oXlWc1?nVb?400ol0003o
Z<O_ojS7k`03ojK5k`;oYlC^0_nV`^d5ojO2k@;oYl7/1onW`>`Aooooo`?o00001oooool00ol0003o
ooooooooo`09ooooo`002Oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool01?ooool00ol0003oooooooooo`0Hooooo`CoZl7Z00CoZl_aokO9j?ngbNSo]lWX0onla^43okg8
hP03okbmf_nk^MSo^kWH00?o^kWH00?o^KCEok6XconaZ<l00ol00002ojjQb`CoZY[60_nVTl800onK
RKooV8>koiR3^`02oiR3^`?oU7jh0onBNK@4oi1f/P?oSW>`0on<LJh3oh]_[P?oRVj^1?n9KZh3ohY_
[`CoSG6_0onALjh3oiEe[@CoUWF/1?nGMZ`01?nFMZko]]_cokKKlonffo<2oi9VW0?oTF>I0on@H9H4
ohiNU0?oSEbC0on<G9<4ohaKT`?oS5bC1?n=GI@3ohmNU0OoT5nD0_nAGi@2oif2]@CoWh2a1?nROjh3
ojJ0ZPCoZH2X0_nnYL04okJA/0Co[hBW00CoZGbRokVS`_niXl;o^J?21?neT[<4ok:9Z`03olCnd_oD
`<Ooe<3700?oe<3700Co_iZbolOWkOo7ingoanO]1?o7]LT01onmW[Woa__XolKkj?o6nnSoMj_coj6N
d_lH00001?n?kNl2olGFi`;oKjkg1?m>]oT3odFnl@;oJmGh0omjbOl4ohGBo`;oV=Km0_nCc?/5oi_@
nP;oXlog0_nPb?D4oj?9l`;oY/Sa00?oY<G`o`000?nTaO000onVaNl2ojG2kPCoY/;]0_nW`^d2ojK0
k0OoYl3/0_nW_n/>ooooo`Co000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`09oooo
o`002Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Iooooo`;oZl7Z0onf`n@00ongbNSo_<KQokc6h@03okc6h@04okg8h_nl_M[o_;gJ
okbmfP?o^kWH00Co]:oDo`000?l0003o00000_naZ<l4ojjQb`;oZY[600?oWi34oi^9_onKRKl00_nK
RKl3oiR3^`?oU7jh1?nBNK@3oi1f/P?oSW>`0on<LJh3oh]_[PCoRVj^0on9KZh3ohY_[`CoSG6_0onA
Ljh4oiEe[@?oUWF/0_nGMZ`4ok3Gm004okKKlonBIYcoTVJLoi9VW0?oTF>I0on@H9H4ohiNU0?oSEbC
0on<G9<4ohaKT`?oS5bC1?n=GI@3ohmNU0KoT5nD00?oW8>goif2]OnMP[D00_nMP[D4oin0/@CoXWn^
1?nVP:X2ojV0Z0?o_ZG01?nfTK03ojn4Y`03okW3h_niXl;o^J?200;o^J?21OneT[<2ok:9Z`?oa?kB
0_oD`<L3oibEc0CoanO]0_o7]LT3oiRQf`03oj^LaonQW];oXIkB00?oXIkB1?n>Y>@2ofn^m`;oVZ[R
0on9]?85ogVmo0CoN/Wo0_n5d_l3ohg4nP?oTlck0_nKd?X2oi_6m@GoX<Se0_nSbO<2oj;4l@?oY<G`
00?o0000ojC5l?nVaNl01?nU`^h2ojK2k@KoY/3/0_nW`>`2ojJoj`GoYko[2_ooool3o`0000Gooooo
00?o0000ooooooooool00oooool00omEEEGoIVIVo`00000;ooooo`002Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`;o00006oooool3okK3i0;o
^lCQ1?nla^400onl`Mgo_;gJokbmfP03okbmfP?o000000?o]:oDok6XconaZ<l00onaZ<l2ojjQb`03
oj>Gb?nOT<CoWi3400;oWi340onKRKl3oiR3^`?oU7jh1?nBNK@3oi1f/P?oSW>`0on<LJh3oh]_[PCo
RVj^1?n9KZh3ohY_[`?oSG6_1?nALjh3oiEe[@;oUWF/0onQdOP3ok3Gm003ogUKXonBJZ7oTVJL00;o
TVJL0onAHiT3oi1PUPCoSUjD0on=G9<4ohaLT`?oS5^C0on<G9<4oheMU0?oSejD0_n@Gi@2oib4^@?o
W8>g1OnMP[D3oin0/@CoXWn^1?nVP:X00onYP:Soa/GIokjU`003okjU`0?o]Y6`00?o[hBWokW3h_ni
`n800_ni`n84okVS`PCo]I:c00Co/XV[ojfC^on]Tk_o[I>k1?nXTl001?nLULco[Y[2ojjJ`_n^V/85
ojRLbP04oiRQfon[W<OoZic7oj^La`CoXIkB0_n>Y>@2ojFTe0GoVZ[R0on9]?82ogVmo0?oU[7Z1?n@
^o@2ohg4nP;oVK[_1OnJ`O<3oi_6m@;oX<Se0onQ`_04oj;4l@;oY<G`00?oY<7^o`000?nT`Nh00_nU
`^h2ojFok0OoY/3/1_nV_n/4ojNoj`Kooooo1?l00008ooooo`03o`000?oooooooooo017ooooo0009
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo
00?o0000ooooooooool06oooool00onf`nCo^lCQok_4h@02ok_4h@03okc6hOnl`Mgo_<7M00;o_<7M
00Co_;gJo`000?l0003o00001Ond[m@2ok6Xc`;oYio=1?nSUlP3oin@a0?oVhVo1?nHPk/3oiAn^0?o
TWVd1?n@M[83ohic/0?oS76^0on;Kjh3ohY^[PCoRFj^0on:Kjl3ohea[`CoTG>^0_nEMJd2oi37nPGo
XM7h00Co/=OdogUKXomiFj?oNE^S0onBIY`3oi5SV@?oT62F1?n>GY@3oheLT`CoS5bC0on<Fi<3ohaL
T`CoSEfD0_n?GY@00onLQKWoW8Bioib4^@02oib4^@CoW8>g1?nMP[D3oin0/@GoXWn^0_nVP:X3olK5
f@Co_ZG00_nfTK02ohoXn@Co^L?R1?niXl82okFB/`03ojRFa?n`U;_o[I>k00?o[I>k0onXTl000onc
Vkoo[Y[2ojjJ`P03ojjJ`P?oZ9c:00?o/ik3oj^Laon[W<L00_n[W<L3oj6NdP03ok2Sc?nUY=CoYJCD
00?oYJCD0onJZ^800onYYmCoWj[NoinZgP02oinZgPGoU[7Z0_n@^o@2oijdj0CoVK[_0_nJ`O<2oj2i
j`GoWkg^0_nQ`_02oj>mj`CoXko]0_nT`Nh00ol0003oYKk[ojFok004ojFok0;oY/3/0_nV_^/7ojJo
j`KoYko[0_ooool3o`0000cooooo00?o0000ooooooooool04Oooool002;ooooo00?o0000oooooooo
ool07Oooool3ok_4h@?o_LCO00Go_<7Mo`000?l0003o0000okbmfP03okJff0?o]:oD00?oZjOCojNO
cOnWWld00onWWld3oj>Gb0?oWi341?nKRKl3oiR3^`?oU7jh0onBNK@4oi1f/P?oSW>`0on<LJh3oh]_
[P?oRVj^0_n9KZh2oh^@d`?oR9[N1?n3Y^/5ohFgmP?oT<Oj0_nQdOP3ogeMX`?oNE^S0_mfFZ@01?nB
IYcoTF>Ioi5SVOnAHiT3oi1PUPCoSUjD0on=G9<4ohaLT`?oS5^C0on<G9<4oheMU003ohmNU?nLQKWo
W8Fi00GoW8Bi0onLPkL4oif2]@CoWh2a1?nROjh00onVP:[o_^_colK5f@03olK5f@;o_ZG01?nRSKd0
0onYT;_oZY6kokW3hP03okW3hP;o^J?200?oZY:nojRFa?n`U;/00_n`U;/5ojfC^`04ojRC`?ncVkoo
/i^ook>K_`Co[Y[200CoZ9c:ok>N`oncW/?o/ik31On[W<L01?nQW];o/:?<ok2Sc?n`Xl`4ojFTe003
oiZZh_nYYmCoZJOD00;oZJOD1?nOZ]h2oiJajP;oY:oO1OnN]>P2oiVjk`;oX[CU1?nP^N/2oinmkP;o
Xk[Y1OnS_N/2oj>ok@06ojFljOnU_^_oYKk[ojFnjol0003oYKk[0_nU_n`3ojJmjPCoY[k[0_nV_n/2
ojNnjPWoYko[00?o0000ooooooooool03_ooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0
003oooooooooo`0Nooooo`04ok_4hOnma=oo_LCOokg4g`;o00000_nl`Md2okVlg@Co][KH00Co]:oD
oj^Wdon[Ym?oZjOC1?nWWld3oj>Gb0CoWi340onKRKl2oiR3^`04ohn6aOn=P/?oSH;3ohf2``?oRgo2
1?n9Ol43ohUo`P?oRX730on;Q<H3oh^9b`GoRi3C0on8V]h4oh>Vj`;oQKOf00CoSg2/ohUYZ?n9JJSo
RFVX0on3HjD3ogeMX`?oNE^S0omfFZ@3oi5SV@?oT62F1?n>GY@3oheLT`CoS5bC0on<Fi<3ohaLT`;o
SEfD0_nLPkP4oib5^@CoW8Bi0onLPkL5oif2]@?oWh2a0_nROjh00on>k^Go_^_cokk[l`04oj:9^@Co
XhZk00CoXXfmojV@^onYT;_oZI2k1?nZTK/3ojZB_P03ok6G_?n`U;_o/9Bk00?o/9Bk0on]Tk/00one
WL3o/i^ook>K_`02ok>K_`?o[Y[200?o]j;3ok>N`oncW/<00oncW/<3oj^La`03okFUb?n`Xlco/:?<
00?o/:?<0_nUY=@00on`YlooZJODojVWe004ojVWe0;oWj[N0_nZ[=T4ojB_g`;oW[CX0_nV/N05oj:d
i@;oX;W[00?oYKOVoj>jjOnS^^T00onS^^T2oj>mj`;oY[[X1?nU_>T3ojFnj`03o`000?nV_N[oY[gZ
00CoY[gZ0_nV_^/6ojNnjPWoYko[4?ooool00ol0003oooooooooo`0@ooooo`008_ooool2o`00023o
oooo0ol000000onma=oo^/?QokVlg@04okVlg@;o][KH00?o[[3Ioj^Wdon[Ym<00_n[Ym<5ojNOc@?o
XiO80_nOT<@01?nFT<_oTX[8oi::b?nBR/P4ohn6a@?oSH;30on;Ol83ohUo`@CoRGo20on:PL<3oh^4
aP?oRhW;1?n;T=<4ohRJgP;oPjK[00CoUWZbohm`[?n?L:coSg2/0on9JJP3oh=SY@?oOEfS0omiFj<3
ogIJY0?oNEfU0on@H9H4ohiNU0?oSEbC1?n<G9<3ohaKT`;oS5bC00?oVh2eoib3^?nLPkP00onLPkP3
oib5^@CoW8Bi1?nLPkL4oif2]@;oWh2a0_n>k^D00onNQ[[oX8Nioj27^@02oj27^@CoXXVi0_nSR[/0
0onWSk_oZI2kojV@^`03ojV@^`CoZY6k00CoZY:nok6G_?naUkco/INl1?n`U;/2ojfC^`;o]Ig01Onc
Vkl01?n^V/;o]j;3okNR`ongX/<4ok>N``03oj^LaoneYLSo]JG800;o]JG80on`Xl`00ongZlgo/:O?
ok2Wc`02ok2Wc`CoZJOD00?o/JgDojZ/fOnZ[=T00onZ[=T2ojB_g`03oj^`fonV/N3oY[7P00?oY[7P
0_nR]>D2ojRdhPCoYKOV0onS^^T00onW^>GoY[[XojJjj003ojJjj0CoYKcY00CoYKk[ojJljOnV_>Wo
00001?nV_NX00onW_NWoYkkZojNnjP07ojNnjPSoYko[4?ooool00ol0003oooooooooo`0@ooooo`00
8_ooool00ol0003oooooooooo`0Looooo`?o000000?ooooookg4gonj`n400onj`n43okVlg@03ok6i
gon^/=Wo[[3I00;o[[3I1?n[Ym<2ojNOc@;oWIkD0onJUll4oiJ@b`?oTX[80on?Q/D3ohf2``?oRgo2
1?n9Ol43ohUo`P?oRX730on;Q<H3oh^9b`GoRi3C0_n8V]h00onMQKWoUWZboiIj/P02oiIj/P?oSg2/
0_n9JJP3oh=SY@CoOEfS0_miFj<3ogIJY0?oNEfU0omoHjP4ohiNU0?oSEbC1?n<G9<2ohaKT`03oiQl
/_nKP;GoVh2e00;oVh2e1?nLPkP3oib5^@GoW8Bi0onLPkL2oif2]@04oiUdYomDc[koE<jnoib6^P?o
WXJj1?nPQkT4oj:9^@04oj>:^onWSk_oYhnkojN?^`CoZI2k0onZTK/00on`V/3o/INlok6G_002ok6G
_0Co/9Bk00?o[I>kokFM`?neWL000_neWL03ok>K_`03okZXaongX/?o]j;300;o]j;30oncW/<00onj
ZLWo]JG8okFUb004okFUb004ok2Sc?ngZlgo]j_=okN[c@Co/:O?00?oZJODok6]e?na[M@00_na[M@3
ojZ/f@03ok2`f?n[/=_oZk3K00;oZk3K0onV/N000on[]=koZ;CRojRdhP03ojRdhPCoYKOV00CoXk[Y
ojNhiOnW^>GoYkSU1?nV^^P2ojFlj@;oYk_X0onV_>T00ol0003oY[cYojJmjP04ojNmj@?oYkkZ00?o
YkkYojNnj_nW_^X00onW_^X2ojNoj`;oZ;oZ1?nW_n/?ooooo`03o`000?oooooooooo013ooooo000R
ooooo`03o`000?oooooooooo01Wooooo0ol00006ooooo`Co^/?Q00Co^KcMok6igona^Moo/KWO1?n^
/=T2oj^Wd`03oj6UfOnMW]CoWIkD00?oWIkD0onJUll3oiJ@b`?oTX[80on?Q/D3ohf2``?oRgo21?n9
Ol43ohUo`P?oRX731?n;Q<H3oh^9b`;oRi3C0_n>LZl3ohU/Z`?oQ6JX00CoUWZbohm`[?n?L:coSg2/
0on9JJP2oh=SY@CoOEfS0_miFj<4ogIJY0;oNEfU0omoHjP3ohIYZP04ohiNU?n=G9?oSEbCohi`[@Co
U7J_0onHO;84oi^0]@CoW8>h1?nLQKT4oib4^@;oW8>g00?oUg:Woco1]_nKQ[`01?nLQ[X3oij6^PCo
X8Ni0_nRRKT2ojF>_0CoYhnk1?nYT;/00onZTK_o/9[0ok2J`002ok2J`0?o/INl0on`U;/00onfXLCo
]Ig0okFM`003okFM`0;o/i^o0onjZ<L4okNR``04ok>N`onjZLWo^ZW9okZYb@Co]JG800?o^k3?okN[
cOngZld00_ngZld3ok2Wc`03okJ_d_na[MCo/JgD00?o/JgD00?oZZcIok2`f?n`/=P00_n`/=P4oj^`
f`04ojJah?n[]=koZkCNoj^dgPCoZ;CR0_nU]nH2ojVgh`GoYkSU0_nV^^P2ojRjiPCoYk_X0_nV_>T0
0onW_>So0000ojNmj@04ojNmj@03ojNnj_nW_^WoYkkY00;oYkkY0onW_^X6ojRojP;oYko[00?oZ<3[
ooooooooool03Oooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0Foooo
o`?o00002_ooool2ok[3h@;o/l;U1?na^Ml2ojj`f@03ojB^g_nQYMWoXJGI00;oXJGI1?nMW]@3oiZG
c`?oUY3;1?nBR/P3ohn6a@?oSH;30on;Ol83ohUo`@CoRGo20on:PL<2oh^4aP03okVee_nMQ[[oUWbd
00;oUWbd0on>LZl3ohU/Z`CoQ6JX0on2I:L3ohUYZ0?oPf>U0ommGJ<3ogUKX`?oMUZT0omiGJD2ogmS
Z0CoQVVZ0on>L:d4oiAf[`CoV7bb0onKP;D5oib3^0?oW8Fi0_nLQ;T01?nDL:OoD<kFoe3>e_nKR;l4
oi^6_0?oW8Jj1?nNQ[X2oj27^@03oj>=_OnUS[coYHjl00?oYHjl0onWSk/3ojV@^`03ojnLa?n`V/3o
/9[000?o/9[01?naUk`01?n`U;_o]Z74okJQa?nfXL@4okFM`003ok>K_onjZ<Oo^ZS700;o^ZS70ong
X/<00onk/<ko^ZW9okZYb@03okZYb@04okFUb?nk/<oo^k3?ok^`c`Go]j_=00Co/:O?okJ_d_nf[m;o
]ZoB0ona[M@00one]=Oo/;3Hok2`f003ok2`f0;oZk3K0_n`]=`5oj^dgP;oZ;CR0_n/]^44ojVgh`;o
YkSU0_nY^ND5ojRjiP;oYk_X0_nX^nL3ojNlj003o`000?nW_NWoYkgY00;oZ;gY1OnW_^T00onW_^[o
Z;oZojRojP04ojRojP;oZ;o[1?nX`>/>ooooo`03o`000?oooooooooo013ooooo000Rooooo`;o0000
5?ooool3o`0000kooooo1?nc`^D2ok6ig`03ojJgiOnT[]koY:kN00;oY:kN1?nQYMT4oifNe0?oVYO?
0onFT</2oi::b004ohNMhOn4W^CoQ9kTohBNi0?oP:;Y1?mkZO45og>enP;oI<7m0_noa=h01?nUT/7o
WHJjoif6^_nMQ[X4oiIl]0?oSW:_0on9K:/3ohAVZ0?oPVBW0on0HZL3oh=SY@?oOEfS0omiFj<3ogIJ
Y0?oNEfU0omoHjP3ohIYZPCoSW2]0onDMZl4oiQl/PCoVh2e1?nLPkP2oib5^@04oi9^Yomfe?koM]Cn
oij?a0?oVhRo1?nKQ[`4oib6^P?oWXJj00CoX8Nioj>=_OnSSKgoXhfm1?nUS[`4ojN?^`04ojV@^on_
W<Co[ic4ojnLa0Co/9[00onaUk`00oneY/[o]Z74okJQa002okJQa0?o]Ig000?o^k3>okZXaonjZ<L0
1?njZ<L01?ngX/?o^k3>ok^`c_nk/<h4okZYb@Go^k3?0ongZld00onj]MGo]ZoBokJ_dP03okJ_dP04
ok6]e?ne]=Oo]KCGokFde`?o/;3H00?o/kOLok2dg?n`]=`00on`]=`2oj^dgP;o[[OP1On/]^42ojVg
h`;oZkWT1?nY^ND2ojRjiP;oZK_V1OnX^nL2ojNlj003ojRmj?l0003oZ;gY00?oZ;gY0_nW_^T2ojRn
j@GoZ;oZ1OnX_n/4ojS0j`gooooo00?o0000ooooooooool04?ooool0027ooooo0_l0000Booooo`?o
00004_ooool2ok?2i@;oZ<3[0onV]nD4ojB^gPCoXJGI0_nMW]@01?nBYN;oSj7QohnQhOn?XN43oh^N
h0CoQigQ0on4W^@3oh2Rj@CoNjWa0_mc]OX3ol?@i003ojbNbOnUT/7oYI;100;oYI;10onMQ[X3oiIl
]0?oSW:_0on9K:/3ohAVZ0?oPVBW0on0HZL3ogeRZ@?oOEfS0omiFj<3ogIJY0?oNEfU0omoHjP4ohIY
ZP?oSW2]1?nDMZl3oiQl/PCoVh2e0_nLPkP4ohN`l004ojFLc?nNSlCoWXo4oij?a0?oVhRo1?nKQ[`4
oib6^P;oWXJj00?oWh^noj>=_OnSSKd00_nSSKd4ojF>_0?oYhnk00?o[Ik8ojnLa?n_W<@00_n_W<@5
ok2J`004ok6G_?neY/[o]JK:okFVbPCo]Z7400Co]Ig0ok^`c_nk/<ko^k3>1?njZ<L00onk^=Oo^k3>
ok^`cP02ok^`cP?o^ZW90_nl^=H4ok^`c`03okN[cOnj]MGo^[GE00;o^[GE0onf[m800onh^M[o]KCG
okFde`03okFde`04ok2`f?nc]mco/kOLok>gg0?o/;CL00?o/K[Pojjgh?n^]n000on^]n02ojbfh@;o
[K[S1On[^N@2ojVii@;oZk_U1?nY^nH2ojRki`;oZKgX0onX_NP01?l0003oZ;gXojRmjOnX_NT6ojRn
j@GoZ;oZ0_nX_n/7ojS0j`cooooo00?o0000ooooooooool04?ooool000Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool03oooool2o`0001Kooooo1?nX`>/3ojJgi@;oY:kN0_nH/>P4oiJ[i@?oTZGR0on?XN43oh^N
h0CoQigQ0on4W^@3oh2Rj@;oNjWa1?o2enT01?o3d>Co[9k9ojbNbOn/W/T3ojFB`@?oWHJj0onFO;@3
ohib[`?oRFb[0on4IZP3oh9TY`?oP6:W0ommHZT3ogIT/0?oNE^S0omfFZ@3ogUMY@?oOf>X1?n6JJX3
ohi`[@CoU7J_1?nHO;82oi^0]@CoPXO?00CoQk3`ojFLc?nUW<coYIc<1?nNSl@3oi^8_`;oVhJl00?o
VHJnoib9__nLRKh00_nLRKh4oin;_P?oXhfm1OnUS[`01?nWSk_o[Ik8ojfNb?n]W/P3ojnLa0Co/9[0
00?o/jcAokFVb_neY/X00_neY/X3okJQa003okVhf?nk/<ko^k3>00?o^k3>00?o^ZS7ok^heonk^=L0
0_nk^=L4ok^`cP03okZYbOnl^=Ko_;SF00;o_;SF0_nk/<l2ok^lfPCo^[GE00?o]ZoBokRif_nh^MX0
0_nh^MX2okFde`;o][_N1Onc]m`01?n`]=co/K[Pok6jh?na^^03ojjgh003ojnlhon]^^?o[K[S00?o
[K[S0_n[^N@2ojbli@GoZk_U0_nY^nH2ojZmi`CoZKgX0_nX_NP00onY_^Wo0000ojRnj@06ojRnj@Go
Z;oZ2_nX`>/=ooooo`03o`000?oooooooooo00oooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`?o
00006Oooool2ojS0j`03oi^ll?nJ]^coV[K/00?oV[K/0onH/>P4oiJ[i@?oTZGR0on?XN43oh^Nh0;o
QigQ0omc`_h2ofG8o@03oeK>^oo0fngo`=_]00Co`]OY00?o/ZW@ojbNbOn/W/T00_n/W/T3ojFB`@?o
WHJj0onFO;@3ohib[`?oRFb[1?n4IZP2oh9TY`?oP6:W0ommHZT3ogIT/0?oHFg81?mfFZ@2ogUMY@?o
Of>X1?n6JJX3ohi`[@CoU7J_1?nHO;800onKP;GoOFnhoh:7c`02oh:7c`03oeC;[?nd]][oYIc<00?o
YIc<0onNSl@2oi^8_`03oiJ5__nIQ[koVHJn00;oVHJn1?nLRKh3oin;_PCoXhfm0_nUS[`2oj^Pc0Co
[Ik81?n_W<@01?n`V/3o/jcAok>/dOnc[=45okFVbP04okJQa?ni^=So^KSHokVhf0?o^k3>00?o^<7Q
ok^heonk^=L00onk^=L2ok^`cP;o^l7N1?nl^=H00onha>?o^kcJok^lfP03ok^lfP;o^[GE0_ni_ml3
okRifP03okK1h_nf^mko][_N00?o][_N0_nc]m`2ok>mhPGo/K[P00Co[[OPojnlhon__>?o[kcS0on]
^^<2ojjmi@Co[;cU0_n[^nD2oj^ni`GoZ[gW0_nY_NP2ojZnj0?oZKkY00?o0000ojRnjOnX_^T00_nY
_nX6ojRojPcoZ<3[3?ooool00ol0003oooooooooo`0?ooooo`001oooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol00005ooooo`;o00002_ooool3o`0001gooooo0onK_?05oiZfk0?oV;3X0_nF
ZnD2ohZfl`?oQ[Kd1?n2^?L3og^ln`;oLl;n0_mZgMd00onUlo7o`=_]ol3Kk@02ol3Kk@04ol;GjOnb
ZM3o/ZW@ok:Yd0Co[9k91?nUT/43oif6^P?oUWbd0_n>LZl3ohU/Z`CoQ6JX0on2I:L2oh1RY`CoOF:Y
0omfI;04of5]b0;oMUZT0omiGJD2ogmSZ0CoQVVZ1?n>L:d3oiAf[`;oV7bb0_mjHJ/3oge_^004oh:7
conES<SoUHc8oiF<b0CoThK20onCQ<04oiJ5_P?oVHJn1?nLRKh3oin;_P?oXhfm00?oZ:3>oj^Pc?n[
X<`00_n[X<`5ojfNb0;o[ic400?o/K7Hok>/dOnc[=400onc[=43okFVbP03okK1h_ni^=So^KSH00?o
^KSH00Co^k3>okS1hOnh`N7o^<7Q0onk^=L00onebNWo^l7Nok_1gP03ok_1gP03okbhe_nha>?o^<CS
00;o^<CS0onk_=X00onfanKo^KoOokVog`03okVog`04okRif_nf`N;o]/7RokK1hP?o][_N0_nc`^D4
ok>mhP;o/K[P0_na_n@5ojnlh`03ojfjhon^_NGo[[gU00;o[[gU0_n/_>D2ojboi`CoZkkW0_nZ_NL2
ojZoj0GoZ[kX0_nY_^T00ol0003oZKoYojVojP03ojVojP;oZ;oZ0onY`>X2ojS0j`;oZL3[2OnX`>/;
ooooo`03o`000?oooooooooo00oooooo0007ooooo`05o`000?ooooooooooooooool000002oooool0
1?m4A4CogMgMooooool00006ooooo`03o`000?oooooooooo00Kooooo0ol0000Qooooo`?oVkc`0_nJ
]^`3ohnhlP?oSKKb1?n:]_<3ohJfm0;oP[Sg0omVd?T01?m<bN?oJ]gMojC^n?nTk_P3okcJk`;o`=_]
00?o][?Fok:Yd?nbZM000onbZM04ojbNb@?oYI;10onMQ[X3oiIl]0?oSW:_0on9K:/3ohAVZ0?oPVBW
0on0HZL3ogeRZ@?oMVB`1?mQKLP2oh1//`?oNEfU0omoHjP4ohIYZP?oSW2]0_nDMZl00omjFj?oNV6[
ogYQZ`02ogYQZ`;oOFnh00?oWnghoibKd_nLVm800onES<P3oi>6`PCoThC00onFQKh3oiV6_PCoW8Vn
1?nORkh01?nSSKgoZ:3>ojRPc_nXX<h4oj^Pc0?o[Ik800?o[[GMok6af?na/MP00_na/MP4ok>/d@03
okFVb_nf`N;o]/7R00;o]/7R0oni^=P2ok79k0Co^<7Q00Co^kSGokG9jOnebNWo]LWY0onk`Mh2ok;;
k0Co^<CS00?o^kcJokK7i_nfanH00_nfanH2okVog`;o/lKX1Onf`N800onf^mko/l;Uok?2i@02ok?2
i@;o/kgR0_na`^L4ok6oi0;o[kcS0_n^_nH4ojjmi@03ojg0j?n/_nOo[;oW00?o[;oW0_n[_^L2oj_0
j@CoZ[oX0_nZ_^P2oj[0j@?oZKoY00Co0000ojVojOnY_n[oZKoZ1OnY`>X6ojW0j`;oZ<3[0_nX`N/5
ojS0j`[ooooo00?o0000ooooooooool03oooool000Oooooo00Go0000ooooooooooooooooo`00000;
ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool00oooool3o`0002Kooooo1?nA
^O83ohnhlP?oSKKb0_n:]_<3oh37oP;oM/go1?n6gOh00omjhO?oY>khojC^n003okcJk`03okRkg?nf
/mKo][?F00;o][?F1?nbZM02ojbNb@;oVhk50onDQ<03ohal_0?oQGFj0omnL;T3ohU/Z`?oQ6JX0on2
I:L3oh1RY`?oOF:Y0omfI;03of5]b004ohn3`On0K;?oP6bcoh1//`;oMV6]0omoHjP4ohIYZP;oSW2]
00CoOE^PogYKXomjFj?oNU^S0_mjHJ/3ojBlj`04ojjihOnLVm;oW9_BoibKdP?oUHc81?nCQ/83oi>4
`0?oUXFn1?nIQ[h4oib9_P;oWh^n00?oY9k?ojRPc_nXX<h00_nXX<h4oj^Pc003ojfNb?n^]Mgo[[GM
00;o[[GM1?na/MP2ok>/d@;o/<S/1?nf`N800oni^=So/LW/ok79k003ok79k0;o^<7Q0_n]d?<4okG9
j@03ok_1g_nbbnco//_/00;o//_/0_nha><2ojo<k`?o]/OV0_n^bnh4ok?6j0;o]/7R0_naa^T4ok?2
i@03ojo5j_na`^Oo/L;W00?o/L;W0_na_n@2ojo2j0Co[[oV00?o[[gUojg0j?n]`>P00_n]`>P2ojbo
i`;oZl7Y1On[`>T2ojZoj0;oZ/3Z1?nZ`>T2ojVoj@03ojW0j_l0003oZL3Z00GoZL3Z1_nY`>/00onY
`N_oZ<7[ojS1j`03ojS1j`;oZ<3[0_nX`N/:ooooo`03o`000?oooooooooo00oooooo0007ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000005ooooo`04o`000?oooooooooo
ooooo`?o0000:_ooool2oi6ilP;oSkWc0on;_OL4ohO2n`;oP<On0on=eOl2ohKMoP?oY>Gk0onheo00
1?nlf^oo^;_LokRkg?nh^m`4okJceP;o/ZW@00?oXYS:oi^>aOnKS/D00_nKS/D3oiB4`0CoS7bl0on5
MKX2ogi`^@?oNFjk0ombL<43oh9TY`?oP6:W1?mmHZT3ogIT/004of5]b?mdGjcoM5n/ohn3`@;oP6bc
0omfHJd3ogMP[0?oO6N`0on5M[X4oiBAc@?oY;c[0_n^^N43oibKdP?oUHc81?nCQ/83oi>4`0CoUXFn
0onIQ[h2oib9_P;oX9_?1?nTW/l4ojRPcP;oZj3<0_n/^>85ojjeg@;o/K7H0_n[c_84ok38k0;o]/7R
0onZd?@2ok79k0;oX]?i1On]d?<2okG9j@?oZLod0_nbbn`2ojO?m@Co[lc_00?o]/OVojk;k_n^bnh0
0_n^bnh2ok?6j0;o[LW_1?naa^T00onc`^Go[lGZojo5jP02ojo5jP;o/L;W0_n^aN/5ojo2j0;o[[oV
0_n]`^T3ojg0j0;oZl;Z1?n[`NT2oj_0j@;oZ/7Z1OnZ`>X2oj[0j@;oZL7[0onY`>X00ol0003oZL3Z
ojW0jP02ojW1j`CoZL3[1OnY`N/9ojS1j`Wooooo00?o0000ooooooooool03oooool000Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Gooooo1?l0000^ooooo`CoSkWc
0on;_OL2ohO2n`?oT/cl0_n=eOl3oj?Ln`;o]=;`0onheo02okS0h0Co^;_L0_nf/mH00onXXLooXYS:
oj:HbP02oj:HbPCoVhk50onDQ<03ohal_0?oQGFj0omnL;T3ogU^^`;oLW310om_O=03oh1RY`CoOF:Y
0_mfI;02ohE]/0?oM5n/0_n0K;<3ogIQ[@?oMf2/1?mlIk03ohEf^PCoU97=00?oY;c[ojjihOn^^N40
0_n^^N43oibKdP?oUHc80onCQ/84oi>4`0;oUXFn00CoUi3:oibFcOnLU/goW9K=1OnPVll4ojBNc`;o
Z:3>0_nY^ND4ojbhhP;o[[GM0_nVd_L5oj_>lP;o/<S/0onRdoT2oj[@m0;oVmGl1?nRdoT2ojg@l`?o
X=;i0_nYco@2oik@n@GoYloe0_n_c>l3ojO=m0;o[/_^0_nWc?<4ojg9k`;o/LKY0_n/b>h3ojo5jP;o
ZlO^1?n^aN/2ojo2j0;o[<C[1On]`^T00on]`>SoZl;Zoj_2jP02oj_2jP;oZl7Y0_nZ`^/4oj[1jP;o
Z/3Z1onY`N/2ojW0jP03o`000?nY`N_oZL7[00?oZL7[00?oZL3[ojW1jonY`N/01?nY`N/:ojS1j`Wo
oooo00?o0000ooooooooool03oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03
ogMgMol0003ooooo00Cooooo0_l0000aooooo`;oSkWc0_nH^o44oiG3mP;oT/cl1?nSdOP00onSg?_o
]=;`okCBl002okCBl003okSGl?nh`>3o^<3P00;o^<3P0_nh^m`00on]Z]CoZ:7?ojRQc`02ojRQc`?o
XYS:1?nKS/D3oiB4`0?oS7bl0on5MKX3ogi`^@?oNFjk0ombL<42ofmld0?oKI[[0_mmHZT2ofC?n@04
oiJ0^On5KK3oQFf`ohE]/0?oM5n/0_m[G;000on0K;?oMV6]ogIQ[@04ogMP[0?oO6N`0on5M[X3oiBA
c@;oVY?<1?n?Q/D3oh]o`P?oRh320on>Q<@4oi:9a`CoUi3:0onLU/d4oj2Kc`;oY9k?0_nW^>D5ojVi
i@;o[;SR0_nSe?T4ojKBm`;oZlkb0onMe_/2oj;Cn@?oUmGm1?nKeO`2oj;Cn@?oVM;k0_nPd_T2oiW?
nPCoW]3i0_nWcoD3oj3=m`;oYlgd0_nQboH5ojO<l`;o[LW_0_nWbO44ojc8kP03ojo5j_n[ankoZlO^
00;oZlO^0_n^aN/2oj_6k@Co[<C[0_n]`^T2oj_4k0CoZl;Z00?oZ/?/oj[2jonZ`^/00onZ`^/2oj[1
jP;oZL;[2onY`N/00ol0003oZL7[ojW1j`05ojW1j`ooZ<7[2?ooool00ol0003oooooooooo`0?oooo
o`008_ooool00ol0003oooooooooo`0_ooooo`CoV;_a0_nE`oH3oj?7l`;oXm7h1?nacNh2okCBl0;o
]l;S0onh`>000on`/MWo[J[DojfZe002ojfZe0?oZ:7?1?nRV<X3oi^>a@?oU8C01?n<O;`3ohEe^P;o
OW2i0omiK[/3og9``@?oKgc@1?m]V^/01?n[VlKoUX2ioiJ0^OnFP;T2ohE]/0?oM5n/0om[G;03ogIQ
[@?oMf2/0omlIk04ohEf^P03oiBAcOn_/=SoVY?<00;oVY?<0on?Q/D4oh]o`P?oRh320on>Q<@3oi:9
a`CoUi3:1?nLU/d2oj2Kc`;oYKKT1?nW^>D2ojVii@?oX]Gj1?nSe?T2ojKBm`?oVmOl0_nMe_/3oiKE
o@;oUmGm1_nGdO`2oiWBn`?oV<kk1?nIcoX2oik@n@?oVlci0_nPcOL2oig:m`CoXL_f0_nWc?<2oj?9
m0GoYlWa0_n/b>h3ojS8l0;oZlO^0_nXa^l4oj_6k@;o[<C[0_nZaNd4oj_4k003oj_2j_nZ`ncoZ/?/
00;oZ/?/0_nZ`^/2ojW3k0GoZL;[0_nY`N/2ojW2k0OoZL7[00Co0000ojW1jonY`N_oZL7[4OnX`N/0
0onX`>_oooooooooo`07ooooo`03o`000?oooooooooo00kooooo000Sooooo`03o`000?oooooooooo
02oooooo0_nH^o43oj>ok@;oXlOc0on^an`3ok7=kP;o]L?U1?ng`^<01?nh`>3o/;7Iok2afOn`/MT4
ojfZe0?oZ:7?0_nRV<X01?nFT<coSX[:ohj:b_n>R/X3ohN5bPCoP8?=0omiR=H3ogi`^@?oNFjk0_mb
L<44ofmld004offJjon[VlKoZi_6oj^KaP?oUX2i0on5KK03ogAO[0;oJeb`0omSI;h3ogMP[0CoO6N`
0_n5M[X3ojn`f0?oVY?<1?n?Q/D3oh]o`P?oRh320on>Q<@4oi:9a`CoUi3:0_nLU/d2oj:`hPCoYKKT
0_nW^>D7oj;EnP;oXmCi0onKf?d2oi_Go0?oV=Km0_nFeOd3oiWAn`GoUm7l0onIcOX2oiS>n`;oVl[h
1?nJboT2oi_<n@;oW<Wg1OnMb_L2oj7;mP;oWlSe1?nSbO@2ojO9l@?oY<Sb0_nXb?02ojK7l@GoZ<K_
0_n[a^d00onXa^ooZ/G]oj[5k@03oj[5k@;oZlC/0onYa>d2oj[3k0;oZL?]1?nY`n`2ojW2j`OoZL;/
0_nY`N/01_nY`^coZL7[ojW1jonY`N_o0000ojS1k17oZ<7[1?nX`>/8ooooo`03o`000?oooooooooo
00kooooo000Tooooo`03o`000?oooooooooo02oooooo0onS_nd2ojg1j@Go[/O/00?o/Lg^okG3iOne
`nD00_ne`nD2okO2h`;o/[OM1?n`/MT2ojfZe004oj:PdonLV<ooW9S?oibHc`CoUY3<0on>R/X3ohN5
bP?oP8?=0omiR=H4ofjEi`;oB:kh0ombL<42ofmld003ol6me_nGT<_oQgg100;oQgg10onFP;T3ohE]
/0?oM5n/0om[G;02of=T_P?oE8cY1?mlIk000on5M[[oamOVolOGiP03ojn`f0?oVY?<0on?Q/D3oh]o
`P?oRh321?n>Q<@3oi:9a`;oUi3:0_nNZMh5oj:`hP;oYKKT0_nSe?T6oj;EnP?oWMWl0_nKf?d3oi_F
o0;oV=Km0onLdOX2oiWAn`;oW/cg1OnKc?T2oiW=nP;oW<Wf1?nKb_P2oi[;n@?oW<Of0onLbOL2oig:
m`?oW/Oe1?nOb?D2oj?9m0?oX/Oc0_nTb?82oj?6lPCoY/Oa0_nXa^l2ojK6l0CoZ<K_0_nZaNd3ojS4
kP;oZLC]0_nXa>h5ojW3k@;oZL?/0_nX`nd6ojW2k0;oZ<;/1?nY`^`01OnY`N_oZ<7/ojS1k?l0003o
Z<7/00;oZ<7[0_nX`N`=ojS1j`CoZ<3[1oooool00ol0003oooooooooo`0>ooooo`009Oooool2o`00
033ooooo00?oXko]ojg1jOn]`NT00_n]`NT2ojk7k0?o]<?U0one`nD2ok>lh0Co/[OM0_n`/MT00onW
Z=OoXZ3Coj:Pd`02oj:Pd`?oW9S?0onFT<`3ohj:bP?oQhG:1?n0Pld3ogV8ePCoKYGW00GoB:kholg`
joo=g>CocMcTojZWe004oiN@b`;oQgg10omfK[`3ohE]/0?oM5n/0om[G;03of=T_P?oE8cY00?oN=jb
omGhh_oEn>800_o7enH01?nPY][oTY7?oi:AconBTLl3ohR5b@?oQh?81?n;Ol83oh^0`P;oSXC400?o
U9ODoiVPfOnIX=T00_nIX=T4oijYgP?oX[3R0_nTdOL4oj?Dn@;oX]Gj0onOf_`2oigIo0?oW]Ol0_nK
e_`3oioAn@;oW=7j0_nPboH4oik<m`;oVlci0onOb?D4oic9mP;oVl[h0onNa_@2oic7mP;oWlGc1?nN
a_@2oik7m@;oX<Gc1?nPa_<2oj;7l`;oX/Gb1OnSa_82ojK7l@;oY<Ga1?nVa_02ojS6k`?oYlG_0_nX
a>h2ojO4kPCoZ<C^0_nY`nd7ojS3k@;oZL;/1_nX`^`2ojW2k0?oZ<;/0_nX`N`00ol0003oZ<7/ojS1
k003ojS1k0coZ<7[1OnX`>/6ooooo`03o`000?oooooooooo00kooooo000Wooooo`03o`000?oooooo
oooo02kooooo0on]`NT3ok;2iPCo]<?U00?o]L?Uok>lh?nc_>000_nc_>02ok:gg@03oj^_fonWZ=Oo
YjSG00;oYjSG0onRX=<3oibHc`CoUY3<0on>R/X3ohN5bP?oP8?=1?miR=H2ofjEi`;ocO3[00?o^;gN
ojZWe?nZYm@00_nZYm@3oiN@b`?oQgg10_mfK[`3og9/_@CoM5n/0_m[G;04of=T_P05oeB<jOnSg_co
eOSRomGhh_nhaN@01?nPY]X3oi:Ac`?oR8G90_n7PlP4ohV7bP?oSXk>1?nDUm@4oiVPf@CoWZWN00?o
X[3RojCAmonTdOL00_nTdOL2oj?Dn@?oX][k0_nOf_`3oj7Hn`;oW]Ol0onQdOP2oioAn@;oX/_e1?nP
boH2oik<m`?oXLOc0_nOb?D2oj;5l@CoX<Gc0_nNa_@2oj74lPGoWlGc0_nNa_@2oj74lPCoX<Gc0_nP
a_<2oj74lPCoX/Gb0_nSa_82oj?5l@GoY<Ga0_nVa_02ojG4k`;oYlG_0_nVa>l5ojO4kP;oZ<C^0_nW
`nh8ojS3k@goZ<;/0onX`N`00ol0003oZ<7/ojS1k002ojS1k0goZ<7[1?nX`>/6ooooo`03o`000?oo
oooooooo00kooooo000Xooooo`03o`000?oooooooooo02kooooo00?o[L7Yok;2i_nb`^H00onb`^H2
okC3i@;o/koS0onc_>000on]]]ooZjoKoj^_f`02oj^_f`CoYjSG0onRX=<3oibHc`;oUY3<00CoSYkO
ohNOi?n7WnCoQioT1?n2Z>d5ogZinP04of_Anonomnko_oO^olg`j`?o^;gN0onZYm@3oiN@b`?oQgg1
0omfK[`2og9/_@?oM7K600CoM5n/of]L/?m[G;3oJeb`0_mSI;h2oj?No003omGhh_nhaNCo^<GT00;o
^<GT0onPY]X3oi:Ac`?oR8G90on7PlP3ohV7bPCoSXk>1?nDUm@2oiVPf@;oXLCa1?nSc?D2ojCAm`?o
Y=[j0_nRf_/3oj?InP;oXMSk0onTd_P2oj7An0;oY<_d1OnRboD2oj3;mP?oXlOb0_nQao<2oj?4l0Co
X/Ga0_nPaO<2oj;3l0CoXLCb0_nOaO<2oj;3l0GoXLCb0_nPaO<00onR`o7oXLCboj74lP03oj74lP;o
X/Gb0_nRa?44oj?5l@;oY<Ga0onTa?02ojG4k`;oYL?_1?nVa>l2ojO4kP;oY/?^1OnW`nh2ojS3k@;o
Yl?]1?nX`nd=ojS2k0;oZ<7/00?o0000ojS1k?nX`N`00onX`N`;ojS1j`KoZ<3[1Oooool00ol0003o
ooooooooo`0>ooooo`00:Oooool00ol0003oooooooooo`0_ooooo`;o//;V0onc`^H4ok>oh`04ok>l
h?n]]]oo[KKOojffg`CoZjoK0_nWZ=L01?nNZ]ooVJGMoiVUgOnIYMd4oi>Pg@?oSYkO0on7Wn@4oh:X
k@;oN[Wj00CoTo7Rokogk_nomnko_oO^0_nnc^H4okRmgP?oZZOD0onGT</2ohMm`@?oMVjl0ombK;d3
ogAfaPGoPiWO00CoXmklol[Uj_o:iN[ob^GZ0onhaN@4oj2VfP?oTY7?0_n8QLT3ohN3b0CoRHO:1?n>
S/h2oiBGe0;oWKW/1?nQa?42oj?<m@?oY]Si0_nTf_X3ojKJnP;oXmWj0onVdoL2ojCBn0;oY/cd1?nT
bo@2oj;;m@?oY<Ob0_nSao82ojG4l0GoXlC`0_nRaO42ojC3k`CoX/?`0_nQa?82oj?2k`CoX/?`0_nQ
a?82oj;3l0CoX/?a0_nQa?83oj?3l0CoX/Ca0_nSaO43ojC3l0;oY<C`1_nU`nl2ojK4k`KoY/?^0_nW
`nh7ojO3k@;oZ<?]0_nW`^d2ojS2k0;oYl;/1onX`^`4ojS1k003o`000?nX`NcoZ<7/00?oZ<7/2?nX
`N/9ojS0j`Cooooo00?o0000ooooooooool03_ooool002[ooooo0_l0000aooooo`Co/l;V0_nc_n<2
ojnlh`Co[KKO0_n[[m/00onS/>7oWZ[OoijZg`02oijZg`?oVJGM1?nCX=d3ohjNg`?oQioT0_n2Z>d0
1?mMe>OoTo7Rok?dl_ncm?82ol3Hj`Co_/kV0_nh_Mh01?nOV<goTHW7oi69aonARLL3oh5ka0?oMWO6
0_mfK[`3og9/_@CoM7K60on3VMl01Oo5o/cob^GZol[Uj_o:iN[o[;;L00?oVicD1?n;S<h3ohF6c@?o
Q8S?0on7PlP3ohV7bP;oSXk>0_nFZnD5oifik0;oXLCa0onWe?P2ojKHn@?oZ=_i0_nVf_X3ojSDm`;o
Y]?g0_nWcO<4ojK<m0;oY<_d0onUao42ojC7lP;oY/C_1?nUa?02oj?4l0;oYL?^1OnT`nl2oj;3l0;o
Y<;^1?nS`^l2oj;3l0?oXl;_0onR`o02oj;3l@?oXl;_0_nS`o02ojC2k`CoXl?_0_nT`o02ojC2k`Oo
YL?_00?oYL?^ojK3k_nV`nh01onV`nh6ojO3k@OoYl;]1?nW`^`2ojS2k0WoZ<7/00?o0000ojS1k?nX
`N`00onX`N`8ojS1j`WoZ<3[0oooool00ol0003oooooooooo`0>ooooo`00;?ooool00ol0003ooooo
ooooo`0_ooooo`;o/l;V0_n_`^L4ojnlh`;o[KKO00?oY[KToj>`hOnS/>400_nS/>44oijZg`?oVJGM
0_nCX=d2ohbjm0CoQ/Cl0_mhd?l01?nDk?Go/oCbok?dl_ncm?84ol3Hj`;o_/kV00?oZZODoinHcOnO
V<d00_nOV<d3oi69a`?oPG_40_mfMlH3ofYkd@;oLVbm1?mdM/H00on3VMooXo?0olofj002olofj004
ol[Uj_n//]co[;;Lojbbg0?oVicD0on;S<h4ohF6c@;oQ8S?0on7T=D4ohnMg@CoUZ_U0_nM^N`4ojK>
m@;oYmCh0onYfoT2ojSKn@?oZMKg0_nXe?L2ojW>l`CoYlgc0_nVc?@3ojK7l@;oYLOa1_nVa>l2ojG4
l0;oY/;^1?nU`nh2ojC3k`?oYL;^1?nT`^h2oj?2k`;oY<;^0_nS`^l2ojG1kPGoY<;^0_nS`^l2ojC1
kPCoY<;_0_nS`nl2ojC2kPCoY<;_0_nU`nl2ojG2kPCoYL?^0_nV`nh2ojK2kPGoY/?^0_nW`nd;ojO2
k@;oYl;/0_nW`N`;ojS1k003o`000?nX`NcoZ<7/00;oZ<7/1onX`N/;ojS0j`?ooooo00?o0000oooo
ooooool03Oooool002gooooo00?o0000ooooooooool0;oooool4ojo2i`;o[kcS0_nX^nL3ojJfi0Co
Xk3Q0_nNZ]l2oiNek0?oTkK_1?n<^_@2ohK4o0;oTn7n0onXk_P3ok_Ll0;o`=S[00?o/[KKojZWe?nZ
Ym@00_nZYm@3oinHc@?oTHW70on1Nl@3ogIgaP?oJW_A0_mXX?42ogAfaP03ofCGjonYm/CocoKX00;o
coKX0_o0c>@3ojbbg0?oVicD1?n;S<h3ohF6c@?oQ8S?0on7T=D4ohnMg@;oUZ_U0onRa?42ojK>m@?o
Z]Wh0_nYfoT3oj_Gm`;oZMKg0_nZco<5ojW>l`;oYlgc0_nWb?02ojK7l@;oYlC^1onVa>l6ojK2kP;o
YL?^0onV`Nd2ojG2kP;oY/7]1?nU`Nd2ojC2kP;oYL7]1?nU`Nh2ojC2kP;oYL7]1OnT`Nh2ojC2k`03
ojG1k_nT`^koY<;^00?oY<;^0_nT`^l6ojG2kP;oYL?^1_nV`^h2ojK3kP?oY/;]2_nW`^d7ojO1k0;o
Z<7/00?oYl7/ojS1k?nX`N`01OnX`N`00ol0003oZ<7/ojS1k003ojS1k0GoZ<7[3?nX`>/3ooooo`03
o`000?oooooooooo00gooooo000^ooooo`03o`000?oooooooooo02oooooo0_n_`^L2ojW0j`CoZ;_W
0onV]^@2oj>`h@;oW;K[1?nG]N`3oi>fk`;oS;[d0_nDe?h3oj;To003ojS^n?nkg?3o^mc`00;o^mc`
00?o]/3Rok:ffonb]]/00_nb]]/4ojZWe0?oWiS=0onARLL2oh5ka0?oMWO61?mZNm42ofRPl@05oj;b
lOnRm]cob__Vol[ki_o;hnT01?o0c>@3ojbbg0?oVicD0on;S<h4ohF6c@?oQ8S?0on7T=D2ohnMg@;o
W;S/0onRa?42ojWEm`?oZ]Wh0on/f?H2oj_Gm`;o[=7c1?nZco<2ojW>l`?oZ<Wa0_nWb?02ojS5kPCo
YlC^0_nVa>l2ojO2k@OoY/;^1OnV`Nd00onV`NcoY/7]ojK1k@03ojK1k@;oYL7]0_nV`N`4ojG1k@;o
YL7^1_nU`Nd2ojC1kP;oYL7]1?nU`Nh2ojC2kP;oYL7]1onU`^h2ojK1k@KoY/;^1OnV`^d2ojK1k@Ko
Yl;]3_nW`N`2ojS1k0;oYl7/0onX`N`00ol0003oZ<7/ojS1k003ojS1k0;oZ<7[3onX`>/2ooooo`03
o`000?oooooooooo00gooooo000_ooooo`03o`000?oooooooooo02oooooo1?nY`>/2ojRki`;oXKc/
0onO^N/4oibfj`;oUkG/0_nGa?H4oiK;nP04oiCDo_nRi?coX^Cloj;To0?o]]_c00?o^mc`okK0h_nf
`>800_nf`>84ok:ff`;oZZOD00CoVIcEohfBdon=T]?oSI;C0on5SM<3ogb=f@?oMWO60_mZNm42oiK9
n@;oX_KL0_o:nnH3ol_Sj@;o`<cT00CoYk3NoiJMfOnFWMWoUYgI0on<T]@3ohF=e0CoQY7G1?n<Vmd3
oi>Xi0CoW;S/00?oX/CaojWEmonYeOL00_nYeOL01?nZfOSo[=SfojcHm_n/f?H2ojgCm0Co[=7c0_nZ
co<3oj[:l@;oZ<Wa1_nXaNh2ojO4kPKoYl;]0_nV`^h3ojO1k0;oY/7]0_nW`N`4ojK1k0;oY/7]1onV
`N`2ojG1k@;oY/7/1_nU`Nd2ojK1k@CoYL7]0_nU`Nh6ojG1k@;oYL;^1onV`Nd2ojK2kP;oY/7]0_nV
`^d7ojK1k@;oYl;]5_nW`N`2ojS1k003ojO1k?l0003oYl7/00;oZ<7/0_nW`>/6ojS0j`;oYl3[1_nX
`>/2ojO0j`;ooooo00?o0000ooooooooool03Oooool0033ooooo0_l0000`ooooo`;oZL3[0_nR_^d4
oj6lk0?oWkW[0_nL]^/3oi[0lP?oUlCf0_nFboX2oioKo0?o[mOe0_nffo<2okK7i`Co]/3R0_nb]]/2
oj:Wf@?oVIcE1?n=T]<3ohF=d`?oO8gI1?n2XNL00onFbOWoX_KLoj;fg002ol[kiP?obn?Y0_nfa>D3
ojN`gP?oUYgI0on<T]@3ohF=e0CoQY7G1?n<Vmd3oi>Xi0;oW;S/0onVc_D2ojWEm`?o[MOf00?o[=Sf
ojgCm?n]do@00_n]do@2ojcAl`?oZlca0_nZb_42ojW6k`KoZ<G^0_nX`nd6ojO2k@_oYl7/0_nV`N`2
ojO0k0KoY/7/0_nV`>`5ojK1k0;oYL7]00?oY/3/ojK1kOnV`Nd00onV`Nd2ojG1k@;oY/7]1_nU`Nd=
ojK1k@;oY/7/1_nV`NdMojO1k003o`000?nW`>coYl3[00CoYl3[0_nX`>/6ojO0j`;oZ<3[1_nW`>/0
0ooooooo0000ooooo`0>ooooo`00<_ooool00ol0003oooooooooo`0^ooooo`CoX[k]0_nQ_>`2oifn
k`CoW;k`0_nJ`?82oig;m`CoWM7j00CoWm_lojoGmOn_eoGo[mOe0_ncb^/4okK7i`;o]/3R0_nY/=d4
oj:Wf@?oVIcE0on=T]<3ohF=d`CoO8gI0_n2XNL2oi7Vn`;o^_K`0_o8knd2okoDj@Co]/CU0onW/=h3
oiJMf@?oS9;D0on5SM@3ohJAe`;oS9_M0_nG]N`5oio3lP;oY/ke0on/eOH2ojgGmP?o[]Cd0_n]do@3
ojc>l@;oZlca00?oZ/O_ojW6konYa^l00onYa^l2ojS5kPKoZ<?]0_nW`^d=ojO1k0KoYl3/0_nV`N`2
ojO0k0CoY/3/0_nV`N`6ojK0k0;oY/7]0_nV`>`5ojK1k@;oYL7]0_nV`N`2ojK1k@;oY/7/1onV`Nd6
ojK1k0;oY/7]7OnW`N`4ojO0k003o`000?nW`>coYl3[01?oYl3[00?oooooo`000?ooool03_ooool0
03?ooooo00?o0000ooooooooool0;_ooool2oj:nk@;oWkk^1?nM_^l2oibnl0;oWLGd1?nMboL2oigA
nP?oZ]7d00?o[mOeok?:joncb^/00_ncb^/2okK7i`;o[[SQ1?nY/=d3oj:Wf@?oVIcE1?n=T]<3ohF=
d`;oO8gI0on8`_X00onAi__o^_K`ok[fl002olS_k@Co_mCY0_nfa>D01?nS[=goUioJoiNOf_nGWmX3
ohbFf0?oQiGJ0on8V]h4ohjVi@CoUkG/0_nO`o83ojS?m0;o[=Gf0on^eO@2ojkDm0?o[]3b0_n/c_42
oj_9k`CoZ/O_0_nYa^l2ojS4k@OoZ<?]0onW`^`:ojO1k0koYl3/0_nV`>`2ojO0k0coY/3/0_nV`Nd3
ojK0k0;oY/7/0_nV`>`4ojK1k0;oY/7]0_nV`>`6ojK1k1koYl7/2?nW`>`00ol0003oYl3[ojO0j`0C
ojO0j`03o`000?oooooooooo00gooooo000dooooo`03o`000?oooooooooo02kooooo1?nO_^h2oifn
k`;oW/7a1?nMaO@2oig;m`?oYlcc0_nZdO@3ok3:k@;o/l[[0_n__N@4ojjhh@;oZK3M00CoX:OKoiRQ
fonHXM_oV:7K1?nAWM`3ohNLh@GoQJS/0_n8`_X2ojoWn@;o`O3a00?o`mo]okoDjOnoe>T00_noe>T0
0on`^n;oXjcMoj>/g@02oj>/g@?oUioJ0on<U]P3ohNEfP?oR9[N1?n>Y^D2oiNek0?oXlKb0_nXco@3
ojgDm0;o[]Gd0_n^dO83ojk@lP;o[<_`1?n[bNl2oj[7k`;oZLG]1?nXa>d2ojS3k@?oZ<;/0_nW`^`8
ojO1k1OoYl3/0_nV`>`3ojO0k0GoY/3/0onW`>`2ojK0k0;oYl3/1?nV`>`2ojK1k0;oYl3/1?nV`>`2
ojK1k0;oYl3/6onW`N`8ojO0k0GoYl3[00?o0000ojO0jonW`>/04OnW`>/00ooooooo0000ooooo`0>
ooooo`00=Oooool2o`0002oooooo0_nO_^h3oj2nkP?oW/7a0_nMaO@3ojG7l@;oYlcc0on]b>h2ok3:
k@;o[l3V1?n__N@2ojjhh@03ojF^g_nPYm_oX:OK00;oX:OK0onHXM/4oi6Mg0?oQicQ0_n5Z>`4oig@
n@03ojoWnOo1l?7o`mo]00?o`mo]00?o_mCYok2kh_n`^n800_n`^n84oj>/g@?oUioJ0on<U]P3ohNE
fP?oR9[N0_n>Y^D2oiZjkP?oXlKb0_nZd?@3ojgDm0;o[m;b1?n^dO800on^d?;o[<_`ojc;l002ojc;
l0;oZlW_0_nZa^h4ojW5k@;oZ<C]1OnX`^`2ojS1k0KoYl7/2?nW`>`2ojO0j`KoYl3/0_nW`>/;ojO0
k0;oYl3[3OnW`>`2ojK0k0KoYl3/0_nV`>`6ojO0k0;oYl7/0_nW`>`CojO1k0[oYl3/1_nW`>/00ol0
003oYl3[ojO0j`0=ojO0j`Kooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000oooooooo
ool0;_ooool2oj2nkP;oY;o]1?nT`nl2ojG7l@;oZlK]0on]b>h2ojk2j0Co[l3V0_n__N@00onY/n3o
YJkNojF^gP02ojF^gPCoX:OK0onHXM/2oi6Mg0;oTk7[1?nD^o82oig@n@;o/>Sh0onlhO82ol?Ok@;o
^<WW1?n`^n82oj>/g@;oV:CN0onAWmd3ohbMg`CoSJ?S1?nC[NP3oiZjkP03oj?6l_nZd?CoZ]3d00;o
Z]3d00?o[MCdojoBl_n_d_800_n_d_82ojkAlP?o[/g`0_n/bo02oj_7kPCoZ/K^0_nYaNd3ojW3k0;o
Z<;/1_nX`N`2ojO1k0SoYl3/1_nW`>/2ojO0k0KoYl3[0_nW`>`3ojO0j`;oYl3/1_nW`>/2ojO0k0;o
Yl3[7OnW`>`2ojO1k003ojO0k?nW`NcoYl7/00GoYl7/0onW`>`2ojO1k0koYl3/1_nW`>/00ol0003o
Yl3[ojO0j`09ojO0j`Wooooo00?o0000ooooooooool03?ooool003Sooooo00?o0000ooooooooool0
;_ooool4ojBok@;oY<?_0_nY`n`4oj_6k@03ojg8k_n^`^So[/;X00;o[/;X0_n_`>H2ojbhh`?oZK?P
1?nU[]h2oj2Wf`03oi^]i?nE[>KoUJcV00;oUJcV1?nC/N/2oiBklP?oY=Wj00Co/>ShokcQl_nlhO;o
_>7b0_njd^/4okS9i`;o/;_R0_nS[n04oiRTgP?oTIoM0on<WMl4ohfSh`;oTjgX0_nM__04ojC8l`;o
Z]3d0on]dO<2ojoBlP?o[/ka0_n^cO02ojc9k`CoZlO^0_nZa^h3ojW4k@;oZL?/0_nX`^`6ojS1k0;o
Yl7/1_nW`>`SojO0j`;oYl3/0_nW`>/LojO0k0;oYl7/3OnW`>`2ojO0j`KoYl3/2OnW`>/00ol0003o
Yl3[ojO0j`05ojO0j`cooooo00?o0000ooooooooool03?ooool003Wooooo00?o0000ooooooooool0
;_ooool2ojBok@;oZ<3[1?nY`n`2oj_6k@?o[L;Y0_n^`^P2ojbli@Co[;SS0onY/n02ojF^gP;oWjoS
0onK[N@4oiF/iP;oTk7[0onLb_L2ojCInP?o]Mgd00?o_>7bok[Bjonjd^/00_njd^/2okS9i`;oZkWS
1?nS[n03oiRTgP?oTIoM1?n<WMl2ohfSh`03oiFck?nM__3oWKk`00?oWKk`0_nTb?<3oj[=l`;o[M7c
0on^co42ojk>l@03ojg;kon/bNoo[<W_00?o[<W_0_n[anh2oj[5k@;oZLC]0_nY`^`5ojS2k0?oZ<7/
1OnW`N`2ojO0k2_oYl3[0_nW`>`2ojO0jb?oYl3/1_nW`>/2ojO0k0goYl3[00?o0000ojO0jonW`>/0
4?ooool00ol0003oooooooooo`0<ooooo`00>_ooool2o`0002oooooo1?nX`>/2ojW3k0?o[<7Y0_n]
`^T2ojbni`Co[;cU0_n/^><00onV]nCoXk?Soj>ch`02oj>ch`CoWjoS0onK[N@2oiF/iP?oVKkb0_nL
b_L3oj_EmP;o]Mgd0onie^l2ok[Bj`;o/L;W1?n[^N<2oj>_h004oi^Yh?nCY>7oTjCQoi>Th@CoT:GS
0onAZ^L4oiFck0;oWKk`0onUb?82oj[=l`?o[Lob0_n^co42ojk<l0Co[L__0_n/bNl3oj_6k@;oZ/G]
0_nY`n`4ojW2k0;oZ<;/1_nX`N`2ojO1k3CoYl3[0_nW`>`00onW`>_oYl3/ojO0k009ojO0k0;oYl3[
1_nW`>`2ojO0j`OoYl3/6?nW`>/00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo
000looooo`03o`000?oooooooooo02gooooo0_nX`>/2oj_1j@?o[<7Y0_n/`>P4ojbni`;o[;cU0_nX
^^H3ojJgi0CoXk?S0_nO[n<2oiffjPCoVkW]0_nI__83ojC<m0;oZmGf0onbe_82okWFk`;o]<WZ1?na
`^L2oj^ih`;oXZoR0onKZN03oi>Th@CoT:GS0onAZ^L2oiFck0?oW[o`0_nUb?82oj[<lP?o[Lob0_n]
cO04ojk<l0;o[L__0on/anh2oj_6k@;oZ/C]1?nY`n`2ojW2k0SoZ<7/0_nX`>/iojO0j`;oYl3/0onW
`>/2ojO0k0KoYl3[0_nW`>`6ojO0j`;oYl3/6?nW`>/5ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool03?ooool003gooooo00?o0000ooooooooool0;Oooool4oj_1j@03ojc1jOn/`>So
[<3X00;o[<3X0_n/_^L2ojZli`CoZ;[V0onV]n@2oj>ch`;oXKOX1?nM]^X2oi^ik@;oXLGb0onTc?@2
ojgBl`?o/]Kb0_nccNd4okC9jP;o/L;W0_nY]n<4oj:_hP?oVjWP0onCY>42oi2Uh`;oUK3Y1?nI]n`2
oijol0;oYLOa1?nZc?800on]co;o[Lg`ojg=l002ojg=l0;o[/c`0on]bNh2ojc7kP;oZlG]1?nZa>d2
ojW3k0;oZ<;/1_nX`N`3ojS1j`?oZ<3[I?nW`>/9ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03?ooool003kooooo00?o0000ooooooooool0;Oooool2oj_1j@?o[<7Y0_n/`>P2ojZo
j0CoZ[cW0_nX^^H2ojFjj0?oXkSX1?nQ]nP2oiffjP;oX<3_1?nQaO800onTc?Co[M;cojgBl`02ojgB
l`03ok;Fl_nccNgo/lg]00;o/lg]0_ndbNX2ojjniPCoZKOS0_nR[n800onM[^CoV:cToiR/i002oiR/
i0?oUJcV1?nE/>T2oiVgk0;oX<7`1?nUao42oj[<lP?o[<ca0_n]cO03ojg:k`;o[LW^0_n[a^d4oj_5
k@;oZ/C]0_nY`n`4ojS2k0GoZ<7/0_nX`N/00onX`>_oYl3[ojO0j`1NojO0ja3ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0<ooooo`00?oooool2o`0002oooooo0_n/`NT2oj[1jPCo
Z[oX0_nZ_>L2ojNlj@CoYK[X0onS^>P2oj6gj0?oXKk]0onP`>l2oj75lP?oYlgc0_n]d_<3ok3=k`;o
/lg]0_n_`nP4ojjniP;oZKOS0_nS/n@3oif^i0CoV:cT0onE[>H2oiF`j@;oVk[^1?nP`O02ojG7l@?o
ZLWa0_n/c?42ojc;l0?o[L[_0_n/b>h4oj_6k@;oZlG]0_nZ`n`4ojW3k0;oZ<;/1OnX`N`5ojS0jeco
Yl3[5?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo0011ooooo`03o`00
0?oooooooooo02gooooo1?nZ`NX2ojZoj0;oZ;kZ1?nW_>T2ojFjj0;oY;g[1?nR_N`2oj6nk@;oXlC`
1?nTb?82ojO=l`?o[<c`0_n`cNl2ok36j`Co[l?X0_n^_^H2ojNhi@CoXk?T0onM[^@2oiR/i0;oVK7X
1?nI]>/3oi^jkP;oX<7`0onUa_02ojW9l@;oZl[`1?n/bo000on]b^oo[<S^ojc8kP02ojc8kP;oZlK]
00?oZ/C]oj[3k?nZ`n`00onZ`n`2ojW3k0;oZ<;/0_nX`N`2ojS1j`KoZ<3[F_nW`>/Hooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool02oooool004;ooooo00?o0000ooooooooool0;Ooo
ool2oj[1jP;oZ<3[1?nX_^X2ojNlj@;oYKk[1?nT_N/2oj:mk0;oXl;_1?nSa?02ojC8lP?oZLW`0_n/
c?02ojk7k@Co/<K[0_n_`nP2ojZliPCoYkSU0_nS/n@00onO/^GoVk3Voi^`iP02oi^`iPCoVK7X0_nI
]>/00onN_>goXL7_oj71k`03oj71k`;oYLK`00?oZ<S`oj_:l?n[b_000on[b_02ojc;l0Co[<S^0_n[
a^d4oj[4k@;oZ/?/0onY`^`2ojS2k0;oZ<7/1?nX`N/4ojS0jeOoYl3[7Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00_ooooo0013ooooo`03o`000?oooooooooo02gooooo1?nX`>/2
ojRnjPKoYKk[0_nT_N/2oj?0kPCoXl;_0_nSa?03ojO6l0;oZLW`0_n/anh4ojk7k@;o/<K[0_n/`>P4
ojZliP;oYkSU00?oXkGUoinbiOnO/^D00_nO/^D4oi^`iP;oVK7X00?oW;S[oijlkOnN_>d00_nN_>d2
oj71k`;oYLG`1?nXb?02oj_:l0?oZlW_0_n/b>h2oj_6kPCoZlK]0_nZa>d3ojW3k0;oZL;/0_nX`^`4
ojS1k0;oZ<7[1_nX`>]CojO0jb3ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`00A?ooool00ol0003oooooooooo`0]ooooo`;oZ<3[0_nV_n`6ojFnj`;oY;o]1?nS`>h2oj?2
k`?oY/C_0_nWa_02ojW6kPCo[<O^0_n^and2ojc2jPCo[<3X0_nZ_>H00onV^>KoXkGUoj>ei@02oj>e
i@;oWk;U0_nN]NP3oibej@CoW;S[0_nN_>d2oj;1k`CoYLG`0_nXb?03oj[8k`;oZlW_0_n[anh4oj_6
kP;oZlK]0onZa>d2ojW3k0;oZL;/1?nX`^`2ojS1k0;oZ<7[1_nX`>]AojO0jbCooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`00AOooool2o`0002oooooo0onV_n`2ojFnj`Ko
Y;o]0_nS`>h3ojG2kP;oY/C_0_nXa>h4ojW6kP;o[<O^0_n/`n/4ojc2jP;o[<3X00?oZ;_WojJhi_nV
^>H00_nV^>H2oj>ei@;oXKKW1?nN]NP3oibej@;oW;S[0_nP_Nh4oj;1k`;oYLG`0onXa^l2oj[8k`;o
Z/O^1?n[anh2oj_6kP?oZ/G]0_nZa>d2ojW3k0CoZL;/0_nX`^`2ojS1k0CoZ<7[0onX`>]?ojO0jbWo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`00Aoooool00ol0003ooooo
ooooo`0]ooooo`CoYKo/0_nT_nd2ojG0k@CoYL7]0_nU`^h2ojO3kPCoZ<C^0_nYa^h2oj_3k0Co[<?[
0_n/`^X2ojZmj0?oZ;_W0_nV^>H2ojBhi`CoXKKW0_nN]NP2oinijPCoWk[/0onP_Nh2oj;1k`?oYLC_
0_nXa^l2ojW6k`CoZ/O^0_n[anh3oj_5k@;oZ/G]1_nY`n`2ojW2k0KoZ<7/0_nX`N/5ojS0jd_oYl3[
;?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo0018ooooo`03o`000?oo
oooooooo02gooooo1?nU_n`4ojG0k@;oYL7]0_nV`^d4ojO3kP;oZ<C^0_nY`n`4oj_3k0;o[<?[0_nZ
_nT2ojZmj0;oYk_X1?nV^^L3ojBhi`;oXKKW0_nQ^>T4oinijP;oWk[/0_nR_^d4oj?1kP;oYLC_0_nW
aNl4ojW6k`;oZ/O^0onZa^h2oj_5k@03oj[4kOnY`ncoZL?/00GoZL?/00?oZL;/ojS1k?nX`N`01?nX
`N`3ojS1j`CoZ<3[B_nW`>/`ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02ooo
ool004Wooooo00?o0000ooooooooool0;Oooool4ojFok0;oYL3]0_nV`N`4ojK2k@;oYl?^0onX`^`3
ojW3k0;oZl?/0_nZ`>X2ojZoj@;oZ;gX1?nW^nP2ojJji`;oY;WX0onR^>P4oj6hj@;oWkWZ0_nQ_>`4
oj:nk@;oXl7^0_nU`nl4ojO5k`;oZLK_0onYa^h2oj[6kP03oj[5kOnZa>goZ/C]00;oZ/C]0_nY`n`6
ojW2k0;oZ<7/1OnX`N/6ojS0jdKoYl3[=?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo001:ooooo`;o0000;_ooool2ojFok0;oY[o/1?nV`N`2ojK2k@?oZ<7/0_nX`^`5ojW1
j`;oZ/3Z0_nY_^T4ojRmj0;oYk_X0_nV^nP4ojBij0?oX[SX0_nQ^>T2oj6kj`CoXKc/0_nR_^d2ojC1
kPCoYL?_0_nWaNl3ojS5kP;oZLK^00?oZLG]oj[5kOnZaNd00_nZaNd2oj[4k@?oZL?/0_nY`^`2ojS2
k0CoZ<7/1?nX`N/6ojS0jd?oYl3[>Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00[ooooo001<ooooo`03o`000?oooooooooo02cooooo1?nV_n`2ojK1k0?oYl7/0_nX`N`00onX`N_o
ZL7[ojW1j`04ojW1j`;oZKoZ1?nY_^T2ojRmj0;oYkcX1?nV^nP2ojBij0;oXk_Z1?nR^nX3oj6kj`;o
XKc/0onS_nd3ojC1kP;oYL?_0_nWa>h2ojS5kP;oZLG^1?nYaNd2oj[5k@?oZL?]0_nY`n`2ojW2k0Co
Z<;/0_nX`N`6ojS1j`?oZ<3[@_nW`>/looooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02_ooool004gooooo00?o0000ooooooooool0;?ooool2ojJok0?oYl3[0_nW`N`00onX`>_oZ<7[
ojS1j`02ojS1j`;oZL7[0_nY`>X4ojVojP;oZKkY0_nX_NT4ojNlj0;oY[_X0_nU^nT4oj>kjP;oX[_Z
0_nS_N`4oj>nk0;oXko]00?oYL7^ojK3k_nV`nh00_nV`nh2ojO4kP;oZ<C^1?nYaNh2ojW5k@?oZLC]
0_nY`nd2ojW3k0CoZL;/0_nX`^`2ojS1k0KoZ<7[1OnX`>/kojO0jd?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0:ooooo`00C_ooool00ol0003oooooooooo`0]ooooo`;oYl3[1OnX
`>/2ojS1j`;oZL3[1?nY`>X2ojVojP;oZ;kY1?nX_NT2ojNlj0;oY[cY1?nU^nT2oj>kjP;oY;c[1?nS
_N`2oj>nk003ojC0kOnU`NkoYL7^00;oYL7^0_nV`nh2ojO3kPCoZ<C^0_nYaNh5ojW4k@KoZL?/0_nY
`^`2ojS2k0CoZ<7/0onX`N/6ojS0jcWoYl3[Aoooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00[ooooo001?ooooo`;o0000;_ooool7ojS0j`CoZL3[0_nY`>X2ojRojPCoZ;kY0_nX_NT2
ojJmj@CoY[cY0_nU^nT2ojBmj`CoY;c[0_nS_N`00onT_ngoY<3]ojC0k@02ojC0k@;oYL7^0_nV`^h4
ojO3kP;oZ<C^0onXa>d2ojW4k@;oZL?]1_nY`n`6ojS2k0;oZ<7/1OnX`N/5ojS0jcGoYl3[C?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo001Aooooo`03o`000?oooooooooo
02cooooo1onX`>/2ojW0j`KoZ;oZ0_nX_^T3ojNnjP?oY[gY0_nV_>T3ojFmjP?oY;g[0_nT_>/00onT
_^coY;o]ojBok@02ojBok@;oY<3]0onU`Nd3ojK2kP;oYl?^0onW`nd2ojS4k@;oZ<?]1?nY`nd2ojW3
k0OoZ<;/0onX`N`4ojS1j`KoZ<3[<onW`>]?ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02_ooool005;ooooo00?o0000ooooooooool0:oooool9ojS0j`CoZ;oZ1_nW_^X2ojJnjPCo
Y[gZ0_nU_NX00onU_^_oYKk/ojFnk002ojFnk0?oY;k/0_nT_nd5ojG1k@;oY/;]1_nW`nd6ojS3k@;o
ZL?]1onX`^`5ojS1k0KoZ<7[1?nX`>/aojO0je?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0:ooooo`00Doooool00ol0003oooooooooo`0[ooooo`OoZ<3[0_nX_n/4ojRojPCoYkkZ
1?nV_^X2ojJmjPGoYKk[0_nU_^`2ojFok0CoYL3]0_nU`Nd2ojK1k@CoY/;]1?nW`nd6ojS3k@[oZ<;/
1?nX`N`6ojS1j`KoZ<3[;OnW`>]Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2Oooool005Cooooo0_l0000]ooooo`CoZ<3[1?nX_n/2ojRojP;oYko[1?nW_^X2ojJnjP03ojJnjonU
_^_oYKk[00CoYKk[1_nU_n`2ojG0k@;oYL7]1?nV`Nd2ojK2k@;oYl;]1?nW`nd2ojS3k@;oZ<;]2_nX
`^`6ojS1k0;oZ<7[1onX`>//ojO0je[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`09ooooo`00E_ooool00ol0003oooooooooo`0[ooooo`CoZ<3[0_nX_n/6ojNoj`;oYkkZ0_nV_n/3
ojJnj`;oYKk[2?nU_n`2ojG0k@CoYL7]0_nV`Nd3ojK2k@?oYl;]0_nW`nd4ojS2k@SoZ<;/2?nX`N`2
ojS1j`GoZ<3[;?nW`>]Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool0
05Oooooo00?o0000ooooooooool0:oooool2ojS0j`;oYl3[1_nW_n/6ojJoj`04ojJnjonV_n_oY[o[
ojJoj`GoYKo/0onU`>`3ojG0k@;oYL7]0onV`Nd2ojK2k@GoYl;]0_nX`^d8ojS2k0[oZ<7/0_nX`N/6
ojS0jbGoYl3[I_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo001Hoooo
o`03o`000?oooooooooo02cooooo0onW`>/5ojNoj`WoY[o[1_nV_n`2ojG0k0;oY/3/1onV`Nd6ojO2
k@;oYl;/2OnX`^`9ojS1k0;oZ<7[1_nX`>/SojO0jf[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`00FOooool00ol0003oooooooooo`0/ooooo`CoYl3[0_nW_n/7ojJoj`SoY[o/1_nV`>`7ojK1
k@GoYl;]0onW`^`7ojS2k0OoZ<7/1_nX`N/2ojS0jb?oYl3[KOooool01Ol0003ooooooooooooooooo
000000_ooooo001Jooooo`;o0000;Oooool2ojO0j`;oY[o/1OnV_n/8ojJok0SoY/3/00?oY/7/ojK1
kOnV`Nd01?nV`Nd3ojO1k0;oYl;]1_nW`N`2ojS2k0WoZ<7/1_nX`N/2ojS0jb7oYl3[LOooool01?l0
003oooooooooool0000;ooooo`00G?ooool00ol0003oooooooooo`0[ooooo`CoY[o/00?oY[o[ojJo
k?nV_n`01_nV_n`:ojK0k0?oY/7/0_nV`Nd>ojO1k0coZ<7/0_nX`N/6ojS0jagoYl3[MOooool00ol0
003oooooo`00000;ooooo`00GOooool00ol0003oooooooooo`0[ooooo`coY[o/2OnV`>`6ojK1k0oo
Yl7/2_nX`N`3ojS1j`;oZ<3[7_nW`>]hooooo`04o`000?ooooooooooo`0000[ooooo001Nooooo`03
o`000?oooooooooo02_ooooo2_nV_n`9ojK0k0KoY/7/4_nW`N`2ojS1k0;oYl7/1?nX`N`2ojS1jako
Yl3[O?ooool00ol0003oooooo`00000:ooooo`00Goooool2o`0002cooooo1_nV_n`=ojK0k0;oY/7/
6_nW`N`2ojS1k1_oYl3[Poooool2o`0000[ooooo001Qooooo`03o`000?oooooooooo02[ooooo1OnV
_n`?ojK0k1WoYl7/6onW`>^5ooooo`?o00002_ooool006;ooooo00?o0000ooooooooool0:oooool4
ojJok0goY/3/0_nW`>`EojO1k0;oYl3/6OnW`>^4ooooo`Co00003Oooool006?ooooo00?o0000oooo
ooooool0:oooool4ojJok0WoY/3/1_nW`>`2ojO1k0;oYl3/3OnW`N`4ojO0k1OoYl3[Poooool4o`00
017ooooo001Tooooo`;o0000;?ooool3ojJok0KoY/3/3_nW`>`6ojO1k0OoYl3/5onW`>^3ooooo`?o
00005Oooool006Kooooo00?o0000ooooooooool0:oooool2ojJok0;oY/3/4_nW`>`2ojO1k0SoYl3/
4onW`>^5ooooo`Co00006?ooool006Oooooo00?o0000ooooooooool0:_oooolOojO0k17oYl3[Q?oo
ool4o`0001cooooo001Xooooo`03o`000?oooooooooo02[ooooo0_nW`>`2ojO0jaWoYl3/3onW`>^3
ooooo`Co00008?ooool006Wooooo0_l0000/ooooo`?oYl3[0_nW`>`3ojO0j`03ojO0k?nW`>_oYl3[
00KoYl3/1OnW`>/2ojO0k0ooYl3[P_ooool4o`0002Cooooo001[ooooo`03o`000?oooooooooo02[o
oooo2onW`>/2ojO0k1KoYl3[P_ooool3o`0002Sooooo001/ooooo`03o`000?oooooooooo02[ooooo
7OnW`>^3ooooo`Co0000:oooool006gooooo00?o0000ooooooooool0:ooooolHojO0jh;ooooo1?l0
000_ooooo`00K_ooool00ol0003oooooooooo`0ZoooooaGoYl3[POooool4o`0003?ooooo001_oooo
o`;o0000:ooooolAojO0jh3ooooo1?l0000gooooo`00LOooool00ol0003oooooooooo`0Zooooo`Wo
Yl3[P_ooool4o`0003_ooooo001booooo`03o`000?oooooooooo02[ooooo1OnW`>^2ooooo`?o0000
?oooool007?ooooo00?o0000ooooooooool0:_ooool00onW`>_oooooooooo`1oooooo`Co0000@_oo
ool007Cooooo0_l0000Zooooo`03o`000?oooooooooo07_ooooo1?l00016ooooo`00M_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo07Sooooo1?l0001:ooooo`00Moooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo07Cooooo1?l0001>ooooo`00N?ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo077ooooo0ol0001Booooo`00NOooool2o`0002Cooooo00?o
0000ooooooooool0KOooool4o`0005Gooooo001kooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0JOooool4o`0005Wooooo001looooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0IOooool4o`0005gooooo001mooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool0HOooool4o`00067ooooo001nooooo`;o00007oooool00ol0003oooooooooo`1Mooooo`Co0000
IOooool0083ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Jooooo`?o0000JOoo
ool0087ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Fooooo`Co0000K?ooool0
08;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Booooo`Co0000L?ooool008?o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1>ooooo`Co0000M?ooool008Cooooo
0_l0000Iooooo`03o`000?oooooooooo04[ooooo1?l0001hooooo`00Q_ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04Kooooo1?l0001looooo`00Qoooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo04?ooooo0ol00020ooooo`00R?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo03oooooo1?l00023ooooo`00ROooool2o`0001Cooooo00?o0000oooooooo
ool0>oooool4o`0008Oooooo002;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
=oooool4o`0008_ooooo002<ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<ooo
ool4o`0008oooooo002=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<?ooool3
o`0009?ooooo002>ooooo`;o00003oooool00ol0003oooooooooo`0/ooooo`Co0000U_ooool0093o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Xooooo`Co0000V_ooool0097ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Tooooo`Co0000W_ooool009;ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`Co0000X_ooool009?ooooo0_l00009
ooooo`03o`000?oooooooooo01gooooo1?l0002Vooooo`00UOooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01[ooooo0ol0002Zooooo`00U_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Kooooo1?l0002]ooooo`00Uoooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01;ooooo1?l0002aooooo`00V?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00kooooo1?l0002eooooo`00VOooool2o`0000?ooooo00?o0000ooooooooool02_ooool4
o`000;Wooooo002Kooooo`04o`000?ooooooooooo`0000Wooooo0ol0002mooooo`00W?ooool00ol0
003oooooo`000005ooooo`Co0000`?ooool009gooooo0_l000000ooooooo0000o`000002o`000<Co
oooo002Nooooo`;o0000b?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:[ooooo00GoV9RHo`00
0?l0003oA4A4okZj^P0:ooooo`Co000000?o410@ooooooooool00_ooool2o`000003oa0@4?oooooo
oooo00?ooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0TOooool00:[ooooo00Go410@okZj
^_o^k^koMgMgoa0@4002ooooo`Ko00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo0_lQ8B47ooooo`03o`000?oooooooooo09;ooooo002Zooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool00_ooool5o`0000_ooooo1Ol0002Cooooo`00Z_ooool00ol0003o
ooooooooo`04ooooo`Ko00001?ooool00ol0003oooooooooo`02ooooo`04odA4A?oMgMgoooooo`00
00cooooo00CoA4A4omgMgOoooooo0000U?ooool00:[ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`02ooooo`04omgMgOmEEEGoooooo`0000cooooo00CogMgMoeEEEOoooooo0000U?oo
ool00:Sooooo00?o410@o`000?l000000ol0000=ooooo`03o`000?oooooooooo00?ooooo00?oMgMg
olc<c?l000003Oooool00omgMgOoc<c<o`00002Dooooo`00Z_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00?ooooo00?ok^k^odA4A?l000003Oooool00oo^k^koA4A4o`00002Doooo
o`00Z_ooool00ol0003oooooooooo`0<ooooo`03oeEEEOmVIVKo000000Kooooo00?oMgMgo`000?oo
ool03Oooool00omgMgOo0000ooooo`2Cooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -20 0 ]
[.5 .82364 20 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15.2) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.655 .751 .921 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69468 Mtetra
.655 .752 .921 r
.4053 .69468 .41061 .69934 .41957 .69681 .41427 .69216 Mtetra
.41427 .69216 .41957 .69681 .42855 .69428 .42327 .68962 Mtetra
.655 .753 .922 r
.42327 .68962 .42855 .69428 .43756 .69174 .4323 .68708 Mtetra
.4323 .68708 .43756 .69174 .4466 .68919 .44136 .68453 Mtetra
.655 .754 .922 r
.44136 .68453 .4466 .68919 .45567 .68663 .45046 .68196 Mtetra
.655 .754 .923 r
.45046 .68196 .45567 .68663 .46478 .68407 .45958 .67939 Mtetra
.655 .755 .923 r
.45958 .67939 .46478 .68407 .47391 .68149 .46873 .6768 Mtetra
.46873 .6768 .47391 .68149 .48307 .67891 .47791 .6742 Mtetra
.47791 .6742 .48307 .67891 .49227 .67632 .48713 .67159 Mtetra
.656 .755 .923 r
.48713 .67159 .49227 .67632 .50149 .67371 .49638 .66897 Mtetra
.49638 .66897 .50149 .67371 .51075 .6711 .50565 .66634 Mtetra
.50565 .66634 .51075 .6711 .52004 .66849 .51496 .6637 Mtetra
.656 .754 .922 r
.51496 .6637 .52004 .66849 .52936 .66586 .5243 .66105 Mtetra
.5243 .66105 .52936 .66586 .53871 .66322 .53367 .65839 Mtetra
.53367 .65839 .53871 .66322 .54809 .66058 .54308 .65571 Mtetra
.656 .753 .922 r
.54308 .65571 .54809 .66058 .55751 .65792 .55251 .65303 Mtetra
.656 .753 .921 r
.55251 .65303 .55751 .65792 .56695 .65526 .56198 .65034 Mtetra
.56198 .65034 .56695 .65526 .57643 .65259 .57148 .64765 Mtetra
.656 .752 .921 r
.57148 .64765 .57643 .65259 .58595 .6499 .58102 .64494 Mtetra
.58102 .64494 .58595 .6499 .59549 .64721 .59058 .64223 Mtetra
.59058 .64223 .59549 .64721 .60507 .64451 .60018 .63951 Mtetra
.656 .752 .92 r
.60018 .63951 .60507 .64451 .61468 .6418 .60982 .63678 Mtetra
.60982 .63678 .61468 .6418 .62432 .63908 .61948 .63404 Mtetra
.61948 .63404 .62432 .63908 .634 .63636 .62918 .6313 Mtetra
.656 .751 .92 r
.62918 .6313 .634 .63636 .64371 .63362 .63892 .62854 Mtetra
.63892 .62854 .64371 .63362 .65345 .63087 .64868 .62577 Mtetra
.64868 .62577 .65345 .63087 .66323 .62811 .65848 .623 Mtetra
.65848 .623 .66323 .62811 .67304 .62535 .66832 .62022 Mtetra
.66832 .62022 .67304 .62535 .68289 .62257 .67819 .61742 Mtetra
.67819 .61742 .68289 .62257 .69277 .61979 .68809 .61462 Mtetra
.68809 .61462 .69277 .61979 .70269 .61699 .69803 .6118 Mtetra
.69803 .6118 .70269 .61699 .71264 .61418 .70801 .60898 Mtetra
.70801 .60898 .71264 .61418 .72262 .61137 .71802 .60615 Mtetra
.71802 .60615 .72262 .61137 .73264 .60854 .72806 .60331 Mtetra
.72806 .60331 .73264 .60854 .7427 .60571 .73814 .60045 Mtetra
.656 .752 .92 r
.73814 .60045 .7427 .60571 .75279 .60286 .74826 .59759 Mtetra
.656 .752 .921 r
.74826 .59759 .75279 .60286 .76291 .60001 .75841 .59472 Mtetra
.75841 .59472 .76291 .60001 .77308 .59714 .7686 .59184 Mtetra
.655 .752 .921 r
.7686 .59184 .77308 .59714 .78328 .59427 .77882 .58896 Mtetra
.77882 .58896 .78328 .59427 .79351 .59138 .78908 .58606 Mtetra
.78908 .58606 .79351 .59138 .80378 .58849 .79938 .58315 Mtetra
.655 .753 .921 r
.79938 .58315 .80378 .58849 .81409 .58558 .80972 .58024 Mtetra
.655 .753 .922 r
.80972 .58024 .81409 .58558 .82443 .58267 .82009 .57731 Mtetra
.82009 .57731 .82443 .58267 .83482 .57974 .8305 .57437 Mtetra
.655 .754 .922 r
.8305 .57437 .83482 .57974 .84523 .5768 .84095 .57142 Mtetra
.655 .754 .923 r
.84095 .57142 .84523 .5768 .85569 .57385 .85143 .56846 Mtetra
.85143 .56846 .85569 .57385 .86618 .57089 .86195 .56549 Mtetra
.655 .755 .923 r
.86195 .56549 .86618 .57089 .87672 .56792 .87251 .56251 Mtetra
.87251 .56251 .87672 .56792 .88729 .56494 .88311 .55951 Mtetra
.88311 .55951 .88729 .56494 .89789 .56195 .89375 .55649 Mtetra
.656 .755 .923 r
.89375 .55649 .89789 .56195 .90854 .55895 .90442 .55347 Mtetra
.90442 .55347 .90854 .55895 .91923 .55594 .91513 .55043 Mtetra
.656 .754 .922 r
.91513 .55043 .91923 .55594 .92995 .55292 .92589 .54737 Mtetra
.92589 .54737 .92995 .55292 .94071 .54988 .93668 .54431 Mtetra
.93668 .54431 .94071 .54988 .95152 .54684 .94751 .54123 Mtetra
.656 .753 .921 r
.94751 .54123 .95152 .54684 .96236 .54378 .95838 .53814 Mtetra
.95838 .53814 .96236 .54378 .97324 .54071 .96929 .53503 Mtetra
.656 .752 .921 r
.96929 .53503 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.655 .751 .921 r
.391 .69252 .39636 .6972 .4053 .69468 .39996 .69 Mtetra
.654 .752 .921 r
.39996 .69 .4053 .69468 .41427 .69216 .40895 .68748 Mtetra
.654 .752 .922 r
.40895 .68748 .41427 .69216 .42327 .68962 .41797 .68494 Mtetra
.654 .753 .922 r
.41797 .68494 .42327 .68962 .4323 .68708 .42702 .68239 Mtetra
.655 .753 .922 r
.42702 .68239 .4323 .68708 .44136 .68453 .4361 .67984 Mtetra
.655 .754 .923 r
.4361 .67984 .44136 .68453 .45046 .68196 .44521 .67726 Mtetra
.44521 .67726 .45046 .68196 .45958 .67939 .45435 .67468 Mtetra
.655 .755 .923 r
.45435 .67468 .45958 .67939 .46873 .6768 .46352 .67209 Mtetra
.46352 .67209 .46873 .6768 .47791 .6742 .47272 .66947 Mtetra
.47272 .66947 .47791 .6742 .48713 .67159 .48196 .66685 Mtetra
.656 .755 .923 r
.48196 .66685 .48713 .67159 .49638 .66897 .49123 .66421 Mtetra
.49123 .66421 .49638 .66897 .50565 .66634 .50052 .66156 Mtetra
.50052 .66156 .50565 .66634 .51496 .6637 .50985 .65889 Mtetra
.656 .755 .922 r
.50985 .65889 .51496 .6637 .5243 .66105 .51922 .65621 Mtetra
.656 .754 .922 r
.51922 .65621 .5243 .66105 .53367 .65839 .52861 .65352 Mtetra
.52861 .65352 .53367 .65839 .54308 .65571 .53803 .65082 Mtetra
.656 .754 .921 r
.53803 .65082 .54308 .65571 .55251 .65303 .54749 .64812 Mtetra
.656 .753 .921 r
.54749 .64812 .55251 .65303 .56198 .65034 .55698 .6454 Mtetra
.55698 .6454 .56198 .65034 .57148 .64765 .5665 .64268 Mtetra
.656 .752 .921 r
.5665 .64268 .57148 .64765 .58102 .64494 .57606 .63995 Mtetra
.57606 .63995 .58102 .64494 .59058 .64223 .58565 .63722 Mtetra
.58565 .63722 .59058 .64223 .60018 .63951 .59527 .63448 Mtetra
.656 .752 .92 r
.59527 .63448 .60018 .63951 .60982 .63678 .60493 .63173 Mtetra
.60493 .63173 .60982 .63678 .61948 .63404 .61461 .62897 Mtetra
.61461 .62897 .61948 .63404 .62918 .6313 .62434 .6262 Mtetra
.656 .751 .92 r
.62434 .6262 .62918 .6313 .63892 .62854 .63409 .62343 Mtetra
.63409 .62343 .63892 .62854 .64868 .62577 .64388 .62065 Mtetra
.64388 .62065 .64868 .62577 .65848 .623 .65371 .61785 Mtetra
.65371 .61785 .65848 .623 .66832 .62022 .66357 .61505 Mtetra
.66357 .61505 .66832 .62022 .67819 .61742 .67346 .61224 Mtetra
.67346 .61224 .67819 .61742 .68809 .61462 .68339 .60942 Mtetra
.68339 .60942 .68809 .61462 .69803 .6118 .69335 .60658 Mtetra
.69335 .60658 .69803 .6118 .70801 .60898 .70335 .60374 Mtetra
.70335 .60374 .70801 .60898 .71802 .60615 .71338 .60089 Mtetra
.71338 .60089 .71802 .60615 .72806 .60331 .72345 .59803 Mtetra
.72345 .59803 .72806 .60331 .73814 .60045 .73356 .59516 Mtetra
.656 .752 .92 r
.73356 .59516 .73814 .60045 .74826 .59759 .7437 .59229 Mtetra
.655 .752 .921 r
.7437 .59229 .74826 .59759 .75841 .59472 .75388 .5894 Mtetra
.75388 .5894 .75841 .59472 .7686 .59184 .76409 .58651 Mtetra
.76409 .58651 .7686 .59184 .77882 .58896 .77434 .58361 Mtetra
.77434 .58361 .77882 .58896 .78908 .58606 .78463 .5807 Mtetra
.78463 .5807 .78908 .58606 .79938 .58315 .79495 .57778 Mtetra
.655 .753 .922 r
.79495 .57778 .79938 .58315 .80972 .58024 .80532 .57486 Mtetra
.80532 .57486 .80972 .58024 .82009 .57731 .81572 .57192 Mtetra
.81572 .57192 .82009 .57731 .8305 .57437 .82615 .56898 Mtetra
.655 .754 .923 r
.82615 .56898 .8305 .57437 .84095 .57142 .83663 .56602 Mtetra
.83663 .56602 .84095 .57142 .85143 .56846 .84714 .56305 Mtetra
.655 .755 .923 r
.84714 .56305 .85143 .56846 .86195 .56549 .85769 .56006 Mtetra
.85769 .56006 .86195 .56549 .87251 .56251 .86828 .55706 Mtetra
.86828 .55706 .87251 .56251 .88311 .55951 .87891 .55404 Mtetra
.656 .755 .923 r
.87891 .55404 .88311 .55951 .89375 .55649 .88957 .551 Mtetra
.88957 .551 .89375 .55649 .90442 .55347 .90027 .54795 Mtetra
.90027 .54795 .90442 .55347 .91513 .55043 .91101 .54488 Mtetra
.656 .755 .922 r
.91101 .54488 .91513 .55043 .92589 .54737 .92179 .54179 Mtetra
.656 .754 .922 r
.92179 .54179 .92589 .54737 .93668 .54431 .93261 .53869 Mtetra
.657 .754 .922 r
.93261 .53869 .93668 .54431 .94751 .54123 .94347 .53558 Mtetra
.657 .754 .921 r
.94347 .53558 .94751 .54123 .95838 .53814 .95437 .53245 Mtetra
.657 .753 .921 r
.95437 .53245 .95838 .53814 .96929 .53503 .96531 .52931 Mtetra
.657 .752 .92 r
.96531 .52931 .96929 .53503 .98024 .53192 .97628 .52616 Mtetra
.654 .751 .921 r
.38561 .68781 .391 .69252 .39996 .69 .39458 .68529 Mtetra
.654 .752 .922 r
.39458 .68529 .39996 .69 .40895 .68748 .40359 .68277 Mtetra
.40359 .68277 .40895 .68748 .41797 .68494 .41263 .68023 Mtetra
.654 .753 .922 r
.41263 .68023 .41797 .68494 .42702 .68239 .4217 .67768 Mtetra
.654 .753 .923 r
.4217 .67768 .42702 .68239 .4361 .67984 .43079 .67512 Mtetra
.654 .754 .923 r
.43079 .67512 .4361 .67984 .44521 .67726 .43992 .67254 Mtetra
.43992 .67254 .44521 .67726 .45435 .67468 .44909 .66995 Mtetra
.655 .755 .923 r
.44909 .66995 .45435 .67468 .46352 .67209 .45828 .66735 Mtetra
.655 .755 .924 r
.45828 .66735 .46352 .67209 .47272 .66947 .4675 .66472 Mtetra
.655 .755 .923 r
.4675 .66472 .47272 .66947 .48196 .66685 .47676 .66209 Mtetra
.656 .756 .923 r
.47676 .66209 .48196 .66685 .49123 .66421 .48604 .65943 Mtetra
.48604 .65943 .49123 .66421 .50052 .66156 .49536 .65675 Mtetra
.49536 .65675 .50052 .66156 .50985 .65889 .50471 .65406 Mtetra
.657 .755 .923 r
.50471 .65406 .50985 .65889 .51922 .65621 .5141 .65136 Mtetra
.657 .755 .922 r
.5141 .65136 .51922 .65621 .52861 .65352 .52351 .64864 Mtetra
.52351 .64864 .52861 .65352 .53803 .65082 .53296 .64591 Mtetra
.657 .754 .922 r
.53296 .64591 .53803 .65082 .54749 .64812 .54244 .64318 Mtetra
.657 .754 .921 r
.54244 .64318 .54749 .64812 .55698 .6454 .55195 .64043 Mtetra
.657 .753 .921 r
.55195 .64043 .55698 .6454 .5665 .64268 .56149 .63769 Mtetra
.656 .753 .921 r
.56149 .63769 .5665 .64268 .57606 .63995 .57107 .63493 Mtetra
.656 .752 .921 r
.57107 .63493 .57606 .63995 .58565 .63722 .58068 .63218 Mtetra
.58068 .63218 .58565 .63722 .59527 .63448 .59032 .62941 Mtetra
.656 .752 .92 r
.59032 .62941 .59527 .63448 .60493 .63173 .6 .62664 Mtetra
.6 .62664 .60493 .63173 .61461 .62897 .60971 .62386 Mtetra
.60971 .62386 .61461 .62897 .62434 .6262 .61946 .62108 Mtetra
.61946 .62108 .62434 .6262 .63409 .62343 .62924 .61829 Mtetra
.656 .751 .92 r
.62924 .61829 .63409 .62343 .64388 .62065 .63905 .61548 Mtetra
.63905 .61548 .64388 .62065 .65371 .61785 .6489 .61267 Mtetra
.6489 .61267 .65371 .61785 .66357 .61505 .65878 .60985 Mtetra
.65878 .60985 .66357 .61505 .67346 .61224 .6687 .60702 Mtetra
.6687 .60702 .67346 .61224 .68339 .60942 .67865 .60418 Mtetra
.67865 .60418 .68339 .60942 .69335 .60658 .68864 .60133 Mtetra
.68864 .60133 .69335 .60658 .70335 .60374 .69866 .59847 Mtetra
.69866 .59847 .70335 .60374 .71338 .60089 .70872 .5956 Mtetra
.70872 .5956 .71338 .60089 .72345 .59803 .71881 .59273 Mtetra
.71881 .59273 .72345 .59803 .73356 .59516 .72894 .58984 Mtetra
.655 .752 .921 r
.72894 .58984 .73356 .59516 .7437 .59229 .73911 .58695 Mtetra
.73911 .58695 .7437 .59229 .75388 .5894 .74931 .58405 Mtetra
.74931 .58405 .75388 .5894 .76409 .58651 .75955 .58114 Mtetra
.75955 .58114 .76409 .58651 .77434 .58361 .76983 .57823 Mtetra
.76983 .57823 .77434 .58361 .78463 .5807 .78014 .57531 Mtetra
.655 .752 .922 r
.78014 .57531 .78463 .5807 .79495 .57778 .7905 .57238 Mtetra
.654 .753 .922 r
.7905 .57238 .79495 .57778 .80532 .57486 .80089 .56945 Mtetra
.80089 .56945 .80532 .57486 .81572 .57192 .81131 .56651 Mtetra
.654 .754 .923 r
.81131 .56651 .81572 .57192 .82615 .56898 .82178 .56356 Mtetra
.82178 .56356 .82615 .56898 .83663 .56602 .83228 .56059 Mtetra
.654 .755 .923 r
.83228 .56059 .83663 .56602 .84714 .56305 .84282 .5576 Mtetra
.655 .755 .924 r
.84282 .5576 .84714 .56305 .85769 .56006 .8534 .5546 Mtetra
.8534 .5546 .85769 .56006 .86828 .55706 .86402 .55158 Mtetra
.655 .756 .924 r
.86402 .55158 .86828 .55706 .87891 .55404 .87467 .54854 Mtetra
.656 .756 .923 r
.87467 .54854 .87891 .55404 .88957 .551 .88537 .54548 Mtetra
.88537 .54548 .88957 .551 .90027 .54795 .8961 .5424 Mtetra
.656 .755 .923 r
.8961 .5424 .90027 .54795 .91101 .54488 .90686 .5393 Mtetra
.657 .755 .922 r
.90686 .5393 .91101 .54488 .92179 .54179 .91767 .53618 Mtetra
.91767 .53618 .92179 .54179 .93261 .53869 .92852 .53305 Mtetra
.657 .754 .922 r
.92852 .53305 .93261 .53869 .94347 .53558 .93941 .5299 Mtetra
.657 .754 .921 r
.93941 .5299 .94347 .53558 .95437 .53245 .95033 .52673 Mtetra
.657 .753 .921 r
.95033 .52673 .95437 .53245 .96531 .52931 .9613 .52356 Mtetra
.657 .753 .92 r
.9613 .52356 .96531 .52931 .97628 .52616 .9723 .52037 Mtetra
.653 .751 .921 r
.38018 .68308 .38561 .68781 .39458 .68529 .38917 .68056 Mtetra
.653 .751 .922 r
.38917 .68056 .39458 .68529 .40359 .68277 .3982 .67803 Mtetra
.653 .752 .922 r
.3982 .67803 .40359 .68277 .41263 .68023 .40726 .67549 Mtetra
.653 .753 .923 r
.40726 .67549 .41263 .68023 .4217 .67768 .41634 .67294 Mtetra
.41634 .67294 .4217 .67768 .43079 .67512 .42546 .67037 Mtetra
.654 .754 .923 r
.42546 .67037 .43079 .67512 .43992 .67254 .43461 .66779 Mtetra
.654 .754 .924 r
.43461 .66779 .43992 .67254 .44909 .66995 .44379 .6652 Mtetra
.654 .755 .924 r
.44379 .6652 .44909 .66995 .45828 .66735 .453 .66259 Mtetra
.655 .755 .924 r
.453 .66259 .45828 .66735 .4675 .66472 .46225 .65996 Mtetra
.655 .756 .924 r
.46225 .65996 .4675 .66472 .47676 .66209 .47152 .6573 Mtetra
.656 .756 .924 r
.47152 .6573 .47676 .66209 .48604 .65943 .48083 .65463 Mtetra
.48083 .65463 .48604 .65943 .49536 .65675 .49017 .65194 Mtetra
.657 .756 .923 r
.49017 .65194 .49536 .65675 .50471 .65406 .49954 .64922 Mtetra
.49954 .64922 .50471 .65406 .5141 .65136 .50895 .64649 Mtetra
.50895 .64649 .5141 .65136 .52351 .64864 .51838 .64374 Mtetra
.657 .755 .922 r
.51838 .64374 .52351 .64864 .53296 .64591 .52785 .64098 Mtetra
.52785 .64098 .53296 .64591 .54244 .64318 .53735 .63822 Mtetra
.657 .754 .921 r
.53735 .63822 .54244 .64318 .55195 .64043 .54688 .63545 Mtetra
.54688 .63545 .55195 .64043 .56149 .63769 .55645 .63267 Mtetra
.657 .753 .921 r
.55645 .63267 .56149 .63769 .57107 .63493 .56605 .62989 Mtetra
.56605 .62989 .57107 .63493 .58068 .63218 .57568 .62711 Mtetra
.656 .752 .921 r
.57568 .62711 .58068 .63218 .59032 .62941 .58535 .62432 Mtetra
.656 .752 .92 r
.58535 .62432 .59032 .62941 .6 .62664 .59505 .62153 Mtetra
.59505 .62153 .6 .62664 .60971 .62386 .60478 .61873 Mtetra
.60478 .61873 .60971 .62386 .61946 .62108 .61455 .61592 Mtetra
.61455 .61592 .61946 .62108 .62924 .61829 .62435 .61311 Mtetra
.62435 .61311 .62924 .61829 .63905 .61548 .63419 .61029 Mtetra
.656 .751 .92 r
.63419 .61029 .63905 .61548 .6489 .61267 .64406 .60746 Mtetra
.64406 .60746 .6489 .61267 .65878 .60985 .65396 .60462 Mtetra
.65396 .60462 .65878 .60985 .6687 .60702 .66391 .60177 Mtetra
.66391 .60177 .6687 .60702 .67865 .60418 .67388 .59891 Mtetra
.67388 .59891 .67865 .60418 .68864 .60133 .68389 .59604 Mtetra
.68389 .59604 .68864 .60133 .69866 .59847 .69394 .59317 Mtetra
.69394 .59317 .69866 .59847 .70872 .5956 .70402 .59028 Mtetra
.70402 .59028 .70872 .5956 .71881 .59273 .71414 .58739 Mtetra
.655 .751 .921 r
.71414 .58739 .71881 .59273 .72894 .58984 .7243 .58449 Mtetra
.655 .752 .921 r
.7243 .58449 .72894 .58984 .73911 .58695 .73449 .58158 Mtetra
.73449 .58158 .73911 .58695 .74931 .58405 .74472 .57867 Mtetra
.74472 .57867 .74931 .58405 .75955 .58114 .75499 .57575 Mtetra
.654 .752 .921 r
.75499 .57575 .75955 .58114 .76983 .57823 .76529 .57282 Mtetra
.654 .752 .922 r
.76529 .57282 .76983 .57823 .78014 .57531 .77563 .5699 Mtetra
.654 .753 .922 r
.77563 .5699 .78014 .57531 .7905 .57238 .78601 .56697 Mtetra
.654 .753 .923 r
.78601 .56697 .7905 .57238 .80089 .56945 .79643 .56403 Mtetra
.654 .754 .923 r
.79643 .56403 .80089 .56945 .81131 .56651 .80688 .56108 Mtetra
.654 .754 .924 r
.80688 .56108 .81131 .56651 .82178 .56356 .81738 .55812 Mtetra
.654 .755 .924 r
.81738 .55812 .82178 .56356 .83228 .56059 .82791 .55514 Mtetra
.82791 .55514 .83228 .56059 .84282 .5576 .83848 .55214 Mtetra
.655 .756 .924 r
.83848 .55214 .84282 .5576 .8534 .5546 .84909 .54912 Mtetra
.84909 .54912 .8534 .5546 .86402 .55158 .85973 .54608 Mtetra
.85973 .54608 .86402 .55158 .87467 .54854 .87041 .54302 Mtetra
.656 .756 .924 r
.87041 .54302 .87467 .54854 .88537 .54548 .88113 .53993 Mtetra
.656 .756 .923 r
.88113 .53993 .88537 .54548 .8961 .5424 .89189 .53681 Mtetra
.657 .756 .923 r
.89189 .53681 .8961 .5424 .90686 .5393 .90269 .53368 Mtetra
.657 .755 .922 r
.90269 .53368 .90686 .5393 .91767 .53618 .91352 .53053 Mtetra
.91352 .53053 .91767 .53618 .92852 .53305 .9244 .52736 Mtetra
.658 .755 .921 r
.9244 .52736 .92852 .53305 .93941 .5299 .93531 .52417 Mtetra
.658 .754 .921 r
.93531 .52417 .93941 .5299 .95033 .52673 .94627 .52098 Mtetra
.658 .753 .921 r
.94627 .52098 .95033 .52673 .9613 .52356 .95726 .51776 Mtetra
.658 .753 .92 r
.95726 .51776 .9613 .52356 .9723 .52037 .96829 .51454 Mtetra
.653 .751 .922 r
.37472 .67831 .38018 .68308 .38917 .68056 .38373 .67579 Mtetra
.38373 .67579 .38917 .68056 .3982 .67803 .39277 .67326 Mtetra
.653 .752 .922 r
.39277 .67326 .3982 .67803 .40726 .67549 .40185 .67071 Mtetra
.653 .752 .923 r
.40185 .67071 .40726 .67549 .41634 .67294 .41095 .66816 Mtetra
.653 .753 .923 r
.41095 .66816 .41634 .67294 .42546 .67037 .42009 .6656 Mtetra
.653 .754 .924 r
.42009 .6656 .42546 .67037 .43461 .66779 .42926 .66302 Mtetra
.42926 .66302 .43461 .66779 .44379 .6652 .43846 .66042 Mtetra
.654 .755 .924 r
.43846 .66042 .44379 .6652 .453 .66259 .44769 .65781 Mtetra
.654 .756 .924 r
.44769 .65781 .453 .66259 .46225 .65996 .45696 .65517 Mtetra
.655 .756 .925 r
.45696 .65517 .46225 .65996 .47152 .6573 .46625 .65251 Mtetra
.655 .757 .924 r
.46625 .65251 .47152 .6573 .48083 .65463 .47558 .64982 Mtetra
.656 .757 .924 r
.47558 .64982 .48083 .65463 .49017 .65194 .48494 .64711 Mtetra
.657 .757 .924 r
.48494 .64711 .49017 .65194 .49954 .64922 .49433 .64437 Mtetra
.49433 .64437 .49954 .64922 .50895 .64649 .50376 .64162 Mtetra
.658 .757 .923 r
.50376 .64162 .50895 .64649 .51838 .64374 .51322 .63884 Mtetra
.51322 .63884 .51838 .64374 .52785 .64098 .52271 .63605 Mtetra
.658 .756 .922 r
.52271 .63605 .52785 .64098 .53735 .63822 .53223 .63325 Mtetra
.658 .755 .922 r
.53223 .63325 .53735 .63822 .54688 .63545 .54179 .63044 Mtetra
.658 .754 .921 r
.54179 .63044 .54688 .63545 .55645 .63267 .55137 .62763 Mtetra
.657 .754 .921 r
.55137 .62763 .55645 .63267 .56605 .62989 .56099 .62482 Mtetra
.657 .753 .921 r
.56099 .62482 .56605 .62989 .57568 .62711 .57065 .62201 Mtetra
.57065 .62201 .57568 .62711 .58535 .62432 .58034 .6192 Mtetra
.656 .752 .921 r
.58034 .6192 .58535 .62432 .59505 .62153 .59006 .61638 Mtetra
.656 .752 .92 r
.59006 .61638 .59505 .62153 .60478 .61873 .59982 .61356 Mtetra
.59982 .61356 .60478 .61873 .61455 .61592 .60961 .61073 Mtetra
.60961 .61073 .61455 .61592 .62435 .61311 .61943 .6079 Mtetra
.61943 .6079 .62435 .61311 .63419 .61029 .62929 .60506 Mtetra
.62929 .60506 .63419 .61029 .64406 .60746 .63919 .60221 Mtetra
.656 .751 .92 r
.63919 .60221 .64406 .60746 .65396 .60462 .64912 .59935 Mtetra
.64912 .59935 .65396 .60462 .66391 .60177 .65908 .59649 Mtetra
.65908 .59649 .66391 .60177 .67388 .59891 .66908 .59361 Mtetra
.66908 .59361 .67388 .59891 .68389 .59604 .67912 .59072 Mtetra
.67912 .59072 .68389 .59604 .69394 .59317 .68919 .58783 Mtetra
.68919 .58783 .69394 .59317 .70402 .59028 .6993 .58493 Mtetra
.655 .751 .921 r
.6993 .58493 .70402 .59028 .71414 .58739 .70944 .58201 Mtetra
.655 .752 .921 r
.70944 .58201 .71414 .58739 .7243 .58449 .71962 .5791 Mtetra
.71962 .5791 .7243 .58449 .73449 .58158 .72984 .57618 Mtetra
.72984 .57618 .73449 .58158 .74472 .57867 .7401 .57325 Mtetra
.654 .752 .921 r
.7401 .57325 .74472 .57867 .75499 .57575 .75039 .57033 Mtetra
.654 .752 .922 r
.75039 .57033 .75499 .57575 .76529 .57282 .76072 .5674 Mtetra
.654 .753 .922 r
.76072 .5674 .76529 .57282 .77563 .5699 .77109 .56446 Mtetra
.653 .753 .923 r
.77109 .56446 .77563 .5699 .78601 .56697 .7815 .56153 Mtetra
.653 .754 .924 r
.7815 .56153 .78601 .56697 .79643 .56403 .79194 .55859 Mtetra
.79194 .55859 .79643 .56403 .80688 .56108 .80243 .55564 Mtetra
.653 .755 .924 r
.80243 .55564 .80688 .56108 .81738 .55812 .81295 .55267 Mtetra
.653 .756 .925 r
.81295 .55267 .81738 .55812 .82791 .55514 .82351 .54968 Mtetra
.654 .756 .925 r
.82351 .54968 .82791 .55514 .83848 .55214 .83411 .54667 Mtetra
.654 .757 .925 r
.83411 .54667 .83848 .55214 .84909 .54912 .84474 .54363 Mtetra
.655 .757 .925 r
.84474 .54363 .84909 .54912 .85973 .54608 .85542 .54056 Mtetra
.656 .757 .924 r
.85542 .54056 .85973 .54608 .87041 .54302 .86613 .53747 Mtetra
.86613 .53747 .87041 .54302 .88113 .53993 .87687 .53435 Mtetra
.657 .757 .923 r
.87687 .53435 .88113 .53993 .89189 .53681 .88766 .5312 Mtetra
.657 .756 .923 r
.88766 .5312 .89189 .53681 .90269 .53368 .89848 .52803 Mtetra
.658 .756 .922 r
.89848 .52803 .90269 .53368 .91352 .53053 .90935 .52484 Mtetra
.658 .755 .922 r
.90935 .52484 .91352 .53053 .9244 .52736 .92025 .52163 Mtetra
.658 .755 .921 r
.92025 .52163 .9244 .52736 .93531 .52417 .93119 .51841 Mtetra
.658 .754 .921 r
.93119 .51841 .93531 .52417 .94627 .52098 .94217 .51518 Mtetra
.658 .754 .92 r
.94217 .51518 .94627 .52098 .95726 .51776 .9532 .51193 Mtetra
.659 .753 .92 r
.9532 .51193 .95726 .51776 .96829 .51454 .96426 .50866 Mtetra
.652 .75 .922 r
.36922 .67351 .37472 .67831 .38373 .67579 .37825 .67099 Mtetra
.652 .751 .922 r
.37825 .67099 .38373 .67579 .39277 .67326 .38732 .66845 Mtetra
.652 .751 .923 r
.38732 .66845 .39277 .67326 .40185 .67071 .39641 .66591 Mtetra
.652 .752 .923 r
.39641 .66591 .40185 .67071 .41095 .66816 .40553 .66335 Mtetra
.652 .753 .923 r
.40553 .66335 .41095 .66816 .42009 .6656 .41469 .66079 Mtetra
.652 .753 .924 r
.41469 .66079 .42009 .6656 .42926 .66302 .42388 .65821 Mtetra
.652 .754 .924 r
.42388 .65821 .42926 .66302 .43846 .66042 .4331 .65562 Mtetra
.653 .755 .925 r
.4331 .65562 .43846 .66042 .44769 .65781 .44235 .653 Mtetra
.653 .756 .925 r
.44235 .653 .44769 .65781 .45696 .65517 .45163 .65037 Mtetra
.654 .757 .925 r
.45163 .65037 .45696 .65517 .46625 .65251 .46095 .6477 Mtetra
.655 .757 .925 r
.46095 .6477 .46625 .65251 .47558 .64982 .4703 .64501 Mtetra
.656 .758 .925 r
.4703 .64501 .47558 .64982 .48494 .64711 .47968 .64228 Mtetra
.657 .758 .925 r
.47968 .64228 .48494 .64711 .49433 .64437 .48909 .63953 Mtetra
.657 .759 .924 r
.48909 .63953 .49433 .64437 .50376 .64162 .49854 .63674 Mtetra
.658 .758 .924 r
.49854 .63674 .50376 .64162 .51322 .63884 .50802 .63394 Mtetra
.659 .758 .923 r
.50802 .63394 .51322 .63884 .52271 .63605 .51753 .63111 Mtetra
.659 .757 .923 r
.51753 .63111 .52271 .63605 .53223 .63325 .52708 .62827 Mtetra
.659 .757 .922 r
.52708 .62827 .53223 .63325 .54179 .63044 .53665 .62543 Mtetra
.658 .756 .922 r
.53665 .62543 .54179 .63044 .55137 .62763 .54626 .62258 Mtetra
.658 .755 .921 r
.54626 .62258 .55137 .62763 .56099 .62482 .55591 .61974 Mtetra
.658 .754 .921 r
.55591 .61974 .56099 .62482 .57065 .62201 .56559 .61689 Mtetra
.657 .753 .921 r
.56559 .61689 .57065 .62201 .58034 .6192 .5753 .61405 Mtetra
.5753 .61405 .58034 .6192 .59006 .61638 .58504 .61121 Mtetra
.656 .752 .921 r
.58504 .61121 .59006 .61638 .59982 .61356 .59482 .60836 Mtetra
.656 .752 .92 r
.59482 .60836 .59982 .61356 .60961 .61073 .60463 .60551 Mtetra
.60463 .60551 .60961 .61073 .61943 .6079 .61448 .60266 Mtetra
.61448 .60266 .61943 .6079 .62929 .60506 .62437 .5998 Mtetra
.62437 .5998 .62929 .60506 .63919 .60221 .63428 .59693 Mtetra
.63428 .59693 .63919 .60221 .64912 .59935 .64424 .59405 Mtetra
.656 .751 .92 r
.64424 .59405 .64912 .59935 .65908 .59649 .65423 .59117 Mtetra
.65423 .59117 .65908 .59649 .66908 .59361 .66425 .58827 Mtetra
.66425 .58827 .66908 .59361 .67912 .59072 .67431 .58537 Mtetra
.67431 .58537 .67912 .59072 .68919 .58783 .68441 .58246 Mtetra
.655 .751 .921 r
.68441 .58246 .68919 .58783 .6993 .58493 .69454 .57954 Mtetra
.655 .752 .921 r
.69454 .57954 .6993 .58493 .70944 .58201 .70471 .57661 Mtetra
.70471 .57661 .70944 .58201 .71962 .5791 .71492 .57368 Mtetra
.71492 .57368 .71962 .5791 .72984 .57618 .72516 .57075 Mtetra
.654 .752 .922 r
.72516 .57075 .72984 .57618 .7401 .57325 .73544 .56781 Mtetra
.73544 .56781 .7401 .57325 .75039 .57033 .74576 .56488 Mtetra
.653 .752 .923 r
.74576 .56488 .75039 .57033 .76072 .5674 .75612 .56195 Mtetra
.653 .753 .923 r
.75612 .56195 .76072 .5674 .77109 .56446 .76652 .55902 Mtetra
.652 .754 .924 r
.76652 .55902 .77109 .56446 .7815 .56153 .77695 .55609 Mtetra
.652 .754 .925 r
.77695 .55609 .7815 .56153 .79194 .55859 .78743 .55314 Mtetra
.652 .755 .925 r
.78743 .55314 .79194 .55859 .80243 .55564 .79794 .55019 Mtetra
.652 .756 .926 r
.79794 .55019 .80243 .55564 .81295 .55267 .80849 .54722 Mtetra
.653 .757 .926 r
.80849 .54722 .81295 .55267 .82351 .54968 .81908 .54422 Mtetra
.654 .757 .926 r
.81908 .54422 .82351 .54968 .83411 .54667 .82971 .54119 Mtetra
.654 .758 .926 r
.82971 .54119 .83411 .54667 .84474 .54363 .84037 .53812 Mtetra
.655 .758 .925 r
.84037 .53812 .84474 .54363 .85542 .54056 .85107 .53503 Mtetra
.656 .758 .925 r
.85107 .53503 .85542 .54056 .86613 .53747 .86181 .53189 Mtetra
.657 .758 .924 r
.86181 .53189 .86613 .53747 .87687 .53435 .87258 .52873 Mtetra
.658 .757 .923 r
.87258 .52873 .87687 .53435 .88766 .5312 .8834 .52555 Mtetra
.8834 .52555 .88766 .5312 .89848 .52803 .89425 .52234 Mtetra
.658 .756 .922 r
.89425 .52234 .89848 .52803 .90935 .52484 .90514 .51911 Mtetra
.659 .755 .921 r
.90514 .51911 .90935 .52484 .92025 .52163 .91607 .51586 Mtetra
.91607 .51586 .92025 .52163 .93119 .51841 .92704 .5126 Mtetra
.659 .754 .92 r
.92704 .5126 .93119 .51841 .94217 .51518 .93805 .50933 Mtetra
.93805 .50933 .94217 .51518 .9532 .51193 .9491 .50605 Mtetra
.659 .753 .92 r
.9491 .50605 .9532 .51193 .96426 .50866 .9602 .50275 Mtetra
.652 .75 .922 r
.36369 .66869 .36922 .67351 .37825 .67099 .37274 .66615 Mtetra
.652 .751 .922 r
.37274 .66615 .37825 .67099 .38732 .66845 .38182 .66361 Mtetra
.651 .751 .923 r
.38182 .66361 .38732 .66845 .39641 .66591 .39093 .66106 Mtetra
.39093 .66106 .39641 .66591 .40553 .66335 .40008 .6585 Mtetra
.651 .752 .923 r
.40008 .6585 .40553 .66335 .41469 .66079 .40925 .65594 Mtetra
.651 .753 .924 r
.40925 .65594 .41469 .66079 .42388 .65821 .41846 .65336 Mtetra
.41846 .65336 .42388 .65821 .4331 .65562 .4277 .65078 Mtetra
.652 .754 .925 r
.4277 .65078 .4331 .65562 .44235 .653 .43697 .64817 Mtetra
.652 .755 .925 r
.43697 .64817 .44235 .653 .45163 .65037 .44627 .64554 Mtetra
.653 .757 .926 r
.44627 .64554 .45163 .65037 .46095 .6477 .45561 .64288 Mtetra
.654 .758 .926 r
.45561 .64288 .46095 .6477 .4703 .64501 .46498 .64019 Mtetra
.655 .759 .926 r
.46498 .64019 .4703 .64501 .47968 .64228 .47438 .63746 Mtetra
.656 .76 .926 r
.47438 .63746 .47968 .64228 .48909 .63953 .48382 .63469 Mtetra
.658 .76 .925 r
.48382 .63469 .48909 .63953 .49854 .63674 .49329 .63188 Mtetra
.659 .76 .925 r
.49329 .63188 .49854 .63674 .50802 .63394 .50279 .62904 Mtetra
.659 .76 .924 r
.50279 .62904 .50802 .63394 .51753 .63111 .51232 .62618 Mtetra
.66 .759 .924 r
.51232 .62618 .51753 .63111 .52708 .62827 .52189 .6233 Mtetra
.66 .758 .923 r
.52189 .6233 .52708 .62827 .53665 .62543 .53149 .62041 Mtetra
.659 .757 .922 r
.53149 .62041 .53665 .62543 .54626 .62258 .54112 .61752 Mtetra
.659 .756 .922 r
.54112 .61752 .54626 .62258 .55591 .61974 .55079 .61464 Mtetra
.658 .755 .921 r
.55079 .61464 .55591 .61974 .56559 .61689 .56049 .61176 Mtetra
.658 .754 .921 r
.56049 .61176 .56559 .61689 .5753 .61405 .57022 .60888 Mtetra
.657 .753 .921 r
.57022 .60888 .5753 .61405 .58504 .61121 .57999 .60601 Mtetra
.57999 .60601 .58504 .61121 .59482 .60836 .58979 .60314 Mtetra
.656 .752 .92 r
.58979 .60314 .59482 .60836 .60463 .60551 .59963 .60026 Mtetra
.59963 .60026 .60463 .60551 .61448 .60266 .6095 .59739 Mtetra
.6095 .59739 .61448 .60266 .62437 .5998 .61941 .59451 Mtetra
.61941 .59451 .62437 .5998 .63428 .59693 .62935 .59162 Mtetra
.62935 .59162 .63428 .59693 .64424 .59405 .63933 .58872 Mtetra
.63933 .58872 .64424 .59405 .65423 .59117 .64934 .58582 Mtetra
.64934 .58582 .65423 .59117 .66425 .58827 .65939 .5829 Mtetra
.656 .751 .92 r
.65939 .5829 .66425 .58827 .67431 .58537 .66947 .57998 Mtetra
.655 .752 .921 r
.66947 .57998 .67431 .58537 .68441 .58246 .6796 .57705 Mtetra
.6796 .57705 .68441 .58246 .69454 .57954 .68975 .57411 Mtetra
.68975 .57411 .69454 .57954 .70471 .57661 .69995 .57118 Mtetra
.69995 .57118 .70471 .57661 .71492 .57368 .71018 .56823 Mtetra
.654 .752 .922 r
.71018 .56823 .71492 .57368 .72516 .57075 .72045 .56529 Mtetra
.72045 .56529 .72516 .57075 .73544 .56781 .73076 .56236 Mtetra
.653 .752 .923 r
.73076 .56236 .73544 .56781 .74576 .56488 .74111 .55942 Mtetra
.652 .753 .923 r
.74111 .55942 .74576 .56488 .75612 .56195 .75149 .55649 Mtetra
.652 .754 .924 r
.75149 .55649 .75612 .56195 .76652 .55902 .76192 .55357 Mtetra
.651 .754 .925 r
.76192 .55357 .76652 .55902 .77695 .55609 .77238 .55064 Mtetra
.651 .755 .926 r
.77238 .55064 .77695 .55609 .78743 .55314 .78289 .5477 Mtetra
.651 .756 .927 r
.78289 .5477 .78743 .55314 .79794 .55019 .79343 .54475 Mtetra
.652 .757 .927 r
.79343 .54475 .79794 .55019 .80849 .54722 .80401 .54177 Mtetra
.652 .758 .927 r
.80401 .54177 .80849 .54722 .81908 .54422 .81463 .53875 Mtetra
.654 .759 .927 r
.81463 .53875 .81908 .54422 .82971 .54119 .82528 .5357 Mtetra
.655 .759 .926 r
.82528 .5357 .82971 .54119 .84037 .53812 .83597 .5326 Mtetra
.656 .759 .926 r
.83597 .5326 .84037 .53812 .85107 .53503 .8467 .52946 Mtetra
.657 .759 .925 r
.8467 .52946 .85107 .53503 .86181 .53189 .85746 .52629 Mtetra
.658 .758 .924 r
.85746 .52629 .86181 .53189 .87258 .52873 .86827 .52308 Mtetra
.659 .758 .923 r
.86827 .52308 .87258 .52873 .8834 .52555 .87911 .51985 Mtetra
.659 .757 .922 r
.87911 .51985 .8834 .52555 .89425 .52234 .88999 .5166 Mtetra
.659 .756 .922 r
.88999 .5166 .89425 .52234 .90514 .51911 .9009 .51333 Mtetra
.659 .755 .921 r
.9009 .51333 .90514 .51911 .91607 .51586 .91186 .51004 Mtetra
.659 .755 .92 r
.91186 .51004 .91607 .51586 .92704 .5126 .92286 .50675 Mtetra
.659 .754 .92 r
.92286 .50675 .92704 .5126 .93805 .50933 .9339 .50344 Mtetra
.9339 .50344 .93805 .50933 .9491 .50605 .94498 .50012 Mtetra
.659 .753 .919 r
.94498 .50012 .9491 .50605 .9602 .50275 .9561 .4968 Mtetra
.652 .75 .922 r
.35813 .66383 .36369 .66869 .37274 .66615 .3672 .66128 Mtetra
.651 .75 .922 r
.3672 .66128 .37274 .66615 .38182 .66361 .3763 .65873 Mtetra
.651 .751 .922 r
.3763 .65873 .38182 .66361 .39093 .66106 .38543 .65617 Mtetra
.651 .751 .923 r
.38543 .65617 .39093 .66106 .40008 .6585 .39459 .6536 Mtetra
.39459 .6536 .40008 .6585 .40925 .65594 .40378 .65104 Mtetra
.651 .752 .923 r
.40378 .65104 .40925 .65594 .41846 .65336 .41301 .64846 Mtetra
.65 .752 .924 r
.41301 .64846 .41846 .65336 .4277 .65078 .42227 .64588 Mtetra
.651 .753 .925 r
.42227 .64588 .4277 .65078 .43697 .64817 .43156 .64329 Mtetra
.651 .754 .925 r
.43156 .64329 .43697 .64817 .44627 .64554 .44088 .64067 Mtetra
.652 .756 .926 r
.44088 .64067 .44627 .64554 .45561 .64288 .45024 .63802 Mtetra
.653 .757 .926 r
.45024 .63802 .45561 .64288 .46498 .64019 .45963 .63534 Mtetra
.654 .759 .927 r
.45963 .63534 .46498 .64019 .47438 .63746 .46905 .63262 Mtetra
.656 .76 .927 r
.46905 .63262 .47438 .63746 .48382 .63469 .47851 .62985 Mtetra
.657 .761 .927 r
.47851 .62985 .48382 .63469 .49329 .63188 .488 .62703 Mtetra
.659 .762 .926 r
.488 .62703 .49329 .63188 .50279 .62904 .49752 .62416 Mtetra
.66 .762 .925 r
.49752 .62416 .50279 .62904 .51232 .62618 .50708 .62126 Mtetra
.661 .761 .925 r
.50708 .62126 .51232 .62618 .52189 .6233 .51667 .61834 Mtetra
.661 .76 .924 r
.51667 .61834 .52189 .6233 .53149 .62041 .52629 .6154 Mtetra
.661 .759 .923 r
.52629 .6154 .53149 .62041 .54112 .61752 .53595 .61247 Mtetra
.66 .758 .922 r
.53595 .61247 .54112 .61752 .55079 .61464 .54564 .60953 Mtetra
.659 .756 .922 r
.54564 .60953 .55079 .61464 .56049 .61176 .55536 .60661 Mtetra
.659 .755 .921 r
.55536 .60661 .56049 .61176 .57022 .60888 .56511 .60369 Mtetra
.658 .754 .921 r
.56511 .60369 .57022 .60888 .57999 .60601 .5749 .60079 Mtetra
.657 .753 .921 r
.5749 .60079 .57999 .60601 .58979 .60314 .58473 .59788 Mtetra
.58473 .59788 .58979 .60314 .59963 .60026 .59459 .59499 Mtetra
.656 .752 .921 r
.59459 .59499 .59963 .60026 .6095 .59739 .60448 .59209 Mtetra
.656 .752 .92 r
.60448 .59209 .6095 .59739 .61941 .59451 .61442 .58918 Mtetra
.61442 .58918 .61941 .59451 .62935 .59162 .62438 .58627 Mtetra
.62438 .58627 .62935 .59162 .63933 .58872 .63438 .58335 Mtetra
.63438 .58335 .63933 .58872 .64934 .58582 .64442 .58043 Mtetra
.64442 .58043 .64934 .58582 .65939 .5829 .65449 .5775 Mtetra
.656 .752 .921 r
.65449 .5775 .65939 .5829 .66947 .57998 .6646 .57456 Mtetra
.655 .752 .921 r
.6646 .57456 .66947 .57998 .6796 .57705 .67475 .57161 Mtetra
.67475 .57161 .6796 .57705 .68975 .57411 .68493 .56866 Mtetra
.68493 .56866 .68975 .57411 .69995 .57118 .69515 .56571 Mtetra
.654 .752 .922 r
.69515 .56571 .69995 .57118 .71018 .56823 .70541 .56276 Mtetra
.653 .752 .922 r
.70541 .56276 .71018 .56823 .72045 .56529 .71571 .55982 Mtetra
.653 .752 .923 r
.71571 .55982 .72045 .56529 .73076 .56236 .72605 .55688 Mtetra
.652 .753 .924 r
.72605 .55688 .73076 .56236 .74111 .55942 .73642 .55395 Mtetra
.651 .754 .925 r
.73642 .55395 .74111 .55942 .75149 .55649 .74683 .55104 Mtetra
.65 .754 .926 r
.74683 .55104 .75149 .55649 .76192 .55357 .75729 .54812 Mtetra
.65 .756 .927 r
.75729 .54812 .76192 .55357 .77238 .55064 .76778 .54521 Mtetra
.65 .757 .928 r
.76778 .54521 .77238 .55064 .78289 .5477 .77832 .54228 Mtetra
.65 .758 .928 r
.77832 .54228 .78289 .5477 .79343 .54475 .78889 .53932 Mtetra
.651 .759 .929 r
.78889 .53932 .79343 .54475 .80401 .54177 .7995 .53633 Mtetra
.652 .76 .928 r
.7995 .53633 .80401 .54177 .81463 .53875 .81014 .53329 Mtetra
.654 .76 .928 r
.81014 .53329 .81463 .53875 .82528 .5357 .82082 .5302 Mtetra
.656 .76 .927 r
.82082 .5302 .82528 .5357 .83597 .5326 .83154 .52705 Mtetra
.657 .76 .926 r
.83154 .52705 .83597 .5326 .8467 .52946 .8423 .52387 Mtetra
.658 .759 .924 r
.8423 .52387 .8467 .52946 .85746 .52629 .85309 .52064 Mtetra
.659 .758 .923 r
.85309 .52064 .85746 .52629 .86827 .52308 .86392 .51738 Mtetra
.66 .757 .922 r
.86392 .51738 .86827 .52308 .87911 .51985 .87478 .51409 Mtetra
.66 .756 .921 r
.87478 .51409 .87911 .51985 .88999 .5166 .88569 .51079 Mtetra
.66 .755 .921 r
.88569 .51079 .88999 .5166 .9009 .51333 .89664 .50748 Mtetra
.66 .755 .92 r
.89664 .50748 .9009 .51333 .91186 .51004 .90762 .50416 Mtetra
.66 .754 .92 r
.90762 .50416 .91186 .51004 .92286 .50675 .91865 .50083 Mtetra
.91865 .50083 .92286 .50675 .9339 .50344 .92972 .4975 Mtetra
.66 .753 .919 r
.92972 .4975 .9339 .50344 .94498 .50012 .94083 .49415 Mtetra
.659 .753 .919 r
.94083 .49415 .94498 .50012 .9561 .4968 .95198 .4908 Mtetra
.652 .75 .922 r
.35253 .65894 .35813 .66383 .3672 .66128 .36162 .65637 Mtetra
.36162 .65637 .3672 .66128 .3763 .65873 .37073 .6538 Mtetra
.651 .75 .922 r
.37073 .6538 .3763 .65873 .38543 .65617 .37988 .65122 Mtetra
.37988 .65122 .38543 .65617 .39459 .6536 .38907 .64865 Mtetra
.65 .75 .922 r
.38907 .64865 .39459 .6536 .40378 .65104 .39828 .64607 Mtetra
.65 .75 .923 r
.39828 .64607 .40378 .65104 .41301 .64846 .40752 .6435 Mtetra
.649 .751 .923 r
.40752 .6435 .41301 .64846 .42227 .64588 .4168 .64092 Mtetra
.649 .752 .924 r
.4168 .64092 .42227 .64588 .43156 .64329 .42611 .63834 Mtetra
.649 .753 .925 r
.42611 .63834 .43156 .64329 .44088 .64067 .43545 .63575 Mtetra
.65 .755 .926 r
.43545 .63575 .44088 .64067 .45024 .63802 .44483 .63313 Mtetra
.651 .757 .927 r
.44483 .63313 .45024 .63802 .45963 .63534 .45424 .63047 Mtetra
.652 .759 .928 r
.45424 .63047 .45963 .63534 .46905 .63262 .46369 .62777 Mtetra
.654 .761 .928 r
.46369 .62777 .46905 .63262 .47851 .62985 .47317 .62501 Mtetra
.656 .763 .928 r
.47317 .62501 .47851 .62985 .488 .62703 .48268 .62219 Mtetra
.659 .764 .927 r
.48268 .62219 .488 .62703 .49752 .62416 .49222 .61931 Mtetra
.66 .764 .927 r
.49222 .61931 .49752 .62416 .50708 .62126 .5018 .61638 Mtetra
.662 .764 .926 r
.5018 .61638 .50708 .62126 .51667 .61834 .51141 .61341 Mtetra
.662 .763 .925 r
.51141 .61341 .51667 .61834 .52629 .6154 .52106 .61042 Mtetra
.662 .762 .924 r
.52106 .61042 .52629 .6154 .53595 .61247 .53074 .60742 Mtetra
.661 .76 .923 r
.53074 .60742 .53595 .61247 .54564 .60953 .54045 .60443 Mtetra
.661 .758 .922 r
.54045 .60443 .54564 .60953 .55536 .60661 .55019 .60145 Mtetra
.66 .757 .922 r
.55019 .60145 .55536 .60661 .56511 .60369 .55997 .59849 Mtetra
.659 .755 .921 r
.55997 .59849 .56511 .60369 .5749 .60079 .56979 .59555 Mtetra
.658 .754 .921 r
.56979 .59555 .5749 .60079 .58473 .59788 .57963 .59261 Mtetra
.657 .753 .921 r
.57963 .59261 .58473 .59788 .59459 .59499 .58952 .58968 Mtetra
.58952 .58968 .59459 .59499 .60448 .59209 .59944 .58675 Mtetra
.656 .752 .921 r
.59944 .58675 .60448 .59209 .61442 .58918 .60939 .58383 Mtetra
.60939 .58383 .61442 .58918 .62438 .58627 .61938 .58089 Mtetra
.61938 .58089 .62438 .58627 .63438 .58335 .62941 .57796 Mtetra
.62941 .57796 .63438 .58335 .64442 .58043 .63947 .57501 Mtetra
.63947 .57501 .64442 .58043 .65449 .5775 .64957 .57206 Mtetra
.655 .752 .921 r
.64957 .57206 .65449 .5775 .6646 .57456 .6597 .56911 Mtetra
.6597 .56911 .6646 .57456 .67475 .57161 .66987 .56615 Mtetra
.66987 .56615 .67475 .57161 .68493 .56866 .68008 .56318 Mtetra
.654 .752 .922 r
.68008 .56318 .68493 .56866 .69515 .56571 .69033 .56022 Mtetra
.653 .752 .922 r
.69033 .56022 .69515 .56571 .70541 .56276 .70061 .55727 Mtetra
.653 .752 .923 r
.70061 .55727 .70541 .56276 .71571 .55982 .71094 .55433 Mtetra
.651 .753 .924 r
.71094 .55433 .71571 .55982 .72605 .55688 .7213 .5514 Mtetra
.65 .753 .925 r
.7213 .5514 .72605 .55688 .73642 .55395 .7317 .54849 Mtetra
.649 .754 .926 r
.7317 .54849 .73642 .55395 .74683 .55104 .74215 .54559 Mtetra
.648 .756 .928 r
.74215 .54559 .74683 .55104 .75729 .54812 .75263 .54269 Mtetra
.648 .757 .929 r
.75263 .54269 .75729 .54812 .76778 .54521 .76316 .53979 Mtetra
.648 .759 .93 r
.76316 .53979 .76778 .54521 .77832 .54228 .77372 .53687 Mtetra
.649 .76 .93 r
.77372 .53687 .77832 .54228 .78889 .53932 .78432 .53391 Mtetra
.651 .761 .93 r
.78432 .53391 .78889 .53932 .7995 .53633 .79496 .5309 Mtetra
.653 .762 .93 r
.79496 .5309 .7995 .53633 .81014 .53329 .80563 .52782 Mtetra
.655 .762 .928 r
.80563 .52782 .81014 .53329 .82082 .5302 .81634 .52468 Mtetra
.657 .762 .927 r
.81634 .52468 .82082 .5302 .83154 .52705 .82708 .52147 Mtetra
.659 .761 .925 r
.82708 .52147 .83154 .52705 .8423 .52387 .83786 .51822 Mtetra
.66 .76 .924 r
.83786 .51822 .8423 .52387 .85309 .52064 .84868 .51492 Mtetra
.661 .758 .922 r
.84868 .51492 .85309 .52064 .86392 .51738 .85953 .5116 Mtetra
.661 .757 .921 r
.85953 .5116 .86392 .51738 .87478 .51409 .87043 .50826 Mtetra
.661 .755 .92 r
.87043 .50826 .87478 .51409 .88569 .51079 .88136 .50491 Mtetra
.661 .754 .919 r
.88136 .50491 .88569 .51079 .89664 .50748 .89233 .50156 Mtetra
.66 .754 .919 r
.89233 .50156 .89664 .50748 .90762 .50416 .90335 .49821 Mtetra
.66 .753 .919 r
.90335 .49821 .90762 .50416 .91865 .50083 .91441 .49485 Mtetra
.91441 .49485 .91865 .50083 .92972 .4975 .92551 .4915 Mtetra
.659 .753 .919 r
.92551 .4915 .92972 .4975 .94083 .49415 .93665 .48813 Mtetra
.93665 .48813 .94083 .49415 .95198 .4908 .94784 .48476 Mtetra
.652 .751 .922 r
.34689 .65403 .35253 .65894 .36162 .65637 .356 .65143 Mtetra
.652 .75 .921 r
.356 .65143 .36162 .65637 .37073 .6538 .36514 .64882 Mtetra
.652 .749 .921 r
.36514 .64882 .37073 .6538 .37988 .65122 .37431 .64622 Mtetra
.651 .749 .921 r
.37431 .64622 .37988 .65122 .38907 .64865 .38351 .64362 Mtetra
.65 .749 .921 r
.38351 .64362 .38907 .64865 .39828 .64607 .39274 .64103 Mtetra
.65 .748 .922 r
.39274 .64103 .39828 .64607 .40752 .6435 .40201 .63845 Mtetra
.649 .748 .922 r
.40201 .63845 .40752 .6435 .4168 .64092 .4113 .63588 Mtetra
.648 .749 .923 r
.4113 .63588 .4168 .64092 .42611 .63834 .42063 .63331 Mtetra
.648 .75 .924 r
.42063 .63331 .42611 .63834 .43545 .63575 .42999 .63074 Mtetra
.648 .752 .925 r
.42999 .63074 .43545 .63575 .44483 .63313 .43939 .62816 Mtetra
.648 .754 .927 r
.43939 .62816 .44483 .63313 .45424 .63047 .44882 .62555 Mtetra
.65 .757 .928 r
.44882 .62555 .45424 .63047 .46369 .62777 .45829 .62288 Mtetra
.652 .76 .929 r
.45829 .62288 .46369 .62777 .47317 .62501 .46778 .62016 Mtetra
.655 .763 .929 r
.46778 .62016 .47317 .62501 .48268 .62219 .47732 .61736 Mtetra
.658 .765 .929 r
.47732 .61736 .48268 .62219 .49222 .61931 .48689 .61447 Mtetra
.66 .766 .928 r
.48689 .61447 .49222 .61931 .5018 .61638 .49649 .61152 Mtetra
.662 .767 .927 r
.49649 .61152 .5018 .61638 .51141 .61341 .50612 .60851 Mtetra
.663 .766 .926 r
.50612 .60851 .51141 .61341 .52106 .61042 .51579 .60547 Mtetra
.664 .765 .925 r
.51579 .60547 .52106 .61042 .53074 .60742 .52549 .60241 Mtetra
.663 .763 .924 r
.52549 .60241 .53074 .60742 .54045 .60443 .53523 .59935 Mtetra
.662 .761 .923 r
.53523 .59935 .54045 .60443 .55019 .60145 .545 .59631 Mtetra
.661 .759 .922 r
.545 .59631 .55019 .60145 .55997 .59849 .5548 .59329 Mtetra
.66 .757 .922 r
.5548 .59329 .55997 .59849 .56979 .59555 .56464 .5903 Mtetra
.659 .755 .921 r
.56464 .5903 .56979 .59555 .57963 .59261 .57451 .58732 Mtetra
.658 .754 .921 r
.57451 .58732 .57963 .59261 .58952 .58968 .58441 .58435 Mtetra
.657 .753 .921 r
.58441 .58435 .58952 .58968 .59944 .58675 .59436 .5814 Mtetra
.59436 .5814 .59944 .58675 .60939 .58383 .60433 .57844 Mtetra
.656 .752 .921 r
.60433 .57844 .60939 .58383 .61938 .58089 .61435 .57549 Mtetra
.61435 .57549 .61938 .58089 .62941 .57796 .6244 .57253 Mtetra
.6244 .57253 .62941 .57796 .63947 .57501 .63448 .56957 Mtetra
.655 .752 .921 r
.63448 .56957 .63947 .57501 .64957 .57206 .64461 .5666 Mtetra
.64461 .5666 .64957 .57206 .6597 .56911 .65477 .56363 Mtetra
.65477 .56363 .6597 .56911 .66987 .56615 .66496 .56065 Mtetra
.654 .752 .922 r
.66496 .56065 .66987 .56615 .68008 .56318 .6752 .55768 Mtetra
.653 .752 .922 r
.6752 .55768 .68008 .56318 .69033 .56022 .68547 .55472 Mtetra
.652 .752 .923 r
.68547 .55472 .69033 .56022 .70061 .55727 .69578 .55177 Mtetra
.651 .753 .924 r
.69578 .55177 .70061 .55727 .71094 .55433 .70613 .54884 Mtetra
.65 .754 .925 r
.70613 .54884 .71094 .55433 .7213 .5514 .71653 .54593 Mtetra
.648 .754 .927 r
.71653 .54593 .7213 .5514 .7317 .54849 .72696 .54304 Mtetra
.647 .756 .929 r
.72696 .54304 .7317 .54849 .74215 .54559 .73743 .54017 Mtetra
.646 .757 .93 r
.73743 .54017 .74215 .54559 .75263 .54269 .74795 .5373 Mtetra
.646 .759 .932 r
.74795 .5373 .75263 .54269 .76316 .53979 .7585 .53442 Mtetra
.647 .761 .932 r
.7585 .53442 .76316 .53979 .77372 .53687 .7691 .5315 Mtetra
.649 .763 .932 r
.7691 .5315 .77372 .53687 .78432 .53391 .77973 .52852 Mtetra
.651 .764 .932 r
.77973 .52852 .78432 .53391 .79496 .5309 .79039 .52546 Mtetra
.654 .764 .93 r
.79039 .52546 .79496 .5309 .80563 .52782 .80109 .52232 Mtetra
.657 .764 .928 r
.80109 .52232 .80563 .52782 .81634 .52468 .81182 .51911 Mtetra
.66 .762 .926 r
.81182 .51911 .81634 .52468 .82708 .52147 .82259 .51582 Mtetra
.661 .761 .924 r
.82259 .51582 .82708 .52147 .83786 .51822 .83339 .51248 Mtetra
.662 .759 .922 r
.83339 .51248 .83786 .51822 .84868 .51492 .84423 .50911 Mtetra
.663 .757 .92 r
.84423 .50911 .84868 .51492 .85953 .5116 .85511 .50572 Mtetra
.662 .755 .919 r
.85511 .50572 .85953 .5116 .87043 .50826 .86603 .50233 Mtetra
.662 .754 .918 r
.86603 .50233 .87043 .50826 .88136 .50491 .87699 .49894 Mtetra
.661 .753 .918 r
.87699 .49894 .88136 .50491 .89233 .50156 .888 .49555 Mtetra
.661 .752 .918 r
.888 .49555 .89233 .50156 .90335 .49821 .89904 .49218 Mtetra
.66 .752 .918 r
.89904 .49218 .90335 .49821 .91441 .49485 .91013 .4888 Mtetra
.659 .752 .918 r
.91013 .4888 .91441 .49485 .92551 .4915 .92127 .48543 Mtetra
.659 .752 .919 r
.92127 .48543 .92551 .4915 .93665 .48813 .93244 .48206 Mtetra
.93244 .48206 .93665 .48813 .94784 .48476 .94366 .47868 Mtetra
.653 .751 .921 r
.34122 .64908 .34689 .65403 .356 .65143 .35035 .64644 Mtetra
.653 .75 .921 r
.35035 .64644 .356 .65143 .36514 .64882 .35951 .64379 Mtetra
.653 .749 .92 r
.35951 .64379 .36514 .64882 .37431 .64622 .3687 .64115 Mtetra
.652 .748 .92 r
.3687 .64115 .37431 .64622 .38351 .64362 .37792 .63852 Mtetra
.651 .747 .92 r
.37792 .63852 .38351 .64362 .39274 .64103 .38717 .6359 Mtetra
.65 .746 .92 r
.38717 .6359 .39274 .64103 .40201 .63845 .39646 .6333 Mtetra
.649 .746 .92 r
.39646 .6333 .40201 .63845 .4113 .63588 .40577 .63072 Mtetra
.647 .746 .921 r
.40577 .63072 .4113 .63588 .42063 .63331 .41512 .62816 Mtetra
.646 .746 .922 r
.41512 .62816 .42063 .63331 .42999 .63074 .4245 .62562 Mtetra
.645 .748 .924 r
.4245 .62562 .42999 .63074 .43939 .62816 .43392 .62308 Mtetra
.645 .75 .926 r
.43392 .62308 .43939 .62816 .44882 .62555 .44336 .62053 Mtetra
.646 .754 .928 r
.44336 .62053 .44882 .62555 .45829 .62288 .45285 .61793 Mtetra
.649 .758 .929 r
.45285 .61793 .45829 .62288 .46778 .62016 .46237 .61527 Mtetra
.652 .762 .93 r
.46237 .61527 .46778 .62016 .47732 .61736 .47192 .61252 Mtetra
.656 .766 .93 r
.47192 .61252 .47732 .61736 .48689 .61447 .48151 .60966 Mtetra
.659 .768 .93 r
.48151 .60966 .48689 .61447 .49649 .61152 .49114 .60671 Mtetra
.663 .77 .929 r
.49114 .60671 .49649 .61152 .50612 .60851 .5008 .60367 Mtetra
.665 .77 .928 r
.5008 .60367 .50612 .60851 .51579 .60547 .51049 .60057 Mtetra
.666 .769 .927 r
.51049 .60057 .51579 .60547 .52549 .60241 .52022 .59744 Mtetra
.665 .767 .925 r
.52022 .59744 .52549 .60241 .53523 .59935 .52997 .5943 Mtetra
.664 .764 .924 r
.52997 .5943 .53523 .59935 .545 .59631 .53976 .59119 Mtetra
.663 .761 .923 r
.53976 .59119 .545 .59631 .5548 .59329 .54959 .5881 Mtetra
.661 .759 .922 r
.54959 .5881 .5548 .59329 .56464 .5903 .55945 .58505 Mtetra
.66 .757 .922 r
.55945 .58505 .56464 .5903 .57451 .58732 .56935 .58202 Mtetra
.659 .755 .922 r
.56935 .58202 .57451 .58732 .58441 .58435 .57928 .57901 Mtetra
.658 .754 .921 r
.57928 .57901 .58441 .58435 .59436 .5814 .58924 .57602 Mtetra
.657 .753 .921 r
.58924 .57602 .59436 .5814 .60433 .57844 .59924 .57304 Mtetra
.656 .753 .921 r
.59924 .57304 .60433 .57844 .61435 .57549 .60928 .57006 Mtetra
.60928 .57006 .61435 .57549 .6244 .57253 .61935 .56708 Mtetra
.656 .752 .921 r
.61935 .56708 .6244 .57253 .63448 .56957 .62947 .56409 Mtetra
.655 .752 .921 r
.62947 .56409 .63448 .56957 .64461 .5666 .63961 .56111 Mtetra
.63961 .56111 .64461 .5666 .65477 .56363 .6498 .55812 Mtetra
.654 .752 .922 r
.6498 .55812 .65477 .56363 .66496 .56065 .66002 .55514 Mtetra
.66002 .55514 .66496 .56065 .6752 .55768 .67028 .55216 Mtetra
.652 .753 .923 r
.67028 .55216 .6752 .55768 .68547 .55472 .68058 .5492 Mtetra
.651 .753 .924 r
.68058 .5492 .68547 .55472 .69578 .55177 .69092 .54626 Mtetra
.649 .754 .926 r
.69092 .54626 .69578 .55177 .70613 .54884 .7013 .54335 Mtetra
.647 .754 .927 r
.7013 .54335 .70613 .54884 .71653 .54593 .71172 .54047 Mtetra
.646 .756 .929 r
.71172 .54047 .71653 .54593 .72696 .54304 .72219 .53762 Mtetra
.644 .757 .931 r
.72219 .53762 .72696 .54304 .73743 .54017 .73269 .53479 Mtetra
.643 .76 .933 r
.73269 .53479 .73743 .54017 .74795 .5373 .74324 .53195 Mtetra
.644 .762 .935 r
.74324 .53195 .74795 .5373 .7585 .53442 .75382 .52909 Mtetra
.646 .764 .935 r
.75382 .52909 .7585 .53442 .7691 .5315 .76445 .52616 Mtetra
.649 .766 .934 r
.76445 .52616 .7691 .5315 .77973 .52852 .7751 .52314 Mtetra
.653 .767 .933 r
.7751 .52314 .77973 .52852 .79039 .52546 .78579 .52002 Mtetra
.657 .766 .93 r
.78579 .52002 .79039 .52546 .80109 .52232 .79652 .51679 Mtetra
.66 .765 .927 r
.79652 .51679 .80109 .52232 .81182 .51911 .80727 .51347 Mtetra
.663 .762 .924 r
.80727 .51347 .81182 .51911 .82259 .51582 .81806 .51008 Mtetra
.665 .76 .921 r
.81806 .51008 .82259 .51582 .83339 .51248 .82889 .50664 Mtetra
.665 .757 .919 r
.82889 .50664 .83339 .51248 .84423 .50911 .83975 .50318 Mtetra
.665 .754 .917 r
.83975 .50318 .84423 .50911 .85511 .50572 .85065 .49972 Mtetra
.664 .752 .916 r
.85065 .49972 .85511 .50572 .86603 .50233 .8616 .49628 Mtetra
.663 .751 .916 r
.8616 .49628 .86603 .50233 .87699 .49894 .87259 .49285 Mtetra
.661 .75 .916 r
.87259 .49285 .87699 .49894 .888 .49555 .88362 .48945 Mtetra
.66 .75 .916 r
.88362 .48945 .888 .49555 .89904 .49218 .8947 .48606 Mtetra
.659 .75 .917 r
.8947 .48606 .89904 .49218 .91013 .4888 .90582 .48268 Mtetra
.90582 .48268 .91013 .4888 .92127 .48543 .91699 .47931 Mtetra
.658 .751 .918 r
.91699 .47931 .92127 .48543 .93244 .48206 .9282 .47594 Mtetra
.658 .751 .919 r
.9282 .47594 .93244 .48206 .94366 .47868 .93945 .47256 Mtetra
.655 .751 .921 r
.33552 .6441 .34122 .64908 .35035 .64644 .34466 .64141 Mtetra
.655 .75 .92 r
.34466 .64141 .35035 .64644 .35951 .64379 .35384 .63872 Mtetra
.654 .749 .919 r
.35384 .63872 .35951 .64379 .3687 .64115 .36305 .63603 Mtetra
.653 .747 .919 r
.36305 .63603 .3687 .64115 .37792 .63852 .37229 .63335 Mtetra
.652 .746 .918 r
.37229 .63335 .37792 .63852 .38717 .6359 .38157 .63069 Mtetra
.651 .745 .918 r
.38157 .63069 .38717 .6359 .39646 .6333 .39087 .62805 Mtetra
.649 .743 .918 r
.39087 .62805 .39646 .6333 .40577 .63072 .40021 .62545 Mtetra
.647 .743 .919 r
.40021 .62545 .40577 .63072 .41512 .62816 .40957 .62288 Mtetra
.645 .742 .92 r
.40957 .62288 .41512 .62816 .4245 .62562 .41897 .62036 Mtetra
.643 .743 .922 r
.41897 .62036 .4245 .62562 .43392 .62308 .42841 .61786 Mtetra
.642 .745 .924 r
.42841 .61786 .43392 .62308 .44336 .62053 .43788 .61537 Mtetra
.642 .748 .926 r
.43788 .61537 .44336 .62053 .45285 .61793 .44738 .61286 Mtetra
.644 .753 .928 r
.44738 .61286 .45285 .61793 .46237 .61527 .45692 .61029 Mtetra
.647 .758 .93 r
.45692 .61029 .46237 .61527 .47192 .61252 .46649 .60763 Mtetra
.652 .764 .931 r
.46649 .60763 .47192 .61252 .48151 .60966 .4761 .60484 Mtetra
.657 .769 .932 r
.4761 .60484 .48151 .60966 .49114 .60671 .48575 .60193 Mtetra
.662 .772 .931 r
.48575 .60193 .49114 .60671 .5008 .60367 .49543 .59888 Mtetra
.665 .774 .93 r
.49543 .59888 .5008 .60367 .51049 .60057 .50515 .59574 Mtetra
.667 .773 .929 r
.50515 .59574 .51049 .60057 .52022 .59744 .5149 .59254 Mtetra
.668 .771 .927 r
.5149 .59254 .52022 .59744 .52997 .5943 .52468 .58932 Mtetra
.667 .769 .926 r
.52468 .58932 .52997 .5943 .53976 .59119 .5345 .58612 Mtetra
.665 .765 .925 r
.5345 .58612 .53976 .59119 .54959 .5881 .54435 .58295 Mtetra
.663 .762 .924 r
.54435 .58295 .54959 .5881 .55945 .58505 .55423 .57982 Mtetra
.662 .76 .923 r
.55423 .57982 .55945 .58505 .56935 .58202 .56415 .57673 Mtetra
.66 .757 .922 r
.56415 .57673 .56935 .58202 .57928 .57901 .5741 .57367 Mtetra
.659 .756 .922 r
.5741 .57367 .57928 .57901 .58924 .57602 .58409 .57064 Mtetra
.657 .755 .922 r
.58409 .57064 .58924 .57602 .59924 .57304 .59412 .56762 Mtetra
.657 .754 .921 r
.59412 .56762 .59924 .57304 .60928 .57006 .60418 .56461 Mtetra
.656 .753 .921 r
.60418 .56461 .60928 .57006 .61935 .56708 .61428 .5616 Mtetra
.656 .753 .922 r
.61428 .5616 .61935 .56708 .62947 .56409 .62441 .5586 Mtetra
.655 .753 .922 r
.62441 .5586 .62947 .56409 .63961 .56111 .63459 .5556 Mtetra
.654 .753 .922 r
.63459 .5556 .63961 .56111 .6498 .55812 .6448 .5526 Mtetra
.654 .753 .923 r
.6448 .5526 .6498 .55812 .66002 .55514 .65505 .54961 Mtetra
.653 .753 .923 r
.65505 .54961 .66002 .55514 .67028 .55216 .66533 .54664 Mtetra
.651 .753 .925 r
.66533 .54664 .67028 .55216 .68058 .5492 .67566 .54369 Mtetra
.649 .754 .926 r
.67566 .54369 .68058 .5492 .69092 .54626 .68603 .54078 Mtetra
.647 .755 .928 r
.68603 .54078 .69092 .54626 .7013 .54335 .69644 .5379 Mtetra
.644 .756 .93 r
.69644 .5379 .7013 .54335 .71172 .54047 .70689 .53507 Mtetra
.642 .758 .933 r
.70689 .53507 .71172 .54047 .72219 .53762 .71739 .53226 Mtetra
.64 .76 .935 r
.71739 .53226 .72219 .53762 .73269 .53479 .72792 .52948 Mtetra
.64 .763 .937 r
.72792 .52948 .73269 .53479 .74324 .53195 .7385 .52667 Mtetra
.642 .765 .938 r
.7385 .52667 .74324 .53195 .75382 .52909 .74912 .52381 Mtetra
.646 .768 .937 r
.74912 .52381 .75382 .52909 .76445 .52616 .75977 .52085 Mtetra
.651 .769 .935 r
.75977 .52085 .76445 .52616 .7751 .52314 .77045 .51775 Mtetra
.656 .769 .932 r
.77045 .51775 .7751 .52314 .78579 .52002 .78116 .51452 Mtetra
.661 .767 .928 r
.78116 .51452 .78579 .52002 .79652 .51679 .79191 .51116 Mtetra
.665 .764 .924 r
.79191 .51116 .79652 .51679 .80727 .51347 .80268 .5077 Mtetra
.667 .76 .92 r
.80268 .5077 .80727 .51347 .81806 .51008 .81349 .50418 Mtetra
.668 .757 .917 r
.81349 .50418 .81806 .51008 .82889 .50664 .82434 .50063 Mtetra
.667 .753 .915 r
.82434 .50063 .82889 .50664 .83975 .50318 .83522 .49709 Mtetra
.666 .751 .913 r
.83522 .49709 .83975 .50318 .85065 .49972 .84615 .49357 Mtetra
.664 .749 .913 r
.84615 .49357 .85065 .49972 .8616 .49628 .85713 .49009 Mtetra
.662 .748 .913 r
.85713 .49009 .8616 .49628 .87259 .49285 .86815 .48665 Mtetra
.661 .747 .914 r
.86815 .48665 .87259 .49285 .88362 .48945 .87922 .48324 Mtetra
.659 .747 .915 r
.87922 .48324 .88362 .48945 .8947 .48606 .89033 .47986 Mtetra
.658 .748 .916 r
.89033 .47986 .8947 .48606 .90582 .48268 .90148 .47649 Mtetra
.658 .749 .917 r
.90148 .47649 .90582 .48268 .91699 .47931 .91268 .47313 Mtetra
.657 .75 .918 r
.91268 .47313 .91699 .47931 .9282 .47594 .92393 .46976 Mtetra
.657 .751 .919 r
.92393 .46976 .9282 .47594 .93945 .47256 .93521 .46639 Mtetra
.656 .751 .92 r
.32977 .63908 .33552 .6441 .34466 .64141 .33894 .63635 Mtetra
.656 .75 .919 r
.33894 .63635 .34466 .64141 .35384 .63872 .34814 .6336 Mtetra
.656 .749 .918 r
.34814 .6336 .35384 .63872 .36305 .63603 .35737 .63086 Mtetra
.655 .747 .917 r
.35737 .63086 .36305 .63603 .37229 .63335 .36664 .62812 Mtetra
.654 .745 .917 r
.36664 .62812 .37229 .63335 .38157 .63069 .37593 .62539 Mtetra
.653 .743 .916 r
.37593 .62539 .38157 .63069 .39087 .62805 .38526 .6227 Mtetra
.651 .741 .916 r
.38526 .6227 .39087 .62805 .40021 .62545 .39461 .62004 Mtetra
.648 .739 .916 r
.39461 .62004 .40021 .62545 .40957 .62288 .404 .61744 Mtetra
.645 .738 .917 r
.404 .61744 .40957 .62288 .41897 .62036 .41342 .61491 Mtetra
.642 .737 .918 r
.41342 .61491 .41897 .62036 .42841 .61786 .42287 .61244 Mtetra
.639 .738 .92 r
.42287 .61244 .42841 .61786 .43788 .61537 .43236 .61002 Mtetra
.638 .741 .923 r
.43236 .61002 .43788 .61537 .44738 .61286 .44188 .60761 Mtetra
.638 .746 .927 r
.44188 .60761 .44738 .61286 .45692 .61029 .45143 .60518 Mtetra
.641 .752 .93 r
.45143 .60518 .45692 .61029 .46649 .60763 .46103 .60266 Mtetra
.646 .76 .932 r
.46103 .60266 .46649 .60763 .4761 .60484 .47066 .59999 Mtetra
.652 .767 .934 r
.47066 .59999 .4761 .60484 .48575 .60193 .48033 .59716 Mtetra
.659 .774 .934 r
.48033 .59716 .48575 .60193 .49543 .59888 .49003 .59415 Mtetra
.665 .777 .933 r
.49003 .59415 .49543 .59888 .50515 .59574 .49977 .59099 Mtetra
.669 .778 .931 r
.49977 .59099 .50515 .59574 .5149 .59254 .50955 .58773 Mtetra
.67 .777 .93 r
.50955 .58773 .5149 .59254 .52468 .58932 .51936 .58443 Mtetra
.67 .774 .928 r
.51936 .58443 .52468 .58932 .5345 .58612 .5292 .58112 Mtetra
.669 .771 .926 r
.5292 .58112 .5345 .58612 .54435 .58295 .53907 .57785 Mtetra
.666 .767 .925 r
.53907 .57785 .54435 .58295 .55423 .57982 .54898 .57463 Mtetra
.664 .763 .924 r
.54898 .57463 .55423 .57982 .56415 .57673 .55892 .57146 Mtetra
.661 .76 .923 r
.55892 .57146 .56415 .57673 .5741 .57367 .5689 .56834 Mtetra
.66 .758 .923 r
.5689 .56834 .5741 .57367 .58409 .57064 .57891 .56525 Mtetra
.658 .756 .922 r
.57891 .56525 .58409 .57064 .59412 .56762 .58896 .56219 Mtetra
.657 .755 .922 r
.58896 .56219 .59412 .56762 .60418 .56461 .59905 .55915 Mtetra
.656 .754 .922 r
.59905 .55915 .60418 .56461 .61428 .5616 .60917 .55612 Mtetra
.60917 .55612 .61428 .5616 .62441 .5586 .61933 .5531 Mtetra
.655 .754 .923 r
.61933 .5531 .62441 .5586 .63459 .5556 .62953 .55008 Mtetra
.654 .754 .923 r
.62953 .55008 .63459 .5556 .6448 .5526 .63977 .54708 Mtetra
.653 .754 .924 r
.63977 .54708 .6448 .5526 .65505 .54961 .65004 .54409 Mtetra
.651 .754 .925 r
.65004 .54409 .65505 .54961 .66533 .54664 .66035 .54113 Mtetra
.649 .755 .926 r
.66035 .54113 .66533 .54664 .67566 .54369 .67071 .5382 Mtetra
.646 .755 .929 r
.67071 .5382 .67566 .54369 .68603 .54078 .68111 .53533 Mtetra
.643 .757 .931 r
.68111 .53533 .68603 .54078 .69644 .5379 .69155 .5325 Mtetra
.64 .758 .934 r
.69155 .5325 .69644 .5379 .70689 .53507 .70203 .52973 Mtetra
.638 .761 .937 r
.70203 .52973 .70689 .53507 .71739 .53226 .71256 .52699 Mtetra
.636 .764 .94 r
.71256 .52699 .71739 .53226 .72792 .52948 .72313 .52426 Mtetra
.637 .767 .941 r
.72313 .52426 .72792 .52948 .7385 .52667 .73374 .52148 Mtetra
.641 .77 .941 r
.73374 .52148 .7385 .52667 .74912 .52381 .74438 .51858 Mtetra
.647 .772 .939 r
.74438 .51858 .74912 .52381 .75977 .52085 .75506 .51555 Mtetra
.655 .773 .935 r
.75506 .51555 .75977 .52085 .77045 .51775 .76576 .51233 Mtetra
.662 .771 .93 r
.76576 .51233 .77045 .51775 .78116 .51452 .77649 .50893 Mtetra
.668 .767 .924 r
.77649 .50893 .78116 .51452 .79191 .51116 .78725 .50539 Mtetra
.671 .762 .919 r
.78725 .50539 .79191 .51116 .80268 .5077 .79805 .50175 Mtetra
.672 .757 .914 r
.79805 .50175 .80268 .5077 .81349 .50418 .80887 .49808 Mtetra
.671 .752 .911 r
.80887 .49808 .81349 .50418 .82434 .50063 .81974 .49441 Mtetra
.669 .748 .91 r
.81974 .49441 .82434 .50063 .83522 .49709 .83065 .4908 Mtetra
.667 .745 .909 r
.83065 .4908 .83522 .49709 .84615 .49357 .84161 .48725 Mtetra
.664 .744 .91 r
.84161 .48725 .84615 .49357 .85713 .49009 .85262 .48377 Mtetra
.661 .743 .911 r
.85262 .48377 .85713 .49009 .86815 .48665 .86367 .48034 Mtetra
.659 .744 .913 r
.86367 .48034 .86815 .48665 .87922 .48324 .87477 .47695 Mtetra
.658 .745 .914 r
.87477 .47695 .87922 .48324 .89033 .47986 .88592 .47359 Mtetra
.657 .746 .916 r
.88592 .47359 .89033 .47986 .90148 .47649 .89711 .47024 Mtetra
.656 .747 .917 r
.89711 .47024 .90148 .47649 .91268 .47313 .90834 .46689 Mtetra
.656 .749 .918 r
.90834 .46689 .91268 .47313 .92393 .46976 .91962 .46354 Mtetra
.656 .75 .919 r
.91962 .46354 .92393 .46976 .93521 .46639 .93095 .46018 Mtetra
.657 .752 .92 r
.32399 .63404 .32977 .63908 .33894 .63635 .33318 .63126 Mtetra
.657 .751 .919 r
.33318 .63126 .33894 .63635 .34814 .6336 .3424 .62847 Mtetra
.657 .75 .918 r
.3424 .62847 .34814 .6336 .35737 .63086 .35166 .62567 Mtetra
.657 .748 .917 r
.35166 .62567 .35737 .63086 .36664 .62812 .36094 .62287 Mtetra
.657 .746 .916 r
.36094 .62287 .36664 .62812 .37593 .62539 .37026 .62007 Mtetra
.655 .744 .915 r
.37026 .62007 .37593 .62539 .38526 .6227 .37961 .61729 Mtetra
.653 .741 .914 r
.37961 .61729 .38526 .6227 .39461 .62004 .38898 .61456 Mtetra
.651 .738 .913 r
.38898 .61456 .39461 .62004 .404 .61744 .39839 .61189 Mtetra
.647 .735 .914 r
.39839 .61189 .404 .61744 .41342 .61491 .40783 .6093 Mtetra
.642 .732 .914 r
.40783 .6093 .41342 .61491 .42287 .61244 .4173 .60681 Mtetra
.637 .731 .916 r
.4173 .60681 .42287 .61244 .43236 .61002 .4268 .60443 Mtetra
.634 .732 .919 r
.4268 .60443 .43236 .61002 .44188 .60761 .43634 .60212 Mtetra
.631 .735 .923 r
.43634 .60212 .44188 .60761 .45143 .60518 .44591 .59983 Mtetra
.633 .742 .927 r
.44591 .59983 .45143 .60518 .46103 .60266 .45553 .59749 Mtetra
.637 .751 .931 r
.45553 .59749 .46103 .60266 .47066 .59999 .46518 .59501 Mtetra
.644 .761 .934 r
.46518 .59501 .47066 .59999 .48033 .59716 .47487 .59234 Mtetra
.654 .771 .935 r
.47487 .59234 .48033 .59716 .49003 .59415 .48459 .58943 Mtetra
.662 .778 .936 r
.48459 .58943 .49003 .59415 .49977 .59099 .49436 .58632 Mtetra
.669 .783 .934 r
.49436 .58632 .49977 .59099 .50955 .58773 .50416 .58303 Mtetra
.672 .783 .933 r
.50416 .58303 .50955 .58773 .51936 .58443 .51399 .57965 Mtetra
.673 .781 .931 r
.51399 .57965 .51936 .58443 .5292 .58112 .52386 .57624 Mtetra
.672 .777 .929 r
.52386 .57624 .5292 .58112 .53907 .57785 .53376 .57285 Mtetra
.669 .773 .927 r
.53376 .57285 .53907 .57785 .54898 .57463 .54369 .56952 Mtetra
.667 .769 .926 r
.54369 .56952 .54898 .57463 .55892 .57146 .55365 .56625 Mtetra
.664 .765 .925 r
.55365 .56625 .55892 .57146 .5689 .56834 .56366 .56305 Mtetra
.661 .762 .924 r
.56366 .56305 .5689 .56834 .57891 .56525 .57369 .5599 Mtetra
.659 .759 .924 r
.57369 .5599 .57891 .56525 .58896 .56219 .58377 .55679 Mtetra
.658 .758 .924 r
.58377 .55679 .58896 .56219 .59905 .55915 .59388 .55371 Mtetra
.657 .756 .924 r
.59388 .55371 .59905 .55915 .60917 .55612 .60403 .55065 Mtetra
.655 .756 .924 r
.60403 .55065 .60917 .55612 .61933 .5531 .61421 .5476 Mtetra
.654 .755 .924 r
.61421 .5476 .61933 .5531 .62953 .55008 .62444 .54458 Mtetra
.653 .755 .925 r
.62444 .54458 .62953 .55008 .63977 .54708 .6347 .54157 Mtetra
.651 .755 .926 r
.6347 .54157 .63977 .54708 .65004 .54409 .645 .53859 Mtetra
.649 .756 .927 r
.645 .53859 .65004 .54409 .66035 .54113 .65534 .53566 Mtetra
.646 .757 .93 r
.65534 .53566 .66035 .54113 .67071 .5382 .66573 .53277 Mtetra
.642 .758 .932 r
.66573 .53277 .67071 .5382 .68111 .53533 .67616 .52996 Mtetra
.639 .76 .936 r
.67616 .52996 .68111 .53533 .69155 .5325 .68663 .5272 Mtetra
.635 .762 .939 r
.68663 .5272 .69155 .5325 .70203 .52973 .69714 .52451 Mtetra
.633 .765 .943 r
.69714 .52451 .70203 .52973 .71256 .52699 .7077 .52184 Mtetra
.633 .768 .945 r
.7077 .52184 .71256 .52699 .72313 .52426 .71831 .51914 Mtetra
.636 .772 .945 r
.71831 .51914 .72313 .52426 .73374 .52148 .72894 .51635 Mtetra
.643 .775 .943 r
.72894 .51635 .73374 .52148 .74438 .51858 .73961 .51337 Mtetra
.652 .776 .939 r
.73961 .51337 .74438 .51858 .75506 .51555 .75031 .51019 Mtetra
.663 .774 .932 r
.75031 .51019 .75506 .51555 .76576 .51233 .76103 .50676 Mtetra
.671 .77 .925 r
.76103 .50676 .76576 .51233 .77649 .50893 .77178 .50313 Mtetra
.676 .764 .917 r
.77178 .50313 .77649 .50893 .78725 .50539 .78255 .49936 Mtetra
.677 .757 .911 r
.78255 .49936 .78725 .50539 .79805 .50175 .79336 .49552 Mtetra
.676 .75 .907 r
.79336 .49552 .79805 .50175 .80887 .49808 .80421 .49172 Mtetra
.673 .745 .905 r
.80421 .49172 .80887 .49808 .81974 .49441 .8151 .48797 Mtetra
.669 .742 .905 r
.8151 .48797 .81974 .49441 .83065 .4908 .82604 .48434 Mtetra
.665 .74 .906 r
.82604 .48434 .83065 .4908 .84161 .48725 .83703 .4808 Mtetra
.662 .74 .908 r
.83703 .4808 .84161 .48725 .85262 .48377 .84807 .47735 Mtetra
.659 .741 .91 r
.84807 .47735 .85262 .48377 .86367 .48034 .85916 .47396 Mtetra
.657 .742 .913 r
.85916 .47396 .86367 .48034 .87477 .47695 .87029 .47061 Mtetra
.656 .744 .915 r
.87029 .47061 .87477 .47695 .88592 .47359 .88148 .46728 Mtetra
.655 .746 .917 r
.88148 .46728 .88592 .47359 .89711 .47024 .8927 .46395 Mtetra
.655 .747 .918 r
.8927 .46395 .89711 .47024 .90834 .46689 .90397 .46062 Mtetra
.654 .749 .919 r
.90397 .46062 .90834 .46689 .91962 .46354 .91529 .45728 Mtetra
.655 .75 .92 r
.91529 .45728 .91962 .46354 .93095 .46018 .92665 .45393 Mtetra
.658 .752 .919 r
.31818 .62896 .32399 .63404 .33318 .63126 .32739 .62616 Mtetra
.32739 .62616 .33318 .63126 .3424 .62847 .33663 .62333 Mtetra
.659 .751 .918 r
.33663 .62333 .3424 .62847 .35166 .62567 .3459 .62048 Mtetra
.659 .75 .917 r
.3459 .62048 .35166 .62567 .36094 .62287 .35521 .61762 Mtetra
.659 .749 .916 r
.35521 .61762 .36094 .62287 .37026 .62007 .36455 .61474 Mtetra
.659 .746 .915 r
.36455 .61474 .37026 .62007 .37961 .61729 .37392 .61187 Mtetra
.658 .743 .913 r
.37392 .61187 .37961 .61729 .38898 .61456 .38332 .60902 Mtetra
.655 .739 .911 r
.38332 .60902 .38898 .61456 .39839 .61189 .39275 .60623 Mtetra
.651 .734 .91 r
.39275 .60623 .39839 .61189 .40783 .6093 .40221 .60353 Mtetra
.645 .729 .91 r
.40221 .60353 .40783 .6093 .4173 .60681 .41171 .60097 Mtetra
.638 .724 .911 r
.41171 .60097 .4173 .60681 .4268 .60443 .42123 .59857 Mtetra
.632 .722 .913 r
.42123 .59857 .4268 .60443 .43634 .60212 .43078 .5963 Mtetra
.625 .723 .917 r
.43078 .5963 .43634 .60212 .44591 .59983 .44037 .59417 Mtetra
.624 .729 .922 r
.44037 .59417 .44591 .59983 .45553 .59749 .44999 .59204 Mtetra
.626 .738 .928 r
.44999 .59204 .45553 .59749 .46518 .59501 .45966 .58982 Mtetra
.633 .751 .933 r
.45966 .58982 .46518 .59501 .47487 .59234 .46937 .58741 Mtetra
.644 .765 .937 r
.46937 .58741 .47487 .59234 .48459 .58943 .47912 .5847 Mtetra
.655 .777 .938 r
.47912 .5847 .48459 .58943 .49436 .58632 .4889 .58171 Mtetra
.666 .786 .938 r
.4889 .58171 .49436 .58632 .50416 .58303 .49873 .57844 Mtetra
.673 .789 .936 r
.49873 .57844 .50416 .58303 .51399 .57965 .50859 .57501 Mtetra
.676 .789 .934 r
.50859 .57501 .51399 .57965 .52386 .57624 .51848 .5715 Mtetra
.676 .786 .932 r
.51848 .5715 .52386 .57624 .53376 .57285 .52841 .56798 Mtetra
.673 .781 .93 r
.52841 .56798 .53376 .57285 .54369 .56952 .53836 .56453 Mtetra
.67 .776 .929 r
.53836 .56453 .54369 .56952 .55365 .56625 .54835 .56114 Mtetra
.667 .771 .927 r
.54835 .56114 .55365 .56625 .56366 .56305 .55838 .55784 Mtetra
.664 .767 .926 r
.55838 .55784 .56366 .56305 .57369 .5599 .56844 .5546 Mtetra
.661 .763 .926 r
.56844 .5546 .57369 .5599 .58377 .55679 .57854 .55143 Mtetra
.659 .761 .925 r
.57854 .55143 .58377 .55679 .59388 .55371 .58868 .5483 Mtetra
.657 .759 .925 r
.58868 .5483 .59388 .55371 .60403 .55065 .59885 .54521 Mtetra
.655 .758 .926 r
.59885 .54521 .60403 .55065 .61421 .5476 .60906 .54214 Mtetra
.653 .758 .926 r
.60906 .54214 .61421 .5476 .62444 .54458 .61931 .53911 Mtetra
.652 .758 .927 r
.61931 .53911 .62444 .54458 .6347 .54157 .6296 .53611 Mtetra
.649 .758 .929 r
.6296 .53611 .6347 .54157 .645 .53859 .63993 .53315 Mtetra
.646 .758 .931 r
.63993 .53315 .645 .53859 .65534 .53566 .6503 .53026 Mtetra
.642 .76 .934 r
.6503 .53026 .65534 .53566 .66573 .53277 .66072 .52744 Mtetra
.637 .761 .938 r
.66072 .52744 .66573 .53277 .67616 .52996 .67118 .5247 Mtetra
.633 .764 .942 r
.67118 .5247 .67616 .52996 .68663 .5272 .68168 .52204 Mtetra
.628 .766 .946 r
.68168 .52204 .68663 .5272 .69714 .52451 .69223 .51943 Mtetra
.627 .77 .949 r
.69223 .51943 .69714 .52451 .7077 .52184 .70282 .51683 Mtetra
.63 .775 .95 r
.70282 .51683 .7077 .52184 .71831 .51914 .71346 .51414 Mtetra
.636 .779 .949 r
.71346 .51414 .71831 .51914 .72894 .51635 .72412 .51128 Mtetra
.649 .781 .944 r
.72412 .51128 .72894 .51635 .73961 .51337 .73481 .50814 Mtetra
.662 .78 .936 r
.73481 .50814 .73961 .51337 .75031 .51019 .74553 .50471 Mtetra
.674 .775 .926 r
.74553 .50471 .75031 .51019 .76103 .50676 .75626 .50098 Mtetra
.681 .767 .916 r
.75626 .50098 .76103 .50676 .77178 .50313 .76701 .49704 Mtetra
.684 .757 .907 r
.76701 .49704 .77178 .50313 .78255 .49936 .7778 .493 Mtetra
.683 .749 .901 r
.7778 .493 .78255 .49936 .79336 .49552 .78862 .48897 Mtetra
.678 .741 .898 r
.78862 .48897 .79336 .49552 .80421 .49172 .79949 .48507 Mtetra
.673 .737 .898 r
.79949 .48507 .80421 .49172 .8151 .48797 .81041 .4813 Mtetra
.667 .734 .9 r
.81041 .4813 .8151 .48797 .82604 .48434 .82138 .4777 Mtetra
.662 .734 .904 r
.82138 .4777 .82604 .48434 .83703 .4808 .83241 .47424 Mtetra
.658 .736 .907 r
.83241 .47424 .83703 .4808 .84807 .47735 .84349 .47087 Mtetra
.655 .739 .911 r
.84349 .47087 .84807 .47735 .85916 .47396 .85462 .46756 Mtetra
.654 .742 .914 r
.85462 .46756 .85916 .47396 .87029 .47061 .86579 .46426 Mtetra
.653 .744 .917 r
.86579 .46426 .87029 .47061 .88148 .46728 .87701 .46098 Mtetra
.653 .747 .918 r
.87701 .46098 .88148 .46728 .8927 .46395 .88827 .45767 Mtetra
.654 .748 .919 r
.88827 .45767 .8927 .46395 .90397 .46062 .89958 .45434 Mtetra
.654 .749 .92 r
.89958 .45434 .90397 .46062 .91529 .45728 .91093 .451 Mtetra
.654 .75 .92 r
.91093 .451 .91529 .45728 .92665 .45393 .92232 .44763 Mtetra
.657 .752 .92 r
.31232 .62385 .31818 .62896 .32739 .62616 .32155 .62104 Mtetra
.658 .752 .92 r
.32155 .62104 .32739 .62616 .33663 .62333 .33081 .6182 Mtetra
.659 .753 .92 r
.33081 .6182 .33663 .62333 .3459 .62048 .34011 .61534 Mtetra
.659 .753 .919 r
.34011 .61534 .3459 .62048 .35521 .61762 .34943 .61244 Mtetra
.661 .753 .918 r
.34943 .61244 .35521 .61762 .36455 .61474 .35879 .6095 Mtetra
.661 .751 .917 r
.35879 .6095 .36455 .61474 .37392 .61187 .36819 .60654 Mtetra
.662 .749 .914 r
.36819 .60654 .37392 .61187 .38332 .60902 .37762 .60356 Mtetra
.66 .744 .912 r
.37762 .60356 .38332 .60902 .39275 .60623 .38707 .60061 Mtetra
.657 .738 .91 r
.38707 .60061 .39275 .60623 .40221 .60353 .39656 .59774 Mtetra
.651 .731 .908 r
.39656 .59774 .40221 .60353 .41171 .60097 .40608 .595 Mtetra
.643 .723 .907 r
.40608 .595 .41171 .60097 .42123 .59857 .41562 .59248 Mtetra
.633 .717 .907 r
.41562 .59248 .42123 .59857 .43078 .5963 .42519 .59017 Mtetra
.622 .712 .91 r
.42519 .59017 .43078 .5963 .44037 .59417 .4348 .58811 Mtetra
.616 .713 .915 r
.4348 .58811 .44037 .59417 .44999 .59204 .44444 .58616 Mtetra
.613 .72 .921 r
.44444 .58616 .44999 .59204 .45966 .58982 .45412 .58425 Mtetra
.618 .733 .928 r
.45412 .58425 .45966 .58982 .46937 .58741 .46384 .58218 Mtetra
.63 .751 .934 r
.46384 .58218 .46937 .58741 .47912 .5847 .4736 .57979 Mtetra
.644 .768 .939 r
.4736 .57979 .47912 .5847 .4889 .58171 .48341 .57705 Mtetra
.66 .784 .94 r
.48341 .57705 .4889 .58171 .49873 .57844 .49326 .57392 Mtetra
.67 .793 .94 r
.49326 .57392 .49873 .57844 .50859 .57501 .50315 .57053 Mtetra
.677 .797 .938 r
.50315 .57053 .50859 .57501 .51848 .5715 .51307 .56695 Mtetra
.679 .795 .936 r
.51307 .56695 .51848 .5715 .52841 .56798 .52302 .56332 Mtetra
.678 .791 .935 r
.52302 .56332 .52841 .56798 .53836 .56453 .533 .55972 Mtetra
.675 .785 .933 r
.533 .55972 .53836 .56453 .54835 .56114 .54302 .55619 Mtetra
.67 .779 .931 r
.54302 .55619 .54835 .56114 .55838 .55784 .55307 .55276 Mtetra
.666 .774 .93 r
.55307 .55276 .55838 .55784 .56844 .5546 .56316 .54943 Mtetra
.663 .77 .929 r
.56316 .54943 .56844 .5546 .57854 .55143 .57328 .54618 Mtetra
.66 .767 .929 r
.57328 .54618 .57854 .55143 .58868 .5483 .58344 .54299 Mtetra
.657 .765 .929 r
.58344 .54299 .58868 .5483 .59885 .54521 .59364 .53986 Mtetra
.655 .763 .929 r
.59364 .53986 .59885 .54521 .60906 .54214 .60388 .53677 Mtetra
.652 .762 .93 r
.60388 .53677 .60906 .54214 .61931 .53911 .61416 .53373 Mtetra
.649 .762 .932 r
.61416 .53373 .61931 .53911 .6296 .53611 .62447 .53075 Mtetra
.646 .762 .934 r
.62447 .53075 .6296 .53611 .63993 .53315 .63483 .52784 Mtetra
.641 .763 .937 r
.63483 .52784 .63993 .53315 .6503 .53026 .64523 .52501 Mtetra
.636 .765 .94 r
.64523 .52501 .6503 .53026 .66072 .52744 .65568 .52226 Mtetra
.63 .767 .945 r
.65568 .52226 .66072 .52744 .67118 .5247 .66617 .51963 Mtetra
.625 .77 .95 r
.66617 .51963 .67118 .5247 .68168 .52204 .67671 .51707 Mtetra
.621 .773 .954 r
.67671 .51707 .68168 .52204 .69223 .51943 .68729 .51454 Mtetra
.622 .778 .956 r
.68729 .51454 .69223 .51943 .70282 .51683 .69792 .51196 Mtetra
.63 .783 .955 r
.69792 .51196 .70282 .51683 .71346 .51414 .70858 .5092 Mtetra
.643 .785 .95 r
.70858 .5092 .71346 .51414 .72412 .51128 .71926 .50616 Mtetra
.661 .785 .94 r
.71926 .50616 .72412 .51128 .73481 .50814 .72997 .50272 Mtetra
.676 .779 .928 r
.72997 .50272 .73481 .50814 .74553 .50471 .74069 .49892 Mtetra
.688 .77 .914 r
.74069 .49892 .74553 .50471 .75626 .50098 .75143 .4948 Mtetra
.692 .758 .902 r
.75143 .4948 .75626 .50098 .76701 .49704 .76219 .4905 Mtetra
.69 .746 .894 r
.76219 .4905 .76701 .49704 .7778 .493 .77298 .48623 Mtetra
.685 .737 .89 r
.77298 .48623 .7778 .493 .78862 .48897 .78382 .48208 Mtetra
.676 .731 .891 r
.78382 .48208 .78862 .48897 .79949 .48507 .79472 .47818 Mtetra
.669 .729 .894 r
.79472 .47818 .79949 .48507 .81041 .4813 .80568 .4745 Mtetra
.662 .729 .9 r
.80568 .4745 .81041 .4813 .82138 .4777 .81669 .47103 Mtetra
.656 .732 .906 r
.81669 .47103 .82138 .4777 .83241 .47424 .82777 .46771 Mtetra
.653 .737 .911 r
.82777 .46771 .83241 .47424 .84349 .47087 .83889 .46445 Mtetra
.651 .741 .915 r
.83889 .46445 .84349 .47087 .85462 .46756 .85006 .46123 Mtetra
.651 .745 .918 r
.85006 .46123 .85462 .46756 .86579 .46426 .86127 .45799 Mtetra
.651 .748 .92 r
.86127 .45799 .86579 .46426 .87701 .46098 .87252 .45473 Mtetra
.652 .75 .921 r
.87252 .45473 .87701 .46098 .88827 .45767 .88382 .45142 Mtetra
.653 .751 .922 r
.88382 .45142 .88827 .45767 .89958 .45434 .89516 .44807 Mtetra
.654 .751 .921 r
.89516 .44807 .89958 .45434 .91093 .451 .90654 .44469 Mtetra
.90654 .44469 .91093 .451 .92232 .44763 .91796 .44128 Mtetra
.655 .751 .92 r
.30643 .61871 .31232 .62385 .32155 .62104 .31568 .61592 Mtetra
.656 .753 .921 r
.31568 .61592 .32155 .62104 .33081 .6182 .32495 .61311 Mtetra
.657 .755 .922 r
.32495 .61311 .33081 .6182 .34011 .61534 .33427 .61026 Mtetra
.659 .756 .922 r
.33427 .61026 .34011 .61534 .34943 .61244 .34361 .60736 Mtetra
.661 .758 .922 r
.34361 .60736 .34943 .61244 .35879 .6095 .353 .60439 Mtetra
.663 .758 .921 r
.353 .60439 .35879 .6095 .36819 .60654 .36241 .60136 Mtetra
.666 .757 .918 r
.36241 .60136 .36819 .60654 .37762 .60356 .37187 .59826 Mtetra
.666 .753 .915 r
.37187 .59826 .37762 .60356 .38707 .60061 .38135 .59514 Mtetra
.666 .747 .911 r
.38135 .59514 .38707 .60061 .39656 .59774 .39087 .59202 Mtetra
.661 .738 .907 r
.39087 .59202 .39656 .59774 .40608 .595 .40041 .58902 Mtetra
.653 .727 .903 r
.40041 .58902 .40608 .595 .41562 .59248 .40998 .58623 Mtetra
.641 .715 .901 r
.40998 .58623 .41562 .59248 .42519 .59017 .41958 .58372 Mtetra
.625 .704 .902 r
.41958 .58372 .42519 .59017 .4348 .58811 .4292 .5816 Mtetra
.613 .698 .905 r
.4292 .5816 .4348 .58811 .44444 .58616 .43886 .57977 Mtetra
.602 .698 .911 r
.43886 .57977 .44444 .58616 .45412 .58425 .44854 .57816 Mtetra
.601 .709 .92 r
.44854 .57816 .45412 .58425 .46384 .58218 .45828 .5765 Mtetra
.61 .728 .929 r
.45828 .5765 .46384 .58218 .4736 .57979 .46806 .57458 Mtetra
.625 .752 .938 r
.46806 .57458 .4736 .57979 .48341 .57705 .47788 .57226 Mtetra
.646 .776 .942 r
.47788 .57226 .48341 .57705 .49326 .57392 .48775 .56941 Mtetra
.662 .793 .944 r
.48775 .56941 .49326 .57392 .50315 .57053 .49766 .56617 Mtetra
.675 .803 .943 r
.49766 .56617 .50315 .57053 .51307 .56695 .50761 .5626 Mtetra
.681 .805 .942 r
.50761 .5626 .51307 .56695 .52302 .56332 .51759 .55888 Mtetra
.682 .803 .94 r
.51759 .55888 .52302 .56332 .533 .55972 .5276 .55514 Mtetra
.679 .798 .938 r
.5276 .55514 .533 .55972 .54302 .55619 .53765 .55146 Mtetra
.675 .791 .936 r
.53765 .55146 .54302 .55619 .55307 .55276 .54772 .54789 Mtetra
.67 .785 .935 r
.54772 .54789 .55307 .55276 .56316 .54943 .55784 .54443 Mtetra
.665 .779 .934 r
.55784 .54443 .56316 .54943 .57328 .54618 .56799 .54108 Mtetra
.661 .775 .934 r
.56799 .54108 .57328 .54618 .58344 .54299 .57817 .53782 Mtetra
.657 .772 .934 r
.57817 .53782 .58344 .54299 .59364 .53986 .5884 .53464 Mtetra
.654 .77 .934 r
.5884 .53464 .59364 .53986 .60388 .53677 .59866 .53154 Mtetra
.65 .769 .935 r
.59866 .53154 .60388 .53677 .61416 .53373 .60897 .52851 Mtetra
.646 .768 .938 r
.60897 .52851 .61416 .53373 .62447 .53075 .61931 .52556 Mtetra
.641 .769 .94 r
.61931 .52556 .62447 .53075 .63483 .52784 .6297 .5227 Mtetra
.635 .77 .944 r
.6297 .5227 .63483 .52784 .64523 .52501 .64013 .51995 Mtetra
.628 .772 .949 r
.64013 .51995 .64523 .52501 .65568 .52226 .65061 .51732 Mtetra
.621 .774 .954 r
.65061 .51732 .65568 .52226 .66617 .51963 .66114 .5148 Mtetra
.616 .778 .959 r
.66114 .5148 .66617 .51963 .67671 .51707 .67171 .51233 Mtetra
.614 .783 .962 r
.67171 .51233 .67671 .51707 .68729 .51454 .68233 .50985 Mtetra
.62 .787 .962 r
.68233 .50985 .68729 .51454 .69792 .51196 .69298 .50722 Mtetra
.636 .792 .957 r
.69298 .50722 .69792 .51196 .70858 .5092 .70366 .50426 Mtetra
.656 .791 .947 r
.70366 .50426 .70858 .5092 .71926 .50616 .71436 .50089 Mtetra
.679 .786 .931 r
.71436 .50089 .71926 .50616 .72997 .50272 .72507 .49699 Mtetra
.694 .774 .913 r
.72507 .49699 .72997 .50272 .74069 .49892 .73579 .49267 Mtetra
.701 .759 .897 r
.73579 .49267 .74069 .49892 .75143 .4948 .74653 .48808 Mtetra
.701 .744 .885 r
.74653 .48808 .75143 .4948 .76219 .4905 .75729 .48343 Mtetra
.692 .731 .88 r
.75729 .48343 .76219 .4905 .77298 .48623 .7681 .479 Mtetra
.682 .723 .881 r
.7681 .479 .77298 .48623 .78382 .48208 .77898 .47486 Mtetra
.67 .72 .886 r
.77898 .47486 .78382 .48208 .79472 .47818 .78992 .47112 Mtetra
.66 .721 .894 r
.78992 .47112 .79472 .47818 .80568 .4745 .80092 .46767 Mtetra
.653 .726 .903 r
.80092 .46767 .80568 .4745 .81669 .47103 .81199 .46443 Mtetra
.648 .733 .911 r
.81199 .46443 .81669 .47103 .82777 .46771 .82311 .46132 Mtetra
.646 .741 .918 r
.82311 .46132 .82777 .46771 .83889 .46445 .83427 .4582 Mtetra
.646 .746 .922 r
.83427 .4582 .83889 .46445 .85006 .46123 .84548 .45507 Mtetra
.648 .751 .924 r
.84548 .45507 .85006 .46123 .86127 .45799 .85673 .45186 Mtetra
.65 .754 .925 r
.85673 .45186 .86127 .45799 .87252 .45473 .86802 .44858 Mtetra
.653 .755 .925 r
.86802 .44858 .87252 .45473 .88382 .45142 .87935 .44522 Mtetra
.654 .755 .924 r
.87935 .44522 .88382 .45142 .89516 .44807 .89071 .44182 Mtetra
.655 .754 .923 r
.89071 .44182 .89516 .44807 .90654 .44469 .90212 .43837 Mtetra
.656 .753 .921 r
.90212 .43837 .90654 .44469 .91796 .44128 .91357 .43489 Mtetra
.653 .751 .921 r
.3005 .61354 .30643 .61871 .31568 .61592 .30976 .61079 Mtetra
.653 .753 .923 r
.30976 .61079 .31568 .61592 .32495 .61311 .31906 .60802 Mtetra
.654 .756 .924 r
.31906 .60802 .32495 .61311 .33427 .61026 .32839 .60522 Mtetra
.656 .759 .925 r
.32839 .60522 .33427 .61026 .34361 .60736 .33775 .60236 Mtetra
.659 .762 .926 r
.33775 .60236 .34361 .60736 .353 .60439 .34715 .59942 Mtetra
.662 .764 .926 r
.34715 .59942 .353 .60439 .36241 .60136 .35659 .59638 Mtetra
.667 .766 .924 r
.35659 .59638 .36241 .60136 .37187 .59826 .36607 .59323 Mtetra
.671 .765 .921 r
.36607 .59323 .37187 .59826 .38135 .59514 .37558 .58997 Mtetra
.674 .762 .917 r
.37558 .58997 .38135 .59514 .39087 .59202 .38513 .58662 Mtetra
.672 .753 .912 r
.38513 .58662 .39087 .59202 .40041 .58902 .3947 .58331 Mtetra
.667 .741 .906 r
.3947 .58331 .40041 .58902 .40998 .58623 .40431 .58011 Mtetra
.655 .725 .901 r
.40431 .58011 .40998 .58623 .41958 .58372 .41393 .57723 Mtetra
.636 .707 .898 r
.41393 .57723 .41958 .58372 .4292 .5816 .42358 .57481 Mtetra
.618 .692 .896 r
.42358 .57481 .4292 .5816 .43886 .57977 .43325 .57286 Mtetra
.597 .681 .9 r
.43325 .57286 .43886 .57977 .44854 .57816 .44295 .57141 Mtetra
.588 .683 .907 r
.44295 .57141 .44854 .57816 .45828 .5765 .45269 .57011 Mtetra
.588 .696 .917 r
.45269 .57011 .45828 .5765 .46806 .57458 .46248 .56875 Mtetra
.601 .721 .929 r
.46248 .56875 .46806 .57458 .47788 .57226 .47232 .56701 Mtetra
.625 .752 .938 r
.47232 .56701 .47788 .57226 .48775 .56941 .48221 .56466 Mtetra
.646 .78 .945 r
.48221 .56466 .48775 .56941 .49766 .56617 .49214 .56177 Mtetra
.667 .801 .947 r
.49214 .56177 .49766 .56617 .50761 .5626 .50211 .55837 Mtetra
.678 .811 .947 r
.50211 .55837 .50761 .5626 .51759 .55888 .51212 .55468 Mtetra
.683 .815 .946 r
.51212 .55468 .51759 .55888 .5276 .55514 .52216 .55086 Mtetra
.683 .812 .944 r
.52216 .55086 .5276 .55514 .53765 .55146 .53224 .54705 Mtetra
.679 .806 .943 r
.53224 .54705 .53765 .55146 .54772 .54789 .54234 .54333 Mtetra
.674 .8 .942 r
.54234 .54333 .54772 .54789 .55784 .54443 .55248 .53973 Mtetra
.668 .793 .942 r
.55248 .53973 .55784 .54443 .56799 .54108 .56266 .53626 Mtetra
.662 .788 .941 r
.56266 .53626 .56799 .54108 .57817 .53782 .57287 .53292 Mtetra
.657 .784 .941 r
.57287 .53292 .57817 .53782 .5884 .53464 .58312 .52969 Mtetra
.652 .781 .942 r
.58312 .52969 .5884 .53464 .59866 .53154 .59342 .52656 Mtetra
.647 .779 .944 r
.59342 .52656 .59866 .53154 .60897 .52851 .60375 .52354 Mtetra
.641 .779 .947 r
.60375 .52354 .60897 .52851 .61931 .52556 .61412 .52063 Mtetra
.634 .779 .951 r
.61412 .52063 .61931 .52556 .6297 .5227 .62454 .51785 Mtetra
.626 .78 .955 r
.62454 .51785 .6297 .5227 .64013 .51995 .63501 .51521 Mtetra
.618 .782 .96 r
.63501 .51521 .64013 .51995 .65061 .51732 .64552 .51268 Mtetra
.61 .785 .965 r
.64552 .51268 .65061 .51732 .66114 .5148 .65608 .51026 Mtetra
.607 .789 .968 r
.65608 .51026 .66114 .5148 .67171 .51233 .66669 .50784 Mtetra
.613 .794 .968 r
.66669 .50784 .67171 .51233 .68233 .50985 .67733 .50528 Mtetra
.628 .797 .964 r
.67733 .50528 .68233 .50985 .69298 .50722 .68801 .50244 Mtetra
.654 .798 .951 r
.68801 .50244 .69298 .50722 .70366 .50426 .6987 .49908 Mtetra
.679 .79 .933 r
.6987 .49908 .70366 .50426 .71436 .50089 .7094 .49516 Mtetra
.701 .777 .91 r
.7094 .49516 .71436 .50089 .72507 .49699 .72011 .49062 Mtetra
.711 .759 .89 r
.72011 .49062 .72507 .49699 .73579 .49267 .73082 .48569 Mtetra
.709 .74 .875 r
.73082 .48569 .73579 .49267 .74653 .48808 .74155 .48067 Mtetra
.702 .725 .868 r
.74155 .48067 .74653 .48808 .75729 .48343 .75233 .47582 Mtetra
.687 .714 .87 r
.75233 .47582 .75729 .48343 .7681 .479 .76318 .47147 Mtetra
.673 .712 .877 r
.76318 .47147 .7681 .479 .77898 .47486 .7741 .46759 Mtetra
.658 .714 .89 r
.7741 .46759 .77898 .47486 .78992 .47112 .78509 .46419 Mtetra
.647 .722 .903 r
.78509 .46419 .78992 .47112 .80092 .46767 .79616 .46111 Mtetra
.641 .732 .915 r
.79616 .46111 .80092 .46767 .81199 .46443 .80728 .45816 Mtetra
.638 .742 .924 r
.80728 .45816 .81199 .46443 .82311 .46132 .81845 .45524 Mtetra
.641 .751 .929 r
.81845 .45524 .82311 .46132 .83427 .4582 .82966 .45222 Mtetra
.643 .757 .931 r
.82966 .45222 .83427 .4582 .84548 .45507 .8409 .4491 Mtetra
.648 .76 .931 r
.8409 .4491 .84548 .45507 .85673 .45186 .85218 .44585 Mtetra
.652 .761 .93 r
.85218 .44585 .85673 .45186 .86802 .44858 .8635 .4425 Mtetra
.655 .76 .927 r
.8635 .4425 .86802 .44858 .87935 .44522 .87485 .43906 Mtetra
.657 .759 .925 r
.87485 .43906 .87935 .44522 .89071 .44182 .88624 .43556 Mtetra
.658 .757 .923 r
.88624 .43556 .89071 .44182 .90212 .43837 .89767 .43202 Mtetra
.658 .755 .921 r
.89767 .43202 .90212 .43837 .91357 .43489 .90915 .42846 Mtetra
.65 .75 .923 r
.29453 .60833 .3005 .61354 .30976 .61079 .30381 .60562 Mtetra
.649 .752 .925 r
.30381 .60562 .30976 .61079 .31906 .60802 .31312 .60292 Mtetra
.65 .755 .927 r
.31312 .60292 .31906 .60802 .32839 .60522 .32246 .60019 Mtetra
.651 .759 .929 r
.32246 .60019 .32839 .60522 .33775 .60236 .33184 .59741 Mtetra
.653 .764 .931 r
.33184 .59741 .33775 .60236 .34715 .59942 .34126 .59457 Mtetra
.657 .769 .932 r
.34126 .59457 .34715 .59942 .35659 .59638 .35071 .59162 Mtetra
.664 .774 .932 r
.35071 .59162 .35659 .59638 .36607 .59323 .36021 .5885 Mtetra
.671 .779 .931 r
.36021 .5885 .36607 .59323 .37558 .58997 .36975 .58521 Mtetra
.68 .78 .926 r
.36975 .58521 .37558 .58997 .38513 .58662 .37932 .5817 Mtetra
.684 .775 .92 r
.37932 .5817 .38513 .58662 .3947 .58331 .38893 .57807 Mtetra
.685 .765 .912 r
.38893 .57807 .3947 .58331 .40431 .58011 .39858 .57438 Mtetra
.676 .745 .903 r
.39858 .57438 .40431 .58011 .41393 .57723 .40825 .57092 Mtetra
.659 .721 .895 r
.40825 .57092 .41393 .57723 .42358 .57481 .41793 .5679 Mtetra
.634 .695 .889 r
.41793 .5679 .42358 .57481 .43325 .57286 .42763 .56552 Mtetra
.603 .671 .888 r
.42763 .56552 .43325 .57286 .44295 .57141 .43735 .56394 Mtetra
.582 .659 .89 r
.43735 .56394 .44295 .57141 .45269 .57011 .4471 .56286 Mtetra
.567 .66 .9 r
.4471 .56286 .45269 .57011 .46248 .56875 .45689 .56206 Mtetra
.572 .681 .914 r
.45689 .56206 .46248 .56875 .47232 .56701 .46673 .56104 Mtetra
.594 .716 .929 r
.46673 .56104 .47232 .56701 .48221 .56466 .47663 .55943 Mtetra
.619 .754 .942 r
.47663 .55943 .48221 .56466 .49214 .56177 .48658 .55716 Mtetra
.649 .788 .949 r
.48658 .55716 .49214 .56177 .50211 .55837 .49657 .55415 Mtetra
.667 .811 .952 r
.49657 .55415 .50211 .55837 .51212 .55468 .50661 .55067 Mtetra
.68 .823 .952 r
.50661 .55067 .51212 .55468 .52216 .55086 .51668 .54688 Mtetra
.683 .826 .952 r
.51668 .54688 .52216 .55086 .53224 .54705 .52678 .54298 Mtetra
.681 .823 .951 r
.52678 .54298 .53224 .54705 .54234 .54333 .53692 .53913 Mtetra
.676 .817 .951 r
.53692 .53913 .54234 .54333 .55248 .53973 .54709 .53539 Mtetra
.67 .81 .951 r
.54709 .53539 .55248 .53973 .56266 .53626 .55729 .5318 Mtetra
.663 .804 .951 r
.55729 .5318 .56266 .53626 .57287 .53292 .56754 .52836 Mtetra
.656 .799 .951 r
.56754 .52836 .57287 .53292 .58312 .52969 .57782 .52507 Mtetra
.649 .796 .953 r
.57782 .52507 .58312 .52969 .59342 .52656 .58814 .52193 Mtetra
.642 .793 .955 r
.58814 .52193 .59342 .52656 .60375 .52354 .5985 .51892 Mtetra
.633 .792 .959 r
.5985 .51892 .60375 .52354 .61412 .52063 .60891 .51607 Mtetra
.624 .792 .963 r
.60891 .51607 .61412 .52063 .62454 .51785 .61936 .51337 Mtetra
.614 .793 .968 r
.61936 .51337 .62454 .51785 .63501 .51521 .62986 .51083 Mtetra
.605 .795 .972 r
.62986 .51083 .63501 .51521 .64552 .51268 .64041 .5084 Mtetra
.599 .798 .976 r
.64041 .5084 .64552 .51268 .65608 .51026 .651 .50601 Mtetra
.603 .802 .976 r
.651 .50601 .65608 .51026 .66669 .50784 .66164 .50352 Mtetra
.621 .806 .971 r
.66164 .50352 .66669 .50784 .67733 .50528 .6723 .50073 Mtetra
.648 .806 .959 r
.6723 .50073 .67733 .50528 .68801 .50244 .68299 .49744 Mtetra
.683 .799 .937 r
.68299 .49744 .68801 .50244 .6987 .49908 .69368 .49341 Mtetra
.707 .782 .91 r
.69368 .49341 .6987 .49908 .7094 .49516 .70437 .48869 Mtetra
.721 .759 .883 r
.70437 .48869 .7094 .49516 .72011 .49062 .71506 .48336 Mtetra
.722 .736 .863 r
.71506 .48336 .72011 .49062 .73082 .48569 .72576 .47781 Mtetra
.71 .716 .854 r
.72576 .47781 .73082 .48569 .74155 .48067 .7365 .47253 Mtetra
.695 .704 .854 r
.7365 .47253 .74155 .48067 .75233 .47582 .74731 .46776 Mtetra
.673 .698 .865 r
.74731 .46776 .75233 .47582 .76318 .47147 .75821 .4638 Mtetra
.654 .702 .882 r
.75821 .4638 .76318 .47147 .7741 .46759 .7692 .4605 Mtetra
.638 .713 .902 r
.7692 .4605 .7741 .46759 .78509 .46419 .78027 .45765 Mtetra
.627 .728 .92 r
.78027 .45765 .78509 .46419 .79616 .46111 .7914 .45504 Mtetra
.626 .745 .933 r
.7914 .45504 .79616 .46111 .80728 .45816 .80258 .45237 Mtetra
.629 .758 .94 r
.80258 .45237 .80728 .45816 .81845 .45524 .81379 .44958 Mtetra
.637 .767 .942 r
.81379 .44958 .81845 .45524 .82966 .45222 .82504 .44656 Mtetra
.644 .771 .94 r
.82504 .44656 .82966 .45222 .8409 .4491 .83631 .44335 Mtetra
.651 .771 .937 r
.83631 .44335 .8409 .4491 .85218 .44585 .84761 .43997 Mtetra
.656 .769 .933 r
.84761 .43997 .85218 .44585 .8635 .4425 .85895 .43647 Mtetra
.658 .765 .929 r
.85895 .43647 .8635 .4425 .87485 .43906 .87032 .4329 Mtetra
.66 .762 .926 r
.87032 .4329 .87485 .43906 .88624 .43556 .88174 .42928 Mtetra
.661 .759 .923 r
.88174 .42928 .88624 .43556 .89767 .43202 .89319 .42563 Mtetra
.661 .756 .921 r
.89319 .42563 .89767 .43202 .90915 .42846 .90469 .42197 Mtetra
.649 .75 .923 r
.28853 .60308 .29453 .60833 .30381 .60562 .29782 .60039 Mtetra
.647 .751 .925 r
.29782 .60039 .30381 .60562 .31312 .60292 .30714 .59772 Mtetra
.647 .752 .926 r
.30714 .59772 .31312 .60292 .32246 .60019 .3165 .59505 Mtetra
.647 .755 .928 r
.3165 .59505 .32246 .60019 .33184 .59741 .3259 .59235 Mtetra
.647 .759 .931 r
.3259 .59235 .33184 .59741 .34126 .59457 .33533 .58964 Mtetra
.65 .766 .934 r
.33533 .58964 .34126 .59457 .35071 .59162 .3448 .58684 Mtetra
.655 .773 .936 r
.3448 .58684 .35071 .59162 .36021 .5885 .3543 .5839 Mtetra
.663 .783 .938 r
.3543 .5839 .36021 .5885 .36975 .58521 .36386 .58074 Mtetra
.676 .792 .936 r
.36386 .58074 .36975 .58521 .37932 .5817 .37346 .57727 Mtetra
.688 .797 .932 r
.37346 .57727 .37932 .5817 .38893 .57807 .3831 .57351 Mtetra
.7 .795 .924 r
.3831 .57351 .38893 .57807 .39858 .57438 .39278 .56944 Mtetra
.699 .78 .914 r
.39278 .56944 .39858 .57438 .40825 .57092 .40249 .56537 Mtetra
.689 .757 .903 r
.40249 .56537 .40825 .57092 .41793 .5679 .41223 .56152 Mtetra
.664 .723 .893 r
.41223 .56152 .41793 .5679 .42763 .56552 .42197 .55831 Mtetra
.627 .685 .885 r
.42197 .55831 .42763 .56552 .43735 .56394 .43172 .55611 Mtetra
.594 .654 .879 r
.43172 .55611 .43735 .56394 .4471 .56286 .44149 .55477 Mtetra
.56 .634 .881 r
.44149 .55477 .4471 .56286 .45689 .56206 .45128 .55425 Mtetra
.551 .638 .89 r
.45128 .55425 .45689 .56206 .46673 .56104 .46112 .55386 Mtetra
.56 .662 .905 r
.46112 .55386 .46673 .56104 .47663 .55943 .47102 .55315 Mtetra
.583 .703 .925 r
.47102 .55315 .47663 .55943 .48658 .55716 .48098 .55178 Mtetra
.619 .75 .94 r
.48098 .55178 .48658 .55716 .49657 .55415 .491 .5495 Mtetra
.645 .788 .95 r
.491 .5495 .49657 .55415 .50661 .55067 .50106 .54654 Mtetra
.667 .816 .955 r
.50106 .54654 .50661 .55067 .51668 .54688 .51115 .54301 Mtetra
.677 .831 .957 r
.51115 .54301 .51668 .54688 .52678 .54298 .52129 .53921 Mtetra
.679 .836 .959 r
.52129 .53921 .52678 .54298 .53692 .53913 .53146 .53533 Mtetra
.676 .835 .96 r
.53146 .53533 .53692 .53913 .54709 .53539 .54166 .5315 Mtetra
.669 .831 .961 r
.54166 .5315 .54709 .53539 .55729 .5318 .55189 .52782 Mtetra
.661 .825 .962 r
.55189 .52782 .55729 .5318 .56754 .52836 .56217 .52429 Mtetra
.653 .82 .964 r
.56217 .52429 .56754 .52836 .57782 .52507 .57248 .52095 Mtetra
.643 .816 .966 r
.57248 .52095 .57782 .52507 .58814 .52193 .58283 .51778 Mtetra
.633 .813 .969 r
.58283 .51778 .58814 .52193 .5985 .51892 .59322 .51479 Mtetra
.622 .811 .973 r
.59322 .51479 .5985 .51892 .60891 .51607 .60366 .51199 Mtetra
.611 .81 .976 r
.60366 .51199 .60891 .51607 .61936 .51337 .61415 .50935 Mtetra
.6 .81 .98 r
.61415 .50935 .61936 .51337 .62986 .51083 .62468 .50685 Mtetra
.595 .811 .982 r
.62468 .50685 .62986 .51083 .64041 .5084 .63526 .5044 Mtetra
.599 .812 .982 r
.63526 .5044 .64041 .5084 .651 .50601 .64588 .50188 Mtetra
.617 .813 .976 r
.64588 .50188 .651 .50601 .66164 .50352 .65654 .49909 Mtetra
.65 .812 .961 r
.65654 .49909 .66164 .50352 .6723 .50073 .66721 .49572 Mtetra
.684 .8 .937 r
.66721 .49572 .6723 .50073 .68299 .49744 .6779 .49165 Mtetra
.715 .78 .903 r
.6779 .49165 .68299 .49744 .69368 .49341 .68857 .48666 Mtetra
.728 .753 .872 r
.68857 .48666 .69368 .49341 .70437 .48869 .69924 .48098 Mtetra
.729 .727 .848 r
.69924 .48098 .70437 .48869 .71506 .48336 .70991 .47496 Mtetra
.72 .707 .837 r
.70991 .47496 .71506 .48336 .72576 .47781 .72062 .46907 Mtetra
.698 .691 .839 r
.72062 .46907 .72576 .47781 .7365 .47253 .73141 .46401 Mtetra
.677 .688 .853 r
.73141 .46401 .7365 .47253 .74731 .46776 .74228 .45983 Mtetra
.649 .692 .877 r
.74228 .45983 .74731 .46776 .75821 .4638 .75326 .45667 Mtetra
.625 .707 .905 r
.75326 .45667 .75821 .4638 .7692 .4605 .76434 .45418 Mtetra
.611 .73 .93 r
.76434 .45418 .7692 .4605 .78027 .45765 .77548 .45192 Mtetra
.604 .75 .947 r
.77548 .45192 .78027 .45765 .7914 .45504 .78667 .44966 Mtetra
.614 .77 .954 r
.78667 .44966 .7914 .45504 .80258 .45237 .79789 .44709 Mtetra
.626 .779 .954 r
.79789 .44709 .80258 .45237 .81379 .44958 .80914 .44421 Mtetra
.641 .783 .949 r
.80914 .44421 .81379 .44958 .82504 .44656 .8204 .44101 Mtetra
.652 .78 .942 r
.8204 .44101 .82504 .44656 .83631 .44335 .83169 .43757 Mtetra
.658 .775 .935 r
.83169 .43757 .83631 .44335 .84761 .43997 .843 .43399 Mtetra
.662 .77 .93 r
.843 .43399 .84761 .43997 .85895 .43647 .85436 .43031 Mtetra
.663 .764 .925 r
.85436 .43031 .85895 .43647 .87032 .4329 .86575 .42661 Mtetra
.663 .76 .922 r
.86575 .42661 .87032 .4329 .88174 .42928 .87719 .42289 Mtetra
.663 .758 .92 r
.87719 .42289 .88174 .42928 .89319 .42563 .88868 .41916 Mtetra
.662 .755 .919 r
.88868 .41916 .89319 .42563 .90469 .42197 .90021 .41544 Mtetra
.649 .75 .923 r
.28248 .59781 .28853 .60308 .29782 .60039 .29179 .59508 Mtetra
.648 .749 .923 r
.29179 .59508 .29782 .60039 .30714 .59772 .30114 .59238 Mtetra
.646 .748 .923 r
.30114 .59238 .30714 .59772 .3165 .59505 .31052 .58971 Mtetra
.644 .748 .925 r
.31052 .58971 .3165 .59505 .3259 .59235 .31993 .58707 Mtetra
.641 .75 .928 r
.31993 .58707 .3259 .59235 .33533 .58964 .32937 .58448 Mtetra
.64 .756 .932 r
.32937 .58448 .33533 .58964 .3448 .58684 .33884 .58189 Mtetra
.641 .764 .938 r
.33884 .58189 .3448 .58684 .3543 .5839 .34836 .57924 Mtetra
.647 .778 .943 r
.34836 .57924 .3543 .5839 .36386 .58074 .35792 .57641 Mtetra
.66 .795 .947 r
.35792 .57641 .36386 .58074 .37346 .57727 .36753 .57325 Mtetra
.678 .813 .947 r
.36753 .57325 .37346 .57727 .3831 .57351 .37719 .56966 Mtetra
.703 .825 .94 r
.37719 .56966 .3831 .57351 .39278 .56944 .3869 .56547 Mtetra
.717 .823 .931 r
.3869 .56547 .39278 .56944 .40249 .56537 .39666 .56091 Mtetra
.725 .805 .915 r
.39666 .56091 .40249 .56537 .41223 .56152 .40645 .55611 Mtetra
.706 .768 .9 r
.40645 .55611 .41223 .56152 .42197 .55831 .41626 .55174 Mtetra
.671 .721 .887 r
.41626 .55174 .42197 .55831 .43172 .55611 .42606 .54832 Mtetra
.626 .67 .872 r
.42606 .54832 .43172 .55611 .44149 .55477 .43586 .5461 Mtetra
.573 .625 .865 r
.43586 .5461 .44149 .55477 .45128 .55425 .44567 .54532 Mtetra
.545 .606 .865 r
.44567 .54532 .45128 .55425 .46112 .55386 .45552 .54526 Mtetra
.531 .608 .875 r
.45552 .54526 .46112 .55386 .47102 .55315 .46541 .54544 Mtetra
.543 .64 .896 r
.46541 .54544 .47102 .55315 .48098 .55178 .47537 .54517 Mtetra
.576 .69 .919 r
.47537 .54517 .48098 .55178 .491 .5495 .48539 .54397 Mtetra
.608 .743 .94 r
.48539 .54397 .491 .5495 .50106 .54654 .49546 .5419 Mtetra
.641 .79 .953 r
.49546 .5419 .50106 .54654 .51115 .54301 .50559 .53897 Mtetra
.66 .821 .961 r
.50559 .53897 .51115 .54301 .52129 .53921 .51575 .53553 Mtetra
.669 .839 .965 r
.51575 .53553 .52129 .53921 .53146 .53533 .52595 .5318 Mtetra
.67 .847 .967 r
.52595 .5318 .53146 .53533 .54166 .5315 .53618 .528 Mtetra
.664 .848 .97 r
.53618 .528 .54166 .5315 .55189 .52782 .54645 .52429 Mtetra
.656 .845 .973 r
.54645 .52429 .55189 .52782 .56217 .52429 .55676 .52071 Mtetra
.646 .841 .975 r
.55676 .52071 .56217 .52429 .57248 .52095 .5671 .51733 Mtetra
.634 .837 .978 r
.5671 .51733 .57248 .52095 .58283 .51778 .57749 .51414 Mtetra
.622 .833 .981 r
.57749 .51414 .58283 .51778 .59322 .51479 .58791 .51115 Mtetra
.609 .83 .984 r
.58791 .51115 .59322 .51479 .60366 .51199 .59839 .50836 Mtetra
.599 .828 .987 r
.59839 .50836 .60366 .51199 .61415 .50935 .6089 .50571 Mtetra
.593 .826 .988 r
.6089 .50571 .61415 .50935 .62468 .50685 .61947 .50314 Mtetra
.598 .825 .986 r
.61947 .50314 .62468 .50685 .63526 .5044 .63008 .5005 Mtetra
.619 .825 .98 r
.63008 .5005 .63526 .5044 .64588 .50188 .64072 .49758 Mtetra
.651 .819 .964 r
.64072 .49758 .64588 .50188 .65654 .49909 .65138 .49414 Mtetra
.693 .805 .935 r
.65138 .49414 .65654 .49909 .66721 .49572 .66205 .48982 Mtetra
.721 .778 .898 r
.66205 .48982 .66721 .49572 .6779 .49165 .67271 .48461 Mtetra
.738 .748 .86 r
.67271 .48461 .6779 .49165 .68857 .48666 .68336 .47845 Mtetra
.738 .718 .832 r
.68336 .47845 .68857 .48666 .69924 .48098 .69401 .47181 Mtetra
.724 .691 .818 r
.69401 .47181 .69924 .48098 .70991 .47496 .70468 .46541 Mtetra
.706 .677 .819 r
.70468 .46541 .70991 .47496 .72062 .46907 .71542 .45973 Mtetra
.673 .668 .836 r
.71542 .45973 .72062 .46907 .73141 .46401 .72628 .45552 Mtetra
.642 .675 .866 r
.72628 .45552 .73141 .46401 .74228 .45983 .73726 .45255 Mtetra
.606 .695 .906 r
.73726 .45255 .74228 .45983 .75326 .45667 .74835 .45054 Mtetra
.576 .722 .943 r
.74835 .45054 .75326 .45667 .76434 .45418 .75952 .44899 Mtetra
.572 .76 .967 r
.75952 .44899 .76434 .45418 .77548 .45192 .77073 .44719 Mtetra
.582 .785 .976 r
.77073 .44719 .77548 .45192 .78667 .44966 .78197 .44501 Mtetra
.612 .801 .972 r
.78197 .44501 .78667 .44966 .79789 .44709 .79321 .44223 Mtetra
.637 .803 .962 r
.79321 .44223 .79789 .44709 .80914 .44421 .80445 .43898 Mtetra
.655 .795 .949 r
.80445 .43898 .80914 .44421 .8204 .44101 .81572 .43539 Mtetra
.665 .784 .938 r
.81572 .43539 .8204 .44101 .83169 .43757 .82701 .4316 Mtetra
.667 .773 .928 r
.82701 .4316 .83169 .43757 .843 .43399 .83834 .42777 Mtetra
.668 .764 .922 r
.83834 .42777 .843 .43399 .85436 .43031 .84971 .42391 Mtetra
.666 .758 .919 r
.84971 .42391 .85436 .43031 .86575 .42661 .86114 .42011 Mtetra
.664 .755 .918 r
.86114 .42011 .86575 .42661 .87719 .42289 .8726 .41633 Mtetra
.663 .753 .917 r
.8726 .41633 .87719 .42289 .88868 .41916 .88412 .41259 Mtetra
.661 .753 .918 r
.88412 .41259 .88868 .41916 .90021 .41544 .89569 .40886 Mtetra
.653 .751 .921 r
.27639 .59249 .28248 .59781 .29179 .59508 .28573 .58966 Mtetra
.652 .747 .919 r
.28573 .58966 .29179 .59508 .30114 .59238 .2951 .58685 Mtetra
.65 .743 .918 r
.2951 .58685 .30114 .59238 .31052 .58971 .3045 .58409 Mtetra
.646 .74 .918 r
.3045 .58409 .31052 .58971 .31993 .58707 .31394 .58141 Mtetra
.64 .737 .919 r
.31394 .58141 .31993 .58707 .32937 .58448 .32339 .57884 Mtetra
.636 .737 .922 r
.32339 .57884 .32937 .58448 .33884 .58189 .33288 .57636 Mtetra
.63 .741 .927 r
.33288 .57636 .33884 .58189 .34836 .57924 .3424 .57399 Mtetra
.631 .752 .935 r
.3424 .57399 .34836 .57924 .35792 .57641 .35196 .57155 Mtetra
.636 .77 .944 r
.35196 .57155 .35792 .57641 .36753 .57325 .36157 .56895 Mtetra
.653 .797 .952 r
.36157 .56895 .36753 .57325 .37719 .56966 .37123 .56589 Mtetra
.682 .826 .953 r
.37123 .56589 .37719 .56966 .3869 .56547 .38095 .56214 Mtetra
.712 .85 .948 r
.38095 .56214 .3869 .56547 .39666 .56091 .39074 .55765 Mtetra
.744 .857 .932 r
.39074 .55765 .39666 .56091 .40645 .55611 .40058 .55234 Mtetra
.746 .837 .92 r
.40058 .55234 .40645 .55611 .41626 .55174 .41045 .54691 Mtetra
.729 .795 .904 r
.41045 .54691 .41626 .55174 .42606 .54832 .42032 .54189 Mtetra
.683 .731 .886 r
.42032 .54189 .42606 .54832 .43586 .5461 .43019 .53807 Mtetra
.617 .662 .871 r
.43019 .53807 .43586 .5461 .44567 .54532 .44004 .53607 Mtetra
.569 .61 .854 r
.44004 .53607 .44567 .54532 .45552 .54526 .44991 .53544 Mtetra
.527 .577 .849 r
.44991 .53544 .45552 .54526 .46541 .54544 .4598 .53593 Mtetra
.52 .581 .857 r
.4598 .53593 .46541 .54544 .47537 .54517 .46975 .53652 Mtetra
.537 .612 .875 r
.46975 .53652 .47537 .54517 .48539 .54397 .47976 .53654 Mtetra
.564 .661 .902 r
.47976 .53654 .48539 .54397 .49546 .5419 .48984 .53572 Mtetra
.603 .719 .926 r
.48984 .53572 .49546 .5419 .50559 .53897 .49998 .53382 Mtetra
.63 .768 .946 r
.49998 .53382 .50559 .53897 .51575 .53553 .51017 .53117 Mtetra
.65 .807 .958 r
.51017 .53117 .51575 .53553 .52595 .5318 .5204 .52795 Mtetra
.657 .831 .967 r
.5204 .52795 .52595 .5318 .53618 .528 .53067 .52446 Mtetra
.656 .844 .973 r
.53067 .52446 .53618 .528 .54645 .52429 .54097 .52089 Mtetra
.649 .85 .977 r
.54097 .52089 .54645 .52429 .55676 .52071 .55131 .51737 Mtetra
.639 .851 .981 r
.55131 .51737 .55676 .52071 .5671 .51733 .56169 .51399 Mtetra
.627 .849 .984 r
.56169 .51399 .5671 .51733 .57749 .51414 .5721 .51079 Mtetra
.616 .845 .987 r
.5721 .51079 .57749 .51414 .58791 .51115 .58256 .50775 Mtetra
.607 .841 .988 r
.58256 .50775 .58791 .51115 .59839 .50836 .59307 .50486 Mtetra
.605 .837 .987 r
.59307 .50486 .59839 .50836 .6089 .50571 .60362 .50202 Mtetra
.613 .832 .984 r
.60362 .50202 .6089 .50571 .61947 .50314 .61421 .49911 Mtetra
.635 .825 .973 r
.61421 .49911 .61947 .50314 .63008 .5005 .62483 .49592 Mtetra
.669 .813 .952 r
.62483 .49592 .63008 .5005 .64072 .49758 .63548 .49215 Mtetra
.701 .789 .92 r
.63548 .49215 .64072 .49758 .65138 .49414 .64613 .48761 Mtetra
.729 .76 .878 r
.64613 .48761 .65138 .49414 .66205 .48982 .65678 .48199 Mtetra
.738 .727 .841 r
.65678 .48199 .66205 .48982 .67271 .48461 .66741 .47549 Mtetra
.738 .697 .812 r
.66741 .47549 .67271 .48461 .68336 .47845 .67804 .4684 Mtetra
.728 .676 .799 r
.67804 .4684 .68336 .47845 .69401 .47181 .68868 .46139 Mtetra
.703 .659 .803 r
.68868 .46139 .69401 .47181 .70468 .46541 .69941 .45552 Mtetra
.677 .658 .824 r
.69941 .45552 .70468 .46541 .71542 .45973 .71024 .45105 Mtetra
.63 .665 .866 r
.71024 .45105 .71542 .45973 .72628 .45552 .72122 .44843 Mtetra
.578 .689 .917 r
.72122 .44843 .72628 .45552 .73726 .45255 .73232 .44705 Mtetra
.532 .729 .965 r
.73232 .44705 .73726 .45255 .74835 .45054 .74351 .44609 Mtetra
.506 .763 .988 r
.74351 .44609 .74835 .45054 .75952 .44899 .75475 .44503 Mtetra
.543 .803 .993 r
.75475 .44503 .75952 .44899 .77073 .44719 .76599 .44312 Mtetra
.592 .82 .986 r
.76599 .44312 .77073 .44719 .78197 .44501 .77723 .44045 Mtetra
.64 .817 .968 r
.77723 .44045 .78197 .44501 .79321 .44223 .78846 .43705 Mtetra
.666 .802 .948 r
.78846 .43705 .79321 .44223 .80445 .43898 .79969 .43319 Mtetra
.675 .782 .93 r
.79969 .43319 .80445 .43898 .81572 .43539 .81096 .42915 Mtetra
.677 .767 .919 r
.81096 .42915 .81572 .43539 .82701 .4316 .82225 .42503 Mtetra
.673 .755 .912 r
.82225 .42503 .82701 .4316 .83834 .42777 .8336 .42102 Mtetra
.67 .748 .91 r
.8336 .42102 .83834 .42777 .84971 .42391 .845 .4171 Mtetra
.665 .745 .91 r
.845 .4171 .84971 .42391 .86114 .42011 .85646 .4133 Mtetra
.662 .745 .912 r
.85646 .4133 .86114 .42011 .8726 .41633 .86797 .40957 Mtetra
.659 .746 .914 r
.86797 .40957 .8726 .41633 .88412 .41259 .87953 .40589 Mtetra
.658 .749 .917 r
.87953 .40589 .88412 .41259 .89569 .40886 .89113 .40224 Mtetra
.66 .752 .919 r
.27027 .58715 .27639 .59249 .28573 .58966 .27964 .58415 Mtetra
.659 .747 .915 r
.27964 .58415 .28573 .58966 .2951 .58685 .28904 .58115 Mtetra
.657 .74 .911 r
.28904 .58115 .2951 .58685 .3045 .58409 .29847 .57819 Mtetra
.653 .733 .908 r
.29847 .57819 .3045 .58409 .31394 .58141 .30793 .57534 Mtetra
.646 .726 .907 r
.30793 .57534 .31394 .58141 .32339 .57884 .31741 .57263 Mtetra
.638 .72 .907 r
.31741 .57263 .32339 .57884 .33288 .57636 .32692 .57012 Mtetra
.627 .715 .91 r
.32692 .57012 .33288 .57636 .3424 .57399 .33645 .56787 Mtetra
.618 .718 .917 r
.33645 .56787 .3424 .57399 .35196 .57155 .34601 .56578 Mtetra
.608 .728 .93 r
.34601 .56578 .35196 .57155 .36157 .56895 .3556 .56385 Mtetra
.614 .756 .946 r
.3556 .56385 .36157 .56895 .37123 .56589 .36524 .56167 Mtetra
.632 .797 .962 r
.36524 .56167 .37123 .56589 .38095 .56214 .37495 .55896 Mtetra
.67 .851 .969 r
.37495 .55896 .38095 .56214 .39074 .55765 .38473 .55529 Mtetra
.727 .893 .955 r
.38473 .55529 .39074 .55765 .40058 .55234 .39459 .55024 Mtetra
.763 .906 .939 r
.39459 .55024 .40058 .55234 .41045 .54691 .40452 .54425 Mtetra
.786 .884 .917 r
.40452 .54425 .41045 .54691 .42032 .54189 .41448 .5376 Mtetra
.758 .821 .901 r
.41448 .5376 .42032 .54189 .43019 .53807 .42444 .53166 Mtetra
.696 .737 .882 r
.42444 .53166 .43019 .53807 .44004 .53607 .43437 .5274 Mtetra
.628 .651 .854 r
.43437 .5274 .44004 .53607 .44991 .53544 .44429 .52507 Mtetra
.555 .58 .834 r
.44429 .52507 .44991 .53544 .4598 .53593 .45419 .52489 Mtetra
.522 .551 .826 r
.45419 .52489 .4598 .53593 .46975 .53652 .46414 .5257 Mtetra
.51 .549 .832 r
.46414 .5257 .46975 .53652 .47976 .53654 .47414 .52677 Mtetra
.522 .579 .853 r
.47414 .52677 .47976 .53654 .48984 .53572 .48421 .52732 Mtetra
.556 .63 .881 r
.48421 .52732 .48984 .53572 .49998 .53382 .49435 .52682 Mtetra
.586 .686 .91 r
.49435 .52682 .49998 .53382 .51017 .53117 .50455 .5254 Mtetra
.618 .742 .935 r
.50455 .5254 .51017 .53117 .5204 .52795 .51481 .52308 Mtetra
.635 .783 .953 r
.51481 .52308 .5204 .52795 .53067 .52446 .5251 .52022 Mtetra
.643 .813 .965 r
.5251 .52022 .53067 .52446 .54097 .52089 .53544 .51705 Mtetra
.643 .831 .973 r
.53544 .51705 .54097 .52089 .55131 .51737 .54581 .51375 Mtetra
.638 .839 .978 r
.54581 .51375 .55131 .51737 .56169 .51399 .55622 .51046 Mtetra
.631 .842 .981 r
.55622 .51046 .56169 .51399 .5721 .51079 .56667 .50723 Mtetra
.627 .841 .982 r
.56667 .50723 .5721 .51079 .58256 .50775 .57717 .50407 Mtetra
.628 .837 .98 r
.57717 .50407 .58256 .50775 .59307 .50486 .5877 .50092 Mtetra
.639 .829 .974 r
.5877 .50092 .59307 .50486 .60362 .50202 .59827 .49764 Mtetra
.66 .818 .96 r
.59827 .49764 .60362 .50202 .61421 .49911 .60887 .49404 Mtetra
.686 .799 .934 r
.60887 .49404 .61421 .49911 .62483 .49592 .6195 .4899 Mtetra
.715 .773 .898 r
.6195 .4899 .62483 .49592 .63548 .49215 .63014 .48485 Mtetra
.732 .739 .857 r
.63014 .48485 .63548 .49215 .64613 .48761 .64077 .47885 Mtetra
.741 .706 .818 r
.64077 .47885 .64613 .48761 .65678 .48199 .65138 .47177 Mtetra
.737 .676 .792 r
.65138 .47177 .65678 .48199 .66741 .47549 .66199 .46415 Mtetra
.723 .653 .779 r
.66199 .46415 .66741 .47549 .67804 .4684 .67262 .45679 Mtetra
.704 .64 .783 r
.67262 .45679 .67804 .4684 .68868 .46139 .68331 .45041 Mtetra
.664 .632 .808 r
.68331 .45041 .68868 .46139 .69941 .45552 .69414 .44623 Mtetra
.616 .645 .856 r
.69414 .44623 .69941 .45552 .71024 .45105 .70512 .44402 Mtetra
.535 .672 .926 r
.70512 .44402 .71024 .45105 .72122 .44843 .71625 .44353 Mtetra
.43 .705 .98 r
.71625 .44353 .72122 .44843 .73232 .44705 .72749 .44378 Mtetra
.392 .759 .993 r
.72749 .44378 .73232 .44705 .74351 .44609 .73875 .44336 Mtetra
.437 .807 .994 r
.73875 .44336 .74351 .44609 .75475 .44503 .75001 .44199 Mtetra
.564 .854 .997 r
.75001 .44199 .75475 .44503 .76599 .44312 .76123 .43919 Mtetra
.649 .849 .977 r
.76123 .43919 .76599 .44312 .77723 .44045 .77242 .4354 Mtetra
.684 .814 .945 r
.77242 .4354 .77723 .44045 .78846 .43705 .78361 .43105 Mtetra
.695 .782 .918 r
.78361 .43105 .78846 .43705 .79969 .43319 .79482 .42644 Mtetra
.688 .754 .902 r
.79482 .42644 .79969 .43319 .81096 .42915 .80608 .42199 Mtetra
.681 .739 .895 r
.80608 .42199 .81096 .42915 .82225 .42503 .81739 .4177 Mtetra
.672 .731 .894 r
.81739 .4177 .82225 .42503 .8336 .42102 .82877 .41368 Mtetra
.665 .728 .897 r
.82877 .41368 .8336 .42102 .845 .4171 .84022 .40986 Mtetra
.659 .73 .902 r
.84022 .40986 .845 .4171 .85646 .4133 .85172 .40619 Mtetra
.656 .734 .907 r
.85172 .40619 .85646 .4133 .86797 .40957 .86328 .40262 Mtetra
.653 .739 .912 r
.86328 .40262 .86797 .40957 .87953 .40589 .87489 .39909 Mtetra
.653 .745 .917 r
.87489 .39909 .87953 .40589 .89113 .40224 .88655 .39556 Mtetra
.665 .754 .916 r
.2641 .58177 .27027 .58715 .27964 .58415 .2735 .57862 Mtetra
.666 .749 .912 r
.2735 .57862 .27964 .58415 .28904 .58115 .28293 .57543 Mtetra
.665 .743 .908 r
.28293 .57543 .28904 .58115 .29847 .57819 .2924 .57225 Mtetra
.662 .735 .904 r
.2924 .57225 .29847 .57819 .30793 .57534 .30189 .56914 Mtetra
.658 .726 .9 r
.30189 .56914 .30793 .57534 .31741 .57263 .31141 .56613 Mtetra
.649 .715 .896 r
.31141 .56613 .31741 .57263 .32692 .57012 .32095 .56334 Mtetra
.636 .702 .894 r
.32095 .56334 .32692 .57012 .33645 .56787 .33051 .56087 Mtetra
.621 .691 .894 r
.33051 .56087 .33645 .56787 .34601 .56578 .34008 .55876 Mtetra
.601 .683 .9 r
.34008 .55876 .34601 .56578 .3556 .56385 .34967 .55712 Mtetra
.591 .69 .911 r
.34967 .55712 .3556 .56385 .36524 .56167 .3593 .55565 Mtetra
.585 .713 .932 r
.3593 .55565 .36524 .56167 .37495 .55896 .36896 .55417 Mtetra
.611 .77 .956 r
.36896 .55417 .37495 .55896 .38473 .55529 .37871 .55194 Mtetra
.664 .845 .969 r
.37871 .55194 .38473 .55529 .39459 .55024 .38854 .54837 Mtetra
.722 .914 .96 r
.38854 .54837 .39459 .55024 .40452 .54425 .39847 .54321 Mtetra
.789 .946 .926 r
.39847 .54321 .40452 .54425 .41448 .5376 .40849 .53623 Mtetra
.805 .933 .916 r
.40849 .53623 .41448 .5376 .42444 .53166 .41854 .52883 Mtetra
.791 .88 .911 r
.41854 .52883 .42444 .53166 .43437 .5274 .42858 .52196 Mtetra
.726 .778 .894 r
.42858 .52196 .43437 .5274 .44429 .52507 .43858 .51686 Mtetra
.632 .666 .865 r
.43858 .51686 .44429 .52507 .45419 .52489 .44856 .51437 Mtetra
.569 .586 .83 r
.44856 .51437 .45419 .52489 .46414 .5257 .45853 .51377 Mtetra
.524 .536 .81 r
.45853 .51377 .46414 .5257 .47414 .52677 .46854 .51464 Mtetra
.515 .529 .808 r
.46854 .51464 .47414 .52677 .48421 .52732 .4786 .5158 Mtetra
.528 .547 .819 r
.4786 .5158 .48421 .52732 .49435 .52682 .48873 .51648 Mtetra
.55 .582 .839 r
.48873 .51648 .49435 .52682 .50455 .5254 .49893 .51639 Mtetra
.581 .628 .864 r
.49893 .51639 .50455 .5254 .51481 .52308 .50918 .5153 Mtetra
.606 .673 .888 r
.50918 .5153 .51481 .52308 .5251 .52022 .5195 .51345 Mtetra
.627 .713 .908 r
.5195 .51345 .5251 .52022 .53544 .51705 .52986 .51099 Mtetra
.64 .743 .923 r
.52986 .51099 .53544 .51705 .54581 .51375 .54026 .50815 Mtetra
.647 .763 .933 r
.54026 .50815 .54581 .51375 .55622 .51046 .5507 .50506 Mtetra
.653 .773 .937 r
.5507 .50506 .55622 .51046 .56667 .50723 .56118 .50181 Mtetra
.659 .775 .935 r
.56118 .50181 .56667 .50723 .57717 .50407 .57169 .4984 Mtetra
.669 .77 .925 r
.57169 .4984 .57717 .50407 .5877 .50092 .58225 .49474 Mtetra
.683 .757 .907 r
.58225 .49474 .5877 .50092 .59827 .49764 .59283 .4907 Mtetra
.699 .738 .881 r
.59283 .4907 .59827 .49764 .60887 .49404 .60343 .48604 Mtetra
.712 .713 .849 r
.60343 .48604 .60887 .49404 .6195 .4899 .61405 .48061 Mtetra
.724 .689 .816 r
.61405 .48061 .6195 .4899 .63014 .48485 .62466 .47415 Mtetra
.726 .664 .788 r
.62466 .47415 .63014 .48485 .64077 .47885 .63527 .46691 Mtetra
.724 .644 .769 r
.63527 .46691 .64077 .47885 .65138 .47177 .64587 .45916 Mtetra
.714 .631 .763 r
.64587 .45916 .65138 .47177 .66199 .46415 .6565 .45168 Mtetra
.691 .622 .774 r
.6565 .45168 .66199 .46415 .67262 .45679 .6672 .4457 Mtetra
.66 .629 .808 r
.6672 .4457 .67262 .45679 .68331 .45041 .67802 .44163 Mtetra
.587 .644 .874 r
.67802 .44163 .68331 .45041 .69414 .44623 .68902 .44023 Mtetra
.459 .674 .957 r
.68902 .44023 .69414 .44623 .70512 .44402 .70017 .44064 Mtetra
.266 .682 .967 r
.70017 .44064 .70512 .44402 .71625 .44353 .71141 .44161 Mtetra
.163 .671 .903 r
.71141 .44161 .71625 .44353 .72749 .44378 .72271 .44217 Mtetra
.334 .79 .946 r
.72271 .44217 .72749 .44378 .73875 .44336 .73396 .44086 Mtetra
.547 .87 .994 r
.73396 .44086 .73875 .44336 .75001 .44199 .74516 .43792 Mtetra
.676 .852 .967 r
.74516 .43792 .75001 .44199 .76123 .43919 .75631 .43359 Mtetra
.713 .802 .92 r
.75631 .43359 .76123 .43919 .77242 .4354 .76744 .42848 Mtetra
.708 .756 .89 r
.76744 .42848 .77242 .4354 .78361 .43105 .7786 .42335 Mtetra
.699 .73 .874 r
.7786 .42335 .78361 .43105 .79482 .42644 .78981 .41839 Mtetra
.683 .714 .872 r
.78981 .41839 .79482 .42644 .80608 .42199 .8011 .4139 Mtetra
.672 .709 .876 r
.8011 .4139 .80608 .42199 .81739 .4177 .81246 .4098 Mtetra
.662 .711 .884 r
.81246 .4098 .81739 .4177 .82877 .41368 .82389 .40602 Mtetra
.655 .716 .893 r
.82389 .40602 .82877 .41368 .84022 .40986 .83539 .40247 Mtetra
.651 .724 .902 r
.83539 .40247 .84022 .40986 .85172 .40619 .84695 .39902 Mtetra
.648 .73 .909 r
.84695 .39902 .85172 .40619 .86328 .40262 .85856 .39563 Mtetra
.647 .737 .915 r
.85856 .39563 .86328 .40262 .87489 .39909 .87022 .39226 Mtetra
.648 .743 .919 r
.87022 .39226 .87489 .39909 .88655 .39556 .88193 .38884 Mtetra
.668 .754 .915 r
.25789 .57635 .2641 .58177 .2735 .57862 .26732 .57311 Mtetra
.67 .752 .912 r
.26732 .57311 .2735 .57862 .28293 .57543 .27678 .5698 Mtetra
.672 .749 .909 r
.27678 .5698 .28293 .57543 .2924 .57225 .28628 .56644 Mtetra
.672 .744 .904 r
.28628 .56644 .2924 .57225 .30189 .56914 .29581 .56306 Mtetra
.672 .735 .897 r
.29581 .56306 .30189 .56914 .31141 .56613 .30537 .55964 Mtetra
.667 .721 .89 r
.30537 .55964 .31141 .56613 .32095 .56334 .31496 .55634 Mtetra
.657 .704 .881 r
.31496 .55634 .32095 .56334 .33051 .56087 .32457 .55328 Mtetra
.64 .681 .873 r
.32457 .55328 .33051 .56087 .34008 .55876 .33418 .55066 Mtetra
.615 .659 .87 r
.33418 .55066 .34008 .55876 .34967 .55712 .3438 .54872 Mtetra
.589 .641 .87 r
.3438 .54872 .34967 .55712 .3593 .55565 .35342 .54745 Mtetra
.554 .632 .883 r
.35342 .54745 .3593 .55565 .36896 .55417 .36305 .54696 Mtetra
.545 .658 .91 r
.36305 .54696 .36896 .55417 .37871 .55194 .37273 .54645 Mtetra
.551 .724 .954 r
.37273 .54645 .37871 .55194 .38854 .54837 .38249 .54539 Mtetra
.607 .848 .99 r
.38249 .54539 .38854 .54837 .39847 .54321 .39236 .54257 Mtetra
.704 .954 .952 r
.39236 .54257 .39847 .54321 .40849 .53623 .40237 .5371 Mtetra
.753 .989 .89 r
.40237 .5371 .40849 .53623 .41854 .52883 .41246 .52966 Mtetra
.823 .99 .871 r
.41246 .52966 .41854 .52883 .42858 .52196 .42261 .52067 Mtetra
.83 .935 .898 r
.42261 .52067 .42858 .52196 .43858 .51686 .43275 .51235 Mtetra
.763 .818 .896 r
.43275 .51235 .43858 .51686 .44856 .51437 .44284 .50614 Mtetra
.67 .682 .852 r
.44284 .50614 .44856 .51437 .45853 .51377 .4529 .50239 Mtetra
.582 .577 .813 r
.4529 .50239 .45853 .51377 .46854 .51464 .46293 .50139 Mtetra
.542 .527 .788 r
.46293 .50139 .46854 .51464 .4786 .5158 .473 .50184 Mtetra
.525 .508 .78 r
.473 .50184 .4786 .5158 .48873 .51648 .48312 .50294 Mtetra
.53 .517 .786 r
.48312 .50294 .48873 .51648 .49893 .51639 .4933 .50383 Mtetra
.55 .543 .8 r
.4933 .50383 .49893 .51639 .50918 .5153 .50355 .50395 Mtetra
.572 .576 .819 r
.50355 .50395 .50918 .5153 .5195 .51345 .51387 .50327 Mtetra
.597 .612 .837 r
.51387 .50327 .5195 .51345 .52986 .51099 .52424 .50172 Mtetra
.618 .642 .852 r
.52424 .50172 .52986 .51099 .54026 .50815 .53465 .4995 Mtetra
.637 .666 .861 r
.53465 .4995 .54026 .50815 .5507 .50506 .54511 .49672 Mtetra
.653 .68 .864 r
.54511 .49672 .5507 .50506 .56118 .50181 .55561 .49344 Mtetra
.667 .686 .859 r
.55561 .49344 .56118 .50181 .57169 .4984 .56615 .48968 Mtetra
.681 .683 .846 r
.56615 .48968 .57169 .4984 .58225 .49474 .57671 .48534 Mtetra
.693 .673 .827 r
.57671 .48534 .58225 .49474 .59283 .4907 .58729 .48033 Mtetra
.704 .66 .803 r
.58729 .48033 .59283 .4907 .60343 .48604 .59788 .47444 Mtetra
.71 .642 .78 r
.59788 .47444 .60343 .48604 .61405 .48061 .60848 .46773 Mtetra
.713 .626 .759 r
.60848 .46773 .61405 .48061 .62466 .47415 .61907 .46022 Mtetra
.708 .612 .747 r
.61907 .46022 .62466 .47415 .63527 .46691 .62967 .45249 Mtetra
.696 .601 .746 r
.62967 .45249 .63527 .46691 .64587 .45916 .64031 .44541 Mtetra
.676 .598 .761 r
.64031 .44541 .64587 .45916 .6565 .45168 .65101 .43978 Mtetra
.628 .6 .802 r
.65101 .43978 .6565 .45168 .6672 .4457 .66187 .43694 Mtetra
.545 .625 .883 r
.66187 .43694 .6672 .4457 .67802 .44163 .67288 .43662 Mtetra
.302 .632 .963 r
.67288 .43662 .67802 .44163 .68902 .44023 .68406 .43847 Mtetra
0 .487 .771 r
.68406 .43847 .68902 .44023 .70017 .44064 .69536 .44101 Mtetra
.147 0 0 r
.69536 .44101 .70017 .44064 .71141 .44161 .70666 .44199 Mtetra
.07 .632 .711 r
.70666 .44199 .71141 .44161 .72271 .44217 .71791 .44097 Mtetra
.528 .903 .957 r
.71791 .44097 .72271 .44217 .73396 .44086 .72906 .4372 Mtetra
.725 .882 .953 r
.72906 .4372 .73396 .44086 .74516 .43792 .74012 .43163 Mtetra
.741 .786 .89 r
.74012 .43163 .74516 .43792 .75631 .43359 .75118 .42548 Mtetra
.727 .729 .852 r
.75118 .42548 .75631 .43359 .76744 .42848 .76226 .4193 Mtetra
.7 .692 .84 r
.76226 .4193 .76744 .42848 .7786 .42335 .77343 .41391 Mtetra
.681 .679 .841 r
.77343 .41391 .7786 .42335 .78981 .41839 .78468 .4092 Mtetra
.664 .678 .853 r
.78468 .4092 .78981 .41839 .8011 .4139 .79604 .4052 Mtetra
.652 .685 .869 r
.79604 .4052 .8011 .4139 .81246 .4098 .80747 .40166 Mtetra
.646 .699 .885 r
.80747 .40166 .81246 .4098 .82389 .40602 .81898 .39836 Mtetra
.641 .712 .898 r
.81898 .39836 .82389 .40602 .83539 .40247 .83054 .39518 Mtetra
.642 .724 .908 r
.83054 .39518 .83539 .40247 .84695 .39902 .84216 .39197 Mtetra
.642 .733 .915 r
.84216 .39197 .84695 .39902 .85856 .39563 .85382 .38874 Mtetra
.643 .74 .919 r
.85382 .38874 .85856 .39563 .87022 .39226 .86553 .38544 Mtetra
.645 .744 .922 r
.86553 .38544 .87022 .39226 .88193 .38884 .87727 .38207 Mtetra
.664 .753 .917 r
.25164 .57089 .25789 .57635 .26732 .57311 .26108 .56772 Mtetra
.667 .757 .917 r
.26108 .56772 .26732 .57311 .27678 .5698 .27056 .56446 Mtetra
.671 .76 .918 r
.27056 .56446 .27678 .5698 .28628 .56644 .28008 .5611 Mtetra
.676 .762 .916 r
.28008 .5611 .28628 .56644 .29581 .56306 .28964 .5576 Mtetra
.682 .76 .911 r
.28964 .5576 .29581 .56306 .30537 .55964 .29924 .55393 Mtetra
.683 .752 .904 r
.29924 .55393 .30537 .55964 .31496 .55634 .30887 .55019 Mtetra
.683 .738 .893 r
.30887 .55019 .31496 .55634 .32457 .55328 .31854 .54643 Mtetra
.671 .714 .881 r
.31854 .54643 .32457 .55328 .33418 .55066 .32822 .54295 Mtetra
.65 .684 .868 r
.32822 .54295 .33418 .55066 .3438 .54872 .33791 .54001 Mtetra
.619 .646 .855 r
.33791 .54001 .3438 .54872 .35342 .54745 .34758 .53792 Mtetra
.575 .608 .849 r
.34758 .53792 .35342 .54745 .36305 .54696 .35724 .53707 Mtetra
.541 .585 .848 r
.35724 .53707 .36305 .54696 .37273 .54645 .3669 .5371 Mtetra
.503 .58 .865 r
.3669 .5371 .37273 .54645 .38249 .54539 .37658 .53788 Mtetra
.522 .642 .908 r
.37658 .53788 .38249 .54539 .39236 .54257 .38635 .53783 Mtetra
.592 .771 .965 r
.38635 .53783 .39236 .54257 .40237 .5371 .39625 .53581 Mtetra
.676 .931 .97 r
.39625 .53581 .40237 .5371 .41246 .52966 .4063 .53108 Mtetra
.753 .994 .863 r
.4063 .53108 .41246 .52966 .42261 .52067 .41647 .52309 Mtetra
.764 .995 .808 r
.41647 .52309 .42261 .52067 .43275 .51235 .42669 .51384 Mtetra
.807 .998 .847 r
.42669 .51384 .43275 .51235 .44284 .50614 .43691 .50458 Mtetra
.807 .933 .915 r
.43691 .50458 .44284 .50614 .4529 .50239 .4471 .49702 Mtetra
.715 .783 .906 r
.4471 .49702 .4529 .50239 .46293 .50139 .45723 .49223 Mtetra
.632 .647 .847 r
.45723 .49223 .46293 .50139 .473 .50184 .46736 .48963 Mtetra
.573 .561 .802 r
.46736 .48963 .473 .50184 .48312 .50294 .4775 .48892 Mtetra
.554 .525 .777 r
.4775 .48892 .48312 .50294 .4933 .50383 .48768 .48897 Mtetra
.554 .515 .766 r
.48768 .48897 .4933 .50383 .50355 .50395 .49793 .48907 Mtetra
.564 .521 .765 r
.49793 .48907 .50355 .50395 .51387 .50327 .50823 .48876 Mtetra
.582 .536 .768 r
.50823 .48876 .51387 .50327 .52424 .50172 .5186 .48771 Mtetra
.6 .552 .773 r
.5186 .48771 .52424 .50172 .53465 .4995 .52902 .48593 Mtetra
.618 .568 .776 r
.52902 .48593 .53465 .4995 .54511 .49672 .53948 .48336 Mtetra
.635 .58 .775 r
.53948 .48336 .54511 .49672 .55561 .49344 .54998 .48006 Mtetra
.65 .588 .772 r
.54998 .48006 .55561 .49344 .56615 .48968 .56051 .47601 Mtetra
.663 .591 .764 r
.56051 .47601 .56615 .48968 .57671 .48534 .57107 .47118 Mtetra
.673 .591 .755 r
.57107 .47118 .57671 .48534 .58729 .48033 .58165 .46561 Mtetra
.682 .59 .746 r
.58165 .46561 .58729 .48033 .59788 .47444 .59224 .45928 Mtetra
.686 .588 .74 r
.59224 .45928 .59788 .47444 .60848 .46773 .60284 .45253 Mtetra
.685 .587 .74 r
.60284 .45253 .60848 .46773 .61907 .46022 .61345 .44581 Mtetra
.678 .592 .752 r
.61345 .44581 .61907 .46022 .62967 .45249 .62412 .43985 Mtetra
.652 .601 .784 r
.62412 .43985 .62967 .45249 .64031 .44541 .63487 .4358 Mtetra
.602 .632 .853 r
.63487 .4358 .64031 .44541 .65101 .43978 .64574 .43398 Mtetra
.407 .657 .961 r
.64574 .43398 .65101 .43978 .66187 .43694 .65678 .43498 Mtetra
0 .477 .774 r
.65678 .43498 .66187 .43694 .67288 .43662 .66797 .43773 Mtetra
.367 0 0 r
.66797 .43773 .67288 .43662 .68406 .43847 .67924 .4405 Mtetra
.325 0 0 r
.67924 .4405 .68406 .43847 .69536 .44101 .69054 .44199 Mtetra
0 0 0 r
.69054 .44199 .69536 .44101 .70666 .44199 .70173 .44015 Mtetra
.631 .925 .974 r
.70173 .44015 .70666 .44199 .71791 .44097 .71282 .43553 Mtetra
.76 .82 .9 r
.71282 .43553 .71791 .44097 .72906 .4372 .72382 .42888 Mtetra
.754 .732 .832 r
.72382 .42888 .72906 .4372 .74012 .43163 .73479 .42136 Mtetra
.721 .678 .808 r
.73479 .42136 .74012 .43163 .75118 .42548 .74583 .41459 Mtetra
.698 .657 .806 r
.74583 .41459 .75118 .42548 .76226 .4193 .75695 .40873 Mtetra
.672 .652 .822 r
.75695 .40873 .76226 .4193 .77343 .41391 .7682 .40412 Mtetra
.654 .66 .844 r
.7682 .40412 .77343 .41391 .78468 .4092 .77956 .40042 Mtetra
.64 .679 .871 r
.77956 .40042 .78468 .4092 .79604 .4052 .79101 .39726 Mtetra
.631 .698 .894 r
.79101 .39726 .79604 .4052 .80747 .40166 .80254 .3944 Mtetra
.63 .72 .912 r
.80254 .3944 .80747 .40166 .81898 .39836 .81411 .39151 Mtetra
.63 .735 .923 r
.81411 .39151 .81898 .39836 .83054 .39518 .82573 .38855 Mtetra
.636 .746 .928 r
.82573 .38855 .83054 .39518 .84216 .39197 .83739 .38541 Mtetra
.641 .751 .929 r
.83739 .38541 .84216 .39197 .85382 .38874 .84908 .38213 Mtetra
.644 .752 .927 r
.84908 .38213 .85382 .38874 .86553 .38544 .86081 .37873 Mtetra
.648 .751 .925 r
.86081 .37873 .86553 .38544 .87727 .38207 .87259 .37524 Mtetra
.655 .751 .921 r
.24535 .5654 .25164 .57089 .26108 .56772 .25479 .56244 Mtetra
.656 .76 .926 r
.25479 .56244 .26108 .56772 .27056 .56446 .26427 .55942 Mtetra
.661 .771 .931 r
.26427 .55942 .27056 .56446 .28008 .5611 .2738 .55627 Mtetra
.669 .781 .933 r
.2738 .55627 .28008 .5611 .28964 .5576 .28337 .55291 Mtetra
.68 .789 .932 r
.28337 .55291 .28964 .5576 .29924 .55393 .29299 .54926 Mtetra
.692 .793 .927 r
.29299 .54926 .29924 .55393 .30887 .55019 .30266 .54531 Mtetra
.705 .788 .916 r
.30266 .54531 .30887 .55019 .31854 .54643 .31239 .54099 Mtetra
.707 .769 .901 r
.31239 .54099 .31854 .54643 .32822 .54295 .32215 .53655 Mtetra
.702 .738 .879 r
.32215 .53655 .32822 .54295 .33791 .54001 .33194 .53211 Mtetra
.675 .689 .855 r
.33194 .53211 .33791 .54001 .34758 .53792 .34172 .5283 Mtetra
.636 .634 .832 r
.34172 .5283 .34758 .53792 .35724 .53707 .35148 .5256 Mtetra
.585 .576 .81 r
.35148 .5256 .35724 .53707 .3669 .5371 .36119 .52451 Mtetra
.517 .522 .8 r
.36119 .52451 .3669 .5371 .37658 .53788 .37085 .52554 Mtetra
.477 .505 .808 r
.37085 .52554 .37658 .53788 .38635 .53783 .38053 .52759 Mtetra
.435 .525 .851 r
.38053 .52759 .38635 .53783 .39625 .53581 .39027 .52993 Mtetra
.465 .677 .957 r
.39027 .52993 .39625 .53581 .4063 .53108 .40015 .53017 Mtetra
.559 .909 .969 r
.40015 .53017 .4063 .53108 .41647 .52309 .41022 .52663 Mtetra
.483 .869 .672 r
.41022 .52663 .41647 .52309 .42669 .51384 .42043 .51968 Mtetra
.533 .845 .539 r
.42043 .51968 .42669 .51384 .43691 .50458 .43075 .50949 Mtetra
.654 .924 .634 r
.43075 .50949 .43691 .50458 .4471 .49702 .44107 .49883 Mtetra
.796 .999 .83 r
.44107 .49883 .4471 .49702 .45723 .49223 .45136 .48936 Mtetra
.8 .887 .908 r
.45136 .48936 .45723 .49223 .46736 .48963 .46161 .48201 Mtetra
.696 .711 .86 r
.46161 .48201 .46736 .48963 .4775 .48892 .47183 .47741 Mtetra
.63 .602 .803 r
.47183 .47741 .4775 .48892 .48768 .48897 .48205 .47462 Mtetra
.593 .543 .768 r
.48205 .47462 .48768 .48897 .49793 .48907 .49231 .4731 Mtetra
.582 .52 .75 r
.49231 .4731 .49793 .48907 .50823 .48876 .50261 .47197 Mtetra
.585 .514 .741 r
.50261 .47197 .50823 .48876 .5186 .48771 .51296 .47066 Mtetra
.595 .518 .738 r
.51296 .47066 .5186 .48771 .52902 .48593 .52337 .46885 Mtetra
.609 .526 .736 r
.52337 .46885 .52902 .48593 .53948 .48336 .53382 .4663 Mtetra
.623 .534 .734 r
.53382 .4663 .53948 .48336 .54998 .48006 .54431 .46297 Mtetra
.636 .542 .731 r
.54431 .46297 .54998 .48006 .56051 .47601 .55484 .45884 Mtetra
.647 .548 .728 r
.55484 .45884 .56051 .47601 .57107 .47118 .56539 .45397 Mtetra
.655 .552 .727 r
.56539 .45397 .57107 .47118 .58165 .46561 .57596 .44859 Mtetra
.658 .556 .728 r
.57596 .44859 .58165 .46561 .59224 .45928 .58656 .44302 Mtetra
.656 .561 .736 r
.58656 .44302 .59224 .45928 .60284 .45253 .5972 .43784 Mtetra
.64 .569 .758 r
.5972 .43784 .60284 .45253 .61345 .44581 .60789 .43394 Mtetra
.608 .591 .808 r
.60789 .43394 .61345 .44581 .62412 .43985 .61868 .43187 Mtetra
.484 .619 .908 r
.61868 .43187 .62412 .43985 .63487 .4358 .62961 .43258 Mtetra
.027 .529 .874 r
.62961 .43258 .63487 .4358 .64574 .43398 .64069 .43547 Mtetra
.479 0 0 r
.64069 .43547 .64574 .43398 .65678 .43498 .6519 .43961 Mtetra
.529 .022 0 r
.6519 .43961 .65678 .43498 .66797 .43773 .66318 .44328 Mtetra
.398 0 0 r
.66318 .44328 .66797 .43773 .67924 .4405 .67441 .44367 Mtetra
.009 0 0 r
.67441 .44367 .67924 .4405 .69054 .44199 .68554 .44057 Mtetra
.746 .965 .935 r
.68554 .44057 .69054 .44199 .70173 .44015 .69651 .43359 Mtetra
.804 .792 .841 r
.69651 .43359 .70173 .44015 .71282 .43553 .70737 .42444 Mtetra
.749 .676 .779 r
.70737 .42444 .71282 .43553 .72382 .42888 .71826 .41557 Mtetra
.714 .628 .76 r
.71826 .41557 .72382 .42888 .73479 .42136 .72923 .40773 Mtetra
.676 .606 .769 r
.72923 .40773 .73479 .42136 .74583 .41459 .74035 .40206 Mtetra
.649 .608 .794 r
.74035 .40206 .74583 .41459 .75695 .40873 .75162 .39805 Mtetra
.628 .63 .833 r
.75162 .39805 .75695 .40873 .7682 .40412 .76302 .39519 Mtetra
.609 .661 .875 r
.76302 .39519 .7682 .40412 .77956 .40042 .77452 .39298 Mtetra
.604 .703 .913 r
.77452 .39298 .77956 .40042 .79101 .39726 .78607 .39077 Mtetra
.602 .736 .938 r
.78607 .39077 .79101 .39726 .80254 .3944 .79768 .38844 Mtetra
.614 .761 .95 r
.79768 .38844 .80254 .3944 .81411 .39151 .80931 .38573 Mtetra
.625 .774 .952 r
.80931 .38573 .81411 .39151 .82573 .38855 .82096 .3827 Mtetra
.638 .778 .948 r
.82096 .3827 .82573 .38855 .83739 .38541 .83263 .37937 Mtetra
.647 .775 .941 r
.83263 .37937 .83739 .38541 .84908 .38213 .84434 .37582 Mtetra
.654 .769 .934 r
.84434 .37582 .84908 .38213 .86081 .37873 .85608 .37213 Mtetra
.656 .76 .926 r
.85608 .37213 .86081 .37873 .87259 .37524 .86786 .36837 Mtetra
.642 .748 .926 r
.23902 .55988 .24535 .5654 .25479 .56244 .24846 .55717 Mtetra
.641 .758 .933 r
.24846 .55717 .25479 .56244 .26427 .55942 .25793 .55446 Mtetra
.643 .771 .941 r
.25793 .55446 .26427 .55942 .2738 .55627 .26745 .55166 Mtetra
.649 .787 .947 r
.26745 .55166 .2738 .55627 .28337 .55291 .27702 .54867 Mtetra
.659 .804 .953 r
.27702 .54867 .28337 .55291 .29299 .54926 .28664 .54541 Mtetra
.675 .824 .955 r
.28664 .54541 .29299 .54926 .30266 .54531 .29632 .54176 Mtetra
.698 .84 .951 r
.29632 .54176 .30266 .54531 .31239 .54099 .30606 .53755 Mtetra
.719 .848 .943 r
.30606 .53755 .31239 .54099 .32215 .53655 .31587 .53284 Mtetra
.74 .84 .926 r
.31587 .53284 .32215 .53655 .33194 .53211 .32574 .52754 Mtetra
.738 .808 .907 r
.32574 .52754 .33194 .53211 .34172 .5283 .33563 .52222 Mtetra
.72 .754 .88 r
.33563 .52222 .34172 .5283 .35148 .5256 .34553 .51721 Mtetra
.669 .676 .848 r
.34553 .51721 .35148 .5256 .36119 .52451 .35539 .51351 Mtetra
.598 .592 .817 r
.35539 .51351 .36119 .52451 .37085 .52554 .36517 .51196 Mtetra
.531 .516 .784 r
.36517 .51196 .37085 .52554 .38053 .52759 .3749 .51266 Mtetra
.457 .456 .768 r
.3749 .51266 .38053 .52759 .39027 .52993 .38459 .51582 Mtetra
.444 .46 .781 r
.38459 .51582 .39027 .52993 .40015 .53017 .39434 .51911 Mtetra
.469 .528 .835 r
.39434 .51911 .40015 .53017 .41022 .52663 .40422 .52096 Mtetra
.562 .729 .953 r
.40422 .52096 .41022 .52663 .42043 .51968 .41428 .51961 Mtetra
.68 .965 .934 r
.41428 .51961 .42043 .51968 .43075 .50949 .42452 .51388 Mtetra
.525 .874 .626 r
.42452 .51388 .43075 .50949 .44107 .49883 .43485 .50544 Mtetra
0 0 0 r
.43485 .50544 .44107 .49883 .45136 .48936 .44523 .49528 Mtetra
.44523 .49528 .45136 .48936 .46161 .48201 .4556 .48546 Mtetra
.589 .922 .702 r
.4556 .48546 .46161 .48201 .47183 .47741 .46594 .47719 Mtetra
.73 .974 .926 r
.46594 .47719 .47183 .47741 .48205 .47462 .47626 .47061 Mtetra
.712 .842 .944 r
.47626 .47061 .48205 .47462 .49231 .4731 .48658 .46582 Mtetra
.67 .716 .883 r
.48658 .46582 .49231 .4731 .50261 .47197 .49692 .46211 Mtetra
.641 .641 .834 r
.49692 .46211 .50261 .47197 .51296 .47066 .50729 .45905 Mtetra
.631 .604 .804 r
.50729 .45905 .51296 .47066 .52337 .46885 .5177 .45613 Mtetra
.631 .587 .786 r
.5177 .45613 .52337 .46885 .53382 .4663 .52816 .45306 Mtetra
.635 .582 .778 r
.52816 .45306 .53382 .4663 .54431 .46297 .53865 .44969 Mtetra
.641 .586 .776 r
.53865 .44969 .54431 .46297 .55484 .45884 .54919 .44603 Mtetra
.647 .595 .782 r
.54919 .44603 .55484 .45884 .56539 .45397 .55976 .44221 Mtetra
.648 .612 .799 r
.55976 .44221 .56539 .45397 .57596 .44859 .57037 .43855 Mtetra
.638 .639 .835 r
.57037 .43855 .57596 .44859 .58656 .44302 .58103 .43553 Mtetra
.601 .689 .904 r
.58103 .43553 .58656 .44302 .5972 .43784 .59176 .43359 Mtetra
.417 .732 .991 r
.59176 .43359 .5972 .43784 .60789 .43394 .60258 .43348 Mtetra
.137 0 0 r
.60258 .43348 .60789 .43394 .61868 .43187 .61352 .43508 Mtetra
.485 0 0 r
.61352 .43508 .61868 .43187 .62961 .43258 .62458 .43829 Mtetra
.538 .054 .055 r
.62458 .43829 .62961 .43258 .64069 .43547 .63574 .44185 Mtetra
.48 .004 .047 r
.63574 .44185 .64069 .43547 .6519 .43961 .64692 .4437 Mtetra
.259 0 0 r
.64692 .4437 .6519 .43961 .66318 .44328 .65808 .4428 Mtetra
.609 .948 .925 r
.65808 .4428 .66318 .44328 .67441 .44367 .66909 .43741 Mtetra
.798 .799 .852 r
.66909 .43741 .67441 .44367 .68554 .44057 .67999 .42874 Mtetra
.761 .669 .761 r
.67999 .42874 .68554 .44057 .69651 .43359 .69081 .41857 Mtetra
.731 .618 .731 r
.69081 .41857 .69651 .43359 .70737 .42444 .70164 .40853 Mtetra
.692 .589 .736 r
.70164 .40853 .70737 .42444 .71826 .41557 .71261 .40098 Mtetra
.663 .587 .76 r
.71261 .40098 .71826 .41557 .72923 .40773 .72375 .39574 Mtetra
.629 .606 .808 r
.72375 .39574 .72923 .40773 .74035 .40206 .73506 .39271 Mtetra
.592 .642 .869 r
.73506 .39271 .74035 .40206 .75162 .39805 .74652 .39104 Mtetra
.564 .699 .931 r
.74652 .39104 .75162 .39805 .76302 .39519 .75805 .3897 Mtetra
.539 .746 .971 r
.75805 .3897 .76302 .39519 .77452 .39298 .76966 .38833 Mtetra
.551 .788 .987 r
.76966 .38833 .77452 .39298 .78607 .39077 .78127 .38636 Mtetra
.574 .809 .988 r
.78127 .38636 .78607 .39077 .79768 .38844 .7929 .38387 Mtetra
.609 .818 .98 r
.7929 .38387 .79768 .38844 .80931 .38573 .80454 .38081 Mtetra
.635 .814 .969 r
.80454 .38081 .80931 .38573 .82096 .3827 .81619 .37732 Mtetra
.651 .803 .956 r
.81619 .37732 .82096 .3827 .83263 .37937 .82787 .37355 Mtetra
.662 .791 .944 r
.82787 .37355 .83263 .37937 .84434 .37582 .83957 .36959 Mtetra
.666 .778 .933 r
.83957 .36959 .84434 .37582 .85608 .37213 .85132 .36552 Mtetra
.667 .766 .924 r
.85132 .36552 .85608 .37213 .86786 .36837 .8631 .36144 Mtetra
.632 .745 .93 r
.23264 .55431 .23902 .55988 .24846 .55717 .24208 .55181 Mtetra
.627 .752 .937 r
.24208 .55181 .24846 .55717 .25793 .55446 .25156 .54937 Mtetra
.624 .763 .945 r
.25156 .54937 .25793 .55446 .26745 .55166 .26106 .54694 Mtetra
.623 .778 .955 r
.26106 .54694 .26745 .55166 .27702 .54867 .27061 .54445 Mtetra
.622 .798 .967 r
.27061 .54445 .27702 .54867 .28664 .54541 .28021 .54186 Mtetra
.629 .828 .977 r
.28021 .54186 .28664 .54541 .29632 .54176 .28986 .53896 Mtetra
.643 .863 .982 r
.28986 .53896 .29632 .54176 .30606 .53755 .29959 .53558 Mtetra
.667 .9 .979 r
.29959 .53558 .30606 .53755 .31587 .53284 .30939 .53148 Mtetra
.709 .929 .963 r
.30939 .53148 .31587 .53284 .32574 .52754 .31928 .52638 Mtetra
.75 .939 .947 r
.31928 .52638 .32574 .52754 .33563 .52222 .32925 .5204 Mtetra
.792 .914 .923 r
.32925 .5204 .33563 .52222 .34553 .51721 .33929 .51346 Mtetra
.786 .843 .895 r
.33929 .51346 .34553 .51721 .35539 .51351 .34934 .50656 Mtetra
.741 .736 .847 r
.34934 .50656 .35539 .51351 .36517 .51196 .35938 .50037 Mtetra
.656 .611 .791 r
.35938 .50037 .36517 .51196 .3749 .51266 .36932 .49648 Mtetra
.563 .504 .747 r
.36932 .49648 .3749 .51266 .38459 .51582 .37914 .49615 Mtetra
.494 .432 .716 r
.37914 .49615 .38459 .51582 .39434 .51911 .38888 .49895 Mtetra
.42 .381 .709 r
.38888 .49895 .39434 .51911 .40422 .52096 .39859 .50467 Mtetra
.392 .401 .75 r
.39859 .50467 .40422 .52096 .41428 .51961 .4084 .50998 Mtetra
.398 .524 .868 r
.4084 .50998 .41428 .51961 .42452 .51388 .41838 .51269 Mtetra
.306 .78 .927 r
.41838 .51269 .42452 .51388 .43485 .50544 .42855 .5115 Mtetra
0 0 0 r
.42855 .5115 .43485 .50544 .44523 .49528 .4389 .50557 Mtetra
.003 0 0 r
.4389 .50557 .44523 .49528 .4556 .48546 .44932 .49699 Mtetra
0 0 0 r
.44932 .49699 .4556 .48546 .46594 .47719 .45978 .48699 Mtetra
.45978 .48699 .46594 .47719 .47626 .47061 .47024 .47724 Mtetra
.47024 .47724 .47626 .47061 .48658 .46582 .48067 .46875 Mtetra
.527 .9 .714 r
.48067 .46875 .48658 .46582 .49692 .46211 .4911 .46158 Mtetra
.684 .962 .941 r
.4911 .46158 .49692 .46211 .50729 .45905 .50154 .45584 Mtetra
.702 .877 .963 r
.50154 .45584 .50729 .45905 .5177 .45613 .51199 .45106 Mtetra
.679 .798 .938 r
.51199 .45106 .5177 .45613 .52816 .45306 .52248 .44708 Mtetra
.657 .759 .925 r
.52248 .44708 .52816 .45306 .53865 .44969 .533 .44369 Mtetra
.631 .75 .933 r
.533 .44369 .53865 .44969 .54919 .44603 .54357 .4409 Mtetra
.581 .766 .967 r
.54357 .4409 .54919 .44603 .55976 .44221 .55419 .4389 Mtetra
.444 .785 .998 r
.55419 .4389 .55976 .44221 .57037 .43855 .56487 .43789 Mtetra
.023 .593 .767 r
.56487 .43789 .57037 .43855 .58103 .43553 .57563 .43831 Mtetra
.388 0 0 r
.57563 .43831 .58103 .43553 .59176 .43359 .58648 .44008 Mtetra
.529 .059 .084 r
.58648 .44008 .59176 .43359 .60258 .43348 .59744 .44315 Mtetra
.552 .132 .199 r
.59744 .44315 .60258 .43348 .61352 .43508 .6085 .4465 Mtetra
.521 .121 .223 r
.6085 .4465 .61352 .43508 .62458 .43829 .6196 .44843 Mtetra
.43 .016 .15 r
.6196 .44843 .62458 .43829 .63574 .44185 .63069 .44767 Mtetra
.004 0 0 r
.63069 .44767 .63574 .44185 .64692 .4437 .64167 .4421 Mtetra
.842 .959 .886 r
.64167 .4421 .64692 .4437 .65808 .4428 .65253 .43254 Mtetra
.803 .708 .76 r
.65253 .43254 .65808 .4428 .66909 .43741 .66328 .42028 Mtetra
.745 .606 .704 r
.66328 .42028 .66909 .43741 .67999 .42874 .67399 .40759 Mtetra
.689 .55 .69 r
.67399 .40759 .67999 .42874 .69081 .41857 .68482 .39786 Mtetra
.654 .531 .702 r
.68482 .39786 .69081 .41857 .70164 .40853 .69583 .39132 Mtetra
.611 .532 .741 r
.69583 .39132 .70164 .40853 .71261 .40098 .70707 .38843 Mtetra
.562 .562 .811 r
.70707 .38843 .71261 .40098 .72375 .39574 .7185 .38792 Mtetra
.5 .64 .918 r
.7185 .38792 .72375 .39574 .73506 .39271 .73005 .38815 Mtetra
.394 .712 .986 r
.73005 .38815 .73506 .39271 .74652 .39104 .74167 .38842 Mtetra
.347 .768 .976 r
.74167 .38842 .74652 .39104 .75805 .3897 .75331 .38772 Mtetra
.377 .809 .964 r
.75331 .38772 .75805 .3897 .76966 .38833 .76494 .38611 Mtetra
.484 .858 .984 r
.76494 .38611 .76966 .38833 .78127 .38636 .77655 .38347 Mtetra
.575 .876 .994 r
.77655 .38347 .78127 .38636 .7929 .38387 .78815 .38008 Mtetra
.634 .862 .985 r
.78815 .38008 .7929 .38387 .80454 .38081 .79977 .37618 Mtetra
.664 .839 .967 r
.79977 .37618 .80454 .38081 .81619 .37732 .8114 .37195 Mtetra
.674 .814 .95 r
.8114 .37195 .81619 .37732 .82787 .37355 .82306 .36761 Mtetra
.678 .794 .937 r
.82306 .36761 .82787 .37355 .83957 .36959 .83476 .36321 Mtetra
.678 .78 .927 r
.83476 .36321 .83957 .36959 .85132 .36552 .84651 .3588 Mtetra
.675 .767 .92 r
.84651 .3588 .85132 .36552 .8631 .36144 .85831 .35446 Mtetra
.633 .746 .929 r
.22623 .54871 .23264 .55431 .24208 .55181 .23569 .54616 Mtetra
.628 .743 .93 r
.23569 .54616 .24208 .55181 .25156 .54937 .24518 .54372 Mtetra
.622 .742 .933 r
.24518 .54372 .25156 .54937 .26106 .54694 .25469 .54139 Mtetra
.616 .744 .938 r
.25469 .54139 .26106 .54694 .27061 .54445 .26424 .53915 Mtetra
.605 .752 .948 r
.26424 .53915 .27061 .54445 .28021 .54186 .27382 .53706 Mtetra
.601 .771 .961 r
.27382 .53706 .28021 .54186 .28986 .53896 .28344 .53492 Mtetra
.597 .801 .978 r
.28344 .53492 .28986 .53896 .29959 .53558 .29312 .53263 Mtetra
.606 .849 .99 r
.29312 .53263 .29959 .53558 .30939 .53148 .30286 .52981 Mtetra
.624 .903 .985 r
.30286 .52981 .30939 .53148 .31928 .52638 .3127 .52614 Mtetra
.647 .949 .951 r
.3127 .52614 .31928 .52638 .32925 .5204 .32264 .52128 Mtetra
.699 .979 .904 r
.32264 .52128 .32925 .5204 .33929 .51346 .3327 .51485 Mtetra
.746 .991 .877 r
.3327 .51485 .33929 .51346 .34934 .50656 .34285 .50724 Mtetra
.816 .985 .884 r
.34285 .50724 .34934 .50656 .35938 .50037 .35305 .49862 Mtetra
.819 .917 .904 r
.35305 .49862 .35938 .50037 .36932 .49648 .36322 .49069 Mtetra
.746 .774 .876 r
.36322 .49069 .36932 .49648 .37914 .49615 .37332 .48472 Mtetra
.626 .601 .805 r
.37332 .48472 .37914 .49615 .38888 .49895 .38329 .48208 Mtetra
.51 .467 .745 r
.38329 .48208 .38888 .49895 .39859 .50467 .39313 .48381 Mtetra
.462 .404 .706 r
.39313 .48381 .39859 .50467 .4084 .50998 .40294 .48806 Mtetra
.436 .38 .697 r
.40294 .48806 .4084 .50998 .41838 .51269 .41279 .49362 Mtetra
.455 .414 .724 r
.41279 .49362 .41838 .51269 .42855 .5115 .42278 .49778 Mtetra
.519 .513 .789 r
.42278 .49778 .42855 .5115 .4389 .50557 .43294 .49877 Mtetra
.606 .71 .918 r
.43294 .49877 .4389 .50557 .44932 .49699 .44323 .49668 Mtetra
.637 .952 .942 r
.44323 .49668 .44932 .49699 .45978 .48699 .45365 .49152 Mtetra
0 0 0 r
.45365 .49152 .45978 .48699 .47024 .47724 .46411 .48485 Mtetra
.46411 .48485 .47024 .47724 .48067 .46875 .47461 .4776 Mtetra
.043 0 0 r
.47461 .4776 .48067 .46875 .4911 .46158 .48511 .4706 Mtetra
.112 0 0 r
.48511 .4706 .4911 .46158 .50154 .45584 .49563 .4644 Mtetra
.151 0 0 r
.49563 .4644 .50154 .45584 .51199 .45106 .50616 .45907 Mtetra
.193 0 0 r
.50616 .45907 .51199 .45106 .52248 .44708 .51672 .45473 Mtetra
.24 0 0 r
.51672 .45473 .52248 .44708 .533 .44369 .52732 .45133 Mtetra
.297 0 0 r
.52732 .45133 .533 .44369 .54357 .4409 .53796 .44887 Mtetra
.36 0 .044 r
.53796 .44887 .54357 .4409 .55419 .4389 .54865 .4474 Mtetra
.411 0 .091 r
.54865 .4474 .55419 .4389 .56487 .43789 .55941 .44682 Mtetra
.45 .018 .125 r
.55941 .44682 .56487 .43789 .57563 .43831 .57024 .44706 Mtetra
.457 .021 .122 r
.57024 .44706 .57563 .43831 .58648 .44008 .58114 .44756 Mtetra
.414 0 .053 r
.58114 .44756 .58648 .44008 .59744 .44315 .5921 .4475 Mtetra
.214 0 0 r
.5921 .4475 .59744 .44315 .6085 .4465 .60309 .4459 Mtetra
.573 .932 .936 r
.60309 .4459 .6085 .4465 .6196 .44843 .61405 .4412 Mtetra
.771 .763 .846 r
.61405 .4412 .6196 .44843 .63069 .44767 .62495 .43336 Mtetra
.749 .633 .732 r
.62495 .43336 .63069 .44767 .64167 .4421 .63575 .42227 Mtetra
.725 .578 .689 r
.63575 .42227 .64167 .4421 .65253 .43254 .64649 .40972 Mtetra
.696 .545 .678 r
.64649 .40972 .65253 .43254 .66328 .42028 .65727 .39849 Mtetra
.675 .537 .69 r
.65727 .39849 .66328 .42028 .67399 .40759 .66815 .38981 Mtetra
.632 .539 .731 r
.66815 .38981 .67399 .40759 .68482 .39786 .67925 .38559 Mtetra
.569 .57 .815 r
.67925 .38559 .68482 .39786 .69583 .39132 .69057 .38478 Mtetra
.409 .638 .95 r
.69057 .38478 .69583 .39132 .70707 .38843 .70207 .386 Mtetra
.054 .578 .869 r
.70207 .386 .70707 .38843 .7185 .38792 .71369 .38796 Mtetra
.1 0 0 r
.71369 .38796 .7185 .38792 .73005 .38815 .72533 .38889 Mtetra
.049 0 0 r
.72533 .38889 .73005 .38815 .74167 .38842 .73697 .3886 Mtetra
.182 .716 .776 r
.73697 .3886 .74167 .38842 .75331 .38772 .74857 .3867 Mtetra
.432 .863 .931 r
.74857 .3867 .75331 .38772 .76494 .38611 .76015 .38356 Mtetra
.601 .899 .987 r
.76015 .38356 .76494 .38611 .77655 .38347 .7717 .37954 Mtetra
.67 .87 .974 r
.7717 .37954 .77655 .38347 .78815 .38008 .78326 .37497 Mtetra
.689 .829 .95 r
.78326 .37497 .78815 .38008 .79977 .37618 .79484 .37023 Mtetra
.692 .799 .931 r
.79484 .37023 .79977 .37618 .8114 .37195 .80646 .36543 Mtetra
.687 .778 .92 r
.80646 .36543 .8114 .37195 .82306 .36761 .81813 .36078 Mtetra
.683 .766 .915 r
.81813 .36078 .82306 .36761 .83476 .36321 .82986 .35622 Mtetra
.678 .76 .913 r
.82986 .35622 .83476 .36321 .84651 .3588 .84164 .35177 Mtetra
.674 .758 .914 r
.84164 .35177 .84651 .3588 .85831 .35446 .85348 .34743 Mtetra
.647 .749 .924 r
.21976 .54307 .22623 .54871 .23569 .54616 .22927 .54021 Mtetra
.643 .738 .918 r
.22927 .54021 .23569 .54616 .24518 .54372 .2388 .53744 Mtetra
.635 .725 .913 r
.2388 .53744 .24518 .54372 .25469 .54139 .24836 .53484 Mtetra
.625 .714 .91 r
.24836 .53484 .25469 .54139 .26424 .53915 .25793 .5325 Mtetra
.608 .706 .913 r
.25793 .5325 .26424 .53915 .27382 .53706 .26752 .53051 Mtetra
.593 .705 .921 r
.26752 .53051 .27382 .53706 .28344 .53492 .27712 .52882 Mtetra
.57 .713 .939 r
.27712 .52882 .28344 .53492 .29312 .53263 .28674 .52748 Mtetra
.553 .744 .965 r
.28674 .52748 .29312 .53263 .30286 .52981 .29641 .52614 Mtetra
.523 .795 .995 r
.29641 .52614 .30286 .52981 .3127 .52614 .30614 .52464 Mtetra
.481 .86 .981 r
.30614 .52464 .3127 .52614 .32264 .52128 .31596 .52235 Mtetra
.398 .854 .836 r
.31596 .52235 .32264 .52128 .3327 .51485 .32589 .51878 Mtetra
0 0 0 r
.32589 .51878 .3327 .51485 .34285 .50724 .33597 .51338 Mtetra
.33597 .51338 .34285 .50724 .35305 .49862 .34619 .50563 Mtetra
.34619 .50563 .35305 .49862 .36322 .49069 .35653 .49594 Mtetra
.711 .95 .661 r
.35653 .49594 .36322 .49069 .37332 .48472 .36694 .48458 Mtetra
.877 .952 .854 r
.36694 .48458 .37332 .48472 .38329 .48208 .37731 .47391 Mtetra
.768 .717 .806 r
.37731 .47391 .38329 .48208 .39313 .48381 .38757 .46562 Mtetra
.631 .528 .719 r
.38757 .46562 .39313 .48381 .40294 .48806 .39768 .46156 Mtetra
.533 .42 .671 r
.39768 .46156 .40294 .48806 .41279 .49362 .40762 .46292 Mtetra
.485 .373 .651 r
.40762 .46292 .41279 .49362 .42278 .49778 .41752 .46771 Mtetra
.447 .349 .651 r
.41752 .46771 .42278 .49778 .43294 .49877 .42745 .47464 Mtetra
.432 .365 .683 r
.42745 .47464 .43294 .49877 .44323 .49668 .43749 .48093 Mtetra
.436 .438 .763 r
.43749 .48093 .44323 .49668 .45365 .49152 .44769 .48481 Mtetra
.406 .627 .943 r
.44769 .48481 .45365 .49152 .46411 .48485 .45802 .48605 Mtetra
0 0 0 r
.45802 .48605 .46411 .48485 .47461 .4776 .46848 .48451 Mtetra
.214 0 0 r
.46848 .48451 .47461 .4776 .48511 .4706 .479 .48134 Mtetra
.292 0 .092 r
.479 .48134 .48511 .4706 .49563 .4644 .48958 .47723 Mtetra
.332 0 .162 r
.48958 .47723 .49563 .4644 .50616 .45907 .5002 .47296 Mtetra
.362 0 .197 r
.5002 .47296 .50616 .45907 .51672 .45473 .51085 .46902 Mtetra
.386 .02 .215 r
.51085 .46902 .51672 .45473 .52732 .45133 .52154 .46561 Mtetra
.403 .035 .222 r
.52154 .46561 .52732 .45133 .53796 .44887 .53227 .46274 Mtetra
.409 .037 .218 r
.53227 .46274 .53796 .44887 .54865 .4474 .54305 .4602 Mtetra
.392 .01 .19 r
.54305 .4602 .54865 .4474 .55941 .44682 .55387 .4575 Mtetra
.32 0 .106 r
.55387 .4575 .55941 .44682 .57024 .44706 .56473 .45387 Mtetra
.07 0 0 r
.56473 .45387 .57024 .44706 .58114 .44756 .57561 .44857 Mtetra
.709 .986 .847 r
.57561 .44857 .58114 .44756 .5921 .4475 .58647 .44046 Mtetra
.822 .776 .81 r
.58647 .44046 .5921 .4475 .60309 .4459 .59728 .42966 Mtetra
.757 .619 .707 r
.59728 .42966 .60309 .4459 .61405 .4412 .60801 .41638 Mtetra
.71 .545 .663 r
.60801 .41638 .61405 .4412 .62495 .43336 .61871 .40242 Mtetra
.669 .499 .647 r
.61871 .40242 .62495 .43336 .63575 .42227 .62945 .3906 Mtetra
.638 .477 .648 r
.62945 .3906 .63575 .42227 .64649 .40972 .64029 .38225 Mtetra
.59 .459 .67 r
.64029 .38225 .64649 .40972 .65727 .39849 .65137 .37943 Mtetra
.523 .463 .731 r
.65137 .37943 .65727 .39849 .66815 .38981 .66269 .38093 Mtetra
.317 .506 .885 r
.66269 .38093 .66815 .38981 .67925 .38559 .67419 .38489 Mtetra
.377 0 0 r
.67419 .38489 .67925 .38559 .69057 .38478 .68584 .38959 Mtetra
.49 0 0 r
.68584 .38959 .69057 .38478 .70207 .386 .6975 .39259 Mtetra
.438 0 .017 r
.6975 .39259 .70207 .386 .71369 .38796 .70914 .39363 Mtetra
.294 0 0 r
.70914 .39363 .71369 .38796 .72533 .38889 .72071 .39224 Mtetra
.015 0 0 r
.72071 .39224 .72533 .38889 .73697 .3886 .73223 .38897 Mtetra
.432 .873 .835 r
.73223 .38897 .73697 .3886 .74857 .3867 .7437 .38436 Mtetra
.676 .931 .969 r
.7437 .38436 .74857 .3867 .76015 .38356 .75516 .37893 Mtetra
.721 .857 .946 r
.75516 .37893 .76015 .38356 .7717 .37954 .76664 .37332 Mtetra
.719 .797 .913 r
.76664 .37332 .7717 .37954 .78326 .37497 .77815 .36771 Mtetra
.704 .759 .895 r
.77815 .36771 .78326 .37497 .79484 .37023 .78972 .36245 Mtetra
.692 .74 .887 r
.78972 .36245 .79484 .37023 .80646 .36543 .80137 .35749 Mtetra
.68 .731 .888 r
.80137 .35749 .80646 .36543 .81813 .36078 .81308 .3529 Mtetra
.672 .73 .893 r
.81308 .3529 .81813 .36078 .82986 .35622 .82486 .34856 Mtetra
.667 .736 .901 r
.82486 .34856 .82986 .35622 .84164 .35177 .83671 .34441 Mtetra
.663 .744 .91 r
.83671 .34441 .84164 .35177 .85348 .34743 .84861 .34035 Mtetra
.667 .754 .915 r
.21326 .53739 .21976 .54307 .22927 .54021 .22283 .53403 Mtetra
.665 .737 .904 r
.22283 .53403 .22927 .54021 .2388 .53744 .23243 .5307 Mtetra
.658 .718 .893 r
.23243 .5307 .2388 .53744 .24836 .53484 .24205 .52751 Mtetra
.647 .698 .883 r
.24205 .52751 .24836 .53484 .25793 .5325 .25168 .52459 Mtetra
.632 .677 .875 r
.25168 .52459 .25793 .5325 .26752 .53051 .26132 .52206 Mtetra
.613 .656 .869 r
.26132 .52206 .26752 .53051 .27712 .52882 .27096 .52001 Mtetra
.589 .638 .868 r
.27096 .52001 .27712 .52882 .28674 .52748 .2806 .5186 Mtetra
.567 .627 .872 r
.2806 .5186 .28674 .52748 .29641 .52614 .29024 .51771 Mtetra
.538 .628 .888 r
.29024 .51771 .29641 .52614 .30614 .52464 .2999 .51737 Mtetra
.523 .657 .92 r
.2999 .51737 .30614 .52464 .31596 .52235 .3096 .51705 Mtetra
.504 .723 .971 r
.3096 .51705 .31596 .52235 .32589 .51878 .31938 .51641 Mtetra
.488 .836 .997 r
.31938 .51641 .32589 .51878 .33597 .51338 .32929 .51454 Mtetra
.417 .865 .836 r
.32929 .51454 .33597 .51338 .34619 .50563 .33935 .51068 Mtetra
0 0 0 r
.33935 .51068 .34619 .50563 .35653 .49594 .34958 .5042 Mtetra
.34958 .5042 .35653 .49594 .36694 .48458 .35999 .49456 Mtetra
.35999 .49456 .36694 .48458 .37731 .47391 .37048 .48311 Mtetra
.37048 .48311 .37731 .47391 .38757 .46562 .38099 .47079 Mtetra
.642 .921 .636 r
.38099 .47079 .38757 .46562 .39768 .46156 .39142 .4603 Mtetra
.776 .946 .933 r
.39142 .4603 .39768 .46156 .40762 .46292 .4017 .45343 Mtetra
.641 .649 .842 r
.4017 .45343 .40762 .46292 .41752 .46771 .41187 .45038 Mtetra
.53 .476 .741 r
.41187 .45038 .41752 .46771 .42745 .47464 .42195 .4513 Mtetra
.501 .415 .691 r
.42195 .4513 .42745 .47464 .43749 .48093 .43205 .45412 Mtetra
.498 .397 .671 r
.43205 .45412 .43749 .48093 .44769 .48481 .44221 .45754 Mtetra
.51 .404 .669 r
.44221 .45754 .44769 .48481 .45802 .48605 .45246 .46029 Mtetra
.533 .426 .678 r
.45246 .46029 .45802 .48605 .46848 .48451 .46282 .46153 Mtetra
.555 .454 .695 r
.46282 .46153 .46848 .48451 .479 .48134 .47327 .46139 Mtetra
.58 .489 .716 r
.47327 .46139 .479 .48134 .48958 .47723 .4838 .45992 Mtetra
.601 .523 .738 r
.4838 .45992 .48958 .47723 .5002 .47296 .49439 .45757 Mtetra
.618 .552 .758 r
.49439 .45757 .5002 .47296 .51085 .46902 .50504 .45459 Mtetra
.63 .569 .768 r
.50504 .45459 .51085 .46902 .52154 .46561 .51572 .45115 Mtetra
.639 .574 .766 r
.51572 .45115 .52154 .46561 .53227 .46274 .52645 .44725 Mtetra
.647 .567 .751 r
.52645 .44725 .53227 .46274 .54305 .4602 .53722 .44272 Mtetra
.652 .552 .729 r
.53722 .44272 .54305 .4602 .55387 .4575 .54802 .4373 Mtetra
.659 .537 .704 r
.54802 .4373 .55387 .4575 .56473 .45387 .55883 .43052 Mtetra
.663 .522 .682 r
.55883 .43052 .56473 .45387 .57561 .44857 .56964 .42235 Mtetra
.667 .513 .666 r
.56964 .42235 .57561 .44857 .58647 .44046 .58044 .41263 Mtetra
.668 .508 .659 r
.58044 .41263 .58647 .44046 .59728 .42966 .59122 .4022 Mtetra
.664 .506 .661 r
.59122 .4022 .59728 .42966 .60801 .41638 .60202 .39237 Mtetra
.657 .516 .679 r
.60202 .39237 .60801 .41638 .61871 .40242 .61287 .38443 Mtetra
.625 .533 .73 r
.61287 .38443 .61871 .40242 .62945 .3906 .62385 .38053 Mtetra
.531 .595 .863 r
.62385 .38053 .62945 .3906 .64029 .38225 .63501 .38053 Mtetra
0 .371 .673 r
.63501 .38053 .64029 .38225 .65137 .37943 .64639 .38423 Mtetra
.587 .086 .029 r
.64639 .38423 .65137 .37943 .66269 .38093 .65793 .38983 Mtetra
.576 .138 .171 r
.65793 .38983 .66269 .38093 .67419 .38489 .66955 .39458 Mtetra
.53 .101 .17 r
.66955 .39458 .67419 .38489 .68584 .38959 .68119 .39748 Mtetra
.404 0 .051 r
.68119 .39748 .68584 .38959 .6975 .39259 .69275 .39716 Mtetra
.124 0 0 r
.69275 .39716 .6975 .39259 .70914 .39363 .70423 .39415 Mtetra
.465 .89 .834 r
.70423 .39415 .70914 .39363 .72071 .39224 .71564 .38908 Mtetra
.739 .916 .953 r
.71564 .38908 .72071 .39224 .73223 .38897 .72701 .38273 Mtetra
.751 .805 .895 r
.72701 .38273 .73223 .38897 .7437 .38436 .73838 .37602 Mtetra
.734 .738 .854 r
.73838 .37602 .7437 .38436 .75516 .37893 .74978 .36934 Mtetra
.711 .699 .837 r
.74978 .36934 .75516 .37893 .76664 .37332 .76125 .3632 Mtetra
.695 .682 .833 r
.76125 .3632 .76664 .37332 .77815 .36771 .77279 .3576 Mtetra
.679 .676 .84 r
.77279 .3576 .77815 .36771 .78972 .36245 .78441 .35266 Mtetra
.668 .678 .851 r
.78441 .35266 .78972 .36245 .80137 .35749 .79613 .34822 Mtetra
.659 .687 .866 r
.79613 .34822 .80137 .35749 .81308 .3529 .80792 .34418 Mtetra
.652 .699 .881 r
.80792 .34418 .81308 .3529 .82486 .34856 .81979 .34041 Mtetra
.648 .714 .896 r
.81979 .34041 .82486 .34856 .83671 .34441 .83172 .33679 Mtetra
.646 .731 .911 r
.83172 .33679 .83671 .34441 .84861 .34035 .8437 .33321 Mtetra
.686 .758 .906 r
.20671 .53168 .21326 .53739 .22283 .53403 .21635 .52779 Mtetra
.686 .742 .893 r
.21635 .52779 .22283 .53403 .23243 .5307 .22602 .52384 Mtetra
.682 .722 .88 r
.22602 .52384 .23243 .5307 .24205 .52751 .23572 .51992 Mtetra
.674 .7 .866 r
.23572 .51992 .24205 .52751 .25168 .52459 .24544 .51614 Mtetra
.663 .676 .851 r
.24544 .51614 .25168 .52459 .26132 .52206 .25517 .51259 Mtetra
.646 .646 .836 r
.25517 .51259 .26132 .52206 .27096 .52001 .2649 .50947 Mtetra
.623 .616 .822 r
.2649 .50947 .27096 .52001 .2806 .5186 .27462 .50699 Mtetra
.597 .584 .809 r
.27462 .50699 .2806 .5186 .29024 .51771 .28432 .50532 Mtetra
.565 .556 .802 r
.28432 .50532 .29024 .51771 .2999 .51737 .29399 .50467 Mtetra
.535 .536 .802 r
.29399 .50467 .2999 .51737 .3096 .51705 .30366 .50493 Mtetra
.499 .526 .816 r
.30366 .50493 .3096 .51705 .31938 .51641 .31332 .50609 Mtetra
.467 .547 .855 r
.31332 .50609 .31938 .51641 .32929 .51454 .32303 .50754 Mtetra
.405 .615 .936 r
.32303 .50754 .32929 .51454 .33935 .51068 .33281 .50883 Mtetra
.185 .69 .907 r
.33281 .50883 .33935 .51068 .34958 .5042 .34272 .50899 Mtetra
.193 0 0 r
.34272 .50899 .34958 .5042 .35999 .49456 .35279 .50718 Mtetra
.281 0 .12 r
.35279 .50718 .35999 .49456 .37048 .48311 .36306 .50228 Mtetra
.257 0 .213 r
.36306 .50228 .37048 .48311 .38099 .47079 .37353 .49347 Mtetra
.208 0 .227 r
.37353 .49347 .38099 .47079 .39142 .4603 .38415 .48127 Mtetra
.067 0 .147 r
.38415 .48127 .39142 .4603 .4017 .45343 .39487 .46624 Mtetra
0 0 0 r
.39487 .46624 .4017 .45343 .41187 .45038 .40556 .45128 Mtetra
.907 .966 .808 r
.40556 .45128 .41187 .45038 .42195 .4513 .41614 .43829 Mtetra
.74 .636 .744 r
.41614 .43829 .42195 .4513 .43205 .45412 .4266 .4287 Mtetra
.625 .486 .673 r
.4266 .4287 .43205 .45412 .44221 .45754 .43695 .42333 Mtetra
.577 .427 .641 r
.43695 .42333 .44221 .45754 .45246 .46029 .44725 .42093 Mtetra
.552 .399 .627 r
.44725 .42093 .45246 .46029 .46282 .46153 .45755 .42069 Mtetra
.545 .392 .624 r
.45755 .42069 .46282 .46153 .47327 .46139 .4679 .42111 Mtetra
.549 .395 .625 r
.4679 .42111 .47327 .46139 .4838 .45992 .47832 .42122 Mtetra
.558 .405 .63 r
.47832 .42122 .4838 .45992 .49439 .45757 .48882 .42045 Mtetra
.571 .418 .634 r
.48882 .42045 .49439 .45757 .50504 .45459 .49938 .41836 Mtetra
.586 .43 .636 r
.49938 .41836 .50504 .45459 .51572 .45115 .51 .41487 Mtetra
.598 .438 .636 r
.51 .41487 .51572 .45115 .52645 .44725 .52066 .40997 Mtetra
.608 .443 .633 r
.52066 .40997 .52645 .44725 .53722 .44272 .53135 .40376 Mtetra
.613 .443 .629 r
.53135 .40376 .53722 .44272 .54802 .4373 .54206 .39663 Mtetra
.613 .44 .625 r
.54206 .39663 .54802 .4373 .55883 .43052 .55278 .38919 Mtetra
.607 .435 .623 r
.55278 .38919 .55883 .43052 .56964 .42235 .56353 .38239 Mtetra
.591 .426 .627 r
.56353 .38239 .56964 .42235 .58044 .41263 .57434 .37778 Mtetra
.568 .421 .642 r
.57434 .37778 .58044 .41263 .59122 .4022 .58523 .37616 Mtetra
.51 .412 .679 r
.58523 .37616 .59122 .4022 .60202 .39237 .59628 .37883 Mtetra
.321 .405 .792 r
.59628 .37883 .60202 .39237 .61287 .38443 .6075 .38498 Mtetra
.632 .075 0 r
.6075 .38498 .61287 .38443 .62385 .38053 .6189 .39317 Mtetra
.639 .245 .281 r
.6189 .39317 .62385 .38053 .63501 .38053 .63042 .40148 Mtetra
.581 .238 .353 r
.63042 .40148 .63501 .38053 .64639 .38423 .64197 .40693 Mtetra
.534 .202 .353 r
.64197 .40693 .64639 .38423 .65793 .38983 .6535 .40895 Mtetra
.458 .117 .299 r
.6535 .40895 .65793 .38983 .66955 .39458 .66494 .40696 Mtetra
.3 0 .138 r
.66494 .40696 .66955 .39458 .68119 .39748 .67628 .4018 Mtetra
0 0 0 r
.67628 .4018 .68119 .39748 .69275 .39716 .68756 .39461 Mtetra
.805 .943 .916 r
.68756 .39461 .69275 .39716 .70423 .39415 .6988 .38624 Mtetra
.778 .761 .838 r
.6988 .38624 .70423 .39415 .71564 .38908 .71004 .37768 Mtetra
.737 .674 .789 r
.71004 .37768 .71564 .38908 .72701 .38273 .72131 .36941 Mtetra
.706 .632 .772 r
.72131 .36941 .72701 .38273 .73838 .37602 .73266 .36205 Mtetra
.686 .613 .769 r
.73266 .36205 .73838 .37602 .74978 .36934 .74409 .35562 Mtetra
.668 .608 .779 r
.74409 .35562 .74978 .36934 .76125 .3632 .75562 .35024 Mtetra
.655 .612 .795 r
.75562 .35024 .76125 .3632 .77279 .3576 .76726 .3457 Mtetra
.645 .625 .816 r
.76726 .3457 .77279 .3576 .78441 .35266 .77899 .34181 Mtetra
.637 .642 .838 r
.77899 .34181 .78441 .35266 .79613 .34822 .79081 .33838 Mtetra
.632 .662 .861 r
.79081 .33838 .79613 .34822 .80792 .34418 .80271 .33518 Mtetra
.628 .682 .882 r
.80271 .33518 .80792 .34418 .81979 .34041 .81467 .33212 Mtetra
.626 .702 .9 r
.81467 .33212 .81979 .34041 .83172 .33679 .82669 .32911 Mtetra
.627 .722 .915 r
.82669 .32911 .83172 .33679 .8437 .33321 .83876 .32602 Mtetra
.692 .759 .903 r
.20012 .52592 .20671 .53168 .21635 .52779 .20979 .52184 Mtetra
.696 .754 .897 r
.20979 .52184 .21635 .52779 .22602 .52384 .21951 .51762 Mtetra
.698 .747 .89 r
.21951 .51762 .22602 .52384 .23572 .51992 .22926 .5133 Mtetra
.697 .735 .88 r
.22926 .5133 .23572 .51992 .24544 .51614 .23905 .50891 Mtetra
.695 .718 .867 r
.23905 .50891 .24544 .51614 .25517 .51259 .24887 .50446 Mtetra
.685 .692 .851 r
.24887 .50446 .25517 .51259 .2649 .50947 .25871 .50017 Mtetra
.67 .661 .832 r
.25871 .50017 .2649 .50947 .27462 .50699 .26856 .49617 Mtetra
.646 .622 .811 r
.26856 .49617 .27462 .50699 .28432 .50532 .27839 .49278 Mtetra
.617 .58 .79 r
.27839 .49278 .28432 .50532 .29399 .50467 .28819 .4903 Mtetra
.584 .539 .77 r
.28819 .4903 .29399 .50467 .30366 .50493 .29795 .48895 Mtetra
.547 .499 .754 r
.29795 .48895 .30366 .50493 .31332 .50609 .30767 .489 Mtetra
.515 .469 .744 r
.30767 .489 .31332 .50609 .32303 .50754 .31737 .49032 Mtetra
.479 .447 .744 r
.31737 .49032 .32303 .50754 .33281 .50883 .32705 .49289 Mtetra
.455 .447 .76 r
.32705 .49289 .33281 .50883 .34272 .50899 .33678 .49596 Mtetra
.429 .475 .805 r
.33678 .49596 .34272 .50899 .35279 .50718 .3466 .49892 Mtetra
.441 .594 .908 r
.3466 .49892 .35279 .50718 .36306 .50228 .35657 .50015 Mtetra
.449 .83 .988 r
.35657 .50015 .36306 .50228 .37353 .49347 .36676 .49838 Mtetra
0 0 0 r
.36676 .49838 .37353 .49347 .38415 .48127 .37716 .49284 Mtetra
.37716 .49284 .38415 .48127 .39487 .46624 .38776 .48308 Mtetra
.065 0 .09 r
.38776 .48308 .39487 .46624 .40556 .45128 .39845 .47106 Mtetra
.118 0 .157 r
.39845 .47106 .40556 .45128 .41614 .43829 .40915 .45809 Mtetra
.162 0 .179 r
.40915 .45809 .41614 .43829 .4266 .4287 .41981 .44615 Mtetra
.196 0 .167 r
.41981 .44615 .4266 .4287 .43695 .42333 .43038 .43647 Mtetra
.178 0 .083 r
.43038 .43647 .43695 .42333 .44725 .42093 .4409 .42898 Mtetra
.101 0 0 r
.4409 .42898 .44725 .42093 .45755 .42069 .45138 .42366 Mtetra
0 0 0 r
.45138 .42366 .45755 .42069 .4679 .42111 .46186 .41964 Mtetra
.538 .893 .977 r
.46186 .41964 .4679 .42111 .47832 .42122 .47237 .41636 Mtetra
.631 .798 .963 r
.47237 .41636 .47832 .42122 .48882 .42045 .48292 .41329 Mtetra
.647 .722 .903 r
.48292 .41329 .48882 .42045 .49938 .41836 .49352 .41006 Mtetra
.655 .693 .874 r
.49352 .41006 .49938 .41836 .51 .41487 .50416 .40655 Mtetra
.663 .696 .87 r
.50416 .40655 .51 .41487 .52066 .40997 .51484 .40274 Mtetra
.671 .731 .894 r
.51484 .40274 .52066 .40997 .53135 .40376 .52556 .39878 Mtetra
.661 .807 .953 r
.52556 .39878 .53135 .40376 .54206 .39663 .53632 .39501 Mtetra
.507 .879 .976 r
.53632 .39501 .54206 .39663 .55278 .38919 .54713 .392 Mtetra
.083 0 0 r
.54713 .392 .55278 .38919 .56353 .38239 .55799 .3903 Mtetra
.437 0 .071 r
.55799 .3903 .56353 .38239 .57434 .37778 .56895 .3908 Mtetra
.537 .146 .249 r
.56895 .3908 .57434 .37778 .58523 .37616 .58001 .39354 Mtetra
.579 .22 .322 r
.58001 .39354 .58523 .37616 .59628 .37883 .59121 .39859 Mtetra
.591 .243 .347 r
.59121 .39859 .59628 .37883 .6075 .38498 .60253 .40472 Mtetra
.578 .229 .342 r
.60253 .40472 .6075 .38498 .6189 .39317 .61395 .40992 Mtetra
.543 .178 .299 r
.61395 .40992 .6189 .39317 .63042 .40148 .6254 .41284 Mtetra
.411 .005 .155 r
.6254 .41284 .63042 .40148 .64197 .40693 .6368 .41146 Mtetra
0 0 0 r
.6368 .41146 .64197 .40693 .6535 .40895 .64811 .40623 Mtetra
.806 .934 .916 r
.64811 .40623 .6535 .40895 .66494 .40696 .65932 .39791 Mtetra
.791 .736 .802 r
.65932 .39791 .66494 .40696 .67628 .4018 .67047 .3878 Mtetra
.743 .64 .746 r
.67047 .3878 .67628 .4018 .68756 .39461 .68162 .37755 Mtetra
.713 .595 .722 r
.68162 .37755 .68756 .39461 .6988 .38624 .69279 .36779 Mtetra
.689 .57 .716 r
.69279 .36779 .6988 .38624 .71004 .37768 .70403 .35929 Mtetra
.672 .561 .722 r
.70403 .35929 .71004 .37768 .72131 .36941 .71536 .35209 Mtetra
.656 .561 .737 r
.71536 .35209 .72131 .36941 .73266 .36205 .72681 .34634 Mtetra
.643 .571 .758 r
.72681 .34634 .73266 .36205 .74409 .35562 .73837 .34175 Mtetra
.632 .588 .786 r
.73837 .34175 .74409 .35562 .75562 .35024 .75004 .33809 Mtetra
.622 .61 .817 r
.75004 .33809 .75562 .35024 .76726 .3457 .76181 .33506 Mtetra
.617 .637 .848 r
.76181 .33506 .76726 .3457 .77899 .34181 .77366 .33235 Mtetra
.612 .663 .875 r
.77366 .33235 .77899 .34181 .79081 .33838 .78558 .3298 Mtetra
.613 .687 .896 r
.78558 .3298 .79081 .33838 .80271 .33518 .79755 .32718 Mtetra
.613 .705 .91 r
.79755 .32718 .80271 .33518 .81467 .33212 .80958 .3245 Mtetra
.615 .719 .92 r
.80958 .3245 .81467 .33212 .82669 .32911 .82166 .32171 Mtetra
.619 .729 .925 r
.82166 .32171 .82669 .32911 .83876 .32602 .83378 .31877 Mtetra
.684 .758 .907 r
.19348 .52013 .20012 .52592 .20979 .52184 .20315 .51626 Mtetra
.69 .767 .91 r
.20315 .51626 .20979 .52184 .21951 .51762 .21287 .51221 Mtetra
.698 .775 .911 r
.21287 .51221 .21951 .51762 .22926 .5133 .22265 .50795 Mtetra
.707 .779 .908 r
.22265 .50795 .22926 .5133 .23905 .50891 .23247 .50341 Mtetra
.718 .776 .898 r
.23247 .50341 .23905 .50891 .24887 .50446 .24236 .4985 Mtetra
.723 .763 .885 r
.24236 .4985 .24887 .50446 .25871 .50017 .25229 .49335 Mtetra
.723 .738 .864 r
.25229 .49335 .25871 .50017 .26856 .49617 .26226 .48795 Mtetra
.71 .7 .838 r
.26226 .48795 .26856 .49617 .27839 .49278 .27226 .48261 Mtetra
.69 .653 .808 r
.27226 .48261 .27839 .49278 .28819 .4903 .28225 .47755 Mtetra
.658 .599 .776 r
.28225 .47755 .28819 .4903 .29795 .48895 .29223 .4732 Mtetra
.623 .545 .746 r
.29223 .4732 .29795 .48895 .30767 .489 .30215 .46995 Mtetra
.587 .496 .719 r
.30215 .46995 .30767 .489 .31737 .49032 .31203 .4681 Mtetra
.552 .453 .696 r
.31203 .4681 .31737 .49032 .32705 .49289 .32184 .46799 Mtetra
.524 .421 .68 r
.32184 .46799 .32705 .49289 .33678 .49596 .33162 .46943 Mtetra
.499 .397 .67 r
.33162 .46943 .33678 .49596 .3466 .49892 .34138 .47237 Mtetra
.477 .383 .67 r
.34138 .47237 .3466 .49892 .35657 .50015 .35116 .47649 Mtetra
.447 .378 .687 r
.35116 .47649 .35657 .50015 .36676 .49838 .36097 .4815 Mtetra
.384 .395 .747 r
.36097 .4815 .36676 .49838 .37716 .49284 .37086 .48676 Mtetra
0 .406 .851 r
.37086 .48676 .37716 .49284 .38776 .48308 .38087 .49158 Mtetra
.528 .091 .153 r
.38087 .49158 .38776 .48308 .39845 .47106 .39105 .49427 Mtetra
.493 .168 .344 r
.39105 .49427 .39845 .47106 .40915 .45809 .40143 .49369 Mtetra
.466 .179 .393 r
.40143 .49369 .40915 .45809 .41981 .44615 .41199 .48943 Mtetra
.44 .169 .405 r
.41199 .48943 .41981 .44615 .43038 .43647 .42271 .48143 Mtetra
.421 .156 .404 r
.42271 .48143 .43038 .43647 .4409 .42898 .43349 .47136 Mtetra
.402 .136 .392 r
.43349 .47136 .4409 .42898 .45138 .42366 .4443 .46034 Mtetra
.385 .112 .371 r
.4443 .46034 .45138 .42366 .46186 .41964 .45509 .44979 Mtetra
.372 .085 .341 r
.45509 .44979 .46186 .41964 .47237 .41636 .46585 .44061 Mtetra
.364 .057 .305 r
.46585 .44061 .47237 .41636 .48292 .41329 .47659 .43314 Mtetra
.374 .044 .271 r
.47659 .43314 .48292 .41329 .49352 .41006 .48732 .42765 Mtetra
.405 .058 .259 r
.48732 .42765 .49352 .41006 .50416 .40655 .49807 .42413 Mtetra
.454 .103 .279 r
.49807 .42413 .50416 .40655 .51484 .40274 .50884 .42258 Mtetra
.504 .162 .32 r
.50884 .42258 .51484 .40274 .52556 .39878 .51967 .42303 Mtetra
.536 .21 .363 r
.51967 .42303 .52556 .39878 .53632 .39501 .53058 .42521 Mtetra
.553 .243 .397 r
.53058 .42521 .53632 .39501 .54713 .392 .54157 .4288 Mtetra
.555 .259 .42 r
.54157 .4288 .54713 .392 .55799 .3903 .55266 .43288 Mtetra
.546 .259 .431 r
.55266 .43288 .55799 .3903 .56895 .3908 .56383 .43604 Mtetra
.529 .248 .433 r
.56383 .43604 .56895 .3908 .58001 .39354 .57506 .43711 Mtetra
.497 .219 .422 r
.57506 .43711 .58001 .39354 .59121 .39859 .5863 .43441 Mtetra
.444 .161 .388 r
.5863 .43441 .59121 .39859 .60253 .40472 .59751 .42796 Mtetra
.315 .013 .284 r
.59751 .42796 .60253 .40472 .61395 .40992 .60866 .41816 Mtetra
0 0 0 r
.60866 .41816 .61395 .40992 .6254 .41284 .61975 .40617 Mtetra
.851 .801 .802 r
.61975 .40617 .6254 .41284 .6368 .41146 .63081 .3937 Mtetra
.737 .601 .706 r
.63081 .3937 .6368 .41146 .64811 .40623 .64186 .38145 Mtetra
.688 .533 .671 r
.64186 .38145 .64811 .40623 .65932 .39791 .65293 .37009 Mtetra
.664 .507 .661 r
.65293 .37009 .65932 .39791 .67047 .3878 .66404 .35991 Mtetra
.65 .497 .663 r
.66404 .35991 .67047 .3878 .68162 .37755 .67523 .35125 Mtetra
.638 .496 .672 r
.67523 .35125 .68162 .37755 .69279 .36779 .68651 .34417 Mtetra
.625 .5 .69 r
.68651 .34417 .69279 .36779 .70403 .35929 .6979 .33887 Mtetra
.614 .513 .715 r
.6979 .33887 .70403 .35929 .71536 .35209 .70942 .33502 Mtetra
.603 .534 .75 r
.70942 .33502 .71536 .35209 .72681 .34634 .72106 .3323 Mtetra
.593 .564 .791 r
.72106 .3323 .72681 .34634 .73837 .34175 .7328 .33032 Mtetra
.586 .605 .838 r
.7328 .33032 .73837 .34175 .75004 .33809 .74463 .32863 Mtetra
.58 .647 .881 r
.74463 .32863 .75004 .33809 .76181 .33506 .75652 .32701 Mtetra
.582 .688 .914 r
.75652 .32701 .76181 .33506 .77366 .33235 .76847 .32514 Mtetra
.586 .719 .935 r
.76847 .32514 .77366 .33235 .78558 .3298 .78046 .32301 Mtetra
.599 .74 .943 r
.78046 .32301 .78558 .3298 .79755 .32718 .79248 .3205 Mtetra
.609 .749 .944 r
.79248 .3205 .79755 .32718 .80958 .3245 .80453 .3177 Mtetra
.619 .751 .94 r
.80453 .3177 .80958 .3245 .82166 .32171 .81663 .31467 Mtetra
.627 .747 .933 r
.81663 .31467 .82166 .32171 .83378 .31877 .82876 .31146 Mtetra
.659 .752 .919 r
.18679 .51429 .19348 .52013 .20315 .51626 .19643 .51104 Mtetra
.663 .776 .933 r
.19643 .51104 .20315 .51626 .21287 .51221 .20611 .50766 Mtetra
.671 .803 .945 r
.20611 .50766 .21287 .51221 .22265 .50795 .21584 .50404 Mtetra
.683 .83 .954 r
.21584 .50404 .22265 .50795 .23247 .50341 .22565 .50007 Mtetra
.701 .855 .956 r
.22565 .50007 .23247 .50341 .24236 .4985 .23552 .49562 Mtetra
.72 .875 .954 r
.23552 .49562 .24236 .4985 .25229 .49335 .24547 .49067 Mtetra
.743 .885 .945 r
.24547 .49067 .25229 .49335 .26226 .48795 .25549 .48512 Mtetra
.759 .88 .933 r
.25549 .48512 .26226 .48795 .27226 .48261 .26557 .47911 Mtetra
.771 .856 .914 r
.26557 .47911 .27226 .48261 .28225 .47755 .2757 .47271 Mtetra
.763 .809 .89 r
.2757 .47271 .28225 .47755 .29223 .4732 .28585 .46629 Mtetra
.739 .743 .855 r
.28585 .46629 .29223 .4732 .30215 .46995 .296 .46013 Mtetra
.699 .665 .813 r
.296 .46013 .30215 .46995 .31203 .4681 .30612 .45471 Mtetra
.653 .589 .771 r
.30612 .45471 .31203 .4681 .32184 .46799 .31619 .45044 Mtetra
.608 .521 .731 r
.31619 .45044 .32184 .46799 .33162 .46943 .3262 .44763 Mtetra
.567 .466 .699 r
.3262 .44763 .33162 .46943 .34138 .47237 .33615 .44663 Mtetra
.529 .421 .675 r
.33615 .44663 .34138 .47237 .35116 .47649 .34604 .44776 Mtetra
.492 .384 .659 r
.34604 .44776 .35116 .47649 .36097 .4815 .35587 .45125 Mtetra
.464 .36 .651 r
.35587 .45125 .36097 .4815 .37086 .48676 .36569 .45657 Mtetra
.441 .344 .649 r
.36569 .45657 .37086 .48676 .38087 .49158 .37555 .46319 Mtetra
.447 .356 .66 r
.37555 .46319 .38087 .49158 .39105 .49427 .38553 .46915 Mtetra
.476 .391 .681 r
.38553 .46915 .39105 .49427 .40143 .49369 .3957 .47308 Mtetra
.525 .451 .715 r
.3957 .47308 .40143 .49369 .41199 .48943 .40605 .47418 Mtetra
.599 .545 .765 r
.40605 .47418 .41199 .48943 .42271 .48143 .41658 .47199 Mtetra
.674 .675 .842 r
.41658 .47199 .42271 .48143 .43349 .47136 .42723 .46758 Mtetra
.743 .867 .937 r
.42723 .46758 .43349 .47136 .4443 .46034 .43795 .46168 Mtetra
.595 .95 .851 r
.43795 .46168 .4443 .46034 .45509 .44979 .4487 .45536 Mtetra
0 0 0 r
.4487 .45536 .45509 .44979 .46585 .44061 .45947 .44933 Mtetra
.128 0 0 r
.45947 .44933 .46585 .44061 .47659 .43314 .47026 .44394 Mtetra
.26 0 .059 r
.47026 .44394 .47659 .43314 .48732 .42765 .48107 .43947 Mtetra
.328 0 .12 r
.48107 .43947 .48732 .42765 .49807 .42413 .4919 .43593 Mtetra
.366 0 .139 r
.4919 .43593 .49807 .42413 .50884 .42258 .50277 .43335 Mtetra
.386 0 .123 r
.50277 .43335 .50884 .42258 .51967 .42303 .51369 .43169 Mtetra
.378 0 .055 r
.51369 .43169 .51967 .42303 .53058 .42521 .52466 .43068 Mtetra
.308 0 0 r
.52466 .43068 .53058 .42521 .54157 .4288 .53569 .42997 Mtetra
0 0 0 r
.53569 .42997 .54157 .4288 .55266 .43288 .54679 .42885 Mtetra
.573 .824 .992 r
.54679 .42885 .55266 .43288 .56383 .43604 .55793 .42622 Mtetra
.681 .678 .841 r
.55793 .42622 .56383 .43604 .57506 .43711 .56909 .42135 Mtetra
.702 .6 .739 r
.56909 .42135 .57506 .43711 .5863 .43441 .58024 .41314 Mtetra
.703 .56 .689 r
.58024 .41314 .5863 .43441 .59751 .42796 .59133 .40202 Mtetra
.699 .536 .663 r
.59133 .40202 .59751 .42796 .60866 .41816 .60237 .38881 Mtetra
.69 .518 .649 r
.60237 .38881 .60866 .41816 .61975 .40617 .61337 .37489 Mtetra
.673 .502 .645 r
.61337 .37489 .61975 .40617 .63081 .3937 .62439 .36227 Mtetra
.658 .491 .647 r
.62439 .36227 .63081 .3937 .64186 .38145 .63545 .35149 Mtetra
.64 .484 .655 r
.63545 .35149 .64186 .38145 .65293 .37009 .64659 .34311 Mtetra
.626 .485 .67 r
.64659 .34311 .65293 .37009 .66404 .35991 .65784 .3369 Mtetra
.614 .496 .695 r
.65784 .3369 .66404 .35991 .67523 .35125 .66921 .33253 Mtetra
.602 .518 .732 r
.66921 .33253 .67523 .35125 .68651 .34417 .68069 .32967 Mtetra
.585 .553 .785 r
.68069 .32967 .68651 .34417 .6979 .33887 .69229 .32799 Mtetra
.56 .602 .852 r
.69229 .32799 .6979 .33887 .70942 .33502 .704 .32708 Mtetra
.528 .664 .923 r
.704 .32708 .70942 .33502 .72106 .3323 .71579 .32645 Mtetra
.488 .72 .974 r
.71579 .32645 .72106 .3323 .7328 .33032 .72765 .32581 Mtetra
.467 .766 .995 r
.72765 .32581 .7328 .33032 .74463 .32863 .73957 .32476 Mtetra
.47 .795 .999 r
.73957 .32476 .74463 .32863 .75652 .32701 .75152 .32326 Mtetra
.508 .819 1 r
.75152 .32326 .75652 .32701 .76847 .32514 .76349 .32113 Mtetra
.552 .83 .997 r
.76349 .32113 .76847 .32514 .78046 .32301 .77548 .31847 Mtetra
.595 .828 .988 r
.77548 .31847 .78046 .32301 .79248 .3205 .78749 .31532 Mtetra
.624 .815 .974 r
.78749 .31532 .79248 .3205 .80453 .3177 .79953 .31179 Mtetra
.642 .795 .956 r
.79953 .31179 .80453 .3177 .81663 .31467 .8116 .30802 Mtetra
.651 .773 .937 r
.8116 .30802 .81663 .31467 .82876 .31146 .82371 .3041 Mtetra
.621 .742 .933 r
.18006 .50842 .18679 .51429 .19643 .51104 .18963 .50598 Mtetra
.616 .772 .955 r
.18963 .50598 .19643 .51104 .20611 .50766 .19924 .50351 Mtetra
.613 .807 .974 r
.19924 .50351 .20611 .50766 .21584 .50404 .20891 .50088 Mtetra
.61 .846 .988 r
.20891 .50088 .21584 .50404 .22565 .50007 .21865 .49797 Mtetra
.605 .884 .991 r
.21865 .49797 .22565 .50007 .23552 .49562 .22845 .49468 Mtetra
.598 .918 .974 r
.22845 .49468 .23552 .49562 .24547 .49067 .23834 .49084 Mtetra
.594 .939 .938 r
.23834 .49084 .24547 .49067 .25549 .48512 .24832 .48631 Mtetra
.591 .948 .889 r
.24832 .48631 .25549 .48512 .26557 .47911 .25839 .48101 Mtetra
.616 .958 .855 r
.25839 .48101 .26557 .47911 .2757 .47271 .26855 .47482 Mtetra
.662 .973 .849 r
.26855 .47482 .2757 .47271 .28585 .46629 .27879 .46786 Mtetra
.74 .991 .876 r
.27879 .46786 .28585 .46629 .296 .46013 .2891 .46016 Mtetra
.804 .972 .906 r
.2891 .46016 .296 .46013 .30612 .45471 .29945 .4521 Mtetra
.818 .889 .895 r
.29945 .4521 .30612 .45471 .31619 .45044 .30981 .44397 Mtetra
.774 .764 .845 r
.30981 .44397 .31619 .45044 .3262 .44763 .32014 .43636 Mtetra
.71 .647 .784 r
.32014 .43636 .3262 .44763 .33615 .44663 .33043 .42976 Mtetra
.655 .555 .73 r
.33043 .42976 .33615 .44663 .34604 .44776 .34067 .42439 Mtetra
.61 .486 .686 r
.34067 .42439 .34604 .44776 .35587 .45125 .35085 .42046 Mtetra
.584 .44 .651 r
.35085 .42046 .35587 .45125 .36569 .45657 .36102 .41745 Mtetra
.568 .409 .626 r
.36102 .41745 .36569 .45657 .37555 .46319 .3712 .41517 Mtetra
.554 .385 .607 r
.3712 .41517 .37555 .46319 .38553 .46915 .38138 .41395 Mtetra
.542 .369 .596 r
.38138 .41395 .38553 .46915 .3957 .47308 .39156 .41401 Mtetra
.529 .356 .59 r
.39156 .41401 .3957 .47308 .40605 .47418 .40173 .41584 Mtetra
.515 .346 .59 r
.40173 .41584 .40605 .47418 .41658 .47199 .41192 .41953 Mtetra
.504 .344 .598 r
.41192 .41953 .41658 .47199 .42723 .46758 .42215 .4242 Mtetra
.494 .35 .614 r
.42215 .4242 .42723 .46758 .43795 .46168 .43248 .42915 Mtetra
.489 .372 .646 r
.43248 .42915 .43795 .46168 .4487 .45536 .44292 .43329 Mtetra
.494 .423 .705 r
.44292 .43329 .4487 .45536 .45947 .44933 .45348 .43591 Mtetra
.515 .525 .805 r
.45348 .43591 .45947 .44933 .47026 .44394 .46416 .43665 Mtetra
.564 .694 .928 r
.46416 .43665 .47026 .44394 .48107 .43947 .47495 .43525 Mtetra
.638 .834 .976 r
.47495 .43525 .48107 .43947 .4919 .43593 .48581 .43169 Mtetra
.732 .856 .939 r
.48581 .43169 .4919 .43593 .50277 .43335 .49674 .42598 Mtetra
.769 .761 .846 r
.49674 .42598 .50277 .43335 .51369 .43169 .50772 .41811 Mtetra
.739 .639 .749 r
.50772 .41811 .51369 .43169 .52466 .43068 .5187 .40833 Mtetra
.699 .551 .682 r
.5187 .40833 .52466 .43068 .53569 .42997 .52969 .39699 Mtetra
.665 .491 .64 r
.52969 .39699 .53569 .42997 .54679 .42885 .54067 .38481 Mtetra
.636 .451 .616 r
.54067 .38481 .54679 .42885 .55793 .42622 .55163 .37289 Mtetra
.615 .425 .602 r
.55163 .37289 .55793 .42622 .56909 .42135 .5626 .36193 Mtetra
.597 .407 .594 r
.5626 .36193 .56909 .42135 .58024 .41314 .57358 .35283 Mtetra
.587 .398 .593 r
.57358 .35283 .58024 .41314 .59133 .40202 .5846 .34551 Mtetra
.582 .398 .598 r
.5846 .34551 .59133 .40202 .60237 .38881 .59568 .33948 Mtetra
.58 .405 .608 r
.59568 .33948 .60237 .38881 .61337 .37489 .60681 .33453 Mtetra
.583 .42 .626 r
.60681 .33453 .61337 .37489 .62439 .36227 .61799 .33031 Mtetra
.584 .44 .652 r
.61799 .33031 .62439 .36227 .63545 .35149 .62926 .32703 Mtetra
.575 .463 .689 r
.62926 .32703 .63545 .35149 .64659 .34311 .64062 .32523 Mtetra
.557 .498 .745 r
.64062 .32523 .64659 .34311 .65784 .3369 .6521 .32468 Mtetra
.517 .551 .83 r
.6521 .32468 .65784 .3369 .66921 .33253 .66369 .32519 Mtetra
.425 .63 .94 r
.66369 .32519 .66921 .33253 .68069 .32967 .67539 .32625 Mtetra
.227 .67 .954 r
.67539 .32625 .68069 .32967 .69229 .32799 .68717 .32725 Mtetra
.008 .58 .762 r
.68717 .32725 .69229 .32799 .704 .32708 .69902 .32789 Mtetra
.067 0 0 r
.69902 .32789 .704 .32708 .71579 .32645 .7109 .32778 Mtetra
.041 0 0 r
.7109 .32778 .71579 .32645 .72765 .32581 .72281 .32689 Mtetra
0 0 0 r
.72281 .32689 .72765 .32581 .73957 .32476 .73474 .32507 Mtetra
.229 .749 .781 r
.73474 .32507 .73957 .32476 .75152 .32326 .74667 .32246 Mtetra
.406 .854 .906 r
.74667 .32246 .75152 .32326 .76349 .32113 .75861 .31912 Mtetra
.541 .898 .973 r
.75861 .31912 .76349 .32113 .77548 .31847 .77056 .31522 Mtetra
.622 .891 .988 r
.77056 .31522 .77548 .31847 .78749 .31532 .78253 .3109 Mtetra
.662 .862 .975 r
.78253 .3109 .78749 .31532 .79953 .31179 .79452 .30629 Mtetra
.68 .827 .954 r
.79452 .30629 .79953 .31179 .8116 .30802 .80654 .30151 Mtetra
.684 .793 .932 r
.80654 .30151 .8116 .30802 .82371 .3041 .81861 .29669 Mtetra
.59 .733 .943 r
.17328 .5025 .18006 .50842 .18963 .50598 .18281 .50064 Mtetra
.579 .751 .959 r
.18281 .50064 .18963 .50598 .19924 .50351 .19238 .49883 Mtetra
.568 .775 .976 r
.19238 .49883 .19924 .50351 .20891 .50088 .20199 .49701 Mtetra
.554 .803 .991 r
.20199 .49701 .20891 .50088 .21865 .49797 .21165 .49509 Mtetra
.531 .834 .999 r
.21165 .49509 .21865 .49797 .22845 .49468 .22137 .49302 Mtetra
.498 .863 .986 r
.22137 .49302 .22845 .49468 .23834 .49084 .23117 .49062 Mtetra
.443 .87 .928 r
.23117 .49062 .23834 .49084 .24832 .48631 .24104 .48774 Mtetra
.368 .836 .81 r
.24104 .48774 .24832 .48631 .25839 .48101 .25102 .48419 Mtetra
.291 .767 .655 r
.25102 .48419 .25839 .48101 .26855 .47482 .26109 .47976 Mtetra
0 0 0 r
.26109 .47976 .26855 .47482 .27879 .46786 .27128 .47437 Mtetra
.27128 .47437 .27879 .46786 .2891 .46016 .28156 .46788 Mtetra
.28156 .46788 .2891 .46016 .29945 .4521 .29194 .46045 Mtetra
.29194 .46045 .29945 .4521 .30981 .44397 .30238 .45214 Mtetra
.30238 .45214 .30981 .44397 .32014 .43636 .31287 .44339 Mtetra
.31287 .44339 .32014 .43636 .33043 .42976 .32336 .43453 Mtetra
.572 .903 .659 r
.32336 .43453 .33043 .42976 .34067 .42439 .33386 .4257 Mtetra
.782 .995 .87 r
.33386 .4257 .34067 .42439 .35085 .42046 .34436 .41709 Mtetra
.815 .87 .887 r
.34436 .41709 .35085 .42046 .36102 .41745 .35484 .40882 Mtetra
.753 .713 .814 r
.35484 .40882 .36102 .41745 .3712 .41517 .3653 .40115 Mtetra
.681 .599 .757 r
.3653 .40115 .3712 .41517 .38138 .41395 .37569 .39509 Mtetra
.62 .52 .719 r
.37569 .39509 .38138 .41395 .39156 .41401 .38602 .39128 Mtetra
.57 .464 .694 r
.38602 .39128 .39156 .41401 .40173 .41584 .39628 .3899 Mtetra
.529 .421 .676 r
.39628 .3899 .40173 .41584 .41192 .41953 .40651 .39089 Mtetra
.512 .399 .662 r
.40651 .39089 .41192 .41953 .42215 .4242 .41677 .39305 Mtetra
.51 .389 .651 r
.41677 .39305 .42215 .4242 .43248 .42915 .4271 .39555 Mtetra
.52 .389 .642 r
.4271 .39555 .43248 .42915 .44292 .43329 .43752 .39745 Mtetra
.536 .395 .636 r
.43752 .39745 .44292 .43329 .45348 .43591 .44805 .39816 Mtetra
.551 .401 .631 r
.44805 .39816 .45348 .43591 .46416 .43665 .45867 .39751 Mtetra
.565 .409 .628 r
.45867 .39751 .46416 .43665 .47495 .43525 .46939 .39536 Mtetra
.578 .417 .626 r
.46939 .39536 .47495 .43525 .48581 .43169 .48017 .39175 Mtetra
.591 .426 .626 r
.48017 .39175 .48581 .43169 .49674 .42598 .49101 .38668 Mtetra
.605 .436 .627 r
.49101 .38668 .49674 .42598 .50772 .41811 .5019 .38009 Mtetra
.618 .448 .63 r
.5019 .38009 .50772 .41811 .5187 .40833 .51282 .37213 Mtetra
.632 .461 .633 r
.51282 .37213 .5187 .40833 .52969 .39699 .52375 .36294 Mtetra
.642 .473 .639 r
.52375 .36294 .52969 .39699 .54067 .38481 .53468 .35314 Mtetra
.646 .481 .646 r
.53468 .35314 .54067 .38481 .55163 .37289 .54562 .34367 Mtetra
.642 .486 .656 r
.54562 .34367 .55163 .37289 .5626 .36193 .55657 .33535 Mtetra
.624 .484 .67 r
.55657 .33535 .5626 .36193 .57358 .35283 .56757 .32943 Mtetra
.6 .483 .692 r
.56757 .32943 .57358 .35283 .5846 .34551 .57864 .32596 Mtetra
.569 .489 .726 r
.57864 .32596 .5846 .34551 .59568 .33948 .5898 .32478 Mtetra
.527 .516 .786 r
.5898 .32478 .59568 .33948 .60681 .33453 .60107 .32525 Mtetra
.462 .588 .893 r
.60107 .32525 .60681 .33453 .61799 .33031 .61243 .32635 Mtetra
.22 .645 .955 r
.61243 .32635 .61799 .33031 .62926 .32703 .62388 .3278 Mtetra
.236 0 0 r
.62388 .3278 .62926 .32703 .64062 .32523 .63542 .32951 Mtetra
.405 0 0 r
.63542 .32951 .64062 .32523 .6521 .32468 .64706 .33126 Mtetra
.447 0 0 r
.64706 .33126 .6521 .32468 .66369 .32519 .65878 .33291 Mtetra
.446 0 .044 r
.65878 .33291 .66369 .32519 .67539 .32625 .67056 .33412 Mtetra
.413 0 .033 r
.67056 .33412 .67539 .32625 .68717 .32725 .68239 .33445 Mtetra
.358 0 0 r
.68239 .33445 .68717 .32725 .69902 .32789 .69425 .33381 Mtetra
.261 0 0 r
.69425 .33381 .69902 .32789 .7109 .32778 .70612 .33205 Mtetra
.11 0 0 r
.70612 .33205 .7109 .32778 .72281 .32689 .71799 .32928 Mtetra
0 0 0 r
.71799 .32928 .72281 .32689 .73474 .32507 .72986 .32562 Mtetra
.372 .838 .805 r
.72986 .32562 .73474 .32507 .74667 .32246 .74174 .32124 Mtetra
.561 .925 .941 r
.74174 .32124 .74667 .32246 .75861 .31912 .75362 .31637 Mtetra
.656 .921 .976 r
.75362 .31637 .75861 .31912 .77056 .31522 .76553 .31113 Mtetra
.693 .885 .969 r
.76553 .31113 .77056 .31522 .78253 .3109 .77746 .30574 Mtetra
.706 .849 .951 r
.77746 .30574 .78253 .3109 .79452 .30629 .78942 .30023 Mtetra
.708 .818 .933 r
.78942 .30023 .79452 .30629 .80654 .30151 .80143 .29469 Mtetra
.705 .791 .918 r
.80143 .29469 .80654 .30151 .81861 .29669 .81347 .28921 Mtetra
.58 .73 .945 r
.16646 .49655 .17328 .5025 .18281 .50064 .17598 .49484 Mtetra
.569 .733 .952 r
.17598 .49484 .18281 .50064 .19238 .49883 .18554 .49327 Mtetra
.557 .738 .96 r
.18554 .49327 .19238 .49883 .20199 .49701 .19513 .49182 Mtetra
.54 .747 .972 r
.19513 .49182 .20199 .49701 .21165 .49509 .20476 .4905 Mtetra
.513 .762 .986 r
.20476 .4905 .21165 .49509 .22137 .49302 .21442 .48932 Mtetra
.478 .784 .998 r
.21442 .48932 .22137 .49302 .23117 .49062 .22412 .48816 Mtetra
.414 .803 .989 r
.22412 .48816 .23117 .49062 .24104 .48774 .23388 .48694 Mtetra
.309 .789 .912 r
.23388 .48694 .24104 .48774 .25102 .48419 .24372 .48545 Mtetra
.152 .691 .715 r
.24372 .48545 .25102 .48419 .26109 .47976 .25363 .48352 Mtetra
.009 0 0 r
.25363 .48352 .26109 .47976 .27128 .47437 .26365 .48095 Mtetra
.12 0 0 r
.26365 .48095 .27128 .47437 .28156 .46788 .27377 .47753 Mtetra
.19 0 0 r
.27377 .47753 .28156 .46788 .29194 .46045 .284 .47315 Mtetra
.225 0 .069 r
.284 .47315 .29194 .46045 .30238 .45214 .29433 .46769 Mtetra
.243 0 .134 r
.29433 .46769 .30238 .45214 .31287 .44339 .30477 .46112 Mtetra
.241 0 .166 r
.30477 .46112 .31287 .44339 .32336 .43453 .3153 .45339 Mtetra
.226 0 .175 r
.3153 .45339 .32336 .43453 .33386 .4257 .32591 .44467 Mtetra
.2 0 .164 r
.32591 .44467 .33386 .4257 .34436 .41709 .33656 .43515 Mtetra
.188 0 .148 r
.33656 .43515 .34436 .41709 .35484 .40882 .34721 .42579 Mtetra
.197 0 .138 r
.34721 .42579 .35484 .40882 .3653 .40115 .35783 .41719 Mtetra
.221 0 .138 r
.35783 .41719 .3653 .40115 .37569 .39509 .3684 .40962 Mtetra
.238 0 .121 r
.3684 .40962 .37569 .39509 .38602 .39128 .37893 .40318 Mtetra
.168 0 .028 r
.37893 .40318 .38602 .39128 .39628 .3899 .38948 .3968 Mtetra
0 0 0 r
.38948 .3968 .39628 .3899 .40651 .39089 .40007 .38994 Mtetra
.783 .962 .923 r
.40007 .38994 .40651 .39089 .41677 .39305 .41071 .38238 Mtetra
.743 .677 .786 r
.41071 .38238 .41677 .39305 .4271 .39555 .42138 .37413 Mtetra
.67 .535 .692 r
.42138 .37413 .4271 .39555 .43752 .39745 .43207 .36594 Mtetra
.63 .47 .647 r
.43207 .36594 .43752 .39745 .44805 .39816 .44275 .35831 Mtetra
.603 .433 .624 r
.44275 .35831 .44805 .39816 .45867 .39751 .45342 .35175 Mtetra
.585 .41 .612 r
.45342 .35175 .45867 .39751 .46939 .39536 .46408 .34658 Mtetra
.57 .396 .606 r
.46408 .34658 .46939 .39536 .48017 .39175 .47475 .34291 Mtetra
.559 .388 .606 r
.47475 .34291 .48017 .39175 .49101 .38668 .48545 .34074 Mtetra
.548 .384 .611 r
.48545 .34074 .49101 .38668 .5019 .38009 .49618 .33997 Mtetra
.539 .388 .624 r
.49618 .33997 .5019 .38009 .51282 .37213 .50697 .34029 Mtetra
.532 .403 .651 r
.50697 .34029 .51282 .37213 .52375 .36294 .51783 .34118 Mtetra
.526 .446 .708 r
.51783 .34118 .52375 .36294 .53468 .35314 .52877 .34215 Mtetra
.515 .573 .852 r
.52877 .34215 .53468 .35314 .54562 .34367 .53978 .34243 Mtetra
.176 .7 .871 r
.53978 .34243 .54562 .34367 .55657 .33535 .55085 .34202 Mtetra
.33 0 0 r
.55085 .34202 .55657 .33535 .56757 .32943 .56199 .34114 Mtetra
.422 .012 .155 r
.56199 .34114 .56757 .32943 .57864 .32596 .57319 .34032 Mtetra
.474 .089 .228 r
.57319 .34032 .57864 .32596 .5898 .32478 .58449 .34066 Mtetra
.504 .128 .261 r
.58449 .34066 .5898 .32478 .60107 .32525 .59588 .34206 Mtetra
.521 .151 .278 r
.59588 .34206 .60107 .32525 .61243 .32635 .60738 .34427 Mtetra
.525 .161 .292 r
.60738 .34427 .61243 .32635 .62388 .3278 .61897 .34664 Mtetra
.512 .154 .296 r
.61897 .34664 .62388 .3278 .63542 .32951 .63063 .34822 Mtetra
.493 .136 .288 r
.63063 .34822 .63542 .32951 .64706 .33126 .64234 .34881 Mtetra
.466 .103 .265 r
.64234 .34881 .64706 .33126 .65878 .33291 .65408 .34821 Mtetra
.427 .051 .22 r
.65408 .34821 .65878 .33291 .67056 .33412 .66584 .34648 Mtetra
.363 0 .14 r
.66584 .34648 .67056 .33412 .68239 .33445 .67762 .34363 Mtetra
.259 0 .006 r
.67762 .34363 .68239 .33445 .69425 .33381 .6894 .33979 Mtetra
.073 0 0 r
.6894 .33979 .69425 .33381 .70612 .33205 .70119 .33508 Mtetra
0 0 0 r
.70119 .33508 .70612 .33205 .71799 .32928 .71298 .32969 Mtetra
.515 .915 .843 r
.71298 .32969 .71799 .32928 .72986 .32562 .72477 .32383 Mtetra
.673 .953 .952 r
.72477 .32383 .72986 .32562 .74174 .32124 .73659 .31768 Mtetra
.721 .912 .96 r
.73659 .31768 .74174 .32124 .75362 .31637 .74843 .31146 Mtetra
.731 .865 .944 r
.74843 .31146 .75362 .31637 .76553 .31113 .76031 .30525 Mtetra
.726 .829 .929 r
.76031 .30525 .76553 .31113 .77746 .30574 .77224 .29917 Mtetra
.72 .805 .917 r
.77224 .29917 .77746 .30574 .78942 .30023 .78421 .29322 Mtetra
.715 .789 .91 r
.78421 .29322 .78942 .30023 .80143 .29469 .79623 .28738 Mtetra
.709 .779 .906 r
.79623 .28738 .80143 .29469 .81347 .28921 .8083 .28168 Mtetra
.606 .738 .938 r
.15958 .49055 .16646 .49655 .17598 .49484 .16918 .48835 Mtetra
.601 .72 .928 r
.16918 .48835 .17598 .49484 .18554 .49327 .1788 .4863 Mtetra
.593 .702 .919 r
.1788 .4863 .18554 .49327 .19513 .49182 .18845 .48445 Mtetra
.582 .686 .913 r
.18845 .48445 .19513 .49182 .20476 .4905 .19811 .48286 Mtetra
.566 .672 .91 r
.19811 .48286 .20476 .4905 .21442 .48932 .20778 .48161 Mtetra
.551 .665 .912 r
.20778 .48161 .21442 .48932 .22412 .48816 .21748 .48065 Mtetra
.531 .664 .922 r
.21748 .48065 .22412 .48816 .23388 .48694 .2272 .48 Mtetra
.513 .676 .939 r
.2272 .48 .23388 .48694 .24372 .48545 .23696 .47951 Mtetra
.486 .702 .965 r
.23696 .47951 .24372 .48545 .25363 .48352 .24677 .47909 Mtetra
.447 .746 .992 r
.24677 .47909 .25363 .48352 .26365 .48095 .25665 .47852 Mtetra
.363 .781 .977 r
.25665 .47852 .26365 .48095 .27377 .47753 .2666 .47763 Mtetra
.201 .729 .815 r
.2666 .47763 .27377 .47753 .284 .47315 .27665 .47618 Mtetra
0 0 0 r
.27665 .47618 .284 .47315 .29433 .46769 .28681 .47395 Mtetra
.121 0 0 r
.28681 .47395 .29433 .46769 .30477 .46112 .29708 .47073 Mtetra
.187 0 0 r
.29708 .47073 .30477 .46112 .3153 .45339 .30748 .46631 Mtetra
.233 0 .075 r
.30748 .46631 .3153 .45339 .32591 .44467 .31797 .46087 Mtetra
.266 0 .154 r
.31797 .46087 .32591 .44467 .33656 .43515 .32854 .45453 Mtetra
.31 0 .218 r
.32854 .45453 .33656 .43515 .34721 .42579 .33915 .44797 Mtetra
.347 .021 .263 r
.33915 .44797 .34721 .42579 .35783 .41719 .34977 .44155 Mtetra
.361 .044 .287 r
.34977 .44155 .35783 .41719 .3684 .40962 .36042 .43488 Mtetra
.358 .046 .292 r
.36042 .43488 .3684 .40962 .37893 .40318 .37112 .42775 Mtetra
.326 .015 .275 r
.37112 .42775 .37893 .40318 .38948 .3968 .38188 .41951 Mtetra
.27 0 .237 r
.38188 .41951 .38948 .3968 .40007 .38994 .39271 .40995 Mtetra
.207 0 .183 r
.39271 .40995 .40007 .38994 .41071 .38238 .40356 .39977 Mtetra
.145 0 .122 r
.40356 .39977 .41071 .38238 .42138 .37413 .41442 .38946 Mtetra
.122 0 .08 r
.41442 .38946 .42138 .37413 .43207 .36594 .42525 .37991 Mtetra
.143 0 .065 r
.42525 .37991 .43207 .36594 .44275 .35831 .43605 .37162 Mtetra
.197 0 .078 r
.43605 .37162 .44275 .35831 .45342 .35175 .44683 .36477 Mtetra
.265 0 .106 r
.44683 .36477 .45342 .35175 .46408 .34658 .45759 .35953 Mtetra
.33 0 .137 r
.45759 .35953 .46408 .34658 .47475 .34291 .46835 .35585 Mtetra
.388 0 .164 r
.46835 .35585 .47475 .34291 .48545 .34074 .47914 .35373 Mtetra
.441 .045 .19 r
.47914 .35373 .48545 .34074 .49618 .33997 .48996 .35322 Mtetra
.485 .089 .215 r
.48996 .35322 .49618 .33997 .50697 .34029 .50083 .35419 Mtetra
.518 .128 .24 r
.50083 .35419 .50697 .34029 .51783 .34118 .51178 .35644 Mtetra
.537 .156 .267 r
.51178 .35644 .51783 .34118 .52877 .34215 .52281 .35946 Mtetra
.536 .169 .291 r
.52281 .35946 .52877 .34215 .53978 .34243 .53393 .36239 Mtetra
.526 .174 .313 r
.53393 .36239 .53978 .34243 .55085 .34202 .54514 .3647 Mtetra
.508 .169 .329 r
.54514 .3647 .55085 .34202 .56199 .34114 .55643 .36571 Mtetra
.493 .164 .337 r
.55643 .36571 .56199 .34114 .57319 .34032 .56778 .36559 Mtetra
.487 .161 .339 r
.56778 .36559 .57319 .34032 .58449 .34066 .57919 .36501 Mtetra
.481 .152 .331 r
.57919 .36501 .58449 .34066 .59588 .34206 .59067 .3642 Mtetra
.478 .139 .313 r
.59067 .3642 .59588 .34206 .60738 .34427 .60223 .36354 Mtetra
.465 .112 .282 r
.60223 .36354 .60738 .34427 .61897 .34664 .61385 .36266 Mtetra
.427 .055 .228 r
.61385 .36266 .61897 .34664 .63063 .34822 .62551 .36087 Mtetra
.363 0 .142 r
.62551 .36087 .63063 .34822 .64234 .34881 .63719 .35803 Mtetra
.241 0 0 r
.63719 .35803 .64234 .34881 .65408 .34821 .64889 .35396 Mtetra
.017 0 0 r
.64889 .35396 .65408 .34821 .66584 .34648 .66059 .34886 Mtetra
.346 .798 .662 r
.66059 .34886 .66584 .34648 .67762 .34363 .67229 .34295 Mtetra
.648 .963 .917 r
.67229 .34295 .67762 .34363 .6894 .33979 .684 .33645 Mtetra
.747 .921 .949 r
.684 .33645 .6894 .33979 .70119 .33508 .69572 .32961 Mtetra
.758 .847 .918 r
.69572 .32961 .70119 .33508 .71298 .32969 .70746 .3226 Mtetra
.747 .792 .889 r
.70746 .3226 .71298 .32969 .72477 .32383 .71923 .31565 Mtetra
.735 .758 .871 r
.71923 .31565 .72477 .32383 .73659 .31768 .73104 .30885 Mtetra
.722 .737 .863 r
.73104 .30885 .73659 .31768 .74843 .31146 .7429 .30235 Mtetra
.713 .727 .861 r
.7429 .30235 .74843 .31146 .76031 .30525 .75482 .29616 Mtetra
.704 .725 .866 r
.75482 .29616 .76031 .30525 .77224 .29917 .7668 .2903 Mtetra
.698 .729 .874 r
.7668 .2903 .77224 .29917 .78421 .29322 .77883 .28472 Mtetra
.694 .738 .885 r
.77883 .28472 .78421 .29322 .79623 .28738 .79093 .27933 Mtetra
.691 .751 .897 r
.79093 .27933 .79623 .28738 .8083 .28168 .80308 .27409 Mtetra
.65 .75 .923 r
.15266 .48451 .15958 .49055 .16918 .48835 .16238 .48136 Mtetra
.645 .719 .902 r
.16238 .48136 .16918 .48835 .1788 .4863 .17212 .47831 Mtetra
.636 .688 .882 r
.17212 .47831 .1788 .4863 .18845 .48445 .18188 .47547 Mtetra
.623 .658 .863 r
.18188 .47547 .18845 .48445 .19811 .48286 .19165 .47292 Mtetra
.607 .63 .848 r
.19165 .47292 .19811 .48286 .20778 .48161 .20141 .47078 Mtetra
.591 .604 .834 r
.20141 .47078 .20778 .48161 .21748 .48065 .21118 .46908 Mtetra
.572 .582 .824 r
.21118 .46908 .21748 .48065 .2272 .48 .22095 .46792 Mtetra
.556 .565 .818 r
.22095 .46792 .2272 .48 .23696 .47951 .23072 .46723 Mtetra
.538 .553 .818 r
.23072 .46723 .23696 .47951 .24677 .47909 .24051 .46704 Mtetra
.524 .55 .825 r
.24051 .46704 .24677 .47909 .25665 .47852 .25032 .46719 Mtetra
.51 .558 .841 r
.25032 .46719 .25665 .47852 .2666 .47763 .26017 .46759 Mtetra
.498 .582 .87 r
.26017 .46759 .2666 .47763 .27665 .47618 .27009 .46801 Mtetra
.483 .628 .916 r
.27009 .46801 .27665 .47618 .28681 .47395 .28007 .46825 Mtetra
.448 .699 .974 r
.28007 .46825 .28681 .47395 .29708 .47073 .29015 .46816 Mtetra
.328 .76 .971 r
.29015 .46816 .29708 .47073 .30748 .46631 .30031 .46758 Mtetra
0 0 0 r
.30031 .46758 .30748 .46631 .31797 .46087 .31056 .46664 Mtetra
.26 0 0 r
.31056 .46664 .31797 .46087 .32854 .45453 .32089 .46536 Mtetra
.358 0 .092 r
.32089 .46536 .32854 .45453 .33915 .44797 .3313 .46347 Mtetra
.387 .012 .2 r
.3313 .46347 .33915 .44797 .34977 .44155 .34182 .46073 Mtetra
.377 .029 .243 r
.34182 .46073 .34977 .44155 .36042 .43488 .35245 .45649 Mtetra
.352 .02 .256 r
.35245 .45649 .36042 .43488 .37112 .42775 .36322 .45051 Mtetra
.338 .014 .261 r
.36322 .45051 .37112 .42775 .38188 .41951 .37405 .44358 Mtetra
.342 .024 .273 r
.37405 .44358 .38188 .41951 .39271 .40995 .38492 .43626 Mtetra
.377 .065 .304 r
.38492 .43626 .39271 .40995 .40356 .39977 .39577 .42968 Mtetra
.42 .116 .34 r
.39577 .42968 .40356 .39977 .41442 .38946 .40661 .42436 Mtetra
.452 .157 .372 r
.40661 .42436 .41442 .38946 .42525 .37991 .41744 .42012 Mtetra
.474 .186 .395 r
.41744 .42012 .42525 .37991 .43605 .37162 .42828 .41679 Mtetra
.482 .201 .41 r
.42828 .41679 .43605 .37162 .44683 .36477 .43916 .41368 Mtetra
.485 .208 .418 r
.43916 .41368 .44683 .36477 .45759 .35953 .45009 .41043 Mtetra
.483 .209 .421 r
.45009 .41043 .45759 .35953 .46835 .35585 .46108 .40677 Mtetra
.48 .206 .42 r
.46108 .40677 .46835 .35585 .47914 .35373 .47211 .4027 Mtetra
.477 .201 .415 r
.47211 .4027 .47914 .35373 .48996 .35322 .4832 .39849 Mtetra
.475 .194 .407 r
.4832 .39849 .48996 .35322 .50083 .35419 .49432 .3945 Mtetra
.477 .189 .396 r
.49432 .3945 .50083 .35419 .51178 .35644 .50547 .39141 Mtetra
.482 .183 .381 r
.50547 .39141 .51178 .35644 .52281 .35946 .51668 .38942 Mtetra
.491 .178 .363 r
.51668 .38942 .52281 .35946 .53393 .36239 .52794 .38873 Mtetra
.496 .171 .345 r
.52794 .38873 .53393 .36239 .54514 .3647 .53928 .38877 Mtetra
.486 .153 .327 r
.53928 .38877 .54514 .3647 .55643 .36571 .55069 .38845 Mtetra
.467 .13 .311 r
.55069 .38845 .55643 .36571 .56778 .36559 .56216 .38716 Mtetra
.429 .09 .288 r
.56216 .38716 .56778 .36559 .57919 .36501 .57366 .38411 Mtetra
.379 .032 .246 r
.57366 .38411 .57919 .36501 .59067 .3642 .58519 .37953 Mtetra
.311 0 .168 r
.58519 .37953 .59067 .3642 .60223 .36354 .59675 .37408 Mtetra
.175 0 0 r
.59675 .37408 .60223 .36354 .61385 .36266 .60832 .36799 Mtetra
0 0 0 r
.60832 .36799 .61385 .36266 .62551 .36087 .61992 .36154 Mtetra
.593 .949 .85 r
.61992 .36154 .62551 .36087 .63719 .35803 .63153 .35472 Mtetra
.767 .92 .939 r
.63153 .35472 .63719 .35803 .64889 .35396 .64316 .34737 Mtetra
.77 .809 .884 r
.64316 .34737 .64889 .35396 .66059 .34886 .65479 .33967 Mtetra
.751 .734 .837 r
.65479 .33967 .66059 .34886 .67229 .34295 .66643 .33177 Mtetra
.732 .687 .807 r
.66643 .33177 .67229 .34295 .684 .33645 .6781 .32388 Mtetra
.716 .657 .79 r
.6781 .32388 .684 .33645 .69572 .32961 .6898 .31623 Mtetra
.703 .639 .782 r
.6898 .31623 .69572 .32961 .70746 .3226 .70154 .30891 Mtetra
.692 .63 .782 r
.70154 .30891 .70746 .3226 .71923 .31565 .71334 .3021 Mtetra
.684 .628 .787 r
.71334 .3021 .71923 .31565 .73104 .30885 .72519 .29577 Mtetra
.676 .632 .797 r
.72519 .29577 .73104 .30885 .7429 .30235 .73712 .28998 Mtetra
.671 .641 .812 r
.73712 .28998 .7429 .30235 .75482 .29616 .74912 .28465 Mtetra
.666 .655 .83 r
.74912 .28465 .75482 .29616 .7668 .2903 .76119 .27974 Mtetra
.662 .674 .85 r
.76119 .27974 .7668 .2903 .77883 .28472 .77334 .27513 Mtetra
.66 .697 .873 r
.77334 .27513 .77883 .28472 .79093 .27933 .78555 .27073 Mtetra
.66 .724 .896 r
.78555 .27073 .79093 .27933 .80308 .27409 .79782 .26643 Mtetra
.691 .759 .903 r
.14569 .47843 .15266 .48451 .16238 .48136 .15555 .47417 Mtetra
.685 .725 .88 r
.15555 .47417 .16238 .48136 .17212 .47831 .16544 .46995 Mtetra
.675 .692 .858 r
.16544 .46995 .17212 .47831 .18188 .47547 .17534 .46586 Mtetra
.662 .659 .837 r
.17534 .46586 .18188 .47547 .19165 .47292 .18525 .462 Mtetra
.646 .627 .817 r
.18525 .462 .19165 .47292 .20141 .47078 .19516 .45845 Mtetra
.629 .596 .797 r
.19516 .45845 .20141 .47078 .21118 .46908 .20507 .4553 Mtetra
.611 .567 .78 r
.20507 .4553 .21118 .46908 .22095 .46792 .21497 .45267 Mtetra
.594 .539 .763 r
.21497 .45267 .22095 .46792 .23072 .46723 .22486 .45058 Mtetra
.576 .514 .749 r
.22486 .45058 .23072 .46723 .24051 .46704 .23474 .44911 Mtetra
.562 .494 .736 r
.23474 .44911 .24051 .46704 .25032 .46719 .24462 .4482 Mtetra
.548 .477 .727 r
.24462 .4482 .25032 .46719 .26017 .46759 .25451 .44785 Mtetra
.539 .465 .721 r
.25451 .44785 .26017 .46759 .27009 .46801 .26442 .44791 Mtetra
.531 .458 .719 r
.26442 .44791 .27009 .46801 .28007 .46825 .27437 .44829 Mtetra
.526 .456 .721 r
.27437 .44829 .28007 .46825 .29015 .46816 .28437 .44889 Mtetra
.523 .46 .728 r
.28437 .44889 .29015 .46816 .30031 .46758 .29442 .44961 Mtetra
.519 .471 .742 r
.29442 .44961 .30031 .46758 .31056 .46664 .30453 .45039 Mtetra
.517 .488 .764 r
.30453 .45039 .31056 .46664 .32089 .46536 .31472 .4511 Mtetra
.532 .524 .792 r
.31472 .4511 .32089 .46536 .3313 .46347 .32501 .45117 Mtetra
.561 .572 .822 r
.32501 .45117 .3313 .46347 .34182 .46073 .33542 .45023 Mtetra
.599 .626 .849 r
.33542 .45023 .34182 .46073 .35245 .45649 .34596 .44812 Mtetra
.64 .695 .885 r
.34596 .44812 .35245 .45649 .36322 .45051 .3566 .44489 Mtetra
.636 .782 .951 r
.3566 .44489 .36322 .45051 .37405 .44358 .36729 .44163 Mtetra
.496 .864 .984 r
.36729 .44163 .37405 .44358 .38492 .43626 .378 .43896 Mtetra
.033 0 0 r
.378 .43896 .38492 .43626 .39577 .42968 .38872 .43721 Mtetra
.349 0 0 r
.38872 .43721 .39577 .42968 .40661 .42436 .39945 .43648 Mtetra
.429 .018 .156 r
.39945 .43648 .40661 .42436 .41744 .42012 .41024 .43603 Mtetra
.45 .074 .232 r
.41024 .43603 .41744 .42012 .42828 .41679 .4211 .43539 Mtetra
.446 .088 .263 r
.4211 .43539 .42828 .41679 .43916 .41368 .43204 .43401 Mtetra
.43 .083 .274 r
.43204 .43401 .43916 .41368 .45009 .41043 .44307 .43155 Mtetra
.407 .067 .272 r
.44307 .43155 .45009 .41043 .46108 .40677 .45418 .42789 Mtetra
.379 .041 .261 r
.45418 .42789 .46108 .40677 .47211 .4027 .46535 .42302 Mtetra
.345 .007 .24 r
.46535 .42302 .47211 .4027 .4832 .39849 .47658 .41707 Mtetra
.304 0 .204 r
.47658 .41707 .4832 .39849 .49432 .3945 .48785 .41035 Mtetra
.255 0 .144 r
.48785 .41035 .49432 .3945 .50547 .39141 .49915 .40344 Mtetra
.174 0 .028 r
.49915 .40344 .50547 .39141 .51668 .38942 .51046 .3968 Mtetra
.036 0 0 r
.51046 .3968 .51668 .38942 .52794 .38873 .52181 .39117 Mtetra
.278 .761 .664 r
.52181 .39117 .52794 .38873 .53928 .38877 .53319 .38648 Mtetra
.595 .902 .985 r
.53319 .38648 .53928 .38877 .55069 .38845 .54461 .38237 Mtetra
.663 .79 .942 r
.54461 .38237 .55069 .38845 .56216 .38716 .55608 .37824 Mtetra
.693 .715 .866 r
.55608 .37824 .56216 .38716 .57366 .38411 .56758 .37295 Mtetra
.705 .672 .815 r
.56758 .37295 .57366 .38411 .58519 .37953 .5791 .36648 Mtetra
.71 .644 .781 r
.5791 .36648 .58519 .37953 .59675 .37408 .59063 .35895 Mtetra
.705 .615 .754 r
.59063 .35895 .59675 .37408 .60832 .36799 .60216 .35075 Mtetra
.692 .587 .733 r
.60216 .35075 .60832 .36799 .61992 .36154 .61371 .34248 Mtetra
.681 .565 .718 r
.61371 .34248 .61992 .36154 .63153 .35472 .62527 .33424 Mtetra
.672 .55 .708 r
.62527 .33424 .63153 .35472 .64316 .34737 .63686 .3261 Mtetra
.665 .541 .703 r
.63686 .3261 .64316 .34737 .65479 .33967 .64847 .31818 Mtetra
.66 .537 .703 r
.64847 .31818 .65479 .33967 .66643 .33177 .66011 .31057 Mtetra
.655 .536 .706 r
.66011 .31057 .66643 .33177 .6781 .32388 .6718 .30338 Mtetra
.651 .538 .713 r
.6718 .30338 .6781 .32388 .6898 .31623 .68354 .29675 Mtetra
.647 .544 .724 r
.68354 .29675 .6898 .31623 .70154 .30891 .69535 .29069 Mtetra
.642 .552 .737 r
.69535 .29069 .70154 .30891 .71334 .3021 .70722 .28526 Mtetra
.639 .564 .754 r
.70722 .28526 .71334 .3021 .72519 .29577 .71918 .28039 Mtetra
.635 .579 .774 r
.71918 .28039 .72519 .29577 .73712 .28998 .73121 .27604 Mtetra
.631 .597 .797 r
.73121 .27604 .73712 .28998 .74912 .28465 .74332 .27212 Mtetra
.628 .619 .822 r
.74332 .27212 .74912 .28465 .76119 .27974 .75551 .26852 Mtetra
.626 .643 .848 r
.75551 .26852 .76119 .27974 .77334 .27513 .76778 .26515 Mtetra
.623 .671 .875 r
.76778 .26515 .77334 .27513 .78555 .27073 .78012 .26192 Mtetra
.622 .702 .902 r
.78012 .26192 .78555 .27073 .79782 .26643 .79252 .25872 Mtetra
.721 .764 .887 r
.13868 .4723 .14569 .47843 .15555 .47417 .14866 .46709 Mtetra
.715 .736 .868 r
.14866 .46709 .15555 .47417 .16544 .46995 .15868 .46184 Mtetra
.707 .708 .849 r
.15868 .46184 .16544 .46995 .17534 .46586 .16872 .4566 Mtetra
.696 .679 .83 r
.16872 .4566 .17534 .46586 .18525 .462 .17878 .45145 Mtetra
.684 .65 .81 r
.17878 .45145 .18525 .462 .19516 .45845 .18885 .44643 Mtetra
.669 .62 .791 r
.18885 .44643 .19516 .45845 .20507 .4553 .19893 .44164 Mtetra
.653 .59 .771 r
.19893 .44164 .20507 .4553 .21497 .45267 .209 .43718 Mtetra
.636 .56 .752 r
.209 .43718 .21497 .45267 .22486 .45058 .21906 .43313 Mtetra
.618 .531 .734 r
.21906 .43313 .22486 .45058 .23474 .44911 .22911 .42959 Mtetra
.601 .504 .716 r
.22911 .42959 .23474 .44911 .24462 .4482 .23915 .42659 Mtetra
.586 .481 .701 r
.23915 .42659 .24462 .4482 .25451 .44785 .24919 .42419 Mtetra
.572 .46 .688 r
.24919 .42419 .25451 .44785 .26442 .44791 .25921 .42239 Mtetra
.56 .443 .677 r
.25921 .42239 .26442 .44791 .27437 .44829 .26924 .42119 Mtetra
.55 .43 .669 r
.26924 .42119 .27437 .44829 .28437 .44889 .27928 .42052 Mtetra
.542 .419 .663 r
.27928 .42052 .28437 .44889 .29442 .44961 .28935 .42033 Mtetra
.538 .414 .659 r
.28935 .42033 .29442 .44961 .30453 .45039 .29946 .42034 Mtetra
.539 .412 .655 r
.29946 .42034 .30453 .45039 .31472 .4511 .30963 .42032 Mtetra
.544 .413 .653 r
.30963 .42032 .31472 .4511 .32501 .45117 .31989 .41992 Mtetra
.552 .417 .651 r
.31989 .41992 .32501 .45117 .33542 .45023 .33025 .41895 Mtetra
.551 .417 .651 r
.33025 .41895 .33542 .45023 .34596 .44812 .34065 .41806 Mtetra
.545 .417 .657 r
.34065 .41806 .34596 .44812 .3566 .44489 .3511 .41762 Mtetra
.53 .419 .671 r
.3511 .41762 .3566 .44489 .36729 .44163 .36155 .41814 Mtetra
.507 .423 .696 r
.36155 .41814 .36729 .44163 .378 .43896 .37203 .41977 Mtetra
.492 .446 .734 r
.37203 .41977 .378 .43896 .38872 .43721 .38257 .42164 Mtetra
.486 .483 .779 r
.38257 .42164 .38872 .43721 .39945 .43648 .3932 .42321 Mtetra
.508 .531 .815 r
.3932 .42321 .39945 .43648 .41024 .43603 .40394 .42381 Mtetra
.551 .573 .83 r
.40394 .42381 .41024 .43603 .4211 .43539 .41481 .42309 Mtetra
.586 .591 .824 r
.41481 .42309 .4211 .43539 .43204 .43401 .42577 .42126 Mtetra
.615 .598 .81 r
.42577 .42126 .43204 .43401 .44307 .43155 .43681 .41838 Mtetra
.633 .601 .799 r
.43681 .41838 .44307 .43155 .45418 .42789 .44793 .41469 Mtetra
.652 .61 .794 r
.44793 .41469 .45418 .42789 .46535 .42302 .45911 .41017 Mtetra
.676 .627 .793 r
.45911 .41017 .46535 .42302 .47658 .41707 .47034 .4046 Mtetra
.7 .644 .791 r
.47034 .4046 .47658 .41707 .48785 .41035 .48163 .3979 Mtetra
.724 .655 .781 r
.48163 .3979 .48785 .41035 .49915 .40344 .49295 .38987 Mtetra
.73 .643 .762 r
.49295 .38987 .49915 .40344 .51046 .3968 .5043 .38083 Mtetra
.716 .609 .737 r
.5043 .38083 .51046 .3968 .52181 .39117 .51565 .37147 Mtetra
.689 .564 .708 r
.51565 .37147 .52181 .39117 .53319 .38648 .52702 .36234 Mtetra
.654 .517 .684 r
.52702 .36234 .53319 .38648 .54461 .38237 .5384 .35431 Mtetra
.63 .484 .666 r
.5384 .35431 .54461 .38237 .55608 .37824 .5498 .34725 Mtetra
.617 .466 .654 r
.5498 .34725 .55608 .37824 .56758 .37295 .56123 .34063 Mtetra
.613 .459 .649 r
.56123 .34063 .56758 .37295 .5791 .36648 .5727 .33408 Mtetra
.619 .463 .648 r
.5727 .33408 .5791 .36648 .59063 .35895 .58418 .32695 Mtetra
.624 .467 .649 r
.58418 .32695 .59063 .35895 .60216 .35075 .59567 .3194 Mtetra
.625 .47 .652 r
.59567 .3194 .60216 .35075 .61371 .34248 .60719 .31181 Mtetra
.625 .472 .655 r
.60719 .31181 .61371 .34248 .62527 .33424 .61873 .30441 Mtetra
.622 .473 .659 r
.61873 .30441 .62527 .33424 .63686 .3261 .63031 .29749 Mtetra
.62 .476 .665 r
.63031 .29749 .63686 .3261 .64847 .31818 .64194 .29111 Mtetra
.617 .48 .673 r
.64194 .29111 .64847 .31818 .66011 .31057 .65363 .28534 Mtetra
.614 .487 .684 r
.65363 .28534 .66011 .31057 .6718 .30338 .66538 .28017 Mtetra
.611 .497 .699 r
.66538 .28017 .6718 .30338 .68354 .29675 .67721 .27562 Mtetra
.608 .509 .716 r
.67721 .27562 .68354 .29675 .69535 .29069 .68911 .27163 Mtetra
.605 .523 .736 r
.68911 .27163 .69535 .29069 .70722 .28526 .70109 .26816 Mtetra
.602 .541 .758 r
.70109 .26816 .70722 .28526 .71918 .28039 .71315 .26512 Mtetra
.599 .561 .783 r
.71315 .26512 .71918 .28039 .73121 .27604 .7253 .26241 Mtetra
.596 .584 .81 r
.7253 .26241 .73121 .27604 .74332 .27212 .73753 .25996 Mtetra
.594 .609 .836 r
.73753 .25996 .74332 .27212 .75551 .26852 .74983 .25764 Mtetra
.591 .635 .863 r
.74983 .25764 .75551 .26852 .76778 .26515 .76221 .25541 Mtetra
.588 .661 .889 r
.76221 .25541 .76778 .26515 .78012 .26192 .77466 .2532 Mtetra
.586 .689 .913 r
.77466 .2532 .78012 .26192 .79252 .25872 .78718 .25095 Mtetra
.73 .765 .881 r
.13161 .46613 .13868 .4723 .14866 .46709 .14166 .46055 Mtetra
.73 .755 .873 r
.14166 .46055 .14866 .46709 .15868 .46184 .15175 .45486 Mtetra
.728 .743 .864 r
.15175 .45486 .15868 .46184 .16872 .4566 .16187 .44909 Mtetra
.726 .729 .854 r
.16187 .44909 .16872 .4566 .17878 .45145 .17202 .44326 Mtetra
.721 .712 .841 r
.17202 .44326 .17878 .45145 .18885 .44643 .1822 .43738 Mtetra
.713 .691 .827 r
.1822 .43738 .18885 .44643 .19893 .44164 .1924 .43152 Mtetra
.703 .667 .812 r
.1924 .43152 .19893 .44164 .209 .43718 .20261 .42575 Mtetra
.689 .639 .794 r
.20261 .42575 .209 .43718 .21906 .43313 .21283 .42016 Mtetra
.674 .61 .776 r
.21283 .42016 .21906 .43313 .22911 .42959 .22305 .41485 Mtetra
.656 .58 .757 r
.22305 .41485 .22911 .42959 .23915 .42659 .23326 .40991 Mtetra
.638 .55 .739 r
.23326 .40991 .23915 .42659 .24919 .42419 .24346 .40541 Mtetra
.621 .522 .721 r
.24346 .40541 .24919 .42419 .25921 .42239 .25365 .40142 Mtetra
.604 .497 .705 r
.25365 .40142 .25921 .42239 .26924 .42119 .26383 .39798 Mtetra
.59 .475 .69 r
.26383 .39798 .26924 .42119 .27928 .42052 .27402 .39505 Mtetra
.578 .456 .677 r
.27402 .39505 .27928 .42052 .28935 .42033 .2842 .39261 Mtetra
.571 .442 .665 r
.2842 .39261 .28935 .42033 .29946 .42034 .29442 .39041 Mtetra
.567 .431 .655 r
.29442 .39041 .29946 .42034 .30963 .42032 .30468 .38829 Mtetra
.564 .423 .647 r
.30468 .38829 .30963 .42032 .31989 .41992 .31499 .38622 Mtetra
.562 .416 .641 r
.31499 .38622 .31989 .41992 .33025 .41895 .32534 .38425 Mtetra
.553 .407 .637 r
.32534 .38425 .33025 .41895 .34065 .41806 .3357 .38295 Mtetra
.541 .398 .636 r
.3357 .38295 .34065 .41806 .3511 .41762 .34606 .3826 Mtetra
.533 .393 .636 r
.34606 .3826 .3511 .41762 .36155 .41814 .35645 .38289 Mtetra
.528 .389 .636 r
.35645 .38289 .36155 .41814 .37203 .41977 .3669 .38352 Mtetra
.536 .393 .633 r
.3669 .38352 .37203 .41977 .38257 .42164 .37744 .38352 Mtetra
.549 .397 .628 r
.37744 .38352 .38257 .42164 .3932 .42321 .3881 .38239 Mtetra
.559 .399 .621 r
.3881 .38239 .3932 .42321 .40394 .42381 .39886 .3801 Mtetra
.567 .4 .615 r
.39886 .3801 .40394 .42381 .41481 .42309 .40971 .37676 Mtetra
.568 .397 .61 r
.40971 .37676 .41481 .42309 .42577 .42126 .42063 .37296 Mtetra
.568 .394 .606 r
.42063 .37296 .42577 .42126 .43681 .41838 .43159 .36904 Mtetra
.565 .391 .604 r
.43159 .36904 .43681 .41838 .44793 .41469 .44259 .36528 Mtetra
.564 .39 .604 r
.44259 .36528 .44793 .41469 .45911 .41017 .45363 .36168 Mtetra
.566 .393 .606 r
.45363 .36168 .45911 .41017 .47034 .4046 .46472 .35795 Mtetra
.571 .399 .61 r
.46472 .35795 .47034 .4046 .48163 .3979 .47586 .35377 Mtetra
.582 .411 .615 r
.47586 .35377 .48163 .3979 .49295 .38987 .48706 .34852 Mtetra
.595 .425 .621 r
.48706 .34852 .49295 .38987 .5043 .38083 .49831 .3421 Mtetra
.609 .44 .628 r
.49831 .3421 .5043 .38083 .51565 .37147 .50958 .33453 Mtetra
.619 .45 .632 r
.50958 .33453 .51565 .37147 .52702 .36234 .52088 .3263 Mtetra
.617 .451 .635 r
.52088 .3263 .52702 .36234 .5384 .35431 .5322 .3184 Mtetra
.612 .448 .636 r
.5322 .3184 .5384 .35431 .5498 .34725 .54353 .31115 Mtetra
.602 .441 .636 r
.54353 .31115 .5498 .34725 .56123 .34063 .5549 .30484 Mtetra
.596 .438 .637 r
.5549 .30484 .56123 .34063 .5727 .33408 .56631 .29921 Mtetra
.597 .44 .64 r
.56631 .29921 .5727 .33408 .58418 .32695 .57775 .29366 Mtetra
.599 .446 .646 r
.57775 .29366 .58418 .32695 .59567 .3194 .58923 .28818 Mtetra
.602 .455 .654 r
.58923 .28818 .59567 .3194 .60719 .31181 .60075 .28276 Mtetra
.604 .464 .663 r
.60075 .28276 .60719 .31181 .61873 .30441 .61231 .27758 Mtetra
.603 .472 .675 r
.61231 .27758 .61873 .30441 .63031 .29749 .62393 .2729 Mtetra
.602 .482 .689 r
.62393 .2729 .63031 .29749 .64194 .29111 .63561 .26873 Mtetra
.598 .493 .706 r
.63561 .26873 .64194 .29111 .65363 .28534 .64737 .26514 Mtetra
.595 .507 .725 r
.64737 .26514 .65363 .28534 .66538 .28017 .6592 .26206 Mtetra
.591 .523 .747 r
.6592 .26206 .66538 .28017 .67721 .27562 .67111 .25945 Mtetra
.587 .542 .772 r
.67111 .25945 .67721 .27562 .68911 .27163 .6831 .25722 Mtetra
.582 .563 .798 r
.6831 .25722 .68911 .27163 .70109 .26816 .69518 .25527 Mtetra
.577 .586 .825 r
.69518 .25527 .70109 .26816 .71315 .26512 .70733 .25352 Mtetra
.573 .609 .85 r
.70733 .25352 .71315 .26512 .7253 .26241 .71957 .25187 Mtetra
.57 .631 .873 r
.71957 .25187 .7253 .26241 .73753 .25996 .73187 .25025 Mtetra
.568 .652 .892 r
.73187 .25025 .73753 .25996 .74983 .25764 .74425 .24858 Mtetra
.567 .67 .908 r
.74425 .24858 .74983 .25764 .76221 .25541 .7567 .24684 Mtetra
.566 .685 .92 r
.7567 .24684 .76221 .25541 .77466 .2532 .76922 .24503 Mtetra
.567 .699 .93 r
.76922 .24503 .77466 .2532 .78718 .25095 .7818 .24311 Mtetra
.724 .764 .885 r
.12449 .45992 .13161 .46613 .14166 .46055 .13454 .45455 Mtetra
.729 .772 .888 r
.13454 .45455 .14166 .46055 .15175 .45486 .14464 .44904 Mtetra
.734 .779 .889 r
.14464 .44904 .15175 .45486 .16187 .44909 .15477 .44338 Mtetra
.739 .784 .889 r
.15477 .44338 .16187 .44909 .17202 .44326 .16495 .43754 Mtetra
.745 .785 .886 r
.16495 .43754 .17202 .44326 .1822 .43738 .17517 .43148 Mtetra
.747 .781 .88 r
.17517 .43148 .1822 .43738 .1924 .43152 .18544 .42526 Mtetra
.748 .771 .872 r
.18544 .42526 .1924 .43152 .20261 .42575 .19573 .41889 Mtetra
.744 .754 .861 r
.19573 .41889 .20261 .42575 .21283 .42016 .20606 .41246 Mtetra
.737 .732 .846 r
.20606 .41246 .21283 .42016 .22305 .41485 .2164 .40603 Mtetra
.725 .703 .829 r
.2164 .40603 .22305 .41485 .23326 .40991 .22676 .39971 Mtetra
.709 .671 .81 r
.22676 .39971 .23326 .40991 .24346 .40541 .23712 .39358 Mtetra
.692 .636 .789 r
.23712 .39358 .24346 .40541 .25365 .40142 .24748 .38769 Mtetra
.673 .602 .767 r
.24748 .38769 .25365 .40142 .26383 .39798 .25784 .38213 Mtetra
.655 .569 .745 r
.25784 .38213 .26383 .39798 .27402 .39505 .2682 .37686 Mtetra
.639 .539 .724 r
.2682 .37686 .27402 .39505 .2842 .39261 .27857 .37188 Mtetra
.625 .512 .705 r
.27857 .37188 .2842 .39261 .29442 .39041 .28895 .36712 Mtetra
.614 .49 .688 r
.28895 .36712 .29442 .39041 .30468 .38829 .29934 .36258 Mtetra
.6 .47 .674 r
.29934 .36258 .30468 .38829 .31499 .38622 .30974 .35853 Mtetra
.587 .453 .665 r
.30974 .35853 .31499 .38622 .32534 .38425 .32014 .35513 Mtetra
.575 .439 .659 r
.32014 .35513 .32534 .38425 .3357 .38295 .33053 .35244 Mtetra
.565 .427 .653 r
.33053 .35244 .3357 .38295 .34606 .3826 .34093 .35037 Mtetra
.567 .424 .646 r
.34093 .35037 .34606 .3826 .35645 .38289 .3514 .348 Mtetra
.574 .421 .637 r
.3514 .348 .35645 .38289 .3669 .38352 .36197 .34478 Mtetra
.581 .418 .625 r
.36197 .34478 .3669 .38352 .37744 .38352 .37264 .34031 Mtetra
.587 .414 .615 r
.37264 .34031 .37744 .38352 .3881 .38239 .3834 .33455 Mtetra
.586 .407 .606 r
.3834 .33455 .3881 .38239 .39886 .3801 .39422 .32825 Mtetra
.582 .399 .599 r
.39422 .32825 .39886 .3801 .40971 .37676 .40506 .32188 Mtetra
.575 .391 .594 r
.40506 .32188 .40971 .37676 .42063 .37296 .41591 .31608 Mtetra
.567 .383 .591 r
.41591 .31608 .42063 .37296 .43159 .36904 .42676 .3112 Mtetra
.559 .376 .59 r
.42676 .3112 .43159 .36904 .44259 .36528 .43762 .30736 Mtetra
.552 .37 .589 r
.43762 .30736 .44259 .36528 .45363 .36168 .44849 .30459 Mtetra
.545 .367 .59 r
.44849 .30459 .45363 .36168 .46472 .35795 .45939 .30274 Mtetra
.542 .366 .593 r
.45939 .30274 .46472 .35795 .47586 .35377 .47035 .30146 Mtetra
.543 .37 .597 r
.47035 .30146 .47586 .35377 .48706 .34852 .48136 .30013 Mtetra
.549 .38 .605 r
.48136 .30013 .48706 .34852 .49831 .3421 .49245 .29825 Mtetra
.563 .397 .614 r
.49245 .29825 .49831 .3421 .50958 .33453 .5036 .29507 Mtetra
.579 .416 .625 r
.5036 .29507 .50958 .33453 .52088 .3263 .51481 .29064 Mtetra
.593 .435 .636 r
.51481 .29064 .52088 .3263 .5322 .3184 .52606 .28534 Mtetra
.601 .447 .645 r
.52606 .28534 .5322 .3184 .54353 .31115 .53735 .27972 Mtetra
.597 .449 .652 r
.53735 .27972 .54353 .31115 .5549 .30484 .54867 .27474 Mtetra
.591 .45 .658 r
.54867 .27474 .5549 .30484 .56631 .29921 .56004 .27048 Mtetra
.585 .452 .665 r
.56004 .27048 .56631 .29921 .57775 .29366 .57147 .26687 Mtetra
.582 .458 .676 r
.57147 .26687 .57775 .29366 .58923 .28818 .58296 .26376 Mtetra
.583 .47 .691 r
.58296 .26376 .58923 .28818 .60075 .28276 .59451 .26087 Mtetra
.584 .487 .71 r
.59451 .26087 .60075 .28276 .61231 .27758 .60612 .25821 Mtetra
.583 .506 .733 r
.60612 .25821 .61231 .27758 .62393 .2729 .6178 .25586 Mtetra
.581 .527 .76 r
.6178 .25586 .62393 .2729 .63561 .26873 .62955 .25381 Mtetra
.576 .551 .79 r
.62955 .25381 .63561 .26873 .64737 .26514 .64138 .25209 Mtetra
.569 .577 .821 r
.64138 .25209 .64737 .26514 .6592 .26206 .65329 .25063 Mtetra
.56 .604 .854 r
.65329 .25063 .6592 .26206 .67111 .25945 .66528 .24938 Mtetra
.551 .631 .884 r
.66528 .24938 .67111 .25945 .6831 .25722 .67735 .24824 Mtetra
.543 .658 .911 r
.67735 .24824 .6831 .25722 .69518 .25527 .6895 .24712 Mtetra
.537 .68 .931 r
.6895 .24712 .69518 .25527 .70733 .25352 .70172 .24593 Mtetra
.536 .7 .945 r
.70172 .24593 .70733 .25352 .71957 .25187 .714 .2446 Mtetra
.539 .713 .952 r
.714 .2446 .71957 .25187 .73187 .25025 .72635 .2431 Mtetra
.548 .722 .955 r
.72635 .2431 .73187 .25025 .74425 .24858 .73877 .24138 Mtetra
.556 .726 .953 r
.73877 .24138 .74425 .24858 .7567 .24684 .75124 .23947 Mtetra
.565 .725 .949 r
.75124 .23947 .7567 .24684 .76922 .24503 .76377 .23741 Mtetra
.572 .721 .943 r
.76377 .23741 .76922 .24503 .7818 .24311 .77637 .23521 Mtetra
.697 .76 .901 r
.11732 .45366 .12449 .45992 .13454 .45455 .12729 .44915 Mtetra
.704 .79 .918 r
.12729 .44915 .13454 .45455 .14464 .44904 .13731 .4445 Mtetra
.711 .821 .933 r
.13731 .4445 .14464 .44904 .15477 .44338 .14738 .43968 Mtetra
.719 .853 .945 r
.14738 .43968 .15477 .44338 .16495 .43754 .1575 .43463 Mtetra
.727 .882 .952 r
.1575 .43463 .16495 .43754 .17517 .43148 .16768 .42928 Mtetra
.732 .908 .955 r
.16768 .42928 .17517 .43148 .18544 .42526 .17792 .42367 Mtetra
.737 .928 .953 r
.17792 .42367 .18544 .42526 .19573 .41889 .18821 .41775 Mtetra
.74 .942 .95 r
.18821 .41775 .19573 .41889 .20606 .41246 .19855 .4116 Mtetra
.743 .95 .945 r
.19855 .4116 .20606 .41246 .2164 .40603 .20893 .40525 Mtetra
.746 .953 .943 r
.20893 .40525 .2164 .40603 .22676 .39971 .21935 .39876 Mtetra
.751 .95 .943 r
.21935 .39876 .22676 .39971 .23712 .39358 .22979 .39223 Mtetra
.756 .94 .944 r
.22979 .39223 .23712 .39358 .24748 .38769 .24025 .38569 Mtetra
.759 .922 .943 r
.24025 .38569 .24748 .38769 .25784 .38213 .25072 .37923 Mtetra
.76 .893 .937 r
.25072 .37923 .25784 .38213 .2682 .37686 .26121 .37287 Mtetra
.755 .856 .924 r
.26121 .37287 .2682 .37686 .27857 .37188 .27171 .36664 Mtetra
.744 .813 .907 r
.27171 .36664 .27857 .37188 .28895 .36712 .28222 .36062 Mtetra
.728 .771 .887 r
.28222 .36062 .28895 .36712 .29934 .36258 .29273 .35488 Mtetra
.706 .732 .871 r
.29273 .35488 .29934 .36258 .30974 .35853 .30323 .34964 Mtetra
.681 .695 .856 r
.30323 .34964 .30974 .35853 .32014 .35513 .31372 .34501 Mtetra
.666 .663 .837 r
.31372 .34501 .32014 .35513 .33053 .35244 .32423 .34068 Mtetra
.656 .628 .809 r
.32423 .34068 .33053 .35244 .34093 .35037 .33477 .33637 Mtetra
.659 .596 .773 r
.33477 .33637 .34093 .35037 .3514 .348 .34539 .33135 Mtetra
.663 .569 .738 r
.34539 .33135 .3514 .348 .36197 .34478 .3561 .32527 Mtetra
.66 .543 .711 r
.3561 .32527 .36197 .34478 .37264 .34031 .36687 .31846 Mtetra
.655 .525 .693 r
.36687 .31846 .37264 .34031 .3834 .33455 .37769 .31118 Mtetra
.645 .511 .685 r
.37769 .31118 .3834 .33455 .39422 .32825 .38851 .30419 Mtetra
.634 .5 .682 r
.38851 .30419 .39422 .32825 .40506 .32188 .39932 .29789 Mtetra
.623 .494 .684 r
.39932 .29789 .40506 .32188 .41591 .31608 .41013 .29238 Mtetra
.612 .488 .688 r
.41013 .29238 .41591 .31608 .42676 .3112 .42095 .28775 Mtetra
.601 .483 .691 r
.42095 .28775 .42676 .3112 .43762 .30736 .43177 .28388 Mtetra
.589 .475 .692 r
.43177 .28388 .43762 .30736 .44849 .30459 .44262 .28076 Mtetra
.574 .464 .691 r
.44262 .28076 .44849 .30459 .45939 .30274 .4535 .27853 Mtetra
.56 .453 .69 r
.4535 .27853 .45939 .30274 .47035 .30146 .46442 .27711 Mtetra
.548 .445 .69 r
.46442 .27711 .47035 .30146 .48136 .30013 .47539 .27638 Mtetra
.543 .446 .695 r
.47539 .27638 .48136 .30013 .49245 .29825 .48642 .27595 Mtetra
.552 .461 .706 r
.48642 .27595 .49245 .29825 .5036 .29507 .49753 .27507 Mtetra
.568 .488 .725 r
.49753 .27507 .5036 .29507 .51481 .29064 .50871 .27344 Mtetra
.595 .53 .752 r
.50871 .27344 .51481 .29064 .52606 .28534 .51995 .27076 Mtetra
.618 .575 .783 r
.51995 .27076 .52606 .28534 .53735 .27972 .53125 .26735 Mtetra
.625 .613 .818 r
.53125 .26735 .53735 .27972 .54867 .27474 .5426 .26397 Mtetra
.621 .643 .851 r
.5426 .26397 .54867 .27474 .56004 .27048 .554 .26088 Mtetra
.601 .662 .882 r
.554 .26088 .56004 .27048 .57147 .26687 .56546 .25842 Mtetra
.577 .684 .913 r
.56546 .25842 .57147 .26687 .58296 .26376 .577 .25649 Mtetra
.553 .711 .945 r
.577 .25649 .58296 .26376 .59451 .26087 .5886 .25484 Mtetra
.521 .742 .975 r
.5886 .25484 .59451 .26087 .60612 .25821 .60028 .2534 Mtetra
.476 .769 .995 r
.60028 .2534 .60612 .25821 .6178 .25586 .61203 .25212 Mtetra
.419 .782 .995 r
.61203 .25212 .6178 .25586 .62955 .25381 .62386 .25094 Mtetra
.358 .779 .976 r
.62386 .25094 .62955 .25381 .64138 .25209 .63576 .24984 Mtetra
.31 .769 .949 r
.63576 .24984 .64138 .25209 .65329 .25063 .64773 .24875 Mtetra
.284 .763 .929 r
.64773 .24875 .65329 .25063 .66528 .24938 .65978 .24761 Mtetra
.285 .766 .924 r
.65978 .24761 .66528 .24938 .67735 .24824 .6719 .24635 Mtetra
.313 .781 .936 r
.6719 .24635 .67735 .24824 .6895 .24712 .68408 .24488 Mtetra
.359 .801 .958 r
.68408 .24488 .6895 .24712 .70172 .24593 .69633 .24317 Mtetra
.418 .82 .981 r
.69633 .24317 .70172 .24593 .714 .2446 .70863 .24116 Mtetra
.476 .828 .996 r
.70863 .24116 .714 .2446 .72635 .2431 .72098 .23886 Mtetra
.528 .825 .999 r
.72098 .23886 .72635 .2431 .73877 .24138 .73338 .23627 Mtetra
.566 .81 .99 r
.73338 .23627 .73877 .24138 .75124 .23947 .74583 .23343 Mtetra
.592 .787 .973 r
.74583 .23343 .75124 .23947 .76377 .23741 .75834 .23041 Mtetra
.607 .761 .952 r
.75834 .23041 .76377 .23741 .77637 .23521 .7709 .22725 Mtetra
.65 .75 .923 r
.1101 .44736 .11732 .45366 .12729 .44915 .11994 .44407 Mtetra
.651 .793 .95 r
.11994 .44407 .12729 .44915 .13731 .4445 .12983 .44067 Mtetra
.648 .838 .973 r
.12983 .44067 .13731 .4445 .14738 .43968 .13978 .43711 Mtetra
.638 .882 .986 r
.13978 .43711 .14738 .43968 .1575 .43463 .14979 .43334 Mtetra
.618 .916 .979 r
.14979 .43334 .1575 .43463 .16768 .42928 .15987 .42927 Mtetra
.58 .931 .945 r
.15987 .42927 .16768 .42928 .17792 .42367 .17001 .42489 Mtetra
.529 .921 .882 r
.17001 .42489 .17792 .42367 .18821 .41775 .18023 .42015 Mtetra
.464 .886 .798 r
.18023 .42015 .18821 .41775 .19855 .4116 .19051 .41508 Mtetra
.4 .838 .706 r
.19051 .41508 .19855 .4116 .20893 .40525 .20085 .40967 Mtetra
.34 .784 .62 r
.20085 .40967 .20893 .40525 .21935 .39876 .21125 .40397 Mtetra
0 0 0 r
.21125 .40397 .21935 .39876 .22979 .39223 .2217 .39801 Mtetra
.2217 .39801 .22979 .39223 .24025 .38569 .2322 .39185 Mtetra
.2322 .39185 .24025 .38569 .25072 .37923 .24272 .38555 Mtetra
.24272 .38555 .25072 .37923 .26121 .37287 .25328 .3792 Mtetra
.25328 .3792 .26121 .37287 .27171 .36664 .26386 .37286 Mtetra
.26386 .37286 .27171 .36664 .28222 .36062 .27444 .36668 Mtetra
.27444 .36668 .28222 .36062 .29273 .35488 .28504 .36074 Mtetra
.28504 .36074 .29273 .35488 .30323 .34964 .29564 .35508 Mtetra
.29564 .35508 .30323 .34964 .31372 .34501 .30625 .34967 Mtetra
.30625 .34967 .31372 .34501 .32423 .34068 .31691 .34399 Mtetra
.447 .862 .711 r
.31691 .34399 .32423 .34068 .33477 .33637 .32763 .33776 Mtetra
.653 .97 .869 r
.32763 .33776 .33477 .33637 .34539 .33135 .33841 .33087 Mtetra
.762 .973 .923 r
.33841 .33087 .34539 .33135 .3561 .32527 .34925 .32339 Mtetra
.775 .939 .935 r
.34925 .32339 .3561 .32527 .36687 .31846 .36009 .31617 Mtetra
.75 .927 .948 r
.36009 .31617 .36687 .31846 .37769 .31118 .37092 .30967 Mtetra
.684 .941 .963 r
.37092 .30967 .37769 .31118 .38851 .30419 .38172 .30416 Mtetra
.529 .917 .917 r
.38172 .30416 .38851 .30419 .39932 .29789 .39251 .29969 Mtetra
.313 .797 .744 r
.39251 .29969 .39932 .29789 .41013 .29238 .40332 .29572 Mtetra
0 0 0 r
.40332 .29572 .41013 .29238 .42095 .28775 .41417 .29196 Mtetra
.41417 .29196 .42095 .28775 .43177 .28388 .42506 .28807 Mtetra
.42506 .28807 .43177 .28388 .44262 .28076 .436 .28404 Mtetra
.436 .28404 .44262 .28076 .4535 .27853 .44698 .28023 Mtetra
.23 .741 .709 r
.44698 .28023 .4535 .27853 .46442 .27711 .45799 .27691 Mtetra
.288 .786 .856 r
.45799 .27691 .46442 .27711 .47539 .27638 .46904 .27464 Mtetra
.306 .776 .935 r
.46904 .27464 .47539 .27638 .48642 .27595 .48012 .27339 Mtetra
.291 .746 .955 r
.48012 .27339 .48642 .27595 .49753 .27507 .49127 .27286 Mtetra
.231 .718 .926 r
.49127 .27286 .49753 .27507 .50871 .27344 .50248 .27261 Mtetra
.175 .706 .845 r
.50248 .27261 .50871 .27344 .51995 .27076 .51377 .27176 Mtetra
0 0 0 r
.51377 .27176 .51995 .27076 .53125 .26735 .52512 .27026 Mtetra
.03 0 0 r
.52512 .27026 .53125 .26735 .5426 .26397 .53655 .26821 Mtetra
.1 0 0 r
.53655 .26821 .5426 .26397 .554 .26088 .54803 .26589 Mtetra
.164 0 0 r
.54803 .26589 .554 .26088 .56546 .25842 .55957 .26382 Mtetra
.204 0 0 r
.55957 .26382 .56546 .25842 .577 .25649 .57119 .26204 Mtetra
.229 0 0 r
.57119 .26204 .577 .25649 .5886 .25484 .58287 .26052 Mtetra
.244 0 0 r
.58287 .26052 .5886 .25484 .60028 .2534 .59463 .25916 Mtetra
.249 0 0 r
.59463 .25916 .60028 .2534 .61203 .25212 .60646 .25783 Mtetra
.245 0 0 r
.60646 .25783 .61203 .25212 .62386 .25094 .61836 .25644 Mtetra
.228 0 0 r
.61836 .25644 .62386 .25094 .63576 .24984 .63032 .25492 Mtetra
.198 0 0 r
.63032 .25492 .63576 .24984 .64773 .24875 .64235 .2532 Mtetra
.149 0 0 r
.64235 .2532 .64773 .24875 .65978 .24761 .65445 .25122 Mtetra
.077 0 0 r
.65445 .25122 .65978 .24761 .6719 .24635 .66659 .24894 Mtetra
0 0 0 r
.66659 .24894 .6719 .24635 .68408 .24488 .67879 .24631 Mtetra
.67879 .24631 .68408 .24488 .69633 .24317 .69104 .24333 Mtetra
.304 .798 .817 r
.69104 .24333 .69633 .24317 .70863 .24116 .70333 .23998 Mtetra
.442 .87 .926 r
.70333 .23998 .70863 .24116 .72098 .23886 .71566 .23631 Mtetra
.547 .892 .981 r
.71566 .23631 .72098 .23886 .73338 .23627 .72802 .23232 Mtetra
.611 .875 .991 r
.72802 .23232 .73338 .23627 .74583 .23343 .74043 .22811 Mtetra
.645 .838 .975 r
.74043 .22811 .74583 .23343 .75834 .23041 .75289 .22372 Mtetra
.659 .795 .948 r
.75289 .22372 .75834 .23041 .7709 .22725 .76539 .21923 Mtetra
.588 .732 .943 r
.10283 .44102 .1101 .44736 .11994 .44407 .11253 .43897 Mtetra
.576 .774 .973 r
.11253 .43897 .11994 .44407 .12983 .44067 .12228 .43688 Mtetra
.555 .817 .995 r
.12228 .43688 .12983 .44067 .13978 .43711 .13209 .43467 Mtetra
.519 .852 .996 r
.13209 .43467 .13978 .43711 .14979 .43334 .14197 .43229 Mtetra
.462 .865 .963 r
.14197 .43229 .14979 .43334 .15987 .42927 .15192 .42969 Mtetra
.379 .842 .879 r
.15192 .42969 .15987 .42927 .17001 .42489 .16194 .4268 Mtetra
.28 .778 .75 r
.16194 .4268 .17001 .42489 .18023 .42015 .17203 .42359 Mtetra
0 0 0 r
.17203 .42359 .18023 .42015 .19051 .41508 .18221 .42004 Mtetra
.18221 .42004 .19051 .41508 .20085 .40967 .19246 .41611 Mtetra
.19246 .41611 .20085 .40967 .21125 .40397 .20278 .41184 Mtetra
.045 0 0 r
.20278 .41184 .21125 .40397 .2217 .39801 .21317 .40723 Mtetra
.092 0 0 r
.21317 .40723 .2217 .39801 .2322 .39185 .22362 .40234 Mtetra
.13 0 0 r
.22362 .40234 .2322 .39185 .24272 .38555 .23413 .39721 Mtetra
.165 0 0 r
.23413 .39721 .24272 .38555 .25328 .3792 .24468 .39193 Mtetra
.195 0 .021 r
.24468 .39193 .25328 .3792 .26386 .37286 .25526 .38658 Mtetra
.223 0 .059 r
.25526 .38658 .26386 .37286 .27444 .36668 .26587 .38125 Mtetra
.249 0 .09 r
.26587 .38125 .27444 .36668 .28504 .36074 .27651 .37602 Mtetra
.264 0 .111 r
.27651 .37602 .28504 .36074 .29564 .35508 .28717 .37079 Mtetra
.27 0 .122 r
.28717 .37079 .29564 .35508 .30625 .34967 .29788 .36548 Mtetra
.255 0 .117 r
.29788 .36548 .30625 .34967 .31691 .34399 .30864 .35975 Mtetra
.233 0 .106 r
.30864 .35975 .31691 .34399 .32763 .33776 .31946 .35349 Mtetra
.228 0 .103 r
.31946 .35349 .32763 .33776 .33841 .33087 .33033 .34709 Mtetra
.247 0 .121 r
.33033 .34709 .33841 .33087 .34925 .32339 .3412 .34086 Mtetra
.302 0 .168 r
.3412 .34086 .34925 .32339 .36009 .31617 .35205 .33553 Mtetra
.363 .007 .22 r
.35205 .33553 .36009 .31617 .37092 .30967 .36288 .3314 Mtetra
.405 .059 .262 r
.36288 .3314 .37092 .30967 .38172 .30416 .3737 .32823 Mtetra
.431 .094 .292 r
.3737 .32823 .38172 .30416 .39251 .29969 .38453 .32573 Mtetra
.437 .107 .307 r
.38453 .32573 .39251 .29969 .40332 .29572 .39543 .32314 Mtetra
.433 .108 .314 r
.39543 .32314 .40332 .29572 .41417 .29196 .40639 .32006 Mtetra
.421 .1 .314 r
.40639 .32006 .41417 .29196 .42506 .28807 .41743 .31617 Mtetra
.406 .087 .308 r
.41743 .31617 .42506 .28807 .436 .28404 .42855 .31146 Mtetra
.394 .074 .3 r
.42855 .31146 .436 .28404 .44698 .28023 .43971 .30625 Mtetra
.386 .062 .288 r
.43971 .30625 .44698 .28023 .45799 .27691 .45092 .30095 Mtetra
.389 .056 .275 r
.45092 .30095 .45799 .27691 .46904 .27464 .46214 .29632 Mtetra
.396 .051 .258 r
.46214 .29632 .46904 .27464 .48012 .27339 .4734 .29265 Mtetra
.41 .05 .239 r
.4734 .29265 .48012 .27339 .49127 .27286 .48468 .2902 Mtetra
.421 .047 .22 r
.48468 .2902 .49127 .27286 .50248 .27261 .49602 .28867 Mtetra
.418 .034 .2 r
.49602 .28867 .50248 .27261 .51377 .27176 .50742 .28731 Mtetra
.41 .022 .189 r
.50742 .28731 .51377 .27176 .52512 .27026 .51889 .28582 Mtetra
.395 .008 .182 r
.51889 .28582 .52512 .27026 .53655 .26821 .53042 .28379 Mtetra
.383 0 .178 r
.53042 .28379 .53655 .26821 .54803 .26589 .54202 .28134 Mtetra
.38 0 .174 r
.54202 .28134 .54803 .26589 .55957 .26382 .55367 .27882 Mtetra
.376 0 .165 r
.55367 .27882 .55957 .26382 .57119 .26204 .56539 .27629 Mtetra
.372 0 .149 r
.56539 .27629 .57119 .26204 .58287 .26052 .57717 .27387 Mtetra
.362 0 .128 r
.57717 .27387 .58287 .26052 .59463 .25916 .58901 .27148 Mtetra
.347 0 .098 r
.58901 .27148 .59463 .25916 .60646 .25783 .60092 .26902 Mtetra
.324 0 .059 r
.60092 .26902 .60646 .25783 .61836 .25644 .61289 .2664 Mtetra
.29 0 .008 r
.61289 .2664 .61836 .25644 .63032 .25492 .62491 .26355 Mtetra
.243 0 0 r
.62491 .26355 .63032 .25492 .64235 .2532 .63699 .2604 Mtetra
.176 0 0 r
.63699 .2604 .64235 .2532 .65445 .25122 .64911 .2569 Mtetra
.083 0 0 r
.64911 .2569 .65445 .25122 .66659 .24894 .66128 .25304 Mtetra
0 0 0 r
.66128 .25304 .66659 .24894 .67879 .24631 .67348 .2488 Mtetra
.67348 .2488 .67879 .24631 .69104 .24333 .68572 .24419 Mtetra
.381 .841 .785 r
.68572 .24419 .69104 .24333 .70333 .23998 .69799 .23924 Mtetra
.53 .919 .91 r
.69799 .23924 .70333 .23998 .71566 .23631 .71029 .23399 Mtetra
.629 .933 .967 r
.71029 .23399 .71566 .23631 .72802 .23232 .72262 .2285 Mtetra
.681 .905 .975 r
.72262 .2285 .72802 .23232 .74043 .22811 .73499 .22281 Mtetra
.703 .861 .958 r
.73499 .22281 .74043 .22811 .75289 .22372 .74739 .21701 Mtetra
.707 .815 .932 r
.74739 .21701 .75289 .22372 .76539 .21923 .75983 .21113 Mtetra
.522 .709 .957 r
.09551 .43462 .10283 .44102 .11253 .43897 .10509 .43362 Mtetra
.5 .74 .98 r
.10509 .43362 .11253 .43897 .12228 .43688 .11472 .4326 Mtetra
.468 .769 .996 r
.11472 .4326 .12228 .43688 .13209 .43467 .12441 .43154 Mtetra
.424 .791 .995 r
.12441 .43154 .13209 .43467 .14197 .43229 .13417 .43039 Mtetra
.36 .797 .963 r
.13417 .43039 .14197 .43229 .15192 .42969 .14399 .4291 Mtetra
.275 .772 .887 r
.14399 .4291 .15192 .42969 .16194 .4268 .15389 .42762 Mtetra
.176 .712 .764 r
.15389 .42762 .16194 .4268 .17203 .42359 .16386 .42589 Mtetra
0 0 0 r
.16386 .42589 .17203 .42359 .18221 .42004 .17391 .42389 Mtetra
.013 0 0 r
.17391 .42389 .18221 .42004 .19246 .41611 .18405 .42157 Mtetra
.087 0 0 r
.18405 .42157 .19246 .41611 .20278 .41184 .19427 .41892 Mtetra
.144 0 0 r
.19427 .41892 .20278 .41184 .21317 .40723 .20456 .41595 Mtetra
.191 0 0 r
.20456 .41595 .21317 .40723 .22362 .40234 .21493 .41269 Mtetra
.228 0 0 r
.21493 .41269 .22362 .40234 .23413 .39721 .22536 .40918 Mtetra
.26 0 .034 r
.22536 .40918 .23413 .39721 .24468 .39193 .23585 .40548 Mtetra
.286 0 .085 r
.23585 .40548 .24468 .39193 .25526 .38658 .2464 .40164 Mtetra
.308 0 .125 r
.2464 .40164 .25526 .38658 .26587 .38125 .25699 .39768 Mtetra
.324 0 .155 r
.25699 .39768 .26587 .38125 .27651 .37602 .26763 .39362 Mtetra
.33 0 .175 r
.26763 .39362 .27651 .37602 .28717 .37079 .27833 .38931 Mtetra
.331 0 .188 r
.27833 .38931 .28717 .37079 .29788 .36548 .28909 .38471 Mtetra
.33 0 .196 r
.28909 .38471 .29788 .36548 .30864 .35975 .29991 .37981 Mtetra
.334 0 .208 r
.29991 .37981 .30864 .35975 .31946 .35349 .31078 .37472 Mtetra
.36 .012 .232 r
.31078 .37472 .31946 .35349 .33033 .34709 .32165 .37012 Mtetra
.395 .053 .264 r
.32165 .37012 .33033 .34709 .3412 .34086 .3325 .3664 Mtetra
.431 .098 .298 r
.3325 .3664 .3412 .34086 .35205 .33553 .34334 .36382 Mtetra
.46 .134 .325 r
.34334 .36382 .35205 .33553 .36288 .3314 .35416 .36239 Mtetra
.472 .152 .343 r
.35416 .36239 .36288 .3314 .3737 .32823 .36502 .36138 Mtetra
.474 .16 .352 r
.36502 .36138 .3737 .32823 .38453 .32573 .37595 .36032 Mtetra
.467 .157 .355 r
.37595 .36032 .38453 .32573 .39543 .32314 .38698 .35859 Mtetra
.455 .148 .354 r
.38698 .35859 .39543 .32314 .40639 .32006 .3981 .35584 Mtetra
.44 .135 .35 r
.3981 .35584 .40639 .32006 .41743 .31617 .40932 .35195 Mtetra
.425 .122 .345 r
.40932 .35195 .41743 .31617 .42855 .31146 .42063 .34692 Mtetra
.409 .108 .339 r
.42063 .34692 .42855 .31146 .43971 .30625 .432 .34086 Mtetra
.397 .095 .332 r
.432 .34086 .43971 .30625 .45092 .30095 .44342 .33413 Mtetra
.39 .086 .324 r
.44342 .33413 .45092 .30095 .46214 .29632 .45487 .32733 Mtetra
.388 .078 .313 r
.45487 .32733 .46214 .29632 .4734 .29265 .46634 .32094 Mtetra
.396 .077 .302 r
.46634 .32094 .4734 .29265 .48468 .2902 .47783 .31571 Mtetra
.405 .074 .287 r
.47783 .31571 .48468 .2902 .49602 .28867 .48934 .31163 Mtetra
.411 .068 .269 r
.48934 .31163 .49602 .28867 .50742 .28731 .50089 .30843 Mtetra
.412 .059 .253 r
.50089 .30843 .50742 .28731 .51889 .28582 .51249 .30574 Mtetra
.401 .042 .237 r
.51249 .30574 .51889 .28582 .53042 .28379 .52416 .30286 Mtetra
.389 .026 .222 r
.52416 .30286 .53042 .28379 .54202 .28134 .53588 .29968 Mtetra
.376 .009 .208 r
.53588 .29968 .54202 .28134 .55367 .27882 .54765 .29619 Mtetra
.361 0 .19 r
.54765 .29619 .55367 .27882 .56539 .27629 .55948 .29245 Mtetra
.346 0 .166 r
.55948 .29245 .56539 .27629 .57717 .27387 .57136 .28861 Mtetra
.325 0 .134 r
.57136 .28861 .57717 .27387 .58901 .27148 .58329 .28464 Mtetra
.297 0 .09 r
.58329 .28464 .58901 .27148 .60092 .26902 .59528 .28053 Mtetra
.258 0 .034 r
.59528 .28053 .60092 .26902 .61289 .2664 .60731 .27623 Mtetra
.203 0 0 r
.60731 .27623 .61289 .2664 .62491 .26355 .61938 .27165 Mtetra
.127 0 0 r
.61938 .27165 .62491 .26355 .63699 .2604 .63149 .26678 Mtetra
.023 0 0 r
.63149 .26678 .63699 .2604 .64911 .2569 .64364 .26156 Mtetra
0 0 0 r
.64364 .26156 .64911 .2569 .66128 .25304 .65582 .256 Mtetra
.65582 .256 .66128 .25304 .67348 .2488 .66803 .2501 Mtetra
.448 .874 .77 r
.66803 .2501 .67348 .2488 .68572 .24419 .68026 .2439 Mtetra
.586 .945 .887 r
.68026 .2439 .68572 .24419 .69799 .23924 .69252 .23744 Mtetra
.674 .959 .944 r
.69252 .23744 .69799 .23924 .71029 .23399 .7048 .23076 Mtetra
.72 .936 .958 r
.7048 .23076 .71029 .23399 .72262 .2285 .71711 .22394 Mtetra
.74 .898 .95 r
.71711 .22394 .72262 .2285 .73499 .22281 .72945 .217 Mtetra
.745 .857 .932 r
.72945 .217 .73499 .22281 .74739 .21701 .74182 .21 Mtetra
.741 .818 .912 r
.74182 .21 .74739 .21701 .75983 .21113 .75422 .20298 Mtetra
.488 .696 .961 r
.08813 .42819 .09551 .43462 .10509 .43362 .09766 .42763 Mtetra
.474 .707 .971 r
.09766 .42763 .10509 .43362 .11472 .4326 .10725 .42711 Mtetra
.458 .72 .981 r
.10725 .42711 .11472 .4326 .12441 .43154 .11689 .42659 Mtetra
.44 .734 .989 r
.11689 .42659 .12441 .43154 .13417 .43039 .12658 .42606 Mtetra
.418 .747 .994 r
.12658 .42606 .13417 .43039 .14399 .4291 .13634 .42549 Mtetra
.39 .761 .992 r
.13634 .42549 .14399 .4291 .15389 .42762 .14616 .42482 Mtetra
.356 .771 .979 r
.14616 .42482 .15389 .42762 .16386 .42589 .15606 .42401 Mtetra
.31 .771 .947 r
.15606 .42401 .16386 .42589 .17391 .42389 .16603 .42303 Mtetra
.253 .755 .888 r
.16603 .42303 .17391 .42389 .18405 .42157 .17608 .42183 Mtetra
.182 .716 .798 r
.17608 .42183 .18405 .42157 .19427 .41892 .18621 .42039 Mtetra
0 0 0 r
.18621 .42039 .19427 .41892 .20456 .41595 .19643 .41868 Mtetra
.19643 .41868 .20456 .41595 .21493 .41269 .20671 .41673 Mtetra
.045 0 0 r
.20671 .41673 .21493 .41269 .22536 .40918 .21708 .41454 Mtetra
.107 0 0 r
.21708 .41454 .22536 .40918 .23585 .40548 .22751 .41213 Mtetra
.156 0 0 r
.22751 .41213 .23585 .40548 .2464 .40164 .23801 .40952 Mtetra
.192 0 0 r
.23801 .40952 .2464 .40164 .25699 .39768 .24858 .4067 Mtetra
.218 0 0 r
.24858 .4067 .25699 .39768 .26763 .39362 .25921 .40366 Mtetra
.232 0 0 r
.25921 .40366 .26763 .39362 .27833 .38931 .26991 .40035 Mtetra
.244 0 0 r
.26991 .40035 .27833 .38931 .28909 .38471 .28068 .39675 Mtetra
.266 0 .036 r
.28068 .39675 .28909 .38471 .29991 .37981 .2915 .39311 Mtetra
.298 0 .083 r
.2915 .39311 .29991 .37981 .31078 .37472 .30235 .38961 Mtetra
.35 0 .14 r
.30235 .38961 .31078 .37472 .32165 .37012 .3132 .38681 Mtetra
.399 .017 .193 r
.3132 .38681 .32165 .37012 .3325 .3664 .32404 .38495 Mtetra
.431 .06 .232 r
.32404 .38495 .3325 .3664 .34334 .36382 .3349 .38382 Mtetra
.449 .086 .255 r
.3349 .38382 .34334 .36382 .35416 .36239 .34579 .38318 Mtetra
.447 .087 .261 r
.34579 .38318 .35416 .36239 .36502 .36138 .35676 .38232 Mtetra
.433 .075 .256 r
.35676 .38232 .36502 .36138 .37595 .36032 .36783 .38083 Mtetra
.413 .054 .243 r
.36783 .38083 .37595 .36032 .38698 .35859 .37899 .37857 Mtetra
.389 .028 .227 r
.37899 .37857 .38698 .35859 .3981 .35584 .39025 .37544 Mtetra
.366 .005 .213 r
.39025 .37544 .3981 .35584 .40932 .35195 .40159 .37155 Mtetra
.345 0 .204 r
.40159 .37155 .40932 .35195 .42063 .34692 .41301 .36689 Mtetra
.325 0 .199 r
.41301 .36689 .42063 .34692 .432 .34086 .4245 .36135 Mtetra
.309 0 .199 r
.4245 .36135 .432 .34086 .44342 .33413 .43604 .35502 Mtetra
.297 0 .199 r
.43604 .35502 .44342 .33413 .45487 .32733 .44764 .34807 Mtetra
.289 0 .195 r
.44764 .34807 .45487 .32733 .46634 .32094 .45926 .34087 Mtetra
.294 0 .189 r
.45926 .34087 .46634 .32094 .47783 .31571 .4709 .33416 Mtetra
.299 0 .173 r
.4709 .33416 .47783 .31571 .48934 .31163 .48256 .32817 Mtetra
.305 0 .148 r
.48256 .32817 .48934 .31163 .50089 .30843 .49425 .32314 Mtetra
.303 0 .116 r
.49425 .32314 .50089 .30843 .51249 .30574 .50598 .3188 Mtetra
.282 0 .074 r
.50598 .3188 .51249 .30574 .52416 .30286 .51775 .31461 Mtetra
.254 0 .03 r
.51775 .31461 .52416 .30286 .53588 .29968 .52957 .31037 Mtetra
.216 0 0 r
.52957 .31037 .53588 .29968 .54765 .29619 .54144 .30585 Mtetra
.172 0 0 r
.54144 .30585 .54765 .29619 .55948 .29245 .55336 .30103 Mtetra
.121 0 0 r
.55336 .30103 .55948 .29245 .57136 .28861 .56532 .29599 Mtetra
.054 0 0 r
.56532 .29599 .57136 .28861 .58329 .28464 .57733 .29072 Mtetra
0 0 0 r
.57733 .29072 .58329 .28464 .59528 .28053 .58937 .28524 Mtetra
.58937 .28524 .59528 .28053 .60731 .27623 .60145 .27953 Mtetra
.60145 .27953 .60731 .27623 .61938 .27165 .61356 .27357 Mtetra
.416 .851 .732 r
.61356 .27357 .61938 .27165 .63149 .26678 .62571 .26734 Mtetra
.544 .928 .844 r
.62571 .26734 .63149 .26678 .64364 .26156 .63788 .26082 Mtetra
.64 .961 .913 r
.63788 .26082 .64364 .26156 .65582 .256 .65008 .25405 Mtetra
.701 .961 .945 r
.65008 .25405 .65582 .256 .66803 .2501 .6623 .24704 Mtetra
.736 .941 .951 r
.6623 .24704 .66803 .2501 .68026 .2439 .67455 .23983 Mtetra
.753 .914 .946 r
.67455 .23983 .68026 .2439 .69252 .23744 .68682 .23246 Mtetra
.76 .887 .935 r
.68682 .23246 .69252 .23744 .7048 .23076 .69911 .22499 Mtetra
.761 .862 .924 r
.69911 .22499 .7048 .23076 .71711 .22394 .71143 .21745 Mtetra
.759 .839 .913 r
.71143 .21745 .71711 .22394 .72945 .217 .72378 .20989 Mtetra
.756 .82 .902 r
.72378 .20989 .72945 .217 .74182 .21 .73616 .20231 Mtetra
.751 .802 .893 r
.73616 .20231 .74182 .21 .75422 .20298 .74857 .19475 Mtetra
.495 .699 .96 r
.0807 .4217 .08813 .42819 .09766 .42763 .09026 .42103 Mtetra
.492 .694 .958 r
.09026 .42103 .09766 .42763 .10725 .42711 .09987 .42042 Mtetra
.49 .691 .957 r
.09987 .42042 .10725 .42711 .11689 .42659 .10952 .41986 Mtetra
.487 .689 .957 r
.10952 .41986 .11689 .42659 .12658 .42606 .11923 .41934 Mtetra
.483 .688 .958 r
.11923 .41934 .12658 .42606 .13634 .42549 .12898 .41886 Mtetra
.48 .691 .961 r
.12898 .41886 .13634 .42549 .14616 .42482 .1388 .41838 Mtetra
.477 .698 .965 r
.1388 .41838 .14616 .42482 .15606 .42401 .14867 .41788 Mtetra
.474 .708 .972 r
.14867 .41788 .15606 .42401 .16603 .42303 .15861 .41731 Mtetra
.471 .723 .979 r
.15861 .41731 .16603 .42303 .17608 .42183 .16862 .41663 Mtetra
.466 .741 .988 r
.16862 .41663 .17608 .42183 .18621 .42039 .17871 .41582 Mtetra
.458 .761 .995 r
.17871 .41582 .18621 .42039 .19643 .41868 .18887 .41483 Mtetra
.444 .782 .998 r
.18887 .41483 .19643 .41868 .20671 .41673 .1991 .41367 Mtetra
.423 .799 .993 r
.1991 .41367 .20671 .41673 .21708 .41454 .20941 .4123 Mtetra
.395 .81 .975 r
.20941 .4123 .21708 .41454 .22751 .41213 .2198 .41073 Mtetra
.361 .812 .944 r
.2198 .41073 .22751 .41213 .23801 .40952 .23027 .40893 Mtetra
.325 .804 .901 r
.23027 .40893 .23801 .40952 .24858 .4067 .24081 .40688 Mtetra
.288 .787 .849 r
.24081 .40688 .24858 .4067 .25921 .40366 .25142 .40458 Mtetra
.245 .759 .787 r
.25142 .40458 .25921 .40366 .26991 .40035 .2621 .40208 Mtetra
.185 .712 .707 r
.2621 .40208 .26991 .40035 .28068 .39675 .27285 .39945 Mtetra
0 0 0 r
.27285 .39945 .28068 .39675 .2915 .39311 .28363 .39697 Mtetra
.051 0 0 r
.28363 .39697 .2915 .39311 .30235 .38961 .29445 .39486 Mtetra
.18 0 0 r
.29445 .39486 .30235 .38961 .3132 .38681 .30528 .39327 Mtetra
.268 0 0 r
.30528 .39327 .3132 .38681 .32404 .38495 .31613 .39222 Mtetra
.289 0 0 r
.31613 .39222 .32404 .38495 .3349 .38382 .32706 .39111 Mtetra
.264 0 0 r
.32706 .39111 .3349 .38382 .34579 .38318 .33807 .38958 Mtetra
.175 0 0 r
.33807 .38958 .34579 .38318 .35676 .38232 .34919 .38725 Mtetra
.02 0 0 r
.34919 .38725 .35676 .38232 .36783 .38083 .36041 .38399 Mtetra
0 0 0 r
.36041 .38399 .36783 .38083 .37899 .37857 .37171 .38025 Mtetra
.316 .801 .76 r
.37171 .38025 .37899 .37857 .39025 .37544 .38306 .37625 Mtetra
.379 .843 .834 r
.38306 .37625 .39025 .37544 .40159 .37155 .39446 .37233 Mtetra
.368 .837 .831 r
.39446 .37233 .40159 .37155 .41301 .36689 .40591 .3685 Mtetra
.32 .804 .762 r
.40591 .3685 .41301 .36689 .4245 .36135 .41741 .3644 Mtetra
0 0 0 r
.41741 .3644 .4245 .36135 .43604 .35502 .42897 .35981 Mtetra
.42897 .35981 .43604 .35502 .44764 .34807 .44061 .3543 Mtetra
.44061 .3543 .44764 .34807 .45926 .34087 .4523 .34796 Mtetra
.4523 .34796 .45926 .34087 .4709 .33416 .46403 .34119 Mtetra
.46403 .34119 .4709 .33416 .48256 .32817 .4758 .33435 Mtetra
.4758 .33435 .48256 .32817 .49425 .32314 .48758 .32804 Mtetra
.48758 .32804 .49425 .32314 .50598 .3188 .4994 .32226 Mtetra
.4994 .32226 .50598 .3188 .51775 .31461 .51125 .31684 Mtetra
.343 .808 .712 r
.51125 .31684 .51775 .31461 .52957 .31037 .52315 .31158 Mtetra
.44 .875 .806 r
.52315 .31158 .52957 .31037 .54144 .30585 .53509 .30617 Mtetra
.522 .918 .873 r
.53509 .30617 .54144 .30585 .55336 .30103 .54706 .30055 Mtetra
.59 .943 .917 r
.54706 .30055 .55336 .30103 .56532 .29599 .55908 .29466 Mtetra
.647 .952 .945 r
.55908 .29466 .56532 .29599 .57733 .29072 .57113 .28852 Mtetra
.689 .946 .959 r
.57113 .28852 .57733 .29072 .58937 .28524 .58322 .28213 Mtetra
.719 .929 .96 r
.58322 .28213 .58937 .28524 .60145 .27953 .59533 .27551 Mtetra
.737 .906 .953 r
.59533 .27551 .60145 .27953 .61356 .27357 .60748 .26868 Mtetra
.748 .88 .94 r
.60748 .26868 .61356 .27357 .62571 .26734 .61965 .26165 Mtetra
.753 .856 .926 r
.61965 .26165 .62571 .26734 .63788 .26082 .63185 .25443 Mtetra
.755 .835 .913 r
.63185 .25443 .63788 .26082 .65008 .25405 .64408 .24705 Mtetra
.755 .817 .901 r
.64408 .24705 .65008 .25405 .6623 .24704 .65633 .23955 Mtetra
.754 .803 .892 r
.65633 .23955 .6623 .24704 .67455 .23983 .6686 .23197 Mtetra
.752 .793 .886 r
.6686 .23197 .67455 .23983 .68682 .23246 .6809 .22434 Mtetra
.751 .786 .882 r
.6809 .22434 .68682 .23246 .69911 .22499 .69323 .2167 Mtetra
.748 .782 .88 r
.69323 .2167 .69911 .22499 .71143 .21745 .70559 .20909 Mtetra
.747 .781 .88 r
.70559 .20909 .71143 .21745 .72378 .20989 .71799 .20151 Mtetra
.746 .781 .882 r
.71799 .20151 .72378 .20989 .73616 .20231 .73041 .19396 Mtetra
.745 .783 .884 r
.73041 .19396 .73616 .20231 .74857 .19475 .74288 .18646 Mtetra
.547 .718 .953 r
.07322 .41517 .0807 .4217 .09026 .42103 .08289 .41373 Mtetra
.551 .695 .935 r
.08289 .41373 .09026 .42103 .09987 .42042 .09261 .41235 Mtetra
.553 .672 .917 r
.09261 .41235 .09987 .42042 .10952 .41986 .10237 .41103 Mtetra
.553 .651 .9 r
.10237 .41103 .10952 .41986 .11923 .41934 .11217 .4098 Mtetra
.551 .632 .885 r
.11217 .4098 .11923 .41934 .12898 .41886 .12201 .40866 Mtetra
.551 .616 .871 r
.12201 .40866 .12898 .41886 .1388 .41838 .1319 .40758 Mtetra
.55 .602 .859 r
.1319 .40758 .1388 .41838 .14867 .41788 .14184 .40655 Mtetra
.55 .592 .848 r
.14184 .40655 .14867 .41788 .15861 .41731 .15183 .40553 Mtetra
.552 .584 .84 r
.15183 .40553 .15861 .41731 .16862 .41663 .16188 .4045 Mtetra
.554 .579 .833 r
.16188 .4045 .16862 .41663 .17871 .41582 .17199 .40341 Mtetra
.557 .576 .828 r
.17199 .40341 .17871 .41582 .18887 .41483 .18216 .40224 Mtetra
.561 .575 .825 r
.18216 .40224 .18887 .41483 .1991 .41367 .19241 .40096 Mtetra
.565 .576 .823 r
.19241 .40096 .1991 .41367 .20941 .4123 .20272 .39954 Mtetra
.57 .578 .822 r
.20272 .39954 .20941 .4123 .2198 .41073 .21311 .39798 Mtetra
.575 .581 .822 r
.21311 .39798 .2198 .41073 .23027 .40893 .22356 .39625 Mtetra
.581 .586 .823 r
.22356 .39625 .23027 .40893 .24081 .40688 .23409 .39434 Mtetra
.586 .592 .825 r
.23409 .39434 .24081 .40688 .25142 .40458 .24469 .39226 Mtetra
.59 .598 .829 r
.24469 .39226 .25142 .40458 .2621 .40208 .25535 .39007 Mtetra
.592 .606 .834 r
.25535 .39007 .2621 .40208 .27285 .39945 .26607 .3878 Mtetra
.59 .613 .843 r
.26607 .3878 .27285 .39945 .28363 .39697 .27684 .38559 Mtetra
.587 .617 .849 r
.27684 .38559 .28363 .39697 .29445 .39486 .28766 .38347 Mtetra
.592 .62 .849 r
.28766 .38347 .29445 .39486 .30528 .39327 .29855 .38121 Mtetra
.602 .612 .834 r
.29855 .38121 .30528 .39327 .31613 .39222 .30951 .37858 Mtetra
.624 .596 .802 r
.30951 .37858 .31613 .39222 .32706 .39111 .32059 .37499 Mtetra
.64 .572 .763 r
.32059 .37499 .32706 .39111 .33807 .38958 .33179 .37019 Mtetra
.643 .542 .726 r
.33179 .37019 .33807 .38958 .34919 .38725 .34309 .36434 Mtetra
.638 .515 .697 r
.34309 .36434 .34919 .38725 .36041 .38399 .35446 .3578 Mtetra
.622 .488 .677 r
.35446 .3578 .36041 .38399 .37171 .38025 .36584 .35155 Mtetra
.604 .465 .666 r
.36584 .35155 .37171 .38025 .38306 .37625 .37722 .34616 Mtetra
.582 .445 .66 r
.37722 .34616 .38306 .37625 .39446 .37233 .38857 .34219 Mtetra
.563 .433 .661 r
.38857 .34219 .39446 .37233 .40591 .3685 .39991 .33964 Mtetra
.552 .431 .668 r
.39991 .33964 .40591 .3685 .41741 .3644 .41128 .33797 Mtetra
.549 .441 .683 r
.41128 .33797 .41741 .3644 .42897 .35981 .4227 .3366 Mtetra
.565 .47 .705 r
.4227 .3366 .42897 .35981 .44061 .3543 .43422 .33453 Mtetra
.591 .512 .734 r
.43422 .33453 .44061 .3543 .4523 .34796 .44582 .33141 Mtetra
.626 .565 .766 r
.44582 .33141 .4523 .34796 .46403 .34119 .4575 .32708 Mtetra
.658 .613 .793 r
.4575 .32708 .46403 .34119 .4758 .33435 .46925 .32176 Mtetra
.675 .646 .813 r
.46925 .32176 .4758 .33435 .48758 .32804 .48105 .31606 Mtetra
.682 .66 .822 r
.48105 .31606 .48758 .32804 .4994 .32226 .49288 .31022 Mtetra
.68 .659 .823 r
.49288 .31022 .4994 .32226 .51125 .31684 .50476 .30446 Mtetra
.676 .652 .818 r
.50476 .30446 .51125 .31684 .52315 .31158 .51667 .29875 Mtetra
.675 .644 .811 r
.51667 .29875 .52315 .31158 .53509 .30617 .52863 .29296 Mtetra
.675 .638 .805 r
.52863 .29296 .53509 .30617 .54706 .30055 .54062 .28704 Mtetra
.677 .635 .8 r
.54062 .28704 .54706 .30055 .55908 .29466 .55265 .28094 Mtetra
.679 .633 .797 r
.55265 .28094 .55908 .29466 .57113 .28852 .56472 .27465 Mtetra
.682 .633 .794 r
.56472 .27465 .57113 .28852 .58322 .28213 .57682 .26818 Mtetra
.684 .633 .792 r
.57682 .26818 .58322 .28213 .59533 .27551 .58895 .26154 Mtetra
.687 .635 .792 r
.58895 .26154 .59533 .27551 .60748 .26868 .60111 .25475 Mtetra
.69 .637 .792 r
.60111 .25475 .60748 .26868 .61965 .26165 .61331 .24784 Mtetra
.692 .641 .794 r
.61331 .24784 .61965 .26165 .63185 .25443 .62553 .24083 Mtetra
.695 .646 .797 r
.62553 .24083 .63185 .25443 .64408 .24705 .63779 .23376 Mtetra
.698 .652 .801 r
.63779 .23376 .64408 .24705 .65633 .23955 .65008 .22665 Mtetra
.7 .661 .808 r
.65008 .22665 .65633 .23955 .6686 .23197 .6624 .21954 Mtetra
.703 .671 .816 r
.6624 .21954 .6686 .23197 .6809 .22434 .67476 .21247 Mtetra
.706 .683 .826 r
.67476 .21247 .6809 .22434 .69323 .2167 .68715 .20545 Mtetra
.709 .698 .837 r
.68715 .20545 .69323 .2167 .70559 .20909 .69958 .19852 Mtetra
.712 .715 .85 r
.69958 .19852 .70559 .20909 .71799 .20151 .71206 .19166 Mtetra
.716 .734 .865 r
.71206 .19166 .71799 .20151 .73041 .19396 .72457 .18486 Mtetra
.72 .755 .88 r
.72457 .18486 .73041 .19396 .74288 .18646 .73713 .1781 Mtetra
.613 .74 .936 r
.06568 .40859 .07322 .41517 .08289 .41373 .07553 .40595 Mtetra
.613 .703 .909 r
.07553 .40595 .08289 .41373 .09261 .41235 .08542 .40337 Mtetra
.61 .67 .883 r
.08542 .40337 .09261 .41235 .10237 .41103 .09535 .40086 Mtetra
.604 .639 .859 r
.09535 .40086 .10237 .41103 .11217 .4098 .1053 .39844 Mtetra
.598 .612 .837 r
.1053 .39844 .11217 .4098 .12201 .40866 .11529 .39615 Mtetra
.592 .588 .817 r
.11529 .39615 .12201 .40866 .1319 .40758 .12531 .39396 Mtetra
.586 .568 .8 r
.12531 .39396 .1319 .40758 .14184 .40655 .13537 .39187 Mtetra
.582 .55 .784 r
.13537 .39187 .14184 .40655 .15183 .40553 .14547 .38985 Mtetra
.579 .536 .771 r
.14547 .38985 .15183 .40553 .16188 .4045 .15561 .38788 Mtetra
.576 .524 .76 r
.15561 .38788 .16188 .4045 .17199 .40341 .1658 .38592 Mtetra
.575 .514 .75 r
.1658 .38592 .17199 .40341 .18216 .40224 .17605 .38395 Mtetra
.574 .506 .741 r
.17605 .38395 .18216 .40224 .19241 .40096 .18635 .38194 Mtetra
.574 .5 .734 r
.18635 .38194 .19241 .40096 .20272 .39954 .19671 .37987 Mtetra
.574 .494 .727 r
.19671 .37987 .20272 .39954 .21311 .39798 .20713 .37773 Mtetra
.574 .49 .722 r
.20713 .37773 .21311 .39798 .22356 .39625 .21761 .3755 Mtetra
.574 .487 .718 r
.21761 .3755 .22356 .39625 .23409 .39434 .22814 .37322 Mtetra
.575 .485 .715 r
.22814 .37322 .23409 .39434 .24469 .39226 .23874 .37089 Mtetra
.575 .483 .713 r
.23874 .37089 .24469 .39226 .25535 .39007 .24939 .36852 Mtetra
.575 .482 .712 r
.24939 .36852 .25535 .39007 .26607 .3878 .26009 .36612 Mtetra
.577 .483 .711 r
.26009 .36612 .26607 .3878 .27684 .38559 .27086 .36359 Mtetra
.581 .484 .709 r
.27086 .36359 .27684 .38559 .28766 .38347 .2817 .36079 Mtetra
.593 .487 .703 r
.2817 .36079 .28766 .38347 .29855 .38121 .29265 .35723 Mtetra
.607 .488 .692 r
.29265 .35723 .29855 .38121 .30951 .37858 .30372 .35258 Mtetra
.622 .487 .677 r
.30372 .35258 .30951 .37858 .32059 .37499 .31493 .34642 Mtetra
.632 .483 .662 r
.31493 .34642 .32059 .37499 .33179 .37019 .32627 .33872 Mtetra
.632 .473 .649 r
.32627 .33872 .33179 .37019 .34309 .36434 .33768 .33011 Mtetra
.627 .461 .639 r
.33768 .33011 .34309 .36434 .35446 .3578 .34912 .32126 Mtetra
.612 .445 .632 r
.34912 .32126 .35446 .3578 .36584 .35155 .36052 .31335 Mtetra
.592 .427 .627 r
.36052 .31335 .36584 .35155 .37722 .34616 .37186 .3071 Mtetra
.568 .408 .625 r
.37186 .3071 .37722 .34616 .38857 .34219 .38313 .30307 Mtetra
.543 .391 .624 r
.38313 .30307 .38857 .34219 .39991 .33964 .39435 .30127 Mtetra
.524 .379 .626 r
.39435 .30127 .39991 .33964 .41128 .33797 .40558 .30115 Mtetra
.512 .375 .631 r
.40558 .30115 .41128 .33797 .4227 .3366 .41684 .30198 Mtetra
.515 .384 .641 r
.41684 .30198 .4227 .3366 .43422 .33453 .4282 .30259 Mtetra
.528 .402 .653 r
.4282 .30259 .43422 .33453 .44582 .33141 .43966 .3023 Mtetra
.552 .43 .667 r
.43966 .3023 .44582 .33141 .4575 .32708 .45124 .30046 Mtetra
.579 .459 .681 r
.45124 .30046 .4575 .32708 .46925 .32176 .46291 .2971 Mtetra
.6 .484 .693 r
.46291 .2971 .46925 .32176 .48105 .31606 .47466 .29262 Mtetra
.615 .501 .7 r
.47466 .29262 .48105 .31606 .49288 .31022 .48647 .28738 Mtetra
.621 .508 .704 r
.48647 .28738 .49288 .31022 .50476 .30446 .49832 .28186 Mtetra
.624 .512 .706 r
.49832 .28186 .50476 .30446 .51667 .29875 .51021 .2762 Mtetra
.624 .513 .706 r
.51021 .2762 .51667 .29875 .52863 .29296 .52215 .27049 Mtetra
.625 .514 .707 r
.52215 .27049 .52863 .29296 .54062 .28704 .53412 .26475 Mtetra
.627 .516 .709 r
.53412 .26475 .54062 .28704 .55265 .28094 .54614 .25895 Mtetra
.629 .52 .711 r
.54614 .25895 .55265 .28094 .56472 .27465 .55819 .25307 Mtetra
.632 .525 .715 r
.55819 .25307 .56472 .27465 .57682 .26818 .57028 .24711 Mtetra
.635 .531 .719 r
.57028 .24711 .57682 .26818 .58895 .26154 .58242 .24106 Mtetra
.638 .538 .724 r
.58242 .24106 .58895 .26154 .60111 .25475 .59459 .23494 Mtetra
.642 .546 .73 r
.59459 .23494 .60111 .25475 .61331 .24784 .6068 .22878 Mtetra
.646 .555 .737 r
.6068 .22878 .61331 .24784 .62553 .24083 .61904 .22259 Mtetra
.65 .565 .746 r
.61904 .22259 .62553 .24083 .63779 .23376 .63133 .21641 Mtetra
.653 .577 .756 r
.63133 .21641 .63779 .23376 .65008 .22665 .64367 .21026 Mtetra
.657 .59 .768 r
.64367 .21026 .65008 .22665 .6624 .21954 .65604 .20418 Mtetra
.661 .606 .782 r
.65604 .20418 .6624 .21954 .67476 .21247 .66846 .19819 Mtetra
.665 .624 .798 r
.66846 .19819 .67476 .21247 .68715 .20545 .68093 .19231 Mtetra
.669 .645 .817 r
.68093 .19231 .68715 .20545 .69958 .19852 .69346 .18654 Mtetra
.674 .669 .837 r
.69346 .18654 .69958 .19852 .71206 .19166 .70603 .18085 Mtetra
.679 .697 .86 r
.70603 .18085 .71206 .19166 .72457 .18486 .71866 .17524 Mtetra
.683 .729 .885 r
.71866 .17524 .72457 .18486 .73713 .1781 .73134 .16968 Mtetra
.674 .755 .912 r
.05808 .40196 .06568 .40859 .07553 .40595 .06816 .39789 Mtetra
.667 .713 .883 r
.06816 .39789 .07553 .40595 .08542 .40337 .07826 .39387 Mtetra
.658 .675 .855 r
.07826 .39387 .08542 .40337 .09535 .40086 .08838 .38992 Mtetra
.647 .641 .83 r
.08838 .38992 .09535 .40086 .1053 .39844 .09854 .38606 Mtetra
.636 .611 .808 r
.09854 .38606 .1053 .39844 .11529 .39615 .10871 .38234 Mtetra
.627 .585 .788 r
.10871 .38234 .11529 .39615 .12531 .39396 .1189 .37874 Mtetra
.617 .562 .77 r
.1189 .37874 .12531 .39396 .13537 .39187 .12912 .37528 Mtetra
.609 .542 .754 r
.12912 .37528 .13537 .39187 .14547 .38985 .13936 .37192 Mtetra
.603 .525 .74 r
.13936 .37192 .14547 .38985 .15561 .38788 .14964 .36866 Mtetra
.597 .51 .727 r
.14964 .36866 .15561 .38788 .1658 .38592 .15995 .36545 Mtetra
.592 .498 .716 r
.15995 .36545 .1658 .38592 .17605 .38395 .17031 .36228 Mtetra
.589 .487 .707 r
.17031 .36228 .17605 .38395 .18635 .38194 .1807 .35913 Mtetra
.586 .478 .698 r
.1807 .35913 .18635 .38194 .19671 .37987 .19114 .35596 Mtetra
.584 .471 .69 r
.19114 .35596 .19671 .37987 .20713 .37773 .20163 .35278 Mtetra
.581 .464 .684 r
.20163 .35278 .20713 .37773 .21761 .3755 .21217 .34957 Mtetra
.579 .457 .678 r
.21217 .34957 .21761 .3755 .22814 .37322 .22275 .34637 Mtetra
.577 .452 .673 r
.22275 .34637 .22814 .37322 .23874 .37089 .23338 .34318 Mtetra
.575 .446 .668 r
.23338 .34318 .23874 .37089 .24939 .36852 .24405 .34003 Mtetra
.573 .442 .664 r
.24405 .34003 .24939 .36852 .26009 .36612 .25476 .33691 Mtetra
.572 .439 .661 r
.25476 .33691 .26009 .36612 .27086 .36359 .26553 .33374 Mtetra
.573 .437 .658 r
.26553 .33374 .27086 .36359 .2817 .36079 .27636 .33041 Mtetra
.579 .439 .656 r
.27636 .33041 .2817 .36079 .29265 .35723 .28728 .32659 Mtetra
.587 .444 .654 r
.28728 .32659 .29265 .35723 .30372 .35258 .29828 .3221 Mtetra
.597 .452 .655 r
.29828 .3221 .30372 .35258 .31493 .34642 .30939 .31682 Mtetra
.608 .463 .658 r
.30939 .31682 .31493 .34642 .32627 .33872 .32057 .31082 Mtetra
.616 .475 .667 r
.32057 .31082 .32627 .33872 .33768 .33011 .3318 .30458 Mtetra
.622 .489 .68 r
.3318 .30458 .33768 .33011 .34912 .32126 .34306 .29845 Mtetra
.624 .506 .699 r
.34306 .29845 .34912 .32126 .36052 .31335 .35432 .29283 Mtetra
.621 .52 .719 r
.35432 .29283 .36052 .31335 .37186 .3071 .36557 .28795 Mtetra
.611 .526 .734 r
.36557 .28795 .37186 .3071 .38313 .30307 .37683 .28389 Mtetra
.595 .517 .736 r
.37683 .28389 .38313 .30307 .39435 .30127 .3881 .28063 Mtetra
.576 .493 .724 r
.3881 .28063 .39435 .30127 .40558 .30115 .39939 .27812 Mtetra
.562 .467 .705 r
.39939 .27812 .40558 .30115 .41684 .30198 .41072 .27613 Mtetra
.556 .447 .685 r
.41072 .27613 .41684 .30198 .4282 .30259 .42211 .27425 Mtetra
.556 .435 .67 r
.42211 .27425 .4282 .30259 .43966 .3023 .43358 .27215 Mtetra
.564 .433 .661 r
.43358 .27215 .43966 .3023 .45124 .30046 .44512 .26931 Mtetra
.573 .435 .656 r
.44512 .26931 .45124 .30046 .46291 .2971 .45674 .26569 Mtetra
.581 .44 .654 r
.45674 .26569 .46291 .2971 .47466 .29262 .46843 .26138 Mtetra
.587 .445 .655 r
.46843 .26138 .47466 .29262 .48647 .28738 .48018 .25658 Mtetra
.59 .449 .657 r
.48018 .25658 .48647 .28738 .49832 .28186 .49197 .2516 Mtetra
.592 .452 .66 r
.49197 .2516 .49832 .28186 .51021 .2762 .50381 .24657 Mtetra
.593 .455 .663 r
.50381 .24657 .51021 .2762 .52215 .27049 .51569 .24157 Mtetra
.594 .459 .667 r
.51569 .24157 .52215 .27049 .53412 .26475 .52762 .2366 Mtetra
.596 .464 .672 r
.52762 .2366 .53412 .26475 .54614 .25895 .5396 .23165 Mtetra
.598 .469 .677 r
.5396 .23165 .54614 .25895 .55819 .25307 .55163 .22669 Mtetra
.6 .476 .682 r
.55163 .22669 .55819 .25307 .57028 .24711 .5637 .2217 Mtetra
.603 .483 .689 r
.5637 .2217 .57028 .24711 .58242 .24106 .57582 .21669 Mtetra
.606 .491 .696 r
.57582 .21669 .58242 .24106 .59459 .23494 .58799 .21166 Mtetra
.61 .5 .704 r
.58799 .21166 .59459 .23494 .6068 .22878 .6002 .20665 Mtetra
.613 .51 .714 r
.6002 .20665 .6068 .22878 .61904 .22259 .61247 .20166 Mtetra
.616 .522 .725 r
.61247 .20166 .61904 .22259 .63133 .21641 .62479 .19673 Mtetra
.619 .534 .737 r
.62479 .19673 .63133 .21641 .64367 .21026 .63716 .19189 Mtetra
.622 .549 .751 r
.63716 .19189 .64367 .21026 .65604 .20418 .64959 .18715 Mtetra
.625 .566 .768 r
.64959 .18715 .65604 .20418 .66846 .19819 .66208 .18255 Mtetra
.628 .585 .787 r
.66208 .18255 .66846 .19819 .68093 .19231 .67464 .17807 Mtetra
.63 .608 .809 r
.67464 .17807 .68093 .19231 .69346 .18654 .68726 .17373 Mtetra
.633 .635 .834 r
.68726 .17373 .69346 .18654 .70603 .18085 .69994 .16948 Mtetra
.636 .666 .862 r
.69994 .16948 .70603 .18085 .71866 .17524 .71269 .16531 Mtetra
.638 .703 .893 r
.71269 .16531 .71866 .17524 .73134 .16968 .7255 .16118 Mtetra
.719 .764 .888 r
.05043 .39529 .05808 .40196 .06816 .39789 .06073 .3898 Mtetra
.708 .724 .863 r
.06073 .3898 .06816 .39789 .07826 .39387 .07105 .38435 Mtetra
.696 .688 .839 r
.07105 .38435 .07826 .39387 .08838 .38992 .08138 .37897 Mtetra
.683 .656 .817 r
.08138 .37897 .08838 .38992 .09854 .38606 .09173 .37369 Mtetra
.671 .627 .797 r
.09173 .37369 .09854 .38606 .10871 .38234 .1021 .36854 Mtetra
.659 .601 .779 r
.1021 .36854 .10871 .38234 .1189 .37874 .11247 .36352 Mtetra
.648 .578 .763 r
.11247 .36352 .1189 .37874 .12912 .37528 .12286 .35865 Mtetra
.638 .557 .748 r
.12286 .35865 .12912 .37528 .13936 .37192 .13327 .35391 Mtetra
.629 .539 .734 r
.13327 .35391 .13936 .37192 .14964 .36866 .14369 .34929 Mtetra
.621 .524 .722 r
.14369 .34929 .14964 .36866 .15995 .36545 .15414 .34477 Mtetra
.615 .51 .711 r
.15414 .34477 .15995 .36545 .17031 .36228 .16461 .34032 Mtetra
.609 .498 .702 r
.16461 .34032 .17031 .36228 .1807 .35913 .17512 .33593 Mtetra
.604 .487 .693 r
.17512 .33593 .1807 .35913 .19114 .35596 .18565 .33157 Mtetra
.6 .478 .685 r
.18565 .33157 .19114 .35596 .20163 .35278 .19623 .32723 Mtetra
.596 .47 .678 r
.19623 .32723 .20163 .35278 .21217 .34957 .20684 .32293 Mtetra
.593 .462 .672 r
.20684 .32293 .21217 .34957 .22275 .34637 .21748 .31866 Mtetra
.589 .455 .667 r
.21748 .31866 .22275 .34637 .23338 .34318 .22816 .31445 Mtetra
.586 .449 .661 r
.22816 .31445 .23338 .34318 .24405 .34003 .23887 .31032 Mtetra
.582 .443 .657 r
.23887 .31032 .24405 .34003 .25476 .33691 .24961 .30629 Mtetra
.579 .438 .653 r
.24961 .30629 .25476 .33691 .26553 .33374 .26039 .30234 Mtetra
.577 .433 .65 r
.26039 .30234 .26553 .33374 .27636 .33041 .27121 .29845 Mtetra
.575 .43 .647 r
.27121 .29845 .27636 .33041 .28728 .32659 .28206 .29461 Mtetra
.574 .43 .647 r
.28206 .29461 .28728 .32659 .29828 .3221 .29296 .29084 Mtetra
.571 .431 .651 r
.29296 .29084 .29828 .3221 .30939 .31682 .30388 .28735 Mtetra
.569 .436 .66 r
.30388 .28735 .30939 .31682 .32057 .31082 .31483 .28424 Mtetra
.566 .447 .677 r
.31483 .28424 .32057 .31082 .3318 .30458 .32579 .28166 Mtetra
.565 .468 .703 r
.32579 .28166 .3318 .30458 .34306 .29845 .33678 .27947 Mtetra
.577 .507 .74 r
.33678 .27947 .34306 .29845 .35432 .29283 .34785 .27707 Mtetra
.598 .555 .777 r
.34785 .27707 .35432 .29283 .36557 .28795 .359 .27407 Mtetra
.632 .6 .799 r
.359 .27407 .36557 .28795 .37683 .28389 .37027 .26997 Mtetra
.658 .612 .792 r
.37027 .26997 .37683 .28389 .3881 .28063 .38163 .26475 Mtetra
.658 .587 .764 r
.38163 .26475 .3881 .28063 .39939 .27812 .39306 .25893 Mtetra
.644 .546 .729 r
.39306 .25893 .39939 .27812 .41072 .27613 .40453 .2529 Mtetra
.621 .503 .697 r
.40453 .2529 .41072 .27613 .42211 .27425 .41602 .24726 Mtetra
.601 .47 .674 r
.41602 .24726 .42211 .27425 .43358 .27215 .42753 .24213 Mtetra
.589 .449 .659 r
.42753 .24213 .43358 .27215 .44512 .26931 .43908 .23739 Mtetra
.581 .437 .651 r
.43908 .23739 .44512 .26931 .45674 .26569 .45066 .23293 Mtetra
.578 .433 .647 r
.45066 .23293 .45674 .26569 .46843 .26138 .46229 .22854 Mtetra
.578 .432 .647 r
.46229 .22854 .46843 .26138 .48018 .25658 .47396 .2242 Mtetra
.577 .434 .65 r
.47396 .2242 .48018 .25658 .49197 .2516 .48569 .21992 Mtetra
.578 .437 .653 r
.48569 .21992 .49197 .2516 .50381 .24657 .49746 .21572 Mtetra
.578 .44 .657 r
.49746 .21572 .50381 .24657 .51569 .24157 .50929 .21162 Mtetra
.578 .444 .662 r
.50929 .21162 .51569 .24157 .52762 .2366 .52116 .20759 Mtetra
.579 .449 .667 r
.52116 .20759 .52762 .2366 .5396 .23165 .5331 .20362 Mtetra
.581 .454 .673 r
.5331 .20362 .5396 .23165 .55163 .22669 .54508 .1997 Mtetra
.582 .461 .679 r
.54508 .1997 .55163 .22669 .5637 .2217 .55713 .19579 Mtetra
.584 .468 .687 r
.55713 .19579 .5637 .2217 .57582 .21669 .56923 .19192 Mtetra
.586 .476 .695 r
.56923 .19192 .57582 .21669 .58799 .21166 .58139 .18808 Mtetra
.588 .485 .704 r
.58139 .18808 .58799 .21166 .6002 .20665 .59361 .18429 Mtetra
.59 .495 .715 r
.59361 .18429 .6002 .20665 .61247 .20166 .60589 .18058 Mtetra
.592 .506 .727 r
.60589 .18058 .61247 .20166 .62479 .19673 .61824 .17696 Mtetra
.593 .519 .74 r
.61824 .17696 .62479 .19673 .63716 .19189 .63065 .17347 Mtetra
.594 .533 .756 r
.63065 .17347 .63716 .19189 .64959 .18715 .64313 .17011 Mtetra
.594 .549 .774 r
.64313 .17011 .64959 .18715 .66208 .18255 .65569 .16691 Mtetra
.594 .568 .794 r
.65569 .16691 .66208 .18255 .67464 .17807 .66832 .16384 Mtetra
.594 .59 .817 r
.66832 .16384 .67464 .17807 .68726 .17373 .68102 .16091 Mtetra
.593 .615 .843 r
.68102 .16091 .68726 .17373 .69994 .16948 .69381 .15808 Mtetra
.591 .645 .872 r
.69381 .15808 .69994 .16948 .71269 .16531 .70667 .15533 Mtetra
.588 .679 .904 r
.70667 .15533 .71269 .16531 .7255 .16118 .71961 .15261 Mtetra
.746 .767 .87 r
.04273 .38856 .05043 .39529 .06073 .3898 .05321 .38196 Mtetra
.736 .738 .852 r
.05321 .38196 .06073 .3898 .07105 .38435 .06371 .3754 Mtetra
.726 .71 .836 r
.06371 .3754 .07105 .38435 .08138 .37897 .07422 .36891 Mtetra
.714 .685 .82 r
.07422 .36891 .08138 .37897 .09173 .37369 .08474 .36251 Mtetra
.703 .661 .805 r
.08474 .36251 .09173 .37369 .1021 .36854 .09526 .35623 Mtetra
.692 .638 .791 r
.09526 .35623 .1021 .36854 .11247 .36352 .10579 .3501 Mtetra
.681 .617 .778 r
.10579 .3501 .11247 .36352 .12286 .35865 .11632 .34411 Mtetra
.67 .598 .766 r
.11632 .34411 .12286 .35865 .13327 .35391 .12687 .33826 Mtetra
.661 .581 .754 r
.12687 .33826 .13327 .35391 .14369 .34929 .13742 .33254 Mtetra
.652 .565 .744 r
.13742 .33254 .14369 .34929 .15414 .34477 .14799 .32695 Mtetra
.645 .551 .734 r
.14799 .32695 .15414 .34477 .16461 .34032 .15857 .32148 Mtetra
.638 .538 .725 r
.15857 .32148 .16461 .34032 .17512 .33593 .16917 .31611 Mtetra
.632 .527 .717 r
.16917 .31611 .17512 .33593 .18565 .33157 .17979 .31083 Mtetra
.626 .517 .71 r
.17979 .31083 .18565 .33157 .19623 .32723 .19043 .30564 Mtetra
.621 .508 .704 r
.19043 .30564 .19623 .32723 .20684 .32293 .2011 .30054 Mtetra
.617 .5 .698 r
.2011 .30054 .20684 .32293 .21748 .31866 .21179 .29552 Mtetra
.613 .493 .693 r
.21179 .29552 .21748 .31866 .22816 .31445 .22251 .29058 Mtetra
.609 .487 .689 r
.22251 .29058 .22816 .31445 .23887 .31032 .23326 .28571 Mtetra
.605 .481 .684 r
.23326 .28571 .23887 .31032 .24961 .30629 .24404 .28089 Mtetra
.602 .475 .679 r
.24404 .28089 .24961 .30629 .26039 .30234 .25485 .27614 Mtetra
.598 .468 .675 r
.25485 .27614 .26039 .30234 .27121 .29845 .2657 .27149 Mtetra
.593 .461 .671 r
.2657 .27149 .27121 .29845 .28206 .29461 .27656 .26707 Mtetra
.585 .454 .668 r
.27656 .26707 .28206 .29461 .29296 .29084 .28743 .26303 Mtetra
.574 .445 .668 r
.28743 .26303 .29296 .29084 .30388 .28735 .29829 .25974 Mtetra
.56 .437 .669 r
.29829 .25974 .30388 .28735 .31483 .28424 .30914 .25732 Mtetra
.547 .432 .674 r
.30914 .25732 .31483 .28424 .32579 .28166 .31999 .25576 Mtetra
.538 .432 .682 r
.31999 .25576 .32579 .28166 .33678 .27947 .33087 .25476 Mtetra
.547 .445 .69 r
.33087 .25476 .33678 .27947 .34785 .27707 .34183 .25334 Mtetra
.567 .464 .697 r
.34183 .25334 .34785 .27707 .359 .27407 .35292 .25091 Mtetra
.598 .488 .699 r
.35292 .25091 .359 .27407 .37027 .26997 .36416 .24676 Mtetra
.624 .504 .696 r
.36416 .24676 .37027 .26997 .38163 .26475 .37553 .24089 Mtetra
.636 .508 .69 r
.37553 .24089 .38163 .26475 .39306 .25893 .38698 .234 Mtetra
.638 .503 .682 r
.38698 .234 .39306 .25893 .40453 .2529 .39848 .22668 Mtetra
.625 .489 .676 r
.39848 .22668 .40453 .2529 .41602 .24726 .40997 .21991 Mtetra
.61 .474 .671 r
.40997 .21991 .41602 .24726 .42753 .24213 .42147 .214 Mtetra
.596 .461 .668 r
.42147 .214 .42753 .24213 .43908 .23739 .43298 .20897 Mtetra
.585 .453 .667 r
.43298 .20897 .43908 .23739 .45066 .23293 .44451 .20468 Mtetra
.58 .45 .669 r
.44451 .20468 .45066 .23293 .46229 .22854 .45608 .20078 Mtetra
.577 .451 .672 r
.45608 .20078 .46229 .22854 .47396 .2242 .4677 .19712 Mtetra
.577 .455 .676 r
.4677 .19712 .47396 .2242 .48569 .21992 .47937 .19356 Mtetra
.577 .459 .681 r
.47937 .19356 .48569 .21992 .49746 .21572 .4911 .19006 Mtetra
.578 .463 .686 r
.4911 .19006 .49746 .21572 .50929 .21162 .50288 .18662 Mtetra
.578 .467 .691 r
.50288 .18662 .50929 .21162 .52116 .20759 .51472 .18325 Mtetra
.578 .472 .697 r
.51472 .18325 .52116 .20759 .5331 .20362 .52663 .17996 Mtetra
.578 .476 .702 r
.52663 .17996 .5331 .20362 .54508 .1997 .53859 .17676 Mtetra
.578 .482 .709 r
.53859 .17676 .54508 .1997 .55713 .19579 .55061 .17365 Mtetra
.578 .488 .716 r
.55061 .17365 .55713 .19579 .56923 .19192 .5627 .17063 Mtetra
.578 .495 .725 r
.5627 .17063 .56923 .19192 .58139 .18808 .57486 .1677 Mtetra
.578 .503 .734 r
.57486 .1677 .58139 .18808 .59361 .18429 .58709 .16489 Mtetra
.577 .512 .745 r
.58709 .16489 .59361 .18429 .60589 .18058 .59938 .16219 Mtetra
.576 .522 .758 r
.59938 .16219 .60589 .18058 .61824 .17696 .61175 .15963 Mtetra
.575 .534 .772 r
.61175 .15963 .61824 .17696 .63065 .17347 .6242 .15721 Mtetra
.573 .547 .788 r
.6242 .15721 .63065 .17347 .64313 .17011 .63673 .15493 Mtetra
.57 .562 .805 r
.63673 .15493 .64313 .17011 .65569 .16691 .64933 .15281 Mtetra
.567 .578 .824 r
.64933 .15281 .65569 .16691 .66832 .16384 .66203 .15083 Mtetra
.562 .596 .845 r
.66203 .15083 .66832 .16384 .68102 .16091 .67481 .14899 Mtetra
.557 .616 .868 r
.67481 .14899 .68102 .16091 .69381 .15808 .68768 .14726 Mtetra
.55 .639 .892 r
.68768 .14726 .69381 .15808 .70667 .15533 .70063 .14559 Mtetra
.542 .665 .917 r
.70063 .14559 .70667 .15533 .71961 .15261 .71368 .14397 Mtetra
.761 .768 .859 r
.03496 .38178 .04273 .38856 .05321 .38196 .04558 .37447 Mtetra
.754 .75 .849 r
.04558 .37447 .05321 .38196 .06371 .3754 .0562 .3672 Mtetra
.746 .733 .839 r
.0562 .3672 .06371 .3754 .07422 .36891 .06684 .36 Mtetra
.738 .716 .83 r
.06684 .36 .07422 .36891 .08474 .36251 .07748 .35289 Mtetra
.73 .699 .822 r
.07748 .35289 .08474 .36251 .09526 .35623 .08812 .3459 Mtetra
.721 .684 .813 r
.08812 .3459 .09526 .35623 .10579 .3501 .09876 .33904 Mtetra
.712 .668 .805 r
.09876 .33904 .10579 .3501 .11632 .34411 .1094 .33231 Mtetra
.704 .653 .796 r
.1094 .33231 .11632 .34411 .12687 .33826 .12005 .32573 Mtetra
.695 .638 .788 r
.12005 .32573 .12687 .33826 .13742 .33254 .1307 .31928 Mtetra
.687 .625 .78 r
.1307 .31928 .13742 .33254 .14799 .32695 .14136 .31297 Mtetra
.68 .612 .773 r
.14136 .31297 .14799 .32695 .15857 .32148 .15203 .3068 Mtetra
.672 .6 .766 r
.15203 .3068 .15857 .32148 .16917 .31611 .16271 .30076 Mtetra
.665 .588 .759 r
.16271 .30076 .16917 .31611 .17979 .31083 .1734 .29487 Mtetra
.659 .579 .753 r
.1734 .29487 .17979 .31083 .19043 .30564 .1841 .28911 Mtetra
.653 .57 .748 r
.1841 .28911 .19043 .30564 .2011 .30054 .19482 .28349 Mtetra
.648 .562 .744 r
.19482 .28349 .2011 .30054 .21179 .29552 .20556 .27797 Mtetra
.644 .555 .739 r
.20556 .27797 .21179 .29552 .22251 .29058 .21631 .27254 Mtetra
.64 .548 .735 r
.21631 .27254 .22251 .29058 .23326 .28571 .2271 .26716 Mtetra
.637 .542 .73 r
.2271 .26716 .23326 .28571 .24404 .28089 .23792 .26179 Mtetra
.634 .536 .726 r
.23792 .26179 .24404 .28089 .25485 .27614 .24877 .25644 Mtetra
.63 .529 .721 r
.24877 .25644 .25485 .27614 .2657 .27149 .25965 .25115 Mtetra
.623 .52 .716 r
.25965 .25115 .2657 .27149 .27656 .26707 .27054 .24614 Mtetra
.612 .509 .713 r
.27054 .24614 .27656 .26707 .28743 .26303 .28143 .2416 Mtetra
.595 .495 .711 r
.28143 .2416 .28743 .26303 .29829 .25974 .2923 .23789 Mtetra
.575 .48 .71 r
.2923 .23789 .29829 .25974 .30914 .25732 .30314 .23517 Mtetra
.557 .467 .709 r
.30314 .23517 .30914 .25732 .31999 .25576 .31398 .23334 Mtetra
.545 .458 .708 r
.31398 .23334 .31999 .25576 .33087 .25476 .32484 .23207 Mtetra
.552 .461 .705 r
.32484 .23207 .33087 .25476 .34183 .25334 .33579 .23043 Mtetra
.57 .471 .703 r
.33579 .23043 .34183 .25334 .35292 .25091 .34686 .22784 Mtetra
.598 .488 .7 r
.34686 .22784 .35292 .25091 .36416 .24676 .35807 .22365 Mtetra
.623 .504 .697 r
.35807 .22365 .36416 .24676 .37553 .24089 .36941 .21785 Mtetra
.637 .513 .695 r
.36941 .21785 .37553 .24089 .38698 .234 .38083 .21109 Mtetra
.643 .518 .695 r
.38083 .21109 .38698 .234 .39848 .22668 .3923 .20395 Mtetra
.636 .514 .698 r
.3923 .20395 .39848 .22668 .40997 .21991 .40377 .19737 Mtetra
.623 .508 .702 r
.40377 .19737 .40997 .21991 .42147 .214 .41524 .19168 Mtetra
.608 .5 .706 r
.41524 .19168 .42147 .214 .43298 .20897 .42671 .18698 Mtetra
.594 .495 .711 r
.42671 .18698 .43298 .20897 .44451 .20468 .43821 .18312 Mtetra
.586 .494 .716 r
.43821 .18312 .44451 .20468 .45608 .20078 .44975 .17974 Mtetra
.582 .495 .722 r
.44975 .17974 .45608 .20078 .4677 .19712 .46133 .17663 Mtetra
.582 .5 .728 r
.46133 .17663 .4677 .19712 .47937 .19356 .47298 .17359 Mtetra
.583 .506 .734 r
.47298 .17359 .47937 .19356 .4911 .19006 .48468 .17058 Mtetra
.584 .511 .739 r
.48468 .17058 .4911 .19006 .50288 .18662 .49645 .16758 Mtetra
.584 .516 .745 r
.49645 .16758 .50288 .18662 .51472 .18325 .50827 .16462 Mtetra
.583 .52 .75 r
.50827 .16462 .51472 .18325 .52663 .17996 .52016 .16176 Mtetra
.581 .524 .756 r
.52016 .16176 .52663 .17996 .53859 .17676 .53212 .15901 Mtetra
.579 .528 .763 r
.53212 .15901 .53859 .17676 .55061 .17365 .54414 .1564 Mtetra
.576 .533 .77 r
.54414 .1564 .55061 .17365 .5627 .17063 .55623 .15393 Mtetra
.573 .539 .779 r
.55623 .15393 .5627 .17063 .57486 .1677 .56839 .15161 Mtetra
.571 .546 .788 r
.56839 .15161 .57486 .1677 .58709 .16489 .58063 .14943 Mtetra
.567 .554 .799 r
.58063 .14943 .58709 .16489 .59938 .16219 .59295 .1474 Mtetra
.564 .563 .811 r
.59295 .1474 .59938 .16219 .61175 .15963 .60534 .14552 Mtetra
.559 .572 .823 r
.60534 .14552 .61175 .15963 .6242 .15721 .61782 .14378 Mtetra
.554 .582 .837 r
.61782 .14378 .6242 .15721 .63673 .15493 .63038 .14219 Mtetra
.548 .593 .851 r
.63038 .14219 .63673 .15493 .64933 .15281 .64304 .14075 Mtetra
.541 .605 .866 r
.64304 .14075 .64933 .15281 .66203 .15083 .65578 .13944 Mtetra
.534 .617 .881 r
.65578 .13944 .66203 .15083 .67481 .14899 .66861 .13827 Mtetra
.526 .63 .897 r
.66861 .13827 .67481 .14899 .68768 .14726 .68154 .13719 Mtetra
.517 .644 .912 r
.68154 .13719 .68768 .14726 .70063 .14559 .69457 .1362 Mtetra
.508 .659 .928 r
.69457 .1362 .70063 .14559 .71368 .14397 .70769 .13525 Mtetra
.764 .768 .856 r
.02714 .37496 .03496 .38178 .04558 .37447 .03781 .36745 Mtetra
.761 .764 .855 r
.03781 .36745 .04558 .37447 .0562 .3672 .04849 .36 Mtetra
.758 .76 .854 r
.04849 .36 .0562 .3672 .06684 .36 .05918 .35263 Mtetra
.755 .756 .853 r
.05918 .35263 .06684 .36 .07748 .35289 .06987 .34535 Mtetra
.751 .752 .853 r
.06987 .34535 .07748 .35289 .08812 .3459 .08056 .33818 Mtetra
.747 .748 .852 r
.08056 .33818 .08812 .3459 .09876 .33904 .09125 .33113 Mtetra
.743 .743 .852 r
.09125 .33113 .09876 .33904 .1094 .33231 .10195 .3242 Mtetra
.739 .738 .851 r
.10195 .3242 .1094 .33231 .12005 .32573 .11265 .31739 Mtetra
.734 .733 .85 r
.11265 .31739 .12005 .32573 .1307 .31928 .12336 .3107 Mtetra
.729 .727 .848 r
.12336 .3107 .1307 .31928 .14136 .31297 .13407 .30415 Mtetra
.724 .721 .847 r
.13407 .30415 .14136 .31297 .15203 .3068 .14479 .29773 Mtetra
.719 .714 .845 r
.14479 .29773 .15203 .3068 .16271 .30076 .15551 .29146 Mtetra
.713 .708 .844 r
.15551 .29146 .16271 .30076 .1734 .29487 .16625 .28533 Mtetra
.708 .702 .842 r
.16625 .28533 .1734 .29487 .1841 .28911 .177 .27934 Mtetra
.702 .696 .841 r
.177 .27934 .1841 .28911 .19482 .28349 .18775 .2735 Mtetra
.698 .69 .839 r
.18775 .2735 .19482 .28349 .20556 .27797 .19853 .26778 Mtetra
.694 .685 .838 r
.19853 .26778 .20556 .27797 .21631 .27254 .20933 .26214 Mtetra
.691 .681 .835 r
.20933 .26214 .21631 .27254 .2271 .26716 .22015 .25655 Mtetra
.689 .677 .833 r
.22015 .25655 .2271 .26716 .23792 .26179 .23101 .25097 Mtetra
.687 .672 .83 r
.23101 .25097 .23792 .26179 .24877 .25644 .24189 .2454 Mtetra
.684 .667 .827 r
.24189 .2454 .24877 .25644 .25965 .25115 .25281 .23988 Mtetra
.677 .661 .826 r
.25281 .23988 .25965 .25115 .27054 .24614 .26374 .23457 Mtetra
.666 .651 .825 r
.26374 .23457 .27054 .24614 .28143 .2416 .27467 .22963 Mtetra
.647 .636 .825 r
.27467 .22963 .28143 .2416 .2923 .23789 .2856 .22531 Mtetra
.624 .615 .821 r
.2856 .22531 .2923 .23789 .30314 .23517 .29651 .22171 Mtetra
.603 .59 .811 r
.29651 .22171 .30314 .23517 .31398 .23334 .30743 .21876 Mtetra
.587 .565 .796 r
.30743 .21876 .31398 .23334 .32484 .23207 .31837 .21622 Mtetra
.589 .549 .777 r
.31837 .21622 .32484 .23207 .33579 .23043 .32938 .2135 Mtetra
.599 .541 .762 r
.32938 .2135 .33579 .23043 .34686 .22784 .34047 .21021 Mtetra
.617 .545 .75 r
.34047 .21021 .34686 .22784 .35807 .22365 .35168 .20598 Mtetra
.636 .555 .747 r
.35168 .20598 .35807 .22365 .36941 .21785 .36299 .2008 Mtetra
.649 .569 .751 r
.36299 .2008 .36941 .21785 .38083 .21109 .37436 .19505 Mtetra
.658 .586 .762 r
.37436 .19505 .38083 .21109 .3923 .20395 .38577 .18911 Mtetra
.657 .601 .78 r
.38577 .18911 .3923 .20395 .40377 .19737 .39721 .18359 Mtetra
.649 .613 .8 r
.39721 .18359 .40377 .19737 .41524 .19168 .40866 .1787 Mtetra
.634 .62 .818 r
.40866 .1787 .41524 .19168 .42671 .18698 .42012 .17455 Mtetra
.619 .623 .833 r
.42012 .17455 .42671 .18698 .43821 .18312 .43162 .17102 Mtetra
.609 .625 .842 r
.43162 .17102 .43821 .18312 .44975 .17974 .44316 .16786 Mtetra
.602 .627 .849 r
.44316 .16786 .44975 .17974 .46133 .17663 .45476 .16492 Mtetra
.6 .631 .853 r
.45476 .16492 .46133 .17663 .47298 .17359 .46641 .16204 Mtetra
.6 .634 .857 r
.46641 .16204 .47298 .17359 .48468 .17058 .47813 .15916 Mtetra
.599 .638 .861 r
.47813 .15916 .48468 .17058 .49645 .16758 .48991 .1563 Mtetra
.597 .641 .865 r
.48991 .1563 .49645 .16758 .50827 .16462 .50176 .15349 Mtetra
.593 .643 .87 r
.50176 .15349 .50827 .16462 .52016 .16176 .51366 .15077 Mtetra
.589 .645 .874 r
.51366 .15077 .52016 .16176 .53212 .15901 .52564 .14817 Mtetra
.583 .647 .879 r
.52564 .14817 .53212 .15901 .54414 .1564 .53768 .14572 Mtetra
.577 .649 .885 r
.53768 .14572 .54414 .1564 .55623 .15393 .54979 .14342 Mtetra
.57 .651 .89 r
.54979 .14342 .55623 .15393 .56839 .15161 .56198 .14128 Mtetra
.563 .653 .896 r
.56198 .14128 .56839 .15161 .58063 .14943 .57425 .13928 Mtetra
.556 .655 .902 r
.57425 .13928 .58063 .14943 .59295 .1474 .58659 .13743 Mtetra
.549 .657 .907 r
.58659 .13743 .59295 .1474 .60534 .14552 .59901 .13572 Mtetra
.542 .659 .913 r
.59901 .13572 .60534 .14552 .61782 .14378 .61152 .13414 Mtetra
.534 .661 .918 r
.61152 .13414 .61782 .14378 .63038 .14219 .62412 .13269 Mtetra
.527 .662 .922 r
.62412 .13269 .63038 .14219 .64304 .14075 .63681 .13138 Mtetra
.519 .663 .926 r
.63681 .13138 .64304 .14075 .65578 .13944 .64958 .13019 Mtetra
.512 .664 .93 r
.64958 .13019 .65578 .13944 .66861 .13827 .66246 .12912 Mtetra
.505 .665 .933 r
.66246 .12912 .66861 .13827 .68154 .13719 .67542 .12815 Mtetra
.499 .666 .937 r
.67542 .12815 .68154 .13719 .69457 .1362 .68849 .12727 Mtetra
.493 .667 .94 r
.68849 .12727 .69457 .1362 .70769 .13525 .70165 .12647 Mtetra
.755 .768 .864 r
.01926 .36808 .02714 .37496 .03781 .36745 .02989 .36102 Mtetra
.756 .781 .873 r
.02989 .36102 .03781 .36745 .04849 .36 .04053 .35406 Mtetra
.757 .796 .884 r
.04053 .35406 .04849 .36 .05918 .35263 .05117 .34719 Mtetra
.758 .812 .895 r
.05117 .34719 .05918 .35263 .06987 .34535 .06181 .34043 Mtetra
.759 .829 .906 r
.06181 .34043 .06987 .34535 .08056 .33818 .07247 .33377 Mtetra
.758 .846 .917 r
.07247 .33377 .08056 .33818 .09125 .33113 .08313 .3272 Mtetra
.756 .863 .927 r
.08313 .3272 .09125 .33113 .10195 .3242 .0938 .32073 Mtetra
.752 .879 .937 r
.0938 .32073 .10195 .3242 .11265 .31739 .10448 .31436 Mtetra
.747 .894 .945 r
.10448 .31436 .11265 .31739 .12336 .3107 .11517 .30809 Mtetra
.74 .907 .951 r
.11517 .30809 .12336 .3107 .13407 .30415 .12588 .30192 Mtetra
.732 .919 .956 r
.12588 .30192 .13407 .30415 .14479 .29773 .1366 .29584 Mtetra
.722 .929 .959 r
.1366 .29584 .14479 .29773 .15551 .29146 .14733 .28986 Mtetra
.71 .936 .961 r
.14733 .28986 .15551 .29146 .16625 .28533 .15808 .28397 Mtetra
.698 .941 .961 r
.15808 .28397 .16625 .28533 .177 .27934 .16885 .27818 Mtetra
.686 .944 .961 r
.16885 .27818 .177 .27934 .18775 .2735 .17964 .27249 Mtetra
.674 .946 .96 r
.17964 .27249 .18775 .2735 .19853 .26778 .19045 .26689 Mtetra
.662 .946 .958 r
.19045 .26689 .19853 .26778 .20933 .26214 .20128 .26139 Mtetra
.648 .946 .956 r
.20128 .26139 .20933 .26214 .22015 .25655 .21214 .25598 Mtetra
.632 .945 .951 r
.21214 .25598 .22015 .25655 .23101 .25097 .22302 .25067 Mtetra
.61 .943 .942 r
.22302 .25067 .23101 .25097 .24189 .2454 .23392 .24546 Mtetra
.582 .938 .927 r
.23392 .24546 .24189 .2454 .25281 .23988 .24485 .24034 Mtetra
.547 .927 .906 r
.24485 .24034 .25281 .23988 .26374 .23457 .25581 .23531 Mtetra
.517 .916 .886 r
.25581 .23531 .26374 .23457 .27467 .22963 .2668 .23038 Mtetra
.504 .909 .882 r
.2668 .23038 .27467 .22963 .2856 .22531 .27782 .22554 Mtetra
.525 .917 .908 r
.27782 .22554 .2856 .22531 .29651 .22171 .28887 .2208 Mtetra
.577 .925 .955 r
.28887 .2208 .29651 .22171 .30743 .21876 .29996 .21616 Mtetra
.632 .905 .984 r
.29996 .21616 .30743 .21876 .31837 .21622 .31108 .21161 Mtetra
.66 .85 .973 r
.31108 .21161 .31837 .21622 .32938 .2135 .32224 .20715 Mtetra
.664 .794 .944 r
.32224 .20715 .32938 .2135 .34047 .21021 .33344 .20279 Mtetra
.66 .759 .923 r
.33344 .20279 .34047 .21021 .35168 .20598 .34467 .19853 Mtetra
.656 .758 .925 r
.34467 .19853 .35168 .20598 .36299 .2008 .35595 .19436 Mtetra
.65 .789 .949 r
.35595 .19436 .36299 .2008 .37436 .19505 .36727 .19028 Mtetra
.631 .842 .981 r
.36727 .19028 .37436 .19505 .38577 .18911 .37864 .1863 Mtetra
.578 .888 .99 r
.37864 .1863 .38577 .18911 .39721 .18359 .39005 .18242 Mtetra
.492 .89 .948 r
.39005 .18242 .39721 .18359 .40866 .1787 .40151 .17863 Mtetra
.407 .858 .883 r
.40151 .17863 .40866 .1787 .42012 .17455 .41302 .17494 Mtetra
.358 .832 .844 r
.41302 .17494 .42012 .17455 .43162 .17102 .42458 .17135 Mtetra
.35 .827 .844 r
.42458 .17135 .43162 .17102 .44316 .16786 .43619 .16785 Mtetra
.363 .834 .865 r
.43619 .16785 .44316 .16786 .45476 .16492 .44786 .16445 Mtetra
.385 .844 .893 r
.44786 .16445 .45476 .16492 .46641 .16204 .45958 .16115 Mtetra
.402 .849 .915 r
.45958 .16115 .46641 .16204 .47813 .15916 .47136 .15795 Mtetra
.412 .851 .931 r
.47136 .15795 .47813 .15916 .48991 .1563 .4832 .15484 Mtetra
.416 .85 .94 r
.4832 .15484 .48991 .1563 .50176 .15349 .4951 .15183 Mtetra
.416 .847 .946 r
.4951 .15183 .50176 .15349 .51366 .15077 .50707 .14893 Mtetra
.416 .844 .952 r
.50707 .14893 .51366 .15077 .52564 .14817 .5191 .14612 Mtetra
.418 .841 .958 r
.5191 .14612 .52564 .14817 .53768 .14572 .5312 .14341 Mtetra
.421 .838 .966 r
.5312 .14341 .53768 .14572 .54979 .14342 .54336 .1408 Mtetra
.428 .835 .974 r
.54336 .1408 .54979 .14342 .56198 .14128 .5556 .1383 Mtetra
.436 .83 .983 r
.5556 .1383 .56198 .14128 .57425 .13928 .56791 .13589 Mtetra
.446 .824 .99 r
.56791 .13589 .57425 .13928 .58659 .13743 .5803 .13359 Mtetra
.457 .817 .996 r
.5803 .13359 .58659 .13743 .59901 .13572 .59277 .13139 Mtetra
.467 .807 .999 r
.59277 .13139 .59901 .13572 .61152 .13414 .60531 .1293 Mtetra
.477 .795 .999 r
.60531 .1293 .61152 .13414 .62412 .13269 .61794 .12731 Mtetra
.485 .781 .997 r
.61794 .12731 .62412 .13269 .63681 .13138 .63065 .12542 Mtetra
.493 .765 .992 r
.63065 .12542 .63681 .13138 .64958 .13019 .64345 .12364 Mtetra
.499 .748 .984 r
.64345 .12364 .64958 .13019 .66246 .12912 .65634 .12197 Mtetra
.504 .731 .975 r
.65634 .12197 .66246 .12912 .67542 .12815 .66932 .12041 Mtetra
.507 .713 .964 r
.66932 .12041 .67542 .12815 .68849 .12727 .68239 .11895 Mtetra
.509 .696 .954 r
.68239 .11895 .68849 .12727 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Jooooo`;oPK_i1?n1]_H4oh:bm003o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0DOooool0063ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Mooooo`?o00000_ooool00ol0003ooooooooo
o`1Cooooo`?oOkok1On1^oT4oh6fmP?oP[;d00?o0000oh:bm?ooool05Oooool00ol0003ooooooooo
o`1@ooooo`00H?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Looooo`;o0000Dooo
ool3ogc7o`CoO/?m1Omo_o/4oh6kn@GoPKKf0_n2/_@00ol0003oOZ[`ooooo`0Dooooo`03o`000?oo
oooo0000057ooooo001Pooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMoooo
ool0000Jooooo`?o0000COooool3ogO>o`GoN/_o1?mlaol4ogk3o@;oOkok0_n3ZNh4oh6ZkPKoOj[_
00CoOZ[`o`000?mnZ_3oOZ[`5_ooool00ol0003oooooooooo`1?ooooo`00H?ooool01Ol0003ooooo
oooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00006?ooool2o`0004cooooo1?mddOh4ogO>
o`;oN/_o0_n8ZN/4ohJYk0CoQ:W]1On3ZNh4oh6ZkPKoOj[_00Co0000ogjZl?mnZ_3oOZ[`5_ooool0
0ol0003oooooooooo`1>ooooo`00H?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMg
olc<c?l000005Oooool3o`0000;ooooo00?o0000ooooooooool0@Oooool4ofoDn`CoL];m0_mddOh2
ohbXj0CoRZSY1On8ZN/4ohJYk0CoQ:W]1On3ZNh4oh6ZkP?oOj[_0_n4Y>T01?l0003oPZS]oh:XkOn2
Z>dFooooo`03o`000?oooooooooo04kooooo001Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00oo^k^koA4A4o`00000Cooooo`;o0000A_ooool3ofgEn@;oKmCk0_n@YnD4ohjWiPGoS:SX1?n:
Z>T5ohRYj`CoQZW/1?n4ZNd2oh>YkP;oR9gQ1?n6XND5ohBTj@03o`000?n2Z>goPZS]00;oPZS]5_oo
ool00ol0003oooooooooo`1=ooooo`00H?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?o
MgMgo`000?ooool03oooool3o`0004Cooooo1?m[e_L2ofgEn@;oTJKS1?n@YnD4ohjWiPGoS:SX1?n:
Z>T2ohRYj`;oSICF1?n<UmT4ohZJg@GoR9gQ1?n6XND4ohBTj@03o`000?n2Z>goPZS]00?oPZS]5_oo
ool00ol0003oooooooooo`1<ooooo`00P_ooool2o`0004?ooooo1?m[eoD2of_Fm`;oTjKR1OnAY^<3
oi2Wi@GoSZOV0_n<Z>P2oi2@c`CoSi;B1On=U=H4ohbGf@CoRY[M1?n8WN45ohJQi@;oQ:CY00?oS:?T
o`000?n:Z^X01?n:Z^XFooooo`03o`000?oooooooooo04cooooo001oooooo`?o00000_ooool00ol0
003oooooooooo`0looooo`;oJ]Sc0_nFYMl4oiFUh@GoTjKR1OnAY^<3oi2Wi@;oSZOV0_nASL`5oi2@
c`CoSi;B1?n=U=H4ohbGf@GoRY[M1?n8WN42ohJQi@;oSYgN0on<Xn@00ol0003oS:?TohZZjP04ohZZ
jQCooooo0ol0001=ooooo`00O?ooool3o`0003cooooo1?mZfO02of[HlP;oUjCN1OnFYMl4oiFUh@Go
TjKR0_nAY^<2oi:9a`?oTX_91OnASL`4oi2@c`CoSi;B1On=U=H4ohbGf@;oRY[M0_nATm84ohnHf0Go
SYgN0_n<Xn@00ol0003oS:?TohZZjP04ohZZjQOooooo00?o0000ooooooooool0B_ooool007[ooooo
0_l0000looooo`CoJMW^0_mZfO000onHY=goUjCNoiNTgP03oiNTgPCoUZGO1OnEYN42oi>VhP;oThS5
1OnBRLL3oi:;b@CoTHg<1?n@T<l5ohnBdP;oSICF0_nBS<T4oi6?cPGoTI?B1?n?V=P5ohjMgP;oS:?T
00Co0000ohbSi?n:Z^[oRZ[Z0onF[NLFooooo`03o`000?oooooooooo04[ooooo001gooooo`?o0000
>_ooool4ofKIjP;oJMW^0_nIXm`4oiRTg@CoUjCN1OnFYMl2oiFUh@;oU8O31OnCR<D4oi:9a`?oTX_9
1?nASL`5oi2@c`;oSi;B0_nCR<D5oi:<b@CoTHo>1?nATm85ohnHf0;oSYgN0_nGWML2oiNUg`03o`00
0?nGYMooUZgW00GoUZgW5_ooool00ol0003oooooooooo`19ooooo`00MOooool2o`0000;ooooo00?o
0000ooooooooool0=?ooool4of;Hi0;oI]WZ0_nIX]/5oiVSg0?oV:CM1OnGY=h2oiJUg`;oU8K11OnD
Ql<4oi>8a@CoTXW70onBRlT5oi6=c0;oT93?0_nCQL85oi>8a@CoTXc91?nASlh5oi6CdP;oSiSH0_nH
Um45oiNMe`04oiNUgol0003oUjGOoiNUg`CoUZgW00?oXk?Tooooooooool05Oooool00ol0003ooooo
ooooo`18ooooo`00L_ooool3o`0000Gooooo00?o0000ooooooooool0<?ooool3oecEg@;oH]ST0_nI
XMX5oiVRf`GoVJ?L0onHY=d2oiNTgP;oUHFo1OnDQ/44oiB7``CoThS51OnBRLL3oi:;b@;oTHg<0_nC
Pkh5oi>5`PCoThS51?nBS<T5oi6?cP;oTI?B0_nHTL/5oiRGd@CoUigG00?oUjGOo`000?nGYMl00_nG
YMl00onF[NOoXk?Toj>ci002oj>ci1Kooooo00?o0000ooooooooool0B?ooool0073ooooo0_l0000j
ooooo`?oG=GM0_nJX=T4oiVQfPGoVJ;K0_nIXm`2oiF2_@?oUHBn1OnEQKl4oiB6`@CoU8O31OnCR<D2
oi:9a`;oTgji0onCP;/5oi>3_PCoThG21?nCR<D5oi:<b@;oTHo>0_nHS<H5oiRAb`CoV9OA1OnGWML0
1?l0003oUjGOoj:Zg?nRZ]`6oj>ci1Kooooo00?o0000ooooooooool0Aoooool003Sooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00023ooooo0ol0000iooooo`;oFM?H0_nK
WmL5oiZPf@CoVJ7J0_nIX]/2oiF1^`GoUH:m0onEQ;h4oiF5_`CoU8K11OnDQl<2oi>8a@;oTgbg1?nC
O[T4oi>0^`CoTh>n1?nCQL85oi>8a@;oTXc90_nHR<45oiR<aPCoV97;1OnHUm42oiNMe`;oXZ;E00?o
0000oj:Zg?nRZ]`00_nRZ]`4oj>ci003ojjjh_oooooooooo01?ooooo0ol00018ooooo`00>?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
7_ooool2o`0000?ooooo00?o0000ooooooooool0<_ooool2oe_Df0;oWYoE1OnKWmL5oiZPf@;oVJ7J
00?oU7njoiF1^onEPK/00_nEPK/5oiF2_@?oUHBn1?nEQKl5oiB6`@;oU8O30_nCNkD4oi=l]`GoTgji
0onCP;/4oi>3_PGoThG20_nCR<D2oiN4_@GoV8S11?nHS<H4oiRAb`CoV9OA00?oXI_?oj:ReOnRX]D0
0_nRX]D00ol0003oXZ[Loj:Zg003oj:Zg003oj>ci?n^^^;o[[[R00;o[[[R5_ooool00ol0003ooooo
ooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`0Yooooo`00>?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h07?ooool3o`0003Oooooo0_mXfn800onRW]7oWYoEoijOe@03oijOe@GoVioG0_nJX=T2oiAn^0?o
U7nj1OnEPK/4oiF2_@?oUHBn1OnEQKl2oiB6`@;oTgVc1?nCNkD5oi=l]`CoTgji1?nCP;/4oi>3_P?o
ThG200?oUh6joiN4_OnGQ;d00onGQ;d4oiR8`@CoV8c61OnHTL/00onHUm7oXI_?oj6Kc`02oj6Kc`?o
XZ;E00?o0000oj:Zg?nRZ]`00_nRZ]`00on]/]co[[[RojjjhP04ojjjhQKooooo00?o0000oooooooo
ool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo
02[ooooo000hooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Hoooo
o`?o0000=_ooool3oggSlP03ojJLc?nRW]7oXYkA00;oXYkA1OnNWmD2oi^Oe`;oUWjg1?nDO[P4oiAo
^PCoUH6k1OnEP[d3oiF4_P;oUHFo0_nCN;84oi=i/`GoTg^e1?nCO;L4oi=n^@CoTh2k1?nCPkh01?nC
QL;oUh6joiN1^_nGPKX5oiN4_@CoV8S11OnHS<H2oiRAb`;oX9G91OnQVll3oj:Re@03o`000?nRX]Go
XZ[L00Co[K;L1?n^^^82okS1hAKooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol0000[ooooo`00>?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool05Oooool3o`0003Cooooo1?nChod00ommho;oYYc<ojJLc002ojJLc0CoXYkA0onN
WmD00onHO[KoUWjgoiIn]`02oiIn]`GoU7jh0onDOkX4oiF1^`GoUH:m0_nEQ;h00onCMk3oTgRboi=h
/P02oi=h/PGoTgVc1?nCNkD4oi=l]`GoTgji1?nCP;/2oi>3_P03oiMn]onGPK[oUh6j00?oUh6j1?nG
Q;d5oiR8`@?oV8c600?oWi34oj2EbOnPULT00onPULT5oj6Kc`;oXZ;E00?o0000ojb[e_n]/]`01On]
/]`00on^^^;o^<7QokS1h@03okS1hAGooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000_ooooo00CoA4A4omgMgOoooooo0000;?ooool003Sooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo017ooooo0ol00003ooooo`03o`000?oooooooooo02ko
oooo1?nQeo/2oi?So@03ojRIaonVW<coYYc<00?oYYc<1OnRW]400onNWmGoV7jfoiQn]P05oiIn]`Co
U7jh0onDOkX5oiF1^`?oUH:m00?oTgJ_oi=g/?nCMk000_nCMk04oi=h/PCoTgVc1?nCNkD5oi=l]`Co
Tgji0_nCP;/2oiIl]0CoUgjg1?nGPKX5oiN4_@CoV8S100?oV8c6oin@a?nOT<@00_nOT<@4oj2Eb@Co
XI_?00CoZjGAojb[e_n/ZmKo00000_n/ZmH4ojfbg003okNkgOnh`N7o^<7Q00?o^<7Q00?o_/SRoooo
ooooool05?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000/ooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
0000okZj^_ooooooV9RHoa0@400Aooooo`;o0000=_ooool4oj7Gn`03ojRF`onXVLOoZ9W700;oZ9W7
1OnVW<`2oj:Nd@;oVgnd1?nHO[H4oiIn]`CoU7jh1?nDOkX4oiF1^`04oiF2_OnCMZooTgJ_oi=f[`Co
TgN`1?nCN;84oi=i/`GoTg^e1?nCO;L2oi=n^@;oUWVa1?nFO;@4oiMn]`CoUh6j1OnGQ;d2oiR8`@;o
Whc01OnOT<@5oj2Eb@03oj6Kcon[YM7oZjGA00;oZjGA00?o[:_Fo`000?n/ZmH00_n/ZmH00on]/]co
]k_MokNkg@02okNkg@?o^<7Q0onnb>8Fooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03ogMgMoo<c<co000002cooooo000hooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00kooooo0ol0000eooooo`CoY/Wb00?oXMOk
ojRF`onXU/<00_nXU/<3ojRIa`CoYYc<00?oWh:coi]o]?nKOk@00_nKOk@4oiQn]PCoUWjg1OnDO[P3
oiAo^P;oUH6k0_nCMJh5oi=f[`?oTgN`1?nCN;84oi=i/`GoTg^e0_nCO;L2oiEg[`CoUWVa1OnFO;@3
oiMn]`GoUh6j0onGQ;d00onNR;coWhc0oin<`003oin<`0CoWi341?nPULT00onZWlcoZjGAoj^Ud@03
oj^Ud@05ojb[e_l0003o[:_Fojb[e_nf]mT01_ng^md00onh`N7o_/SRokk8hP03okk8hQCooooo0_l0
0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000/ooooo`00FOoo
ool3o`0003Cooooo0_nW`^`4ojK9lP03ojJA`?nXU/?oZ9K300?oZ9K31?nXVLL01?nVW<coWh:coin2
/onOP[<5oi]o]0?oV7jf1OnFO[L4oiAn^0;oU7nj00?oTgB]oi=e[_nCMJh00_nCMJh5oi=f[`CoTgN`
0onCN;85oi=i/`?oTg^e00?oU7J]oiEg[onEMjl00_nEMjl5oiIi/@CoUWbd1?nGO[L4oiN1^P03oiN4
_OnNR;coWXRl00;oWXRl1?nOS<05oin@a003oj2EbOnZWlcoZYo<00;oZYo<1On[YM400ol0003o][OI
okJgf@02okJgf@Co]k_M0_nnan44okk8hP03ol3=i?oooooooooo017ooooo00Co0000oooooooooooo
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0:oooool005Ko
oooo0ol00003ooooo`03o`000?oooooooooo02kooooo00?oZ<;/ojO2k?nW`^`00onW`^`00onVbO;o
YY70ojJA`002ojJA`0CoZ9K30onXVLL00onRPk;oWh:coin2/`03oin2/`CoVgnd1?nHO[H4oiIn]`;o
U7jh0_nCLj`3oi=d[@GoTgF^1?nCMZl4oi=g/0CoTgRb1?nCNK<01?nCNkGoU7J]oiAf[OnDMZd5oiEg
[`CoUWVa1?nFO;@4oiMn]`;oUh6j0_nMQKT5oij8_0CoWhc01?nOT<@00onYVlSoZYo<ojZOc003ojZO
c0CoZjGA00?o]K;Fo`000?nf]mT01?nf]mT00ong^mgo_/OQokk7h@03okk7h@03okk8h_o0cNCo`<gT
00;o`<gT5_ooool00ol0003oooooooooo`10ooooo`00E?ooool2o`0003Gooooo1?nX`^`3ojO2k003
oj:>_onVTL3oYY7000?oYY701OnXU/<00onXVLOoXX>boj:3/P05oin2/`CoVgnd1?nHO[H2oiIn]`;o
U7>[1?nCLj`4oi=d[@CoTgF^1?nCMZl4oi=g/0CoTgRb0_nCNK<2oiAd[0GoU7J]1?nEMjl4oiIi/@Go
UWbd0_nGO[L00onLP[KoWHFioif5^@03oif5^@CoWXRl1OnOS<000onOT<CoZI_8ojVKb002ojVKb0Go
ZYo<00GoZjGAokFbe_ne/]Ko]K;Fo`000004okJgf@03oko7hOnnan7o_/OQ00?o_/OQ00?o`M7Vol3=
i?o0cN@00oo0cN@Fooooo`03o`000?oooooooooo043ooooo001Aooooo`?o0000=?ooool3ojW;l@Go
Z<;/00CoYl;/oj:>_onRS[ooXXjo1?nVTL04ojRF``03ojB4/OnRPk;oXX>b00;oXX>b1?nOP[<5oi]o
]0;oV7jf00?oUG>ZoiAcZonDLj/00_nDLj/5oi=c[0?oTgB]1?nCMJh5oi=f[`CoTgN`0_nCN;800onD
LZ[oU7B/oiAd[002oiAd[0GoU7J]1?nEMjl5oiIi/@CoUWbd00CoUgjgoib2]_nLP[KoW8:f1?nMQKT5
oij8_0?oWhc000?oZ9O4ojVKb?nYVlP00onYVlP4ojZOc003okB^done/]Ko]K;F00;o]K;F00Co0000
okJgfOnf]mWo][OI0onoan43okk7h@?o`M7V0oo0cN@2okgAjAKooooo00?o0000ooooooooool0?ooo
ool004kooooo1Ol0000booooo`?oZ=Wi1?nYbo42ojS2k0;oWH^o1?nRS[l5ojJA`004ojRF`onTQ;7o
Y8BaojB4/@CoXX>b1OnOP[<4oi]o]003oiQn]_nELj[oUG>Z00GoU7>[1?nCLj`3oi=d[@CoTgF^1OnC
MZl2oi=g/0;oTg6Y0onDLZX5oiAd[0CoU7J]1?nEMjl5oiIi/@;oUWbd0_nLOk@4oib2]PCoWHFi1OnN
R;`00onOS<3oZ9O4ojRGa002ojRGa0CoZI_80onZWl`3okB^d`?o]K;F00?o0000okFbe_nf]mT01Ono
an400onnan7o`M7Vol7AiP03ol7AiP03ol3=i?nmdNWo_M7Y00;o_M7Y5_ooool00ol0003ooooooooo
o`0nooooo`00C?ooool2o`0000Gooooo00?o0000ooooooooool0;?ooool2oj7Wn`GoZ=Wi0_nYbo40
0onIR/?oWH^ooif;_`03oif;_`?oXXjo1?nVTL000onSPk7oY8BaojB4/@03ojB4/@?oXX>b1OnOP[<2
oi]o]0;oV7J[1?nELjX4oiAcZ`CoTg>/0onCM:d5oi=e[P?oTgJ_00?oTg2Xoi=aZOnCLJT00_nCLJT4
oiAbZPCoU7B/1?nDMZd5oiEg[`?oUWVa00?oVgfboiao]?nLOk@00_nLOk@5oib2]PCoWHFi0onNR;`0
0onWTl7oZ9O4ojRGa003ojRGa0GoZI_800?oZYo<okB^dond[]<00_nd[]<3okFbeP03o`000?nob>7o
_lSQ00Co_lOQ0_o2e^T4ol7AiP03okkKk_nmdNWo_M7Y00;o_M7Y00?o]=3^ooooooooool05?ooool0
0ol0003oooooooooo`0nooooo`00BOooool3o`0003Cooooo1OnQio/2ojSIn@;oUXc61?nIR/<4oif;
_`CoXXjo00CoYY70oj>3/OnSPk7oXh>a1OnTQ;44oj:3/P?oWh:c00?oW7V[oiQfZonHMZ/00_nHMZ/4
oiEcZPCoU7>[1?nCLj`4oi=d[@CoTgF^00CoTgJ_oi=`Z?nCL:SoTg2X1OnCLJT3oiAbZPCoU7B/1?nD
MZd5oiEg[`04oiIi/OnKOK;oVgfboi]m/PGoW7nd1?nLP[H4oif5^@03oij8_?nWTl7oYi?100;oYi?1
1?nXUl@4ojVKb003ok>[d?nd[]?o]:kC00Co]:kC00Co]K;Foko8hOnob>7o00000_nob>400onoan7o
`]KYol;Fj@03ol;Fj@03ol7Ai_nnfnko_]_^00;o_]_^00?o_M7YokC@k_ndd>h00_ndd>hDooooo`?o
0000?oooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Pooooo`;o0000=Oooool4oi?/m0;o
XNOk00?oUY3;oiJ<a_nFS<H00onFS<H3oiV:``CoWH^o0onRS[l00onOPK;oXh>aoj>3/@03oj>3/@Co
Y8Ba1?nRPk801?nOP[?oW7V[oiaiZonLNJ/5oiQfZ`?oUG>Z1?nDLj/5oi=c[0?oTgB]0_nCMJh2oi=_
Y`GoTg2X1?nCLJT3oiAbZPCoU7B/1OnDMZd3oiEg[`03oiYk/?nKOK;oVgfb00?oVgfb1?nLOk@4oib2
]P?oWHFi00?oYY2nojNC`OnWTl400onWTl45ojRGa003ojVKb?ncZm3o/j_@00;o/j_@1?nd[]<01_o0
bN7o_lSQoko8hOnob>7o0000oko8h@;o`]c/1?o2e^T00onmiO?o_]_^okkKkP02okkKkP;o/mce1Ond
d>hEooooo`03o`000?oooooooooo03gooooo000Rooooo`05ogMgMonHV9SooooooiRHV?mgMgL07Ooo
ool3o`0000;ooooo00?o0000ooooooooool0;oooool3ohKZj0;oTncd0_nJUll4oiJ@b`CoUXc60onI
R/<5oif;_`03oj:>_onOPK;oWh6b00GoXh>a1OnTQ;42oj:3/P03oimm[OnLNJ_oW7V[00?oW7V[1?nH
MZ/3oiEcZPCoU7>[1OnCLj`2oi=d[@03oi=_Y_nCKjOoTfnW00;oTfnW1OnCL:P4oi=aZ@?oU7:Z1OnD
M:`4oiAf[@04oiEg[onJNk3oVW^`oiYk/0GoVgfb1?nLOk@5oib2]P04oif5^OnVT;koYY2nojJ@_PCo
Yi?11?nXUl@00oncZLko/j_@ok>[d004ok>[d003okB^doo0bN7o`<WQ00;o`<WQ0_nob>400ol0003o
`]c/ol;Lk002ol;Lk003ol;FjOnmiO?o_NGc00;o_NGc00?o_]_^ok?LmOncg?D00oncg?D2okC@kP?o
Z<_b5Oooool00ol0003oooooooooo`0looooo`008_ooool01Ol@413ooooooooooooooooo410@01_o
oooo0_l0000eooooo`CoQ^[X00?oWigBoiZGconJUll00onJUll3oiJ@b`CoUXc61?nIR/<3oif;_`03
oiUl/onOPK;oWh6b00;oWh6b1?nSPk45ojB4/@03oj:3/_nOOJgoWgf]00GoW7V[1?nHMZ/3oiEcZPGo
U7>[0onCLj`01?nCKZGoTfnVoi=_Y_nCKjH5oi=_Y`CoTg2X1?nCLJT3oiAbZPGoU7B/0_nDMZd2oiUi
[PGoVW^`1?nKOK85oiao]0?oW8:f00?oYHjlojJ@__nVT;h00onVT;h4ojNC`@03ojRGa?ncZLko/jW>
00;o/jW>1?ncZm000oo0bn;o`<WQol39h@04ol39h@03oko8hOl0003o`]c/00;o`]c/00?o^>oeokgU
lonmiO<00_nmiO<2ojkWn@Co/mce0_nUe_T5ojS;lQGooooo00?o0000ooooooooool0>oooool002;o
oooo00Go0000ooooooooooooooooo`00000Hooooo`?o0000=Oooool2oh7Xh@;oYJ;C1?nOWM84oiZG
c`?oUY3;1OnFS<H3oiV:``04oif;_onIO;?oVGbcoiUl/`CoWh6b1?nSPk44ojB4/@03oj>0[_nOOJgo
Wgf]00;oWgf]1?nLNJ/4oiQfZ`CoUG>Z1?nDLj/01?nCLjcoTfjUoi=^YOnCKZD4oi=_YPCoTfnW1?nC
L:P4oi=aZ@CoU7:Z0onDM:`00onIN:goVGV^oiUi[P02oiUi[PGoVW^`1?nKOK85oiao]003oib2]_nU
S[coYHjl00;oYHjl1?nVT;h3ojNC`@03ok:VcOncZLko/jW>00?o/jW>0oncZm03ol3;hPCo`<WQ0_o2
hnl00ol0003o`]c/okS_m@03okS_m@03okgUlon^ioWo[^Oi00?o[^Oi00?o/mceojGFnOnUe_T00onU
e_T2ojS;lP;oVl;c5Oooool00ol0003oooooooooo`0kooooo`008_ooool01Ol0003ooooooooooooo
oooo000001Kooooo0ol0000dooooo`;oQ>[R00?oZZKCojFRdonUX]<00onUX]<3oinMdPGoVYO?0onF
T</2oiJ<aP;oSGJd0onAN;<5oiUl/`?oWh6b1OnSPk42ojB4/@;oXh2^1?nOOJd4oiaiZ`CoV7J[1?nE
LjX2oiAcZ`KoTfjU1?nCKjH4oi=_Y`CoTg2X1OnCLJT3oiAbZP04oiAd[?nIN:goVGR]oiUh[@GoVGV^
1?nJNk05oi]m/P?oW7nd00?oY8^jojF>_?nUS[`00onUS[`5ojJ@_P04ojNC`OnbY/go/ZK=ok:Vc@Go
/jW>00?o/j_@ol3;h_o0bn800oo0bn800oo0bN7o`^?_ol;Sk`02ol;Sk`03o`000?n/mO7o[?Ga00;o
^>oe0onQk_L2ojkWn@CoW=om0_nUe_T2oiO9n@GoVl;c5Oooool00ol0003oooooooooo`0jooooo`00
8_ooool01Ol@413ooooooooooooooooo410@01?ooooo0ol00002ooooo`03o`000?oooooooooo033o
oooo0on4j^83ojZVd`CoYJ;C1?nOWM82oiZGc`;oSWNe0on;MKD4ohef]0?oTGRc1OnIO;<3oin1/PGo
Xh>a00?oY8Baoj>0[_nSP:h00_nSP:h3oimm[@CoW7V[1OnHMZ/2oiEcZP03oiA_Y_nCKZGoTfjU00Oo
TfjU0onCKjH4oi=_Y`GoTg2X1?nCLJT2oiAbZP03oiQf[?nIN:goVGR]00?oVGR]1?nINJh4oiYk/0Go
Vgfb00?oW7ndojB;^_nTRkX00_nTRkX4ojF>_0CoYY2n00?o/JG<ok:VcOnbY/d00_nbY/d4ok>YcP;o
`LgT1?o0bn82ol3YlP?o`^?_00?o[?Gao`000?n/mO400_n7jnP2oj7^m`CoS>Ck0_nLgod3oi3?o@Co
UlWi1?nK`_<Fooooo`03o`000?oooooooooo03Wooooo000Rooooo`05ogMgMonHV9SooooooiRHV?mg
MgL04?ooool3o`0003Kooooo0_n<kNL2ojfYd`GoZZKC1?nUX]<2oinMdP03oi=j]On>MkGoSWNe00;o
SWNe0on;MKD5ohef]0?oTGRc1?nIO;<4oin1/P?oXh>a00?oXX:`oj>0[_nSP:h00onSP:h3oimm[@Go
W7V[1?nHMZ/00onELj[oU6nVoiA_YP09oi=^Y@?oTfnV1?nCKjL5oi=`Z0?oTg6Y00CoV7FZoiQf[?nH
MZcoV7J/1OnIN:d4oiUi[PGoVW^`0onKOK800onSRKWoY8^jojB;^P03ojB;^PGoYHjl0_nVT;h3ok6U
c0Co/ZK=00?o/jW>ol7=i?o1cN@00oo1cN@00oo0bn;o`>Wbol3YlP03ol3YlP05ol;Skon/mO7o[?Ga
o`000?n7jnP01?mag^d2ohcTn`?oQm?o1On@cod3oiO9n@;oVl;c0onB^?4Dooooo`;o0000>oooool0
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`;o0000>?ooool00on_Z]?o[JWCojfYd`03
ojfYd`GoZZKC0_nUX]<01?nHO[KoTgZeoi=j]OnCN[D5ohig]@?oRgFe1?n=M[@3oi5h/`CoVGbc1?nO
PK801?nSPk7oXX:`oj:2/?nRP[05oj>0[P?oWgf]1OnLNJ/2oiQfZ`;oUW:X0onDKjH9oi=^Y@?oTfnV
1OnCKjL4oi=`Z004oi=aZOnHMJ[oV7FZoiQeZPCoV7J/1?nIN:d4oiUi[PGoVW^`00?oVgfboj>9^OnS
RKT00_nSRKT4ojB;^PGoYHjl00?oYY2nok6Uc?naYL`00_naYL`4ok:Vc@Go`LgT0_nll?<4ol3YlP;o
U_7S0_m=c=401?l0003oCLcAog7NkOmag^d4ogWCoPCoQm?o0_n@cod2ohjil`CoT;Wb1OnB^?4Eoooo
o`03o`000?oooooooooo03Sooooo000booooo`Go0000=Oooool2oiC`k@?o[j[C1On]ZM<2ojZVd`;o
W8:f0onHO[H4oi=j]@CoSWNe0on;MKD4ohef]0?oTGRc1OnIO;<3oin1/PGoXX:`1?nSP:h4oimm[@?o
W7V[00?oVGR/oiIbZ?nFLZP00_nFLZP4oiA_YPSoTfjU1?nCKjH4oi=_Y`;oTg2X0_nGM:T5oiQeZP?o
V7J/1?nIN:d5oiUi[P?oVW^`00?oXXNhoj>9^OnSRKT00onSRKT5ojB;^P?oYHjl00?o/JC;ok6Uc?na
YL`00onaYL`3ok:Vc@;o`M7V0oo1cN@4okc`l`03ol3Yl_nFlN?oU_7S00?oFlge0_l00003of_An`;o
NM?n0_n9]_<4ohbhm0GoS[Wc1?n@^O82oi:hl@;oTK;^5_ooool00ol0003oooooooooo`0gooooo`00
<?ooool2o`0003Oooooo0onLlO400on_[=Co[j[CojnZd`03ojnZd`?o[JWC00?oWhFgoib2]_nLP[H0
0_nLP[H4oiQn]P?oTgZe1?n>MkD3oh]e]@CoSGJd1?nAN;<4oiUl/`?oWh6b1OnRP[05oj>0[P?oWgf]
00CoW7V[oiUh[?nIN:coVGR/1?nFLZP4oiA_YPSoTfjU1?nCKjH3oi=_Y`03oiMcZ?nGM:WoUgBY00;o
UgBY1OnHMJX3oiQf[0CoVGR]1OnINJh00onJNk3oXXNhoj:7^002oj:7^0CoXhVi1OnTRkX00onUS[co
/JC;ok6Tb`02ok6Tb`Go/JG<00?o/ZK=ol7Ai_o1dNH00_o1dNH00oo1cNCo_?3cokc`l`02okc`l`04
og;OaOm@anooD<O_oe37k`?o000000?oRJk^o`000?n9/o400_n9/o45ohVfl`CoS;Sd1?n>^O<2oi2i
lP;oT:o[1OnA/^hEooooo`03o`000?oooooooooo03Oooooo000]ooooo`?o0000>?ooool3oical@?o
[jcD1On_Z]<00on]ZM?oWhFgoin5]`04oib2]PCoV7jf0onCN[D5ohig]@?oRgFe1?n=M[@3oi5h/`;o
VGbc0_nIO;84oin1/PCoXX:`1OnSP:h2oimm[@03oij0/_nIN:coVGR/00?oVGR/0onFLZP4oiA_YPWo
TfjU0onCKjH01?nCKjOoUg>XoiMcZ?nGLjP5oiMdZ@CoV7FZ0onHMZ`5oiUh[@?oVGV^00?oXHJgoj:7
^?nRQkP00onRQkP5oj>9^@?oY8^j00?o/:?:ok6TbonaY</00onaY</4ok6Uc003ol7EjOo1dNKo`M7V
00;o`M7V0oncm_401?nll??oSJ7RohfQh_n;Z>T3o`000003oh^XjOn9[^koRJk^00;oRJk^00Co0000
ohVclOn9/o7oRK?a1?n9]_<2ohbhm0;oTJKT1OnAZnP4oi2_j`GoTK;^5Oooool00ol0003ooooooooo
o`0fooooo`00;?ooool2o`0003Sooooo0onQlO<00on`[MGo[jcDojn/e002ojn/e0Co[j[C00?oXHNh
oin5]onOQKL00_nOQKL4oib2]P?oV7jf1?nCN[D4ohig]@?oRgFe1?n=M[@2oi5h/`03oi5f/_nIO;;o
VGbb00;oVGbb1?nOPK85oj:2/0?oXh2^00CoY8^joij0/_nNP;;oWX2b1OnIN:`3oiIbZ0CoU6nV2OnC
KZD2oi=_YP03oiMbZ?nGLjSoUg>X00?oUg>X1?nGM:T4oiQeZPCoV7J/1?nIN:d00onINJkoXHJgoj66
]`02oj66]`CoXXNh1OnSRKT00onTRk[o/:?:ok2SbP02ok2SbPGo/JC;00?o/JG<ol7EjOo1eNT00_o1
eNT01oo1dNKo/oKaok?flOncm_7o0000ohnJf_n=XN800ol00005oh^Xj@CoRJk^00?o0000ohVclOnB
VmT01?nAXMl5oi6Vi0GoTJ_X1?n@[n/2oi6bkP?oU[3Y5Oooool00ol0003oooooooooo`0eooooo`00
;?ooool3o`0003Cooooo0onUl_@00onQlO?o/:gEok2]e@02ok2]e@Co[jcD00?o[j[Coj67^?nQQkP0
0_nQQkP3oin5]`CoW8:f1?nHO[H3oi=j]@;oSWNe0_n<KZ`3ohU^[PCoS76`0onAM[85oiUl/P?oWh6b
1OnRP[001?nSP:koY8^jojB;^_nTRkX4oij0/PCoVGR/1?nFLZP3oiA_YPWoTfjU00?oTfnVoiMbZ?nG
LZP01OnGLjP4oiMdZ@CoV7FZ1?nHMZ`2oiUh[@;oXHFf1OnQQ[L5oj:7^0?oXhVi00?o[j;:ok2Sb_n`
XlX00on`XlX4ok6Tb`;o`=_]0oo1eNT2oj?fj@03o`000?n?V][oSi[J00?o00001?n=XN82oh^Xj@;o
U93<1?nCU]<01?nBVmWo0000oi:KfOnBVmT4oi6Qg`GoTJKT0_nAZnP2oiNRg0GoUZWS1OnF/>TDoooo
o`03o`000?oooooooooo03Gooooo000/ooooo`04o`000?oooooo0000o`00037ooooo1?nUl_@00on`
[]Go/:gEok2]e@04ok2]e@;o[jcD00?oXXVioj67^?nQQkP00onQQkP3oin5]`CoW8:f1?nHO[H2oi=j
]@03ohm_Zon<KZcoS6j/00;oS6j/0on9KZh4ohaa/0CoTGJb1?nIO;84oin1/P?oXX:`00?oZ9K3ojB;
^_nTRkX00onTRkX3oij0/PCoVGR/1?nFLZP4oiA_YPKoTfjU0_nFLJL4oiMbZ0CoUg>X1?nGM:T5oiQe
ZP;oV7J/00?oX8Beoj65]_nQQKH00onQQKH4oj66]`GoXXNh00?oXhViojnRb_n_X/X00_n_X/X5ok2S
bP03ok6Tboo0fngo`=_]00?o`=_]00Co`MGYoj?fjOnATm;oTI?B0ol00003ohnJfP;oSJ7R0_nFR/D5
oiB@c0CoTiKC00?o0000oi:KfOnBVmT01OnAXMl2oi6Vi0;oV9_F1OnGX]`5oiJYh`;oU[3Y0_nO/nHC
ooooo`03o`000?oooooo000000Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool01Oo^k^ko<S8bo`000?l@413oc<c<01Wooooo000/ooooo`;o00000_ooool00ol0003ooooooooo
o`0/ooooo`?oZO;e00?o/JoFok2^eOn`[]D00_n`[]D4ok2]e@03oj>:^_nRRKWoXXVi00;oXXVi1?nQ
QkP4oin5]`?oW8:f0_nHO[H2oi9aZ`?oSfn[1On<KZ`3ohU^[PCoS76`0onAM[84oiUl/PCoWh6b00?o
XX:`ojRF`onXU/<00_nXU/<4ojB;^P?oWX2b1?nIN:`4oiIbZ0CoU6nV0onCKZD00onDL:OoUW6WoiIa
Y`02oiIaY`CoUg:X1?nGLjP4oiMdZ@GoV7FZ00CoV7J/oj24]OnPQ;GoX8Be1?nQQKH5oj66]`?oXXNh
1_n_X/X4ok2SbP;o_n7`1?o0fnd00on;kMSoThg:o`000002o`000003oi6Cd_nHPKWoUhFo00?oUhFo
1OnFR/D4oiB@c0CoTiKC00CoTY_Io`000?nBVmWoTY_I0_nAXMl2oiREc`GoV9_F1OnGX]`2oiJYh`;o
Wj_O1OnO/nHEooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q01Wooooo000[ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0:_ooool2ojWbm@Co/JoF1?n`[]D00on`[MGoXhZjoj>:^P02oj>:
^P?oXXVi1OnQQkP3oin5]`;oW8:f00?oUGB[oi9aZonBLJ/00_nBLJ/4ohm_Z`CoS6j/0on9KZh4ohaa
/0?oTGJb1OnIO;82oin1/P03ojRLb_nXU/?oZ9K300?oZ9K31?nTRkX3oij0/PGoVGR/0onFLZP4oiA_
YP04oi=^YOnDL:OoU72WoiA`Y`GoUW6W0onGLZP4oiMcZ0GoUgBY0onHMJX00onOPkCoX8Beoj24]@02
oj24]@CoXHFf1OnQQ[L00onRQkSo[j;:ojnRbP06ojnRbP?o/:?:1?nohO000oo0fngoRngHoh_]f002
o`000003oi>=b_nIO[CoV86i00?oV86i1?nGQKl4oiJ:a@GoU93<0_nCU]<01OnJR/;oVHo8oiV?b?l0
003oVHo800GoV9G?1OnHVmH2oiNRg0;oX:CI1OnOZml4oinciQGooooo00?o0000ooooooooool01Ooo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Iooooo`00
:oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Oooooo0_n/l_D00onb/=Ko/JoF
ok6_eP03ok6_eP?o/:kE00?oXhbloj>:^_nSR[X00onSR[X3oj:9^@GoXHNh0_nOQKL01?nGMZ_oUGB[
oiEdZonEM:/5oi9aZ`?oSfn[1?n<KZ`3ohU^[PCoS76`1?nAM[84oiUl/P04oin1/_nXW<[oZ9c:ojRL
bPCoZ9K31?nTRkX4oij0/PCoVGR/0onFLZP2oiA_YP;oTVnW1OnDL:L4oiIaY`?oUg:X1OnGLjP4oiMd
Z@04oiQeZ_nOPkCoWh>doin3]0GoX8Be1?nQQKH3oj66]`03ojjRbon_X/[o[j;:00So[j;:00?o/:?:
okoQl?nohO000_nohO001OmZfK_o0000o`000?l0003oThg:00?oVGjd1?nHPKT4oiN5_`GoUX[50_nD
T<`2oiZ5_0CoVX[200CoVHo8o`000?nISlSoVHo81?nHULl4oiRKeP03oj2Nd_nPY=WoX:CI00?oX:CI
1?nOZml2oinciP?oZ;WU5Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00002oooool01Ol0003oV9RHoooooonHV9So8B4Q01Wooooo000[ooooo`?o00001Oooool00ol0003o
ooooooooo`0Tooooo`?o[?;e0onb/=H5ok6_eP04ok2^eOnSS;coXhbloj><_0CoXhZj1?nRRKT3oj67
^004oiUg[?nGMZ_oUgJ[oiMfZ`CoUGB[1?nBLJ/3ohm_Z`CoS6j/0on9KZh5ohaa/0?oTGJb0_nIO;82
oj6Ic0CoZ9c:1OnXU/<4ojB;^P?oWX2b1?nIN:`2oiIbZ003oi1^ZOnBKjOoTVnW00;oTVnW1OnDL:L4
oiIaY`?oUg:X1OnGLjP3oiMdZ@KoWh>d1?nPQ;D4oj65]P03oj66]on^X/_o[Z;;00;o[Z;;2?n_X/X3
okcWl`05okoQl?l0003o0000o`000?nDQ/800_nJNk05oiUn]0?oV86i1?nGQKl4oiJ:a@03oi^2]onJ
QKcoVXFl00?oVXFl0onJR/82oiV?b003o`000?nISlSoV9G?00CoV9G?00?oV9_Foj2Nd_nPW]800_nP
W]84oj2Tf@?oWj_O00?oZ;;OojRiiOnX^ND01?nX^NDEooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`06Oooool002_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Qooooo`?o[o7f00?o/k;Gok:`e_nb/=H0
0onb/=H2ok6_eP;oY8jm1?nSS;`5oj>:^P?oXXVi00CoXHNhoiUg[?nIMjcoVGN/1?nGMZ/3oiEdZ`Co
TW6[0on?Kj/4oha^[0CoRFj^1?n<LK02oi5f/P03oiV>a_nQVLcoXIW<00?oXIW<0onXW<X5ojRF``Co
Y8^j0_nNP;800on>LZooSVn[ohi_Z`02ohi_Z`?oT6jY1OnBKjL4oiA`Y`CoUW6W1?nGLZP4oiMcZ003
oiMdZOnOPkCoWh>d00KoWh>d1?nPQ;D3oj65]P03ojfRc?n^X/_o[Z;;00?o[Z;;1_n_X/X3okcWl`?o
00000_nJN:`4oiYk/0GoVGjd1?nHPKT4oiN5_`03oiJ:aOnKP[OoVh:g00;oVh:g1?nJQK`3oiZ:`P?o
VHo800Co0000oiV?b?nHULooV9G?0_nQV<`5oj2NdPGoX:CI00CoWj_OojRbgonX/]ooZ;;O1?nX^ND0
0on``>Goooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo01_ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool07oooool2ojoamPCo/k;G0onb/=H00onUSkkoY8jmojB>_@03ojB>_@?oXhbl1OnSR[X2
oj:9^@03oiYi[OnIMjcoVGN/00;oVGN/1?nGMZ/3oiEdZ`CoTW6[1?n?Kj/4oha^[0?oRFj^0_n<LK02
oi>1_@CoVHk61?nQVL`4ojRLbP;oZ9K30_nCO[T4ohmg]0?oSW:_1?n>Kj/4oi1^Z@CoTVnW1?nDL:L4
oiIaY`CoUg:X0onGLjP:oin3]0GoX8Be00CoXHFfojfRc?n]X/co[J;<1?n^X//4ojnRbP;o^>ge0ol0
00000onJMZWoVWR/oiYh[002oiYh[0GoVW^`1?nIO[@4oiR1^@;oUhFo0_nLOk85oi^2]`CoVXFl1?nJ
R/82oiV?b003oj:Da_l0003oXIS<00CoXIS<1OnPW]82oj2Tf@;oZJcI1OnX/]l00onX^NGo/<3Uok30
i@02ok30iA?ooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@
oiRHV00Kooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o0000
00?o410@ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo
0onbl?H2okFce`Go/k;G00Co/[3FojF?__nUSkkoYHnn1?nTS[d4oj><_0?oXhZj00CoVW^_oiYi[OnJ
NJgoVWV]1?nIMj`4oiMfZ`?oUGB[1OnBLJ/3ohm_Z`CoS6j/0_n9KZh00on@Mk?oTh6moi>1_@03oi>1
_@?oVHk61OnQVL`2ojRLbP03oiR4_?nCO[WoTgji00;oTgji1?n?Mk@4ohib[`CoSVn[0on@KZT4oi9_
Y`CoU72W1OnFLJL3oiMbZ003oiMcZ?nOPkCoWh>d00_oWh>d0onPQ;D5ojfRc0Go[Z;;00?o[j;:okS]
mOl000000_l000001?nEN;3oUGbeoiYfZOnJMZT5oiYh[0CoVW^`1OnIO[@2oiR1^@03oiel[onLOk;o
W7nb00?oW7nb1?nKP[L5oiZ5_0;oVX[200KoXi31oj:Da_nRU<KoXYC6o`000?nRU<H4oj6Hc0CoX9kB
00?oZZODojV/fOnY[=T00onY[=T3ojRbg`;o/KcR1On``>DEooooo`09o`000?ooooooooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@6Oooool0013ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`?o00002_oo
ool00ol0003oooooooooo`0Gooooo`Co]Nof00?o/_3fokFceone/mL00_ne/mL3ok>be`03ojNA_onU
SkkoYHnn00;oYHnn1?nTS[d4oj><_004oj>:^_nJNjooVW^_oiYk[`CoVWV]1?nIMj`3oiMfZ`?oUGB[
1OnBLJ/2ohm_Z`03oi5_Z?n@LZgoT7:]00;oT7:]1?n@Mk<4oi>1_@?oVHk61?nQVL`01?nLQ[_oV8Bl
oiR4_?nHQ;`5oi=n^@?oSgNd1?n>LZl4ohi_Z`?oT6jY1?nBKjL5oiA`Y`CoUW6W0_nGLZP00onNP[Co
Wh>doin3]00<oin3]003oj24]On]X/co[J;<00Go[J;<1?n^X//3o`000004okS]mOnEN;3oUGR`oiYd
Y`CoVWJY1?nJN:`4oiYk/0GoVGjd00?oV86ioiel[onMO:l01OnLOk85oi^2]`CoVXFl00CoVX[2oj>@
`OnST<7oXi310onRU<H00ol0003oXIS<oj6Hc003oj6Hc003oj2Nd_nZYmCoZZOD00;oZZOD1?nY[=T0
0onX/]oo/KcRok6lhP03ok6lhP;o/<3U0_neanLEooooo`03o`000?oooooooooo02oooooo0008oooo
o`Ko00000_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00005ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool05Oooool4okG_mP03okJef?ne/mOo]K?G00Co]K?G00Co/k;G
ojNA_onWTKooYi6o0onUSkh5ojB>_@;oXhbl00?oVgb`oiYk[onJNjl00_nJNjl4oiYi[@CoVGN/0onG
MZ/4oiEdZ`?oTW6[00CoTVjVoi5_Z?nAKjSoTFnX1?n@LZd4oi1g/`CoTh6m1?nIS/H00onQVLcoW8Jk
oib6^`02oib6^`?oV8Bl1?nCO[T3ohmg]0CoSW:_1?n>Kj/3oi1^Z@CoTVnW1OnDL:L3oiIaY`04oif0
/onNP[CoWX:doij2]0goWh>d00?o[:?>ojfRc?n]X/`01on]X/`01?n^X/_o0000o`000?n`l_D2oiAe
[@04oiEh/?nJM:OoVWBWoiYdY`CoVWJY1?nJN:`5oiYk/0?oVGjd00?oWGZ/oiel[onMO:l00_nMO:l4
oiao/PGoVh:g0_nJQK`2ojB=_0CoXi311?nRU<H00ol0003oXIS<oj6Hc002oj^Tc`GoZZOD0_nY[=T3
ok:jg`Co/KcR00?o]lWXokG7ioneanL00oneanLEooooo`03o`000?oooooooooo02kooooo000@oooo
o`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00006ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool04_ooool4okS]m@04okG_m_nf]MSo][GHokJef0Co]K?G
00?oZ9C0ojNA_onWTKl00_nWTKl4ojF?_P?oY8jm00CoW7jaoi]l/?nKO;3oVgb`1?nJNjl4oiYi[@Co
VGN/1?nGMZ/3oiEdZ`04oi9aZonBKZKoTVjVoi9^YPCoTFnX0on@LZd4oi1g/`GoTh6m0_nIS/H00onN
QKSoW8Jkoib6^`03oib6^`?oV8Bl1?nCO[T4ohmg]0?oSW:_1?n>Kj/3oi1^Z@GoTVnW1?nDL:L01?nF
LJOoWH2coif0/onMP;<4oij2]0[oWh>d1?n/Xlh6ojfRc0?o000000?oUG>ZoiAe[OnDMJd00_nILZD5
oiYdY`?oVWJY1?nJN:`5oiYk/004oiUn]?nMNZcoWGZ/oiej[0CoWGb_1OnLOk83oi^2]`03ojF;^OnT
SKcoY8fl00;oY8fl1?nST<44oj:DaP03o`000?n[Y<ooZjC?00?oZjC?0onZYm@00ond^Mgo/[[Ook:j
g`04ok:jg`03ok6lh_ngbNSo]lWX00;o]lWX0oneanL2okC:jaGooooo00?o0000ooooooooool0;Ooo
ool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0@ooooo`Co^>ge00?o^;KHokJef?nf]MP0
0onf]MP00one/mOoZ9C0ojRD`002ojRD`0?oYi6o1?nUSkh01?nTS[goW7jaoian/OnLO[44oi]l/0Co
VW^_0onJNJd4oiUg[0CoUgJ[0_nEM:/00onBKZGoTVjVoi9^YP02oi9^YPCoTFnX1?n@LZd4oi1g/`?o
Th6m00?oWh6boij5^?nNQKP00_nNQKP4oib6^`?oV8Bl1?nCO[T4ohmg]0?oSW:_1?n>Kj/4oi1^Z@Co
TVnW0onDL:L00onINk7oWH2coif0/`03oif0/`?oWX:d2?nOPk@00on/Y<oo[:?>ojbScP03ojbScP?o
[J;<0ol00002ojGcl@03oiEcZ_nHL:?oVG:U00?oVG:U1OnJM:L3oiYfZ@GoVWR/0onJNk000onNNJ[o
WGZ/oiej[003oiej[0?oWGb_1OnLOk800onKP[OoYH^iojF;^@02ojF;^@CoY8fl1?nST<401OnRU<Ko
[J7<ojfQc?n]XLco000000GoZjC?00CoZZODokBigOnd^Mgo];WM1?nb^]l00onhc^[o]lWXokO9j003
okO9j003okG7iondb^_o]<[[00?o]<[[5?ooool00ol0003oooooooooo`0]ooooo`004?ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool2o`0000oooooo0_l0000>
ooooo`?o^n_d00?o^>geokRff?nh]]P00_nh]]P3okJef003ojZF`_nXU<3oZ9C000?oZ9C01?nWTKl2
ojF?_P03oieo/_nLO[7oW7ja00?oW7ja0onKO;04oiYk[`CoVWV]0onIMj`2oiMfZ`;oTfjU0onBKZD4
oi9^YPCoTFnX1?n@LZd4oi1g/`04oi>1_OnOPK;oWh6boin1/PCoWXFh1OnLQ[/3oiR4_0CoTgji0on?
Mk@4ohib[`CoSVn[0on@KZT4oi9_Y`04oiA`YonINk7oVG^aoiUk/@GoWH2c0onNP[@6oin3]0Co[:C?
1?n/Xlh3o`000005ojfRc?nGlN[oUo7ZoiMcZ?nELjX00_nHL:<5oiUbY@CoVWBW0onJMZT5oiYh[004
oiYk/?nNNJ[oWWVZoiiiZPGoWGZ/0onMO:l4oiao/P03ojJ9]_nURkWoYH^i00?oYH^i1?nTSK`3oj>@
`@03ojnPbOn]XLco[J7<00?o[J7<00Go0000oj^Tcon[Y<ooZjC?okJjg005okBig@03ok:jgonhc^[o
^<kZ00;o^<kZ0ongbNP2okGAkPCo]<[[00?o[l_^ooooooooool04oooool00ol0003oooooooooo`0/
ooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo1?nkjo@00oni^=So^;KHokRff004
okRff004okJef?nZU/;oZYK2ojZF`PCoZ9C01?nWTKl00onUSkkoWGnboieo/P05oian/@?oVgb`1?nJ
Njl4oiYi[@;oVGN/00?oTfjVoi=^YOnCKZD00_nCKZD4oi9^Y@?oTVjV1?nAKjP4oi1b[@?oT7Nc00?o
Wgf^oin1/_nOPK800onOPK83oij5^0GoW8Jk0onHQ;`4oi=n^@?oSgNd1?n>LZl4ohi_Z`?oT6jY0_nB
KjL2oiAe[PGoVG^a1?nMP;<4oij2]0?oWh>d00?o[JKAojbTcon/Y<l00on/Y<l01_n/Xlko0000o`00
0?l0003o[:?>ojfRc0;oUo7Z0_nGLjP5oiQ`X`CoVG:U1?nJM:L4oiYfZ@?oVWR/00?oWgVXoiiiZ_nN
NJX00onNNJX4oiej[0CoWGb_0_nLOk82ojJ9]PGoYH^i1?nTSK`00onST<7o[j39ojnPb@02ojnPb@Go
[J7<00?o0000okJjg?nf^]`00_nf^]`3okBig@;o^MC]1Onhc^X00ongbNSo]M7^okGAkP02okGAkP03
okC:jon_bnko[l_^00;o[l_^4oooool2o`0002kooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03Oooool00omgMgOo0000ooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool01_ooool4okgXl`04ok_[m?ni^=So^KSHokVhf0Co^;KH00?o[9W4ojZF`_nZU/800_nZU/85ojRD
`0;oYi6o00?oWX:doieo/_nMOk800_nMOk84oian/@?oVgb`1?nJNjl2oiYi[@;oU72W0onCKZH4oi=^
Y@CoTVjU1?nBKZH3oi5_Z0CoT7:]00CoT7Ncoimm[_nOOJkoWgf^1OnOPK84oij5^0?oW8Jk00CoTFRO
oh]TWon;I9ooRfBO1?n6HJ03oh=OX@CoPf:T1?n7IZL3ohe^ZPCoU7F^1OnINk44oif0/`CoWX:d00?o
Wh>dojfVdOn]Y]400_n]Y]42ojbTc`?o00000_n/Xlh2ohG[g`;oV7:V00?oUg>XoiQ`XonHL:<01OnH
L:<4oiUbY@CoVWBW1?nJMZT01?nJN:coWgVXoimiZ?nONJP5oiiiZPCoWGZ/1?nMO:l00onLOk;oYXVf
ojJ9]P02ojJ9]PGoYH^i0_nTSK`00onaXLSo[j39ojnPb@03ojnPb@Co[J7<00?o^;cLo`000?nf^]`0
0onf^]`00ond^Mgo^MC]okWDk@03okWDk@;o^<kZ0ondfO<2okGAkP?o[]?d1?n_bnhEooooo`03o`00
0?oooooooooo02_ooooo000Yooooo`;o00005?ooool00ol0003oooooooooo`04ooooo`Co_NSc00?o
^[[IokVhf?ni^=P00oni^=P00onh]]So[9W4ojbIa002ojbIa0?oZYK21?nXU<001?nPQ;GoWX:doij2
]?nNP[@4oieo/PCoW7ja1?nKO;02oiYk[`03oiAaZ?nDL:OoU72W00;oU72W1?nCKZH3oi=^Y@CoTVjU
1?nBKZH4oi5_Z0;oT7:]00?oWGVZoimm[_nOOJh00onOOJh4oin1/PCoWXFh00CoW8Jkoi5XWonAJ9oo
TFRO0on;I9l4ohIQX0?oPenQ1?n3HZ@4ohMVY`?oSFjZ1OnDMJh4oiUk/@GoWH2c0_nNP[@00on^Z=;o
[JKAojfVd@02ojfVd@?o00000_n/Y<l2og3OcP;oVG:U0_nHLZH00onJL:;oV72SoiQ`X`06oiQ`X`Co
VG:U1OnJM:L2oiYfZ@03oimhYonONJSoWgVX00?oWgVX1?nNNJX5oiej[0;oWGb_00?oYhVdojJ9]_nV
RKH00onVRKH5ojF;^@04ojB=_?naXLSo/J78ok6Qb0Go[j3900?o[J7<okRlg?nh_=`00_nh_=`00ol0
003o][[LokJjg002ok_Ml@Co^MC]00?o/N;hokCIlondfO<00_ndfO<2ojWLn@Go[]?d0_n_bnh2ojK5
kaGooooo00?o0000ooooooooool0:_ooool002Wooooo00?o0000ooooooooool05?ooool01?l0003o
ooooooooooooool3okoTl@03okgXlonj^]Wo^[[I00;o^[[I0oni^=P00on^W<Go[9W4ojbIa003ojbI
a0CoZYK200CoZ9C0oj24]OnPQ;GoX8Be1?nNP[@3oieo/PGoW7ja0onKO;000onJNjooU76XoiAaZ004
oiA`Y`CoTfjV0onCKZD4oi9^Y@CoTVjV1?nAKjP00on@LZgoWGVZoieiZP05oimm[PGoWh6b0_nNQKP0
0onGKJ3oTFROoi5XW`02oi5XW`?oRfBO1?n6HJ03oh=OX@GoPf:T1?n7IZL3ohe^ZPCoU7F^1?nINk45
oif0/`05oij2]?n^Z=;o[ZSBojjXd_n]Y]400_l00002ojfVd@03ojbTcom`glkoL=o>00CoVG:U00?o
V7:VoiY`X_nJL:802OnHL:<3oiUbY@GoVWBW00CoVWJYoimhYonON:OoWgRW1?nONJP4oiiiZPGoWGZ/
00CoWGb_ojN9]?nWRKCoYhVd1?nVRKH4ojF;^@03ok>Sb?naXLSo/J7800;o/J781?n_X<T00onl`]ko
^;cLokRlg004okRlg003o`000?nkgO7o^mga00;o^mga00?o^MC]ok7Rn?nah_P00_nah_P00ondfO?o
ZMciojWLn@03ojWLn@;o[]?d0_nTbo@5ojK5kaCooooo00?o0000ooooooooool0:_ooool002Wooooo
00?o0000ooooooooool05Oooool00ol0003o_nCaokoTl@02okoTl@;o^k_I1Onj^]T01?ni^=So[Yc5
ojjLaOn^W<D4ojbIa0?oZYK200?oXHJgoj24]OnPQ;D00_nPQ;D4oij2]0CoWGnb1?nLO[42oi]l/003
oiIbZOnDLJSoU76X00;oU76X0onDL:L4oi=^YPCoTfjU0onBKZD4oi9^YP?oTFnX00?oVgJXoieiZ_nM
NJX00_nMNJX4oimm[PGoWh6b00?oWXFhoiM]X?nGKJ001?nAJ9l4oh]TW`CoQV6P0on3Gj44oh=RY0Co
QfJW0on=KZX4oiAe[PGoVG^a0onMP;<3ojjXdP?o00000on]Y]401?mGc[KoUfnRoiM_X_nGKj83oiUb
Y@04oiabX_nJL:;oVW2RoiY`XPWoV72S1?nILZD3oiYdY`03oimhY_nON:OoWgRW00;oWgRW1?nONJP5
oiiiZP?oWGZ/00?oZ8VcojN9]?nWRK@00_nWRK@5ojJ9]P;oYH^i0oncXlP4ok6Qb003ojnPbOnl`]ko
_<;N00;o_<;N1?nh_=`00onhjOGo^mgao`000002ok_Ml@?oYn_i0_nah_P3oioTo0;oZMci0_nOd?T5
ojC;m0;oY/G_0onP_nhDooooo`03o`000?oooooooooo02Wooooo000Yooooo`03o`000?oooooooooo
01Cooooo1?o0hNl00onoi?7o^k_Iok^kf@02ok^kf@?o^[[I00?o[io7ojjLaOn^W<D00on^W<D4ojbI
a004ojZF`_nQQ[OoXHJgoj66]`CoX8Be0onNP[@4oieo/P;oW7ja0_nFM:X3oiIbZ@CoU76X0onDL:L4
oi=^YPCoTfjU1?nBKZD3oi9^YP04oi5_Z?nKMZSoVgJXoi]fZ0CoWGVZ1OnOOJh3oin1/P04oiaaXOnG
KJ3oUffPoiM]X0CoTFRO1?n;I9l4ohIQX0?oPenQ1?n3HZ@4ohMVY`?oSFjZ1OnDMJh4oiUk/@03oif0
/on^Z=;o[ZSB00?o00000on^Z=800on]Y]7oU6ZOoiAZW`04oiM_XP04oiUbYOnLLZ;oW7:RoiabXPCo
VW2R2?nHL:<4oiUbY@;oVWBW0_nON:H4oimhY`CoWgVX1OnNNJX01?nMNZcoZ8VcojR9/onXRK<4ojN9
]0GoYXVf00?oYH^iok>Sb?ncXlP00_ncXlP4ok6Qb0Ko_<;N00?o^;cLokSYmOnhjOD00_nhjOD01?l0
003oYn_iojO[nOnWjoT3oh[Un@;oWnCl0onHdo`4oio@n@;oY<_d0onN`?05oj2okQCooooo00?o0000
ooooooooool0:?ooool002Wooooo0ol0000Cooooo`Co`>7_00?o_KcIok^kfOnk^mT01?nk^mT01?nj
^]Wo[io7ojnOaon_WlL5ojjLa@;o[9W400?oXhVioj66]onQQ[L00_nQQ[L4oj24]@CoWX:d0_nMOk80
0onGMZcoUWBZoiIdZP02oiIdZPCoUW:Y0onDLJP4oiA`Y`?oTfjV1?nCKZD4oi9^Y@;oTVjV00?oV7>W
oi]fZ?nKMZP00onKMZP3oieiZPGoWgf^00CoWh6boiaaXOnLLJ7oW76Q1?nGKJ03oi5XW`CoRfBO1?n6
HJ03oh=OX@CoPf:T1?n7IZL3ohe^ZPGoU7F^0_nINk42ojbUd0?o00001On^Z=84oiAZW`?oUfnR00?o
WG>RoiabX_nLLZ800_nLLZ84oiY`XPSoV72S1?nILZD00onJM:OoWgRVoimhYP02oimhYPCoWgRW0onO
NJP4oiiiZP03ojZ:/onXRK?oZ8Vc00?oZ8Vc1?nWRK@3ojJ9]P03okNXb_ncXlSo/j?800?o/j?80ona
XLP2oko:h`Co_<;N0_n/lo<2okSYm@?oSnc`00Co0000ofOJion:iOWoR^Gi0on=e?l5oiSCo0;oWm3i
0_nK_o45oik0l0;oX;o^0_nN^^`Cooooo`;o0000:_ooool002Wooooo00?o0000ooooooooool04Ooo
ool4ol7Lk@04ol3Qkonm_=Wo_KcIokflf@Co^k_I00?o/J?9ojnOaon_WlL00_n_WlL4ojjLa@03ojF=
^onSRKWoXhVi00;oXhVi0onQQ[L4oj24]@CoWX:d00?oWGnboiMf[?nGMZ`01?nFM:X4oiIbZ@?oU76X
1?nDL:L4oi=^YP?oTfjU0onBKZD01?nFLJOoV7>WoiQcYonHLjL5oi]fZ0?oWGVZ1?nOOJh00onPMZ?o
W76QoiaaX@02oiaaX@CoUffP1?nAJ9l3oh]TW`CoQV6P0on3Gj44oh=RY0CoQfJW1?n=KZX3oiAe[P03
ojRLbon/YM3o000000;o000000?o[:G@ojjXd_n^Z=800_n^Z=83oi1UW@CoU6ZO0_nGKj82oiecXPGo
W7:R0onJL:89oiQ`X`;oVG:U00?oWgNVoimhY_nON:H00onON:H4oimhY`CoWgVX0_nNNJX2ojZ:/`Go
Z8Vc1?nWRK@00onVRKKo]jS:okNXbP02okNXbPGo/j?800?o/J78oko:honob^<00_nob^<01?nl`]ko
[??cojcclon/lo<3oeoFcP05oho/l?mWf^OoIm[WofOJiol000000_n2dOl4ohgDo`;oV=?l0_nI_O45
oi^ol@;oW/3`0_nM^>/5oijjk1Cooooo00?o0000ooooooooool09oooool000kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool04Oooool4
ol7Lk@03okjnf_nm_=Wo_KcI00?o_KcI00?o^k_Iok6SbOnaXlT00_naXlT4ojnOa`04ojjLaOnUSK_o
YHfkojF=^`CoXhVi1?nQQ[L3oj24]@;oWX:d0_nHN:d4oiMf[0?oUWBZ1?nFLZT3oiAaZ0CoU72W1?nC
KZH3oi=^Y@04oi9^YOnFLJOoUW6WoiIaY`CoV7>W1?nKMZP4oieiZP;oWgf^0_nPMZ<4oiaaX@CoUffP
1?nAJ9l3oh]TW`CoQV6P0on3Gj45oh=RY0CoQfJW0on=KZX00onDMJkoZ9c;o`000002o`0000Go[:G@
00?o[ZSBohaQV_n@IId01?n@IId3oiAZW`04oiM_X_nMLj;oWG>RoiecXPGoW7:R0onJL:89oiQ`X`03
oiUbYOnOMjKoWgNV00GoWgRV1?nON:L4oimiZ003oiiiZ_nZR[?oZXZc00;oZXZc1?nXRK<4ojN9]0Go
]jS:1?ncXlP00oo2f>_o_l[Soko:h`02oko:h`?oPn[G00?o[??cogO4o_mga?h01Omhbol01?n2dOoo
0000oiB`jOnD/>T4oiJhk`GoVKga0_nK_o42oibdj0GoWKS[1?nN^^`Eooooo`03o`000?oooooooooo
02Kooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo00oooooo0oo2f>X00oo1g>go_[kJokjnfP02
okjnfP?o_KcI00?o]:O;ok6SbOnaXlT00onaXlT3ojnOa`03ojJ@__nUSK_oYHfk00;oYHfk1?nSRKT4
oj66]`;oX8Be00?oVGZ_oiQh[OnHN:d00_nHN:d4oiMf[0CoUWBZ0onFLZT4oiAaZ0?oU72W1?nCKZH2
oi=^Y@03oiA`YonFLJOoUW6W00?oUW6W0onHLjL4oi]fZ0CoWGVZ00CoWgf^oj1fXonPMZ?oX7JS1?nL
LJ44oiM]X0CoTFRO0on;I9l5ohIQX0?oPenQ1?n3HZ@4ohMVY`;oSFjZ0ol00003ojRLb`Co[:G@0on<
HIX5oi1UW@;oU6ZO00?oWW>QoiecX_nMLj800onMLj84oiabXP?oVW2R2?nHL:<00onNMZGoWgNVoimg
YP02oimgYPCoWgRV1OnON:L2oimiZ003ojb<]OnZR[?oZXZc00?oZXZc1OnXRK<2ojN9]0;o^jo>1Ong
Z<X00oncXlSo`]S[ol;Hj`02ol;Hj`04oko:hon3j]OoPn[Goh?Ze`?oO;Si0omga?h2ogS;o`;oU:GQ
0_nD/>T00ol0003oU;3YoiB`j@04oiJhk`;oVKga0_nL[nD5oibdj0CoWKS[0_nN^^`3oj2hjQCooooo
00?o0000ooooooooool09_ooool000Kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP06ooooo`;o00003_ooool5ol;HjP03oknof_nn_][o_[kJ00?o_[kJ
00Co_KcIokBWbondYl_o]:O;1OnaXlT01?n_WlOoYY2nojJ@__nVT;h4ojF=^`CoXhVi0_nQQ[L01?nJ
O;7oVGZ_oiUj[onINZl5oiQh[@?oUgJ/1?nFM:X3oiIbZ@CoU76X0onDL:L2oi=^YP;oTVnX0onDL:L5
oiIaY`?oV7>W1?nKMZP4oieiZPGoX7JS0onLLJ44oiM]X0CoTFRO1?n;I9l4ohIQX0?oPenQ1?n3HZ@2
ohMVY`;oUh>k0_l00002oj2@a0GoZ9c;00?o[:G@oh]NV?n;GYP01?n<HIX4oi1UW@03oiAZWonNLj7o
WW>Q00GoWG>R1?nLLZ84oiY`XPGoV72S0onNMZD4oimgYPCoWgRV1OnON:L01?nONJSo[8beojb<]On/
S;D4ojZ:/`GoZ8Vc00CoYhVdok^_c_nk[lko^jo>1?ngZ<X2oko[lP?o`]S[00Co0000ohNYk?n7ZNco
QjW/0_ml^?T2oiN@bP?oUY[F1OnDYN42oiB`j@03o`000?nD/>WoU;3Y00;oU[S_00?oW:WOoib_iOnL
[nD00onL[nD5oibdj0;oWKS[0_nP/nH5oj2hjQCooooo00?o0000ooooooooool09Oooool000kooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000oooooooo
ool02oooool3ol;Di`?o`]SZ0ono_mX3okjnfP03okJ[c_ndYl_o]:O;00;o]:O;1?naXlT00onYU<7o
YY2nojJ@_P02ojJ@_PCoYHfk1?nSRKT00onQQ[OoVWbaoiYl/@04oiUj[`CoV7R]0onGMZ`4oiIdZPCo
UW:Y0onDLJP2oiA`Y`03oi9`ZOnBKjSoTVnX00;oTVnX1?nDL:L4oiIaY`?oV7>W1OnKMZP2oieiZP03
oj5iY_nPMZ?oX7JS00?oX7JS1?nLLJ43oiM]X0CoTFRO1?n;I9l4ohIQX0?oPenQ0_n3HZ@2oi1h]005
oiN3^ol0003o0000o`000?nGPk/00onPT<@4ojRLb`CoRejH1?n<HIX3oi1UW@04oi]`X?nNLj7oWW>Q
oiicX@GoWG>R1?nLLZ84oiY`XP?oV72S00?oW7FVoiifYOnNMZD00onNMZD3oimgYPGoWgRV0onON:L0
0on^T;Oo[8beojb<]@02ojb<]@GoZXZc0onXRK<00oo0^mKo^jo>ok^_cP03ok^_cP03okNXb_nojo;o
_n_b00?o_n_b00Co`]S[ohnJf_n7ZNcoQjW/0_nJR;l4oiN@bPCoUY[F1OnDYN42oiB`j@03o`000?nM
XmWoW:WO00?oW:WO1OnL[nD2oibdj0;oX:kQ1OnP/nH2oj2hjP;oYK_Y5Oooool00ol0003ooooooooo
o`0Tooooo`003_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01?oo
ool00ol0003oooooooooo`0:ooooo`Go`]CW00?o`]SZoknof_no_mX00ono_mX01?nn_][o]Z_>okJ[
c_nfZlh4okBWb`03ok6SbOnYU<7oZIC100;oZIC10onVT;h4ojF=^`;oXhVi0_nKOk<4oiYl/@?oVGZ_
1?nHN:d3oiMf[0CoUWBZ1?nFLZT2oiAaZ004oi9aZOnBL:WoTW2Yoi9`Z@GoTVnX0onDL:L4oiIaY`?o
V7>W1OnKMZP00onMNJ[oXGVVoj5iYP05oj1fX`CoW76Q1?nGKJ03oi5XW`CoRfBO0_n6HJ02ohe^Z`?o
S72^0_n@N;@3o`0000CoUh>k1?nPT<@00onXW<_oRUfGohYMU`05oh]NV0?oS66J0_n@IId2oi]`X0Co
WW>Q1?nMLj85oiabXP?oVW2R00CoV72SoiaeY_nLMJKoW7FV1OnNMZD3oimgYPGoWgRV0_nON:L2ojj@
]`Co[8be1OnZR[<00onXRK?o`;_Fol2keP02ol2keP?o^jo>0onUm^X2oko[lP04oiF=b?n?V][oSi[J
oif3]`GoVXRo1?nGT<X4oiJJeP;oU:GQ0_nOW=42oifSf@03o`000?nMXmWoWJ?I00CoW:WO0_nL[nD2
oj6Yg0GoX:kQ0_nP/nH2ojFfi@GoYK_Y4oooool2o`0000Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Wooooo000>ooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`;o00002Oooool2ol;?i@Co`]CW
0_o0`=X4oknofP03okR_d?nfZlko]Z_>00?o]Z_>0_ndYl/00on[VLCoZIC1ojVD`@03ojVD`@CoYY2n
0_nUSK/00onMP[KoVgncoi]o/`02oi]o/`CoVWba0onINZl4oiQh[@CoUgJ/0onFM:X2oiIbZ@;oTg:[
0onBLJT4oi9`Z@CoTVnX0onDL:L4oiIaY`CoV7>W0onKMZP00onQNjWoXGVVoj5iYP02oj5iYPCoX7JS
1?nLLJ44oiM]X0?oTFRO0_n;I9l2oi1^Z@CoSFj[0_n<L:h3o`0000?oT7Rd1?nGPk/4oj2@a0CoRUfG
1?n;GYP3ohaQVP04oi1UWOnKL:3oVg2Poi]`X0CoWW>Q1?nMLj85oiabXP;oVW2R00?oWGNWoiaeY_nL
MJH00_nLMJH5oiifY@?oWgNV1OnON:H00onON:Oo[Y2gojj@]`02ojj@]`Co[8be0onZR[<00oo5cn;o
`;_Fol2keP03ol2keP05ok^_c_nUm^[oYOKZojGfj_nJQ;/00_nESLP2oimo/0CoWH>g1?nJR;l4oiN@
bP;oUY[F0_nQU/T5oinLd@;oWJ?I00Co0000oifSfOnLZMooW:WO0_nSY=H5oj6Yg0;oX:kQ0_nV/^45
ojFfi@?oYK_Y0_nY_^PDooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Wooooo000>ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo0_l00008ooooo`Go
`/oU00?o`]CWol30f_o0`=X00oo0`=X00ono_m[o^:o@okR_d002okR_d0?o]Z_>00?o[Yg7oj^Ia?n[
VL@00_n[VL@4ojVD`@CoYY2n00?oYHfkoif2]_nMP[H01OnKOk<3oiYl/@?oVGZ_1OnHN:d3oiMf[0;o
UWBZ00?oTg>/oi=bZonCLZ/00_nCLZ/4oi9aZ@?oTW2Y1?nBKjP3oiA`Y`GoUW6W0onHLjL01?nKMZSo
XG^Yoj5kZOnQNjT4oj5iYPCoX7JS1?nLLJ44oiM]X0;oTFRO00?oU76Xoi1^ZOn@KZT00_n@KZT3ohe^
Z`?o00000_n<L:h4oi1h]0GoUh>k0_nPT<@2oh]MU`?oRUfG1?n;GYP2ohaQVP03oiQ/W_nKL:3oVg2P
00?oVg2P0onNLj44oiecXPGoW7:R00?oVW2RoiegYonMMjL01OnLMJH4oiifY@CoWgNV0onON:H00ona
U[_o[Y2gojj@]`03ojj@]`Co[8be00?oZXZcolG?h_o5cn800_o5cn83ol2keP03oeS<ZOnJQ;_oVXBk
00;oVXBk00?oXgj/oimo/?nOOk000onOOk03oif3]`GoVXRo0_nGT<X00onTT/;oXIK9oj6Fb@03oj6F
b@GoWicA0_nMXmT00ol0003oXjCFoj>TeP03oj>TeP?oXJWL00?oZ:oMojJbhOnV/^400onV/^45ojFf
i@03ojFkjOnY_^SoZKkX00;oZKkX5?ooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000000Wooooo000>ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo00?o0000ooooooooool0
1_ooool2ol7;hP?o`/oU0oo1`MX3ol30fP03okZbd_nh[m3o^:o@00Co^:o@00Co]Z_>ojjMaon^WLOo
[Yg71?n[VL@4ojVD`@;oYY2n00?oWXJhoif2]_nMP[H00_nMP[H4oi]o/`?oVWba1?nINZl4oiQh[@;o
UgJ/00CoU7B]oi=c[?nCLjcoTg>/1?nCLZ/4oi9aZ@?oTW2Y1?nBKjP3oiA`Y`GoUW6W0_nHLjL00onO
O:goXG^Yoj5kZ@02oj5kZ@CoXGVV1?nPMZ<4oiaaX@?oUffP00CoVWNZoiAaZ?nDLJSoU76X1?n@KZT3
o`0000;oSFj[0on<L:h4oi1h]0GoUh>k00CoX934oh]MUon;GIOoRefG0on:GIL4oh]NV003ohaQV_nH
K9koV6bN00GoVg2P0onNLj45oiecXP?oW7:R00CoXG^ZoiegYonMMjOoWGNW1OnLMJH4oiifY@CoWgNV
0_nON:H3ok6F^`Co[Y2g1?n/S;D6olG?hP04ol2ke_nMO[7oWGjaoien/@;oVXBk0_nSOZ`5oimo/0?o
WH>g1?nJR;l00onWSkcoY9;2ojBB`P02ojBB`PGoXIK90_nOW=42ojNLb`?oYIo@00?o0000oj>Te_nS
Y=H00onSY=H01?nQZMcoZ:oMojR_gOnX[md5ojJbh@;oYKKU0_nZ_>H4ojVnj003ojc2jOoooooooooo
01;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8b
oiRHV?ooooooV9RHoc8b<P09ooooo`009oooool00ol0003oooooooooo`05ooooo`Co`L_R00?o`/oU
ol71f_o1`MX00oo1`MX01?o0`=[o^[;BokZbd_nj/]84okR_d003ok6Sb_n^WLOo[Yg700;o[Yg71?n[
VL@3ojVD`@03oj69^onNQ[SoWXJh00;oWXJh0onMP[H4oi]o/`CoVWba0onINZl2oiQh[@;oU7J_0onD
M:d4oi=c[0?oTg:[1?nBLJT3oi9`Z@CoTVnX1?nDL:L4oiIaY`03oiQcYonOO:goWgb]00CoXG^Y1?nQ
NJH5oj1fX`?oW76Q00CoUffPoiYgZ_nJMj[oVWNZ1?nDLJP3o`000003oi1^ZOn=KZ_oSFj[00;oSFj[
0on<L:h5oi1h]0?oUh>k00?oSEjFoh]MUon;GIL00_n;GIL3ohYMU`;oRejH0_nDJId3oiQ/WPGoVg2P
0onNLj45oiecXP;oW7:R0_nQNjX4oiegY`CoW7FV1OnNMZD3oimgYP03oimhY_naU[_o/IJk00;o/IJk
1On^T;L2ojb<]@;oa>_`1?o5cn800onPO:_oWGjaoien/@02oien/@03oiZ4^onSOZcoXgj/00;oXgj/
1?nOOk04oif3]`03oiZ8_onWSkcoYhnl00;oYhnl0onTT/84oj6Fb@03oj^KaonWW<_oYic;00;oYic;
0onUWm001?l0003oYIo@oj>Te_nSY=H2oj^]f@GoZ:oM0_nV/^42ojbji0GoZ[cV00?oZKkXojc2jOn/
`^T00_n/`^TDooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`05olc<c?l0003o0000o`000?o<c<`02Oooool002Oooooo0_l00005ooooo`Co`L_R0_o2`]X4ol71
fP03okbge?nj/];o^[;B00?o^[;B00?o^:o@ok6Sb_naXlX00_naXlX3ojjMa`GoZiW400CoZIC1oj69
^onQRK_oXHVk0onNQ[P3oif2]PGoVgnc0onJO;42oiUj[`03oiEh/?nDMZooU7J_00;oU7J_1?nDM:d3
oi=c[0CoTg:[0onBLJT3oi9`Z@GoTVnX0onDL:L3oiIaY`03oi]l/OnOO:goWgb]00;oWgb]0onQNjT4
oj5iYPGoX7JS0_nLLJ400onOO:goVWNZoiYgZP03oiYgZP03oiAaZ?l0003o000000CoT6jY1?n=KZ/4
oha`[PCoT7Rd00CoUh>koheNU_n=GYKoSEjF1?n;GIL2ohYMU`03oi9VW?nDJIgoU6VM00;oU6VM1?nH
K9h4oi]`X0CoWW>Q1?nMLj800onLLZ;oXG^Zoj5kZP02oj5kZP?oWGNW1?nLMJH5oiifY@;oWgNV00?o
]9g1ok6F^onaU[/00onaU[/5ojj@]`03ojb<]Oo4jo3oa>_`00;oa>_`00?oaLoRoj1lZonPO:/00_nP
O:/2oien/@03ojIoZOnSOZcoXgj/00?oXgj/1OnOOk02oif3]`03ojb?^?nWSkcoYhnl00?oYhnl1?nT
T/800onQU/WoZi_7oj^Ka`02oj^Ka`CoYic;0onUWm000ol0003oZjgIoj^]f@03oj^]f@?oZ:oM00?o
[[_Sojbji?n/^^@00on/^^@2ojZliP?o[L;Y1?n/`^TEooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41002Oooool002Oooooo
00?o0000ooooooooool00_ooool4ol77g`03ol7;h_o2`][o`/;J00;o`/;J00?o`L7Jokbge?nl]m@0
0_nl]m@3okZbdP03ok>Yc_naXl[o/J?:00?o/J?:1?n^WLL2oj^Ia0;oXhjo1?nQRK/3oij6^0CoWH:f
1?nKOk<2oiYl/@04oiIj/_nEN;3oUGR`oiEh/0CoU7J_1?nDM:d3oi=c[0CoTg:[0onBLJT4oi9`Z@Co
TVnX0onDL:L01?nFLJOoVgbaoi]l/OnKO;44oiml[@CoXG^Y1?nQNJH4oj1fX`03oiaaXOnOO:goWgb]
00?oVWNZ0ol00002oiAaZ0CoT6jY1?n=KZ/4oha`[P;oT7Rd0on?H9L3oheNUPCoRefG00?oRUfGoi9V
W?nBIY`01?nDJId4oiQ/WPCoVg2P1?nNLj43oiecXP03ojN4[onQNj[oXG^Z00?oXG^Z0onMMjL4oiae
YPGoWWJU00CoWgNVokBM`OndWL7o]9g11OnaU[/3ojj@]`;oUo;I0_o4jo02oj=kY`GoX7b[00?oWGja
ojIoZOnVOjT01OnSOZ`5oimo/004oif3]on/SkSo[8nhojb?^0CoYhnl0onTT/800on_W<CoZi_7oj^K
a`03oj^Ka`CoYic;00GoYIo@ojf]eon][MOo[JgGo`000004oj^]f@03ojR_gOn^^n?o[[_S00;o[[_S
0on/^^@2ojk4jPGo[L;Y0_n/`^T2ojc4ja;ooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Wooooo000Wooooo`04o`000?oooooooooooooo
o`Co`LOO00?o`/?Jol;2f_o2`]X00oo2`]X00onn^mKo_;ODokbge003okbge004okZbd_ncZLko/jW>
ok>YcPCo/J?:0on^WLL00onUTl?oXhjooj>>_`02oj>>_`CoXHVk1?nNQ[P3oif2]P;oVgnc0_nFO;@3
oiIj/PCoUGR`0onDMZl4oiAd[@?oTg>/1?nCLZ/4oi9aZ@?oTW2Y1?nBKjP2oiA`Y`03oiMl/onKO;7o
Vgba00;oVgba1?nOO:d4oj5kZ@CoXGVV0onPMZ<01?nSPk;oWgb]oiml[OnOO:d3o`0000;oVWNZ0onD
LJP4oi1^Z@GoSFj[0_n<L:h00ol0003oTF:GohmPU`03ohmPU`?oSEjF0_n;GIL2oi1TV`?oTVJL1OnD
JId3oiQ/WPCoVg2P1?nNLj401?nMLj;oYhB_ojN4[onWQ:l5oj5kZP?oWGNW1OnLMJH3oiifY@03okFT
aondWL7o]9g100;o]9g11OnaU[/01?n^T;OoUo;IoiObfOnGl]T2ojQmY@?oXg^W1OnPO:/4ojIoZ@Co
Xgj/1?nOOk000on`TKOo[8nhojb?^002ojb?^0GoYhnl00CoY9;2ojnLa?n_W<Co[ic41On[VlL2ojNL
b`03ok6^eOn][MOo[JgG00;o[JgG00Co0000ojf]eon[[MWoZjgI0_na_N<5ojjkh`03ojbji?n^a>[o
[/CZ00;o[/CZ0_n]`^T2ojg7k@Go[<C[5?ooool02Ol0003oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT02Oooool002Kooooo0ol00002ol74g@?o
`LOO0oo2`mX3ol;2fP?o_[_F0onl]m@00onf[m7o/jW>ok>YcP03ok>YcPCo/J?:00Co[Yg7ojFC`onU
Tl?oYI?31?nSS[l4oj69^`?oWXJh0_nMP[H00onGOkOoUWbdoiIl]002oiIl]0CoUWZb0onEN;04oiAf
[`?oU7B]0onCLj`4oi=bZ`CoTW6Y0onBL:T2oi9_Z0;oU7^e0onGO;<4oi]l/@CoWgb]1?nQNjT4oj5i
YP04oj1fXonSPk;oXh>boj>3/P?o000000?oWgb]oiYgZ_nJMjX00_nJMjX3oiAaZ0GoT6jY1?n=KZ/0
1?n<L:koTF:Goi5RUonAHYL4ohmPU`;oSEjF00?oT6>Joi1TVon@I9/00_n@I9/4oi9VW0CoU6VM0onH
K9h5oi]`X0?oWW>Q1OnWQ:l4oj5kZP?oWGNW1OnLMJH2oiifY@?o]JC70ondWL44ok6F^`;oUF^P1OnX
OJD3oj=kY`CoX7b[00?oZH6YojIoZOnVOjT00_nVOjT5oj=n[0;oWgn`0_n`TKL4ojb?^0CoYhnl00?o
]:75ojnLa?n_W<@00_n_W<@4oj^Ka`03okJbe_na[]Go/JkE00;o/JkE1?n][ML00ol0003o/KgSok6m
h`03ok6mh`;o[[_S0_n_an/4ojk4jP03ojg;kon]ango[LO]00?o[LO]0_n/a>/2oj[4k1Gooooo00?o
0000ooooooooool07_ooool002Kooooo00?o0000ol74gOo1a=d00oo1a=d00oo1amoo`/?Jol;3fP03
ol;3fP03ol;2f_nn^mKo_[_F00?o_[_F00Co_;ODokJ_dOnf[m7o]ZoA1OncZLh2ok6SbP03ojRIaonU
Tl?oYI?300;oYI?31?nSS[l4oj69^`;oWXJh00CoV8:joiMo]onGOkOoUgng1?nFO;@4oiIj/P?oUGR`
1?nDMZl3oiAd[@CoTg>/0onCLZ/2oi9aZ@GoTg^f1?nDNkD4oiMl/`CoVgba0onOO:d4oj5kZ@?oXGVV
00?oY8Zioj>3/_l000000_l000001?nSPk;oWgb]oiml[OnOO:d4oiYgZPCoU76X1?n@KZT2ohe^Z`03
oe7=`onCI9SoTfBH00?oTF:G0_n?H9L2oi1TVP?oT6>J1?n@I9/4oi9VW0CoU6VM0onHK9h5oi]`X0;o
WW>Q00?o/92eojN4[onWQ:l00onWQ:l4oj5kZPCoWGNW1?nLMJH00onNMZGo]JC7okFTa`02okFTa`Co
]9g100?o/IJkoiAWVonEJj000_nEJj05ojQmY@CoXg^W0_nPO:/3ojV1Z@?oYWnY1OnSOZ`01?nOOk3o
/96gok2A]on`TKL5ojb?^004ojN?_?ndXLGo]:75okBQa@Go[ic400CoZi_7okJbe_nf/]Ko][;F1Ona
[]D01On][MOo]<;UokC2iOnd`^Go000000?o/KgS0_nac>h4ojo7j`03ojk4j_n]bnoo[L__00;o[L__
0on]and2oj[7kPCoZ/C/5?ooool00ol0003oooooooooo`0Nooooo`006oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000ooooooo1a=d00_o1a=d3ol?4f`?o`/?J0_o1_mT4okjkeP03okVe
e_nf[m7o]ZoA00;o]ZoA1?ncZLh00on[X<coZ9W7ojRIa`02ojRIa`?oYI?31?nSS[l2oj69^`;oVXJm
0onHP[X4oiMo]`CoUWbd0onFN[83oiEh/0CoU7J_1?nDM:d3oi=c[0;oTg:[2?nCNkH4oiAk]@CoUgbc
1?nKO;44oiml[@?oXG^Y00?oXGVVojB:^Ol000000_l00004oj>3/P?oWgb]1OnJMjX3oiAaZ0;oT6jY
0omNe]@4oi=TV0;oTF:G00?oTFBKoi1TV_n@I9X00_n@I9X3oi1SVPCoT6BK1?nBIY`4oiAYW@?oV6bN
1OnKL:001?nNLj7o/92eok2@]On`T;D4ojN4[`GoXG^Z0onMMjL3oiaeYP03okB/d?neY<Oo]JC700?o
]JC70ondWL43oiAWV`;oUF^P0_n/P:D4ojQmY@CoXg^W00?oX7b[ojV1ZOnYPJT00_nYPJT3ojIoZ@Co
Xgj/00?o]YRhok2A]on`TKL00on`TKL3ojb?^003okb/bOndXLGo]:7500?o]:750on_W<@00onk_=[o
][;FokJbeP03okJbeP?o/JkE0_nhc>T4okC2i@03o`000?nac>ko/Lc^00?o/Lc^0_n_an/2ojc@l`Go
[L__00?o[LO]oj[7k_nZanh00_nZanh2oj[4k0;oYl;]5?ooool00ol0003oooooooooo`0Mooooo`00
6oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00Co0000oooooooooooo`LCM1Oo3a=/00oo2
`m[o`KoIol6of@02ol6of@03okjke_ni]MKo^KGF00;o^KGF1?nf[m400oncZLkoZj3<oj^Pc002oj^P
c0?oZ9W71?nUTl<2oj>>_`03oi^:`OnJQ[goVXJm00?oVXJm0onHP[X3oiMo]`CoUWbd0onFN[84oiEh
/0?oU7J_1?nDM:d2oi=c[003oi=l]onCNkKoTg^f00WoTg^f1?nDNkD3oiMl/`CoVgba1?nOO:d2oj5k
Z@?o00000onTR[T4oj>3/P?oWgb]1OnJMjX2oiAaZ0;oHMOE00CoUVRKoiAVVOnDIYWoU6JI1?nCI9P0
0onAHYOoTFBKoi5TV`04oi1TVP?oT6>J1?n@I9/4oi9VW0CoU6VM1?nHK9h3oi]`X003okNK_?n`T;Go
/92e00;o/92e1?nWQ:l5oj5kZP?oWGNW00?oW7FVokB/d?nd[=000_nd[=05okFTa`03okBM`OnDIi_o
U6NK00;oU6NK00CoUF^Pojb0YOn/P:Go[82U1?nXOJD4oj=kY`GoZH6Y1?nVOjT2oj=n[0?o]YRh1?n`
TKL2ojb?^0?o_:c91?ndXLD2ojnLa0?o^kcJ1?nf/]H00ona[]Go^<cYokS<j@03okS<j@;o]<;U00?o
/=Cco`000?nac>h00onac>h00onYe_Oo[=3cojc@l`03ojc@l`;o[L__0onYb_42oj[7kP;oYlC_1OnW
`^dCooooo`;o00007_ooool001_ooooo00Go410@oooooooooooooooooa0@4006ooooo`;o00000_oo
ool4ol?4f`;o`/CK0oo1_mT2okblfPGo^KGF0_nf[m400on^Ym7oZj3<oj^Pc003oj^Pc0CoZ9W70_nU
Tl<00onMSlGoVh[1oi^:`@02oi^:`@CoVXJm0onHP[X3oiMo]`CoUWbd1?nFN[83oiEh/0;oU7J_00?o
TWfhoi9l]onBO;L00_nBO;L3oi=l]`_oTg^f1?nDNkD4oiMl/`?oVgba0_nOO:d01?nOV<go0000o`00
0?l00002oj>B``CoY8Zi1?nSPk84oiml[@CoVWNZ00?oU76XoiIXVonFJ9/00_nFJ9/3oiAVV@;oTfBH
0_nAII`3oi5TV`CoT6BJ1?n@HiX3oi1TV`CoTVJL1?nDJId4oiQ/WP;oVg2P0ongVk`3ok2@]@CoYhB_
1OnQNjX2oiegY`03ok6ggOnd[=3o]:c@00?o]:c@1?neY<L00onDIIWoU6NKoiAWV`03oiAWV`Co[82U
1OnXOJD2oj=kY`03ok28ZonYPJWoZH6Y00?oZH6Y1?nVOjT00onSOZco]YRhokJH^002okJH^0Co/96g
00?o[8nhokb/bOnl[<T00_nl[<T4okBQa@03ojnLa?nk_=[o^kcJ00?o^kcJ0_nf/]H2okSKlPCo^<cY
00?oZmkiok3Dlon`e?<00_n`e?<00ol0003o/Lc^ojWFm`03ojWFm`;o[=3c0_nVcO@4ojW:l@;oYLK`
1?nWa>l2ojO2k@;oYL3/4_ooool00ol0003oooooo`00000Nooooo`006oooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool00_ooool00oo3a=_o`/CKol;4f`03ol;4f`03ol6o
fOnl_=[o_;cJ00;o_;cJ0oni]MH00onb/=Ko[ZOAojjWd@02ojjWd@CoZj3<0onXVLL00onPULWoWHo5
oif?a@02oif?a@?oVh[11?nJQ[d3oiR2^PCoUgng0onFO;@4oiIj/P;oUGR`00CoTWjjoi9m^?nBOKSo
TWfh1?nBO;L4oi=l]`[oTg^f1?nDNkD4oiMl/`;oVgba00CoVYcEoinHcOl0003o00000_nOV<d3oj>B
``CoY8Zi1OnSPk83oiml[@;oVWNZ0onFJId4oiIXV`;oU6JI00?oTFJMoi5UW?nAII`00_nAII`3oi5T
V`CoT6BJ1?n@HiX3oi1TV`CoTVJL1?nDJId4oiQ/WP03oi]`X?ngVkco]i^l00;o]i^l0on`T;D5ojN4
[`?oXG^Z00?oZL[aok6ggOna]md00_na]md5okB/d003okFTaonDIIWoU6FI00;oU6FI1?nDIi/4ojb0
Y@GoZ7fU00CoXg^Wok28Zon`R:_o/8R[1?nYPJT4ojIoZ@Go]YRh1?n`TKL5okb/b@?o]:750_o0c^D4
ok^lfP03ojg^n?nhfo;o^=_b00?o^=_b00?o^<cYoj_NnOn[g_T00_n[g_T2ok3Dl`;oX]cl00?o0000
ojWFmonYe_L00onRd?P4ojK=m003ojW:lOnUa_3oYLK`00?oYLK`0_nWa>l00onT`>goYL3/ojG0k003
ojG0k1Cooooo00?o0000ooooooooool06oooool001_ooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo00?ooooo1Oo2a=/00onna=ko_;cJokblfP03okblfP04okVee_nb/=Ko
/[3Fok:`ePCo[ZOA1?n[X<`01?nXVLOoX9G9oj2EbOnPULT3oif?a@?oVh[11OnJQ[d3oiR2^P?oUgng
0_nFO;@00onBPKgoTWnkoi9o^`02oi9o^`?oTWjj1?nBOKP3oi9l]`CoTgbg2onCNkH3oiAk]@;oUgbc
0_nGW]T01?nJW=Go0000o`000?l00004oinHc@?oXi;31OnTR[T4oj>3/P;oWgb]0onDJil3oiIYW@;o
UVRK0_n?IYh3oi5VW@CoTFFL1?nAI9/3oi1TVPCoT6>J1?n@I9/3oi9VW0GoU6VM0onHK9h5okNK_0Co
/92e1?nWQ:l00onQNj[oZL[aojW:l@02ojW:l@Co/KOM0_nd[=03oiIUU`CoU6FI0onDIi/2ok24YP?o
[82U1OnXOJD4ok28Z`GoZH6Y0_nVOjT2okjS_PGo]YRh0_n`TKL2olO2ePGo_:c900?o]:75ol3>iOo0
c^D00_o0c^D00onk_=[o[Nkhojg^n002ojg^n0;o^=_b1?nIi_`2oj_Nn@?oTn3n0_nRg?`00ol0003o
Vm7joj;@n004oj;@n0;oY/gd0_nSao84ojG6l0GoY<3]0onU`>`00onU_^coooooooooo`0Cooooo`03
o`000?oooooooooo01[ooooo000Kooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003o
ooooooooo`05ooooo`?o`/CK0onna=h3okblfP03okFig?nb/=Ko/[3F00;o/[3F1On^Ym42oj^Pc003
oj:Lc_nPULWoX9G900;oX9G90onMSlD4oi^:`@CoVXJm0onHP[X2oiMo]`03oi>3_onBPKgoTX6m00;o
TX6m1?nBOk/3oi9n^P?oTWfh1?nBO;L3oi=l]`_oTg^f0_nDNkD00onFWMWoUikIoiNNf@03o`0000Co
VYcE0onOV<d4oj>B``CoY8Zi0_nSPk84ohMSXP?oRFBR0on<IJ04ohmVWP?oTFJM1?nAII`4oi5TV`?o
T6BJ1?n@HiX4oi1TV`CoTVJL1?nDJId2oiQ/WP;o^ZC31OngVk`3ok2@]@;oYhB_1?nHi_`4ojW:l@;o
/KOM0_nHJ9P4oiIUU`CoU6FI0_nDIi/3ok24YPCo[82U0onXOJD00onlVKCo/8R[ok28Z`02ok28Z`Go
ZH6Y00CoYWnYokjS__nnXkko_Z>n1OnfV;P01?n`TKOoal;FolO2e_o7`]H4okb/b@03okgZloo0c^Go
`<kU00;o`<kU0om^gmD2ojg^n0?oK]c^0_nIi_`3og_Kn`;oTn3n0onBco`2oi_AnP04o`000?nKdO[o
X]3hoj;@n0;oWlKc1OnSao800onUa_3oY<3]ojC0k@06ojC0k@04ojG0k?nU_^coYKk/ojFnk1Cooooo
00?o0000ooooooooool06_ooool001_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o0000
1oooool00oo2a=_o_/CNokk4gP03okk4gP04okblf_ne^Mco]KWLokFig0Co/[3F0_n^Ym42ojFTe0Co
XYc>0onPULT4oif?a@?oVh[10_nJQ[d2oiB9a@?oThK21?nCPkl3oi:1_@CoTWnk0onBO[X3oi9m^0Co
TWbg1?nCO;L5oi=k]P;oUi_E0onGW=L2oiJMf@?o00000onGW]T4oiZLe@CoWiS=0onST/<2ojB:^@04
ohYUX_n8I:;oR6BRohQTXPCoQf>R0on9I:83ohaUX0CoSfJN1?nAIYd3oi5UW0CoTFBK0on@I9X4oi1S
VPCoT6BK1?nBIY`4oiAYW@04oiQ/W_njY<?o^ZC3okZT``Go]i^l0_n`T;D3odO2Z@;oV>Kl0onRLid4
oie/VP?oV6RH1OnFIIL3oiAUV@03oiAWVon`Q:Ko/8BV00;o/8BV1?n/P:D2ojQmY@?o_9Vd0on`R:/4
ojV1Z@03olZlcOnnXkko_Z>n00;o_Z>n1?nfV;P2olkajPCoal;F00?o_:c9okgZlonmj_<00_nmj_<0
1Oo0c^GoK]oEofkOeOm^gmGoI;Kl00CoF<Ci0_mPcoH2ohVnn0GoSLWl0_nBco`2oiZll0;oWL;c00?o
0000oig2lonOa_<00onOa_<2oj?7lP;oX[k]1onT`>d2ojBmj`GoYKk/5?ooool00ol0003ooooooooo
o`0Iooooo`006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool01ooo
ool4okk4gP;o^<?S1?ne^M`2ok:`eP03ojR/f_nUY=CoYJCD00?oYJCD0onRW<h4oj2Eb@?oWHo50_nK
R/400onDS<SoU8W5oiB9a@03oiB9a@?oThK20onCPkl3oi:1_@CoTWnk0onBO[X4oi9m^0?oTWbg1?nC
O;L2oi=k]P03oiNIe?nGVmGoUi_E00?oUi_E00CoUicGo`000?l0003o00000onFWMT4oiNNf@CoVYcE
0_nOV<d4oheXX`?oRVFR0on8I:84ohMSXP?oRFBR0on<IJ04ohmVWPCoTFJM0onAII`4oi5TV`CoT6BJ
0on@HiX4oi1TV`CoTVJL0onDJId00oniYlOo^ZC3okZT``02okZT``Co]i^l0onQMZ82ojAiX`;oZWfS
1?nRLid4oie/VP?oV6RH1OnFIIL3oiAUV@Go/8BV1?n/P:D00onXOJGo_9VdokbI]002okbI]0Co/8R[
0_nYPJT3olZlc@Co_Z>n00?o]YRholkaj_o>lNX00oo>lNX2olO2eP?oMn?E0_nmj_<2ognSj`;oI;Kl
0_nGY=h4oi2bkPGoRKkh0_n=bO`2oiZcj@GoV[c`0_nM`_<00ol0003oXKc/oj6lk003oj6lk0CoX[k]
0_nT`>d3ojBkjPCoY;g[0_nU_^`2ojFnjaCooooo00?o0000ooooooooool06Oooool002Gooooo00?o
0000ooooooooool02?ooool00onna=ko^<?SokS3h`03okS3h`;o]KWL00?oZ[KRojR/f_nX[=X00_nX
[=X4ojFTe0CoXYc>0_nPULT01?nGU]7oUY7<oiJAc?nFTL`4oiB<b0CoU8W50onCQ/83oi>3_`CoTX6m
1?nBOk/3oi9n^P?oTWfh0_nBO;L00onDU];oUYOCoiJGd`02oiJGd`CoUiWD0_nGVmD3o`0000?oUicG
1?nFWMT2oiNNf@03oi5^Yon@K:GoT6bU00;oT6bU0on?JZ@3oheXX`CoRVFR0on8I:83ohMSXPCoRFBR
0on<IJ03ohmVWPCoTFJM0onAII`4oi5TV`CoT6BJ0on@HiX4oi1TV`CoTVJL00?oU6VMokVWaoniYlL0
0_niYlL4okZT``03okNK_?nNLZ7oXGJR00?oXGJR00?oY7VSojYmXonZOJ<00_nZOJ<3oj9cW@CoWFbJ
0onHJ9P5oiIUU`?oU6FI1On`Q:H4ojb0Y@Go_9Vd1?n`R:/00onYPJWob[c=olZlc@02olZlc@Co_Z>n
0_l00002olkajP?oW8Rm1On?Sll2ognSj`03oj6Kc_nGY=koUjCN00?oUjCN1?n@/^h2ohVnn0;oVjWO
1OnJ/nT2oiZll0;oXK;T0_nQ^>T00ol0003oXKSYoj6lk004oj6lk0;oX[k]0_nT^NP5ojBkjP;oY;g[
0_nU_>X4ojFnja;ooooo00?o0000ooooool000006_ooool002Gooooo00?o0000ooooooooool02_oo
ool3okS3h`03ojc1jOnZ]^;oZ[KR00;oZ[KR1?nX[=X4ojFTe0;oXYc>00?oVIcFoiNFdOnGU]400_nG
U]43oiJAc0?oU8c81?nDRLD3oi>6`PCoTh>o0onBPKd4oi9o^`?oTWjj0_nBOKP00onCU=;oU9KBoiBF
dP02oiBFdPCoUYOC0_nGVM@3o`0000?oUi_E0_nGW=L00onCM:goTW6Zoi9aZP02oi9aZP?oTFjW1?n@
K:D3ohmZY0?oSFRS1?n:IJ83ohQTXP?oQf>R1?n9I:83ohaUX0?oSfJN1?nAIYd4oi5UW0?oTFBK1?n@
I9X4oi1SVP?oT6BK0onBIY`00oncY<[o^JO7okVWa`03okVWa`?o^ZC30onNLZ44oj5fXPGoZWfS0onR
Lid4oie/VPCoV6RH1?nFIIL2oiAUV@;o/XVY1On`Q:H3ojb0Y@03omW=cOnlVKCo_9Vd00;o_9Vd1?n`
R:/5olZlc@?o_Z>n1OnWQk<4oib8_@;oSho?0_nYU/84oj6KcPGoUjCN0_n@/^h2oj2Qe@CoVjWO0_nJ
/nT2oj>]gPGoXK;T0_nQ^>T01?l0003oXKSYoj6lk?nQ_>`2ojBfi@GoY;WX0_nT^nX2ojFjj0GoYKcZ
0_nU_^/2ojNnjQCooooo00?o0000ooooooooool05oooool002Gooooo0_l0000<ooooo`04okS3hon/
`NWo[<7Yojc1j@CoZ[KR0_nX[=X00onLZn;oVZ?KoiZSf`02oiZSf`CoVIcF0onGU]43oiJAc0?oU8c8
1OnDRLD3oi>6`P?oTh>o0_nBPKd00on?Tm?oT9?Boi2CdP02oi2CdP?oTI?B1?nCU=84oiBFdP?oUYOC
0_l00002oiNIe0;oUi_E0_nGNK04oi=d[@?oTW6Z0onAKZL4oi1/Y@?oSfZT1?n=J:<3ohYUXP?oR6BR
1?n7Hj83ohUTXP?oS6FP0on?IYh4oi5VW@CoTFFL0onAI9/4oi1TVPCoT6>J0on@I9/2oi9VW0?o/jC:
1OniYlL00onjY<?oWW:QoiibX@03oiibX@?oXGJR1OnZOJ<3oj9cW@CoWFbJ1?nHJ9P4oiIUU`04oiAU
VOnbRJWo/XVYok:9Z@Go/8BV0_n/P:D2omW=c@Go_9Vd0_n`R:/2olk_jPGob[c=00?o_Z>noj69^onW
Qk<01?nWQk<4oib8_@GoZIK21?nQVlh2oiNTgP;oYY_;1OnPXMD2oi^Yg`03ojNXf?nS[MkoXjgN00?o
XjgN1?nQ/^@2oj6hj@03ojFbh_l0003oYK;R00CoY;KU0_nT^NP2ojJiiPGoYK[X0_nU_>X2ojNmj@Go
YkkZ4oooool00ol0003oooooooooo`0Gooooo`009?ooool00ol0003oooooooooo`0=ooooo`Co[<7Y
0_nZ]^82oibcj0?oW:_R1?nJXm/3oiVLeP?oUiKA1?nFTL`3oiB<b0CoU8W50_nCQ/801?n=U=GoSY?C
ohjCdon>Tm<4ohnCd`CoT9?B0onATm83oi>DdPCoU9KB0ol000000onFUm?oUiWDoiNIe002oiYo]0Co
UgV`0onCM:d3oi9aZPCoTFjW0on@K:D3ohmZY0CoSFRS0on:IJ83ohQTXPCoQf>R0on9I:83ohaUX0Co
SfJN0onAIYd4oi5UW0?oTFBK1?n@I9X4oi1SVP?oT6BK00?oTVJLok>Tb_ncY<X00_ncY<X4okVWa`;o
VVnP1OnNLZ42oj5fXP03ok:=[_nZOJ?oZWfS00?oZWfS0onRLid4oie/VPCoV6RH0onFIIL00oncSk3o
/XVYok:9Z@02ok:9Z@Go/8BV00Co[82UomW=cOoIcLgofLg=1OnlVK@00on`R:_oc^oZolk_jP02olk_
jP;ob[c=00?o[8V`oj69^onQRK/00_n`S;05ojN7/`;oW8Rm0_naU[`4ojVF`P?oXI_>00?o[I_4ojJK
bonVVl/00onVVl/3oj2Qe@03ojbVd_nWZ=SoYjSH00;oYjSH1OnS[Mh2oj6bi0;oYZoN0onU/^801?l0
003oYK;RojBfiOnT]^D2ojNgi0CoY[WV0_nU^^P3ojNkj0CoYkgY0_nW_^X2ojRojQCooooo00?o0000
ooooooooool05_ooool002Cooooo00?o0000ooooooooool03_ooool2ojc1j@;oW;g_1?nL/nP3oib[
hPCoVZ?K0onIW=H3oiNFd@;oUY7<00CoS9[KohbGfOn<UmWoS9OI1?n=UML4ohfDe@?oSY?C0on?Tm<4
oi2CdP?oTI?B1?nCU=83o`0000;oDlgV0onNQKP4oiYo]0?oUgV`0onCM:d4oi9aZP?oTFjW0on@K:D3
ohmZY0CoSFRS0on:IJ83ohQTXPCoQf>R0on9I:83ohaUX0CoSfJN0onAIYd4oi5UW0CoTFBK0on@I9X4
oi1SVP;oT6BK00?o[J3;ok>Tb_ncY<X01?ncY<X00oniYlOoUffPoiY_X002oiY_X0GoWW:Q00CoXGJR
ok:=[_nbSJko/Xf^1?nZOJ<3oj9cW@GoWFbJ0onHJ9P2oiIUU`;o/hn`1?nbRJT5ok24YP03o`000?oI
cLgofLg=00;ofLg=0onlVK@00onGMJ_o/X^]o`000002olk_jPCo[8V`00CoXHVkok2</?n`S;3o/8b`
1OnWQk<01?nLR;go/IJlok6F_?naU[`5ojVF`P04oj6Kc_n]VlCo[I_4ojfKa0CoYY_;00?oX:7EojbV
d_n/Y]800_n/Y]84ojNXf0;oXjgN0_nY[MX5ojJ_gP;oYK;R00?o0000ojVfh_nW]n@01?nW]n@2ojJi
iP;oZ;[V1OnW^nP2ojNmj@;oZ;kY1?nX_nXDooooo`03o`000?oooooooooo01Gooooo000Tooooo`?o
00003oooool4oibmk`CoW;?X0onLZn82oiZSf`04ohfVi_n=XN;oSJ7RohfQhP?oSIgN1?n<V]/3ohbG
f@CoSIGG0on=U=D3ohjCd`CoSi?C1?n@Tm83oi6CdP?o000000?oG<oaoj><_OnSS;d00_nSS;d3oij5
^0CoVWnd0onGNK03oi=d[@CoTW6Z0onAKZL4oi1/Y@?oSfZT0on=J:<4ohYUXP?oR6BR0on7Hj83ohUT
XP?oS6FP1?n?IYh4oi5VW@?oTFFL1?nAI9/3oi1TVP?oT6>J00?oYYc;ojfPbon]X</00_n]X</4ok>T
bP?oUffP1?nJKj03oiibX@03okfS_onbSJko/Xf^00;o/Xf^1?nZOJ<3oj9cW@GoWFbJ0onHJ9P00onF
IIOo/hn`ok>?/002ok>?/0?o/XVY1?n`Q:H00oneRjWoZgnUo`000003omW=c@03okbI]?nSNZGoXgZU
00Go/X^]1?n/RK04ok2</0CoYhNc00?o^ijkok6F_?naU[`00_naU[`4ojVF`P03okJP`_n]VlCo[I_4
00;o[I_40onVVl/00onbZ<ko[:KBojbVdP03ojbVdP?oYjSH00?o[ZgGojV]f_nY[MX00onY[MX3ojJ_
gP06ojbeh?nY]^;oZKKRojVfh_l0003oZKKR0_nW]n@2ojZji@GoZ;[V0_nW^nP2ojVnj@GoZ;kY0_nX
_nX2ojW0ja;ooooo0_l00009ooooo`Co000000?o410@ooooooooool01oooool002Cooooo00?o0000
ooooooooool04?ooool4oibmk`;oW;?X00?oSK7_ohf/j_n=[>X00_n=[>X3ohfViP?oSJ7R0on=WMh3
ohbJf`CoS9OI1?n=UML3ohfDe@?oSY?C0_n?Tm<4og78o`06ofc<o_l0003o0000o`000?mUcoWo^K?D
0onWU<43oj><_@CoWXFh0onJOk@3oiMi/0?oTgB]1?nBLJX3oi5^Y`CoT6bU0on?JZ@3oheXX`CoRVFR
0on8I:83ohMSXPCoRFBR0_n<IJ04ohmVWPCoTFJM0onAII`4oi5TV`?oT6BJ00?oT6>JojJLbonVW</0
0_nVW</3ojfPb`?o/jC:00CoTfZPoiM]X?nGKJ3oUffP1?nJKj02oiibX@;o_J>o1?nbSJh4ojYmX`Co
XW>M1?nMK9X3oiQXV0Go/hn`1?nbRJT2ok24YP;o]H^Y1On[OjD3oj=jY@Go/X^]1?n/RK000onnVkCo
/8b`ok2</002ok2</0;oYhNc0onkW[/4ok6F_004ojVF`_nfX<;o]Z32okJP`PGo[I_400CoYY_;ok:X
c_nbZ<ko/ZS>1On/Y]801?nWZ=So[ZgGojj]eon^[ML4ojV]fP03ojJ_g_n/]N3o[;GP00;o[;GP0onY
]^800ol0003oZ[[UojZji@03ojZji@?oZ;[V00?oZ[kXojVnjOnY_^T00onY_^T2ojRnj@;oZL3Z1OnY
`>/Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool000Wooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool04_oo
ool3ohbgl`?oSK7_1?n=[>X3ohfViP?oSJ7R0on=WMh3ohbJf`CoS9OI0_n=UML2ogRinP?oMkgl1Ome
`_h01?mab?oo0000o`000?l00003okbkf003ojbLa_nWU<7oYiC100;oYiC10onSS;d4oij5^0CoVWnd
0onGNK03oi=d[@?oTW6Z0onAKZL4oi1/Y@?oSfZT0on=J:<4ohYUXP?oR6BR0on7Hj84ohUTXP?oS6FP
0on?IYh4oi5VW@?oTFFL1?nAI9/2oi1TVP03oj:Ic?nVW<_oYYc;00?oYYc;1?n]X</00oncY<[oTfZP
oi=ZX004oiM]X0?oVVnP00?oWW:QokfS_onmXkl00_nmXkl3ok:=[PGoZWfS0onRLid4oie/VP;oV6RH
00?o/iVmok>?/?ncSk000oncSk04ok:9Z@04ok24Y_neRjWo]H^YokF;Z@GoZgnU0_nSNZD2okVC/0Go
/X^]0_n/RK02okjK]0Co/8b`00?oYhNcok^N^onkW[/00_nkW[/4ok6F_0Go]Z320on]Vl@00onh[Lko
/ZS>ok:XcP03ok:XcP;o[:KB0_nc/ML5ojj]e`;oZJgJ0_n^]]l4ojbeh005ojVfh_n/^nCo[;_To`00
0?n/^n@01?nZ^^D00onX^^KoZ[kXojZnj002ojZnj0?oZKkY00?oZL7[ojW0j_nY`>X00onY`>X2ojW0
j`;oZL7[5?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006
ooooo`03o`000?oooooooooo01?ooooo0on<]o<3ohfak`;oSJcZ00?oOK3dogb`m?ml/?@00_ml/?@3
og^`m@CoN[3f0omj/_L4ogVen0?oN;Wj0omg_O`2ogG2oP?o00001?nn`M`01?nl^mSo[9c6ojbLa_n/
W<H3ojND`@CoXhbm0onNQKP4oiYo]0?oUgV`0onCM:d3oi9aZP?oTFjW0_n@K:D2oh]YY`KoSFZV1?n;
JZP3ohM[Z`?oPFbb0ommL[/01?n9I:;oS6FPohaUX?n<IJ03ohmVWPCoTFJM0onAII`2oi5TV`;oWIW?
1?nRVL`5ojJLb`;o[J3;1?nCJZ04oiM]X0;oVVnP00?oa<;HokfS_onmXkl00onmXkl3ok:=[PGoZWfS
0onRLid4oie/VP04oiQXV?ncVKgo/iVmok>I_@Co/hn`1?nbRJT4okF;Z@GoZgnU00CoXgZUokVC/?ni
Tk3o^I>`1OnbRjd01?n/RK3o_Y^dokjK]?nnVk@4ok2</0Go^ijk0onaU[`2okn]a`Co]Z3200?o[I_4
okR]c_nh[Lh00_nh[Lh3ok:XcP03okZjf_nc/MOo/k7G00?o/k7G0on^[ML00onb^]oo[[KOojjfg`03
ojjfg`;o[;GP0_n^_ND3ojbki004o`000?n/^nCoZ[[UojZji@;oZkoX1?nZ_^P00onY_^WoZL7[ojW1
j`02ojW1j`;oZL3Z0onY`^/4ojW1ja?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`09ooooo`002Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_oo
ool00ol0003oooooooooo`0Eooooo`?oO[;e0omm/OD3ogf`m0CoO;3d0omk/?D4ogZ`mP?oN[;g0_mi
]OP3odo5lP;o@<7S00CoQn_Qokc]lol0003o00001?noaMl2okk1g003ok2Sbon/W<Ko[9c600;o[9c6
1?nWU<43oj><_@;oWXFh00?oTWF`ohma[On?LJd00_n?LJd3oha^Z`?oRV^Y0on9JJP3ohUYY`CoRfVW
1_n=JZH4oh]ZZ0?oQf^[0on1K;84ogeb^`?oO7_70on?IYh2oi5VW@;oSI;D0onFUm85oifIc`?oXYW<
1?nVW</3oi1XX0CoTfZP1?nGKJ001?nJKj3oa<;HolC2f?o4`]P4okfS_`Co/Xf^1?nZOJ<3oj9cW@;o
WFbJ0_n^[ML4ok>I_@Go/hn`0_nbRJT2ol6N]0?o]H^Y1On[OjD4okVC/0Co/X^]00?ocKG2okjK]?nn
Vk@00onnVk@2ok2</0;o`Z_21OnkW[/01?naU[co_jg7okn]aono[LL3okJP`P03ol6ke?nh[Lko^:g>
00?o^:g>00?o/ZS>okZjf_nj^]X00_nj^]X4ok>ae`03ojj]eonb^]oo/[[O00;o/[[O0on^]]l00on`
`NKo[[gUojjmi@03ojjmi@;o[;_T00?o[<7Yo`000?n[_nP01?n[_nP2ojZnj0;oZ/;[0onY`N/2ojW2
k0GoZL;[1?nY`N/Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool000Wo
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0ol0000Foooo
o`?oO[;e0omm/OD3ogf`m0;oO;3d0om`^od4of^ooP?oHl;m0_mKaOX3obff``03oiC^lOnkj?Co0000
00;o000000?o_lOQoko5gonoaMl00_noaMl00oncZ/oo/:?;ok2Sb`02ok2Sb`?o[9c61?nWU<42oj><
_@04oiIk/onBMK3oTWF`oi9e/0CoSg6]0on<KZ/3ohY[Z@?oRFVX0on9JJL4oh]YY`OoSFZV0on;JZP4
ohM[Z`?oPFbb1?mmL[/2ogaka`?oPXO@1On=T]@3oiJGdPCoWIW?1?nRVL`00onVW<_oSFJQoheVX@04
oi1XX0?oTfZP0onGKJ000onkfo3oa<;HolC2f002olC2f0Go_J>o0onbSJh4ojYmX`;oXW>M00?oT];m
ojj]eon^[ML00on^[ML3ok>I_@Go/hn`00Co/XVYol6N]?o1W[Co`Ijd1?neRjT3oj]oY@;o_j:k1?ni
Tk02ok:;[@;ocKG21OnnVk@01?n`S;3o`Z_2ol:[`_o2Zl84ok^N^`03olg:eono[LOo_jg700?o_jg7
00Co]Z32ol6ke?o1^mCo`K_D0onh[Lh00onmbN?o^[[JokZjfP04okZjfP;o/k7G0_ne`N<4ok:jg`03
ojjfgon``NKo/<7V00;o/<7V0_n^_ND3ojg4j`?o[<7Y00?o0000oj^oj?n[_nP00_n[`n`5oj[2j`03
ojW1jonY`^coZL;/00;oZL;/0_nY`^/2ojW2k0GoZL7[4Oooool3o`0000Oooooo00?o0000oooooooo
ool02Oooool000Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Co
oooo00?o0000ooooooooool06?ooool3ogbbmPCoNKCh0ome^?/3og2ko@;oJkon0omLc?H2odK5h`;o
W^[j00Go^^7co`000?l0003o0000ok_Xm004oko7h@03oko5goncZ/oo/j[?00;o/j[?0on`Xl/4ojbL
aP;oYiC100CoVH6goiIk/onFNk?oUW^c1?nBMK03ohma[@?oS6j[1?n:JjT3ohUYZ0?oRFVW0on;JJL7
oheZYP?oRfZX1?n7Jj/3oh5//PCoOG:k0omlNlL3oh:7d0CoSI;D0onFUm85oifIc`;oXYW<00CoRFFR
oheVXOn=IZ7oSFJQ1?n@J:03oi=ZX003oiM]X?nkfo3o^m_`00;o^m_`1?o4`]P4okfS_`?o/Xf^0_nZ
OJ<2oiaaX@04o`000?nBd_goT];moi;Bo@Co[ZgG1?ncVKd3ok>?/003oj^2Z?nYPJWo`Ijd00;o`Ijd
1?neRjT2oj]oY@?o_j:k1?niTk000onbRjgocKG2olfe`P02olfe`P?o_Y^d00?oc<cJol:[`_o2Zl80
0_o2Zl83ok^N^`?ocL[G0ono[LL00oo2dNKo`K_Dol6ke003ol6ke004okR]c_nmbN?o_LWSokg9h`Co
^[[J00?o]/g[okG1hone`N<00one`N<2ok:jg`;o/LS[0on``NH2ojc8kPGo[LC[0_n/`NT00ol0003o
Z/G]oj_3k003oj_3k0;oZ/;[0_nY`n`4ojW2k003ojS3kOnY`^coZL;/00?oZL;/0_nY`N/2ojS1j`ko
oooo1?l000000ooooooo0000ooooo`06ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05oa0@
4?ooooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wo
oooo0oml/_H2ogVdn0;oOkgj1?mga?h2ofc:oPCoQ=[n00?oM]gfoikZn_l000000_l00002ok[Ql`;o
_/SR0onoan400onf/=?o/j[?ok>Zc`03ok>Zc`Co/:?;0_n/W<H00onNQk_oVH6goiV1]`02oiV1]`?o
UW^c0onBMK03ohma[@?oS6j[1?n:JjT3ohUYZ0?oRFVW0on;JJL7oheZYPCoRfZX0on7Jj/3oh5//PCo
OG:k0omlNlL3oh:7d0GoSI;D0onFUm82oifIc`;oOEnU0on9IJ83oheVX@CoT6RP0_nCJZ02oj?En@Go
^m_`0_o4`]P01?nFKZ;oVG2RoiU`X_nIL:84oi]aXPCoW76Q0_nLL9l2oi;Bo@Co[ZgG1?ncVKd01?nc
Sk3oZh:Xoj^2Z?oBa/l4ol6N]0Co]H^Y00?oZgnUoknR^onoX[/00_noX[/4okVC/0GocKG20_nnVk@3
olc<fPCo`Z_200?o^ijkolg:eoo=b]L00_o=b]L00ono[LOo`]7Vol;AiP02ol;AiP?o`K_D0_nihO<4
okg9h`03okZjf_nfcN_o]/g[00;o]/g[0_ne`N<2ojo@l@Go/LS[00?o/<7Vojc8k_n/b>h00_n/b>h2
ojg4j`;oZ/S`0onZaNd01?l0003oZ/G]oj_3k?n[`n`2ojW5kPCoZL?/00?oZL;/ojS3kOnX`nd00_nX
`nd2ojW2k0;oZ<7/1OnX`N/:ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`03oeEEEOmV
IVKo000000_ooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Gooooo0_l0000Kooooo`?oQKGd1?mo_OX2ogO4oPCoS]7n0_n4f_h3o`0000?o^=[a
00?o^^7cokk8h_nnb>800_nnb>801?noan7o][3CokJ`donf/=<5ok>Zc`;o/:?;00?oXXo0oij7^onN
Qk/00_nNQk/3oiV1]`?oUW^c0onBMK04ohma[@?oS6j[0on:JjT3ohUYZ0?oRFVW1?n;JJL6oheZYPCo
RfZX1?n7Jj/3oh5//PCoOG:k0omlNlL3oh:7d0;oSI;D0on1F9T2ogiIW@CoOEnU0omnK;@3oheVX@;o
T6RP0on@/Nd4oj?En@;o^m_`0_nBJj83oiI^XP?oVG2R1OnKLJ83oiaaX@03oia`WonXRKCoZ8Vd00;o
ZHF^1?n^[ML2ok>I_@03ojZ3Z_n[PZSoZh:X00?od/K?1?o1W[@2okF;Z@03olG3f?noX[_o_j:k00Co
_j:k0_niTk02omOehPCocKG200?o_Y^dolc<f_o<c=X00_o<c=X3ol:[`P;o__O_0oo=b]L2oj7/n@Co
`]7V00?o`K_DokWQlonihO<00onihO<2okg9h`;o[M[g0onfcN/2ojKInPCo[m3a0_nab>/2oj[=lPCo
[<S^00?oYl_boj[8l?nZb?000onZb?02oj[5k@03ojS6kol0003oZLG^00CoZLG^0_nY`n`5ojS3k@;o
Z<;/1?nX`N`2ojS1j`;oYl3[1_ooool4o`0000Sooooo00?o0000ooooooooool04Oooool000Wooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0
003oooooooooo`0Kooooo`?oQKGd0_mo_OX3oi?6n@;oS]7n00GoYMKio`000?l0003o0000oj?Qo004
okSJl@;o_LSS0onnb>800onh]]Oo][3CokJ`d`03okJ`d`;o/j[?0_nWUlD4oj:?`0?oWXNk0onIPKL3
oiIk/`?oTWF`1?n?LJd3oha^Z`?oRV^Y0on9JJP3ohUYY`CoRfVW1_n=JZH4oh]ZZ0CoQf^[0on1K;82
ogeb^`?oRUjH0on7FiL3oh=HU`CoPERI0omnFId3ogeOY@?oOVbd1?n3Q/h5oi2ak@;oXmGi00?oSVNQ
oi9[X_nBJj800_nBJj83oiI^XPCoVG2R1?nKLJ82oiaaX@03ojJ=^_nXRKCoZ8Vd00;oZ8Vd1?nYQJh4
ojZ3ZP03oj^2Z?oBa/ood/K?00;od/K?1?o1W[@01?neRjWoaL?HolG3f?o5`mP5oknR^`04okVC/?oG
mN;oeoGRomOehP?ocKG20_nKl^`5olc<fP03ol:[`_nnmnoo__O_00;o__O_00?ocL[Goj7/nOnQk?T0
0_nQk?T2ol;AiP?oQnOd0_nihO<3ohcNoPCo[M[g00?o]/g[ojKIn_nVfOX00_nVfOX2ojo@l@;oXm7g
1?nZcO800on/b>koYl_bojO;lP02ojO;lP;oZ/S`0_nVao43ojS6k`04o`000?nXa^ooZLG^ojW5kP;o
YlC^1_nX`nd4ojS2k0;oZ<7/0_nW`N`4ojO0j`;ooooo0ol0000<ooooo`03o`000?oooooooooo017o
oooo000Rooooo`03o`000?oooooooooo01gooooo1?nF^o42oi?6n@04ojK;lol0003o0000o`0000;o
YMKi0onfd^h00onhf_7o_LSSokg8h`03okg8h`04okk8h_nh]]Oo^;KGokRfe`?o][3C00?oZik:ojNG
aOnWUlD00_nWUlD4oj:?`0?oWXNk1?nIPKL3oiIk/`?oTWF`0on?LJd3oha^Z`?oRV^Y0on9JJP3ohUY
Y`CoRfVW1on=JZH3oh]ZZ0;oQf^[1?nRb?<00omngO_oSF:KoheRV`03ohYNV0?oQe^G0on3F9L4oh5H
V@?oOUVM1?mmGjD3ogi/]0CoPhK>0_n@/Nd2ohaUW`?oSVNQ1?nBJj84oiI^XP?oVG2R1?nKLJ801?nL
LJ7oYXfjojJ=^_nVSKX3ojR9]0CoZHF^1?nZPjX00oneo=Sod/K?om;6c`02om;6c`?o`Ijd00?oT^k_
olG3f?o5`mP00_o5`mP4oknR^`;oVZ7J1?oGmN800oo=]L;oVo;/oi_bk002oi_bk0;oc<cJ0onFY=l5
ogF/m0?oA:kg0_lYZnL2ohOWm0CoEL[b0_n<g_h3ofo>oP?oT=[o0_nVfOX3oiOAo0CoXm7g0_nZcO83
oj?=mP;oYl_b0_nTb?84ojK7l@;oZ<K_00?oY/G_o`000?nVaNl01?nWa>h2ojS3k@?oYl;]0_nX`^`7
ojO1k0CoYl3[00?o0000ooooooooool03_ooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0
003oooooooooo`0Nooooo`;oU[_a0_nV_n`2o`0000;oY/_c0_ndb^/3okKBkP?o^lOS0onmb><2okVj
fPCo^;KG00Co][3Coj^Nb_n[W/[oZik:1?nWUlD3oj:?`0CoWXNk0onIPKL3oiIk/`?oTWF`0on?LJd3
oha^Z`CoRV^Y0on9JJP3ohUYY`?oRfVW1on=JZH2oh]ZZ0;oXk7R1?nRb?<01?nAJ:3oSF:KoheRVon=
HY/3ohYNV0CoQe^G0on3F9L3oh5HV@?oOUVM1?mmGjD3ogi/]0?oPhK>0_n;I9l3ohaUW`?oSVNQ1?nB
Jj84oiI^XP?oVG2R0_nKLJ82ojFA`0CoYXfj0onXRK@5ojV5[P;oZX>Z0oneo=P4om;6c`04ol6N]?nB
k^ooT^k_oi;^k`CoaL?H00Co_j:kojJIb?nVVLSoVZ7J0on]VL85oj2Ic@04oh^Oh_nXXLkoZ:7>ojRQ
cPCoUZCO0_me[?@2oifUf`CoR:c]1Om^]?X3ofC2oP;oKlkn0_n1`o`5oh_=oP;oUm7l0_nDb?T4oic=
n0;oXlgf0_nPao@5ojC8lP;oY/Oa0_nTaO03ojK5k`04o`000?nVaNooYlC^ojO4kP;oY/;^0onW`^d8
ojO1k0OoYl3[4?ooool00ol0003oooooooooo`0@ooooo`008_ooool2o`00023ooooo0ol00002ojJo
k003ojK;londb^_o]<[[00;o]<[[00?o]];^ok_7honkan<00onkan<00onmb>?o^K[JokVjfP02okVj
fP;o^;KG00?o[jK?oj^Nb_n[W/X00_n[W/X4ojNGa@CoXXo00onNQk/2oiV1]`04ohmn_?n<N[[oS7Zj
ohaj^P?oRGNh0on7MKP3ohId^0CoRV^Y0on9JJP3ohUYY`?oRfVW1_n=JZH00onIX=WoXk7Roj>ahP03
oj>ahP04oj;8lonAJ:3oTFRPoi5XX0?oSF:K0on:GYP4ohMKU`?oPeRG0on1F9T3ogiIW@CoOEnU1?mn
K;@01?n3Q/koRfBOoh]TWon;I9l3ohaUW`CoSVNQ0onBJj84oiI^XP;oVG2R00?oXi;4ojFA`?nUTL00
0_nUTL04ojJ=^PCoZ8Vd1?nYQJh01?nZPj[oZ8jjojR>^_nXS[X4ojN?_0?oXi7200?o[iJmojfG`?nB
k^l00_o5`mP3ojJIb003ok:I__n]VL;o[IW200?o[IW20onPVLd00on`WlKoZ:7>ojRQcP03ojRQcP;o
UZCO00?oZJ7>oifUfonMYM/00onMYM/4ohR/k@;oK[Cj0_nC/>X5ohRjm`?oPL?l0_n;cOh2oi;2m`Go
U<Si0_nLcOP2oig5m0CoX<Od0_nTb?82oj?4l@GoY<G`0_nVaNl00onU`^ko0000ojK2kP04ojK2kP03
ojO2kOnW`NcoYl7/00CoYl7/0_nW`>`6ojO0j`;oYko[4?ooool00ol0003oooooooooo`0@ooooo`00
8_ooool00ol0003oooooooooo`0Looooo`?o000000?oooooojJok?nV_n`01?nb`^H2okC:j`;o^/GS
1?nkan<2okZng@?o^K[J00?o/ZgDojnVcon_Y/l00_n_Y/l3oj^NbPCoYiO50_nRSl02oiR9``?oTh>o
1?n?O[`2ohaj^P?oRGNh0on7MKP3ohId^0CoQGFj0on4N;d3ohAl``?oR8K:1?n?T]84oiVPf@?oXk7R
00?oMUbVoiE`Y_nAJ:000_nAJ:03oheRV`?oRUjH1?n7FiL3oh=HU`?oPERI0omnFId5ogeOY@;oOVbd
00?oSFJPoh]TWon;I9l00_n;I9l4ohaUW`?oSVNQ0onBJj82oiI^XP;oXI741?nST/@4ojFA`0CoYXfj
0onXRK@2ojV5[P03ojFLc?nWSK[oZ8jj00?oZ8jj1?nWSk`00onSTL;o[iJmojnF_@02ojnF_@Co[IO0
00CoYYW8ok:I__nbVKko/YVn1?n]VL800onPVLgo/9o6ok2OaP02ok2OaP?oZ:7>00?o]:?8ojVQc_nY
XLh00_nYXLh3oifUf`03ojfXd_nQZ]goXJ[M00?oXJ[M1?nC/>X2ohRjm`;oVk7W1OnC^?43oi;2m`;o
U<Si0_nJ_o85oig5m0;oX<Od0_nQ`_04oj?4l@;oY<G`0_nT`Nh3ojG2kP04o`000?nU`^koY/;^ojK2
kP;oY/7/1?nW`N`00onV_n_oYl3/ojO0k003ojO0k0;oYl3[1_nW_n/?ooooo`03o`000?oooooooooo
013ooooo000Rooooo`03o`000?oooooooooo01Wooooo0ol00006ooooo`?o//;V0_ni`n84ok[5h`03
ok_7honj_]go^[kM00?o^[kM00Co^K[Jok:]e?nb[MCo/ZgD0on_Y/l4oj^NbP;oYiO500?oW977oiR9
`onHRL<00_nHRL<4oi>3_`?oSgjl0on<N[X3ohUg^0?oQgFh0on6M;P3ohEe^PCoQ7Rm0on4O<<3ohR6
bPCoSi;B1?nIX=T01?nS/N;oMUbVogILY_mfG:H3oi5XX0?oSF:K0on:GYP4ohMKU`?oPeRG0on1F9T4
ogiIW@CoOEnU00CoOVbdoheVX?n=IZ3oSFJP0on;I9l4ohaUW`?oSVNQ0_nBJj800onNSL;oXI74oj6A
a003oj6Aa0?oXi;41?nUTL04ojJ=^P;oZ8Vd00?oYIS8ojF<^_nWSKX00onWSKX3ojR>^P?oYhnl1_n_
U[d3ojfG`003okFL_onbVKko/YVn00;o/YVn0on]VL800onfXL?o/9o6ok2OaP04ok2OaP04ojRQc_nd
XlSo]:?8okBSb0CoZJ7>00CoWJGKojfXd_n]Z=;o[JSB1OnQZ]d2oi>`jP;oY:cM1?nK/NL2oi>hl@;o
WkCW1OnL^^h3oiZolP;oWLGd0_nP_^h5oj72l0;oXlCa0_nT`>d4ojC1kP;oYL;^00?oYL3/o`000?nV
`N`01?nV`N`00onW`NcoY[o[ojJoj`02ojJoj`;oYl3/2_nW_n/?ooooo`03o`000?oooooooooo013o
oooo000Rooooo`03o`000?oooooooooo01Kooooo0ol0000:ooooo`03ok;2i_ni`n;o^L?R00;o^L?R
0_njaN<3ok[1g`?o^[kM00?o];GIok:]e?nb[M@00_nb[M@4ojnVc`;oZik:00?oXIS<oibAaonLTLL0
0_nLTLL4oiR9``?oTh>o0on?O[`3ohaj^P?oRGNh0on7MKP3ohId^0?oQGFj1?n4N;d3ohAl``?oR8K:
1On?T]82oiVPf@?oOF:X0_mfG:H2og1HYP03oi5XX?n=HY_oSF:K00;oSF:K0on:GYP3ohMKU`?oPeRG
1?n1F9T3ogiIW@?oOEnU00?oPVN[oi=]Y?n=IZ000_n=IZ03oh]TW`CoS6FO0_n>Ij400onIQKcoWXg2
oij=`P02oij=`PCoXI740onST/@4ojFA`0;oYXfj0_nTU/H01?nUV<SoYHbjojF<^_nUS;X4ojN=^PCo
Z8jj00?oYhnlojnF_On_U[d01_n_U[d01?n]Ul3o]IbookFL_oneW;l4ok:I_P04ojfI`_nfXL?o]Z73
okJQ``Co/9o600?o^JO7okBSb?ndXlP00_ndXlP3ojVQcP03ok>XcOn]Z=;o[JSB00?o[JSB0_nQZ]d2
ojb[ePGoY:cM0_nK/NL2ojJah0CoWkCW0_nL^^h2oj>fiPCoX;[[1?nP_^h2oj72l0;oXkg/1OnT`>d2
ojC1kP;oYKk/0onU`>`00ol0003oY/7/ojK1k005ojJoj`ooYko[3_ooool00ol0003oooooooooo`0@
ooooo`008_ooool2o`0001Cooooo0ol0000>ooooo`?o^L?R0_nj`n45ok[1g`04okZngOnd]MWo];GI
okBef@Co/ZgD0_n_Y/l00onUX=7oXIS<oj6Hc002oj6Hc0?oW9771?nHRL<3oi>3_`CoSgjl0_n<N[X3
ohUg^0?oQgFh0on6M;P4ohEe^P?oQ7Rm0on4O<<4ohR6bP;oSi;B00CoTGNbohM[[?n7JjcoQf^/0omm
HZP2ogILYP?oL5RV1?n=HY/3ohYNV0?oQe^G0on3F9L4oh5HV@?oOUVM00?oOEnUokkMkon2Ij/00_n2
Ij/3ohQ][@?oRfBO0_n<IIl2oiAm]`CoVHFl0onNSL84oj6Aa0CoXi;40_nUTL02oj:Da`;oY9K600?o
XXZkojF<^_nUS;X00_nUS;X4ojN=^P?oZ8jj00?o[YNnojnF_On_U[d01_n_U[d00onfX<;o]IbookFL
_`02okFL_`?o/YVn00?o^JC4okJQ`onfXL<00onfXL<01?n`WlKo^JO7okVWaoniYlL5okBSb004ojVQ
c_ncZ<go/jS=ok>Xc@?o[JSB00?o]:gAojb[e_n/ZmH00on/ZmH2ojB/g@;o[K3J1OnV/N02oindi`03
ojNchOnS]^KoXkKV00?oXkKV1?nP^^/2oj2nkP;oY;_Z1?nS_N`2ojC0k@;oYKg[1OnU_^`2ojG0k003
ojJnjol0003oY[o[00;oY[o[0_nW_^XAojNoj`gooooo00?o0000ooooooooool04?ooool0027ooooo
0_l0000Booooo`?o00004_ooool00oni`n;o^/?Qok[3h@02ok[3h@;o^/7O0ong_=h4okBef@;o/ZgD
00?oZJSFojFPdOnUX=400_nUX=43oj6Hc0?oW9771?nHRL<4oi>3_`?oSgjl0on<N[X3ohUg^0?oQgFh
0on6M;P3ohEe^PCoQ7Rm0on4O<<2ohR6bP04oi^5^onAMk;oTGNboi5g/P?oQf^/0ommHZP3ogILYP;o
L5RV0_mbFjP2oheRV`?oRUjH0on7FiL3oh=HU`CoPERI0_mnFId3okkMk`?oPVN[0on8KJd3ohid/@Go
U7fg0onIQK`3oij=`PGoXI740_nST/@2oj6Fb@;oXYC700?oWhRkoj::^onRR[/00_nRR[/4ojF<^PCo
Yhfj00CoZ8jjojjG__n^Ukko[YNn1_n_U[d2okJP`PGo]Ibo00Co/YVnokVTa?niY<Co^JC41?nfXL<5
okVWa`?o]:?800?o^Zg<ok>XcOncZ<d00oncZ<d01?n]Z=;o]:gAokB]dOnd[M43ojb[eP03ok:`e_n]
/=[o[K3J00?o[K3J0onV/N000on//]goYk?QojNch@02ojNch@CoXkKV0_nP^^/2ojFhi`GoY;_Z0_nS
_N`2ojFkj@CoYKg[0_nU_^`2ojJmjP?oY[k[00?o0000ojJnjonV_n/01?nW_^X2ojNoj`;oYkkZ3OnW
_n/<ooooo`03o`000?oooooooooo013ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00oooooo0_l0
000Fooooo`?o^/?Q0_nh`n<5okNlgP;o];GI00?o[;7KojVXe_nYZ=H00_nYZ=H3ojFPd@CoXIS<0onL
TLL2oiR9``03ohj@dOn9SM7oRHgA00;oRHgA0on6S=<3oh:>e`?oRGNh0on7MKP3ohId^0?oQGFj0_n4
N;d2ok:Zd0?oYiK50onKQK/4oi5g/P;oQf^/0ommHZP3ogILYP;oL5RV1?mbFjP3ohYNV0?oQe^G0on3
F9L4oh5HV@05ogiIWOnngNoo_]g_okkMkomoIJ/01?n2Ij/2ohQ][@CoSWBa1?nDOKL3oiV5_0CoWXg2
0_nQTL@2oj6Jc@;oXIK90_nKQ[`4oin8^`?oXXZk1?nUS;X3ojN=^P03ojbG`On^Ukko[YNn00;o[YNn
1On_U[d4okJP`P?o]Ibo00?o^JW9okVTa?niY<@00_niY<@3okJQ``;o_:g:1?niYlL00ondXlSo^Zg<
okZ]c002okZ]c0?o/jS=00?o^K3AokB]dOnd[M400ond[M401?n/ZmKo/[3Fok:`e_nb/=H4ojf`fP03
ojJah?n//]go[;;M00;o[;;M1?nW/n42oj>fiP;oZ;KS1?nU^>L2ojBkjP;oYkWW1OnU^nT2ojFmj`;o
YkcY1?nV_NX2ojJnj`03ojNmjOl0003oYkkZ00WoYkkZ0_nW_n/2ojNojPKoYko[0_nX`>/=ooooo`03
o`000?oooooooooo00oooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`?o00006Oooool00onj`n7o
^<?SokS3h`02okS3h`?o]kcN00?o[kWQojbafon//M/00_n//M/4ojVXeP?oYJ3A0_nQV<`01?nGV]Go
TYCBoi:Dd_nBU=84ohj@d@CoRHgA0on6S=<2oh:>e`CoOiCN0omkX>X4og:bn@03oe?2n?nORkkoUWjh
00;oUWjh0on=Lk83ohI[[P?oOfF[00CoTGNbohM[[?n7JjcoQf^/0_mmHZP3ogILYP?oL5RV0ombFjP3
ogUT[P?oQe^G0on3F9L2oh5HV@Co[:cG00?o_]g_ogmUZomoIJ/01?n2Ij/3ohQ][@?oSWBa1?nDOKL4
oiV5_0;oWXg20_nTY=D2oj6Jc@03oiR4_?nKQ[coVhJl00;oVhJl1?nOR;/3oj::^`CoYHbj00?oYhfj
ojbG`On/Ul400_n/Ul43ojjG_P?o[iJm00?o]JC7okJP`_nfX<800onfX<82okFL_`;o^JW91OniY<@0
1?nfXL?o_:g:okb]b_nl[LX3okVWa`03okbbconj[Lco^Zg<00?o^Zg<00?o/jS=okV`dOni/=400_ni
/=43okB]d@03okRde_nb/=Ko/[3F00?o/[3F0_n]/=X2ok6dfPCo[;;M0_nW/n42ojbfh0GoZ;KS0_nU
^>L2ojRhi0CoYkWW0_nU^nT2ojNki`GoYkcY0_nV_NX5ojNmj@03o`000?nW_^[oYkkZ00GoYkkZ0_nX
_^X5ojNojP;oYko[0_nX_n/4ojS0j`cooooo00?o0000ooooooooool03oooool000Oooooo00Go410@
oooooooooooooooooa0@400;ooooo`Go00001Oooool2o`0000[ooooo0ol0000Mooooo`Go^<?S00Co
]kcNojnihOn_^N7o[kWQ1?n//M/2ojVXeP04oinXg?nKXMWoVj7Ioi^Qf@CoUi[E0onBU=83ohj@d@Co
RHgA0on6S=<3oh:>e`CoOiCN0omkX>X2og:bn@CoWh^n0_nFO[P3ohec/P?oQV^^1?moIJ/3ogYRZ`?o
OF:X0_mfG:H3og1HYP?oLU^X0omiI:h3ohIc]`;oPeRG00?oVH_3ojb/eon/[=L00on/[=L01?n0J[3o
OfF[ogmUZomoIJ/4oh9WZ`?oR6f]0on>M;45oiAm]`;oVHFl0_nDQKl3oiF3_@CoV8Bl0onKQ[`4oin8
^`CoXXZk0_nUS;X00onYUl?o[9O1ojbG`@03ojbG`@Co[YNn00Co[iJmokFTaoneY<Oo]JC71?nfX<80
0oneW;oo^JW9okVYb@02okVYb@?o^JC400?o_KCAokb]b_nl[LX00onl[LX01?niYlOo_;;?okbbconl
//l3okZ]c003okbge?ni/=7o^K3A00?o^K3A00?o]:gAokRde_nh]=H00_nh]=H3ok:`eP03okFgf_na
]=[o/KCJ00?o/KCJ0_n//]d2ojnfgPCo[;KP0_nX]^<2oj^hhPGoZ;ST0_nW^NL2ojVjiPCoYk_W0_nW
_>T2ojRlj0OoYkgY00?o0000ojRmjOnW_^X00_nW_^X2ojRnj@CoZ;kZ0_nW_nX2ojRojPGoZ;o[1?nX
`>/;ooooo`03o`000?oooooooooo00oooooo0007ooooo`05o`000?ooooooooooooooool000002ooo
ool01?m4A4CogMgMooooool00006ooooo`03o`000?oooooooooo00Kooooo0ol0000Qooooo`;o^<?S
0on``^L4ojnih@;o[;7K00?oX[3QoinXg?nOZ=`00_nOZ=`3oi^Qf@?oUi[E0onBU=84ohj@d@CoRHgA
0on6S=<3oh:>e`;oOiCN00Co<k[@olGKjOo5fnWo`loS0onXVLH3oin;_P?oUWjh0on=Lk83ohI[[P?o
OfF[0omjHZ/2og9P[`03ogeRZ?mfG:KoMUbV00?oL5RV0ombFjP3ogUT[P?oQW>g1?nIRl<3ojb/e`;o
KUf^00?oP6Z`ogmUZomoIJ/01?n2Ij/3ohQ][@CoSWBa1?nDOKL01?nIQKcoU8FooiB5_onDQKl4oiF3
_@?oV8Bl1?nKQ[`4oin8^`;oXXZk00?oYYK5ojVG`onYUl<00_nYUl<4ojbG`@?o[YNn00?o]:S=okFT
aoneY<L00_neY<L3okJP`P03okV`d?niZLWo^JW900?o^JW900?o^JC4okfddOnm]=400_nm]=43okb]
bP03okbjeonl//oo_;;?00?o_;;?00Co^Zg<okbge?nl]mCo_;OD0oni/=400onj^]Wo^;CFokRdeP03
okRdeP03ok:`e_ne]m[o]KOJ00;o]KOJ0ona]=X00onc^Mko[kKNojnfgP03ojnfgP;o[;KP0_n^^N44
oj^hhP;oZ;ST0_n[^^@5ojVjiP;oYk_W0_nY^nL4ojRlj0;oYkgY0_nX_NP3ojRmj@03o`000?nX_NWo
YkkZ00CoZ;kY0_nX_^X6ojRojP;oZ;o[1onX`>/:ooooo`03o`000?oooooooooo00oooooo0007oooo
o`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00006ooooo`03o`000?oo
oooooooo00?ooooo0ol0000Vooooo`Co/<;W0_n_^N400onU^>KoX[3Qoj:`h@02oj:`h@CoWjSL0onK
XMT3oiNJe@?oTYCB0_n>T=43oh>]l0?oO;?g1?mb__d2oec7nP04ol;Qk_o5fnWoaM_Yok2WcPCoZ9W6
0onORkh3oiIn^0?oSG>b0on6Jjh3ogmUZ`?oNV:[0ombH:l3ogILYP;oL5RV0ombFjP4ogUT[P?oQW>g
1?nIRl<00on/[=OoLUVVofiM[P02ofiM[P?oOfF[1?n2Ij/3ohQ][@?oSWBa0_nDOKL3oiN;a0CoU8Fo
0onEPkd3oiR4_0CoVhJl1?nOR;/01?nRR[_oYYK5ojJFaOnVU/D3ojVG``Go[9O100Co[YNnokBXcOnd
Z<go]:S=1?neY<L01?nfX<;o^K3@okV`d?ni/=03okVYb@03ok^mfonm]=7o_KCA00Co_KCA00Co_:g:
okbjeonl^]Oo_;[G0onl//l00onl_mco_;ODokbge003okbge004okV`dOnj^]Wo^[[IokZjf@?o^;CF
0_nh_=`4okFgfP03ok6df_nc^Mko/kWN00;o/kWN0on_]]h00ona^n7o[[WQojjih@03ojjih@;oZkSR
0_n]^n@4oj^ji0;oZK[V0_nZ^nH5ojVki`;oZ;cX0_nY_NP4ojRmj0;oZ;gY00?oZ;kYo`000?nX_^T0
0onX_^T9ojRojPWoZ<3[2_ooool00ol0003oooooooooo`0?ooooo`001oooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oMgMgolc<c?l000001Oooool01?l0003oooooooooooooool3o`0002[o
oooo0_n``^L2ojJok0?oYKSV1?nR/>42oinXg003oiB_jOn@[>SoT:cX00;oT:cX0on=Z^T3ohNYk0Go
Pjg`0oml/oL2og:no@?o`^7^00?o]K?Fok2Wc_n`Ylh00_n`Ylh3ojRIaPCoWh^n0_nFO[P3ohec/P?o
QV^^0omoIJ/3ogYRZ`?oLV2_0_mRIKl00omfG:KoL5RVog1HYP04og9KZ0?oNFB^0on6LkL4oiV;``?o
LUVV0_m^GJh3ofm```CoPVN[0on8KJd2ohid/@?oXI[=0onGRl@4oiB5_`?oUH>m1?nHQ;`3oi^6_0;o
WhRk0_nRU<H4ojJFa@CoZIO30_n/Ul42ok6/d`Go]:S=0_neY<L00onf]]Wo^K3@okV`d003okV`d004
okVYbOnk_M_o^kgKok^mf`Co_KCA00?o^/;Pokbjeonl^]L00onl^]L01?nl//oo_;oLokbog?nl_m`3
okbge0;o^/3O1?nj^]T00onh]=Ko^;cLokRlg002okRlg0;o]KOJ0_ne_Ml4ok>igP03ojnfg_na^n7o
/K_Q00;o/K_Q0_n^^N42ojnlh`Go[K_T0_n[^^@2ojbli@CoZ[_V0_nY^nL2ojZmi`GoZKgX0_nX_NP2
ojVnj@?oZ;kY00?o0000ojRnjOnX_nX02onX_nX9ojS0j`Wooooo00?o0000ooooooooool03oooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Gooooo1?l0000^
ooooo`CoY[o/0onU^>H2oj:`h@;oUk?[0onD[nT4oi2/j0?oSJ[Y0on7ZN`2oh>]l0?oClWY00GoG]K?
okkRlOnnh_7o_^;aol;QkP04okFceP?o/:O>1?nXVLH3oin;_P?oUWjh0_n=Lk83ohI[[PCoOfF[0_mj
HZ/4og9P[`;oHVFo0om`F:H3og9KZ0?oNFB^0on6LkL3oiV;``04ogaOY_mbFJKoLUVVog9IYP?oKUf^
0om_L<<3ofNPl@03o`000?o<hnSo/[KL00?o/[KL0onQV/d3oiN;a0?oU8Fo1?nEPkd2oiR4_004oiV=
aOnNTLKoWY76oijAaPCoXYC61?nVU/D3ojVG``03ojj^f?na[=?o/JcC00?o/JcC0ondZ<d00onb_>7o
][KIokJff@02okJff@?o^K3@0_ngaND4ok^mf`03okfddOnj`^3o^/;P00;o^/;P0onl^]L00onhanGo
_;oLokbog003okbog003okbge?nj`=oo^/3O00;o^/3O0_nj^]T2okS2hP?o^;cL00?o]/;SokFmgone
_Ml00one_Ml2ok>igP;o/kkR0ona^n400on`_^Co[kcSojnlh`03ojnlh`;o[K_T0_n]_ND5ojbli@;o
Z[_V0_n[_NL4ojZmi`;oZKgX0_nY_^P5ojVnj@;oZ;kY00?o0000ojRoj_nX_nX02_nX_nX:ojS0j`Wo
oooo00?o0000ooooooooool03oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03
ogMgMol0003ooooo00Cooooo0_l0000aooooo`;oY[o/0_nK_?03oiVhk@CoUk?[0onD[nT2oi2/j0;o
Pl?l1Omjb?l2ofW=o@;oLMk]00GoV?3`okkRlOnnh_7o_^;aokVlg@05okFcePCo/:O>0_nXVLH01?nE
RLGoS7o1ohao`On<Ol43oh=h_P?oSG>b0_n6Jjh4ogmUZ`?oNV:[0ombH:l3of9U_`;o06OI0ombFjP4
ogUT[P?oQW>g00?oVH_3ogaOY_mlGjH00ombFJH3ofiM[PCoKg3300CoIj3aoj?clOo<hnSoc>?X0_nb
]]`2oi:?c@?oSHK60on=Pl@3oi25``CoU8W41?nISLD3oijAaPCoXYC61?nVU/D01?nYUl?o[ZkHojj^
f?n^[]P4ok6/d`03okBXcOnb_>7o/[cQ00;o/[cQ1?nf]]T00oni/=3o]lGUokO5i@02okO5i@;o^kgK
0_ncbN/4ok[2h003okbjeonhanGo^<OU00;o^<OU0_nl_m`2okO7i`Co^/3O00?o]<SXokS2h_nh`^80
0onh`^801?nh_=co]/;SokK2honf`^<3okFmg`;o/l;U1?nc_^801?na^n7o/;kTok2ni?n`_^@3ojnl
h`;o[[oV1?n]_ND2ojbli@;o[;kW1On[_NL2ojZmi`;oZ[kX1?nY_^P2ojVnj@GoZKoY00?o0000ojRo
j_nX_nX01OnX_nX?ojS0j`Sooooo00?o0000ooooooooool03oooool002;ooooo00?o0000oooooooo
ool0;oooool4oi^ll0?oVKS]0_nG/n/2ohjlm@CoR[oh0on3`o`2og[8o`?oOmcl0_nIjoT3okSOm004
okkRlOni_=go^KcMokVlg@Go]K?F0_n`Ylh00onMU<[oUHW5oiF9a@02oiF9a@?oS7o10_n3N;h3ogYb
_P?oQV^^0omoIJ/3ogYRZ`?oLV2_1?mRIKl01?l0ImWoX9W>oj2Ic_n2Mkh4ogUT[P;oQW>g00CoKf6b
ogaOY_mlGjKoO5nV1?mbFJH2ofiM[P?oKg330_nSlo43oj6Uf0CoTXo=1?n=Q/H3ohf3a0?oT8G31?nD
RL@3oiV=a@?oWY761?nRU<H2ojJFa@?oZZoK1?n^[]P2ok6/d`;o[/7X1?nb_>42okJff@;o[lc_1?ng
aND00on[d??o/lW[ok?9j`03ok?9j`;o^/;P0_nac^l3okS7i@;o[lc_1?nganL00onj`=oo]<SXokC8
j002okC8j0;o^<;R0_nca^P5okK2h`03okFmgonc`^Go/l;U00;o/l;U0_nc_^82ok72iPCo/;kT00?o
[kcSojjoi_n^_nH00_n^_nH2ojfmi@;o[KoX1?n/_^L2oj^mi`;oZkoX1OnZ_^P2ojVnj0SoZKoY00?o
ZKoZo`000?nY_nX00_nX_nX2ojW0ja3oZ<3[2Oooool00ol0003oooooooooo`0>ooooo`008oooool0
0ol0003oooooooooo`0_ooooo`;oVkc`0_nD^_44oi6kl`?oS[ce0_n:_oP4ohg=o@;oQmGo0_nJh_d3
ok?Jm0;o^=od0_ni`n84okVlg@;o]K?F0_nUWll3oifDbPCoUHW50on<Ol43oh=h_P;oNW:n0omdL/83
ogmUZ`?oNV:[1?mbH:l2of9U_`03okk6h?nPVLkoX9W>00;oX9W>0_n2Mkh3ogIW]0;oKf6b0omdJKT4
og9IYP?oKUf^00?oKg33oj?clOnSlo400_ngb>L3oj6Uf0CoTXo=0on=Q/H3ohf3a0?oT8G31?nDRL@3
oiV=a@CoWY760_nRU<H2ojN^g@GoZZoK0_n^[]P2oj_5k0Co[/7X0_nb_>42ojSAm@Co[lc_00?o]lGU
oj_@lon[d?<00_n[d?<2ok?9j`;oY]7f1Onac^l00onhanGo[lc_ojo<k`02ojo<k`;o]lOW0_n^c>l3
okC8j0;o[L[^1?nca^P2okK2h`;o/LKY1?nc`^D00on`aNWo/L;Vok72iP03ok72iP;o/;kT00?o[l7X
ojjoi_n^_nH00_n^_nH00on]`NWo[KoXojfoj003ojfoj0;o[;kW0_n[`>T4oj^oj0;oZ[kX0_nZ`>T6
ojVoj@;oZL3Z0onY_nX00ol0003oZL3[ojW0j`04ojW0ja3oZ<3[2?ooool00ol0003oooooooooo`0>
ooooo`009?ooool00ol0003oooooooooo`0_ooooo`CoU;[a0_nA^o<2oiC0m@GoTLKi0_n=cOd3oicH
o004oi[RoOncf_Co/m[dok?Jm0;o]lKU1?ni`n82okVlg@03oj^Ye?nUWlooYIo?00;oYIo?1?nMU<X3
oiF9a@?oS7o10on3N;h3ogYb_P;oM7;20om]NLh3ogYRZ`;oLV2_0_mbe?`3oi21_`?oOVjg00CoX9W>
oh9g__n2MkkoPWNn0_mfIk@3ofmQ/P;oM6Vi1?n4PlT4oi^ej`03olk^j_ngb>Oo]lSW00;o]lSW0onQ
YMP3oi:?c@?oSHK60on=Pl@3oi25``GoU8W40onISLD2oijAaP;oXj[L1?nW[]d2ojZ_f`;oZ<K_1On[
aN`2ojk1j0;oXmCi1?nXdOD2ojo<k`?oX]?i0_n[d?<3oikCnP?oY]7f0_nac^l3ojK?mP;o[lc_0_nU
c_D5ojk<k`03okC8j?n]b^ko[L[^00;o[L[^0_nca^P2ojg9kPCo/LKY00?o/l;Uok35jOn`aNT00_n`
aNT2ok72iP;o[/CZ1?n_`NP00on^_nKo[L7Yojg1j@02ojg1j@;o[KoX0_n/`NT5oj_0j@;oZkoX0_nZ
`>X4oj[0j@;oZKoY1_nY`>X01?nY_n[oZL3[ojW0jol00003ojW0j`;oZ<7[1onX`>/00onX`N_oZ<3[
ojS0j`07ojS0j`Oooooo00?o0000ooooooooool03_ooool002Gooooo0_l0000`ooooo`;oU;[a0_nG
^o44oiC0m@;oTLKi1?nLc_T2oicHo0?o[]Cd00?o/m[dokO6iOnga^D00_nga^D2okW3hP03ojnafOn[
ZMCoZjWD00;oZjWD1?nUWll3oifDbPCoUHW50on<Ol42oh=h_P?oNW:n0omdL/83ofeicPCoL9SX00?o
L]ClojNLb_nWW<X00on@PKl3ogi^]`?oJf6e0_mfIk@3ofmQ/P?oM6Vi1?n4PlT2oi^ej`?oc^kZ0_ng
b>L01?nDTm3oRXK9ohZ6bOn:Q/T3ohJ2a`CoSHK60on=Pl@3oi25``;oU8W40_nHW=H4oijTfPCoXj[L
0_nW[]d2ojO5k`CoZ<K_0_n[aN`3oj3FnPCoXmCi0_nXdOD3oicDn`;oX]?i0onIdo`2oikCnP;oVLok
1?nMd?T2ojK?mP;oW/kh1?nUc_D2ojk<k`?oYlcc0_n]b^h2ojO:lPGo[LW^0_naa^T3ojg7k@;o/<GY
0_n/a^d4ojk4jP;o[l7X0_n]`nX3ojg1j@;oZl?[1?n/`NT2oj_0j@;oZl7Z1OnZ`>X2oj[0j@03oj[1
j_nY`>[oZL3Z00GoZL3Z0onY`N/2ojW0j`03o`000?nY`N_oZ<7[00?oZ<7[0_nX`>/6ojS1j`;oZ<3[
0_nX`N/5ojS0j`Kooooo00?o0000ooooooooool03_ooool002Oooooo00?o0000ooooooooool0;_oo
ool4oiNkl@;oU<3e1?nMaO@2oic>n@?oZlga0_n^e?@2okC7j0?o]lKU00?o/KOMojnafOn_/MT00_n_
/MT4oj^Ye0?oYIo?0_nMU<X00on@S/goR8W=ohR9c@02ohR9c@?oOhK@0on3N;h2ogYb_P?oM7;21?m]
NLh2og2Hj004okflf?nWW<[oYic:ojNLbP?oT86o0omnK[L3of]Q]@;oI6Jo00?oMVNdofmQ/_m_HK80
0omdJKT4ohB3b@05oi^ejoo>omSoc^kZolk^j_n[[]X01?nDTm03ohZ6b@;oQX;71?n7Q<T3ohb;c0?o
TY?A1OnHW=H4oijTfP;oXj[L0_nU`nh4ojO5k`;oZ<K_0onPeo/2oj3FnP;oVmOl1?nJe_`2oicDn`?o
Um?l0_nIdo`2oiS?n`GoVLok0_nMd?T3oi[=n@?oW/kh0_nUc_D3oj3<mP;oYlcc0_nRb_@4ojO:lP;o
[LW^0onYb?02ojg7k@;oZLO_1On/a^d2ojk4jP;oZlG/1?n]`nX00on]`NWoZl?[oj_3j`02oj_3j`;o
[<7Y0_nZ`^/4oj_1jP;oZ/3Z0_nZ`N/4oj[1jP;oZL3Z2_nY`N/00ol0003oZL7[ojS1j`0?ojS1j`Co
Z<3[1_ooool00ol0003oooooooooo`0>ooooo`00:?ooool00ol0003oooooooooo`0^ooooo`;oUk_a
1?nN_Nh2oig5m0;oZLK^0on[cO42ok;6j@Co]<OX00Co]lKUok6ggOna]mgo/KOM1?n_/MT2oj^Ye004
oinMd_nHULooV9G?oiREc`CoT8k=0on8RLd3ogn6d0CoMhcJ0_mWWNl3ogAb`P;oKGW>00CobMOUokfl
f?nm_=So_KcH0onWW<X3oi21_`?oOVjg0om[HKD3ofAV_`?oKf6b0_mdJKT3ohB3b@;oc_oH0_o3dND3
oj^^fP?oU9?@0on:Q/T3ohJ2a`?oQhC91?n<Rl`3oi:Cd@CoV9cF0_nNY=X2oj>nk0GoYL?^0_nWaNl3
oj7Gn`;oX=Ok0onMf?`3oi_Go0;oV]Kl0onIdo`2oiOCo0?oVLoj0onHco/2oiW?n`?oVLci0_nJcOT2
oi_9m`GoW<_g0_nPc?H2oik9mPCoX/[d0_nWb_83ojC8l`;oZLS`0_nVao44ojW7k`;o[<K]0_nYa^h5
oj_5k0;o[L?Z0_n[a>`2oj_3j`;oZ/?/1OnZ`^/2oj_1jP;oZ/;[1?nZ`N/2oj[1jPgoZL7[00?o0000
ojS1jonX`N/04?nX`N/4ojS0j`Gooooo00?o0000ooooooooool03_ooool002Wooooo00?o0000oooo
ooooool0;oooool2oijmkP?oZ<3[1?nYa^h00on[cO7o//KYok;6j@02ok;6j@;o]<OX0_nb_>44ok6g
g@;o[k7I00?oYJGFoinMd_nOWM800_nOWM83oiREc`?oT8k=1?n8RLd3ogn6d0CoMhcJ0_mWWNl00omZ
gMKo__gPolWGi@03olWGi@?o_KcH0onWW<X3oi21_`?oOVjg0_m[HKD3ofAV_`?oIHKN0omdJKT00on4
PlWoc_oHol?Ai@04ol?Ai@?oZjkJ0_nDTm03ohZ6b@?oQX;71?n7Q<T3ohb;c0CoTY?A0_nHW=H2oj2f
j0CoXkk/0_nU`nh3oj?FnP;oXMOk0onPfO/2oigHo0;oWmGk1OnKe?/2oiWCo0?oW<oi0_nIcoX2oig;
m`CoV/_h0_nIc?T2oic8m`CoVlWg0_nLboL3oig8mPCoW/Wf0_nRb_@3oj78m0;oY<Sc00?oX/ObojK7
lOnVao400onVao42ojW7k`;oY/K`1?nYa^h2oj_5k0?oZLG^0_n[a>`2ojW4k@CoZ/?/0_nZ`^/2ojW3
k0GoZ/;[0_nZ`N/00onY`^coZL7[ojW1j`0:ojW1j`CoZ<7[00?o0000ojS1jonX`N/04?nX`N/4ojS0
j`Cooooo00?o0000ooooooooool03_ooool002[ooooo0_l0000aooooo`CoZ<3[0_nYa^h3ok34j0;o
//KY0_nb_n<4ok:lh@;o/KOM00?oZJgIojFUe_nUYMH00_nUYMH3oinMdPCoV9G?0on@S/d3ohR9c@Co
OhK@0_mgS=X2ogcFo`04o`000?o:jNcob^W/ol[Yk0;obMOU00CoZjgIoiVGdOnIUm7oVIOA0on7Q<P3
ogAda0?oOVjg0om[HKD3ofAV_`?oIHKN0_n^mnl3omC_i@;o`m7U0_nQZ]d3oi6Fe0?oQXW?0on:Q/T3
ohJ2a`?oQhC91?n<Rl`2oi:Cd@;oVjcS1?nP]^P2oj>nk0?oY=Ci0_nSe_X3oj?In`;oX=Wk0onRe_X3
oioEn`;oVmCk0onOcoT2oic?n@;oWl[f1OnMboL2oi[;n0?oW/Se0onLb?L2oi_9m`?oWLOe0_nMb?H2
oik5m0CoWlOd0_nQb?@2oj76l`CoX/Ob0_nVao42ojC6l@GoY/K`0_nYa^h3ojO5k`;oZLG^00?oYlC^
ojW4kOnYa>d00onYa>d2oj[3k0;oZ<?]1?nY`n`2oj[2j`KoZL;/0_nY`N/3ojW2k0;oZL7[0_nX`N`7
ojS1j`03o`000?nX`N_oZ<7[013oZ<7[1?nX`>/3ooooo`03o`000?oooooooooo00kooooo000/oooo
o`03o`000?oooooooooo02oooooo0_nX`>/2ojo2j0?o/<CX0_nb`ND4ok:oh`;o/[cQ00?o[;?MojV]
fOnY[MT00_nY[MT4ojFUeP?oWigB0_nHULl01?nAX=ooRJ3SohVPhon9X><4ohFXj`GoPKWh00?oO=Ko
ok;jioo:jN`00_o:jN`00onh`N7oZjgIoj^]f@02oj^]f@?oVIOA0on7Q<P2ogAda0?oLGG70om[HKD4
ofAV_`03ofF6g_n^mnoo[_O_00?oe>oU00?o^LOToj6ZgOnQZ]d00_nQZ]d3oi6Fe0?oQXW?0on3Qlh3
ohN<d@?oS9CF1OnDX=d4oi^/h`;oX;KX0onTd?L2ojCDn@?oY]Wj0_nSfO/2ojGGn@?oX]Kj0_nTd?L4
oj;@n0;oWloi0onRb_D3oio:mP;oWL_g0onPao@2oik8m@;oX<Gb1OnNa_@2oig7m@03oio5lonNaOCo
W/Gd00?oW/Gd0_nOao@2oj35lPCoXLKc0_nRao82oj;5l@CoY<Ka0_nVa_03ojG5l0;oYlG_0_nVa>l4
ojO4kP;oZLC]0_nXa>h5ojS3k@;oZL?/0_nX`nd6ojW2k0?oZ<;/0_nY`^`2ojS2k0CoZ<7/0_nX`N/5
ojS1k003o`000?nX`N_oZ<7[00koZ<7[1_nX`>/3ooooo`03o`000?oooooooooo00gooooo000]oooo
o`03o`000?oooooooooo02oooooo1?n_`^P00on`a>So//7Uok;1i@02ok;1i@;o/[oS00?o[[SQojbc
gOn//md00_n//md4ojV]f@;oYJGF00CoW:ONoiJSg_nFXmkoUZ?N1?nAX=l3ohVPh`CoQJS[0_n1^OP2
ofGJeP?o_o3b00Cob^W/okS1hOnh`N7o^<7Q0on[[MT3oiVGd@?oQhC80omdM<@2og5ea`?oN8OE0_mT
I[l3ohnjl`04ol3ng?oBoMkod_gNomC_i@?o^LOT1?nQZ]d3oi6Fe0?oQXW?0on3Qlh3ohN<d@?oS9CF
1OnDX=d2oi^/h`;oX/Sc0onTd?L2ojOHn@?oY]Wj0_nWf?T4ojGGn@03oj;Fn_nTd?OoY=3g00;oY=3g
0_nRd?P3ojC;m0;oX/[e0_nTao84oj;7l`;oX<Od0_nRaO44oj35lP;oW/Kd0_nQa?44oio5l`;oW/Gd
0_nPa?85oj35lP;oXLKc0_nRa?44oj;5l@;oY<Ka0onTaO02ojG5l0;oYLC_1?nVa>l4ojO4kPCoZ<C^
2OnX`nd2ojW2k0_oZ<;/0_nX`N`00onX`^coZ<7/ojS1k005ojS1k003o`000?nX`NcoZ<7[00coZ<7[
2?nX`>/3ooooo`03o`000?oooooooooo00gooooo000^ooooo`03o`000?oooooooooo02oooooo0_n_
`^P2ok72i`?o//7U00?o[kgTojjhhOn^^>400_n^^>44ojbcg@;oZJgI00?oXJgOoibWg_nLYmh00_nL
Ymh3oiJSgPCoTJ3O0on9X><2ohFXj`;oNmck0_nUl_<3oko`lP;o_<kX1?nh`N43oj^]f@?oVIOA0_n7
Q<P3ogAda0?oLGG71?mhQmD00on?^_?oSnShol3ng002om;mgP;ob^7Y1?nian@3oj6Zg@?oTIKD1?n6
RLl2oh>7cPCoQhcA0on<U=H2oiBPg@;oW[g_1OnRb?<00onTd?OoYmSiojOHn@02ojOHn@03ojKIn_nW
f?WoYmSi00;oYmSi0_nUeoT3ojOAmP;oY=3g0_nVbo<2ojC;m0;oYLOa1OnTao82oj;7l`;oY<C`1?nR
aO42oj35lP;oX/?`1?nQa?42oio5l`?oX/?a0onPa?82oj35lP?oX/?a1?nRa?42oj;5l@;oXlC`0_nT
aO02ojC3l0GoYLC_1?nVa>l4ojO4kP;oZ<C^0_nW`nh9ojS3k@;oZ<;/0_nX`^d<ojS2k0OoZ<7/00Go
0000ojS1k?nX`N_oZ<7[ojS1k00:ojS1j`SoZ<3[0_ooool00ol0003oooooooooo`0=ooooo`00;ooo
ool00ol0003oooooooooo`0_ooooo`Co/L;W00Co//7Uojnmi?n__NCo[kgT1?n^^>42ojbcg@;oYK;R
0onQ[Ml4oibWgP?oUZ?N0_nAX=l3ohfnm`;oQL_n0onOio`3okG]mP03oko`l_nlc^So_<kX00;o_<kX
0_nh`N401?nRX]CoUI??oiFCconETll3ohB5c0?oNX7>0omdM<@3og5ea`;oN8OE0_n?j?P00oo0o]co
d_gNom;mgP04ol[Qj@;o^LOT00CoX:KJohjDeOn>U=GoSYCE0on5SM<4oh:<e0?oQICJ0_n7S=400on>
XN7oUZoXoiJ_j002oiJ_j0CoW[g_0_nRb?<3ojSDm`;oYmSi0onYfOP2ojOHn@?oZM?f0_nWdOH3ojO<
l`;oY/_c0_nVao44ojG7l@;oY<Ob0_nUa?05ojC4l0;oX/Ga0_nT`nl4oj;3l0;oXLCa0onS`_02oj;3
l@;oXl;_1?nR`o02oj;3l@;oXl;_1?nR`o02oj?4l0;oXl?_1?nT`o02ojG4k`;oYL?_1OnVa>l2ojO4
kP03ojK3k_nW`nkoYl?^00?oYl?^0_nX`nd3ojO3k@;oZ<?]00?oYl;]ojS2kOnX`^d00onX`^d:ojS2
k0WoZ<7/00?o0000ojS1k?nX`N`00_nX`N`9ojS1j`SoZ<3[0_ooool00ol0003oooooooooo`0=oooo
o`00<?ooool2o`00033ooooo0_na`^L2ojo2i`Co[kgT0_n^^>42ojRgi0CoYK;R0onQ[Ml2oibWgP;o
UkC[1?nA]_02ohfnm`?oVmWm00CoWnOlokG]m_nekOKo]Ngf1?nmend2okc>j003ojb`f_nRX]CoXZ;D
00;oXZ;D0onETll3ohB5c0;oNX7>1?m_Q]T4ogN]m003ohoXn?n]k_So`?gS00?oc^kZ0_o:hNT2ok:l
h@?oX:KJ0on>U=D3ohF=d`CoPXcD0on5U=X3ohjQh@CoUZoX0_nN_Nl3ojK>m@;oZ=Cg0on[f?L2ojWI
n0?oZmCf0_nYdoH3ojW=l`;oYlcc0_nXb?04ojK7l@;oYLOa0_nVa>l4ojG4l0;oY<C`0onU`nl2ojC3
k`;oYL;^1?nT`^l2oj?2l0;oY<;^1OnS`^l2oj;3l0KoXl;_0_nR`o02oj?2k`CoXl?_0_nT`o02ojC3
k`CoYL?_0_nVa>l6ojK3kPGoYl?^0_nW`nd6ojO2k@;oZ<;]0_nW`^d8ojS2k0_oZ<7/00?o0000ojS1
k?nX`N`01?nX`N`2ojS1j`03ojS1k?nX`N_oZ<7[00?oZ<7[2?nX`>/00ooooooo0000ooooo`0>oooo
o`00<_ooool00ol0003oooooooooo`0^ooooo`Co[l;W0_n__N@2ojZli`CoZ;OT0_nU/^82oinfj0?o
VkCY1?nG]>/2oi6fl0?oV<gj0_nKfOd2oj[VnP?o^=Wa0_nmend2ok>lh@Co[;3J0onRX]@3oiFCc`?o
Q8G<0omjPLh4ofn6f@;oMjgd0_n]k_P01?o0oN?oc^kZolk^j_o>k^X2ol;BiPCo/[cQ0onPY]X3ohjD
e@?oQHgC0on2S=@4ohFDfP?oSZ7Q0_nF[nP3oj74lP;oY/ke0on[e_L2oj_Hm`?o[MGe0_n[e?H3oj_?
l`;oZLgc0_nYbO04ojS8l0;oY/Oa0_nWaNl4ojK4k`;oYLC`0onV`nh2ojG3k`;oY/;]1?nU`^h2ojC2
k`;oYL7^1?nT`^h2oj?2k`;oY<7^1_nS`^l2ojC2kPGoXl;_0_nS`nl00onT`^koY<?_ojC3k`03ojC3
k`;oYL?_0_nU`^h6ojK3kP?oY/;^0_nW`nh2ojK2k@coYl;]0_nX`^`2ojO2k0CoZ<;/2onX`N`00ol0
003oZ<7/ojS1k007ojS1k0CoZ<7[1onX`>/00onW`>_oooooo`00000?ooooo`00<oooool00ol0003o
ooooooooo`0^ooooo`;o[l;W0_nZ`NX4ojZli`;oZ;OT0_nR^NT4oinfj0?oVkCY0_nG]>/3oiW5mP;o
V<gj0onTg?/01?nZi_[o^=WaokSIlOnhfO42okC4iPCo/kcQ0on//=X4oj:Re0?oUI??0on4QL`3ogZ1
cP;oKhKI0onGaOL01On]k_So]?CcolWbkOo9l^goc^kZ00Co`];V0_nb_>401?nMZMkoTIcJoi6Lf_nA
W=X3ohJCf@?oQICK0on9W=l4oi2YiPGoV[S]0_nQa?83ojSBmP;oZmKg0on]e_D2ojgEm@;o[M7c0_n[
co<2oj_;l@GoZLW`0_nXb?02ojS5k`CoYlG_0_nVa>l5ojK3kPKoY/;]0_nU`^h2ojK1k@CoYL7^0_nT
`^h2ojG1k@CoY<7^0_nS`^l2ojC1kPCoY<;^0_nS`^l2ojC1kPCoY<;^0_nT`nl7ojG2kP;oY/?^1?nV
`^h7ojK2k@[oYl;]1_nW`^`2ojS2k0;oYl7/2onX`N`00ol0003oZ<7/ojS1k007ojS1k0CoZ<7[0_nX
`>/6ojO0j`03o`000?oooooooooo00gooooo000dooooo`03o`000?oooooooooo02kooooo1?nZ`NX2
ojZli`;oY;c[1?nR^NT2oinfj0;oWKk`1?nJ`?82oiW5mP?oXM?j0_nTg?/3ok;Gl`03okSIlOnda>Ko
]<CV00;o]<CV0onc_>42ojb`fP03oijUf_nCVmWoTi_I00;oTi_I0on:UMT4oh2Dg@CoQJCX0_nGaOL2
okCdl`;obO;]0oo9h^X2ol;BiP03ojjkh_nMZMkoWJWN00;oWJWN0onAW=X3ohJCf@?oQICK0on9W=l4
oi2YiP;oV[S]0onTb_<2ojSBmP?o[MCd0_n]e_D2ojkBl`?o[M7c0_n/c?44oj_;l@;oZLW`0onYa^l4
ojS5k`;oYlG_0_nW`nd2ojK3kP;oYl;]1onV`^d6ojK1k@;oYL7^0_nV`Nd4ojG1k@;oY<7^0_nU`Nd4
ojC1kP;oY<;^0_nU`Nd4ojC1kP;oY<;^0onU`Nh2ojG2kP;oYL7]1?nU`^h2ojK2kP[oY/;]2?nW`^d7
ojO2k0KoYl7/0_nX`N`2ojO1k0;oZ<7/0_nW`N`3ojS1k005o`000?nX`NcoZ<7/ojS1k?nW`N`01OnX
`N`2ojS1j`SoYl3[00?oooooo`000?ooool03_ooool003Gooooo0_l0000_ooooo`;oZ/7Z0onU_n`3
ojBlj`;oX[WY0_nO_Nh4oifnl0;oV/3b0onOc?L2oj7CnP?o[=;d0_nbeo<2okC9jP?o]<CV00?oZkKQ
ojJ_g_nV[mh00_nV[mh3oijUfPCoTi_I0on:UMT4oh2Dg@;oQJCX0onKfOd00ondm??obO;]olWbk@03
olWRjP03ok[;ion^^n;o[[_R00;o[[_R1?nMZMh3oi6LfP?oQY?I0on5U=/3ohVLg`;oT:WV0_nK__03
ojC:l`;oZ]3d0on]e?@2ojkCl`Co[];c00?o[M7cojc<lOn/c?400_n/c?42oj_;l@;oZ/O_0onYa^l2
ojS4k@CoZ<?]0_nW`nd6ojO2k@;oY/;]0_nW`N`6ojK1k@;oY/7/1OnV`Nd2ojG1k@03ojK1kOnU`Ngo
YL7]00?oYL7]0_nT`Nh6ojG1k@;oY<7^0onU`Nd2ojG1kPKoYL7]0_nU`^h2ojK1k@KoY/;]0_nV`Nd4
ojK2k@;oYl;]0_nW`Nd4ojO2k@;oYl;/4onW`N`2ojS1k003o`000?nW`NcoYl7/00?oYl7/0_nX`N`2
ojO1k0KoYl3[1_ooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`0^oooo
o`;oYKo/0_nR_^d3oj2nkPCoWkg^0_nM__03oio7m0;oWlcg0onXcO<2ojcBm0;o/L_]1?ndbNX01?nd
a>KoZkKQoj^fhOn[]^44ojJ_gP?oWZGJ0onCVmT3ohZEf@;oP9CM0on=^O@2oi_Io@?o^>We0_o3io00
0oo9h^[o^/_Wok[;i`02ok[;i`;o[[_R00?oX:_Ooi:OgOnBWmd00_nBWmd3oh^Kg@?oQi_O1?n;XnD3
oi>`j`CoVkk`00?oY<[coj[@m?nZd?@00_nZd?@00on]e?Co[]?cojkCl`02ojkCl`;o[];c0on]c_42
ojc<l@;oZlS_1?nZanl00onYa^ooZ<C]ojS4k@02ojS4k@;oZ<?]0_nX`^`6ojO2k@KoYl7/0_nV`Nd2
ojO1k0CoY/7/0_nV`Nd3ojK0k0?oY/7]0_nU`Nd3ojK1k@;oYL7]0_nV`N`6ojG1k@;oY/7]1_nU`Nd7
ojK1k@;oY/;]1_nV`Nd2ojK2k@KoYl7]0_nW`^dIojO1k003o`000?nW`NcoYl7/00OoYl7/0_nW`>/9
ooooo`03o`000?oooooooooo00cooooo000hooooo`03o`000?oooooooooo02kooooo1?nR_^d3oj2n
kP;oWkg^0onO`o42oio7m0;oY/Wb0onXcO<2ojk9kPCo/L_]0_ndbNX2ojjli0CoZkKQ0_nV[mh01?nM
Z=koUZCNoiJTg_nFY=h4ohfQhPCoRjSX0_n=^O@3ojWHn004okSYmOo3io3o`nO`ol?Wl0?o_]K[0_nj
bnL00on[^>?oX:_Ooj2[g`02oj2[g`CoTYoM0on;Vmd3ohNKg`CoRj?U0onC/>/2oi^nl0?oYLWc0_nZ
d?@3ojkBl`;o[]?c0on^co42ojg>l@;o[<[_1?n[b>l2oj[7k`?oZLG]0_nXa>d6ojS2k0;oYl;]3_nW
`N`2ojK1k0?oYl3/2?nV`>`2ojK1k@;oY/3/1?nV`N`2ojG1k@;oY/3/1?nV`Nd2ojG1kA;oY/7]1_nW
`NdNojO1k003o`000?nW`NcoYl7/00GoYl7/3?ooool00ol0003oooooooooo`0<ooooo`00>Oooool0
0ol0003oooooooooo`0^ooooo`;oX[k]0_nQ_^h4oj30k`;oWl?a0_nTaO04ojK9lP03ojS=lon^bNko
[/W^00;o[/W^0_nabnd2ojk0i`Co[[cT0_n[]^42oj>^g`?oWJSN0onFY=h4ohfQhP;oRjSX0onLaO@2
ojWHn0;o^^Cd0_nnfnh3okkFj`;o]<CV0on[^><4oj2[g`?oTYoM0on;Vmd4ohNKg`;oRj?U0_nE/n`4
oijol0;oYLWc0onZco<2ojkBl`?o[]3b0_n^co400on]c?3o[<[_ojc:k`03ojc:k`;oZlS_0onZa^h2
ojW5k@03ojW3kOnX`^coZ<;/00GoZ<;/00?oZ<7/ojO1k?nW`N`03OnW`N`6ojO0k0goY/3/0_nV`N`6
ojK0k0;oY/7]0_nV`N`6ojK1k@;oY/7/1_nV`Nd2ojK1k0CoY/7]0_nW`NdRojO1k003o`000?nW`Nco
Yl7/013ooooo00?o0000ooooooooool03?ooool003[ooooo0_l0000_ooooo`CoXKk^0_nP`>l2ojC2
kPCoY<G`0_nVbO83oj_7kP;o[/W^0_n^`^T4ojk0i`;o[[cT0_nX]>44oj>^g`?oWJSN0onFY=h2ohfQ
hP;oUKK^0onLaO@3oj_In003ok[Tm?nnfnko_]_^00;o_]_^00?o_]K[okC4i_nda>H00_nda>H3oj^h
h`;oX:_O00CoV:OQohnRhOn?X^7oSj;Q1?n=Xn<3ohnYi`GoUK?/0_nN_o02ojK9lP;oZ/oc0_n]co84
ojk@lP03ojk=l?n]c?3o[Lc`00;o[Lc`0_n/b^l3oj_7kP;oZ/K^0_nYa>d4ojW3k@CoZ<;/1?nX`N`7
ojO1k0koYl3/0_nV`>`2ojO0k0KoY/3/0_nW`>`8ojK0k0GoY/7/0_nV`Nd6ojK1k0;oY/7]1_nV`N`2
ojK1kBGoYl7/00?o0000ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`00??ooool00ol0
003oooooooooo`0]ooooo`;oXKk^0_nT_nd4ojC2kP;oY<G`0onYaNh2oj_7kP;o[L?Z1?n^`^T2ojk0
i`;oZ[SS1?nX]>42oj>^g`03oij`i?nI[^KoVJkV00;oVJkV1?nG/>T3oiFfkP04oic5m?n[fOSoZmWh
oj_In0?o]]Wb0_nnfnh3okW>jP;o]<CV00?oZKWToj2_h_nP[n800_nP[n83oiRWh@?oSj;Q1?n=Xn<3
ohnYi`;oUK?/0onN`O42ojK9lP;oZ/gb1?n]co800on^d?;o[/g`ojk=l002ojk=l0;o[Lc`0on/b>h2
oj_7kP;oZ/G]1?nYa>d2ojW3k@KoZ<;/0_nX`N`5ojO1k0SoYl3/0_nW`>/<ojO0k0;oY/3/1_nW`>`2
ojK0k0;oYl3/1?nV`>`2ojK1k0;oY/3/2onV`N`XojO1k0Gooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0<ooooo`00?Oooool00ol0003oooooooooo`0]ooooo`CoY;o]0_nT`^h3ojO2
k@;oZLG^0_n[`^/4ojg3jP;o[/;Y0_n/_>D4ojZhh`;oZ;CQ0_nR/n@3oij`i0CoVJkV0_nG/>T2oig1
lPCoXLcf00CoZmWhokKIl_nffO;o]]Wb0_ngd^h3okW>jP;o/<7W0onY^N@4oj2_hP?oV:OQ0on?X^42
ohfSh`;oTZkY1?nH]nd2oik1l@;oYLOa1?nZcO82ojg?lP?o[/ka0_n^cO03ojg:k`;o[<S^0_n[a^d4
oj[5k@;oZLC]0_nY`n`6ojS2k0?oZ<7/0_nW`N`2ojO0j`KoYl3/1_nW`>/2ojO0k0;oYl3[5?nW`>`2
ojK0k0?oYl3/0onV`>`2ojK1k0?oYl3/0_nV`N`2ojO0k2KoYl7/2Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00cooooo000nooooo`03o`000?oooooooooo02gooooo0_nT_nd3ojO0
j`;oYl;]0_nZ`NX4oj_2j`;o[L?Z0_n/_^L4ojbli@;oZ[SS0_nV]nD4oj:ci0?oW[3T0_nI[^H2oi^j
kPCoWL7b0_nQc?H3ojkCl`03okKIl_ngd^ko]m;^00;o]m;^00?o^LkZok31ion``NL00_n``NL3ojVi
i0;oX:oR00?oVZ_SoiBXhonDZ><00_nDZ><3oi6XiPCoTZkY0_nH]nd2oio0l0CoYLOa0_nZcO83ojc=
l@;o[/ka0on]bnl2ojg:k`;o[<O^1?n[a^d2oj[5k@KoZL?/0_nX`^`5ojS1k003ojS1jonW`>_oYl3[
00?oYl3[0_nW`>`>ojO0j`;oYl3/00?oYl3[ojO0k?nW`>`08?nW`>`2ojO1k003ojO0k?nW`NcoYl7/
01WoYl7/4?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo000oooooo`;o
0000;oooool2ojO0j`;oZL3Z1?nZ`NX2oj_2j`;o[;oX1?n/_^L2ojbli@;oZ;WV1?nV]nD2oj:ci0;o
X;OX0onN]nX4oi^jkP;oWL7b0onWc?<2ojkCl`?o/m?`0_ngd^h3ok;7j@;o/<7W00?oZ;SUoj:ahonR
/N<00_nR/N<3oiZ[h`CoU:SS0onAZ>H2oi:^j@;oVKS]1?nO`?02ojG7l@?oZL_a0_n/cO42ojg<l0?o
[L__0_n]bNh4ojc7kP;oZlK]0_nZa>d6ojW3k0;oZ<;/1?nX`N`4ojS1jaSoYl3[0_nW`>`3ojO0j`;o
Yl3/0_nW`>/LojO0k0;oYl7/0_nW`>`CojO1k1Cooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0;ooooo`00@Oooool00ol0003oooooooooo`0]ooooo`CoZL3Z0_nZ`NX2oj_0j@Co[;oX
0_n/_^L2ojVli`CoZ;WV0_nV]nD2oj>hj0CoX;OX0onN]nX2oi^jkP?oX/Ga0_nWc?<3ojg@lP;o/m?`
0oncbn`2ok;7j@;o[KkW0onX^>D4oj:ah`?oVZ_S0_nDZ><2oiJ^j0?oU[;Z1?nI^>d2oio0l0?oYLKa
0_nYbo42oj_;l0Co[Lc`00?o[L__ojg9k_n]bNh00_n]bNh2ojc7kP03oj_5kOnZa>goZ/C]00?oZ/C]
0_nY`n`2ojW2k0;oZ<;/1_nX`N`2ojS1jb?oYl3[0_nW`>`2ojO0j`KoYl3/0_nW`>/DojO0k0;oYl7/
0onW`>`:ojO1k1Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`00@_oo
ool00ol0003oooooooooo`0]ooooo`;oZL3Z0_n[`NX4oj_0j@;o[;oX0_nZ_^P4ojVli`;oZ;WV0_nU
^NP4oj>hj0;oX;OX0_nQ_Nd4oj70k`;oX/Ga0onXbo82ojg@lP;o/<c^0oncbn`00on_`nWo[KkWojfn
i`03ojfni`?oZ;SU0_nR/N<00onN/NGoV:kVoiR^iP02oiR^iPCoUZkX0onF/^X2oiVhk@?oWl3`0_nU
a_400onXb?3oZl_`oj_;l003oj_;l0;o[Lc`0_n]bNl2ojg9kP;o[<K]1?n[aNd2oj[4k@?oZL?/0_nY
`^`8ojS1k0;oZ<3[:OnW`>/2ojO0k0KoYl3[0_nW`>`00onW`>_oYl3/ojO0k00CojO0k0KoYl7/7Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0013ooooo`03o`000?oooooo
oooo02gooooo1?n[`NX2oj_0j@;oZ[oY1?nZ_^P2ojVli`;oYk_X1?nU^NP2oj>hj0;oX[c/1?nQ_Nd2
oj70k`?oYLOa0_nXbo82ojg:k`Co/<c^00Co/l_/ojo3jOn_`nWo[l?Y0_n]_^L2ojNiiP?oX[CU1?nN
/ND4oiR^iP;oUZkX00?oVKG[oibjkOnL^^d00_nL^^d2oio0l0;oY<C`1?nXb?02oj_;l0?o[<W_0_n]
bNl2ojc7kPCo[<K]0_n[aNd3oj[4k0;oZL?/0_nY`^`6ojS1k0;oZ<7[1?nX`>/dojO0j`;oYl3/0onW
`>/@ojO0k0;oYl7/8?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0014
ooooo`03o`000?oooooooooo02gooooo0_n[`NX2oj[1jPCoZ[oY0_nZ_^P2ojRmj@CoYk_X0_nU^NP2
oj>lj`CoX[c/0_nQ_Nd3ojC3l0;oYLOa0_nYb?04ojg:k`;o/<c^0_n_a^/2ojo3j@;oZ[gW1?nW^NH3
oj:di@;oW[7U0_nL/^L3oiZbj@CoVKG[0_nL^^d2oj70k`CoY<C`0_nXb?03oj[9l0;o[<W_0_n/b>h4
ojc7kP;o[<K]0on[aNd2oj[4k0;oZL?/1?nY`^`4ojS1k0CoZ<7[1OnX`>/lojO0j`;oYl3/00?oYl3[
ojO0k?nW`>`01OnW`>`Tooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
04Gooooo0_l0000_ooooo`?oZ/7Z0_nZ_nT3ojRojP?oZ;gY0_nW^nP3ojFmj`?oXkc[0_nR_>`3oj?1
kP;oY<?`00?oYlG_ojW8l?nYb?000onYb?02ojg:k`;o[/O]0_n_a^/2ojc0j@CoZ[gW0_nW^NH2ojBg
iP?oWkCV1?nL/^L3oiZbj@;oVKG[0_nN^nd4oj70k`;oY<C`0onWa_02oj[9l0;oZlS_1?n/b>h2ojc7
kP?oZlK]0_n[aNd2oj[3k0CoZL?/0_nY`^`6ojS1k0;oZ<7[1?nX`>]2ojO0j`;oYl3/:Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo0017ooooo`03o`000?oooooooooo02go
oooo1?nX`>/2ojRojP;oY[o[1?nV_^/2ojFmj`;oY;o/1?nT_nd2oj?1kP03ojK4konWaNooYlG_00;o
YlG_0_nYb?03oj_7kP;o[/O]0_n/`nX4ojc0j@;oZ[gW0_nW^^L4ojBgiP?oWkCV0_nL/^L2oiffjPCo
W;S[0onN^nd2oj70k`?oY<?_0_nWa_02ojW7k`CoZlS_0_n/b>h3oj_6kP;oZlK]00?oZ/C]oj[3k?nZ
`n`00onZ`n`2ojW3k0;oZL;/1OnX`N`3ojS1j`CoZ<3[@_nW`>//ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02oooool004Sooooo00?o0000ooooooooool0;Oooool2ojS0j`;oYl3[
1?nV_n/2ojJnj`;oYKo/1?nT_n`2ojBok@03ojG2k_nVa>ooY/C_00;oY/C_0_nWaNl3ojW6kP;oZlO^
0_n[`n/4ojc3jP;o[<3Y0_nY_>P4ojNji`;oY;OV0_nR]nP3oinfj0CoWKKZ0_nL^>/2oj2lk@CoX/3^
0_nT`nl2ojO5k`CoZLO_0_n[b>l3oj_7kP;oZlK^00?oZlG]oj[4kOnZa>d00_nZa>d2oj[3k0GoZL;/
0_nX`N`6ojS1j`KoZ<3[?_nW`>/`ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2oooool004Wooooo00?o0000ooooooooool0;Oooool4ojO0j`;oY[o[1_nU_n`2ojBok003ojG1kOnU
`^koYL;^00;oYL;^0_nVa>l3ojS4kP;oZLK^0_nZa>`4oj_3j`;o[<?Z0_nZ_nT4ojVlj0;oYk[W0_nT
^NP4oj:gj0?oWkKX0_nM]^X2oinjk0CoX;c]0_nR`>h2ojC2k`CoYlG_0_nYanl2oj[6kP;oZlO^0_nZ
aNd4oj_5k@;oZ/C]0onY`n`4ojW2k0CoZ<7/1?nX`N/6ojS0jccoYl3[=?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo001:ooooo`;o0000;_ooool2ojO0j`;oY[o/1_nU_n`2
ojG0k@?oYL7]0_nU`^h3ojO3kP;oZ<C^0_nY`nd4oj[4k0;oZl?[0_nZ`>X4ojZoj@;oZKcX0_nV^nP4
ojBij0;oX[OX0_nQ^>T3oinijPCoWk[/0_nP_>d2oj?0kPCoY<;_0_nWaNl2ojS6k`CoZ/K^1?nZaNd2
oj_5k@?oZ/C/0_nY`n`6ojW2k0;oZ<7/1_nX`N/3ojS0jc[oYl3[>Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00[ooooo001<ooooo`03o`000?oooooooooo02cooooo1?nV_n`2ojFo
k0?oYL3/0onU`>d01?nU`NgoY/;]ojK2kOnV`^d2ojO3kP;oZ<?]1?nY`nd2oj[4k0;oZ/7[1?nZ`>X2
ojZoj@;oZ;cX1?nV^nP2ojBij0;oXkWY1?nQ^>T3oinijP;oWk[/0_nR_Nd4oj?0kP;oY<;_0_nVa>l2
ojS6k`;oZLG^1?nZa^h2oj[5k@?oZ/C]0_nZa>`2ojW3k0KoZL;/00?oZ<7/ojS1jonX`N/01OnX`N/5
ojS0jcKoYl3[??ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo001=oooo
o`03o`000?oooooooooo02cooooo1OnV_n`2ojG0k003ojK0k?nV`NgoY/7]00;oY/7]0_nV`^d2ojO2
k0CoZ<?]0_nY`nd2ojW2j`CoZ/7[0_nZ`>X2ojRnj@CoZ;cX0_nV^nP2ojFjj0CoXkWY0_nQ^>T00onR
^n_oXKc/oj6lk002oj6lk0;oX[g]0_nT`>h4ojG2kP;oY/C_0_nXa>h4ojW5kP;oZ/K^0onZaNd2oj[4
k@KoZL?/0onY`^`4ojS1k0GoZ<7[1OnX`>/aojO0jd?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0:ooooo`00C_ooool00ol0003oooooooooo`0]ooooo`?oY[o/1?nV`>`2ojK1k@;o
Yl7/1?nW`^`2ojS3k@;oZL;/1?nY`^/2oj[1j`?oZKoY0onX_^T2ojRlj0;oY[_X1?nU^^P2oj>ij@03
oj>kj_nR^n_oX[_[00;oX[_[0_nQ_>`2oj>nk@CoY<3^0_nU`^h2ojK3kPCoZ<C^0_nYaNh3ojW5k@;o
Z/G]0_nYa>d6ojW3k0GoZL;/0_nX`N`5ojS1j`KoZ<3[;_nW`>]7ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02_ooool004oooooo0_l0000^ooooo`?oY[o/0_nV`>`2ojO0k0CoYl7/
0_nW`^`2ojS1k0CoZL;/0_nY`^/3ojW0jP;oZKoY0_nX_^T4ojNmj@?oY[_X0_nU^^P00onT^nWoXk_Z
oj>kjP02oj>kjP;oX[_[0_nS_N`4oj>nk@;oY<3^0_nU`^h4ojK3kPGoZ<C^0_nYaNd6ojW4k@?oZL?/
1_nY`^`3ojS1k0CoZ<7[1_nX`>/[ojO0jdcooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0:ooooo`00DOooool00ol0003oooooooooo`0/ooooo`03ojJok?nW`>_oYl3[00CoYl3/0_nW
`N`6ojS1k0;oZL;/0onY`>/2ojW0jP;oZ;kZ1?nX_^T2ojNmj@03ojJljOnU_>WoYKcY00;oYKcY0onT
^nT2oj>kjP?oXkc[0onS_N`2oj>nk@?oY<3]0onU`^h2ojK3kP?oYlC^0_nXa>h00onXa>goZLC]ojW4
k@04ojW4k@KoZL?/0_nY`^`3ojS2k0;oZ<7/1_nX`N/3ojS0jb[oYl3[Coooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00[ooooo001Booooo`03o`000?oooooooooo02_ooooo1?nW`>/2
ojO0k0?oYl3[0_nX`N`6ojS0j`;oZL3[0_nX_nX4ojRnjP;oZ;kY00?oYkgYojJljOnV_>T00_nV_>T2
ojFlj@;oYKcZ1?nT_>/2oj>lj`;oY;k/1?nT_nd2ojC0k@;oY/;]1?nV`nh2ojO4kP03ojS3kOnXa>go
Z<C]00;oZ<C]0_nYa>d3ojW3k@;oZL?/1_nY`^`2ojS2k0;oZ<7/1_nX`N/5ojS0jbKoYl3[Doooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo001Cooooo`03o`000?oooooooooo
02_ooooo1onW`>/8ojS0j`KoZ;oZ0_nX_^X00onW_^[oYkgYojNmj@02ojNmj@;oY[cY0_nU_NX4ojFl
jP;oY;c[1_nT_^`2ojBok@;oYL7]1?nV`^d2ojK3kP03ojO3kOnX`ngoZ<?]00;oZ<?]0_nXa>d3ojS3
k@;oZL?]2?nY`^`6ojS1k0?oZ<7[1_nX`>/TojO0jeOooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`09ooooo`00E?ooool2o`0002gooooo0_nW`>/:ojS0j`KoZ;oZ00?oZ;kZojNnj_nW
_^X00_nW_^X2ojNmj@;oY[gZ1?nU_NX2ojFljP;oYKg[1_nT_^`2ojFok@CoYL7]0onV`^d4ojO3k@Oo
Z<?]0_nX`n`6ojW2k003ojS2k?nX`NcoZ<7/00CoZ<7/1_nX`N/5ojS0jb7oYl3[F_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Wooooo001Fooooo`03o`000?oooooooooo02_ooooo
3?nX`>/5ojRojP;oZ;kZ1OnW_^X3ojJmjP;oYKgZ0_nU_^/4ojFmj`;oY;k/0_nU_n`4ojFok@;oYL7]
0_nV`Nd3ojK2k@GoYl?]1?nX`nd4ojS3k0;oZL;/1OnX`^`5ojS1k0CoZ<7[1_nX`>/OojO0jekooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`00Eoooool00ol0003ooooooooo
o`0[ooooo`[oZ<3[0onX_n/2ojRojP03ojNoj_nW_^[oYkkZ00CoYkkZ1_nV_^/3ojFnj`;oYKg[0onU
_^`3ojFok0;oYKo]0_nU`Nd2ojK1k@;oY/;]1?nW`^d2ojO3k@;oZ<;]1?nX`nd2ojS3k0OoZ<;/1OnX
`N`6ojS1j`?oZ<3[6_nW`>]Vooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Ooo
ool005Sooooo00?o0000ooooooooool0;?ooool8ojS0j`;oZ;o[00?oYko[ojNoj_nW_nX00_nW_nX2
ojNnjP[oY[k[1?nU_^/2ojFnk003ojFok?nU`>coYL3/00;oYL3/0_nU`Nd2ojK1k@CoY/;]1?nW`^d4
ojS2k@;oZ<?]1_nX`^`8ojS1k0KoZ<7[1OnX`>/FojO0jf[ooooo00Go0000ooooooooooooooooo`00
000;ooooo`00FOooool00ol0003oooooooooo`0/ooooo`KoZ<3[1OnW_n/2ojNojP;oYko[3?nV_^/2
ojFnj`GoYKo/0_nU`>`6ojK1k@;oY/;]1_nW`^d2ojS2k@[oZ<;/2?nX`N`3ojS1j`KoZ<3[5?nW`>]]
ooooo`05o`000?ooooooooooooooool000002oooool005[ooooo0_l0000]ooooo`;oZ<3[0_nW`>/;
ojNoj`;oY[k[0_nV_n/6ojJnj`03ojJok?nU_ncoYKo/00CoYKo/0onV`>`5ojK1k@?oYl7]1onW`^d:
ojS2k0SoZ<7/1OnX`N/2ojS0jaCoYl3[LOooool01?l0003oooooooooool0000;ooooo`00G?ooool0
0ol0003oooooooooo`0[ooooo`CoYl3[2OnW_n/6ojJoj`;oY[k[1OnV_n`2ojFok0GoY/3/0_nV`N`4
ojK1k@;oYl7]1onW`^d8ojS2k0[oZ<7/1?nX`N/4ojS0ja7oYl3[MOooool00ol0003oooooo`00000;
ooooo`00GOooool00ol0003oooooooooo`0[ooooo`CoYl3[2?nW_n/8ojJoj`?oY[o/2?nV`>`4ojK1
k0;oY/7]00?oYl7]ojO2kOnW`^d01?nW`^d2ojO2k0KoZ<;/3_nX`N`4ojS1j`;oZ<3[3onW`>]hoooo
o`04o`000?ooooooooooo`0000[ooooo001Nooooo`03o`000?oooooooooo02_ooooo1?nW`>/6ojNo
j`SoY[o[1OnV_n`8ojK0k0?oY/7/1?nW`Nd2ojO2k@?oYl7/0onW`^`2ojS2k1;oZ<7/0_nX`N/?ojO0
jgcooooo00?o0000ooooool000002_ooool005oooooo0_l0000/ooooo`CoYl3[0_nW_n/8ojJoj`Oo
Y[o/2?nV`>`5ojK1k0;oYl7]2onW`N`AojS1k0;oYl7[2_nW`>^3ooooo`;o00002_ooool0067ooooo
00?o0000ooooooooool0:_ooool2ojO0j`?oY/3/1OnV_n/7ojJok0_oY/3/0_nV`N`@ojO1k0koZ<7/
0_nW`N`2ojO1j`;oYl3/1_nW`>^5ooooo`?o00002_ooool006;ooooo00?o0000ooooooooool0:ooo
ool2ojK0k0OoY[o/4?nV`>`00onV`NcoYl7/ojO1k00AojO1k0;oZ<7/0onW`N`2ojS1k0WoYl7/1?nW
`>`2ojO0jhCooooo1?l0000=ooooo`00Hoooool00ol0003oooooooooo`0[ooooo`OoY[o/3onV`>`4
ojK1k2?oYl7/0_nW`>b3ooooo`Co00004Oooool006Cooooo0_l0000/ooooo`OoY[o/3onV`>`2ojK1
k2?oYl7/Poooool3o`0001Gooooo001Vooooo`03o`000?oooooooooo02_ooooo1?nV_n`<ojK0k0;o
Yl3/8OnW`Nb5ooooo`Co00006?ooool006Oooooo00?o0000ooooooooool0:_ooool4ojJok0[oY/3/
1OnW`>`MojO1k8Cooooo1?l0000Looooo`00J?ooool00ol0003oooooooooo`0Zooooo`CoY[o/1_nV
`>`:ojO0k1SoYl7/Poooool4o`00023ooooo001Yooooo`;o0000;?ooool3ojJok0;oY/3/3_nW`>`D
ojO1k8;ooooo1?l0000Tooooo`00Joooool00ol0003oooooooooo`0Zoooooa?oYl3/4?nW`Nb2oooo
o`?o0000:?ooool006cooooo00?o0000ooooooooool0:_ooool2ojO0k003ojO0jonW`>coYl3/00ko
Yl3/2_nW`Nb3ooooo`Co0000:oooool006gooooo00?o0000ooooooooool0:oooool2ojO0ja3oYl3/
1_nW`Nb2ooooo`Co0000;oooool006kooooo00?o0000ooooooooool0:_ooool4ojO0j`;oYl3/0_nW
`>/;ojO0k0;oYl7/POooool4o`0003?ooooo001_ooooo`;o0000:oooool8ojO0j`04ojO0k?nW`>_o
Yl3[ojO0j`GoYl3/P?ooool4o`0003Oooooo001aooooo`03o`000?oooooooooo02[ooooo2OnW`>^2
ooooo`Co0000>oooool007;ooooo00?o0000ooooooooool0:_ooool5ojO0jh;ooooo0ol0000ooooo
o`00Loooool00ol0003oooooooooo`0Zooooo`03ojO0jooooooooooo07oooooo1?l00012ooooo`00
M?ooool2o`0002[ooooo00?o0000ooooooooool0Noooool4o`0004Kooooo001fooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0N?ooool4o`0004[ooooo001gooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0M?ooool4o`0004kooooo001hooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0LOooool3o`0005;ooooo001iooooo`;o00009?ooool00ol0003o
ooooooooo`1]ooooo`Co0000EOooool007_ooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`1Yooooo`Co0000FOooool007cooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`1Uooooo`Co0000GOooool007gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Q
ooooo`Co0000HOooool007kooooo0_l0000Oooooo`03o`000?oooooooooo05gooooo1?l0001Uoooo
o`00P?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05[ooooo0ol0001Yooooo`00
POooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Kooooo1?l0001/ooooo`00P_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05;ooooo1?l0001`ooooo`00Poooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04kooooo1?l0001dooooo`00Q?ooool2o`00
01Wooooo00?o0000ooooooooool0B_ooool4o`0007Sooooo0026ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0A_ooool4o`0007cooooo0027ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0@oooool3o`00083ooooo0028ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0?oooool4o`0008?ooooo0029ooooo`;o00005?ooool00ol0003oooooooooo`0k
ooooo`Co0000Qoooool008_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0goooo
o`Co0000Roooool008cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0cooooo`Co
0000Soooool008gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0`ooooo`?o0000
Toooool008kooooo0_l0000?ooooo`03o`000?oooooooooo02cooooo1?l0002Fooooo`00T?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Sooooo1?l0002Jooooo`00TOooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo02Cooooo1?l0002Nooooo`00T_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo027ooooo1?l0002Rooooo`00Toooool2o`0000Wooooo
00?o0000ooooooooool07Oooool4o`000:Kooooo002Eooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool06_ooool3o`000:[ooooo002Fooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool05_ooool4o`000:gooooo002Gooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool04_ooool4o`000;7ooooo002Hooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool03_ooool4o`000;Gooooo002Iooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000
^Oooool009_ooooo00Co0000oooooooooooo00002Oooool3o`000;gooooo002Looooo`03o`000?oo
oooo000000Gooooo1?l00030ooooo`00WOooool2o`000003ooooool0003o000000;o0000a?ooool0
09kooooo0_l00038ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z_ooool01OnHV9So0000o`00
0?m4A4Co^[Zj00[ooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOoo
ool00oooool2ob4Q8@Cooooo1Ol0002Cooooo`00Z_ooool01Ol@413o^[Zjonk^k_mgMgOo410@00;o
oooo1_l00004ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool00oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A02Cooooo`00Z_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00onHV9So8B4Qonk^kP2Dooooo`00
Z_ooool00ol0003oooooooooo`04ooooo`Ko00001?ooool00ol0003oooooooooo`06ooooo`03ogMg
Molb<S;ooooo00_ooooo00?oV9RHob4Q8Oo^k^h0Toooool00:[ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03Oooool00omgMgOoIVIV
ooooo`2Booooo`00Z?ooool00ol@413o0000o`000003o`0000gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo097ooooo002Zooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`05o`000?nj^[[o
oooooiRHV?l@4100Toooool00:[ooooo00?o0000ooooooooool03?ooool00omEEEGoIVIVo`000005
ooooo`Co00002oooool01OnHV9So410@o`000?lQ8B7oc<c<09?ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -17 0 ]
[.5 .82364 17 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16.) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.655 .751 .921 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69469 Mtetra
.655 .752 .921 r
.4053 .69469 .41061 .69934 .41957 .69681 .41427 .69217 Mtetra
.655 .753 .922 r
.41427 .69217 .41957 .69681 .42855 .69428 .42327 .68964 Mtetra
.42327 .68964 .42855 .69428 .43756 .69174 .4323 .6871 Mtetra
.655 .754 .923 r
.4323 .6871 .43756 .69174 .4466 .68919 .44136 .68456 Mtetra
.655 .755 .924 r
.44136 .68456 .4466 .68919 .45567 .68663 .45046 .682 Mtetra
.654 .756 .924 r
.45046 .682 .45567 .68663 .46478 .68407 .45958 .67944 Mtetra
.654 .757 .925 r
.45958 .67944 .46478 .68407 .47391 .68149 .46873 .67686 Mtetra
.46873 .67686 .47391 .68149 .48307 .67891 .47791 .67428 Mtetra
.655 .758 .926 r
.47791 .67428 .48307 .67891 .49227 .67632 .48713 .67168 Mtetra
.48713 .67168 .49227 .67632 .50149 .67371 .49637 .66907 Mtetra
.655 .759 .926 r
.49637 .66907 .50149 .67371 .51075 .6711 .50565 .66645 Mtetra
.50565 .66645 .51075 .6711 .52004 .66849 .51496 .66381 Mtetra
.51496 .66381 .52004 .66849 .52936 .66586 .5243 .66116 Mtetra
.656 .759 .926 r
.5243 .66116 .52936 .66586 .53871 .66322 .53367 .6585 Mtetra
.656 .758 .925 r
.53367 .6585 .53871 .66322 .54809 .66058 .54308 .65582 Mtetra
.54308 .65582 .54809 .66058 .55751 .65792 .55252 .65313 Mtetra
.656 .757 .924 r
.55252 .65313 .55751 .65792 .56695 .65526 .56198 .65043 Mtetra
.656 .756 .923 r
.56198 .65043 .56695 .65526 .57643 .65259 .57149 .64772 Mtetra
.656 .755 .923 r
.57149 .64772 .57643 .65259 .58595 .6499 .58102 .645 Mtetra
.656 .754 .922 r
.58102 .645 .58595 .6499 .59549 .64721 .59059 .64228 Mtetra
.59059 .64228 .59549 .64721 .60507 .64451 .60019 .63954 Mtetra
.656 .753 .921 r
.60019 .63954 .60507 .64451 .61468 .6418 .60982 .63681 Mtetra
.60982 .63681 .61468 .6418 .62432 .63908 .61948 .63406 Mtetra
.656 .752 .921 r
.61948 .63406 .62432 .63908 .634 .63636 .62918 .63131 Mtetra
.62918 .63131 .634 .63636 .64371 .63362 .63892 .62855 Mtetra
.63892 .62855 .64371 .63362 .65345 .63087 .64868 .62578 Mtetra
.656 .752 .92 r
.64868 .62578 .65345 .63087 .66323 .62811 .65848 .623 Mtetra
.65848 .623 .66323 .62811 .67304 .62535 .66832 .62022 Mtetra
.66832 .62022 .67304 .62535 .68289 .62257 .67819 .61743 Mtetra
.67819 .61743 .68289 .62257 .69277 .61979 .68809 .61462 Mtetra
.68809 .61462 .69277 .61979 .70269 .61699 .69803 .61181 Mtetra
.656 .752 .921 r
.69803 .61181 .70269 .61699 .71264 .61418 .70801 .60899 Mtetra
.70801 .60899 .71264 .61418 .72262 .61137 .71802 .60616 Mtetra
.655 .752 .921 r
.71802 .60616 .72262 .61137 .73264 .60854 .72806 .60332 Mtetra
.72806 .60332 .73264 .60854 .7427 .60571 .73814 .60048 Mtetra
.73814 .60048 .7427 .60571 .75279 .60286 .74826 .59763 Mtetra
.655 .753 .922 r
.74826 .59763 .75279 .60286 .76291 .60001 .75841 .59477 Mtetra
.75841 .59477 .76291 .60001 .77308 .59714 .7686 .5919 Mtetra
.655 .754 .923 r
.7686 .5919 .77308 .59714 .78328 .59427 .77883 .58903 Mtetra
.655 .755 .923 r
.77883 .58903 .78328 .59427 .79351 .59138 .78909 .58614 Mtetra
.654 .755 .924 r
.78909 .58614 .79351 .59138 .80378 .58849 .79939 .58325 Mtetra
.654 .756 .925 r
.79939 .58325 .80378 .58849 .81409 .58558 .80973 .58034 Mtetra
.654 .757 .925 r
.80973 .58034 .81409 .58558 .82443 .58267 .8201 .57742 Mtetra
.655 .758 .926 r
.8201 .57742 .82443 .58267 .83482 .57974 .83051 .57449 Mtetra
.83051 .57449 .83482 .57974 .84523 .5768 .84096 .57154 Mtetra
.655 .759 .926 r
.84096 .57154 .84523 .5768 .85569 .57385 .85144 .56858 Mtetra
.85144 .56858 .85569 .57385 .86618 .57089 .86196 .56559 Mtetra
.86196 .56559 .86618 .57089 .87672 .56792 .87252 .5626 Mtetra
.87252 .5626 .87672 .56792 .88729 .56494 .88312 .55959 Mtetra
.656 .758 .925 r
.88312 .55959 .88729 .56494 .89789 .56195 .89375 .55656 Mtetra
.89375 .55656 .89789 .56195 .90854 .55895 .90443 .55352 Mtetra
.656 .757 .924 r
.90443 .55352 .90854 .55895 .91923 .55594 .91514 .55047 Mtetra
.656 .756 .924 r
.91514 .55047 .91923 .55594 .92995 .55292 .92589 .5474 Mtetra
.656 .756 .923 r
.92589 .5474 .92995 .55292 .94071 .54988 .93668 .54433 Mtetra
.656 .755 .922 r
.93668 .54433 .94071 .54988 .95152 .54684 .94751 .54124 Mtetra
.656 .754 .922 r
.94751 .54124 .95152 .54684 .96236 .54378 .95838 .53814 Mtetra
.656 .753 .921 r
.95838 .53814 .96236 .54378 .97324 .54071 .96929 .53504 Mtetra
.656 .752 .921 r
.96929 .53504 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.654 .751 .921 r
.391 .69252 .39636 .6972 .4053 .69469 .39996 .69001 Mtetra
.654 .752 .921 r
.39996 .69001 .4053 .69469 .41427 .69217 .40895 .68749 Mtetra
.654 .752 .922 r
.40895 .68749 .41427 .69217 .42327 .68964 .41797 .68497 Mtetra
.654 .753 .923 r
.41797 .68497 .42327 .68964 .4323 .6871 .42702 .68243 Mtetra
.654 .754 .923 r
.42702 .68243 .4323 .6871 .44136 .68456 .4361 .67989 Mtetra
.654 .755 .924 r
.4361 .67989 .44136 .68456 .45046 .682 .44521 .67734 Mtetra
.44521 .67734 .45046 .682 .45958 .67944 .45435 .67478 Mtetra
.654 .756 .925 r
.45435 .67478 .45958 .67944 .46873 .67686 .46352 .67221 Mtetra
.654 .757 .925 r
.46352 .67221 .46873 .67686 .47791 .67428 .47272 .66962 Mtetra
.654 .758 .926 r
.47272 .66962 .47791 .67428 .48713 .67168 .48196 .66702 Mtetra
.48196 .66702 .48713 .67168 .49637 .66907 .49122 .66441 Mtetra
.655 .759 .926 r
.49122 .66441 .49637 .66907 .50565 .66645 .50052 .66177 Mtetra
.50052 .66177 .50565 .66645 .51496 .66381 .50985 .65912 Mtetra
.656 .759 .926 r
.50985 .65912 .51496 .66381 .5243 .66116 .51922 .65644 Mtetra
.51922 .65644 .5243 .66116 .53367 .6585 .52861 .65375 Mtetra
.656 .759 .925 r
.52861 .65375 .53367 .6585 .54308 .65582 .53804 .65104 Mtetra
.657 .758 .925 r
.53804 .65104 .54308 .65582 .55252 .65313 .54749 .64831 Mtetra
.657 .757 .924 r
.54749 .64831 .55252 .65313 .56198 .65043 .55698 .64557 Mtetra
.657 .757 .923 r
.55698 .64557 .56198 .65043 .57149 .64772 .56651 .64283 Mtetra
.657 .756 .923 r
.56651 .64283 .57149 .64772 .58102 .645 .57606 .64007 Mtetra
.657 .755 .922 r
.57606 .64007 .58102 .645 .59059 .64228 .58565 .63731 Mtetra
.657 .754 .922 r
.58565 .63731 .59059 .64228 .60019 .63954 .59527 .63455 Mtetra
.657 .753 .921 r
.59527 .63455 .60019 .63954 .60982 .63681 .60493 .63178 Mtetra
.656 .753 .921 r
.60493 .63178 .60982 .63681 .61948 .63406 .61461 .62901 Mtetra
.656 .752 .921 r
.61461 .62901 .61948 .63406 .62918 .63131 .62434 .62623 Mtetra
.62434 .62623 .62918 .63131 .63892 .62855 .63409 .62345 Mtetra
.63409 .62345 .63892 .62855 .64868 .62578 .64388 .62066 Mtetra
.656 .752 .92 r
.64388 .62066 .64868 .62578 .65848 .623 .65371 .61786 Mtetra
.65371 .61786 .65848 .623 .66832 .62022 .66357 .61506 Mtetra
.66357 .61506 .66832 .62022 .67819 .61743 .67346 .61225 Mtetra
.67346 .61225 .67819 .61743 .68809 .61462 .68339 .60943 Mtetra
.68339 .60943 .68809 .61462 .69803 .61181 .69335 .6066 Mtetra
.655 .752 .921 r
.69335 .6066 .69803 .61181 .70801 .60899 .70335 .60376 Mtetra
.70335 .60376 .70801 .60899 .71802 .60616 .71338 .60092 Mtetra
.71338 .60092 .71802 .60616 .72806 .60332 .72345 .59807 Mtetra
.72345 .59807 .72806 .60332 .73814 .60048 .73356 .59522 Mtetra
.655 .752 .922 r
.73356 .59522 .73814 .60048 .74826 .59763 .7437 .59236 Mtetra
.654 .753 .922 r
.7437 .59236 .74826 .59763 .75841 .59477 .75388 .5895 Mtetra
.654 .753 .923 r
.75388 .5895 .75841 .59477 .7686 .5919 .7641 .58663 Mtetra
.654 .754 .923 r
.7641 .58663 .7686 .5919 .77883 .58903 .77435 .58376 Mtetra
.654 .755 .924 r
.77435 .58376 .77883 .58903 .78909 .58614 .78464 .58087 Mtetra
.78464 .58087 .78909 .58614 .79939 .58325 .79497 .57798 Mtetra
.654 .756 .925 r
.79497 .57798 .79939 .58325 .80973 .58034 .80533 .57508 Mtetra
.654 .757 .926 r
.80533 .57508 .80973 .58034 .8201 .57742 .81574 .57215 Mtetra
.654 .758 .926 r
.81574 .57215 .8201 .57742 .83051 .57449 .82617 .56921 Mtetra
.654 .759 .926 r
.82617 .56921 .83051 .57449 .84096 .57154 .83665 .56625 Mtetra
.655 .759 .926 r
.83665 .56625 .84096 .57154 .85144 .56858 .84716 .56327 Mtetra
.84716 .56327 .85144 .56858 .86196 .56559 .85771 .56026 Mtetra
.656 .759 .926 r
.85771 .56026 .86196 .56559 .87252 .5626 .8683 .55724 Mtetra
.8683 .55724 .87252 .5626 .88312 .55959 .87892 .55419 Mtetra
.656 .758 .925 r
.87892 .55419 .88312 .55959 .89375 .55656 .88958 .55113 Mtetra
.657 .758 .924 r
.88958 .55113 .89375 .55656 .90443 .55352 .90028 .54805 Mtetra
.657 .757 .924 r
.90028 .54805 .90443 .55352 .91514 .55047 .91102 .54496 Mtetra
.657 .756 .923 r
.91102 .54496 .91514 .55047 .92589 .5474 .9218 .54185 Mtetra
.9218 .54185 .92589 .5474 .93668 .54433 .93262 .53873 Mtetra
.657 .755 .922 r
.93262 .53873 .93668 .54433 .94751 .54124 .94347 .53561 Mtetra
.657 .754 .921 r
.94347 .53561 .94751 .54124 .95838 .53814 .95437 .53247 Mtetra
.657 .753 .921 r
.95437 .53247 .95838 .53814 .96929 .53504 .96531 .52932 Mtetra
.657 .753 .92 r
.96531 .52932 .96929 .53504 .98024 .53192 .97628 .52616 Mtetra
.654 .751 .921 r
.38561 .68781 .391 .69252 .39996 .69001 .39458 .6853 Mtetra
.653 .751 .922 r
.39458 .6853 .39996 .69001 .40895 .68749 .40359 .68278 Mtetra
.653 .752 .922 r
.40359 .68278 .40895 .68749 .41797 .68497 .41263 .68026 Mtetra
.653 .753 .923 r
.41263 .68026 .41797 .68497 .42702 .68243 .42169 .67772 Mtetra
.42169 .67772 .42702 .68243 .4361 .67989 .43079 .67518 Mtetra
.653 .754 .924 r
.43079 .67518 .4361 .67989 .44521 .67734 .43992 .67263 Mtetra
.653 .755 .924 r
.43992 .67263 .44521 .67734 .45435 .67478 .44908 .67008 Mtetra
.653 .756 .925 r
.44908 .67008 .45435 .67478 .46352 .67221 .45828 .66751 Mtetra
.653 .756 .926 r
.45828 .66751 .46352 .67221 .47272 .66962 .4675 .66493 Mtetra
.653 .757 .926 r
.4675 .66493 .47272 .66962 .48196 .66702 .47675 .66233 Mtetra
.654 .758 .926 r
.47675 .66233 .48196 .66702 .49122 .66441 .48604 .65971 Mtetra
.654 .759 .926 r
.48604 .65971 .49122 .66441 .50052 .66177 .49536 .65707 Mtetra
.655 .759 .926 r
.49536 .65707 .50052 .66177 .50985 .65912 .50471 .6544 Mtetra
.656 .76 .926 r
.50471 .6544 .50985 .65912 .51922 .65644 .5141 .6517 Mtetra
.5141 .6517 .51922 .65644 .52861 .65375 .52351 .64898 Mtetra
.657 .759 .925 r
.52351 .64898 .52861 .65375 .53804 .65104 .53296 .64624 Mtetra
.658 .759 .925 r
.53296 .64624 .53804 .65104 .54749 .64831 .54244 .64348 Mtetra
.658 .758 .924 r
.54244 .64348 .54749 .64831 .55698 .64557 .55195 .6407 Mtetra
.658 .757 .923 r
.55195 .6407 .55698 .64557 .56651 .64283 .5615 .63791 Mtetra
.658 .756 .923 r
.5615 .63791 .56651 .64283 .57606 .64007 .57107 .63512 Mtetra
.658 .756 .922 r
.57107 .63512 .57606 .64007 .58565 .63731 .58068 .63232 Mtetra
.657 .755 .922 r
.58068 .63232 .58565 .63731 .59527 .63455 .59033 .62953 Mtetra
.657 .754 .921 r
.59033 .62953 .59527 .63455 .60493 .63178 .6 .62673 Mtetra
.657 .753 .921 r
.6 .62673 .60493 .63178 .61461 .62901 .60971 .62392 Mtetra
.60971 .62392 .61461 .62901 .62434 .62623 .61946 .62112 Mtetra
.656 .752 .921 r
.61946 .62112 .62434 .62623 .63409 .62345 .62924 .61832 Mtetra
.62924 .61832 .63409 .62345 .64388 .62066 .63905 .6155 Mtetra
.656 .752 .92 r
.63905 .6155 .64388 .62066 .65371 .61786 .6489 .61269 Mtetra
.6489 .61269 .65371 .61786 .66357 .61506 .65878 .60986 Mtetra
.65878 .60986 .66357 .61506 .67346 .61225 .6687 .60703 Mtetra
.6687 .60703 .67346 .61225 .68339 .60943 .67865 .6042 Mtetra
.656 .752 .921 r
.67865 .6042 .68339 .60943 .69335 .6066 .68864 .60135 Mtetra
.655 .752 .921 r
.68864 .60135 .69335 .6066 .70335 .60376 .69866 .5985 Mtetra
.69866 .5985 .70335 .60376 .71338 .60092 .70872 .59565 Mtetra
.70872 .59565 .71338 .60092 .72345 .59807 .71882 .59279 Mtetra
.654 .752 .921 r
.71882 .59279 .72345 .59807 .73356 .59522 .72895 .58993 Mtetra
.654 .752 .922 r
.72895 .58993 .73356 .59522 .7437 .59236 .73912 .58706 Mtetra
.654 .753 .922 r
.73912 .58706 .7437 .59236 .75388 .5895 .74932 .5842 Mtetra
.653 .753 .923 r
.74932 .5842 .75388 .5895 .7641 .58663 .75957 .58133 Mtetra
.653 .754 .924 r
.75957 .58133 .7641 .58663 .77435 .58376 .76985 .57846 Mtetra
.653 .755 .925 r
.76985 .57846 .77435 .58376 .78464 .58087 .78017 .57558 Mtetra
.653 .756 .925 r
.78017 .57558 .78464 .58087 .79497 .57798 .79052 .5727 Mtetra
.653 .757 .926 r
.79052 .5727 .79497 .57798 .80533 .57508 .80091 .56979 Mtetra
.653 .758 .926 r
.80091 .56979 .80533 .57508 .81574 .57215 .81134 .56686 Mtetra
.654 .758 .927 r
.81134 .56686 .81574 .57215 .82617 .56921 .82181 .56391 Mtetra
.654 .759 .927 r
.82181 .56391 .82617 .56921 .83665 .56625 .83231 .56093 Mtetra
.655 .759 .926 r
.83231 .56093 .83665 .56625 .84716 .56327 .84285 .55793 Mtetra
.656 .759 .926 r
.84285 .55793 .84716 .56327 .85771 .56026 .85343 .55489 Mtetra
.85343 .55489 .85771 .56026 .8683 .55724 .86404 .55183 Mtetra
.657 .759 .925 r
.86404 .55183 .8683 .55724 .87892 .55419 .87469 .54875 Mtetra
.657 .758 .925 r
.87469 .54875 .87892 .55419 .88958 .55113 .88538 .54565 Mtetra
.657 .758 .924 r
.88538 .54565 .88958 .55113 .90028 .54805 .89611 .54253 Mtetra
.658 .757 .923 r
.89611 .54253 .90028 .54805 .91102 .54496 .90688 .53939 Mtetra
.658 .756 .923 r
.90688 .53939 .91102 .54496 .9218 .54185 .91768 .53625 Mtetra
.658 .756 .922 r
.91768 .53625 .9218 .54185 .93262 .53873 .92852 .53309 Mtetra
.658 .755 .922 r
.92852 .53309 .93262 .53873 .94347 .53561 .93941 .52993 Mtetra
.658 .754 .921 r
.93941 .52993 .94347 .53561 .95437 .53247 .95033 .52675 Mtetra
.658 .753 .921 r
.95033 .52675 .95437 .53247 .96531 .52932 .9613 .52357 Mtetra
.658 .753 .92 r
.9613 .52357 .96531 .52932 .97628 .52616 .9723 .52037 Mtetra
.653 .751 .921 r
.38018 .68308 .38561 .68781 .39458 .6853 .38917 .68056 Mtetra
.653 .751 .922 r
.38917 .68056 .39458 .6853 .40359 .68278 .3982 .67804 Mtetra
.653 .752 .922 r
.3982 .67804 .40359 .68278 .41263 .68026 .40725 .67551 Mtetra
.653 .752 .923 r
.40725 .67551 .41263 .68026 .42169 .67772 .41634 .67297 Mtetra
.652 .753 .923 r
.41634 .67297 .42169 .67772 .43079 .67518 .42546 .67043 Mtetra
.652 .753 .924 r
.42546 .67043 .43079 .67518 .43992 .67263 .43461 .66788 Mtetra
.652 .754 .924 r
.43461 .66788 .43992 .67263 .44908 .67008 .44379 .66533 Mtetra
.652 .755 .925 r
.44379 .66533 .44908 .67008 .45828 .66751 .453 .66277 Mtetra
.453 .66277 .45828 .66751 .4675 .66493 .46224 .66019 Mtetra
.652 .756 .926 r
.46224 .66019 .4675 .66493 .47675 .66233 .47152 .65759 Mtetra
.653 .757 .926 r
.47152 .65759 .47675 .66233 .48604 .65971 .48083 .65498 Mtetra
.654 .758 .927 r
.48083 .65498 .48604 .65971 .49536 .65707 .49017 .65233 Mtetra
.655 .759 .927 r
.49017 .65233 .49536 .65707 .50471 .6544 .49954 .64966 Mtetra
.655 .76 .926 r
.49954 .64966 .50471 .6544 .5141 .6517 .50894 .64695 Mtetra
.657 .76 .926 r
.50894 .64695 .5141 .6517 .52351 .64898 .51838 .64421 Mtetra
.51838 .64421 .52351 .64898 .53296 .64624 .52785 .64144 Mtetra
.658 .76 .925 r
.52785 .64144 .53296 .64624 .54244 .64348 .53735 .63864 Mtetra
.659 .759 .924 r
.53735 .63864 .54244 .64348 .55195 .6407 .54689 .63582 Mtetra
.54689 .63582 .55195 .6407 .5615 .63791 .55645 .63299 Mtetra
.659 .758 .923 r
.55645 .63299 .5615 .63791 .57107 .63512 .56605 .63016 Mtetra
.659 .757 .922 r
.56605 .63016 .57107 .63512 .58068 .63232 .57568 .62732 Mtetra
.658 .756 .922 r
.57568 .62732 .58068 .63232 .59033 .62953 .58535 .62448 Mtetra
.658 .755 .921 r
.58535 .62448 .59033 .62953 .6 .62673 .59505 .62165 Mtetra
.657 .754 .921 r
.59505 .62165 .6 .62673 .60971 .62392 .60478 .61882 Mtetra
.657 .753 .921 r
.60478 .61882 .60971 .62392 .61946 .62112 .61455 .61599 Mtetra
.61455 .61599 .61946 .62112 .62924 .61832 .62435 .61315 Mtetra
.656 .752 .921 r
.62435 .61315 .62924 .61832 .63905 .6155 .63419 .61032 Mtetra
.656 .752 .92 r
.63419 .61032 .63905 .6155 .6489 .61269 .64406 .60748 Mtetra
.64406 .60748 .6489 .61269 .65878 .60986 .65397 .60464 Mtetra
.656 .752 .921 r
.65397 .60464 .65878 .60986 .6687 .60703 .66391 .60179 Mtetra
.66391 .60179 .6687 .60703 .67865 .6042 .67388 .59894 Mtetra
.655 .752 .921 r
.67388 .59894 .67865 .6042 .68864 .60135 .6839 .59608 Mtetra
.6839 .59608 .68864 .60135 .69866 .5985 .69394 .59321 Mtetra
.69394 .59321 .69866 .5985 .70872 .59565 .70403 .59035 Mtetra
.654 .752 .921 r
.70403 .59035 .70872 .59565 .71882 .59279 .71415 .58748 Mtetra
.654 .752 .922 r
.71415 .58748 .71882 .59279 .72895 .58993 .72431 .58461 Mtetra
.653 .752 .922 r
.72431 .58461 .72895 .58993 .73912 .58706 .7345 .58175 Mtetra
.653 .753 .923 r
.7345 .58175 .73912 .58706 .74932 .5842 .74473 .57888 Mtetra
.652 .754 .924 r
.74473 .57888 .74932 .5842 .75957 .58133 .755 .57602 Mtetra
.652 .754 .925 r
.755 .57602 .75957 .58133 .76985 .57846 .76531 .57316 Mtetra
.652 .755 .926 r
.76531 .57316 .76985 .57846 .78017 .57558 .77566 .57028 Mtetra
.652 .756 .926 r
.77566 .57028 .78017 .57558 .79052 .5727 .78604 .5674 Mtetra
.652 .757 .927 r
.78604 .5674 .79052 .5727 .80091 .56979 .79647 .56449 Mtetra
.652 .758 .927 r
.79647 .56449 .80091 .56979 .81134 .56686 .80692 .56156 Mtetra
.653 .759 .927 r
.80692 .56156 .81134 .56686 .82181 .56391 .81742 .55859 Mtetra
.654 .76 .927 r
.81742 .55859 .82181 .56391 .83231 .56093 .82795 .55559 Mtetra
.655 .76 .927 r
.82795 .55559 .83231 .56093 .84285 .55793 .83852 .55255 Mtetra
.656 .76 .926 r
.83852 .55255 .84285 .55793 .85343 .55489 .84912 .54948 Mtetra
.657 .759 .925 r
.84912 .54948 .85343 .55489 .86404 .55183 .85976 .54638 Mtetra
.658 .759 .925 r
.85976 .54638 .86404 .55183 .87469 .54875 .87044 .54326 Mtetra
.658 .758 .924 r
.87044 .54326 .87469 .54875 .88538 .54565 .88115 .54011 Mtetra
.658 .757 .923 r
.88115 .54011 .88538 .54565 .89611 .54253 .89191 .53695 Mtetra
.89191 .53695 .89611 .54253 .90688 .53939 .9027 .53377 Mtetra
.658 .756 .922 r
.9027 .53377 .90688 .53939 .91768 .53625 .91353 .53059 Mtetra
.658 .755 .921 r
.91353 .53059 .91768 .53625 .92852 .53309 .9244 .5274 Mtetra
.658 .754 .921 r
.9244 .5274 .92852 .53309 .93941 .52993 .93532 .52419 Mtetra
.93532 .52419 .93941 .52993 .95033 .52675 .94627 .52099 Mtetra
.658 .753 .92 r
.94627 .52099 .95033 .52675 .9613 .52357 .95726 .51777 Mtetra
.95726 .51777 .9613 .52357 .9723 .52037 .96829 .51454 Mtetra
.653 .751 .922 r
.37472 .67831 .38018 .68308 .38917 .68056 .38373 .67578 Mtetra
.38373 .67578 .38917 .68056 .3982 .67804 .39277 .67325 Mtetra
.652 .751 .922 r
.39277 .67325 .3982 .67804 .40725 .67551 .40185 .67071 Mtetra
.40185 .67071 .40725 .67551 .41634 .67297 .41095 .66817 Mtetra
.652 .752 .923 r
.41095 .66817 .41634 .67297 .42546 .67043 .42009 .66562 Mtetra
.42009 .66562 .42546 .67043 .43461 .66788 .42926 .66308 Mtetra
.651 .753 .924 r
.42926 .66308 .43461 .66788 .44379 .66533 .43846 .66053 Mtetra
.43846 .66053 .44379 .66533 .453 .66277 .44769 .65797 Mtetra
.651 .754 .925 r
.44769 .65797 .453 .66277 .46224 .66019 .45695 .6554 Mtetra
.651 .755 .926 r
.45695 .6554 .46224 .66019 .47152 .65759 .46625 .65281 Mtetra
.652 .756 .926 r
.46625 .65281 .47152 .65759 .48083 .65498 .47558 .65021 Mtetra
.653 .758 .927 r
.47558 .65021 .48083 .65498 .49017 .65233 .48494 .64757 Mtetra
.654 .759 .927 r
.48494 .64757 .49017 .65233 .49954 .64966 .49433 .64489 Mtetra
.655 .76 .927 r
.49433 .64489 .49954 .64966 .50894 .64695 .50376 .64218 Mtetra
.656 .761 .927 r
.50376 .64218 .50894 .64695 .51838 .64421 .51322 .63942 Mtetra
.658 .761 .926 r
.51322 .63942 .51838 .64421 .52785 .64144 .52271 .63663 Mtetra
.659 .761 .926 r
.52271 .63663 .52785 .64144 .53735 .63864 .53223 .6338 Mtetra
.659 .761 .925 r
.53223 .6338 .53735 .63864 .54689 .63582 .54179 .63094 Mtetra
.66 .76 .924 r
.54179 .63094 .54689 .63582 .55645 .63299 .55138 .62807 Mtetra
.66 .759 .923 r
.55138 .62807 .55645 .63299 .56605 .63016 .561 .62519 Mtetra
.66 .758 .923 r
.561 .62519 .56605 .63016 .57568 .62732 .57065 .6223 Mtetra
.659 .757 .922 r
.57065 .6223 .57568 .62732 .58535 .62448 .58034 .61942 Mtetra
.659 .755 .922 r
.58034 .61942 .58535 .62448 .59505 .62165 .59006 .61655 Mtetra
.658 .754 .921 r
.59006 .61655 .59505 .62165 .60478 .61882 .59982 .61369 Mtetra
.657 .754 .921 r
.59982 .61369 .60478 .61882 .61455 .61599 .60961 .61082 Mtetra
.657 .753 .921 r
.60961 .61082 .61455 .61599 .62435 .61315 .61943 .60796 Mtetra
.61943 .60796 .62435 .61315 .63419 .61032 .62929 .60511 Mtetra
.656 .752 .921 r
.62929 .60511 .63419 .61032 .64406 .60748 .63919 .60225 Mtetra
.63919 .60225 .64406 .60748 .65397 .60464 .64912 .59938 Mtetra
.64912 .59938 .65397 .60464 .66391 .60179 .65908 .59652 Mtetra
.655 .752 .921 r
.65908 .59652 .66391 .60179 .67388 .59894 .66908 .59364 Mtetra
.66908 .59364 .67388 .59894 .6839 .59608 .67912 .59077 Mtetra
.67912 .59077 .6839 .59608 .69394 .59321 .68919 .58789 Mtetra
.654 .752 .921 r
.68919 .58789 .69394 .59321 .70403 .59035 .6993 .58502 Mtetra
.654 .752 .922 r
.6993 .58502 .70403 .59035 .71415 .58748 .70945 .58214 Mtetra
.653 .752 .922 r
.70945 .58214 .71415 .58748 .72431 .58461 .71963 .57927 Mtetra
.652 .753 .923 r
.71963 .57927 .72431 .58461 .7345 .58175 .72986 .57641 Mtetra
.652 .753 .924 r
.72986 .57641 .7345 .58175 .74473 .57888 .74012 .57355 Mtetra
.651 .754 .925 r
.74012 .57355 .74473 .57888 .755 .57602 .75041 .5707 Mtetra
.651 .755 .926 r
.75041 .5707 .755 .57602 .76531 .57316 .76075 .56784 Mtetra
.65 .756 .927 r
.76075 .56784 .76531 .57316 .77566 .57028 .77113 .56498 Mtetra
.651 .757 .927 r
.77113 .56498 .77566 .57028 .78604 .5674 .78154 .56209 Mtetra
.651 .758 .928 r
.78154 .56209 .78604 .5674 .79647 .56449 .79199 .55918 Mtetra
.652 .759 .928 r
.79199 .55918 .79647 .56449 .80692 .56156 .80248 .55624 Mtetra
.653 .76 .928 r
.80248 .55624 .80692 .56156 .81742 .55859 .813 .55325 Mtetra
.655 .76 .927 r
.813 .55325 .81742 .55859 .82795 .55559 .82356 .55022 Mtetra
.656 .76 .927 r
.82356 .55022 .82795 .55559 .83852 .55255 .83415 .54714 Mtetra
.657 .76 .926 r
.83415 .54714 .83852 .55255 .84912 .54948 .84478 .54403 Mtetra
.658 .76 .925 r
.84478 .54403 .84912 .54948 .85976 .54638 .85545 .54088 Mtetra
.659 .759 .924 r
.85545 .54088 .85976 .54638 .87044 .54326 .86615 .53771 Mtetra
.659 .758 .923 r
.86615 .53771 .87044 .54326 .88115 .54011 .87689 .53451 Mtetra
.659 .757 .922 r
.87689 .53451 .88115 .54011 .89191 .53695 .88767 .53131 Mtetra
.659 .756 .921 r
.88767 .53131 .89191 .53695 .9027 .53377 .89849 .52809 Mtetra
.659 .755 .921 r
.89849 .52809 .9027 .53377 .91353 .53059 .90935 .52487 Mtetra
.659 .754 .921 r
.90935 .52487 .91353 .53059 .9244 .5274 .92025 .52164 Mtetra
.659 .754 .92 r
.92025 .52164 .9244 .5274 .93532 .52419 .93119 .51841 Mtetra
.659 .753 .92 r
.93119 .51841 .93532 .52419 .94627 .52099 .94217 .51517 Mtetra
.658 .753 .92 r
.94217 .51517 .94627 .52099 .95726 .51777 .9532 .51192 Mtetra
.9532 .51192 .95726 .51777 .96829 .51454 .96426 .50866 Mtetra
.653 .751 .921 r
.36922 .67351 .37472 .67831 .38373 .67578 .37825 .67097 Mtetra
.653 .751 .922 r
.37825 .67097 .38373 .67578 .39277 .67325 .38732 .66842 Mtetra
.652 .751 .922 r
.38732 .66842 .39277 .67325 .40185 .67071 .39641 .66587 Mtetra
.39641 .66587 .40185 .67071 .41095 .66817 .40553 .66331 Mtetra
.40553 .66331 .41095 .66817 .42009 .66562 .41469 .66076 Mtetra
.651 .751 .923 r
.41469 .66076 .42009 .66562 .42926 .66308 .42388 .65821 Mtetra
.42388 .65821 .42926 .66308 .43846 .66053 .4331 .65566 Mtetra
.65 .752 .924 r
.4331 .65566 .43846 .66053 .44769 .65797 .44235 .6531 Mtetra
.44235 .6531 .44769 .65797 .45695 .6554 .45163 .65054 Mtetra
.65 .753 .925 r
.45163 .65054 .45695 .6554 .46625 .65281 .46094 .64797 Mtetra
.65 .755 .926 r
.46094 .64797 .46625 .65281 .47558 .65021 .47029 .64538 Mtetra
.651 .756 .927 r
.47029 .64538 .47558 .65021 .48494 .64757 .47967 .64276 Mtetra
.652 .758 .927 r
.47967 .64276 .48494 .64757 .49433 .64489 .48909 .6401 Mtetra
.654 .76 .927 r
.48909 .6401 .49433 .64489 .50376 .64218 .49854 .63739 Mtetra
.656 .761 .927 r
.49854 .63739 .50376 .64218 .51322 .63942 .50802 .63463 Mtetra
.657 .762 .927 r
.50802 .63463 .51322 .63942 .52271 .63663 .51753 .63182 Mtetra
.659 .763 .926 r
.51753 .63182 .52271 .63663 .53223 .6338 .52708 .62896 Mtetra
.66 .763 .926 r
.52708 .62896 .53223 .6338 .54179 .63094 .53666 .62607 Mtetra
.661 .762 .925 r
.53666 .62607 .54179 .63094 .55138 .62807 .54627 .62315 Mtetra
.661 .761 .924 r
.54627 .62315 .55138 .62807 .561 .62519 .55591 .62022 Mtetra
.661 .76 .923 r
.55591 .62022 .561 .62519 .57065 .6223 .56559 .61729 Mtetra
.66 .758 .922 r
.56559 .61729 .57065 .6223 .58034 .61942 .5753 .61436 Mtetra
.66 .757 .922 r
.5753 .61436 .58034 .61942 .59006 .61655 .58505 .61144 Mtetra
.659 .756 .921 r
.58505 .61144 .59006 .61655 .59982 .61369 .59482 .60854 Mtetra
.658 .754 .921 r
.59482 .60854 .59982 .61369 .60961 .61082 .60464 .60564 Mtetra
.657 .754 .921 r
.60464 .60564 .60961 .61082 .61943 .60796 .61448 .60275 Mtetra
.657 .753 .921 r
.61448 .60275 .61943 .60796 .62929 .60511 .62437 .59987 Mtetra
.656 .753 .921 r
.62437 .59987 .62929 .60511 .63919 .60225 .63429 .59698 Mtetra
.656 .752 .921 r
.63429 .59698 .63919 .60225 .64912 .59938 .64424 .5941 Mtetra
.64424 .5941 .64912 .59938 .65908 .59652 .65423 .59121 Mtetra
.655 .752 .921 r
.65423 .59121 .65908 .59652 .66908 .59364 .66425 .58832 Mtetra
.66425 .58832 .66908 .59364 .67912 .59077 .67431 .58543 Mtetra
.654 .752 .921 r
.67431 .58543 .67912 .59077 .68919 .58789 .68441 .58255 Mtetra
.654 .752 .922 r
.68441 .58255 .68919 .58789 .6993 .58502 .69455 .57966 Mtetra
.653 .752 .922 r
.69455 .57966 .6993 .58502 .70945 .58214 .70472 .57679 Mtetra
.652 .753 .923 r
.70472 .57679 .70945 .58214 .71963 .57927 .71493 .57392 Mtetra
.651 .753 .924 r
.71493 .57392 .71963 .57927 .72986 .57641 .72518 .57106 Mtetra
.65 .754 .925 r
.72518 .57106 .72986 .57641 .74012 .57355 .73547 .56822 Mtetra
.649 .755 .926 r
.73547 .56822 .74012 .57355 .75041 .5707 .74579 .56538 Mtetra
.649 .756 .927 r
.74579 .56538 .75041 .5707 .76075 .56784 .75616 .56253 Mtetra
.649 .757 .928 r
.75616 .56253 .76075 .56784 .77113 .56498 .76656 .55968 Mtetra
.649 .758 .929 r
.76656 .55968 .77113 .56498 .78154 .56209 .77701 .55679 Mtetra
.65 .76 .929 r
.77701 .55679 .78154 .56209 .79199 .55918 .78748 .55387 Mtetra
.652 .761 .929 r
.78748 .55387 .79199 .55918 .80248 .55624 .798 .5509 Mtetra
.654 .761 .928 r
.798 .5509 .80248 .55624 .813 .55325 .80855 .54788 Mtetra
.656 .761 .927 r
.80855 .54788 .813 .55325 .82356 .55022 .81913 .5448 Mtetra
.657 .761 .926 r
.81913 .5448 .82356 .55022 .83415 .54714 .82975 .54168 Mtetra
.659 .76 .925 r
.82975 .54168 .83415 .54714 .84478 .54403 .84041 .53851 Mtetra
.659 .759 .924 r
.84041 .53851 .84478 .54403 .85545 .54088 .8511 .53531 Mtetra
.66 .758 .922 r
.8511 .53531 .85545 .54088 .86615 .53771 .86183 .53208 Mtetra
.66 .757 .922 r
.86183 .53208 .86615 .53771 .87689 .53451 .8726 .52884 Mtetra
.66 .756 .921 r
.8726 .52884 .87689 .53451 .88767 .53131 .8834 .52559 Mtetra
.66 .755 .92 r
.8834 .52559 .88767 .53131 .89849 .52809 .89425 .52233 Mtetra
.66 .754 .92 r
.89425 .52233 .89849 .52809 .90935 .52487 .90514 .51908 Mtetra
.659 .753 .92 r
.90514 .51908 .90935 .52487 .92025 .52164 .91607 .51582 Mtetra
.659 .753 .919 r
.91607 .51582 .92025 .52164 .93119 .51841 .92704 .51256 Mtetra
.92704 .51256 .93119 .51841 .94217 .51517 .93805 .5093 Mtetra
.658 .753 .919 r
.93805 .5093 .94217 .51517 .9532 .51192 .9491 .50603 Mtetra
.658 .752 .92 r
.9491 .50603 .9532 .51192 .96426 .50866 .9602 .50275 Mtetra
.653 .751 .921 r
.36369 .66869 .36922 .67351 .37825 .67097 .37274 .66612 Mtetra
.653 .75 .921 r
.37274 .66612 .37825 .67097 .38732 .66842 .38183 .66354 Mtetra
.38183 .66354 .38732 .66842 .39641 .66587 .39094 .66097 Mtetra
.652 .75 .921 r
.39094 .66097 .39641 .66587 .40553 .66331 .40008 .65839 Mtetra
.652 .749 .921 r
.40008 .65839 .40553 .66331 .41469 .66076 .40926 .65583 Mtetra
.651 .749 .921 r
.40926 .65583 .41469 .66076 .42388 .65821 .41846 .65326 Mtetra
.65 .749 .922 r
.41846 .65326 .42388 .65821 .4331 .65566 .4277 .65071 Mtetra
.65 .75 .923 r
.4277 .65071 .4331 .65566 .44235 .6531 .43697 .64816 Mtetra
.649 .75 .923 r
.43697 .64816 .44235 .6531 .45163 .65054 .44627 .64561 Mtetra
.649 .751 .924 r
.44627 .64561 .45163 .65054 .46094 .64797 .45561 .64306 Mtetra
.649 .753 .925 r
.45561 .64306 .46094 .64797 .47029 .64538 .46498 .64049 Mtetra
.649 .755 .926 r
.46498 .64049 .47029 .64538 .47967 .64276 .47438 .6379 Mtetra
.65 .757 .927 r
.47438 .6379 .47967 .64276 .48909 .6401 .48381 .63527 Mtetra
.652 .759 .928 r
.48381 .63527 .48909 .6401 .49854 .63739 .49328 .63258 Mtetra
.654 .761 .928 r
.49328 .63258 .49854 .63739 .50802 .63463 .50278 .62983 Mtetra
.657 .763 .928 r
.50278 .62983 .50802 .63463 .51753 .63182 .51232 .62702 Mtetra
.659 .764 .928 r
.51232 .62702 .51753 .63182 .52708 .62896 .52189 .62414 Mtetra
.661 .765 .927 r
.52189 .62414 .52708 .62896 .53666 .62607 .53149 .62122 Mtetra
.662 .764 .926 r
.53149 .62122 .53666 .62607 .54627 .62315 .54113 .61825 Mtetra
.662 .763 .925 r
.54113 .61825 .54627 .62315 .55591 .62022 .55079 .61527 Mtetra
.662 .762 .924 r
.55079 .61527 .55591 .62022 .56559 .61729 .56049 .61228 Mtetra
.662 .76 .923 r
.56049 .61228 .56559 .61729 .5753 .61436 .57023 .60929 Mtetra
.661 .759 .922 r
.57023 .60929 .5753 .61436 .58505 .61144 .57999 .60633 Mtetra
.66 .757 .922 r
.57999 .60633 .58505 .61144 .59482 .60854 .5898 .60337 Mtetra
.659 .756 .921 r
.5898 .60337 .59482 .60854 .60464 .60564 .59963 .60044 Mtetra
.658 .754 .921 r
.59963 .60044 .60464 .60564 .61448 .60275 .6095 .59751 Mtetra
.657 .754 .921 r
.6095 .59751 .61448 .60275 .62437 .59987 .61941 .5946 Mtetra
.657 .753 .921 r
.61941 .5946 .62437 .59987 .63429 .59698 .62935 .59169 Mtetra
.656 .753 .921 r
.62935 .59169 .63429 .59698 .64424 .5941 .63933 .58878 Mtetra
.656 .752 .921 r
.63933 .58878 .64424 .5941 .65423 .59121 .64934 .58588 Mtetra
.655 .752 .921 r
.64934 .58588 .65423 .59121 .66425 .58832 .65939 .58297 Mtetra
.65939 .58297 .66425 .58832 .67431 .58543 .66948 .58007 Mtetra
.654 .752 .922 r
.66948 .58007 .67431 .58543 .68441 .58255 .6796 .57718 Mtetra
.653 .752 .922 r
.6796 .57718 .68441 .58255 .69455 .57966 .68976 .57429 Mtetra
.652 .752 .923 r
.68976 .57429 .69455 .57966 .70472 .57679 .69996 .57141 Mtetra
.651 .753 .924 r
.69996 .57141 .70472 .57679 .71493 .57392 .7102 .56856 Mtetra
.65 .754 .925 r
.7102 .56856 .71493 .57392 .72518 .57106 .72047 .56571 Mtetra
.649 .754 .927 r
.72047 .56571 .72518 .57106 .73547 .56822 .73079 .56289 Mtetra
.648 .756 .928 r
.73079 .56289 .73547 .56822 .74579 .56538 .74115 .56007 Mtetra
.647 .757 .929 r
.74115 .56007 .74579 .56538 .75616 .56253 .75154 .55724 Mtetra
.647 .759 .93 r
.75154 .55724 .75616 .56253 .76656 .55968 .76198 .55439 Mtetra
.649 .76 .931 r
.76198 .55439 .76656 .55968 .77701 .55679 .77245 .55151 Mtetra
.65 .761 .931 r
.77245 .55151 .77701 .55679 .78748 .55387 .78295 .54857 Mtetra
.652 .762 .93 r
.78295 .54857 .78748 .55387 .798 .5509 .79349 .54556 Mtetra
.655 .763 .929 r
.79349 .54556 .798 .5509 .80855 .54788 .80407 .54249 Mtetra
.657 .762 .927 r
.80407 .54249 .80855 .54788 .81913 .5448 .81468 .53935 Mtetra
.659 .761 .925 r
.81468 .53935 .81913 .5448 .82975 .54168 .82532 .53616 Mtetra
.66 .76 .924 r
.82532 .53616 .82975 .54168 .84041 .53851 .836 .53292 Mtetra
.661 .758 .922 r
.836 .53292 .84041 .53851 .8511 .53531 .84672 .52965 Mtetra
.662 .757 .921 r
.84672 .52965 .8511 .53531 .86183 .53208 .85747 .52636 Mtetra
.662 .755 .92 r
.85747 .52636 .86183 .53208 .8726 .52884 .86827 .52307 Mtetra
.661 .754 .919 r
.86827 .52307 .8726 .52884 .8834 .52559 .8791 .51978 Mtetra
.661 .753 .919 r
.8791 .51978 .8834 .52559 .89425 .52233 .88997 .51649 Mtetra
.66 .752 .918 r
.88997 .51649 .89425 .52233 .90514 .51908 .90089 .51321 Mtetra
.659 .752 .918 r
.90089 .51321 .90514 .51908 .91607 .51582 .91185 .50993 Mtetra
.659 .752 .919 r
.91185 .50993 .91607 .51582 .92704 .51256 .92285 .50665 Mtetra
.92285 .50665 .92704 .51256 .93805 .5093 .93389 .50337 Mtetra
.658 .752 .919 r
.93389 .50337 .93805 .5093 .9491 .50603 .94498 .50009 Mtetra
.94498 .50009 .9491 .50603 .9602 .50275 .9561 .4968 Mtetra
.654 .751 .921 r
.35813 .66383 .36369 .66869 .37274 .66612 .3672 .66123 Mtetra
.654 .75 .921 r
.3672 .66123 .37274 .66612 .38183 .66354 .3763 .65863 Mtetra
.653 .75 .92 r
.3763 .65863 .38183 .66354 .39094 .66097 .38543 .65602 Mtetra
.653 .749 .92 r
.38543 .65602 .39094 .66097 .40008 .65839 .3946 .65342 Mtetra
.652 .748 .92 r
.3946 .65342 .40008 .65839 .40926 .65583 .40379 .65082 Mtetra
.651 .748 .92 r
.40379 .65082 .40926 .65583 .41846 .65326 .41302 .64824 Mtetra
.65 .747 .921 r
.41302 .64824 .41846 .65326 .4277 .65071 .42227 .64567 Mtetra
.649 .747 .921 r
.42227 .64567 .4277 .65071 .43697 .64816 .43156 .64312 Mtetra
.648 .747 .922 r
.43156 .64312 .43697 .64816 .44627 .64561 .44088 .64058 Mtetra
.647 .748 .923 r
.44088 .64058 .44627 .64561 .45561 .64306 .45024 .63804 Mtetra
.647 .749 .924 r
.45024 .63804 .45561 .64306 .46498 .64049 .45963 .63551 Mtetra
.647 .751 .925 r
.45963 .63551 .46498 .64049 .47438 .6379 .46905 .63296 Mtetra
.648 .754 .927 r
.46905 .63296 .47438 .6379 .48381 .63527 .4785 .63037 Mtetra
.65 .757 .928 r
.4785 .63037 .48381 .63527 .49328 .63258 .48799 .62773 Mtetra
.652 .76 .929 r
.48799 .62773 .49328 .63258 .50278 .62983 .49752 .62501 Mtetra
.655 .763 .929 r
.49752 .62501 .50278 .62983 .51232 .62702 .50708 .62222 Mtetra
.658 .765 .929 r
.50708 .62222 .51232 .62702 .52189 .62414 .51667 .61934 Mtetra
.661 .767 .928 r
.51667 .61934 .52189 .62414 .53149 .62122 .52629 .61639 Mtetra
.663 .767 .927 r
.52629 .61639 .53149 .62122 .54113 .61825 .53595 .61338 Mtetra
.664 .766 .926 r
.53595 .61338 .54113 .61825 .55079 .61527 .54564 .61034 Mtetra
.664 .765 .925 r
.54564 .61034 .55079 .61527 .56049 .61228 .55536 .60729 Mtetra
.664 .763 .924 r
.55536 .60729 .56049 .61228 .57023 .60929 .56512 .60424 Mtetra
.662 .761 .923 r
.56512 .60424 .57023 .60929 .57999 .60633 .57491 .60121 Mtetra
.661 .759 .922 r
.57491 .60121 .57999 .60633 .5898 .60337 .58474 .59821 Mtetra
.66 .757 .922 r
.58474 .59821 .5898 .60337 .59963 .60044 .59459 .59522 Mtetra
.659 .756 .922 r
.59459 .59522 .59963 .60044 .6095 .59751 .60449 .59226 Mtetra
.658 .754 .921 r
.60449 .59226 .6095 .59751 .61941 .5946 .61442 .58931 Mtetra
.657 .754 .921 r
.61442 .58931 .61941 .5946 .62935 .59169 .62438 .58638 Mtetra
.656 .753 .921 r
.62438 .58638 .62935 .59169 .63933 .58878 .63439 .58345 Mtetra
.63439 .58345 .63933 .58878 .64934 .58588 .64442 .58052 Mtetra
.655 .752 .922 r
.64442 .58052 .64934 .58588 .65939 .58297 .6545 .5776 Mtetra
.654 .752 .922 r
.6545 .5776 .65939 .58297 .66948 .58007 .66461 .57469 Mtetra
.653 .752 .922 r
.66461 .57469 .66948 .58007 .6796 .57718 .67476 .57179 Mtetra
.652 .753 .923 r
.67476 .57179 .6796 .57718 .68976 .57429 .68494 .5689 Mtetra
.651 .753 .924 r
.68494 .5689 .68976 .57429 .69996 .57141 .69517 .56604 Mtetra
.649 .754 .926 r
.69517 .56604 .69996 .57141 .7102 .56856 .70544 .5632 Mtetra
.648 .754 .927 r
.70544 .5632 .7102 .56856 .72047 .56571 .71574 .56038 Mtetra
.646 .756 .929 r
.71574 .56038 .72047 .56571 .73079 .56289 .72609 .55758 Mtetra
.645 .757 .93 r
.72609 .55758 .73079 .56289 .74115 .56007 .73647 .55478 Mtetra
.645 .759 .932 r
.73647 .55478 .74115 .56007 .75154 .55724 .7469 .55197 Mtetra
.646 .761 .932 r
.7469 .55197 .75154 .55724 .76198 .55439 .75736 .54913 Mtetra
.648 .762 .932 r
.75736 .54913 .76198 .55439 .77245 .55151 .76786 .54623 Mtetra
.651 .763 .932 r
.76786 .54623 .77245 .55151 .78295 .54857 .77839 .54325 Mtetra
.654 .764 .93 r
.77839 .54325 .78295 .54857 .79349 .54556 .78896 .54019 Mtetra
.657 .764 .928 r
.78896 .54019 .79349 .54556 .80407 .54249 .79956 .53704 Mtetra
.66 .763 .926 r
.79956 .53704 .80407 .54249 .81468 .53935 .81019 .53382 Mtetra
.662 .761 .924 r
.81019 .53382 .81468 .53935 .82532 .53616 .82086 .53054 Mtetra
.663 .759 .921 r
.82086 .53054 .82532 .53616 .836 .53292 .83156 .52723 Mtetra
.663 .757 .92 r
.83156 .52723 .836 .53292 .84672 .52965 .8423 .52388 Mtetra
.663 .755 .918 r
.8423 .52388 .84672 .52965 .85747 .52636 .85308 .52054 Mtetra
.663 .753 .917 r
.85308 .52054 .85747 .52636 .86827 .52307 .8639 .5172 Mtetra
.662 .752 .917 r
.8639 .5172 .86827 .52307 .8791 .51978 .87476 .51387 Mtetra
.661 .751 .917 r
.87476 .51387 .8791 .51978 .88997 .51649 .88566 .51056 Mtetra
.66 .751 .917 r
.88566 .51056 .88997 .51649 .90089 .51321 .89661 .50726 Mtetra
.659 .75 .917 r
.89661 .50726 .90089 .51321 .91185 .50993 .9076 .50397 Mtetra
.659 .75 .918 r
.9076 .50397 .91185 .50993 .92285 .50665 .91863 .50068 Mtetra
.658 .751 .918 r
.91863 .50068 .92285 .50665 .93389 .50337 .92971 .49739 Mtetra
.658 .751 .919 r
.92971 .49739 .93389 .50337 .94498 .50009 .94083 .4941 Mtetra
.658 .752 .919 r
.94083 .4941 .94498 .50009 .9561 .4968 .95198 .4908 Mtetra
.655 .751 .921 r
.35253 .65894 .35813 .66383 .3672 .66123 .36162 .65631 Mtetra
.655 .75 .92 r
.36162 .65631 .3672 .66123 .3763 .65863 .37074 .65367 Mtetra
.654 .749 .92 r
.37074 .65367 .3763 .65863 .38543 .65602 .37989 .65102 Mtetra
.654 .749 .919 r
.37989 .65102 .38543 .65602 .3946 .65342 .38908 .64838 Mtetra
.653 .748 .919 r
.38908 .64838 .3946 .65342 .40379 .65082 .39829 .64575 Mtetra
.652 .747 .919 r
.39829 .64575 .40379 .65082 .41302 .64824 .40754 .64314 Mtetra
.651 .746 .919 r
.40754 .64314 .41302 .64824 .42227 .64567 .41681 .64054 Mtetra
.649 .745 .919 r
.41681 .64054 .42227 .64567 .43156 .64312 .42612 .63797 Mtetra
.648 .744 .92 r
.42612 .63797 .43156 .64312 .44088 .64058 .43546 .63543 Mtetra
.646 .745 .921 r
.43546 .63543 .44088 .64058 .45024 .63804 .44484 .63291 Mtetra
.645 .746 .922 r
.44484 .63291 .45024 .63804 .45963 .63551 .45424 .63041 Mtetra
.644 .747 .924 r
.45424 .63041 .45963 .63551 .46905 .63296 .46368 .62791 Mtetra
.645 .75 .926 r
.46368 .62791 .46905 .63296 .4785 .63037 .47316 .62538 Mtetra
.646 .754 .928 r
.47316 .62538 .4785 .63037 .48799 .62773 .48267 .62281 Mtetra
.649 .758 .929 r
.48267 .62281 .48799 .62773 .49752 .62501 .49222 .62015 Mtetra
.652 .762 .93 r
.49222 .62015 .49752 .62501 .50708 .62222 .5018 .61741 Mtetra
.656 .766 .93 r
.5018 .61741 .50708 .62222 .51667 .61934 .51141 .61455 Mtetra
.66 .768 .93 r
.51141 .61455 .51667 .61934 .52629 .61639 .52106 .61159 Mtetra
.663 .77 .929 r
.52106 .61159 .52629 .61639 .53595 .61338 .53074 .60855 Mtetra
.665 .77 .928 r
.53074 .60855 .53595 .61338 .54564 .61034 .54045 .60546 Mtetra
.666 .768 .926 r
.54045 .60546 .54564 .61034 .55536 .60729 .5502 .60234 Mtetra
.666 .766 .925 r
.5502 .60234 .55536 .60729 .56512 .60424 .55998 .59922 Mtetra
.664 .764 .924 r
.55998 .59922 .56512 .60424 .57491 .60121 .56979 .59612 Mtetra
.663 .761 .923 r
.56979 .59612 .57491 .60121 .58474 .59821 .57964 .59305 Mtetra
.661 .759 .922 r
.57964 .59305 .58474 .59821 .59459 .59522 .58952 .59001 Mtetra
.66 .757 .922 r
.58952 .59001 .59459 .59522 .60449 .59226 .59944 .587 Mtetra
.659 .756 .922 r
.59944 .587 .60449 .59226 .61442 .58931 .6094 .58401 Mtetra
.657 .755 .922 r
.6094 .58401 .61442 .58931 .62438 .58638 .61938 .58104 Mtetra
.656 .754 .922 r
.61938 .58104 .62438 .58638 .63439 .58345 .62941 .57809 Mtetra
.656 .753 .922 r
.62941 .57809 .63439 .58345 .64442 .58052 .63947 .57514 Mtetra
.655 .753 .922 r
.63947 .57514 .64442 .58052 .6545 .5776 .64957 .57221 Mtetra
.654 .753 .923 r
.64957 .57221 .6545 .5776 .66461 .57469 .65971 .56929 Mtetra
.653 .753 .923 r
.65971 .56929 .66461 .57469 .67476 .57179 .66988 .56639 Mtetra
.651 .753 .924 r
.66988 .56639 .67476 .57179 .68494 .5689 .6801 .56351 Mtetra
.649 .754 .926 r
.6801 .56351 .68494 .5689 .69517 .56604 .69035 .56066 Mtetra
.647 .754 .927 r
.69035 .56066 .69517 .56604 .70544 .5632 .70064 .55785 Mtetra
.645 .756 .929 r
.70064 .55785 .70544 .5632 .71574 .56038 .71098 .55506 Mtetra
.644 .757 .931 r
.71098 .55506 .71574 .56038 .72609 .55758 .72135 .5523 Mtetra
.643 .759 .933 r
.72135 .5523 .72609 .55758 .73647 .55478 .73177 .54953 Mtetra
.643 .761 .934 r
.73177 .54953 .73647 .55478 .7469 .55197 .74222 .54674 Mtetra
.645 .763 .935 r
.74222 .54674 .7469 .55197 .75736 .54913 .75271 .54389 Mtetra
.648 .765 .934 r
.75271 .54389 .75736 .54913 .76786 .54623 .76324 .54096 Mtetra
.652 .766 .933 r
.76324 .54096 .76786 .54623 .77839 .54325 .7738 .53793 Mtetra
.656 .766 .93 r
.7738 .53793 .77839 .54325 .78896 .54019 .78439 .53478 Mtetra
.66 .765 .927 r
.78439 .53478 .78896 .54019 .79956 .53704 .79501 .53153 Mtetra
.663 .763 .924 r
.79501 .53153 .79956 .53704 .81019 .53382 .80566 .5282 Mtetra
.665 .76 .921 r
.80566 .5282 .81019 .53382 .82086 .53054 .81635 .52482 Mtetra
.666 .757 .918 r
.81635 .52482 .82086 .53054 .83156 .52723 .82708 .52141 Mtetra
.666 .754 .916 r
.82708 .52141 .83156 .52723 .8423 .52388 .83784 .51799 Mtetra
.665 .752 .915 r
.83784 .51799 .8423 .52388 .85308 .52054 .84865 .51459 Mtetra
.663 .75 .915 r
.84865 .51459 .85308 .52054 .8639 .5172 .85949 .51121 Mtetra
.662 .749 .915 r
.85949 .51121 .8639 .5172 .87476 .51387 .87039 .50786 Mtetra
.661 .749 .915 r
.87039 .50786 .87476 .51387 .88566 .51056 .88132 .50454 Mtetra
.66 .748 .916 r
.88132 .50454 .88566 .51056 .89661 .50726 .8923 .50123 Mtetra
.659 .749 .917 r
.8923 .50123 .89661 .50726 .9076 .50397 .90332 .49793 Mtetra
.658 .749 .917 r
.90332 .49793 .9076 .50397 .91863 .50068 .91438 .49464 Mtetra
.657 .75 .918 r
.91438 .49464 .91863 .50068 .92971 .49739 .92549 .49136 Mtetra
.657 .75 .919 r
.92549 .49136 .92971 .49739 .94083 .4941 .93664 .48806 Mtetra
.657 .751 .919 r
.93664 .48806 .94083 .4941 .95198 .4908 .94784 .48476 Mtetra
.656 .751 .92 r
.34689 .65403 .35253 .65894 .36162 .65631 .356 .65135 Mtetra
.356 .65135 .36162 .65631 .37074 .65367 .36515 .64867 Mtetra
.655 .75 .919 r
.36515 .64867 .37074 .65367 .37989 .65102 .37432 .64599 Mtetra
.655 .749 .919 r
.37432 .64599 .37989 .65102 .38908 .64838 .38352 .64331 Mtetra
.654 .747 .918 r
.38352 .64331 .38908 .64838 .39829 .64575 .39276 .64063 Mtetra
.653 .746 .918 r
.39276 .64063 .39829 .64575 .40754 .64314 .40202 .63797 Mtetra
.652 .745 .918 r
.40202 .63797 .40754 .64314 .41681 .64054 .41132 .63533 Mtetra
.65 .743 .918 r
.41132 .63533 .41681 .64054 .42612 .63797 .42065 .63273 Mtetra
.648 .742 .918 r
.42065 .63273 .42612 .63797 .43546 .63543 .43001 .63017 Mtetra
.646 .741 .919 r
.43001 .63017 .43546 .63543 .44484 .63291 .4394 .62765 Mtetra
.644 .741 .92 r
.4394 .62765 .44484 .63291 .45424 .63041 .44883 .62517 Mtetra
.642 .742 .922 r
.44883 .62517 .45424 .63041 .46368 .62791 .45829 .62272 Mtetra
.641 .745 .924 r
.45829 .62272 .46368 .62791 .47316 .62538 .46778 .62027 Mtetra
.642 .749 .926 r
.46778 .62027 .47316 .62538 .48267 .62281 .47731 .61778 Mtetra
.644 .753 .929 r
.47731 .61778 .48267 .62281 .49222 .62015 .48688 .61522 Mtetra
.648 .759 .93 r
.48688 .61522 .49222 .62015 .5018 .61741 .49648 .61255 Mtetra
.653 .764 .931 r
.49648 .61255 .5018 .61741 .51141 .61455 .50612 .60975 Mtetra
.658 .769 .931 r
.50612 .60975 .51141 .61455 .52106 .61159 .51579 .60682 Mtetra
.663 .772 .931 r
.51579 .60682 .52106 .61159 .53074 .60855 .52549 .60376 Mtetra
.666 .773 .929 r
.52549 .60376 .53074 .60855 .54045 .60546 .53523 .60063 Mtetra
.668 .772 .928 r
.53523 .60063 .54045 .60546 .5502 .60234 .545 .59744 Mtetra
.668 .77 .927 r
.545 .59744 .5502 .60234 .55998 .59922 .55481 .59424 Mtetra
.667 .768 .925 r
.55481 .59424 .55998 .59922 .56979 .59612 .56464 .59106 Mtetra
.665 .765 .924 r
.56464 .59106 .56979 .59612 .57964 .59305 .57452 .58791 Mtetra
.663 .762 .923 r
.57452 .58791 .57964 .59305 .58952 .59001 .58442 .58481 Mtetra
.661 .759 .923 r
.58442 .58481 .58952 .59001 .59944 .587 .59436 .58174 Mtetra
.659 .758 .923 r
.59436 .58174 .59944 .587 .6094 .58401 .60434 .57871 Mtetra
.658 .756 .922 r
.60434 .57871 .6094 .58401 .61938 .58104 .61435 .57571 Mtetra
.657 .755 .922 r
.61435 .57571 .61938 .58104 .62941 .57809 .6244 .57272 Mtetra
.656 .754 .923 r
.6244 .57272 .62941 .57809 .63947 .57514 .63449 .56976 Mtetra
.654 .754 .923 r
.63449 .56976 .63947 .57514 .64957 .57221 .64461 .56682 Mtetra
.653 .754 .924 r
.64461 .56682 .64957 .57221 .65971 .56929 .65478 .56389 Mtetra
.651 .754 .925 r
.65478 .56389 .65971 .56929 .66988 .56639 .66498 .561 Mtetra
.649 .754 .926 r
.66498 .561 .66988 .56639 .6801 .56351 .67522 .55814 Mtetra
.647 .755 .928 r
.67522 .55814 .6801 .56351 .69035 .56066 .6855 .55532 Mtetra
.644 .756 .93 r
.6855 .55532 .69035 .56066 .70064 .55785 .69582 .55254 Mtetra
.642 .757 .932 r
.69582 .55254 .70064 .55785 .71098 .55506 .70619 .54979 Mtetra
.641 .759 .935 r
.70619 .54979 .71098 .55506 .72135 .5523 .71659 .54707 Mtetra
.64 .762 .936 r
.71659 .54707 .72135 .5523 .73177 .54953 .72704 .54434 Mtetra
.642 .764 .937 r
.72704 .54434 .73177 .54953 .74222 .54674 .73752 .54155 Mtetra
.644 .766 .937 r
.73752 .54155 .74222 .54674 .75271 .54389 .74804 .53868 Mtetra
.65 .768 .935 r
.74804 .53868 .75271 .54389 .76324 .54096 .75859 .53568 Mtetra
.655 .768 .933 r
.75859 .53568 .76324 .54096 .7738 .53793 .76917 .53255 Mtetra
.66 .767 .929 r
.76917 .53255 .7738 .53793 .78439 .53478 .77978 .52928 Mtetra
.665 .765 .924 r
.77978 .52928 .78439 .53478 .79501 .53153 .79043 .5259 Mtetra
.668 .761 .92 r
.79043 .5259 .79501 .53153 .80566 .5282 .8011 .52244 Mtetra
.669 .757 .917 r
.8011 .52244 .80566 .5282 .81635 .52482 .81181 .51894 Mtetra
.668 .754 .914 r
.81181 .51894 .81635 .52482 .82708 .52141 .82256 .51544 Mtetra
.667 .751 .913 r
.82256 .51544 .82708 .52141 .83784 .51799 .83334 .51195 Mtetra
.665 .748 .912 r
.83334 .51195 .83784 .51799 .84865 .51459 .84418 .50852 Mtetra
.663 .747 .912 r
.84418 .50852 .84865 .51459 .85949 .51121 .85505 .50512 Mtetra
.662 .746 .913 r
.85505 .50512 .85949 .51121 .87039 .50786 .86598 .50176 Mtetra
.66 .746 .914 r
.86598 .50176 .87039 .50786 .88132 .50454 .87694 .49844 Mtetra
.659 .747 .915 r
.87694 .49844 .88132 .50454 .8923 .50123 .88795 .49513 Mtetra
.658 .747 .916 r
.88795 .49513 .8923 .50123 .90332 .49793 .89901 .49185 Mtetra
.657 .748 .917 r
.89901 .49185 .90332 .49793 .91438 .49464 .91011 .48856 Mtetra
.656 .749 .918 r
.91011 .48856 .91438 .49464 .92549 .49136 .92125 .48528 Mtetra
.656 .75 .919 r
.92125 .48528 .92549 .49136 .93664 .48806 .93243 .48198 Mtetra
.656 .751 .92 r
.93243 .48198 .93664 .48806 .94784 .48476 .94366 .47868 Mtetra
.656 .752 .92 r
.34122 .64908 .34689 .65403 .356 .65135 .35035 .64637 Mtetra
.657 .751 .919 r
.35035 .64637 .356 .65135 .36515 .64867 .35951 .64365 Mtetra
.656 .75 .919 r
.35951 .64365 .36515 .64867 .37432 .64599 .36871 .64093 Mtetra
.656 .749 .918 r
.36871 .64093 .37432 .64599 .38352 .64331 .37793 .6382 Mtetra
.656 .748 .918 r
.37793 .6382 .38352 .64331 .39276 .64063 .38719 .63547 Mtetra
.655 .746 .917 r
.38719 .63547 .39276 .64063 .40202 .63797 .39648 .63275 Mtetra
.654 .744 .916 r
.39648 .63275 .40202 .63797 .41132 .63533 .40579 .63005 Mtetra
.652 .742 .916 r
.40579 .63005 .41132 .63533 .42065 .63273 .41514 .62739 Mtetra
.65 .74 .916 r
.41514 .62739 .42065 .63273 .43001 .63017 .42452 .62478 Mtetra
.647 .738 .916 r
.42452 .62478 .43001 .63017 .4394 .62765 .43394 .62223 Mtetra
.643 .737 .917 r
.43394 .62223 .4394 .62765 .44883 .62517 .44338 .61976 Mtetra
.64 .737 .919 r
.44338 .61976 .44883 .62517 .45829 .62272 .45286 .61735 Mtetra
.637 .738 .921 r
.45286 .61735 .45829 .62272 .46778 .62027 .46237 .61498 Mtetra
.637 .742 .924 r
.46237 .61498 .46778 .62027 .47731 .61778 .47192 .6126 Mtetra
.638 .747 .927 r
.47192 .6126 .47731 .61778 .48688 .61522 .48151 .61018 Mtetra
.642 .754 .93 r
.48151 .61018 .48688 .61522 .49648 .61255 .49113 .60764 Mtetra
.648 .762 .932 r
.49113 .60764 .49648 .61255 .50612 .60975 .50079 .60494 Mtetra
.654 .768 .933 r
.50079 .60494 .50612 .60975 .51579 .60682 .51048 .60207 Mtetra
.661 .774 .933 r
.51048 .60207 .51579 .60682 .52549 .60376 .52021 .59903 Mtetra
.666 .776 .932 r
.52021 .59903 .52549 .60376 .53523 .60063 .52998 .59586 Mtetra
.669 .777 .93 r
.52998 .59586 .53523 .60063 .545 .59744 .53977 .59261 Mtetra
.67 .775 .929 r
.53977 .59261 .545 .59744 .55481 .59424 .5496 .58933 Mtetra
.669 .772 .927 r
.5496 .58933 .55481 .59424 .56464 .59106 .55946 .58605 Mtetra
.668 .769 .926 r
.55946 .58605 .56464 .59106 .57452 .58791 .56936 .58282 Mtetra
.665 .766 .925 r
.56936 .58282 .57452 .58791 .58442 .58481 .57929 .57963 Mtetra
.663 .762 .924 r
.57929 .57963 .58442 .58481 .59436 .58174 .58925 .5765 Mtetra
.661 .76 .924 r
.58925 .5765 .59436 .58174 .60434 .57871 .59925 .57342 Mtetra
.659 .758 .923 r
.59925 .57342 .60434 .57871 .61435 .57571 .60929 .57037 Mtetra
.657 .757 .923 r
.60929 .57037 .61435 .57571 .6244 .57272 .61936 .56736 Mtetra
.655 .756 .924 r
.61936 .56736 .6244 .57272 .63449 .56976 .62947 .56438 Mtetra
.654 .755 .924 r
.62947 .56438 .63449 .56976 .64461 .56682 .63962 .56142 Mtetra
.652 .755 .925 r
.63962 .56142 .64461 .56682 .65478 .56389 .64981 .5585 Mtetra
.65 .755 .926 r
.64981 .5585 .65478 .56389 .66498 .561 .66004 .55562 Mtetra
.647 .755 .928 r
.66004 .55562 .66498 .561 .67522 .55814 .67031 .55279 Mtetra
.644 .756 .931 r
.67031 .55279 .67522 .55814 .6855 .55532 .68062 .55001 Mtetra
.641 .758 .933 r
.68062 .55001 .6855 .55532 .69582 .55254 .69097 .54728 Mtetra
.638 .76 .936 r
.69097 .54728 .69582 .55254 .70619 .54979 .70137 .54459 Mtetra
.637 .762 .938 r
.70137 .54459 .70619 .54979 .71659 .54707 .7118 .54192 Mtetra
.637 .765 .94 r
.7118 .54192 .71659 .54707 .72704 .54434 .72228 .53921 Mtetra
.64 .768 .94 r
.72228 .53921 .72704 .54434 .73752 .54155 .73279 .53641 Mtetra
.645 .77 .939 r
.73279 .53641 .73752 .54155 .74804 .53868 .74334 .53349 Mtetra
.653 .771 .936 r
.74334 .53349 .74804 .53868 .75859 .53568 .75391 .53039 Mtetra
.66 .77 .931 r
.75391 .53039 .75859 .53568 .76917 .53255 .76451 .52711 Mtetra
.666 .768 .926 r
.76451 .52711 .76917 .53255 .77978 .52928 .77514 .52367 Mtetra
.671 .764 .92 r
.77514 .52367 .77978 .52928 .79043 .5259 .7858 .52011 Mtetra
.673 .758 .915 r
.7858 .52011 .79043 .5259 .8011 .52244 .79649 .51649 Mtetra
.673 .754 .912 r
.79649 .51649 .8011 .52244 .81181 .51894 .80722 .51287 Mtetra
.671 .749 .909 r
.80722 .51287 .81181 .51894 .82256 .51544 .81799 .50928 Mtetra
.668 .746 .909 r
.81799 .50928 .82256 .51544 .83334 .51195 .82881 .50576 Mtetra
.665 .744 .909 r
.82881 .50576 .83334 .51195 .84418 .50852 .83967 .50231 Mtetra
.662 .743 .91 r
.83967 .50231 .84418 .50852 .85505 .50512 .85058 .49891 Mtetra
.66 .743 .912 r
.85058 .49891 .85505 .50512 .86598 .50176 .86153 .49558 Mtetra
.658 .744 .913 r
.86153 .49558 .86598 .50176 .87694 .49844 .87253 .49227 Mtetra
.657 .745 .915 r
.87253 .49227 .87694 .49844 .88795 .49513 .88358 .48899 Mtetra
.656 .747 .916 r
.88358 .48899 .88795 .49513 .89901 .49185 .89466 .48572 Mtetra
.656 .748 .918 r
.89466 .48572 .89901 .49185 .91011 .48856 .9058 .48244 Mtetra
.655 .749 .919 r
.9058 .48244 .91011 .48856 .92125 .48528 .91697 .47916 Mtetra
.655 .75 .919 r
.91697 .47916 .92125 .48528 .93243 .48198 .92819 .47587 Mtetra
.655 .751 .92 r
.92819 .47587 .93243 .48198 .94366 .47868 .93945 .47256 Mtetra
.657 .752 .92 r
.33552 .6441 .34122 .64908 .35035 .64637 .34467 .64136 Mtetra
.657 .751 .92 r
.34467 .64136 .35035 .64637 .35951 .64365 .35385 .63862 Mtetra
.657 .751 .919 r
.35385 .63862 .35951 .64365 .36871 .64093 .36306 .63586 Mtetra
.657 .75 .919 r
.36306 .63586 .36871 .64093 .37793 .6382 .37231 .63309 Mtetra
.657 .749 .918 r
.37231 .63309 .37793 .6382 .38719 .63547 .38158 .6303 Mtetra
.657 .748 .917 r
.38158 .6303 .38719 .63547 .39648 .63275 .39089 .62752 Mtetra
.656 .746 .916 r
.39089 .62752 .39648 .63275 .40579 .63005 .40023 .62475 Mtetra
.655 .743 .915 r
.40023 .62475 .40579 .63005 .41514 .62739 .4096 .622 Mtetra
.652 .74 .914 r
.4096 .622 .41514 .62739 .42452 .62478 .41901 .61932 Mtetra
.649 .737 .914 r
.41901 .61932 .42452 .62478 .43394 .62223 .42844 .61671 Mtetra
.644 .734 .914 r
.42844 .61671 .43394 .62223 .44338 .61976 .43791 .6142 Mtetra
.64 .732 .915 r
.43791 .6142 .44338 .61976 .45286 .61735 .4474 .61179 Mtetra
.635 .731 .918 r
.4474 .61179 .45286 .61735 .46237 .61498 .45693 .60948 Mtetra
.632 .733 .921 r
.45693 .60948 .46237 .61498 .47192 .6126 .4665 .60721 Mtetra
.631 .738 .925 r
.4665 .60721 .47192 .6126 .48151 .61018 .4761 .60494 Mtetra
.634 .746 .929 r
.4761 .60494 .48151 .61018 .49113 .60764 .48574 .60258 Mtetra
.64 .755 .932 r
.48574 .60258 .49113 .60764 .50079 .60494 .49542 .60004 Mtetra
.648 .765 .934 r
.49542 .60004 .50079 .60494 .51048 .60207 .50514 .5973 Mtetra
.657 .773 .935 r
.50514 .5973 .51048 .60207 .52021 .59903 .5149 .59433 Mtetra
.664 .779 .934 r
.5149 .59433 .52021 .59903 .52998 .59586 .52468 .59117 Mtetra
.67 .781 .933 r
.52468 .59117 .52998 .59586 .53977 .59261 .5345 .58787 Mtetra
.672 .781 .931 r
.5345 .58787 .53977 .59261 .5496 .58933 .54436 .58451 Mtetra
.672 .778 .929 r
.54436 .58451 .5496 .58933 .55946 .58605 .55424 .58114 Mtetra
.671 .775 .928 r
.55424 .58114 .55946 .58605 .56936 .58282 .56416 .5778 Mtetra
.668 .771 .927 r
.56416 .5778 .56936 .58282 .57929 .57963 .57412 .57452 Mtetra
.665 .767 .926 r
.57412 .57452 .57929 .57963 .58925 .5765 .5841 .57131 Mtetra
.662 .764 .925 r
.5841 .57131 .58925 .5765 .59925 .57342 .59413 .56816 Mtetra
.66 .761 .925 r
.59413 .56816 .59925 .57342 .60929 .57037 .60419 .56507 Mtetra
.657 .759 .925 r
.60419 .56507 .60929 .57037 .61936 .56736 .61429 .56202 Mtetra
.655 .758 .925 r
.61429 .56202 .61936 .56736 .62947 .56438 .62443 .55902 Mtetra
.653 .757 .926 r
.62443 .55902 .62947 .56438 .63962 .56142 .6346 .55606 Mtetra
.65 .757 .927 r
.6346 .55606 .63962 .56142 .64981 .5585 .64482 .55315 Mtetra
.647 .757 .929 r
.64482 .55315 .64981 .5585 .66004 .55562 .65507 .55029 Mtetra
.644 .758 .932 r
.65507 .55029 .66004 .55562 .67031 .55279 .66537 .5475 Mtetra
.64 .759 .934 r
.66537 .5475 .67031 .55279 .68062 .55001 .67571 .54477 Mtetra
.636 .761 .938 r
.67571 .54477 .68062 .55001 .69097 .54728 .68609 .54211 Mtetra
.634 .763 .941 r
.68609 .54211 .69097 .54728 .70137 .54459 .69652 .53948 Mtetra
.633 .766 .943 r
.69652 .53948 .70137 .54459 .7118 .54192 .70699 .53685 Mtetra
.635 .769 .944 r
.70699 .53685 .7118 .54192 .72228 .53921 .71749 .53415 Mtetra
.641 .772 .943 r
.71749 .53415 .72228 .53921 .73279 .53641 .72803 .5313 Mtetra
.649 .774 .94 r
.72803 .5313 .73279 .53641 .74334 .53349 .7386 .52827 Mtetra
.659 .774 .934 r
.7386 .52827 .74334 .53349 .75391 .53039 .7492 .525 Mtetra
.668 .771 .927 r
.7492 .525 .75391 .53039 .76451 .52711 .75981 .52151 Mtetra
.674 .766 .92 r
.75981 .52151 .76451 .52711 .77514 .52367 .77046 .51785 Mtetra
.677 .76 .913 r
.77046 .51785 .77514 .52367 .7858 .52011 .78113 .51409 Mtetra
.677 .753 .908 r
.78113 .51409 .7858 .52011 .79649 .51649 .79184 .51032 Mtetra
.675 .748 .906 r
.79184 .51032 .79649 .51649 .80722 .51287 .80259 .50659 Mtetra
.671 .744 .905 r
.80259 .50659 .80722 .51287 .81799 .50928 .81339 .50296 Mtetra
.668 .741 .905 r
.81339 .50296 .81799 .50928 .82881 .50576 .82423 .49943 Mtetra
.663 .74 .907 r
.82423 .49943 .82881 .50576 .83967 .50231 .83512 .49601 Mtetra
.66 .741 .91 r
.83512 .49601 .83967 .50231 .85058 .49891 .84607 .49266 Mtetra
.658 .742 .912 r
.84607 .49266 .85058 .49891 .86153 .49558 .85706 .48936 Mtetra
.656 .744 .914 r
.85706 .48936 .86153 .49558 .87253 .49227 .86809 .4861 Mtetra
.655 .746 .916 r
.86809 .4861 .87253 .49227 .88358 .48899 .87917 .48284 Mtetra
.655 .747 .918 r
.87917 .48284 .88358 .48899 .89466 .48572 .8903 .47958 Mtetra
.655 .749 .919 r
.8903 .47958 .89466 .48572 .9058 .48244 .90146 .47631 Mtetra
.655 .75 .92 r
.90146 .47631 .9058 .48244 .91697 .47916 .91267 .47302 Mtetra
.91267 .47302 .91697 .47916 .92819 .47587 .92392 .46971 Mtetra
.655 .751 .92 r
.92392 .46971 .92819 .47587 .93945 .47256 .93521 .46639 Mtetra
.656 .752 .92 r
.32977 .63908 .33552 .6441 .34467 .64136 .33894 .63634 Mtetra
.657 .752 .92 r
.33894 .63634 .34467 .64136 .35385 .63862 .34814 .63358 Mtetra
.34814 .63358 .35385 .63862 .36306 .63586 .35738 .6308 Mtetra
.658 .752 .92 r
.35738 .6308 .36306 .63586 .37231 .63309 .36664 .628 Mtetra
.659 .752 .919 r
.36664 .628 .37231 .63309 .38158 .6303 .37594 .62517 Mtetra
.659 .751 .918 r
.37594 .62517 .38158 .6303 .39089 .62752 .38527 .62232 Mtetra
.659 .749 .917 r
.38527 .62232 .39089 .62752 .40023 .62475 .39463 .61946 Mtetra
.658 .746 .915 r
.39463 .61946 .40023 .62475 .4096 .622 .40403 .61662 Mtetra
.656 .743 .913 r
.40403 .61662 .4096 .622 .41901 .61932 .41345 .61381 Mtetra
.653 .738 .912 r
.41345 .61381 .41901 .61932 .42844 .61671 .42291 .61108 Mtetra
.648 .733 .911 r
.42291 .61108 .42844 .61671 .43791 .6142 .4324 .60848 Mtetra
.641 .728 .911 r
.4324 .60848 .43791 .6142 .4474 .61179 .44191 .60602 Mtetra
.634 .725 .913 r
.44191 .60602 .4474 .61179 .45693 .60948 .45146 .60373 Mtetra
.628 .724 .916 r
.45146 .60373 .45693 .60948 .4665 .60721 .46105 .60155 Mtetra
.624 .727 .921 r
.46105 .60155 .4665 .60721 .4761 .60494 .47067 .59946 Mtetra
.624 .734 .926 r
.47067 .59946 .4761 .60494 .48574 .60258 .48033 .59731 Mtetra
.629 .745 .931 r
.48033 .59731 .48574 .60258 .49542 .60004 .49002 .59501 Mtetra
.638 .758 .935 r
.49002 .59501 .49542 .60004 .50514 .5973 .49976 .59248 Mtetra
.65 .77 .937 r
.49976 .59248 .50514 .5973 .5149 .59433 .50954 .58965 Mtetra
.66 .78 .937 r
.50954 .58965 .5149 .59433 .52468 .59117 .51935 .58656 Mtetra
.669 .786 .936 r
.51935 .58656 .52468 .59117 .5345 .58787 .5292 .58325 Mtetra
.674 .787 .934 r
.5292 .58325 .5345 .58787 .54436 .58451 .53908 .57981 Mtetra
.675 .785 .932 r
.53908 .57981 .54436 .58451 .55424 .58114 .54899 .57634 Mtetra
.674 .782 .931 r
.54899 .57634 .55424 .58114 .56416 .5778 .55893 .57289 Mtetra
.671 .777 .929 r
.55893 .57289 .56416 .5778 .57412 .57452 .56891 .5695 Mtetra
.668 .773 .928 r
.56891 .5695 .57412 .57452 .5841 .57131 .57893 .56619 Mtetra
.664 .769 .928 r
.57893 .56619 .5841 .57131 .59413 .56816 .58897 .56297 Mtetra
.661 .765 .927 r
.58897 .56297 .59413 .56816 .60419 .56507 .59906 .55981 Mtetra
.658 .763 .927 r
.59906 .55981 .60419 .56507 .61429 .56202 .60919 .55673 Mtetra
.655 .761 .928 r
.60919 .55673 .61429 .56202 .62443 .55902 .61935 .55371 Mtetra
.652 .76 .929 r
.61935 .55371 .62443 .55902 .6346 .55606 .62955 .55075 Mtetra
.648 .76 .931 r
.62955 .55075 .6346 .55606 .64482 .55315 .63979 .54785 Mtetra
.645 .76 .933 r
.63979 .54785 .64482 .55315 .65507 .55029 .65008 .54503 Mtetra
.64 .761 .936 r
.65008 .54503 .65507 .55029 .66537 .5475 .6604 .5423 Mtetra
.635 .762 .939 r
.6604 .5423 .66537 .5475 .67571 .54477 .67077 .53964 Mtetra
.631 .764 .943 r
.67077 .53964 .67571 .54477 .68609 .54211 .68119 .53706 Mtetra
.628 .767 .946 r
.68119 .53706 .68609 .54211 .69652 .53948 .69165 .53449 Mtetra
.629 .771 .948 r
.69165 .53449 .69652 .53948 .70699 .53685 .70214 .53189 Mtetra
.634 .775 .948 r
.70214 .53189 .70699 .53685 .71749 .53415 .71268 .52916 Mtetra
.644 .778 .945 r
.71268 .52916 .71749 .53415 .72803 .5313 .72324 .52621 Mtetra
.655 .779 .939 r
.72324 .52621 .72803 .5313 .7386 .52827 .73383 .523 Mtetra
.668 .776 .93 r
.73383 .523 .7386 .52827 .7492 .525 .74444 .51947 Mtetra
.678 .771 .921 r
.74444 .51947 .7492 .525 .75981 .52151 .75507 .5157 Mtetra
.683 .763 .912 r
.75507 .5157 .75981 .52151 .77046 .51785 .76572 .51177 Mtetra
.684 .754 .905 r
.76572 .51177 .77046 .51785 .78113 .51409 .77641 .50779 Mtetra
.681 .746 .9 r
.77641 .50779 .78113 .51409 .79184 .51032 .78714 .50389 Mtetra
.676 .74 .899 r
.78714 .50389 .79184 .51032 .80259 .50659 .79791 .50009 Mtetra
.67 .737 .9 r
.79791 .50009 .80259 .50659 .81339 .50296 .80874 .49648 Mtetra
.665 .736 .903 r
.80874 .49648 .81339 .50296 .82423 .49943 .81962 .493 Mtetra
.66 .737 .907 r
.81962 .493 .82423 .49943 .83512 .49601 .83055 .48966 Mtetra
.656 .739 .911 r
.83055 .48966 .83512 .49601 .84607 .49266 .84153 .48639 Mtetra
.654 .742 .914 r
.84153 .48639 .84607 .49266 .85706 .48936 .85256 .48316 Mtetra
.653 .745 .917 r
.85256 .48316 .85706 .48936 .86809 .4861 .86363 .47994 Mtetra
.653 .747 .919 r
.86363 .47994 .86809 .4861 .87917 .48284 .87475 .47671 Mtetra
.653 .749 .92 r
.87475 .47671 .87917 .48284 .8903 .47958 .8859 .47346 Mtetra
.654 .75 .921 r
.8859 .47346 .8903 .47958 .90146 .47631 .8971 .47018 Mtetra
.654 .751 .921 r
.8971 .47018 .90146 .47631 .91267 .47302 .90834 .46687 Mtetra
.655 .751 .921 r
.90834 .46687 .91267 .47302 .92392 .46971 .91962 .46354 Mtetra
.91962 .46354 .92392 .46971 .93521 .46639 .93095 .46018 Mtetra
.655 .751 .92 r
.32399 .63404 .32977 .63908 .33894 .63634 .33318 .6313 Mtetra
.656 .752 .921 r
.33318 .6313 .33894 .63634 .34814 .63358 .3424 .62855 Mtetra
.656 .753 .921 r
.3424 .62855 .34814 .63358 .35738 .6308 .35165 .62577 Mtetra
.657 .754 .921 r
.35165 .62577 .35738 .6308 .36664 .628 .36094 .62295 Mtetra
.659 .755 .921 r
.36094 .62295 .36664 .628 .37594 .62517 .37026 .6201 Mtetra
.66 .755 .92 r
.37026 .6201 .37594 .62517 .38527 .62232 .37961 .6172 Mtetra
.661 .754 .919 r
.37961 .6172 .38527 .62232 .39463 .61946 .38899 .61427 Mtetra
.662 .752 .917 r
.38899 .61427 .39463 .61946 .40403 .61662 .39841 .61131 Mtetra
.661 .748 .915 r
.39841 .61131 .40403 .61662 .41345 .61381 .40786 .60836 Mtetra
.659 .743 .912 r
.40786 .60836 .41345 .61381 .42291 .61108 .41734 .60547 Mtetra
.654 .737 .91 r
.41734 .60547 .42291 .61108 .4324 .60848 .42685 .6027 Mtetra
.646 .729 .909 r
.42685 .6027 .4324 .60848 .44191 .60602 .43639 .6001 Mtetra
.636 .722 .909 r
.43639 .6001 .44191 .60602 .45146 .60373 .44596 .59774 Mtetra
.627 .717 .911 r
.44596 .59774 .45146 .60373 .46105 .60155 .45556 .59559 Mtetra
.618 .715 .915 r
.45556 .59559 .46105 .60155 .47067 .59946 .4652 .59363 Mtetra
.615 .72 .92 r
.4652 .59363 .47067 .59946 .48033 .59731 .47488 .59172 Mtetra
.616 .73 .927 r
.47488 .59172 .48033 .59731 .49002 .59501 .48459 .58972 Mtetra
.625 .745 .933 r
.48459 .58972 .49002 .59501 .49976 .59248 .49435 .58749 Mtetra
.639 .762 .937 r
.49435 .58749 .49976 .59248 .50954 .58965 .50415 .5849 Mtetra
.652 .776 .939 r
.50415 .5849 .50954 .58965 .51935 .58656 .51398 .58197 Mtetra
.666 .787 .939 r
.51398 .58197 .51935 .58656 .5292 .58325 .52386 .57871 Mtetra
.674 .792 .938 r
.52386 .57871 .5292 .58325 .53908 .57981 .53376 .57526 Mtetra
.678 .793 .936 r
.53376 .57526 .53908 .57981 .54899 .57634 .5437 .5717 Mtetra
.678 .79 .934 r
.5437 .5717 .54899 .57634 .55893 .57289 .55367 .56813 Mtetra
.675 .786 .933 r
.55367 .56813 .55893 .57289 .56891 .5695 .56367 .56462 Mtetra
.671 .781 .932 r
.56367 .56462 .56891 .5695 .57893 .56619 .57371 .5612 Mtetra
.667 .776 .931 r
.57371 .5612 .57893 .56619 .58897 .56297 .58379 .55789 Mtetra
.662 .772 .931 r
.58379 .55789 .58897 .56297 .59906 .55981 .5939 .55467 Mtetra
.658 .769 .931 r
.5939 .55467 .59906 .55981 .60919 .55673 .60405 .55154 Mtetra
.654 .766 .932 r
.60405 .55154 .60919 .55673 .61935 .55371 .61424 .5485 Mtetra
.65 .765 .933 r
.61424 .5485 .61935 .55371 .62955 .55075 .62447 .54554 Mtetra
.645 .765 .935 r
.62447 .54554 .62955 .55075 .63979 .54785 .63474 .54268 Mtetra
.64 .765 .938 r
.63474 .54268 .63979 .54785 .65008 .54503 .64505 .53991 Mtetra
.635 .766 .942 r
.64505 .53991 .65008 .54503 .6604 .5423 .65541 .53724 Mtetra
.629 .767 .946 r
.65541 .53724 .6604 .5423 .67077 .53964 .66581 .53467 Mtetra
.624 .77 .95 r
.66581 .53467 .67077 .53964 .68119 .53706 .67626 .53216 Mtetra
.623 .774 .953 r
.67626 .53216 .68119 .53706 .69165 .53449 .68675 .52964 Mtetra
.627 .778 .953 r
.68675 .52964 .69165 .53449 .70214 .53189 .69727 .52702 Mtetra
.636 .781 .951 r
.69727 .52702 .70214 .53189 .71268 .52916 .70783 .5242 Mtetra
.651 .783 .944 r
.70783 .5242 .71268 .52916 .72324 .52621 .71842 .52105 Mtetra
.667 .781 .934 r
.71842 .52105 .72324 .52621 .73383 .523 .72902 .51754 Mtetra
.681 .775 .922 r
.72902 .51754 .73383 .523 .74444 .51947 .73963 .51367 Mtetra
.689 .766 .91 r
.73963 .51367 .74444 .51947 .75507 .5157 .75027 .50955 Mtetra
.691 .755 .9 r
.75027 .50955 .75507 .5157 .76572 .51177 .76093 .50535 Mtetra
.689 .745 .894 r
.76093 .50535 .76572 .51177 .77641 .50779 .77163 .50118 Mtetra
.682 .737 .893 r
.77163 .50118 .77641 .50779 .78714 .50389 .78239 .4972 Mtetra
.674 .733 .894 r
.78239 .4972 .78714 .50389 .79791 .50009 .79319 .49345 Mtetra
.666 .732 .899 r
.79319 .49345 .79791 .50009 .80874 .49648 .80406 .48993 Mtetra
.659 .733 .904 r
.80406 .48993 .80874 .49648 .81962 .493 .81498 .48659 Mtetra
.655 .737 .91 r
.81498 .48659 .81962 .493 .83055 .48966 .82595 .48336 Mtetra
.651 .741 .915 r
.82595 .48336 .83055 .48966 .84153 .48639 .83697 .4802 Mtetra
.651 .745 .918 r
.83697 .4802 .84153 .48639 .85256 .48316 .84804 .47704 Mtetra
.651 .748 .921 r
.84804 .47704 .85256 .48316 .86363 .47994 .85915 .47387 Mtetra
.652 .751 .922 r
.85915 .47387 .86363 .47994 .87475 .47671 .8703 .47064 Mtetra
.653 .753 .923 r
.8703 .47064 .87475 .47671 .8859 .47346 .88149 .46737 Mtetra
.654 .753 .923 r
.88149 .46737 .8859 .47346 .8971 .47018 .89272 .46406 Mtetra
.655 .753 .922 r
.89272 .46406 .8971 .47018 .90834 .46687 .90398 .46071 Mtetra
.656 .753 .922 r
.90398 .46071 .90834 .46687 .91962 .46354 .9153 .45733 Mtetra
.656 .752 .921 r
.9153 .45733 .91962 .46354 .93095 .46018 .92665 .45393 Mtetra
.654 .751 .921 r
.31818 .62896 .32399 .63404 .33318 .6313 .32738 .62625 Mtetra
.654 .752 .922 r
.32738 .62625 .33318 .6313 .3424 .62855 .33662 .62352 Mtetra
.654 .754 .923 r
.33662 .62352 .3424 .62855 .35165 .62577 .34589 .62076 Mtetra
.656 .756 .924 r
.34589 .62076 .35165 .62577 .36094 .62295 .35519 .61796 Mtetra
.657 .758 .924 r
.35519 .61796 .36094 .62295 .37026 .6201 .36453 .61512 Mtetra
.66 .759 .924 r
.36453 .61512 .37026 .6201 .37961 .6172 .3739 .61221 Mtetra
.662 .76 .923 r
.3739 .61221 .37961 .6172 .38899 .61427 .38331 .60922 Mtetra
.665 .76 .921 r
.38331 .60922 .38899 .61427 .39841 .61131 .39275 .60617 Mtetra
.667 .757 .918 r
.39275 .60617 .39841 .61131 .40786 .60836 .40223 .60307 Mtetra
.666 .752 .914 r
.40223 .60307 .40786 .60836 .41734 .60547 .41174 .59997 Mtetra
.663 .744 .911 r
.41174 .59997 .41734 .60547 .42685 .6027 .42128 .59695 Mtetra
.655 .734 .907 r
.42128 .59695 .42685 .6027 .43639 .6001 .43084 .59411 Mtetra
.644 .722 .905 r
.43084 .59411 .43639 .6001 .44596 .59774 .44043 .59155 Mtetra
.631 .712 .905 r
.44043 .59155 .44596 .59774 .45556 .59559 .45005 .5893 Mtetra
.616 .704 .908 r
.45005 .5893 .45556 .59559 .4652 .59363 .45971 .58741 Mtetra
.607 .704 .913 r
.45971 .58741 .4652 .59363 .47488 .59172 .4694 .5857 Mtetra
.602 .71 .92 r
.4694 .5857 .47488 .59172 .48459 .58972 .47913 .58406 Mtetra
.608 .726 .929 r
.47913 .58406 .48459 .58972 .49435 .58749 .4889 .58222 Mtetra
.622 .747 .936 r
.4889 .58222 .49435 .58749 .50415 .5849 .49872 .58001 Mtetra
.639 .768 .941 r
.49872 .58001 .50415 .5849 .51398 .58197 .50858 .57737 Mtetra
.658 .786 .942 r
.50858 .57737 .51398 .58197 .52386 .57871 .51848 .57426 Mtetra
.67 .796 .942 r
.51848 .57426 .52386 .57871 .53376 .57526 .52841 .57086 Mtetra
.678 .801 .941 r
.52841 .57086 .53376 .57526 .5437 .5717 .53837 .56724 Mtetra
.68 .8 .939 r
.53837 .56724 .5437 .5717 .55367 .56813 .54837 .56357 Mtetra
.678 .796 .937 r
.54837 .56357 .55367 .56813 .56367 .56462 .5584 .55994 Mtetra
.675 .791 .936 r
.5584 .55994 .56367 .56462 .57371 .5612 .56847 .55639 Mtetra
.669 .785 .936 r
.56847 .55639 .57371 .5612 .58379 .55789 .57857 .55298 Mtetra
.664 .78 .936 r
.57857 .55298 .58379 .55789 .5939 .55467 .5887 .54968 Mtetra
.659 .776 .936 r
.5887 .54968 .5939 .55467 .60405 .55154 .59888 .5465 Mtetra
.653 .774 .937 r
.59888 .5465 .60405 .55154 .61424 .5485 .60909 .54344 Mtetra
.648 .772 .939 r
.60909 .54344 .61424 .5485 .62447 .54554 .61935 .54049 Mtetra
.641 .771 .942 r
.61935 .54049 .62447 .54554 .63474 .54268 .62965 .53766 Mtetra
.635 .771 .945 r
.62965 .53766 .63474 .54268 .64505 .53991 .63999 .53496 Mtetra
.628 .772 .95 r
.63999 .53496 .64505 .53991 .65541 .53724 .65038 .53238 Mtetra
.621 .774 .954 r
.65038 .53238 .65541 .53724 .66581 .53467 .66082 .52989 Mtetra
.617 .777 .958 r
.66082 .52989 .66581 .53467 .67626 .53216 .6713 .52745 Mtetra
.619 .781 .959 r
.6713 .52745 .67626 .53216 .68675 .52964 .68182 .52495 Mtetra
.628 .786 .958 r
.68182 .52495 .68675 .52964 .69727 .52702 .69237 .52224 Mtetra
.643 .789 .952 r
.69237 .52224 .69727 .52702 .70783 .5242 .70295 .51922 Mtetra
.665 .788 .94 r
.70295 .51922 .70783 .5242 .71842 .52105 .71355 .51573 Mtetra
.683 .782 .925 r
.71355 .51573 .71842 .52105 .72902 .51754 .72415 .5118 Mtetra
.696 .771 .909 r
.72415 .5118 .72902 .51754 .73963 .51367 .73477 .50748 Mtetra
.701 .757 .896 r
.73477 .50748 .73963 .51367 .75027 .50955 .74541 .50296 Mtetra
.697 .743 .887 r
.74541 .50296 .75027 .50955 .76093 .50535 .75609 .4985 Mtetra
.69 .733 .884 r
.75609 .4985 .76093 .50535 .77163 .50118 .76681 .49422 Mtetra
.678 .726 .886 r
.76681 .49422 .77163 .50118 .78239 .4972 .77759 .4903 Mtetra
.668 .725 .892 r
.77759 .4903 .78239 .4972 .79319 .49345 .78844 .48671 Mtetra
.658 .727 .9 r
.78844 .48671 .79319 .49345 .80406 .48993 .79935 .4834 Mtetra
.651 .732 .909 r
.79935 .4834 .80406 .48993 .81498 .48659 .81032 .48027 Mtetra
.647 .739 .916 r
.81032 .48027 .81498 .48659 .82595 .48336 .82134 .47722 Mtetra
.646 .745 .922 r
.82134 .47722 .82595 .48336 .83697 .4802 .8324 .47417 Mtetra
.647 .751 .925 r
.8324 .47417 .83697 .4802 .84804 .47704 .84351 .47107 Mtetra
.649 .755 .927 r
.84351 .47107 .84804 .47704 .85915 .47387 .85465 .4679 Mtetra
.651 .757 .927 r
.85465 .4679 .85915 .47387 .8703 .47064 .86583 .46465 Mtetra
.653 .758 .926 r
.86583 .46465 .8703 .47064 .88149 .46737 .87705 .46134 Mtetra
.655 .757 .925 r
.87705 .46134 .88149 .46737 .89272 .46406 .88831 .45796 Mtetra
.656 .756 .924 r
.88831 .45796 .89272 .46406 .90398 .46071 .8996 .45454 Mtetra
.657 .755 .922 r
.8996 .45454 .90398 .46071 .9153 .45733 .91094 .4511 Mtetra
.658 .754 .921 r
.91094 .4511 .9153 .45733 .92665 .45393 .92232 .44763 Mtetra
.652 .75 .922 r
.31232 .62385 .31818 .62896 .32738 .62625 .32154 .62116 Mtetra
.652 .752 .923 r
.32154 .62116 .32738 .62625 .33662 .62352 .3308 .61846 Mtetra
.652 .754 .924 r
.3308 .61846 .33662 .62352 .34589 .62076 .34008 .61574 Mtetra
.653 .756 .925 r
.34008 .61574 .34589 .62076 .35519 .61796 .34941 .61298 Mtetra
.655 .759 .926 r
.34941 .61298 .35519 .61796 .36453 .61512 .35876 .61018 Mtetra
.657 .762 .927 r
.35876 .61018 .36453 .61512 .3739 .61221 .36815 .6073 Mtetra
.661 .765 .927 r
.36815 .6073 .3739 .61221 .38331 .60922 .37758 .60432 Mtetra
.665 .767 .926 r
.37758 .60432 .38331 .60922 .39275 .60617 .38705 .60123 Mtetra
.67 .767 .923 r
.38705 .60123 .39275 .60617 .40223 .60307 .39655 .59802 Mtetra
.672 .764 .919 r
.39655 .59802 .40223 .60307 .41174 .59997 .40609 .59474 Mtetra
.673 .758 .914 r
.40609 .59474 .41174 .59997 .42128 .59695 .41565 .59143 Mtetra
.668 .747 .91 r
.41565 .59143 .42128 .59695 .43084 .59411 .42525 .58826 Mtetra
.657 .733 .905 r
.42525 .58826 .43084 .59411 .44043 .59155 .43487 .58534 Mtetra
.642 .716 .902 r
.43487 .58534 .44043 .59155 .45005 .5893 .44452 .58282 Mtetra
.621 .701 .902 r
.44452 .58282 .45005 .5893 .45971 .58741 .45419 .58081 Mtetra
.604 .691 .904 r
.45419 .58081 .45971 .58741 .4694 .5857 .46389 .57918 Mtetra
.59 .689 .911 r
.46389 .57918 .4694 .5857 .47913 .58406 .47363 .57786 Mtetra
.59 .701 .92 r
.47363 .57786 .47913 .58406 .4889 .58222 .48342 .57646 Mtetra
.601 .722 .93 r
.48342 .57646 .4889 .58222 .49872 .58001 .49325 .57475 Mtetra
.619 .748 .939 r
.49325 .57475 .49872 .58001 .50858 .57737 .50313 .57256 Mtetra
.643 .775 .943 r
.50313 .57256 .50858 .57737 .51848 .57426 .51306 .56978 Mtetra
.661 .794 .945 r
.51306 .56978 .51848 .57426 .52841 .57086 .52302 .56655 Mtetra
.675 .805 .945 r
.52302 .56655 .52841 .57086 .53837 .56724 .53301 .56297 Mtetra
.681 .809 .944 r
.53301 .56297 .53837 .56724 .54837 .56357 .54304 .55924 Mtetra
.681 .808 .943 r
.54304 .55924 .54837 .56357 .5584 .55994 .55309 .55551 Mtetra
.678 .804 .942 r
.55309 .55551 .5584 .55994 .56847 .55639 .56319 .55184 Mtetra
.672 .798 .942 r
.56319 .55184 .56847 .55639 .57857 .55298 .57331 .54832 Mtetra
.665 .792 .942 r
.57331 .54832 .57857 .55298 .5887 .54968 .58348 .54493 Mtetra
.658 .788 .943 r
.58348 .54493 .5887 .54968 .59888 .5465 .59368 .5417 Mtetra
.651 .784 .945 r
.59368 .5417 .59888 .5465 .60909 .54344 .60392 .53862 Mtetra
.644 .782 .947 r
.60392 .53862 .60909 .54344 .61935 .54049 .61421 .53568 Mtetra
.636 .781 .951 r
.61421 .53568 .61935 .54049 .62965 .53766 .62454 .5329 Mtetra
.628 .781 .955 r
.62454 .5329 .62965 .53766 .63999 .53496 .63491 .53027 Mtetra
.619 .781 .959 r
.63491 .53027 .63999 .53496 .65038 .53238 .64533 .52777 Mtetra
.613 .784 .963 r
.64533 .52777 .65038 .53238 .66082 .52989 .6558 .52535 Mtetra
.611 .787 .965 r
.6558 .52535 .66082 .52989 .6713 .52745 .66631 .52292 Mtetra
.618 .791 .964 r
.66631 .52292 .6713 .52745 .68182 .52495 .67686 .52034 Mtetra
.636 .795 .958 r
.67686 .52034 .68182 .52495 .69237 .52224 .68743 .51742 Mtetra
.659 .793 .947 r
.68743 .51742 .69237 .52224 .70295 .51922 .69803 .51404 Mtetra
.685 .788 .929 r
.69803 .51404 .70295 .51922 .71355 .51573 .70862 .51004 Mtetra
.701 .775 .909 r
.70862 .51004 .71355 .51573 .72415 .5118 .71923 .50556 Mtetra
.709 .759 .891 r
.71923 .50556 .72415 .5118 .73477 .50748 .72985 .50074 Mtetra
.708 .743 .879 r
.72985 .50074 .73477 .50748 .74541 .50296 .74049 .49585 Mtetra
.698 .729 .874 r
.74049 .49585 .74541 .50296 .75609 .4985 .75118 .49126 Mtetra
.686 .721 .877 r
.75118 .49126 .75609 .4985 .76681 .49422 .76194 .48706 Mtetra
.669 .718 .885 r
.76194 .48706 .76681 .49422 .77759 .4903 .77277 .48338 Mtetra
.656 .721 .896 r
.77277 .48338 .77759 .4903 .78844 .48671 .78367 .48011 Mtetra
.646 .728 .909 r
.78367 .48011 .78844 .48671 .79935 .4834 .79463 .4771 Mtetra
.64 .737 .919 r
.79463 .4771 .79935 .4834 .81032 .48027 .80566 .47422 Mtetra
.639 .747 .927 r
.80566 .47422 .81032 .48027 .82134 .47722 .81672 .47132 Mtetra
.641 .754 .931 r
.81672 .47132 .82134 .47722 .8324 .47417 .82782 .46835 Mtetra
.645 .759 .932 r
.82782 .46835 .8324 .47417 .84351 .47107 .83896 .46524 Mtetra
.649 .762 .932 r
.83896 .46524 .84351 .47107 .85465 .4679 .85013 .46203 Mtetra
.653 .762 .93 r
.85013 .46203 .85465 .4679 .86583 .46465 .86134 .4587 Mtetra
.655 .761 .928 r
.86134 .4587 .86583 .46465 .87705 .46134 .87259 .4553 Mtetra
.657 .76 .925 r
.87259 .4553 .87705 .46134 .88831 .45796 .88387 .45184 Mtetra
.658 .758 .924 r
.88387 .45184 .88831 .45796 .8996 .45454 .89519 .44834 Mtetra
.659 .756 .922 r
.89519 .44834 .8996 .45454 .91094 .4511 .90655 .44482 Mtetra
.659 .754 .92 r
.90655 .44482 .91094 .4511 .92232 .44763 .91796 .44128 Mtetra
.65 .75 .923 r
.30643 .61871 .31232 .62385 .32154 .62116 .31567 .61604 Mtetra
.65 .751 .924 r
.31567 .61604 .32154 .62116 .3308 .61846 .32494 .61336 Mtetra
.65 .753 .925 r
.32494 .61336 .3308 .61846 .34008 .61574 .33424 .61068 Mtetra
.65 .755 .926 r
.33424 .61068 .34008 .61574 .34941 .61298 .34358 .60798 Mtetra
.65 .758 .928 r
.34358 .60798 .34941 .61298 .35876 .61018 .35295 .60525 Mtetra
.652 .762 .93 r
.35295 .60525 .35876 .61018 .36815 .6073 .36236 .60245 Mtetra
.656 .767 .931 r
.36236 .60245 .36815 .6073 .37758 .60432 .37181 .59955 Mtetra
.662 .772 .932 r
.37181 .59955 .37758 .60432 .38705 .60123 .38129 .59652 Mtetra
.669 .777 .93 r
.38129 .59652 .38705 .60123 .39655 .59802 .39082 .59329 Mtetra
.676 .779 .927 r
.39082 .59329 .39655 .59802 .40609 .59474 .40038 .58988 Mtetra
.683 .776 .921 r
.40038 .58988 .40609 .59474 .41565 .59143 .40998 .5863 Mtetra
.682 .766 .915 r
.40998 .5863 .41565 .59143 .42525 .58826 .41961 .58273 Mtetra
.676 .751 .907 r
.41961 .58273 .42525 .58826 .43487 .58534 .42927 .57929 Mtetra
.66 .729 .9 r
.42927 .57929 .43487 .58534 .44452 .58282 .43894 .57627 Mtetra
.635 .705 .896 r
.43894 .57627 .44452 .58282 .45419 .58081 .44864 .57388 Mtetra
.611 .684 .895 r
.44864 .57388 .45419 .58081 .46389 .57918 .45836 .57212 Mtetra
.584 .67 .899 r
.45836 .57212 .46389 .57918 .47363 .57786 .46812 .57099 Mtetra
.573 .673 .907 r
.46812 .57099 .47363 .57786 .48342 .57646 .47791 .57004 Mtetra
.575 .689 .919 r
.47791 .57004 .48342 .57646 .49325 .57475 .48776 .56895 Mtetra
.592 .719 .932 r
.48776 .56895 .49325 .57475 .50313 .57256 .49765 .5674 Mtetra
.62 .754 .942 r
.49765 .5674 .50313 .57256 .51306 .56978 .5076 .56513 Mtetra
.644 .784 .948 r
.5076 .56513 .51306 .56978 .52302 .56655 .51758 .56226 Mtetra
.666 .806 .95 r
.51758 .56226 .52302 .56655 .53301 .56297 .5276 .55885 Mtetra
.677 .816 .95 r
.5276 .55885 .53301 .56297 .54304 .55924 .53766 .55517 Mtetra
.681 .82 .95 r
.53766 .55517 .54304 .55924 .55309 .55551 .54775 .55137 Mtetra
.679 .818 .95 r
.54775 .55137 .55309 .55551 .56319 .55184 .55787 .5476 Mtetra
.673 .813 .95 r
.55787 .5476 .56319 .55184 .57331 .54832 .56802 .54397 Mtetra
.666 .807 .951 r
.56802 .54397 .57331 .54832 .58348 .54493 .57822 .5405 Mtetra
.657 .802 .952 r
.57822 .5405 .58348 .54493 .59368 .5417 .58845 .53721 Mtetra
.648 .798 .954 r
.58845 .53721 .59368 .5417 .60392 .53862 .59872 .53411 Mtetra
.639 .795 .957 r
.59872 .53411 .60392 .53862 .61421 .53568 .60904 .53119 Mtetra
.628 .793 .961 r
.60904 .53119 .61421 .53568 .62454 .5329 .6194 .52846 Mtetra
.618 .793 .965 r
.6194 .52846 .62454 .5329 .63491 .53027 .6298 .52589 Mtetra
.609 .793 .97 r
.6298 .52589 .63491 .53027 .64533 .52777 .64026 .52346 Mtetra
.605 .795 .972 r
.64026 .52346 .64533 .52777 .6558 .52535 .65075 .52106 Mtetra
.61 .799 .972 r
.65075 .52106 .6558 .52535 .66631 .52292 .66129 .51855 Mtetra
.625 .802 .967 r
.66129 .51855 .66631 .52292 .67686 .52034 .67186 .51576 Mtetra
.654 .803 .954 r
.67186 .51576 .67686 .52034 .68743 .51742 .68245 .51242 Mtetra
.682 .796 .935 r
.68245 .51242 .68743 .51742 .69803 .51404 .69305 .50847 Mtetra
.708 .782 .91 r
.69305 .50847 .69803 .51404 .70862 .51004 .70364 .5038 Mtetra
.719 .762 .886 r
.70364 .5038 .70862 .51004 .71923 .50556 .71424 .49863 Mtetra
.719 .741 .869 r
.71424 .49863 .71923 .50556 .72985 .50074 .72485 .49332 Mtetra
.71 .725 .861 r
.72485 .49332 .72985 .50074 .74049 .49585 .73551 .48818 Mtetra
.692 .711 .864 r
.73551 .48818 .74049 .49585 .75118 .49126 .74623 .48368 Mtetra
.674 .708 .874 r
.74623 .48368 .75118 .49126 .76194 .48706 .75704 .47982 Mtetra
.653 .711 .89 r
.75704 .47982 .76194 .48706 .77277 .48338 .76793 .47662 Mtetra
.638 .72 .907 r
.76793 .47662 .77277 .48338 .78367 .48011 .7789 .47384 Mtetra
.63 .735 .923 r
.7789 .47384 .78367 .48011 .79463 .4771 .78992 .4712 Mtetra
.627 .748 .934 r
.78992 .4712 .79463 .4771 .80566 .47422 .80099 .46856 Mtetra
.632 .761 .94 r
.80099 .46856 .80566 .47422 .81672 .47132 .8121 .46575 Mtetra
.638 .767 .941 r
.8121 .46575 .81672 .47132 .82782 .46835 .82324 .46275 Mtetra
.646 .77 .939 r
.82324 .46275 .82782 .46835 .83896 .46524 .8344 .45955 Mtetra
.652 .77 .935 r
.8344 .45955 .83896 .46524 .85013 .46203 .84559 .4562 Mtetra
.656 .767 .931 r
.84559 .4562 .85013 .46203 .86134 .4587 .85682 .45275 Mtetra
.659 .765 .928 r
.85682 .45275 .86134 .4587 .87259 .4553 .86809 .44923 Mtetra
.66 .761 .925 r
.86809 .44923 .87259 .4553 .88387 .45184 .8794 .44567 Mtetra
.661 .759 .923 r
.8794 .44567 .88387 .45184 .89519 .44834 .89074 .44209 Mtetra
.661 .756 .921 r
.89074 .44209 .89519 .44834 .90655 .44482 .90213 .43849 Mtetra
.66 .755 .92 r
.90213 .43849 .90655 .44482 .91796 .44128 .91357 .43489 Mtetra
.65 .75 .923 r
.3005 .61354 .30643 .61871 .31567 .61604 .30976 .61085 Mtetra
.649 .75 .923 r
.30976 .61085 .31567 .61604 .32494 .61336 .31905 .60817 Mtetra
.648 .75 .924 r
.31905 .60817 .32494 .61336 .33424 .61068 .32837 .60549 Mtetra
.648 .751 .925 r
.32837 .60549 .33424 .61068 .34358 .60798 .33772 .60283 Mtetra
.647 .753 .927 r
.33772 .60283 .34358 .60798 .35295 .60525 .34711 .60017 Mtetra
.647 .757 .929 r
.34711 .60017 .35295 .60525 .36236 .60245 .35654 .59748 Mtetra
.649 .762 .932 r
.35654 .59748 .36236 .60245 .37181 .59955 .366 .59473 Mtetra
.654 .77 .934 r
.366 .59473 .37181 .59955 .38129 .59652 .3755 .59185 Mtetra
.662 .778 .935 r
.3755 .59185 .38129 .59652 .39082 .59329 .38504 .58875 Mtetra
.673 .787 .935 r
.38504 .58875 .39082 .59329 .40038 .58988 .39462 .58538 Mtetra
.687 .792 .93 r
.39462 .58538 .40038 .58988 .40998 .5863 .40425 .58168 Mtetra
.694 .789 .924 r
.40425 .58168 .40998 .5863 .41961 .58273 .41392 .57779 Mtetra
.697 .779 .914 r
.41392 .57779 .41961 .58273 .42927 .57929 .42361 .5738 Mtetra
.685 .756 .906 r
.42361 .5738 .42927 .57929 .43894 .57627 .43333 .5701 Mtetra
.661 .727 .898 r
.43333 .5701 .43894 .57627 .44864 .57388 .44306 .56701 Mtetra
.63 .694 .891 r
.44306 .56701 .44864 .57388 .45836 .57212 .45281 .56474 Mtetra
.591 .664 .89 r
.45281 .56474 .45836 .57212 .46812 .57099 .46258 .56347 Mtetra
.567 .651 .892 r
.46258 .56347 .46812 .57099 .47791 .57004 .47238 .56275 Mtetra
.553 .653 .901 r
.47238 .56275 .47791 .57004 .48776 .56895 .48224 .56227 Mtetra
.562 .677 .916 r
.48224 .56227 .48776 .56895 .49765 .5674 .49214 .56147 Mtetra
.589 .715 .931 r
.49214 .56147 .49765 .5674 .5076 .56513 .5021 .55995 Mtetra
.618 .755 .944 r
.5021 .55995 .5076 .56513 .51758 .56226 .51211 .5577 Mtetra
.648 .791 .95 r
.51211 .5577 .51758 .56226 .5276 .55885 .52216 .55469 Mtetra
.666 .813 .954 r
.52216 .55469 .5276 .55885 .53766 .55517 .53224 .55122 Mtetra
.676 .826 .955 r
.53224 .55122 .53766 .55517 .54775 .55137 .54236 .54749 Mtetra
.677 .83 .957 r
.54236 .54749 .54775 .55137 .55787 .5476 .55251 .5437 Mtetra
.672 .828 .958 r
.55251 .5437 .55787 .5476 .56802 .54397 .5627 .54 Mtetra
.665 .824 .96 r
.5627 .54 .56802 .54397 .57822 .5405 .57292 .53646 Mtetra
.654 .819 .963 r
.57292 .53646 .57822 .5405 .58845 .53721 .58318 .53312 Mtetra
.643 .815 .966 r
.58318 .53312 .58845 .53721 .59872 .53411 .59349 .53 Mtetra
.631 .811 .969 r
.59349 .53 .59872 .53411 .60904 .53119 .60383 .52709 Mtetra
.619 .809 .973 r
.60383 .52709 .60904 .53119 .6194 .52846 .61423 .52439 Mtetra
.608 .807 .976 r
.61423 .52439 .6194 .52846 .6298 .52589 .62466 .52185 Mtetra
.601 .807 .979 r
.62466 .52185 .6298 .52589 .64026 .52346 .63515 .5194 Mtetra
.604 .808 .978 r
.63515 .5194 .64026 .52346 .65075 .52106 .64568 .5169 Mtetra
.62 .81 .973 r
.64568 .5169 .65075 .52106 .66129 .51855 .65624 .51413 Mtetra
.647 .808 .96 r
.65624 .51413 .66129 .51855 .67186 .51576 .66682 .51089 Mtetra
.684 .801 .938 r
.66682 .51089 .67186 .51576 .68245 .51242 .67741 .50689 Mtetra
.71 .784 .91 r
.67741 .50689 .68245 .51242 .69305 .50847 .688 .50213 Mtetra
.727 .762 .88 r
.688 .50213 .69305 .50847 .70364 .5038 .69858 .49665 Mtetra
.73 .739 .859 r
.69858 .49665 .70364 .5038 .71424 .49863 .70916 .49082 Mtetra
.719 .718 .848 r
.70916 .49082 .71424 .49863 .72485 .49332 .71979 .48522 Mtetra
.703 .705 .849 r
.71979 .48522 .72485 .49332 .73551 .48818 .73047 .48018 Mtetra
.676 .698 .863 r
.73047 .48018 .73551 .48818 .74623 .48368 .74126 .47616 Mtetra
.652 .702 .883 r
.74126 .47616 .74623 .48368 .75704 .47982 .75214 .47298 Mtetra
.629 .714 .908 r
.75214 .47298 .75704 .47982 .76793 .47662 .7631 .47042 Mtetra
.612 .731 .93 r
.7631 .47042 .76793 .47662 .7789 .47384 .77414 .46817 Mtetra
.612 .752 .945 r
.77414 .46817 .7789 .47384 .78992 .4712 .78522 .46581 Mtetra
.617 .766 .951 r
.78522 .46581 .78992 .4712 .80099 .46856 .79633 .46326 Mtetra
.631 .776 .95 r
.79633 .46326 .80099 .46856 .8121 .46575 .80747 .46036 Mtetra
.643 .779 .946 r
.80747 .46036 .8121 .46575 .82324 .46275 .81862 .45719 Mtetra
.653 .776 .939 r
.81862 .45719 .82324 .46275 .8344 .45955 .8298 .45379 Mtetra
.659 .772 .933 r
.8298 .45379 .8344 .45955 .84559 .4562 .84101 .45025 Mtetra
.662 .766 .927 r
.84101 .45025 .84559 .4562 .85682 .45275 .85226 .44664 Mtetra
.663 .762 .923 r
.85226 .44664 .85682 .45275 .86809 .44923 .86355 .44299 Mtetra
.662 .758 .921 r
.86355 .44299 .86809 .44923 .8794 .44567 .87488 .43935 Mtetra
.662 .756 .92 r
.87488 .43935 .8794 .44567 .89074 .44209 .88626 .43571 Mtetra
.661 .754 .919 r
.88626 .43571 .89074 .44209 .90213 .43849 .89768 .43208 Mtetra
.89768 .43208 .90213 .43849 .91357 .43489 .90915 .42846 Mtetra
.652 .75 .922 r
.29453 .60833 .3005 .61354 .30976 .61085 .30381 .60558 Mtetra
.651 .749 .921 r
.30381 .60558 .30976 .61085 .31905 .60817 .31312 .60284 Mtetra
.65 .747 .921 r
.31312 .60284 .31905 .60817 .32837 .60549 .32247 .60013 Mtetra
.648 .746 .921 r
.32247 .60013 .32837 .60549 .33772 .60283 .33184 .59746 Mtetra
.644 .745 .922 r
.33184 .59746 .33772 .60283 .34711 .60017 .34124 .59485 Mtetra
.642 .747 .925 r
.34124 .59485 .34711 .60017 .35654 .59748 .35068 .59226 Mtetra
.64 .751 .929 r
.35068 .59226 .35654 .59748 .366 .59473 .36015 .58971 Mtetra
.642 .76 .934 r
.36015 .58971 .366 .59473 .3755 .59185 .36966 .58707 Mtetra
.648 .772 .939 r
.36966 .58707 .3755 .59185 .38504 .58875 .37921 .58427 Mtetra
.66 .788 .943 r
.37921 .58427 .38504 .58875 .39462 .58538 .38881 .58117 Mtetra
.679 .803 .942 r
.38881 .58117 .39462 .58538 .40425 .58168 .39846 .5776 Mtetra
.697 .813 .937 r
.39846 .5776 .40425 .58168 .41392 .57779 .40815 .5736 Mtetra
.715 .812 .926 r
.40815 .5736 .41392 .57779 .42361 .5738 .41789 .56912 Mtetra
.713 .794 .914 r
.41789 .56912 .42361 .5738 .43333 .5701 .42765 .56465 Mtetra
.699 .763 .902 r
.42765 .56465 .43333 .5701 .44306 .56701 .43744 .56052 Mtetra
.665 .72 .89 r
.43744 .56052 .44306 .56701 .45281 .56474 .44722 .55731 Mtetra
.615 .674 .883 r
.44722 .55731 .45281 .56474 .46258 .56347 .45702 .55541 Mtetra
.576 .64 .877 r
.45702 .55541 .46258 .56347 .47238 .56275 .46684 .55454 Mtetra
.541 .62 .881 r
.46684 .55454 .47238 .56275 .48224 .56227 .4767 .5545 Mtetra
.535 .631 .893 r
.4767 .5545 .48224 .56227 .49214 .56147 .48661 .55447 Mtetra
.552 .664 .911 r
.48661 .55447 .49214 .56147 .5021 .55995 .49657 .55391 Mtetra
.58 .71 .932 r
.49657 .55391 .5021 .55995 .51211 .5577 .5066 .55256 Mtetra
.618 .759 .946 r
.5066 .55256 .51211 .5577 .52216 .55469 .51667 .55024 Mtetra
.644 .796 .956 r
.51667 .55024 .52216 .55469 .53224 .55122 .52679 .54725 Mtetra
.663 .823 .96 r
.52679 .54725 .53224 .55122 .54236 .54749 .53694 .54376 Mtetra
.669 .836 .963 r
.53694 .54376 .54236 .54749 .55251 .5437 .54712 .54008 Mtetra
.667 .841 .966 r
.54712 .54008 .55251 .5437 .5627 .54 .55734 .53639 Mtetra
.66 .84 .969 r
.55734 .53639 .5627 .54 .57292 .53646 .56759 .53282 Mtetra
.649 .837 .973 r
.56759 .53282 .57292 .53646 .58318 .53312 .57789 .52945 Mtetra
.636 .833 .976 r
.57789 .52945 .58318 .53312 .59349 .53 .58822 .52631 Mtetra
.622 .829 .98 r
.58822 .52631 .59349 .53 .60383 .52709 .5986 .52339 Mtetra
.609 .825 .983 r
.5986 .52339 .60383 .52709 .61423 .52439 .60902 .52068 Mtetra
.601 .822 .985 r
.60902 .52068 .61423 .52439 .62466 .52185 .61949 .51809 Mtetra
.601 .821 .984 r
.61949 .51809 .62466 .52185 .63515 .5194 .63001 .5155 Mtetra
.615 .82 .979 r
.63001 .5155 .63515 .5194 .64568 .5169 .64056 .51271 Mtetra
.646 .818 .966 r
.64056 .51271 .64568 .5169 .65624 .51413 .65113 .50942 Mtetra
.681 .808 .943 r
.65113 .50942 .65624 .51413 .66682 .51089 .66171 .50544 Mtetra
.717 .789 .909 r
.66171 .50544 .66682 .51089 .67741 .50689 .67229 .50048 Mtetra
.734 .762 .875 r
.67229 .50048 .67741 .50689 .688 .50213 .68286 .4947 Mtetra
.739 .734 .847 r
.68286 .4947 .688 .50213 .69858 .49665 .69342 .48838 Mtetra
.731 .711 .832 r
.69342 .48838 .69858 .49665 .70916 .49082 .70401 .48205 Mtetra
.708 .692 .832 r
.70401 .48205 .70916 .49082 .71979 .48522 .71467 .47656 Mtetra
.684 .685 .845 r
.71467 .47656 .71979 .48522 .73047 .48018 .72541 .47212 Mtetra
.648 .686 .872 r
.72541 .47212 .73047 .48018 .74126 .47616 .73628 .46902 Mtetra
.614 .699 .905 r
.73628 .46902 .74126 .47616 .75214 .47298 .74725 .46686 Mtetra
.591 .726 .937 r
.74725 .46686 .75214 .47298 .7631 .47042 .7583 .46506 Mtetra
.579 .752 .959 r
.7583 .46506 .7631 .47042 .77414 .46817 .76941 .46326 Mtetra
.596 .779 .968 r
.76941 .46326 .77414 .46817 .78522 .46581 .78053 .46099 Mtetra
.617 .791 .965 r
.78053 .46099 .78522 .46581 .79633 .46326 .79166 .45825 Mtetra
.641 .794 .956 r
.79166 .45825 .79633 .46326 .80747 .46036 .8028 .45504 Mtetra
.657 .788 .944 r
.8028 .45504 .80747 .46036 .81862 .45719 .81396 .45151 Mtetra
.665 .777 .933 r
.81396 .45151 .81862 .45719 .8298 .45379 .82515 .44781 Mtetra
.668 .768 .925 r
.82515 .44781 .8298 .45379 .84101 .45025 .83637 .44402 Mtetra
.667 .76 .92 r
.83637 .44402 .84101 .45025 .85226 .44664 .84764 .44026 Mtetra
.666 .755 .917 r
.84764 .44026 .85226 .44664 .86355 .44299 .85895 .43652 Mtetra
.663 .751 .916 r
.85895 .43652 .86355 .44299 .87488 .43935 .87032 .43284 Mtetra
.661 .75 .916 r
.87032 .43284 .87488 .43935 .88626 .43571 .88173 .4292 Mtetra
.66 .75 .917 r
.88173 .4292 .88626 .43571 .89768 .43208 .89319 .42558 Mtetra
.659 .751 .918 r
.89319 .42558 .89768 .43208 .90915 .42846 .90469 .42197 Mtetra
.656 .751 .92 r
.28853 .60308 .29453 .60833 .30381 .60558 .29783 .60023 Mtetra
.655 .748 .918 r
.29783 .60023 .30381 .60558 .31312 .60284 .30717 .59739 Mtetra
.653 .745 .917 r
.30717 .59739 .31312 .60284 .32247 .60013 .31653 .59458 Mtetra
.65 .741 .916 r
.31653 .59458 .32247 .60013 .33184 .59746 .32593 .59184 Mtetra
.646 .738 .916 r
.32593 .59184 .33184 .59746 .34124 .59485 .33535 .58918 Mtetra
.642 .736 .917 r
.33535 .58918 .34124 .59485 .35068 .59226 .34481 .58662 Mtetra
.636 .735 .92 r
.34481 .58662 .35068 .59226 .36015 .58971 .35429 .58418 Mtetra
.633 .74 .925 r
.35429 .58418 .36015 .58971 .36966 .58707 .36381 .58178 Mtetra
.632 .749 .932 r
.36381 .58178 .36966 .58707 .37921 .58427 .37336 .57937 Mtetra
.64 .767 .94 r
.37336 .57937 .37921 .58427 .38881 .58117 .38296 .57672 Mtetra
.657 .79 .945 r
.38296 .57672 .38881 .58117 .39846 .5776 .39262 .57363 Mtetra
.683 .816 .947 r
.39262 .57363 .39846 .5776 .40815 .5736 .40233 .56992 Mtetra
.716 .835 .938 r
.40233 .56992 .40815 .5736 .41789 .56912 .4121 .56539 Mtetra
.732 .835 .928 r
.4121 .56539 .41789 .56912 .42765 .56465 .42191 .56041 Mtetra
.738 .816 .913 r
.42191 .56041 .42765 .56465 .43744 .56052 .43174 .55521 Mtetra
.711 .772 .9 r
.43174 .55521 .43744 .56052 .44722 .55731 .44159 .5507 Mtetra
.662 .717 .889 r
.44159 .5507 .44722 .55731 .45702 .55541 .45143 .54753 Mtetra
.608 .66 .875 r
.45143 .54753 .45702 .55541 .46684 .55454 .46128 .5458 Mtetra
.55 .612 .868 r
.46128 .5458 .46684 .55454 .4767 .5545 .47114 .54562 Mtetra
.525 .597 .868 r
.47114 .54562 .4767 .5545 .48661 .55447 .48106 .54602 Mtetra
.522 .608 .88 r
.48106 .54602 .48661 .55447 .49657 .55391 .49103 .54639 Mtetra
.541 .645 .901 r
.49103 .54639 .49657 .55391 .5066 .55256 .50106 .54613 Mtetra
.58 .698 .923 r
.50106 .54613 .5066 .55256 .51667 .55024 .51115 .54482 Mtetra
.612 .748 .942 r
.51115 .54482 .51667 .55024 .52679 .54725 .52129 .54265 Mtetra
.641 .791 .954 r
.52129 .54265 .52679 .54725 .53694 .54376 .53147 .53971 Mtetra
.654 .819 .963 r
.53147 .53971 .53694 .54376 .54712 .54008 .54168 .53638 Mtetra
.657 .836 .969 r
.54168 .53638 .54712 .54008 .55734 .53639 .55193 .53287 Mtetra
.653 .844 .973 r
.55193 .53287 .55734 .53639 .56759 .53282 .56222 .52938 Mtetra
.642 .845 .978 r
.56222 .52938 .56759 .53282 .57789 .52945 .57255 .52603 Mtetra
.63 .843 .982 r
.57255 .52603 .57789 .52945 .58822 .52631 .58292 .52287 Mtetra
.618 .839 .984 r
.58292 .52287 .58822 .52631 .5986 .52339 .59333 .51989 Mtetra
.609 .835 .986 r
.59333 .51989 .5986 .52339 .60902 .52068 .60378 .51706 Mtetra
.61 .831 .984 r
.60378 .51706 .60902 .52068 .61949 .51809 .61428 .51425 Mtetra
.624 .827 .978 r
.61428 .51425 .61949 .51809 .63001 .5155 .62481 .51127 Mtetra
.651 .819 .964 r
.62481 .51127 .63001 .5155 .64056 .51271 .63538 .50788 Mtetra
.689 .806 .937 r
.63538 .50788 .64056 .51271 .65113 .50942 .64595 .50371 Mtetra
.718 .781 .902 r
.64595 .50371 .65113 .50942 .66171 .50544 .65652 .49867 Mtetra
.74 .753 .863 r
.65652 .49867 .66171 .50544 .67229 .50048 .66708 .49256 Mtetra
.744 .724 .833 r
.66708 .49256 .67229 .50048 .68286 .4947 .67763 .48579 Mtetra
.735 .698 .816 r
.67763 .48579 .68286 .4947 .69342 .48838 .68819 .47898 Mtetra
.719 .683 .814 r
.68819 .47898 .69342 .48838 .70401 .48205 .69881 .47275 Mtetra
.685 .671 .831 r
.69881 .47275 .70401 .48205 .71467 .47656 .70953 .46808 Mtetra
.649 .676 .862 r
.70953 .46808 .71467 .47656 .72541 .47212 .72037 .4649 Mtetra
.6 .691 .906 r
.72037 .4649 .72541 .47212 .73628 .46902 .73135 .46308 Mtetra
.553 .716 .949 r
.73135 .46308 .73628 .46902 .74725 .46686 .74242 .46198 Mtetra
.541 .756 .976 r
.74242 .46198 .74725 .46686 .7583 .46506 .75354 .46067 Mtetra
.554 .785 .985 r
.75354 .46067 .7583 .46506 .76941 .46326 .76468 .45889 Mtetra
.602 .806 .978 r
.76468 .45889 .76941 .46326 .78053 .46099 .77581 .45626 Mtetra
.64 .806 .963 r
.77581 .45626 .78053 .46099 .79166 .45825 .78694 .45299 Mtetra
.664 .793 .944 r
.78694 .45299 .79166 .45825 .8028 .45504 .79807 .44927 Mtetra
.675 .778 .928 r
.79807 .44927 .8028 .45504 .81396 .45151 .80923 .44529 Mtetra
.675 .763 .917 r
.80923 .44529 .81396 .45151 .82515 .44781 .82042 .4413 Mtetra
.674 .753 .911 r
.82042 .4413 .82515 .44781 .83637 .44402 .83166 .43734 Mtetra
.669 .746 .908 r
.83166 .43734 .83637 .44402 .84764 .44026 .84296 .43351 Mtetra
.665 .743 .908 r
.84296 .43351 .84764 .44026 .85895 .43652 .8543 .42977 Mtetra
.661 .742 .91 r
.8543 .42977 .85895 .43652 .87032 .43284 .8657 .42613 Mtetra
.659 .743 .913 r
.8657 .42613 .87032 .43284 .88173 .4292 .87716 .42254 Mtetra
.657 .746 .915 r
.87716 .42254 .88173 .4292 .89319 .42558 .88866 .41899 Mtetra
.656 .749 .918 r
.88866 .41899 .89319 .42558 .90469 .42197 .90021 .41544 Mtetra
.66 .752 .918 r
.28248 .59781 .28853 .60308 .29783 .60023 .29181 .59483 Mtetra
.66 .749 .915 r
.29181 .59483 .29783 .60023 .30717 .59739 .30117 .59184 Mtetra
.659 .744 .912 r
.30117 .59184 .30717 .59739 .31653 .59458 .31057 .58888 Mtetra
.656 .738 .91 r
.31057 .58888 .31653 .59458 .32593 .59184 .31999 .58597 Mtetra
.652 .732 .908 r
.31999 .58597 .32593 .59184 .33535 .58918 .32944 .58315 Mtetra
.646 .725 .906 r
.32944 .58315 .33535 .58918 .34481 .58662 .33892 .58048 Mtetra
.637 .72 .907 r
.33892 .58048 .34481 .58662 .35429 .58418 .34842 .57802 Mtetra
.629 .717 .91 r
.34842 .57802 .35429 .58418 .36381 .58178 .35795 .57576 Mtetra
.618 .719 .918 r
.35795 .57576 .36381 .58178 .37336 .57937 .36751 .57371 Mtetra
.616 .732 .929 r
.36751 .57371 .37336 .57937 .38296 .57672 .3771 .57164 Mtetra
.621 .757 .943 r
.3771 .57164 .38296 .57672 .39262 .57363 .38675 .56937 Mtetra
.646 .797 .955 r
.38675 .56937 .39262 .57363 .40233 .56992 .39645 .56645 Mtetra
.688 .84 .956 r
.39645 .56645 .40233 .56992 .4121 .56539 .40623 .5625 Mtetra
.729 .871 .947 r
.40623 .5625 .4121 .56539 .42191 .56041 .41607 .55753 Mtetra
.768 .874 .925 r
.41607 .55753 .42191 .56041 .43174 .55521 .42597 .5515 Mtetra
.763 .841 .911 r
.42597 .5515 .43174 .55521 .44159 .5507 .43588 .54555 Mtetra
.729 .784 .897 r
.43588 .54555 .44159 .5507 .45143 .54753 .44579 .54047 Mtetra
.667 .707 .877 r
.44579 .54047 .45143 .54753 .46128 .5458 .45569 .53707 Mtetra
.589 .631 .861 r
.45569 .53707 .46128 .5458 .47114 .54562 .46558 .53589 Mtetra
.54 .585 .848 r
.46558 .53589 .47114 .54562 .48106 .54602 .4755 .53608 Mtetra
.507 .564 .848 r
.4755 .53608 .48106 .54602 .49103 .54639 .48547 .5371 Mtetra
.509 .581 .863 r
.48547 .5371 .49103 .54639 .50106 .54613 .4955 .53792 Mtetra
.537 .624 .886 r
.4955 .53792 .50106 .54613 .51115 .54482 .50559 .53786 Mtetra
.569 .677 .913 r
.50559 .53786 .51115 .54482 .52129 .54265 .51575 .53686 Mtetra
.607 .734 .935 r
.51575 .53686 .52129 .54265 .53147 .53971 .52595 .53483 Mtetra
.629 .778 .953 r
.52595 .53483 .53147 .53971 .54168 .53638 .5362 .53215 Mtetra
.642 .811 .964 r
.5362 .53215 .54168 .53638 .55193 .53287 .54648 .52905 Mtetra
.644 .829 .972 r
.54648 .52905 .55193 .53287 .56222 .52938 .55681 .52578 Mtetra
.639 .839 .977 r
.55681 .52578 .56222 .52938 .57255 .52603 .56717 .52252 Mtetra
.631 .841 .981 r
.56717 .52252 .57255 .52603 .58292 .52287 .57757 .51934 Mtetra
.626 .839 .982 r
.57757 .51934 .58292 .52287 .59333 .51989 .58801 .51624 Mtetra
.627 .835 .98 r
.58801 .51624 .59333 .51989 .60378 .51706 .59849 .51314 Mtetra
.64 .828 .973 r
.59849 .51314 .60378 .51706 .61428 .51425 .60901 .50988 Mtetra
.666 .818 .956 r
.60901 .50988 .61428 .51425 .62481 .51127 .61956 .5062 Mtetra
.696 .798 .928 r
.61956 .5062 .62481 .51127 .63538 .50788 .63012 .50185 Mtetra
.726 .773 .89 r
.63012 .50185 .63538 .50788 .64595 .50371 .64068 .49646 Mtetra
.741 .74 .851 r
.64068 .49646 .64595 .50371 .65652 .49867 .65123 .4901 Mtetra
.747 .71 .817 r
.65123 .4901 .65652 .49867 .66708 .49256 .66176 .48284 Mtetra
.739 .684 .798 r
.66176 .48284 .66708 .49256 .67763 .48579 .6723 .47536 Mtetra
.718 .663 .795 r
.6723 .47536 .67763 .48579 .68819 .47898 .68289 .46872 Mtetra
.692 .656 .809 r
.68289 .46872 .68819 .47898 .69881 .47275 .69358 .46345 Mtetra
.642 .653 .846 r
.69358 .46345 .69881 .47275 .70953 .46808 .70441 .46045 Mtetra
.58 .67 .901 r
.70441 .46045 .70953 .46808 .72037 .4649 .71539 .45917 Mtetra
.507 .705 .959 r
.71539 .45917 .72037 .4649 .73135 .46308 .72648 .45878 Mtetra
.447 .739 .99 r
.72648 .45878 .73135 .46308 .74242 .46198 .73764 .4585 Mtetra
.489 .797 .999 r
.73764 .4585 .74242 .46198 .75354 .46067 .7488 .45713 Mtetra
.564 .829 .995 r
.7488 .45713 .75354 .46067 .76468 .45889 .75993 .45471 Mtetra
.641 .831 .973 r
.75993 .45471 .76468 .45889 .77581 .45626 .77103 .45123 Mtetra
.68 .809 .944 r
.77103 .45123 .77581 .45626 .78694 .45299 .78213 .44707 Mtetra
.689 .778 .92 r
.78213 .44707 .78694 .45299 .79807 .44927 .79324 .4427 Mtetra
.689 .757 .903 r
.79324 .4427 .79807 .44927 .80923 .44529 .8044 .4383 Mtetra
.68 .74 .896 r
.8044 .4383 .80923 .44529 .82042 .4413 .81561 .43412 Mtetra
.673 .732 .895 r
.81561 .43412 .82042 .4413 .83166 .43734 .82688 .43014 Mtetra
.665 .729 .897 r
.82688 .43014 .83166 .43734 .84296 .43351 .83821 .42637 Mtetra
.66 .73 .901 r
.83821 .42637 .84296 .43351 .8543 .42977 .8496 .42276 Mtetra
.656 .733 .906 r
.8496 .42276 .8543 .42977 .8657 .42613 .86105 .41923 Mtetra
.654 .737 .911 r
.86105 .41923 .8657 .42613 .87716 .42254 .87254 .41577 Mtetra
.652 .741 .915 r
.87254 .41577 .87716 .42254 .88866 .41899 .88409 .41233 Mtetra
.652 .746 .918 r
.88409 .41233 .88866 .41899 .90021 .41544 .89569 .40886 Mtetra
.663 .753 .917 r
.27639 .59249 .28248 .59781 .29181 .59483 .28575 .58942 Mtetra
.665 .751 .914 r
.28575 .58942 .29181 .59483 .30117 .59184 .29514 .58631 Mtetra
.665 .747 .912 r
.29514 .58631 .30117 .59184 .31057 .58888 .30456 .5832 Mtetra
.663 .742 .909 r
.30456 .5832 .31057 .58888 .31999 .58597 .31402 .5801 Mtetra
.661 .736 .905 r
.31402 .5801 .31999 .58597 .32944 .58315 .3235 .57704 Mtetra
.656 .727 .901 r
.3235 .57704 .32944 .58315 .33892 .58048 .33301 .57412 Mtetra
.647 .716 .899 r
.33301 .57412 .33892 .58048 .34842 .57802 .34254 .57141 Mtetra
.635 .705 .897 r
.34254 .57141 .34842 .57802 .35795 .57576 .35209 .569 Mtetra
.617 .695 .9 r
.35209 .569 .35795 .57576 .36751 .57371 .36166 .56701 Mtetra
.605 .693 .905 r
.36166 .56701 .36751 .57371 .3771 .57164 .37125 .56528 Mtetra
.591 .701 .919 r
.37125 .56528 .3771 .57164 .38675 .56937 .38088 .56379 Mtetra
.602 .733 .937 r
.38088 .56379 .38675 .56937 .39645 .56645 .39057 .56193 Mtetra
.633 .785 .955 r
.39057 .56193 .39645 .56645 .40623 .5625 .40032 .55926 Mtetra
.688 .852 .961 r
.40032 .55926 .40623 .5625 .41607 .55753 .41016 .55524 Mtetra
.757 .899 .94 r
.41016 .55524 .41607 .55753 .42597 .5515 .42009 .54942 Mtetra
.787 .908 .924 r
.42009 .54942 .42597 .5515 .43588 .54555 .43006 .54274 Mtetra
.794 .879 .908 r
.43006 .54274 .43588 .54555 .44579 .54047 .44005 .53578 Mtetra
.747 .805 .899 r
.44005 .53578 .44579 .54047 .45569 .53707 .45003 .53014 Mtetra
.664 .711 .883 r
.45003 .53014 .45569 .53707 .46558 .53589 .45998 .52682 Mtetra
.591 .625 .854 r
.45998 .52682 .46558 .53589 .4755 .53608 .46993 .52555 Mtetra
.526 .562 .835 r
.46993 .52555 .4755 .53608 .48547 .5371 .4799 .52619 Mtetra
.507 .545 .83 r
.4799 .52619 .48547 .5371 .4955 .53792 .48993 .52742 Mtetra
.512 .557 .838 r
.48993 .52742 .4955 .53792 .50559 .53786 .50002 .52841 Mtetra
.534 .592 .858 r
.50002 .52841 .50559 .53786 .51575 .53686 .51018 .52866 Mtetra
.57 .642 .882 r
.51018 .52866 .51575 .53686 .52595 .53483 .5204 .5278 Mtetra
.599 .69 .906 r
.5204 .5278 .52595 .53483 .5362 .53215 .53067 .5261 Mtetra
.624 .734 .926 r
.53067 .5261 .5362 .53215 .54648 .52905 .54098 .52369 Mtetra
.637 .765 .94 r
.54098 .52369 .54648 .52905 .55681 .52578 .55134 .52086 Mtetra
.645 .786 .949 r
.55134 .52086 .55681 .52578 .56717 .52252 .56173 .5178 Mtetra
.649 .796 .953 r
.56173 .5178 .56717 .52252 .57757 .51934 .57216 .5146 Mtetra
.654 .797 .951 r
.57216 .5146 .57757 .51934 .58801 .51624 .58263 .51126 Mtetra
.666 .792 .942 r
.58263 .51126 .58801 .51624 .59849 .51314 .59313 .50767 Mtetra
.683 .779 .924 r
.59313 .50767 .59849 .51314 .60901 .50988 .60366 .50368 Mtetra
.706 .761 .895 r
.60366 .50368 .60901 .50988 .61956 .5062 .6142 .49896 Mtetra
.723 .735 .86 r
.6142 .49896 .61956 .5062 .63012 .50185 .62475 .49337 Mtetra
.737 .708 .824 r
.62475 .49337 .63012 .50185 .64068 .49646 .63529 .48668 Mtetra
.739 .683 .797 r
.63529 .48668 .64068 .49646 .65123 .4901 .64582 .4792 Mtetra
.733 .662 .78 r
.64582 .4792 .65123 .4901 .66176 .48284 .65636 .47148 Mtetra
.719 .649 .778 r
.65636 .47148 .66176 .48284 .6723 .47536 .66693 .46433 Mtetra
.686 .64 .797 r
.66693 .46433 .6723 .47536 .68289 .46872 .6776 .45911 Mtetra
.644 .648 .839 r
.6776 .45911 .68289 .46872 .69358 .46345 .68841 .45598 Mtetra
.555 .664 .91 r
.68841 .45598 .69358 .46345 .70441 .46045 .69939 .45523 Mtetra
.423 .685 .972 r
.69939 .45523 .70441 .46045 .71539 .45917 .71051 .45582 Mtetra
.331 .72 .983 r
.71051 .45582 .71539 .45917 .72648 .45878 .72168 .45616 Mtetra
.357 .766 .981 r
.72168 .45616 .72648 .45878 .73764 .4585 .73286 .45561 Mtetra
.533 .845 .999 r
.73286 .45561 .73764 .4585 .7488 .45713 .74399 .45322 Mtetra
.651 .847 .975 r
.74399 .45322 .7488 .45713 .75993 .45471 .75506 .44944 Mtetra
.698 .806 .932 r
.75506 .44944 .75993 .45471 .77103 .45123 .76612 .44482 Mtetra
.708 .769 .899 r
.76612 .44482 .77103 .45123 .78213 .44707 .77718 .43982 Mtetra
.697 .738 .883 r
.77718 .43982 .78213 .44707 .79324 .4427 .7883 .43504 Mtetra
.687 .723 .877 r
.7883 .43504 .79324 .4427 .8044 .4383 .79947 .43053 Mtetra
.674 .715 .88 r
.79947 .43053 .8044 .4383 .81561 .43412 .81072 .42646 Mtetra
.664 .715 .886 r
.81072 .42646 .81561 .43412 .82688 .43014 .82204 .42269 Mtetra
.657 .719 .895 r
.82204 .42269 .82688 .43014 .83821 .42637 .83342 .41914 Mtetra
.652 .725 .902 r
.83342 .41914 .83821 .42637 .8496 .42276 .84487 .41573 Mtetra
.65 .732 .909 r
.84487 .41573 .8496 .42276 .86105 .41923 .85636 .41236 Mtetra
.649 .737 .914 r
.85636 .41236 .86105 .41923 .87254 .41577 .86791 .40901 Mtetra
.648 .742 .918 r
.86791 .40901 .87254 .41577 .88409 .41233 .8795 .40565 Mtetra
.649 .746 .92 r
.8795 .40565 .88409 .41233 .89569 .40886 .89113 .40224 Mtetra
.664 .753 .917 r
.27027 .58715 .27639 .59249 .28575 .58942 .27964 .58405 Mtetra
.666 .753 .916 r
.27964 .58405 .28575 .58942 .29514 .58631 .28906 .58089 Mtetra
.668 .753 .914 r
.28906 .58089 .29514 .58631 .30456 .5832 .29851 .57767 Mtetra
.669 .75 .911 r
.29851 .57767 .30456 .5832 .31402 .5801 .30799 .5744 Mtetra
.671 .745 .906 r
.30799 .5744 .31402 .5801 .3235 .57704 .31751 .57107 Mtetra
.669 .736 .9 r
.31751 .57107 .3235 .57704 .33301 .57412 .32706 .56777 Mtetra
.664 .723 .893 r
.32706 .56777 .33301 .57412 .34254 .57141 .33663 .56458 Mtetra
.652 .705 .886 r
.33663 .56458 .34254 .57141 .35209 .569 .34622 .5617 Mtetra
.633 .685 .881 r
.34622 .5617 .35209 .569 .36166 .56701 .35583 .5593 Mtetra
.611 .666 .879 r
.35583 .5593 .36166 .56701 .37125 .56528 .36544 .55749 Mtetra
.58 .652 .885 r
.36544 .55749 .37125 .56528 .38088 .56379 .37506 .55643 Mtetra
.565 .659 .9 r
.37506 .55643 .38088 .56379 .39057 .56193 .38471 .55562 Mtetra
.556 .692 .93 r
.38471 .55562 .39057 .56193 .40032 .55926 .39442 .55475 Mtetra
.599 .778 .966 r
.39442 .55475 .40032 .55926 .41016 .55524 .40422 .55264 Mtetra
.686 .881 .971 r
.40422 .55264 .41016 .55524 .42009 .54942 .41413 .54844 Mtetra
.755 .949 .942 r
.41413 .54844 .42009 .54942 .43006 .54274 .42412 .54223 Mtetra
.822 .96 .901 r
.42412 .54223 .43006 .54274 .44005 .53578 .43419 .53405 Mtetra
.823 .919 .901 r
.43419 .53405 .44005 .53578 .45003 .53014 .44426 .52606 Mtetra
.773 .833 .899 r
.44426 .52606 .45003 .53014 .45998 .52682 .45431 .51963 Mtetra
.685 .712 .869 r
.45431 .51963 .45998 .52682 .46993 .52555 .46432 .51558 Mtetra
.587 .605 .837 r
.46432 .51558 .46993 .52555 .4799 .52619 .47433 .51446 Mtetra
.537 .546 .812 r
.47433 .51446 .4799 .52619 .48993 .52742 .48436 .51497 Mtetra
.511 .52 .802 r
.48436 .51497 .48993 .52742 .50002 .52841 .49445 .51636 Mtetra
.515 .53 .81 r
.49445 .51636 .50002 .52841 .51018 .52866 .5046 .51757 Mtetra
.539 .561 .826 r
.5046 .51757 .51018 .52866 .5204 .5278 .51482 .51794 Mtetra
.565 .6 .847 r
.51482 .51794 .5204 .5278 .53067 .5261 .5251 .51741 Mtetra
.596 .643 .867 r
.5251 .51741 .53067 .5261 .54098 .52369 .53543 .5159 Mtetra
.619 .678 .884 r
.53543 .5159 .54098 .52369 .55134 .52086 .54581 .51371 Mtetra
.639 .705 .894 r
.54581 .51371 .55134 .52086 .56173 .5178 .55623 .51094 Mtetra
.655 .721 .897 r
.55623 .51094 .56173 .5178 .57216 .5146 .56668 .50771 Mtetra
.671 .726 .891 r
.56668 .50771 .57216 .5146 .58263 .51126 .57717 .50403 Mtetra
.687 .722 .877 r
.57717 .50403 .58263 .51126 .59313 .50767 .58768 .49977 Mtetra
.702 .71 .854 r
.58768 .49977 .59313 .50767 .60366 .50368 .59821 .4948 Mtetra
.718 .693 .825 r
.59821 .4948 .60366 .50368 .6142 .49896 .60874 .48886 Mtetra
.725 .671 .797 r
.60874 .48886 .6142 .49896 .62475 .49337 .61928 .48199 Mtetra
.728 .652 .774 r
.61928 .48199 .62475 .49337 .63529 .48668 .6298 .47426 Mtetra
.723 .636 .76 r
.6298 .47426 .63529 .48668 .64582 .4792 .64033 .46633 Mtetra
.706 .622 .761 r
.64033 .46633 .64582 .4792 .65636 .47148 .6509 .45927 Mtetra
.682 .62 .78 r
.6509 .45927 .65636 .47148 .66693 .46433 .66156 .45386 Mtetra
.622 .621 .828 r
.66156 .45386 .66693 .46433 .6776 .45911 .67238 .45142 Mtetra
.522 .642 .909 r
.67238 .45142 .6776 .45911 .68841 .45598 .68336 .45142 Mtetra
.3 .648 .969 r
.68336 .45142 .68841 .45598 .69939 .45523 .6945 .45303 Mtetra
.055 .582 .866 r
.6945 .45303 .69939 .45523 .71051 .45582 .70572 .45484 Mtetra
.142 .678 .849 r
.70572 .45484 .71051 .45582 .72168 .45616 .7169 .45465 Mtetra
.422 .842 .961 r
.7169 .45465 .72168 .45616 .73286 .45561 .72802 .45241 Mtetra
.669 .883 .977 r
.72802 .45241 .73286 .45561 .74399 .45322 .73906 .44801 Mtetra
.734 .819 .917 r
.73906 .44801 .74399 .45322 .75506 .44944 .75004 .44233 Mtetra
.725 .752 .874 r
.75004 .44233 .75506 .44944 .76612 .44482 .76104 .43657 Mtetra
.71 .716 .853 r
.76104 .43657 .76612 .44482 .77718 .43982 .77209 .43107 Mtetra
.687 .695 .851 r
.77209 .43107 .77718 .43982 .7883 .43504 .78324 .42633 Mtetra
.671 .69 .859 r
.78324 .42633 .7883 .43504 .79947 .43053 .79447 .4222 Mtetra
.658 .694 .872 r
.79447 .4222 .79947 .43053 .81072 .42646 .80578 .41857 Mtetra
.648 .703 .887 r
.80578 .41857 .81072 .42646 .82204 .42269 .81717 .41525 Mtetra
.645 .716 .9 r
.81717 .41525 .82204 .42269 .83342 .41914 .82862 .41204 Mtetra
.642 .727 .91 r
.82862 .41204 .83342 .41914 .84487 .41573 .84012 .40887 Mtetra
.644 .736 .916 r
.84012 .40887 .84487 .41573 .85636 .41236 .85166 .40564 Mtetra
.645 .742 .92 r
.85166 .40564 .85636 .41236 .86791 .40901 .86325 .40234 Mtetra
.647 .746 .922 r
.86325 .40234 .86791 .40901 .8795 .40565 .87488 .39899 Mtetra
.649 .748 .922 r
.87488 .39899 .8795 .40565 .89113 .40224 .88655 .39556 Mtetra
.66 .752 .919 r
.2641 .58177 .27027 .58715 .27964 .58405 .27349 .57874 Mtetra
.662 .756 .92 r
.27349 .57874 .27964 .58405 .28906 .58089 .28292 .57565 Mtetra
.665 .76 .921 r
.28292 .57565 .28906 .58089 .29851 .57767 .29238 .57247 Mtetra
.67 .763 .921 r
.29238 .57247 .29851 .57767 .30799 .5744 .30189 .56917 Mtetra
.676 .764 .917 r
.30189 .56917 .30799 .5744 .31751 .57107 .31144 .5657 Mtetra
.68 .761 .913 r
.31144 .5657 .31751 .57107 .32706 .56777 .32103 .56212 Mtetra
.683 .752 .904 r
.32103 .56212 .32706 .56777 .33663 .56458 .33065 .55845 Mtetra
.676 .735 .895 r
.33065 .55845 .33663 .56458 .34622 .5617 .34029 .55491 Mtetra
.663 .712 .884 r
.34029 .55491 .34622 .5617 .35583 .5593 .34995 .55168 Mtetra
.638 .68 .873 r
.34995 .55168 .35583 .5593 .36544 .55749 .35962 .54912 Mtetra
.601 .646 .867 r
.35962 .54912 .36544 .55749 .37506 .55643 .36927 .54755 Mtetra
.567 .619 .863 r
.36927 .54755 .37506 .55643 .38471 .55562 .37893 .54689 Mtetra
.524 .603 .874 r
.37893 .54689 .38471 .55562 .39442 .55475 .38859 .54715 Mtetra
.53 .639 .903 r
.38859 .54715 .39442 .55475 .40422 .55264 .39833 .54704 Mtetra
.574 .728 .947 r
.39833 .54704 .40422 .55264 .41413 .54844 .40817 .54562 Mtetra
.669 .87 .975 r
.40817 .54562 .41413 .54844 .42412 .54223 .41813 .54175 Mtetra
.781 .965 .922 r
.41813 .54175 .42412 .54223 .43419 .53405 .42821 .53465 Mtetra
.814 .988 .88 r
.42821 .53465 .43419 .53405 .44426 .52606 .43835 .52604 Mtetra
.839 .972 .881 r
.43835 .52604 .44426 .52606 .45431 .51963 .4485 .51702 Mtetra
.804 .892 .907 r
.4485 .51702 .45431 .51963 .46432 .51558 .45861 .50966 Mtetra
.703 .759 .896 r
.45861 .50966 .46432 .51558 .47433 .51446 .4687 .5052 Mtetra
.617 .636 .847 r
.4687 .5052 .47433 .51446 .48436 .51497 .47877 .50314 Mtetra
.551 .553 .81 r
.47877 .50314 .48436 .51497 .49445 .51636 .48887 .50319 Mtetra
.532 .522 .79 r
.48887 .50319 .49445 .51636 .5046 .51757 .49902 .50399 Mtetra
.536 .519 .784 r
.49902 .50399 .5046 .51757 .51482 .51794 .50923 .50472 Mtetra
.551 .534 .789 r
.50923 .50472 .51482 .51794 .5251 .51741 .51951 .50489 Mtetra
.577 .558 .797 r
.51951 .50489 .5251 .51741 .53543 .5159 .52985 .50412 Mtetra
.6 .582 .805 r
.52985 .50412 .53543 .5159 .54581 .51371 .54023 .50251 Mtetra
.623 .604 .811 r
.54023 .50251 .54581 .51371 .55623 .51094 .55066 .50003 Mtetra
.644 .62 .811 r
.55066 .50003 .55623 .51094 .56668 .50771 .56112 .49677 Mtetra
.662 .628 .806 r
.56112 .49677 .56668 .50771 .57717 .50403 .57161 .49275 Mtetra
.678 .631 .794 r
.57161 .49275 .57717 .50403 .58768 .49977 .58213 .48785 Mtetra
.691 .627 .78 r
.58213 .48785 .58768 .49977 .59821 .4948 .59265 .48209 Mtetra
.702 .621 .764 r
.59265 .48209 .59821 .4948 .60874 .48886 .60318 .47538 Mtetra
.705 .614 .753 r
.60318 .47538 .60874 .48886 .61928 .48199 .61371 .46808 Mtetra
.703 .609 .748 r
.61371 .46808 .61928 .48199 .6298 .47426 .62425 .4607 Mtetra
.694 .608 .756 r
.62425 .4607 .6298 .47426 .64033 .46633 .63484 .45408 Mtetra
.664 .611 .785 r
.63484 .45408 .64033 .46633 .6509 .45927 .64552 .44958 Mtetra
.612 .633 .847 r
.64552 .44958 .6509 .45927 .66156 .45386 .65633 .44751 Mtetra
.44 .649 .947 r
.65633 .44751 .66156 .45386 .67238 .45142 .66732 .4484 Mtetra
.052 .552 .884 r
.66732 .4484 .67238 .45142 .68336 .45142 .67846 .451 Mtetra
.194 0 0 r
.67846 .451 .68336 .45142 .6945 .45303 .68967 .4532 Mtetra
.096 0 0 r
.68967 .4532 .6945 .45303 .70572 .45484 .70088 .45388 Mtetra
.408 .848 .932 r
.70088 .45388 .70572 .45484 .7169 .45465 .71197 .45125 Mtetra
.708 .885 .963 r
.71197 .45125 .7169 .45465 .72802 .45241 .72295 .44611 Mtetra
.751 .785 .881 r
.72295 .44611 .72802 .45241 .73906 .44801 .73388 .43961 Mtetra
.741 .723 .835 r
.73388 .43961 .73906 .44801 .75004 .44233 .74481 .4327 Mtetra
.71 .684 .823 r
.74481 .4327 .75004 .44233 .76104 .43657 .75582 .42675 Mtetra
.688 .671 .828 r
.75582 .42675 .76104 .43657 .77209 .43107 .76694 .42171 Mtetra
.665 .672 .847 r
.76694 .42171 .77209 .43107 .78324 .42633 .77816 .41771 Mtetra
.648 .683 .869 r
.77816 .41771 .78324 .42633 .79447 .4222 .78949 .41439 Mtetra
.638 .702 .892 r
.78949 .41439 .79447 .4222 .80578 .41857 .80088 .41138 Mtetra
.631 .719 .91 r
.80088 .41138 .80578 .41857 .81717 .41525 .81234 .40853 Mtetra
.633 .736 .922 r
.81234 .40853 .81717 .41525 .82862 .41204 .82385 .40557 Mtetra
.636 .747 .929 r
.82385 .40557 .82862 .41204 .84012 .40887 .83539 .40249 Mtetra
.642 .754 .93 r
.83539 .40249 .84012 .40887 .85166 .40564 .84697 .39924 Mtetra
.646 .756 .929 r
.84697 .39924 .85166 .40564 .86325 .40234 .85858 .39586 Mtetra
.649 .756 .927 r
.85858 .39586 .86325 .40234 .87488 .39899 .87023 .39239 Mtetra
.652 .753 .924 r
.87023 .39239 .87488 .39899 .88655 .39556 .88193 .38884 Mtetra
.652 .75 .922 r
.25789 .57635 .2641 .58177 .27349 .57874 .26729 .57349 Mtetra
.652 .758 .927 r
.26729 .57349 .27349 .57874 .28292 .57565 .27672 .5706 Mtetra
.656 .766 .931 r
.27672 .5706 .28292 .57565 .29238 .57247 .28619 .56761 Mtetra
.662 .776 .934 r
.28619 .56761 .29238 .57247 .30189 .56917 .29571 .56445 Mtetra
.671 .784 .934 r
.29571 .56445 .30189 .56917 .31144 .5657 .30528 .56107 Mtetra
.681 .791 .932 r
.30528 .56107 .31144 .5657 .32103 .56212 .31489 .55743 Mtetra
.695 .791 .924 r
.31489 .55743 .32103 .56212 .33065 .55845 .32456 .55343 Mtetra
.701 .781 .914 r
.32456 .55343 .33065 .55845 .34029 .55491 .33426 .54926 Mtetra
.703 .759 .896 r
.33426 .54926 .34029 .55491 .34995 .55168 .344 .54495 Mtetra
.685 .722 .877 r
.344 .54495 .34995 .55168 .35962 .54912 .35375 .54105 Mtetra
.654 .675 .858 r
.35375 .54105 .35962 .54912 .36927 .54755 .36348 .53795 Mtetra
.608 .621 .838 r
.36348 .53795 .36927 .54755 .37893 .54689 .3732 .53619 Mtetra
.544 .568 .829 r
.3732 .53619 .37893 .54689 .38859 .54715 .38287 .53629 Mtetra
.501 .544 .832 r
.38287 .53629 .38859 .54715 .39833 .54704 .39256 .53749 Mtetra
.456 .55 .863 r
.39256 .53749 .39833 .54704 .40817 .54562 .40229 .53928 Mtetra
.498 .671 .941 r
.40229 .53928 .40817 .54562 .41813 .54175 .41214 .5393 Mtetra
.627 .878 .988 r
.41214 .5393 .41813 .54175 .42821 .53465 .42215 .53589 Mtetra
.677 .978 .872 r
.42215 .53589 .42821 .53465 .43835 .52604 .43228 .52918 Mtetra
.751 .986 .761 r
.43228 .52918 .43835 .52604 .4485 .51702 .44252 .51926 Mtetra
.812 1 .807 r
.44252 .51926 .4485 .51702 .45861 .50966 .45275 .50906 Mtetra
.834 .961 .892 r
.45275 .50906 .45861 .50966 .4687 .5052 .46295 .50036 Mtetra
.761 .809 .891 r
.46295 .50036 .4687 .5052 .47877 .50314 .47312 .49411 Mtetra
.65 .657 .843 r
.47312 .49411 .47877 .50314 .48887 .50319 .48327 .49093 Mtetra
.592 .569 .797 r
.48327 .49093 .48887 .50319 .49902 .50399 .49344 .48959 Mtetra
.562 .524 .77 r
.49344 .48959 .49902 .50399 .50923 .50472 .50365 .48939 Mtetra
.56 .512 .759 r
.50365 .48939 .50923 .50472 .51951 .50489 .51391 .48934 Mtetra
.572 .517 .756 r
.51391 .48934 .51951 .50489 .52985 .50412 .52424 .48878 Mtetra
.589 .53 .756 r
.52424 .48878 .52985 .50412 .54023 .50251 .53462 .48746 Mtetra
.61 .545 .757 r
.53462 .48746 .54023 .50251 .55066 .50003 .54504 .48515 Mtetra
.63 .558 .755 r
.54504 .48515 .55066 .50003 .56112 .49677 .55551 .48187 Mtetra
.648 .568 .751 r
.55551 .48187 .56112 .49677 .57161 .49275 .566 .4776 Mtetra
.663 .574 .745 r
.566 .4776 .57161 .49275 .58213 .48785 .5765 .47235 Mtetra
.674 .577 .738 r
.5765 .47235 .58213 .48785 .59265 .48209 .58702 .46632 Mtetra
.68 .578 .734 r
.58702 .46632 .59265 .48209 .60318 .47538 .59756 .45977 Mtetra
.679 .579 .736 r
.59756 .45977 .60318 .47538 .61371 .46808 .60811 .45334 Mtetra
.665 .58 .75 r
.60811 .45334 .61371 .46808 .62425 .4607 .61872 .44807 Mtetra
.639 .593 .786 r
.61872 .44807 .62425 .4607 .63484 .45408 .62942 .44467 Mtetra
.55 .609 .865 r
.62942 .44467 .63484 .45408 .64552 .44958 .64027 .44436 Mtetra
.282 .61 .955 r
.64027 .44436 .64552 .44958 .65633 .44751 .65128 .44657 Mtetra
.3 0 0 r
.65128 .44657 .65633 .44751 .66732 .4484 .66243 .45031 Mtetra
.459 0 0 r
.66243 .45031 .66732 .4484 .67846 .451 .67366 .45381 Mtetra
.278 0 0 r
.67366 .45381 .67846 .451 .68967 .4532 .68482 .45404 Mtetra
.26 .767 .756 r
.68482 .45404 .68967 .4532 .70088 .45388 .69588 .45089 Mtetra
.764 .912 .939 r
.69588 .45089 .70088 .45388 .71197 .45125 .70679 .44424 Mtetra
.787 .772 .84 r
.70679 .44424 .71197 .45125 .72295 .44611 .7176 .43574 Mtetra
.741 .682 .794 r
.7176 .43574 .72295 .44611 .73388 .43961 .72847 .42783 Mtetra
.709 .645 .784 r
.72847 .42783 .73388 .43961 .74481 .4327 .73942 .42104 Mtetra
.673 .63 .799 r
.73942 .42104 .74481 .4327 .75582 .42675 .75053 .41616 Mtetra
.646 .637 .827 r
.75053 .41616 .75582 .42675 .76694 .42171 .76177 .41266 Mtetra
.627 .663 .865 r
.76177 .41266 .76694 .42171 .77816 .41771 .77313 .41 Mtetra
.61 .693 .902 r
.77313 .41 .77816 .41771 .78949 .41439 .78457 .40774 Mtetra
.609 .729 .93 r
.78457 .40774 .78949 .41439 .80088 .41138 .79605 .40536 Mtetra
.612 .754 .946 r
.79605 .40536 .80088 .41138 .81234 .40853 .80757 .40279 Mtetra
.624 .771 .951 r
.80757 .40279 .81234 .40853 .82385 .40557 .81911 .39986 Mtetra
.635 .778 .949 r
.81911 .39986 .82385 .40557 .83539 .40249 .83068 .39665 Mtetra
.646 .778 .944 r
.83068 .39665 .83539 .40249 .84697 .39924 .84228 .39319 Mtetra
.653 .774 .937 r
.84228 .39319 .84697 .39924 .85858 .39586 .8539 .38957 Mtetra
.657 .767 .931 r
.8539 .38957 .85858 .39586 .87023 .39239 .86557 .38584 Mtetra
.659 .76 .924 r
.86557 .38584 .87023 .39239 .88193 .38884 .87727 .38207 Mtetra
.643 .748 .925 r
.25164 .57089 .25789 .57635 .26729 .57349 .26104 .56821 Mtetra
.642 .755 .931 r
.26104 .56821 .26729 .57349 .27672 .5706 .27048 .56553 Mtetra
.643 .764 .937 r
.27048 .56553 .27672 .5706 .28619 .56761 .27995 .5628 Mtetra
.647 .776 .942 r
.27995 .5628 .28619 .56761 .29571 .56445 .28947 .55994 Mtetra
.653 .79 .947 r
.28947 .55994 .29571 .56445 .30528 .56107 .29904 .55689 Mtetra
.666 .807 .95 r
.29904 .55689 .30528 .56107 .31489 .55743 .30866 .55353 Mtetra
.685 .822 .949 r
.30866 .55353 .31489 .55743 .32456 .55343 .31834 .54971 Mtetra
.704 .833 .944 r
.31834 .54971 .32456 .55343 .33426 .54926 .32808 .54543 Mtetra
.726 .832 .93 r
.32808 .54543 .33426 .54926 .344 .54495 .33788 .54057 Mtetra
.73 .812 .915 r
.33788 .54057 .344 .54495 .35375 .54105 .34771 .53556 Mtetra
.721 .772 .893 r
.34771 .53556 .35375 .54105 .36348 .53795 .35756 .53066 Mtetra
.68 .706 .868 r
.35756 .53066 .36348 .53795 .3732 .53619 .36738 .5268 Mtetra
.617 .631 .842 r
.36738 .5268 .3732 .53619 .38287 .53629 .37716 .52474 Mtetra
.548 .556 .814 r
.37716 .52474 .38287 .53629 .39256 .53749 .38689 .52479 Mtetra
.465 .491 .801 r
.38689 .52479 .39256 .53749 .40229 .53928 .39658 .52727 Mtetra
.45 .495 .814 r
.39658 .52727 .40229 .53928 .41214 .5393 .40634 .52992 Mtetra
.478 .568 .868 r
.40634 .52992 .41214 .5393 .42215 .53589 .41621 .53121 Mtetra
.59 .775 .968 r
.41621 .53121 .42215 .53589 .43228 .52918 .42624 .52917 Mtetra
.736 .976 .923 r
.42624 .52917 .43228 .52918 .44252 .51926 .43644 .52255 Mtetra
.688 .966 .742 r
.43644 .52255 .44252 .51926 .45275 .50906 .44671 .51337 Mtetra
.688 .947 .674 r
.44671 .51337 .45275 .50906 .46295 .50036 .45701 .50286 Mtetra
.759 .992 .791 r
.45701 .50286 .46295 .50036 .47312 .49411 .46729 .49332 Mtetra
.783 .963 .923 r
.46729 .49332 .47312 .49411 .48327 .49093 .47754 .48609 Mtetra
.726 .808 .916 r
.47754 .48609 .48327 .49093 .49344 .48959 .48777 .481 Mtetra
.647 .668 .856 r
.48777 .481 .49344 .48959 .50365 .48939 .49802 .47793 Mtetra
.612 .594 .808 r
.49802 .47793 .50365 .48939 .51391 .48934 .5083 .47584 Mtetra
.6 .557 .779 r
.5083 .47584 .51391 .48934 .52424 .48878 .51863 .47409 Mtetra
.603 .545 .762 r
.51863 .47409 .52424 .48878 .53462 .48746 .529 .4721 Mtetra
.614 .544 .753 r
.529 .4721 .53462 .48746 .54504 .48515 .53942 .46952 Mtetra
.627 .549 .747 r
.53942 .46952 .54504 .48515 .55551 .48187 .54987 .4662 Mtetra
.64 .557 .744 r
.54987 .4662 .55551 .48187 .566 .4776 .56036 .46215 Mtetra
.651 .565 .745 r
.56036 .46215 .566 .4776 .5765 .47235 .57088 .4575 Mtetra
.658 .575 .75 r
.57088 .4575 .5765 .47235 .58702 .46632 .58142 .45261 Mtetra
.658 .588 .765 r
.58142 .45261 .58702 .46632 .59756 .45977 .59201 .44805 Mtetra
.646 .611 .799 r
.59201 .44805 .59756 .45977 .60811 .45334 .60264 .44448 Mtetra
.592 .644 .871 r
.60264 .44448 .60811 .45334 .61872 .44807 .61338 .44295 Mtetra
.405 .684 .975 r
.61338 .44295 .61872 .44807 .62942 .44467 .62423 .44359 Mtetra
.222 0 0 r
.62423 .44359 .62942 .44467 .64027 .44436 .63523 .4466 Mtetra
.502 0 0 r
.63523 .4466 .64027 .44436 .65128 .44657 .64636 .45061 Mtetra
.479 0 0 r
.64636 .45061 .65128 .44657 .66243 .45031 .65752 .4533 Mtetra
.276 0 0 r
.65752 .4533 .66243 .45031 .67366 .45381 .66865 .45338 Mtetra
.544 .923 .921 r
.66865 .45338 .67366 .45381 .68482 .45404 .67963 .4488 Mtetra
.795 .829 .878 r
.67963 .4488 .68482 .45404 .69588 .45089 .69048 .4408 Mtetra
.767 .697 .785 r
.69048 .4408 .69588 .45089 .70679 .44424 .70126 .43139 Mtetra
.739 .644 .754 r
.70126 .43139 .70679 .44424 .7176 .43574 .71205 .42213 Mtetra
.695 .614 .761 r
.71205 .42213 .7176 .43574 .72847 .42783 .723 .41535 Mtetra
.663 .613 .788 r
.723 .41535 .72847 .42783 .73942 .42104 .7341 .41073 Mtetra
.627 .634 .838 r
.7341 .41073 .73942 .42104 .75053 .41616 .74538 .40796 Mtetra
.59 .669 .894 r
.74538 .40796 .75053 .41616 .76177 .41266 .75678 .40628 Mtetra
.57 .721 .944 r
.75678 .40628 .76177 .41266 .77313 .41 .76825 .40471 Mtetra
.558 .76 .972 r
.76825 .40471 .77313 .41 .78457 .40774 .77976 .40299 Mtetra
.578 .792 .98 r
.77976 .40299 .78457 .40774 .79605 .40536 .79129 .40068 Mtetra
.602 .806 .978 r
.79129 .40068 .79605 .40536 .80757 .40279 .80284 .39788 Mtetra
.629 .808 .969 r
.80284 .39788 .80757 .40279 .81911 .39986 .81439 .39461 Mtetra
.647 .802 .957 r
.81439 .39461 .81911 .39986 .83068 .39665 .82596 .391 Mtetra
.658 .792 .946 r
.82596 .391 .83068 .39665 .84228 .39319 .83756 .38719 Mtetra
.664 .782 .936 r
.83756 .38719 .84228 .39319 .8539 .38957 .84919 .38325 Mtetra
.667 .772 .928 r
.84919 .38325 .8539 .38957 .86557 .38584 .86087 .37924 Mtetra
.666 .763 .922 r
.86087 .37924 .86557 .38584 .87727 .38207 .87259 .37524 Mtetra
.638 .747 .927 r
.24535 .5654 .25164 .57089 .26104 .56821 .25476 .56282 Mtetra
.634 .75 .932 r
.25476 .56282 .26104 .56821 .27048 .56553 .26421 .5603 Mtetra
.631 .756 .938 r
.26421 .5603 .27048 .56553 .27995 .5628 .27368 .5578 Mtetra
.629 .765 .944 r
.27368 .5578 .27995 .5628 .28947 .55994 .2832 .55529 Mtetra
.627 .779 .954 r
.2832 .55529 .28947 .55994 .29904 .55689 .29275 .55275 Mtetra
.633 .802 .964 r
.29275 .55275 .29904 .55689 .30866 .55353 .30236 .54999 Mtetra
.643 .83 .972 r
.30236 .54999 .30866 .55353 .31834 .54971 .31202 .54688 Mtetra
.665 .865 .975 r
.31202 .54688 .31834 .54971 .32808 .54543 .32175 .54317 Mtetra
.702 .894 .967 r
.32175 .54317 .32808 .54543 .33788 .54057 .33157 .53859 Mtetra
.737 .908 .953 r
.33157 .53859 .33788 .54057 .34771 .53556 .34145 .53319 Mtetra
.775 .894 .928 r
.34145 .53319 .34771 .53556 .35756 .53066 .35141 .52686 Mtetra
.772 .839 .903 r
.35141 .52686 .35756 .53066 .36738 .5268 .36139 .52051 Mtetra
.737 .752 .864 r
.36139 .52051 .36738 .5268 .37716 .52474 .37135 .51476 Mtetra
.658 .637 .818 r
.37135 .51476 .37716 .52474 .38689 .52479 .38124 .51119 Mtetra
.559 .53 .78 r
.38124 .51119 .38689 .52479 .39658 .52727 .39103 .51102 Mtetra
.485 .457 .75 r
.39103 .51102 .39658 .52727 .40634 .52992 .40077 .51367 Mtetra
.404 .407 .749 r
.40077 .51367 .40634 .52992 .41621 .53121 .41049 .51879 Mtetra
.396 .458 .808 r
.41049 .51879 .41621 .53121 .42624 .52917 .42034 .52272 Mtetra
.468 .659 .944 r
.42034 .52272 .42624 .52917 .43644 .52255 .43036 .52314 Mtetra
.455 .885 .874 r
.43036 .52314 .43644 .52255 .44671 .51337 .44056 .51927 Mtetra
0 0 0 r
.44056 .51927 .44671 .51337 .45701 .50286 .45089 .51072 Mtetra
.45089 .51072 .45701 .50286 .46729 .49332 .46126 .50031 Mtetra
.46126 .50031 .46729 .49332 .47754 .48609 .47163 .48969 Mtetra
.652 .944 .702 r
.47163 .48969 .47754 .48609 .48777 .481 .48198 .48036 Mtetra
.773 .969 .923 r
.48198 .48036 .48777 .481 .49802 .47793 .49231 .47317 Mtetra
.739 .817 .912 r
.49231 .47317 .49802 .47793 .5083 .47584 .50264 .46761 Mtetra
.68 .693 .855 r
.50264 .46761 .5083 .47584 .51863 .47409 .51299 .46341 Mtetra
.652 .629 .814 r
.51299 .46341 .51863 .47409 .529 .4721 .52337 .45985 Mtetra
.639 .597 .79 r
.52337 .45985 .529 .4721 .53942 .46952 .53379 .45652 Mtetra
.637 .585 .78 r
.53379 .45652 .53942 .46952 .54987 .4662 .54425 .45318 Mtetra
.54425 .45318 .54987 .4662 .56036 .46215 .55475 .44981 Mtetra
.634 .594 .792 r
.55475 .44981 .56036 .46215 .57088 .4575 .5653 .44669 Mtetra
.622 .615 .822 r
.5653 .44669 .57088 .4575 .58142 .45261 .57589 .4442 Mtetra
.573 .648 .886 r
.57589 .4442 .58142 .45261 .59201 .44805 .58656 .44309 Mtetra
.402 .69 .978 r
.58656 .44309 .59201 .44805 .60264 .44448 .59732 .44364 Mtetra
.223 0 0 r
.59732 .44364 .60264 .44448 .61338 .44295 .60821 .44636 Mtetra
.532 .003 0 r
.60821 .44636 .61338 .44295 .62423 .44359 .61922 .45041 Mtetra
.558 .099 .118 r
.61922 .45041 .62423 .44359 .63523 .4466 .63031 .45427 Mtetra
.503 .054 .116 r
.63031 .45427 .63523 .4466 .64636 .45061 .64142 .45628 Mtetra
.214 0 0 r
.64142 .45628 .64636 .45061 .65752 .4533 .65244 .45351 Mtetra
.686 .979 .883 r
.65244 .45351 .65752 .4533 .66865 .45338 .66331 .44639 Mtetra
.823 .779 .811 r
.66331 .44639 .66865 .45338 .67963 .4488 .67404 .43564 Mtetra
.77 .654 .735 r
.67404 .43564 .67963 .4488 .69048 .4408 .6847 .42367 Mtetra
.709 .587 .716 r
.6847 .42367 .69048 .4408 .70126 .43139 .69548 .41419 Mtetra
.671 .565 .727 r
.69548 .41419 .70126 .43139 .71205 .42213 .70643 .40758 Mtetra
.624 .565 .768 r
.70643 .40758 .71205 .42213 .723 .41535 .7176 .40447 Mtetra
.571 .595 .838 r
.7176 .40447 .723 .41535 .7341 .41073 .72897 .4036 Mtetra
.515 .668 .932 r
.72897 .4036 .7341 .41073 .74538 .40796 .74044 .40336 Mtetra
.441 .733 .989 r
.74044 .40336 .74538 .40796 .75678 .40628 .75198 .40311 Mtetra
.437 .794 .997 r
.75198 .40311 .75678 .40628 .76825 .40471 .76351 .40191 Mtetra
.482 .833 .996 r
.76351 .40191 .76825 .40471 .77976 .40299 .77505 .39986 Mtetra
.563 .857 .997 r
.77505 .39986 .77976 .40299 .79129 .40068 .78657 .39691 Mtetra
.621 .855 .987 r
.78657 .39691 .79129 .40068 .80284 .39788 .79809 .39333 Mtetra
.654 .835 .97 r
.79809 .39333 .80284 .39788 .81439 .39461 .80963 .38938 Mtetra
.67 .814 .952 r
.80963 .38938 .81439 .39461 .82596 .391 .82119 .3852 Mtetra
.673 .794 .939 r
.82119 .3852 .82596 .391 .83756 .38719 .83279 .38098 Mtetra
.674 .78 .929 r
.83279 .38098 .83756 .38719 .84919 .38325 .84443 .37674 Mtetra
.674 .77 .923 r
.84443 .37674 .84919 .38325 .86087 .37924 .85612 .37252 Mtetra
.671 .762 .919 r
.85612 .37252 .86087 .37924 .87259 .37524 .86786 .36837 Mtetra
.641 .748 .926 r
.23902 .55988 .24535 .5654 .25476 .56282 .24846 .5572 Mtetra
.637 .744 .926 r
.24846 .5572 .25476 .56282 .26421 .5603 .25792 .55461 Mtetra
.632 .741 .926 r
.25792 .55461 .26421 .5603 .27368 .5578 .26742 .55212 Mtetra
.626 .74 .929 r
.26742 .55212 .27368 .5578 .2832 .55529 .27694 .54974 Mtetra
.616 .743 .936 r
.27694 .54974 .2832 .55529 .29275 .55275 .28649 .54753 Mtetra
.612 .755 .946 r
.28649 .54753 .29275 .55275 .30236 .54999 .29607 .54533 Mtetra
.608 .776 .961 r
.29607 .54533 .30236 .54999 .31202 .54688 .3057 .54308 Mtetra
.618 .815 .976 r
.3057 .54308 .31202 .54688 .32175 .54317 .3154 .54042 Mtetra
.639 .864 .984 r
.3154 .54042 .32175 .54317 .33157 .53859 .32517 .53706 Mtetra
.673 .918 .975 r
.32517 .53706 .33157 .53859 .34145 .53319 .33504 .53264 Mtetra
.729 .957 .946 r
.33504 .53264 .34145 .53319 .35141 .52686 .34502 .52676 Mtetra
.771 .971 .922 r
.34502 .52676 .35141 .52686 .36139 .52051 .35507 .51977 Mtetra
.818 .95 .906 r
.35507 .51977 .36139 .52051 .37135 .51476 .36518 .51179 Mtetra
.798 .873 .903 r
.36518 .51179 .37135 .51476 .38124 .51119 .37526 .5046 Mtetra
.718 .741 .87 r
.37526 .5046 .38124 .51119 .39103 .51102 .38527 .49948 Mtetra
.601 .585 .807 r
.38527 .49948 .39103 .51102 .40077 .51367 .39517 .4978 Mtetra
.479 .457 .756 r
.39517 .4978 .40077 .51367 .41049 .51879 .40496 .50055 Mtetra
.436 .408 .729 r
.40496 .50055 .41049 .51879 .42034 .52272 .41475 .50525 Mtetra
.42 .405 .737 r
.41475 .50525 .42034 .52272 .43036 .52314 .42462 .51028 Mtetra
.467 .494 .803 r
.42462 .51028 .43036 .52314 .44056 .51927 .43465 .51269 Mtetra
.605 .714 .921 r
.43465 .51269 .44056 .51927 .45089 .51072 .44486 .51067 Mtetra
.652 .96 .932 r
.44486 .51067 .45089 .51072 .46126 .50031 .45518 .50519 Mtetra
0 0 0 r
.45518 .50519 .46126 .50031 .47163 .48969 .46558 .49686 Mtetra
.46558 .49686 .47163 .48969 .48198 .48036 .476 .48778 Mtetra
.476 .48778 .48198 .48036 .49231 .47317 .48642 .47918 Mtetra
.48642 .47918 .49231 .47317 .50264 .46761 .49684 .47162 Mtetra
.49684 .47162 .50264 .46761 .51299 .46341 .50726 .46545 Mtetra
.401 .844 .734 r
.50726 .46545 .51299 .46341 .52337 .45985 .51769 .46036 Mtetra
.461 .889 .868 r
.51769 .46036 .52337 .45985 .53379 .45652 .52816 .45623 Mtetra
.455 .88 .916 r
.52816 .45623 .53379 .45652 .54425 .45318 .53867 .45287 Mtetra
.368 .833 .895 r
.53867 .45287 .54425 .45318 .55475 .44981 .54922 .45027 Mtetra
.154 .696 .755 r
.54922 .45027 .55475 .44981 .5653 .44669 .55983 .44865 Mtetra
.14 0 0 r
.55983 .44865 .5653 .44669 .57589 .4442 .5705 .44811 Mtetra
.377 0 0 r
.5705 .44811 .57589 .4442 .58656 .44309 .58127 .44899 Mtetra
.481 0 .033 r
.58127 .44899 .58656 .44309 .59732 .44364 .59212 .45093 Mtetra
.515 .061 .11 r
.59212 .45093 .59732 .44364 .60821 .44636 .60306 .45338 Mtetra
.485 .023 .08 r
.60306 .45338 .60821 .44636 .61922 .45041 .61406 .45509 Mtetra
.269 0 0 r
.61406 .45509 .61922 .45041 .63031 .45427 .62505 .45391 Mtetra
.554 .927 .922 r
.62505 .45391 .63031 .45427 .64142 .45628 .63599 .44923 Mtetra
.798 .772 .829 r
.63599 .44923 .64142 .45628 .65244 .45351 .64678 .44003 Mtetra
.765 .648 .733 r
.64678 .44003 .65244 .45351 .66331 .44639 .65748 .42813 Mtetra
.725 .587 .701 r
.65748 .42813 .66331 .44639 .67404 .43564 .66817 .41654 Mtetra
.699 .567 .702 r
.66817 .41654 .67404 .43564 .6847 .42367 .67895 .40691 Mtetra
.651 .558 .736 r
.67895 .40691 .6847 .42367 .69548 .41419 .68995 .40181 Mtetra
.592 .579 .807 r
.68995 .40181 .69548 .41419 .70643 .40758 .70119 .40024 Mtetra
.476 .641 .929 r
.70119 .40024 .70643 .40758 .7176 .40447 .7126 .4008 Mtetra
.238 .657 .96 r
.7126 .4008 .7176 .40447 .72897 .4036 .72415 .40219 Mtetra
.118 .653 .859 r
.72415 .40219 .72897 .4036 .74044 .40336 .73571 .40258 Mtetra
.172 .703 .845 r
.73571 .40258 .74044 .40336 .75198 .40311 .74726 .40183 Mtetra
.38 .829 .937 r
.74726 .40183 .75198 .40311 .76351 .40191 .75877 .39957 Mtetra
.552 .884 .988 r
.75877 .39957 .76351 .40191 .77505 .39986 .77026 .39621 Mtetra
.645 .869 .983 r
.77026 .39621 .77505 .39986 .78657 .39691 .78173 .39212 Mtetra
.681 .835 .957 r
.78173 .39212 .78657 .39691 .79809 .39333 .79321 .38759 Mtetra
.687 .801 .935 r
.79321 .38759 .79809 .39333 .80963 .38938 .80473 .38302 Mtetra
.687 .778 .921 r
.80473 .38302 .80963 .38938 .82119 .3852 .8163 .37844 Mtetra
.68 .763 .914 r
.8163 .37844 .82119 .3852 .83279 .38098 .82792 .37404 Mtetra
.676 .756 .912 r
.82792 .37404 .83279 .38098 .84443 .37674 .83959 .36974 Mtetra
.672 .754 .912 r
.83959 .36974 .84443 .37674 .85612 .37252 .85132 .36555 Mtetra
.668 .754 .915 r
.85132 .36555 .85612 .37252 .86786 .36837 .8631 .36144 Mtetra
.654 .751 .921 r
.23264 .55431 .23902 .55988 .24846 .5572 .24212 .55134 Mtetra
.651 .74 .915 r
.24212 .55134 .24846 .5572 .25792 .55461 .25163 .54843 Mtetra
.645 .729 .91 r
.25163 .54843 .25792 .55461 .26742 .55212 .26116 .54566 Mtetra
.635 .717 .907 r
.26116 .54566 .26742 .55212 .27694 .54974 .27072 .54311 Mtetra
.621 .708 .908 r
.27072 .54311 .27694 .54974 .28649 .54753 .28028 .54088 Mtetra
.607 .704 .912 r
.28028 .54088 .28649 .54753 .29607 .54533 .28986 .53896 Mtetra
.587 .707 .926 r
.28986 .53896 .29607 .54533 .3057 .54308 .29946 .53741 Mtetra
.575 .728 .947 r
.29946 .53741 .3057 .54308 .3154 .54042 .3091 .53593 Mtetra
.557 .77 .978 r
.3091 .53593 .3154 .54042 .32517 .53706 .31879 .53437 Mtetra
.552 .844 .998 r
.31879 .53437 .32517 .53706 .33504 .53264 .32856 .5321 Mtetra
.543 .909 .958 r
.32856 .5321 .33504 .53264 .34502 .52676 .33845 .5286 Mtetra
.521 .916 .823 r
.33845 .5286 .34502 .52676 .35507 .51977 .34846 .5233 Mtetra
.585 .927 .727 r
.34846 .5233 .35507 .51977 .36518 .51179 .35862 .51564 Mtetra
.686 .963 .732 r
.35862 .51564 .36518 .51179 .37526 .5046 .36886 .50634 Mtetra
.851 .994 .833 r
.36886 .50634 .37526 .5046 .38527 .49948 .37915 .49583 Mtetra
.827 .847 .862 r
.37915 .49583 .38527 .49948 .39517 .4978 .38937 .48695 Mtetra
.69 .639 .793 r
.38937 .48695 .39517 .4978 .40496 .50055 .39946 .48168 Mtetra
.568 .485 .721 r
.39946 .48168 .40496 .50055 .41475 .50525 .40941 .48109 Mtetra
.468 .388 .683 r
.40941 .48109 .41475 .50525 .42462 .51028 .41924 .48586 Mtetra
.429 .361 .679 r
.41924 .48586 .42462 .51028 .43465 .51269 .4291 .4925 Mtetra
.406 .373 .71 r
.4291 .4925 .43465 .51269 .44486 .51067 .43907 .49882 Mtetra
.404 .478 .822 r
.43907 .49882 .44486 .51067 .45518 .50519 .4492 .50231 Mtetra
.405 .781 .993 r
.4492 .50231 .45518 .50519 .46558 .49686 .4595 .5015 Mtetra
.004 0 0 r
.4595 .5015 .46558 .49686 .476 .48778 .4699 .49759 Mtetra
.142 0 0 r
.4699 .49759 .476 .48778 .48642 .47918 .48037 .49128 Mtetra
.194 0 .085 r
.48037 .49128 .48642 .47918 .49684 .47162 .49087 .48425 Mtetra
.228 0 .115 r
.49087 .48425 .49684 .47162 .50726 .46545 .50138 .47753 Mtetra
.253 0 .115 r
.50138 .47753 .50726 .46545 .51769 .46036 .51191 .47164 Mtetra
.291 0 .115 r
.51191 .47164 .51769 .46036 .52816 .45623 .52246 .46699 Mtetra
.337 0 .124 r
.52246 .46699 .52816 .45623 .53867 .45287 .53305 .46362 Mtetra
.389 0 .15 r
.53305 .46362 .53867 .45287 .54922 .45027 .54369 .46153 Mtetra
.441 .043 .187 r
.54369 .46153 .54922 .45027 .55983 .44865 .55438 .46069 Mtetra
.474 .084 .219 r
.55438 .46069 .55983 .44865 .5705 .44811 .56515 .4607 Mtetra
.486 .101 .234 r
.56515 .4607 .5705 .44811 .58127 .44899 .57598 .46102 Mtetra
.462 .071 .212 r
.57598 .46102 .58127 .44899 .59212 .45093 .58687 .46063 Mtetra
.342 0 .096 r
.58687 .46063 .59212 .45093 .60306 .45338 .59777 .45783 Mtetra
0 0 0 r
.59777 .45783 .60306 .45338 .61406 .45509 .60863 .45189 Mtetra
.858 .897 .862 r
.60863 .45189 .61406 .45509 .62505 .45391 .6194 .44156 Mtetra
.79 .672 .733 r
.6194 .44156 .62505 .45391 .63599 .44923 .63007 .42835 Mtetra
.728 .573 .68 r
.63007 .42835 .63599 .44923 .64678 .44003 .6407 .41476 Mtetra
.69 .53 .666 r
.6407 .41476 .64678 .44003 .65748 .42813 .65138 .40305 Mtetra
.636 .498 .677 r
.65138 .40305 .65748 .42813 .66817 .41654 .66227 .39678 Mtetra
.582 .494 .719 r
.66227 .39678 .66817 .41654 .67895 .40691 .67342 .3953 Mtetra
.466 .523 .833 r
.67342 .3953 .67895 .40691 .68995 .40181 .68481 .39753 Mtetra
.039 .495 .884 r
.68481 .39753 .68995 .40181 .70119 .40024 .69637 .40145 Mtetra
.355 0 0 r
.69637 .40145 .70119 .40024 .7126 .4008 .70796 .40416 Mtetra
.349 0 0 r
.70796 .40416 .7126 .4008 .72415 .40219 .71954 .40518 Mtetra
.15 0 0 r
.71954 .40518 .72415 .40219 .73571 .40258 .73105 .40379 Mtetra
.206 .724 .696 r
.73105 .40379 .73571 .40258 .74726 .40183 .74249 .40054 Mtetra
.573 .924 .954 r
.74249 .40054 .74726 .40183 .75877 .39957 .7539 .39601 Mtetra
.701 .89 .966 r
.7539 .39601 .75877 .39957 .77026 .39621 .76528 .39073 Mtetra
.715 .819 .93 r
.76528 .39073 .77026 .39621 .78173 .39212 .7767 .38537 Mtetra
.709 .773 .902 r
.7767 .38537 .78173 .39212 .79321 .38759 .78815 .38007 Mtetra
.694 .744 .89 r
.78815 .38007 .79321 .38759 .80473 .38302 .79968 .37516 Mtetra
.683 .73 .886 r
.79968 .37516 .80473 .38302 .8163 .37844 .81127 .37055 Mtetra
.673 .726 .889 r
.81127 .37055 .8163 .37844 .82792 .37404 .82293 .36627 Mtetra
.666 .727 .896 r
.82293 .36627 .82792 .37404 .83959 .36974 .83467 .36221 Mtetra
.661 .734 .904 r
.83467 .36221 .83959 .36974 .85132 .36555 .84646 .35831 Mtetra
.658 .743 .912 r
.84646 .35831 .85132 .36555 .8631 .36144 .85831 .35446 Mtetra
.669 .754 .915 r
.22623 .54871 .23264 .55431 .24212 .55134 .23576 .54534 Mtetra
.668 .742 .905 r
.23576 .54534 .24212 .55134 .25163 .54843 .24532 .54198 Mtetra
.663 .726 .896 r
.24532 .54198 .25163 .54843 .26116 .54566 .25491 .53871 Mtetra
.654 .709 .888 r
.25491 .53871 .26116 .54566 .27072 .54311 .26451 .53566 Mtetra
.641 .691 .881 r
.26451 .53566 .27072 .54311 .28028 .54088 .27413 .53292 Mtetra
.624 .671 .874 r
.27413 .53292 .28028 .54088 .28986 .53896 .28375 .53062 Mtetra
.601 .653 .873 r
.28375 .53062 .28986 .53896 .29946 .53741 .29337 .52892 Mtetra
.58 .641 .875 r
.29337 .52892 .29946 .53741 .3091 .53593 .303 .52775 Mtetra
.551 .638 .89 r
.303 .52775 .3091 .53593 .31879 .53437 .31264 .52716 Mtetra
.539 .663 .917 r
.31264 .52716 .31879 .53437 .32856 .5321 .32232 .52661 Mtetra
.528 .722 .962 r
.32232 .52661 .32856 .5321 .33845 .5286 .33208 .52575 Mtetra
.544 .837 .999 r
.33208 .52575 .33845 .5286 .34846 .5233 .34195 .52359 Mtetra
.55 .926 .92 r
.34195 .52359 .34846 .5233 .35862 .51564 .35198 .5193 Mtetra
.496 .879 .687 r
.35198 .5193 .35862 .51564 .36886 .50634 .36217 .51237 Mtetra
.542 .855 .556 r
.36217 .51237 .36886 .50634 .37915 .49583 .37251 .50231 Mtetra
.587 .869 .546 r
.37251 .50231 .37915 .49583 .38937 .48695 .3829 .49108 Mtetra
.759 .979 .722 r
.3829 .49108 .38937 .48695 .39946 .48168 .39328 .48004 Mtetra
.816 .928 .908 r
.39328 .48004 .39946 .48168 .40941 .48109 .40353 .47213 Mtetra
.64 .658 .851 r
.40353 .47213 .40941 .48109 .41924 .48586 .41362 .46921 Mtetra
.526 .479 .747 r
.41362 .46921 .41924 .48586 .4291 .4925 .42362 .47033 Mtetra
.462 .396 .697 r
.42362 .47033 .4291 .4925 .43907 .49882 .4336 .4749 Mtetra
.461 .386 .685 r
.4336 .4749 .43907 .49882 .4492 .50231 .44365 .4799 Mtetra
.486 .411 .698 r
.44365 .4799 .4492 .50231 .4595 .5015 .45382 .48351 Mtetra
.521 .466 .736 r
.45382 .48351 .4595 .5015 .4699 .49759 .46411 .48498 Mtetra
.581 .565 .801 r
.46411 .48498 .4699 .49759 .48037 .49128 .47451 .48384 Mtetra
.634 .703 .896 r
.47451 .48384 .48037 .49128 .49087 .48425 .48499 .48107 Mtetra
.649 .867 .981 r
.48499 .48107 .49087 .48425 .50138 .47753 .49552 .47726 Mtetra
.524 .912 .928 r
.49552 .47726 .50138 .47753 .51191 .47164 .50608 .4732 Mtetra
.305 .791 .738 r
.50608 .4732 .51191 .47164 .52246 .46699 .51669 .46937 Mtetra
0 0 0 r
.51669 .46937 .52246 .46699 .53305 .46362 .52733 .46598 Mtetra
.52733 .46598 .53305 .46362 .54369 .46153 .53801 .46304 Mtetra
.53801 .46304 .54369 .46153 .55438 .46069 .54875 .46032 Mtetra
.403 .852 .905 r
.54875 .46032 .55438 .46069 .56515 .4607 .55952 .45737 Mtetra
.655 .869 .98 r
.55952 .45737 .56515 .4607 .57598 .46102 .57033 .45335 Mtetra
.718 .733 .862 r
.57033 .45335 .57598 .46102 .58687 .46063 .58114 .4477 Mtetra
.724 .636 .759 r
.58114 .4477 .58687 .46063 .59777 .45783 .59193 .43939 Mtetra
.713 .579 .703 r
.59193 .43939 .59777 .45783 .60863 .45189 .60268 .4289 Mtetra
.702 .548 .675 r
.60268 .4289 .60863 .45189 .6194 .44156 .61339 .41696 Mtetra
.691 .534 .669 r
.61339 .41696 .6194 .44156 .63007 .42835 .62409 .40544 Mtetra
.663 .524 .684 r
.62409 .40544 .63007 .42835 .6407 .41476 .6349 .3974 Mtetra
.629 .54 .735 r
.6349 .3974 .6407 .41476 .65138 .40305 .64588 .39347 Mtetra
.481 .578 .875 r
.64588 .39347 .65138 .40305 .66227 .39678 .65711 .39464 Mtetra
0 .344 .679 r
.65711 .39464 .66227 .39678 .67342 .3953 .66856 .39903 Mtetra
.543 .015 0 r
.66856 .39903 .67342 .3953 .68481 .39753 .68012 .40363 Mtetra
.527 .043 .05 r
.68012 .40363 .68481 .39753 .69637 .40145 .69172 .40706 Mtetra
.383 0 0 r
.69172 .40706 .69637 .40145 .70796 .40416 .70324 .40731 Mtetra
.065 0 0 r
.70324 .40731 .70796 .40416 .71954 .40518 .71468 .40483 Mtetra
.517 .914 .905 r
.71468 .40483 .71954 .40518 .73105 .40379 .72603 .40015 Mtetra
.734 .894 .952 r
.72603 .40015 .73105 .40379 .74249 .40054 .73734 .39412 Mtetra
.742 .793 .893 r
.73734 .39412 .74249 .40054 .7539 .39601 .74865 .38775 Mtetra
.727 .734 .857 r
.74865 .38775 .7539 .39601 .76528 .39073 .75999 .38142 Mtetra
.705 .7 .843 r
.75999 .38142 .76528 .39073 .7767 .38537 .7714 .37569 Mtetra
.689 .686 .842 r
.7714 .37569 .7767 .38537 .78815 .38007 .78289 .37049 Mtetra
.674 .682 .85 r
.78289 .37049 .78815 .38007 .79968 .37516 .79447 .36591 Mtetra
.663 .686 .861 r
.79447 .36591 .79968 .37516 .81127 .37055 .80614 .36178 Mtetra
.655 .695 .875 r
.80614 .36178 .81127 .37055 .82293 .36627 .81788 .35798 Mtetra
.649 .706 .889 r
.81788 .35798 .82293 .36627 .83467 .36221 .82968 .35439 Mtetra
.645 .719 .902 r
.82968 .35439 .83467 .36221 .84646 .35831 .84155 .35091 Mtetra
.644 .733 .914 r
.84155 .35091 .84646 .35831 .85831 .35446 .85348 .34743 Mtetra
.682 .757 .908 r
.21976 .54307 .22623 .54871 .23576 .54534 .22935 .53934 Mtetra
.684 .746 .899 r
.22935 .53934 .23576 .54534 .24532 .54198 .23897 .53553 Mtetra
.682 .732 .888 r
.23897 .53553 .24532 .54198 .25491 .53871 .24862 .53171 Mtetra
.677 .715 .877 r
.24862 .53171 .25491 .53871 .26451 .53566 .25829 .52796 Mtetra
.669 .694 .864 r
.25829 .52796 .26451 .53566 .27413 .53292 .26799 .52435 Mtetra
.654 .668 .85 r
.26799 .52435 .27413 .53292 .28375 .53062 .27769 .52111 Mtetra
.634 .639 .837 r
.27769 .52111 .28375 .53062 .29337 .52892 .28739 .51841 Mtetra
.608 .607 .825 r
.28739 .51841 .29337 .52892 .303 .52775 .29707 .51647 Mtetra
.575 .578 .818 r
.29707 .51647 .303 .52775 .31264 .52716 .30673 .51556 Mtetra
.543 .557 .818 r
.30673 .51556 .31264 .52716 .32232 .52661 .31638 .51557 Mtetra
.502 .546 .834 r
.31638 .51557 .32232 .52661 .33208 .52575 .32603 .51653 Mtetra
.471 .574 .877 r
.32603 .51653 .33208 .52575 .34195 .52359 .33572 .51769 Mtetra
.411 .657 .96 r
.33572 .51769 .34195 .52359 .35198 .5193 .3455 .51848 Mtetra
.233 .742 .884 r
.3455 .51848 .35198 .5193 .36217 .51237 .35543 .51755 Mtetra
.035 0 0 r
.35543 .51755 .36217 .51237 .37251 .50231 .36554 .51381 Mtetra
.107 0 .006 r
.36554 .51381 .37251 .50231 .3829 .49108 .37586 .50631 Mtetra
.013 0 .043 r
.37586 .50631 .3829 .49108 .39328 .48004 .38637 .49443 Mtetra
0 0 0 r
.38637 .49443 .39328 .48004 .40353 .47213 .39694 .48046 Mtetra
.627 .85 .47 r
.39694 .48046 .40353 .47213 .41362 .46921 .40751 .46604 Mtetra
.869 .86 .829 r
.40751 .46604 .41362 .46921 .42362 .47033 .41795 .45467 Mtetra
.675 .575 .735 r
.41795 .45467 .42362 .47033 .4336 .4749 .42822 .44846 Mtetra
.577 .451 .671 r
.42822 .44846 .4336 .4749 .44365 .4799 .43839 .44683 Mtetra
.521 .391 .644 r
.43839 .44683 .44365 .4799 .45382 .48351 .44851 .4494 Mtetra
.502 .376 .64 r
.44851 .4494 .45382 .48351 .46411 .48498 .45868 .45349 Mtetra
.5 .382 .65 r
.45868 .45349 .46411 .48498 .47451 .48384 .46894 .4575 Mtetra
.509 .407 .675 r
.46894 .4575 .47451 .48384 .48499 .48107 .4793 .46034 Mtetra
.535 .455 .712 r
.4793 .46034 .48499 .48107 .49552 .47726 .48975 .46131 Mtetra
.566 .515 .757 r
.48975 .46131 .49552 .47726 .50608 .4732 .50029 .46071 Mtetra
.607 .582 .8 r
.50029 .46071 .50608 .4732 .51669 .46937 .51089 .45857 Mtetra
.644 .63 .821 r
.51089 .45857 .51669 .46937 .52733 .46598 .52155 .45515 Mtetra
.675 .644 .811 r
.52155 .45515 .52733 .46598 .53801 .46304 .53224 .45045 Mtetra
.694 .625 .775 r
.53224 .45045 .53801 .46304 .54875 .46032 .54296 .44421 Mtetra
.695 .587 .73 r
.54296 .44421 .54875 .46032 .55952 .45737 .55369 .43637 Mtetra
.69 .55 .69 r
.55369 .43637 .55952 .45737 .57033 .45335 .5644 .42663 Mtetra
.677 .517 .662 r
.5644 .42663 .57033 .45335 .58114 .4477 .5751 .41569 Mtetra
.66 .491 .644 r
.5751 .41569 .58114 .4477 .59193 .43939 .58579 .40464 Mtetra
.641 .471 .638 r
.58579 .40464 .59193 .43939 .60268 .4289 .59651 .39511 Mtetra
.607 .45 .644 r
.59651 .39511 .60268 .4289 .61339 .41696 .60733 .38981 Mtetra
.563 .442 .672 r
.60733 .38981 .61339 .41696 .62409 .40544 .61832 .38916 Mtetra
.427 .43 .76 r
.61832 .38916 .62409 .40544 .6349 .3974 .62955 .39378 Mtetra
.397 0 0 r
.62955 .39378 .6349 .3974 .64588 .39347 .64099 .40153 Mtetra
.637 .196 .186 r
.64099 .40153 .64588 .39347 .65711 .39464 .65254 .40887 Mtetra
.587 .207 .288 r
.65254 .40887 .65711 .39464 .66856 .39903 .66411 .41411 Mtetra
.502 .132 .27 r
.66411 .41411 .66856 .39903 .68012 .40363 .67559 .41489 Mtetra
.361 0 .143 r
.67559 .41489 .68012 .40363 .69172 .40706 .68695 .41181 Mtetra
0 0 0 r
.68695 .41181 .69172 .40706 .70324 .40731 .69821 .40583 Mtetra
.769 .971 .922 r
.69821 .40583 .70324 .40731 .71468 .40483 .70939 .39807 Mtetra
.782 .791 .86 r
.70939 .39807 .71468 .40483 .72603 .40015 .72057 .38992 Mtetra
.743 .695 .806 r
.72057 .38992 .72603 .40015 .73734 .39412 .73177 .38194 Mtetra
.709 .647 .786 r
.73177 .38194 .73734 .39412 .74865 .38775 .74306 .37494 Mtetra
.687 .628 .784 r
.74306 .37494 .74865 .38775 .75999 .38142 .75444 .36888 Mtetra
.668 .623 .795 r
.75444 .36888 .75999 .38142 .7714 .37569 .76592 .36388 Mtetra
.654 .628 .812 r
.76592 .36388 .7714 .37569 .78289 .37049 .77751 .35966 Mtetra
.644 .642 .834 r
.77751 .35966 .78289 .37049 .79447 .36591 .78919 .35602 Mtetra
.636 .659 .856 r
.78919 .35602 .79447 .36591 .80614 .36178 .80095 .35275 Mtetra
.633 .68 .876 r
.80095 .35275 .80614 .36178 .81788 .35798 .81278 .34961 Mtetra
.63 .697 .893 r
.81278 .34961 .81788 .35798 .82968 .35439 .82467 .34656 Mtetra
.629 .714 .907 r
.82467 .34656 .82968 .35439 .84155 .35091 .83662 .3435 Mtetra
.631 .729 .918 r
.83662 .3435 .84155 .35091 .85348 .34743 .84861 .34035 Mtetra
.683 .757 .908 r
.21326 .53739 .21976 .54307 .22935 .53934 .22287 .53361 Mtetra
.688 .757 .904 r
.22287 .53361 .22935 .53934 .23897 .53553 .23252 .52968 Mtetra
.691 .755 .9 r
.23252 .52968 .23897 .53553 .24862 .53171 .24221 .52562 Mtetra
.694 .748 .893 r
.24221 .52562 .24862 .53171 .25829 .52796 .25194 .52145 Mtetra
.696 .736 .882 r
.25194 .52145 .25829 .52796 .26799 .52435 .26171 .51715 Mtetra
.69 .715 .868 r
.26171 .51715 .26799 .52435 .27769 .52111 .2715 .51292 Mtetra
.678 .687 .851 r
.2715 .51292 .27769 .52111 .28739 .51841 .28131 .50889 Mtetra
.656 .649 .831 r
.28131 .50889 .28739 .51841 .29707 .51647 .2911 .50541 Mtetra
.626 .607 .811 r
.2911 .50541 .29707 .51647 .30673 .51556 .30088 .50279 Mtetra
.59 .562 .791 r
.30088 .50279 .30673 .51556 .31638 .51557 .31062 .50135 Mtetra
.547 .519 .776 r
.31062 .50135 .31638 .51557 .32603 .51653 .32031 .50141 Mtetra
.51 .487 .767 r
.32031 .50141 .32603 .51653 .33572 .51769 .32998 .50276 Mtetra
.468 .465 .772 r
.32998 .50276 .33572 .51769 .3455 .51848 .33965 .50534 Mtetra
.448 .481 .8 r
.33965 .50534 .3455 .51848 .35543 .51755 .34938 .508 Mtetra
.437 .551 .873 r
.34938 .508 .35543 .51755 .36554 .51381 .35923 .50983 Mtetra
.48 .771 .995 r
.35923 .50983 .36554 .51381 .37586 .50631 .36927 .50886 Mtetra
.41 .848 .729 r
.36927 .50886 .37586 .50631 .38637 .49443 .37956 .50365 Mtetra
0 0 0 r
.37956 .50365 .38637 .49443 .39694 .48046 .39003 .49442 Mtetra
.39003 .49442 .39694 .48046 .40751 .46604 .40065 .48142 Mtetra
0 0 .011 r
.40065 .48142 .40751 .46604 .41795 .45467 .41127 .46791 Mtetra
0 0 0 r
.41127 .46791 .41795 .45467 .42822 .44846 .42181 .45595 Mtetra
.42181 .45595 .42822 .44846 .43839 .44683 .43225 .44701 Mtetra
.599 .946 .919 r
.43225 .44701 .43839 .44683 .44851 .4494 .4426 .44196 Mtetra
.623 .698 .898 r
.4426 .44196 .44851 .4494 .45868 .45349 .45292 .43947 Mtetra
.567 .537 .781 r
.45292 .43947 .45868 .45349 .46894 .4575 .46325 .43879 Mtetra
.557 .483 .727 r
.46325 .43879 .46894 .4575 .4793 .46034 .47363 .43857 Mtetra
.564 .466 .702 r
.47363 .43857 .4793 .46034 .48975 .46131 .48408 .43798 Mtetra
.575 .465 .691 r
.48408 .43798 .48975 .46131 .50029 .46071 .49459 .43664 Mtetra
.589 .471 .686 r
.49459 .43664 .50029 .46071 .51089 .45857 .50516 .43424 Mtetra
.604 .479 .683 r
.50516 .43424 .51089 .45857 .52155 .45515 .51578 .43079 Mtetra
.617 .488 .682 r
.51578 .43079 .52155 .45515 .53224 .45045 .52644 .42626 Mtetra
.631 .497 .681 r
.52644 .42626 .53224 .45045 .54296 .44421 .53714 .42068 Mtetra
.642 .507 .684 r
.53714 .42068 .54296 .44421 .55369 .43637 .54785 .41433 Mtetra
.651 .521 .691 r
.54785 .41433 .55369 .43637 .5644 .42663 .55859 .4076 Mtetra
.658 .543 .713 r
.55859 .4076 .5644 .42663 .5751 .41569 .56935 .40133 Mtetra
.65 .581 .764 r
.56935 .40133 .5751 .41569 .58579 .40464 .58017 .39686 Mtetra
.593 .684 .905 r
.58017 .39686 .58579 .40464 .59651 .39511 .59108 .395 Mtetra
.219 0 0 r
.59108 .395 .59651 .39511 .60733 .38981 .60213 .39709 Mtetra
.589 .133 .138 r
.60213 .39709 .60733 .38981 .61832 .38916 .61336 .40226 Mtetra
.615 .227 .284 r
.61336 .40226 .61832 .38916 .62955 .39378 .62473 .40904 Mtetra
.603 .229 .307 r
.62473 .40904 .62955 .39378 .64099 .40153 .63621 .41534 Mtetra
.533 .15 .26 r
.63621 .41534 .64099 .40153 .65254 .40887 .64766 .41783 Mtetra
.37 0 .074 r
.64766 .41783 .65254 .40887 .66411 .41411 .65903 .41621 Mtetra
.398 .834 .697 r
.65903 .41621 .66411 .41411 .67559 .41489 .67026 .41024 Mtetra
.816 .864 .883 r
.67026 .41024 .67559 .41489 .68695 .41181 .68138 .40139 Mtetra
.77 .701 .787 r
.68138 .40139 .68695 .41181 .69821 .40583 .69246 .39167 Mtetra
.734 .632 .746 r
.69246 .39167 .69821 .40583 .70939 .39807 .70355 .38199 Mtetra
.702 .597 .735 r
.70355 .38199 .70939 .39807 .72057 .38992 .71472 .37357 Mtetra
.682 .583 .738 r
.71472 .37357 .72057 .38992 .73177 .38194 .72598 .36646 Mtetra
.662 .582 .754 r
.72598 .36646 .73177 .38194 .74306 .37494 .73737 .36091 Mtetra
.647 .591 .778 r
.73737 .36091 .74306 .37494 .75444 .36888 .74888 .35656 Mtetra
.634 .61 .808 r
.74888 .35656 .75444 .36888 .76592 .36388 .7605 .3531 Mtetra
.623 .634 .84 r
.7605 .3531 .76592 .36388 .77751 .35966 .77221 .35022 Mtetra
.619 .662 .87 r
.77221 .35022 .77751 .35966 .78919 .35602 .784 .34754 Mtetra
.615 .687 .894 r
.784 .34754 .78919 .35602 .80095 .35275 .79585 .34494 Mtetra
.618 .709 .911 r
.79585 .34494 .80095 .35275 .81278 .34961 .80774 .3422 Mtetra
.62 .724 .92 r
.80774 .3422 .81278 .34961 .82467 .34656 .81969 .33934 Mtetra
.624 .733 .925 r
.81969 .33934 .82467 .34656 .83662 .3435 .83167 .33635 Mtetra
.629 .738 .926 r
.83167 .33635 .83662 .3435 .84861 .34035 .8437 .33321 Mtetra
.672 .755 .913 r
.20671 .53168 .21326 .53739 .22287 .53361 .21631 .52818 Mtetra
.677 .767 .918 r
.21631 .52818 .22287 .53361 .23252 .52968 .22596 .52452 Mtetra
.685 .779 .922 r
.22596 .52452 .23252 .52968 .24221 .52562 .23566 .52065 Mtetra
.696 .789 .922 r
.23566 .52065 .24221 .52562 .25194 .52145 .24541 .51649 Mtetra
.71 .792 .915 r
.24541 .51649 .25194 .52145 .26171 .51715 .25522 .51193 Mtetra
.72 .785 .904 r
.25522 .51193 .26171 .51715 .2715 .51292 .26509 .50705 Mtetra
.726 .765 .884 r
.26509 .50705 .2715 .51292 .28131 .50889 .27501 .50184 Mtetra
.717 .729 .86 r
.27501 .50184 .28131 .50889 .2911 .50541 .28495 .49661 Mtetra
.699 .682 .829 r
.28495 .49661 .2911 .50541 .30088 .50279 .2949 .49157 Mtetra
.667 .623 .797 r
.2949 .49157 .30088 .50279 .31062 .50135 .30483 .48726 Mtetra
.627 .565 .765 r
.30483 .48726 .31062 .50135 .32031 .50141 .31472 .48414 Mtetra
.585 .509 .735 r
.31472 .48414 .32031 .50141 .32998 .50276 .32454 .48261 Mtetra
.541 .459 .712 r
.32454 .48261 .32998 .50276 .33965 .50534 .3343 .48311 Mtetra
.505 .423 .697 r
.3343 .48311 .33965 .50534 .34938 .508 .34401 .48545 Mtetra
.466 .396 .694 r
.34401 .48545 .34938 .508 .35923 .50983 .3537 .48958 Mtetra
.427 .387 .711 r
.3537 .48958 .35923 .50983 .36927 .50886 .36343 .49468 Mtetra
.342 .403 .78 r
.36343 .49468 .36927 .50886 .37956 .50365 .37323 .50002 Mtetra
0 .438 .809 r
.37323 .50002 .37956 .50365 .39003 .49442 .38321 .50354 Mtetra
.443 .012 .124 r
.38321 .50354 .39003 .49442 .40065 .48142 .39339 .50365 Mtetra
.412 .092 .311 r
.39339 .50365 .40065 .48142 .41127 .46791 .40382 .49897 Mtetra
.362 .08 .344 r
.40382 .49897 .41127 .46791 .42181 .45595 .41446 .48885 Mtetra
.316 .046 .336 r
.41446 .48885 .42181 .45595 .43225 .44701 .42519 .47553 Mtetra
.235 0 .284 r
.42519 .47553 .43225 .44701 .4426 .44196 .43594 .46056 Mtetra
.052 0 .12 r
.43594 .46056 .4426 .44196 .45292 .43947 .44664 .44645 Mtetra
0 0 0 r
.44664 .44645 .45292 .43947 .46325 .43879 .45726 .43465 Mtetra
.832 .849 .858 r
.45726 .43465 .46325 .43879 .47363 .43857 .46783 .42523 Mtetra
.701 .616 .759 r
.46783 .42523 .47363 .43857 .48408 .43798 .47837 .41825 Mtetra
.643 .528 .708 r
.47837 .41825 .48408 .43798 .49459 .43664 .4889 .41283 Mtetra
.615 .488 .684 r
.4889 .41283 .49459 .43664 .50516 .43424 .49946 .40857 Mtetra
.601 .471 .676 r
.49946 .40857 .50516 .43424 .51578 .43079 .51004 .40507 Mtetra
.591 .464 .676 r
.51004 .40507 .51578 .43079 .52644 .42626 .52067 .40234 Mtetra
.576 .463 .688 r
.52067 .40234 .52644 .42626 .53714 .42068 .53134 .40076 Mtetra
.551 .472 .719 r
.53134 .40076 .53714 .42068 .54785 .41433 .54208 .40077 Mtetra
.465 .49 .8 r
.54208 .40077 .54785 .41433 .55859 .4076 .55291 .40325 Mtetra
0 .388 .805 r
.55291 .40325 .55859 .4076 .56935 .40133 .56384 .40816 Mtetra
.641 .188 .159 r
.56384 .40816 .56935 .40133 .58017 .39686 .57492 .41543 Mtetra
.622 .269 .351 r
.57492 .41543 .58017 .39686 .59108 .395 .58613 .42361 Mtetra
.586 .27 .401 r
.58613 .42361 .59108 .395 .60213 .39709 .59742 .43016 Mtetra
.551 .25 .41 r
.59742 .43016 .60213 .39709 .61336 .40226 .60875 .43348 Mtetra
.49 .192 .388 r
.60875 .43348 .61336 .40226 .62473 .40904 .62001 .43129 Mtetra
.373 .061 .301 r
.62001 .43129 .62473 .40904 .63621 .41534 .63117 .42421 Mtetra
0 0 0 r
.63117 .42421 .63621 .41534 .64766 .41783 .64222 .41363 Mtetra
.881 .872 .824 r
.64222 .41363 .64766 .41783 .65903 .41621 .65319 .40116 Mtetra
.757 .634 .724 r
.65319 .40116 .65903 .41621 .67026 .41024 .66415 .38889 Mtetra
.704 .559 .687 r
.66415 .38889 .67026 .41024 .68138 .40139 .67515 .3776 Mtetra
.674 .528 .679 r
.67515 .3776 .68138 .40139 .69246 .39167 .68622 .36813 Mtetra
.654 .518 .685 r
.68622 .36813 .69246 .39167 .70355 .38199 .69741 .36053 Mtetra
.636 .518 .702 r
.69741 .36053 .70355 .38199 .71472 .37357 .70873 .35501 Mtetra
.621 .53 .73 r
.70873 .35501 .71472 .37357 .72598 .36646 .72019 .35113 Mtetra
.608 .554 .768 r
.72019 .35113 .72598 .36646 .73737 .36091 .73177 .34847 Mtetra
.594 .588 .815 r
.73177 .34847 .73737 .36091 .74888 .35656 .74347 .34657 Mtetra
.587 .634 .865 r
.74347 .34657 .74888 .35656 .7605 .3531 .75523 .34488 Mtetra
.58 .678 .907 r
.75523 .34488 .7605 .3531 .77221 .35022 .76707 .34318 Mtetra
.585 .719 .936 r
.76707 .34318 .77221 .35022 .784 .34754 .77894 .34112 Mtetra
.593 .746 .95 r
.77894 .34112 .784 .34754 .79585 .34494 .79084 .33874 Mtetra
.609 .762 .953 r
.79084 .33874 .79585 .34494 .80774 .3422 .80277 .33595 Mtetra
.622 .767 .949 r
.80277 .33595 .80774 .3422 .81969 .33934 .81473 .33284 Mtetra
.633 .764 .942 r
.81473 .33284 .81969 .33934 .83167 .33635 .82673 .32951 Mtetra
.64 .755 .932 r
.82673 .32951 .83167 .33635 .8437 .33321 .83876 .32602 Mtetra
.647 .749 .924 r
.20012 .52592 .20671 .53168 .21631 .52818 .20968 .52298 Mtetra
.649 .771 .937 r
.20968 .52298 .21631 .52818 .22596 .52452 .21929 .51995 Mtetra
.655 .796 .95 r
.21929 .51995 .22596 .52452 .23566 .52065 .22896 .51672 Mtetra
.666 .824 .959 r
.22896 .51672 .23566 .52065 .24541 .51649 .23869 .51315 Mtetra
.683 .851 .963 r
.23869 .51315 .24541 .51649 .25522 .51193 .24849 .50913 Mtetra
.703 .875 .962 r
.24849 .50913 .25522 .51193 .26509 .50705 .25836 .50457 Mtetra
.73 .89 .953 r
.25836 .50457 .26509 .50705 .27501 .50184 .26831 .49935 Mtetra
.751 .892 .942 r
.26831 .49935 .27501 .50184 .28495 .49661 .27833 .49359 Mtetra
.769 .872 .923 r
.27833 .49359 .28495 .49661 .2949 .49157 .2884 .48731 Mtetra
.766 .827 .9 r
.2884 .48731 .2949 .49157 .30483 .48726 .2985 .48096 Mtetra
.744 .759 .865 r
.2985 .48096 .30483 .48726 .31472 .48414 .3086 .47486 Mtetra
.699 .674 .822 r
.3086 .47486 .31472 .48414 .32454 .48261 .31866 .46967 Mtetra
.644 .589 .778 r
.31866 .46967 .32454 .48261 .3343 .48311 .32866 .46596 Mtetra
.588 .512 .737 r
.32866 .46596 .3343 .48311 .34401 .48545 .33858 .46424 Mtetra
.535 .449 .704 r
.33858 .46424 .34401 .48545 .3537 .48958 .34842 .46502 Mtetra
.489 .4 .681 r
.34842 .46502 .3537 .48958 .36343 .49468 .35818 .46834 Mtetra
.444 .361 .668 r
.35818 .46834 .36343 .49468 .37323 .50002 .36791 .47415 Mtetra
.428 .353 .67 r
.36791 .47415 .37323 .50002 .38321 .50354 .3777 .48062 Mtetra
.429 .371 .691 r
.3777 .48062 .38321 .50354 .39339 .50365 .38762 .48633 Mtetra
.479 .449 .746 r
.38762 .48633 .39339 .50365 .40382 .49897 .39776 .489 Mtetra
.598 .626 .85 r
.39776 .489 .40382 .49897 .41446 .48885 .40813 .48718 Mtetra
.709 .933 .962 r
.40813 .48718 .41446 .48885 .42519 .47553 .41866 .48166 Mtetra
0 0 0 r
.41866 .48166 .42519 .47553 .43594 .46056 .42932 .47303 Mtetra
.031 0 0 r
.42932 .47303 .43594 .46056 .44664 .44645 .44001 .46339 Mtetra
.2 0 .161 r
.44001 .46339 .44664 .44645 .45726 .43465 .45069 .45401 Mtetra
.285 0 .231 r
.45069 .45401 .45726 .43465 .46783 .42523 .46136 .44561 Mtetra
.343 .02 .266 r
.46136 .44561 .46783 .42523 .47837 .41825 .47201 .43867 Mtetra
.376 .051 .281 r
.47201 .43867 .47837 .41825 .4889 .41283 .48267 .43296 Mtetra
.403 .074 .289 r
.48267 .43296 .4889 .41283 .49946 .40857 .49334 .42845 Mtetra
.425 .092 .295 r
.49334 .42845 .49946 .40857 .51004 .40507 .50404 .42495 Mtetra
.448 .113 .304 r
.50404 .42495 .51004 .40507 .52067 .40234 .51478 .42247 Mtetra
.474 .137 .315 r
.51478 .42247 .52067 .40234 .53134 .40076 .52556 .42118 Mtetra
.498 .161 .326 r
.52556 .42118 .53134 .40076 .54208 .40077 .53641 .42114 Mtetra
.523 .184 .334 r
.53641 .42114 .54208 .40077 .55291 .40325 .54734 .42259 Mtetra
.539 .192 .329 r
.54734 .42259 .55291 .40325 .56384 .40816 .55835 .42505 Mtetra
.541 .18 .304 r
.55835 .42505 .56384 .40816 .57492 .41543 .56945 .42779 Mtetra
.51 .112 .222 r
.56945 .42779 .57492 .41543 .58613 .42361 .58063 .42953 Mtetra
.289 0 0 r
.58063 .42953 .58613 .42361 .59742 .43016 .59181 .42813 Mtetra
.667 .929 .971 r
.59181 .42813 .59742 .43016 .60875 .43348 .60297 .42297 Mtetra
.768 .697 .784 r
.60297 .42297 .60875 .43348 .62001 .43129 .61404 .41323 Mtetra
.74 .6 .701 r
.61404 .41323 .62001 .43129 .63117 .42421 .62501 .40036 Mtetra
.713 .552 .669 r
.62501 .40036 .63117 .42421 .64222 .41363 .63594 .38668 Mtetra
.693 .528 .659 r
.63594 .38668 .64222 .41363 .65319 .40116 .64686 .37364 Mtetra
.669 .51 .661 r
.64686 .37364 .65319 .40116 .66415 .38889 .65787 .36314 Mtetra
.65 .505 .673 r
.65787 .36314 .66415 .38889 .67515 .3776 .669 .3552 Mtetra
.631 .509 .696 r
.669 .3552 .67515 .3776 .68622 .36813 .68026 .34983 Mtetra
.612 .526 .733 r
.68026 .34983 .68622 .36813 .69741 .36053 .69167 .3465 Mtetra
.59 .56 .789 r
.69167 .3465 .69741 .36053 .70873 .35501 .70321 .3447 Mtetra
.559 .611 .861 r
.70321 .3447 .70873 .35501 .72019 .35113 .71487 .34383 Mtetra
.521 .678 .937 r
.71487 .34383 .72019 .35113 .73177 .34847 .72661 .34324 Mtetra
.475 .735 .984 r
.72661 .34324 .73177 .34847 .74347 .34657 .73843 .34258 Mtetra
.46 .781 .998 r
.73843 .34258 .74347 .34657 .75523 .34488 .75028 .34139 Mtetra
.475 .81 .999 r
.75028 .34139 .75523 .34488 .76707 .34318 .76215 .33965 Mtetra
.524 .834 1 r
.76215 .33965 .76707 .34318 .77894 .34112 .77404 .33722 Mtetra
.573 .841 .995 r
.77404 .33722 .77894 .34112 .79084 .33874 .78594 .33423 Mtetra
.615 .834 .984 r
.78594 .33423 .79084 .33874 .80277 .33595 .79786 .33076 Mtetra
.641 .818 .968 r
.79786 .33076 .80277 .33595 .81473 .33284 .8098 .32694 Mtetra
.656 .797 .95 r
.8098 .32694 .81473 .33284 .82673 .32951 .82177 .3229 Mtetra
.662 .775 .933 r
.82177 .3229 .82673 .32951 .83876 .32602 .83378 .31877 Mtetra
.616 .741 .935 r
.19348 .52013 .20012 .52592 .20968 .52298 .203 .51783 Mtetra
.609 .763 .953 r
.203 .51783 .20968 .52298 .21929 .51995 .21256 .51555 Mtetra
.605 .792 .971 r
.21256 .51555 .21929 .51995 .22896 .51672 .22217 .51317 Mtetra
.601 .826 .986 r
.22217 .51317 .22896 .51672 .23869 .51315 .23184 .51057 Mtetra
.595 .863 .993 r
.23184 .51057 .23869 .51315 .24849 .50913 .24158 .50767 Mtetra
.59 .901 .985 r
.24158 .50767 .24849 .50913 .25836 .50457 .25139 .50426 Mtetra
.588 .929 .955 r
.25139 .50426 .25836 .50457 .26831 .49935 .26129 .50015 Mtetra
.588 .944 .908 r
.26129 .50015 .26831 .49935 .27833 .49359 .27129 .4952 Mtetra
.618 .959 .869 r
.27129 .4952 .27833 .49359 .2884 .48731 .28139 .48924 Mtetra
.668 .975 .857 r
.28139 .48924 .2884 .48731 .2985 .48096 .29158 .48237 Mtetra
.753 .992 .88 r
.29158 .48237 .2985 .48096 .3086 .47486 .30184 .47459 Mtetra
.814 .963 .905 r
.30184 .47459 .3086 .47486 .31866 .46967 .31214 .46643 Mtetra
.816 .865 .884 r
.31214 .46643 .31866 .46967 .32866 .46596 .32244 .45826 Mtetra
.758 .728 .825 r
.32244 .45826 .32866 .46596 .33858 .46424 .33271 .45084 Mtetra
.686 .605 .76 r
.33271 .45084 .33858 .46424 .34842 .46502 .34292 .44479 Mtetra
.627 .513 .704 r
.34292 .44479 .34842 .46502 .35818 .46834 .35306 .44038 Mtetra
.583 .448 .663 r
.35306 .44038 .35818 .46834 .36791 .47415 .36313 .43794 Mtetra
.551 .403 .634 r
.36313 .43794 .36791 .47415 .3777 .48062 .37315 .43767 Mtetra
.526 .373 .616 r
.37315 .43767 .3777 .48062 .38762 .48633 .38312 .4398 Mtetra
.501 .349 .607 r
.38312 .4398 .38762 .48633 .39776 .489 .39305 .44463 Mtetra
.47 .33 .609 r
.39305 .44463 .39776 .489 .40813 .48718 .40298 .45208 Mtetra
.431 .323 .63 r
.40298 .45208 .40813 .48718 .41866 .48166 .41298 .46059 Mtetra
.336 .325 .698 r
.41298 .46059 .41866 .48166 .42932 .47303 .42309 .46895 Mtetra
0 .189 .613 r
.42309 .46895 .42932 .47303 .44001 .46339 .43338 .47544 Mtetra
.559 .163 .247 r
.43338 .47544 .44001 .46339 .45069 .45401 .44384 .47906 Mtetra
.521 .2 .365 r
.44384 .47906 .45069 .45401 .46136 .44561 .45444 .48011 Mtetra
.501 .207 .399 r
.45444 .48011 .46136 .44561 .47201 .43867 .46516 .47882 Mtetra
.494 .211 .414 r
.46516 .47882 .47201 .43867 .48267 .43296 .47595 .47626 Mtetra
.491 .213 .42 r
.47595 .47626 .48267 .43296 .49334 .42845 .4868 .47302 Mtetra
.49 .214 .423 r
.4868 .47302 .49334 .42845 .50404 .42495 .49769 .46954 Mtetra
.488 .213 .422 r
.49769 .46954 .50404 .42495 .51478 .42247 .50863 .46582 Mtetra
.48 .204 .417 r
.50863 .46582 .51478 .42247 .52556 .42118 .51961 .46141 Mtetra
.462 .184 .405 r
.51961 .46141 .52556 .42118 .53641 .42114 .53063 .45572 Mtetra
.417 .135 .375 r
.53063 .45572 .53641 .42114 .54734 .42259 .54166 .44768 Mtetra
.308 .014 .292 r
.54166 .44768 .54734 .42259 .55835 .42505 .55269 .437 Mtetra
0 0 0 r
.55269 .437 .55835 .42505 .56945 .42779 .56368 .42341 Mtetra
.904 .846 .776 r
.56368 .42341 .56945 .42779 .58063 .42953 .57461 .40787 Mtetra
.742 .579 .673 r
.57461 .40787 .58063 .42953 .59181 .42813 .58551 .39215 Mtetra
.674 .491 .63 r
.58551 .39215 .59181 .42813 .60297 .42297 .59639 .37746 Mtetra
.634 .448 .614 r
.59639 .37746 .60297 .42297 .61404 .41323 .6073 .36541 Mtetra
.613 .43 .611 r
.6073 .36541 .61404 .41323 .62501 .40036 .61828 .35608 Mtetra
.601 .427 .618 r
.61828 .35608 .62501 .40036 .63594 .38668 .62934 .34918 Mtetra
.592 .432 .634 r
.62934 .34918 .63594 .38668 .64686 .37364 .64051 .34449 Mtetra
.582 .448 .664 r
.64051 .34449 .64686 .37364 .65787 .36314 .65179 .34182 Mtetra
.567 .476 .711 r
.65179 .34182 .65787 .36314 .669 .3552 .66321 .34082 Mtetra
.532 .523 .791 r
.66321 .34082 .669 .3552 .68026 .34983 .67475 .34124 Mtetra
.451 .6 .908 r
.67475 .34124 .68026 .34983 .69167 .3465 .68642 .34246 Mtetra
.262 .665 .967 r
.68642 .34246 .69167 .3465 .70321 .3447 .69817 .34367 Mtetra
.019 .586 .786 r
.69817 .34367 .70321 .3447 .71487 .34383 .70998 .3445 Mtetra
.057 0 0 r
.70998 .3445 .71487 .34383 .72661 .34324 .72181 .34441 Mtetra
.016 0 0 r
.72181 .34441 .72661 .34324 .73843 .34258 .73366 .34339 Mtetra
.124 .67 .699 r
.73366 .34339 .73843 .34258 .75028 .34139 .74551 .34132 Mtetra
.304 .798 .835 r
.74551 .34132 .75028 .34139 .76215 .33965 .75736 .33837 Mtetra
.479 .885 .943 r
.75736 .33837 .76215 .33965 .77404 .33722 .76921 .3347 Mtetra
.593 .903 .984 r
.76921 .3347 .77404 .33722 .78594 .33423 .78107 .3305 Mtetra
.651 .881 .983 r
.78107 .3305 .78594 .33423 .79786 .33076 .79294 .32597 Mtetra
.677 .849 .965 r
.79294 .32597 .79786 .33076 .8098 .32694 .80484 .3212 Mtetra
.687 .817 .945 r
.80484 .3212 .8098 .32694 .82177 .3229 .81678 .31633 Mtetra
.687 .788 .927 r
.81678 .31633 .82177 .3229 .83378 .31877 .82876 .31146 Mtetra
.599 .736 .94 r
.18679 .51429 .19348 .52013 .203 .51783 .1963 .51231 Mtetra
.589 .745 .951 r
.1963 .51231 .203 .51783 .21256 .51555 .20584 .51043 Mtetra
.58 .758 .963 r
.20584 .51043 .21256 .51555 .22217 .51317 .21542 .50859 Mtetra
.57 .777 .976 r
.21542 .50859 .22217 .51317 .23184 .51057 .22505 .50675 Mtetra
.552 .802 .991 r
.22505 .50675 .23184 .51057 .24158 .50767 .23471 .50488 Mtetra
.534 .837 .999 r
.23471 .50488 .24158 .50767 .25139 .50426 .24445 .50276 Mtetra
.5 .868 .983 r
.24445 .50276 .25139 .50426 .26129 .50015 .25426 .50027 Mtetra
.447 .877 .913 r
.25426 .50027 .26129 .50015 .27129 .4952 .26416 .49711 Mtetra
.382 .841 .781 r
.26416 .49711 .27129 .4952 .28139 .48924 .27416 .49303 Mtetra
0 0 0 r
.27416 .49303 .28139 .48924 .29158 .48237 .28428 .48786 Mtetra
.28428 .48786 .29158 .48237 .30184 .47459 .29452 .48138 Mtetra
.29452 .48138 .30184 .47459 .31214 .46643 .30485 .47376 Mtetra
.30485 .47376 .31214 .46643 .32244 .45826 .31526 .46503 Mtetra
.31526 .46503 .32244 .45826 .33271 .45084 .32571 .45574 Mtetra
.616 .921 .664 r
.32571 .45574 .33271 .45084 .34292 .44479 .33618 .44626 Mtetra
.806 .996 .86 r
.33618 .44626 .34292 .44479 .35306 .44038 .34663 .43706 Mtetra
.82 .868 .882 r
.34663 .43706 .35306 .44038 .36313 .43794 .35704 .42865 Mtetra
.726 .688 .814 r
.35704 .42865 .36313 .43794 .37315 .43767 .36737 .4221 Mtetra
.634 .556 .749 r
.36737 .4221 .37315 .43767 .38312 .4398 .37759 .41821 Mtetra
.558 .462 .702 r
.37759 .41821 .38312 .4398 .39305 .44463 .38771 .41769 Mtetra
.497 .395 .669 r
.38771 .41769 .39305 .44463 .40298 .45208 .39775 .4208 Mtetra
.473 .363 .648 r
.39775 .4208 .40298 .45208 .41298 .46059 .40779 .42585 Mtetra
.469 .35 .635 r
.40779 .42585 .41298 .46059 .42309 .46895 .4179 .43171 Mtetra
.487 .357 .629 r
.4179 .43171 .42309 .46895 .43338 .47544 .42814 .43666 Mtetra
.513 .373 .627 r
.42814 .43666 .43338 .47544 .44384 .47906 .43853 .43967 Mtetra
.535 .387 .627 r
.43853 .43967 .44384 .47906 .45444 .48011 .44904 .44079 Mtetra
.554 .401 .628 r
.44904 .44079 .45444 .48011 .46516 .47882 .45966 .44001 Mtetra
.566 .411 .63 r
.45966 .44001 .46516 .47882 .47595 .47626 .47036 .43802 Mtetra
.575 .419 .631 r
.47036 .43802 .47595 .47626 .4868 .47302 .48113 .43511 Mtetra
.582 .424 .632 r
.48113 .43511 .4868 .47302 .49769 .46954 .49194 .43158 Mtetra
.587 .428 .632 r
.49194 .43158 .49769 .46954 .50863 .46582 .50281 .42741 Mtetra
.595 .432 .631 r
.50281 .42741 .50863 .46582 .51961 .46141 .51372 .42233 Mtetra
.604 .437 .629 r
.51372 .42233 .51961 .46141 .53063 .45572 .52466 .41601 Mtetra
.618 .446 .627 r
.52466 .41601 .53063 .45572 .54166 .44768 .53562 .40778 Mtetra
.632 .456 .625 r
.53562 .40778 .54166 .44768 .55269 .437 .54658 .39762 Mtetra
.648 .467 .625 r
.54658 .39762 .55269 .437 .56368 .42341 .55752 .38548 Mtetra
.657 .476 .627 r
.55752 .38548 .56368 .42341 .57461 .40787 .56843 .37238 Mtetra
.658 .481 .633 r
.56843 .37238 .57461 .40787 .58551 .39215 .57933 .36006 Mtetra
.652 .485 .644 r
.57933 .36006 .58551 .39215 .59639 .37746 .59026 .34971 Mtetra
.63 .484 .664 r
.59026 .34971 .59639 .37746 .6073 .36541 .60127 .34301 Mtetra
.601 .49 .699 r
.60127 .34301 .6073 .36541 .61828 .35608 .6124 .33974 Mtetra
.558 .512 .76 r
.6124 .33974 .61828 .35608 .62934 .34918 .62367 .33919 Mtetra
.465 .568 .875 r
.62367 .33919 .62934 .34918 .64051 .34449 .63506 .34055 Mtetra
.154 .6 .933 r
.63506 .34055 .64051 .34449 .65179 .34182 .64658 .34272 Mtetra
.311 0 0 r
.64658 .34272 .65179 .34182 .66321 .34082 .65819 .34522 Mtetra
.44 0 0 r
.65819 .34522 .66321 .34082 .67475 .34124 .6699 .34754 Mtetra
.451 0 0 r
.6699 .34754 .67475 .34124 .68642 .34246 .68166 .34929 Mtetra
.413 0 0 r
.68166 .34929 .68642 .34246 .69817 .34367 .69346 .34993 Mtetra
.344 0 0 r
.69346 .34993 .69817 .34367 .70998 .3445 .70526 .34939 Mtetra
.214 0 0 r
.70526 .34939 .70998 .3445 .72181 .34441 .71707 .3475 Mtetra
.006 0 0 r
.71707 .3475 .72181 .34441 .73366 .34339 .72886 .34449 Mtetra
.281 .776 .734 r
.72886 .34449 .73366 .34339 .74551 .34132 .74064 .34052 Mtetra
.523 .913 .921 r
.74064 .34052 .74551 .34132 .75736 .33837 .75242 .33586 Mtetra
.646 .923 .976 r
.75242 .33586 .75736 .33837 .76921 .3347 .76422 .33078 Mtetra
.692 .887 .97 r
.76422 .33078 .76921 .3347 .78107 .3305 .77604 .32545 Mtetra
.703 .848 .952 r
.77604 .32545 .78107 .3305 .79294 .32597 .78789 .32008 Mtetra
.706 .819 .935 r
.78789 .32008 .79294 .32597 .80484 .3212 .79978 .3147 Mtetra
.703 .797 .923 r
.79978 .3147 .80484 .3212 .81678 .31633 .81172 .30935 Mtetra
.698 .78 .914 r
.81172 .30935 .81678 .31633 .82876 .31146 .82371 .3041 Mtetra
.604 .737 .939 r
.18006 .50842 .18679 .51429 .1963 .51231 .1896 .50631 Mtetra
.597 .731 .938 r
.1896 .50631 .1963 .51231 .20584 .51043 .19916 .50435 Mtetra
.587 .726 .94 r
.19916 .50435 .20584 .51043 .21542 .50859 .20875 .50257 Mtetra
.573 .724 .945 r
.20875 .50257 .21542 .50859 .22505 .50675 .21837 .501 Mtetra
.552 .728 .956 r
.21837 .501 .22505 .50675 .23471 .50488 .228 .49972 Mtetra
.528 .742 .973 r
.228 .49972 .23471 .50488 .24445 .50276 .23767 .49859 Mtetra
.488 .767 .993 r
.23767 .49859 .24445 .50276 .25426 .50027 .24738 .49758 Mtetra
.424 .798 .993 r
.24738 .49758 .25426 .50027 .26416 .49711 .25714 .49643 Mtetra
.294 .782 .9 r
.25714 .49643 .26416 .49711 .27416 .49303 .26699 .49496 Mtetra
0 0 0 r
.26699 .49496 .27416 .49303 .28428 .48786 .27692 .49285 Mtetra
.06 0 0 r
.27692 .49285 .28428 .48786 .29452 .48138 .28697 .48978 Mtetra
.154 0 0 r
.28697 .48978 .29452 .48138 .30485 .47376 .29715 .48552 Mtetra
.19 0 .034 r
.29715 .48552 .30485 .47376 .31526 .46503 .30745 .47979 Mtetra
.201 0 .105 r
.30745 .47979 .31526 .46503 .32571 .45574 .31787 .47255 Mtetra
.184 0 .132 r
.31787 .47255 .32571 .45574 .33618 .44626 .3284 .46376 Mtetra
.162 0 .133 r
.3284 .46376 .33618 .44626 .34663 .43706 .33899 .45402 Mtetra
.126 0 .108 r
.33899 .45402 .34663 .43706 .35704 .42865 .3496 .44376 Mtetra
.077 0 .054 r
.3496 .44376 .35704 .42865 .36737 .4221 .3602 .43369 Mtetra
0 0 0 r
.3602 .43369 .36737 .4221 .37759 .41821 .37077 .42423 Mtetra
.486 .826 .538 r
.37077 .42423 .37759 .41821 .38771 .41769 .38135 .41471 Mtetra
.848 .881 .864 r
.38135 .41471 .38771 .41769 .39775 .4208 .39194 .40489 Mtetra
.724 .602 .72 r
.39194 .40489 .39775 .4208 .40779 .42585 .40253 .39483 Mtetra
.655 .488 .646 r
.40253 .39483 .40779 .42585 .4179 .43171 .41313 .38473 Mtetra
.613 .43 .61 r
.41313 .38473 .4179 .43171 .42814 .43666 .42369 .3757 Mtetra
.588 .398 .592 r
.42369 .3757 .42814 .43666 .43853 .43967 .43421 .36825 Mtetra
.573 .38 .582 r
.43421 .36825 .43853 .43967 .44904 .44079 .4447 .36242 Mtetra
.562 .369 .576 r
.4447 .36242 .44904 .44079 .45966 .44001 .45519 .35807 Mtetra
.558 .364 .574 r
.45519 .35807 .45966 .44001 .47036 .43802 .46569 .35438 Mtetra
.557 .362 .573 r
.46569 .35438 .47036 .43802 .48113 .43511 .47624 .35092 Mtetra
.47624 .35092 .48113 .43511 .49194 .43158 .48683 .34729 Mtetra
.558 .363 .573 r
.48683 .34729 .49194 .43158 .50281 .42741 .49746 .3435 Mtetra
.557 .362 .573 r
.49746 .3435 .50281 .42741 .51372 .42233 .50813 .33994 Mtetra
.554 .361 .574 r
.50813 .33994 .51372 .42233 .52466 .41601 .51884 .33704 Mtetra
.548 .358 .575 r
.51884 .33704 .52466 .41601 .53562 .40778 .5296 .33564 Mtetra
.54 .356 .58 r
.5296 .33564 .53562 .40778 .54658 .39762 .54043 .33587 Mtetra
.53 .355 .589 r
.54043 .33587 .54658 .39762 .55752 .38548 .55134 .33771 Mtetra
.519 .362 .608 r
.55134 .33771 .55752 .38548 .56843 .37238 .56234 .34066 Mtetra
.508 .389 .652 r
.56234 .34066 .56843 .37238 .57933 .36006 .57344 .34359 Mtetra
.472 .46 .763 r
.57344 .34359 .57933 .36006 .59026 .34971 .58462 .34628 Mtetra
.072 .563 .894 r
.58462 .34628 .59026 .34971 .60127 .34301 .59588 .3487 Mtetra
.472 0 0 r
.59588 .3487 .60127 .34301 .6124 .33974 .60724 .35108 Mtetra
.532 .117 .2 r
.60724 .35108 .6124 .33974 .62367 .33919 .6187 .35411 Mtetra
.542 .159 .266 r
.6187 .35411 .62367 .33919 .63506 .34055 .63026 .35734 Mtetra
.534 .165 .286 r
.63026 .35734 .63506 .34055 .64658 .34272 .6419 .36007 Mtetra
.517 .152 .286 r
.6419 .36007 .64658 .34272 .65819 .34522 .6536 .36185 Mtetra
.483 .116 .266 r
.6536 .36185 .65819 .34522 .6699 .34754 .66532 .36205 Mtetra
.436 .055 .217 r
.66532 .36205 .6699 .34754 .68166 .34929 .67704 .3607 Mtetra
.355 0 .122 r
.67704 .3607 .68166 .34929 .69346 .34993 .68875 .35785 Mtetra
.211 0 0 r
.68875 .35785 .69346 .34993 .70526 .34939 .70045 .35375 Mtetra
0 0 0 r
.70045 .35375 .70526 .34939 .71707 .3475 .71213 .34867 Mtetra
.442 .872 .774 r
.71213 .34867 .71707 .3475 .72886 .34449 .72382 .3429 Mtetra
.669 .955 .948 r
.72382 .3429 .72886 .34449 .74064 .34052 .73552 .33679 Mtetra
.73 .904 .956 r
.73552 .33679 .74064 .34052 .75242 .33586 .74724 .33053 Mtetra
.732 .845 .934 r
.74724 .33053 .75242 .33586 .76422 .33078 .759 .32438 Mtetra
.725 .806 .915 r
.759 .32438 .76422 .33078 .77604 .32545 .77081 .31839 Mtetra
.713 .781 .905 r
.77081 .31839 .77604 .32545 .78789 .32008 .78267 .31267 Mtetra
.705 .768 .901 r
.78267 .31267 .78789 .32008 .79978 .3147 .7946 .30717 Mtetra
.699 .763 .902 r
.7946 .30717 .79978 .3147 .81172 .30935 .80657 .30185 Mtetra
.694 .763 .905 r
.80657 .30185 .81172 .30935 .82371 .3041 .81861 .29669 Mtetra
.636 .746 .928 r
.17328 .5025 .18006 .50842 .1896 .50631 .1829 .49973 Mtetra
.631 .723 .914 r
.1829 .49973 .1896 .50631 .19916 .50435 .19255 .49709 Mtetra
.622 .7 .9 r
.19255 .49709 .19916 .50435 .20875 .50257 .20222 .49466 Mtetra
.61 .677 .889 r
.20222 .49466 .20875 .50257 .21837 .501 .21189 .49256 Mtetra
.592 .656 .882 r
.21189 .49256 .21837 .501 .228 .49972 .22157 .49088 Mtetra
.575 .639 .877 r
.22157 .49088 .228 .49972 .23767 .49859 .23126 .48962 Mtetra
.553 .628 .88 r
.23126 .48962 .23767 .49859 .24738 .49758 .24095 .48886 Mtetra
.534 .627 .889 r
.24095 .48886 .24738 .49758 .25714 .49643 .25066 .48844 Mtetra
.511 .638 .911 r
.25066 .48844 .25714 .49643 .26699 .49496 .26041 .4883 Mtetra
.488 .674 .946 r
.26041 .4883 .26699 .49496 .27692 .49285 .27022 .48815 Mtetra
.446 .732 .988 r
.27022 .48815 .27692 .49285 .28697 .48978 .28009 .48776 Mtetra
.35 .785 .966 r
.28009 .48776 .28697 .48978 .29715 .48552 .29007 .48675 Mtetra
.154 .692 .715 r
.29007 .48675 .29715 .48552 .30745 .47979 .30017 .48477 Mtetra
.043 0 0 r
.30017 .48477 .30745 .47979 .31787 .47255 .31039 .48153 Mtetra
.144 0 0 r
.31039 .48153 .31787 .47255 .3284 .46376 .32075 .47676 Mtetra
.214 0 .074 r
.32075 .47676 .3284 .46376 .33899 .45402 .33121 .47075 Mtetra
.253 0 .163 r
.33121 .47075 .33899 .45402 .3496 .44376 .34176 .46363 Mtetra
.271 0 .212 r
.34176 .46363 .3496 .44376 .3602 .43369 .35238 .45542 Mtetra
.266 0 .229 r
.35238 .45542 .3602 .43369 .37077 .42423 .36307 .44614 Mtetra
.221 0 .212 r
.36307 .44614 .37077 .42423 .38135 .41471 .37383 .43532 Mtetra
.142 0 .164 r
.37383 .43532 .38135 .41471 .39194 .40489 .38465 .42295 Mtetra
.057 0 .094 r
.38465 .42295 .39194 .40489 .40253 .39483 .39547 .4102 Mtetra
0 0 .016 r
.39547 .4102 .40253 .39483 .41313 .38473 .40625 .39789 Mtetra
0 0 0 r
.40625 .39789 .41313 .38473 .42369 .3757 .41697 .38729 Mtetra
.056 0 0 r
.41697 .38729 .42369 .3757 .43421 .36825 .4276 .379 Mtetra
.142 0 0 r
.4276 .379 .43421 .36825 .4447 .36242 .43819 .37266 Mtetra
.221 0 .02 r
.43819 .37266 .4447 .36242 .45519 .35807 .44877 .36795 Mtetra
.254 0 .027 r
.44877 .36795 .45519 .35807 .46569 .35438 .45936 .36401 Mtetra
.265 0 .026 r
.45936 .36401 .46569 .35438 .47624 .35092 .46999 .36039 Mtetra
.261 0 .018 r
.46999 .36039 .47624 .35092 .48683 .34729 .48066 .35676 Mtetra
.26 0 .018 r
.48066 .35676 .48683 .34729 .49746 .3435 .49137 .3531 Mtetra
.282 0 .034 r
.49137 .3531 .49746 .3435 .50813 .33994 .50212 .34975 Mtetra
.326 0 .064 r
.50212 .34975 .50813 .33994 .51884 .33704 .51291 .34719 Mtetra
.403 0 .113 r
.51291 .34719 .51884 .33704 .5296 .33564 .52375 .34628 Mtetra
.476 .056 .162 r
.52375 .34628 .5296 .33564 .54043 .33587 .53466 .34733 Mtetra
.544 .133 .213 r
.53466 .34733 .54043 .33587 .55134 .33771 .54567 .35074 Mtetra
.581 .185 .257 r
.54567 .35074 .55134 .33771 .56234 .34066 .55678 .35591 Mtetra
.587 .207 .29 r
.55678 .35591 .56234 .34066 .57344 .34359 .56801 .36155 Mtetra
.577 .214 .316 r
.56801 .36155 .57344 .34359 .58462 .34628 .57934 .36684 Mtetra
.551 .202 .33 r
.57934 .36684 .58462 .34628 .59588 .3487 .59075 .37058 Mtetra
.528 .187 .333 r
.59075 .37058 .59588 .3487 .60724 .35108 .60222 .37278 Mtetra
.511 .17 .325 r
.60222 .37278 .60724 .35108 .6187 .35411 .61375 .3739 Mtetra
.488 .139 .301 r
.61375 .3739 .6187 .35411 .63026 .35734 .62533 .37392 Mtetra
.452 .086 .251 r
.62533 .37392 .63026 .35734 .6419 .36007 .63694 .37281 Mtetra
.386 0 .161 r
.63694 .37281 .6419 .36007 .6536 .36185 .64857 .37044 Mtetra
.234 0 0 r
.64857 .37044 .6536 .36185 .66532 .36205 .6602 .36649 Mtetra
0 0 0 r
.6602 .36649 .66532 .36205 .67704 .3607 .67181 .36124 Mtetra
.553 .932 .847 r
.67181 .36124 .67704 .3607 .68875 .35785 .68342 .35499 Mtetra
.748 .934 .948 r
.68342 .35499 .68875 .35785 .70045 .35375 .69501 .34807 Mtetra
.764 .837 .908 r
.69501 .34807 .70045 .35375 .71213 .34867 .70662 .3409 Mtetra
.749 .768 .869 r
.70662 .3409 .71213 .34867 .72382 .3429 .71826 .3337 Mtetra
.73 .725 .846 r
.71826 .3337 .72382 .3429 .73552 .33679 .72994 .32678 Mtetra
.716 .702 .836 r
.72994 .32678 .73552 .33679 .74724 .33053 .74166 .3202 Mtetra
.702 .69 .835 r
.74166 .3202 .74724 .33053 .759 .32438 .75346 .31413 Mtetra
.692 .688 .841 r
.75346 .31413 .759 .32438 .77081 .31839 .76532 .30848 Mtetra
.683 .693 .853 r
.76532 .30848 .77081 .31839 .78267 .31267 .77726 .30328 Mtetra
.677 .703 .867 r
.77726 .30328 .78267 .31267 .7946 .30717 .78927 .29839 Mtetra
.673 .718 .883 r
.78927 .29839 .7946 .30717 .80657 .30185 .80134 .29374 Mtetra
.671 .737 .9 r
.80134 .29374 .80657 .30185 .81861 .29669 .81347 .28921 Mtetra
.676 .756 .911 r
.16646 .49655 .17328 .5025 .1829 .49973 .1762 .4928 Mtetra
.671 .725 .89 r
.1762 .4928 .1829 .49973 .19255 .49709 .18597 .48911 Mtetra
.661 .693 .869 r
.18597 .48911 .19255 .49709 .20222 .49466 .19575 .48559 Mtetra
.647 .662 .85 r
.19575 .48559 .20222 .49466 .21189 .49256 .20555 .48236 Mtetra
.631 .631 .833 r
.20555 .48236 .21189 .49256 .22157 .49088 .21534 .47953 Mtetra
.612 .602 .816 r
.21534 .47953 .22157 .49088 .23126 .48962 .22512 .47721 Mtetra
.591 .574 .803 r
.22512 .47721 .23126 .48962 .24095 .48886 .23489 .47552 Mtetra
.571 .55 .792 r
.23489 .47552 .24095 .48886 .25066 .48844 .24465 .47448 Mtetra
.549 .53 .786 r
.24465 .47448 .25066 .48844 .26041 .4883 .2544 .47415 Mtetra
.531 .517 .785 r
.2544 .47415 .26041 .4883 .27022 .48815 .26417 .47438 Mtetra
.513 .514 .794 r
.26417 .47438 .27022 .48815 .28009 .48776 .27395 .47512 Mtetra
.498 .524 .815 r
.27395 .47512 .28009 .48776 .29007 .48675 .28378 .4761 Mtetra
.479 .556 .856 r
.28378 .4761 .29007 .48675 .30017 .48477 .29367 .47712 Mtetra
.441 .622 .928 r
.29367 .47712 .30017 .48477 .31039 .48153 .30365 .47792 Mtetra
.298 .705 .975 r
.30365 .47792 .31039 .48153 .32075 .47676 .31371 .47829 Mtetra
.102 0 0 r
.31371 .47829 .32075 .47676 .33121 .47075 .32388 .47796 Mtetra
.316 0 0 r
.32388 .47796 .33121 .47075 .34176 .46363 .33416 .47667 Mtetra
.36 0 .15 r
.33416 .47667 .34176 .46363 .35238 .45542 .34458 .47385 Mtetra
.365 .017 .235 r
.34458 .47385 .35238 .45542 .36307 .44614 .35514 .46926 Mtetra
.381 .058 .287 r
.35514 .46926 .36307 .44614 .37383 .43532 .36578 .46371 Mtetra
.407 .102 .332 r
.36578 .46371 .37383 .43532 .38465 .42295 .37646 .45782 Mtetra
.446 .154 .375 r
.37646 .45782 .38465 .42295 .39547 .4102 .38712 .45287 Mtetra
.48 .198 .408 r
.38712 .45287 .39547 .4102 .40625 .39789 .39776 .44947 Mtetra
.497 .224 .43 r
.39776 .44947 .40625 .39789 .41697 .38729 .40841 .44701 Mtetra
.506 .239 .443 r
.40841 .44701 .41697 .38729 .4276 .379 .41909 .44512 Mtetra
.507 .244 .45 r
.41909 .44512 .4276 .379 .43819 .37266 .42982 .44298 Mtetra
.505 .245 .453 r
.42982 .44298 .43819 .37266 .44877 .36795 .44063 .44023 Mtetra
.504 .245 .455 r
.44063 .44023 .44877 .36795 .45936 .36401 .45149 .43706 Mtetra
.502 .244 .455 r
.45149 .43706 .45936 .36401 .46999 .36039 .46241 .43354 Mtetra
.502 .243 .455 r
.46241 .43354 .46999 .36039 .48066 .35676 .47337 .42994 Mtetra
.47337 .42994 .48066 .35676 .49137 .3531 .48438 .42627 Mtetra
.5 .241 .454 r
.48438 .42627 .49137 .3531 .50212 .34975 .49543 .42224 Mtetra
.497 .239 .453 r
.49543 .42224 .50212 .34975 .51291 .34719 .50653 .41779 Mtetra
.492 .234 .451 r
.50653 .41779 .51291 .34719 .52375 .34628 .51767 .41272 Mtetra
.488 .228 .446 r
.51767 .41272 .52375 .34628 .53466 .34733 .52885 .40739 Mtetra
.488 .223 .439 r
.52885 .40739 .53466 .34733 .54567 .35074 .54006 .40263 Mtetra
.488 .216 .427 r
.54006 .40263 .54567 .35074 .55678 .35591 .55132 .39882 Mtetra
.493 .209 .411 r
.55132 .39882 .55678 .35591 .56801 .36155 .56264 .39659 Mtetra
.494 .196 .389 r
.56264 .39659 .56801 .36155 .57934 .36684 .57403 .39531 Mtetra
.48 .167 .357 r
.57403 .39531 .57934 .36684 .59075 .37058 .58549 .39369 Mtetra
.45 .12 .314 r
.58549 .39369 .59075 .37058 .60222 .37278 .59698 .39111 Mtetra
.383 .035 .246 r
.59698 .39111 .60222 .37278 .61375 .3739 .60848 .38671 Mtetra
.253 0 .103 r
.60848 .38671 .61375 .3739 .62533 .37392 .61998 .38074 Mtetra
0 0 0 r
.61998 .38074 .62533 .37392 .63694 .37281 .63148 .37378 Mtetra
.634 .963 .831 r
.63148 .37378 .63694 .37281 .64857 .37044 .64298 .36608 Mtetra
.796 .884 .909 r
.64298 .36608 .64857 .37044 .6602 .36649 .65447 .35792 Mtetra
.767 .75 .838 r
.65447 .35792 .6602 .36649 .67181 .36124 .66598 .34952 Mtetra
.736 .675 .792 r
.66598 .34952 .67181 .36124 .68342 .35499 .6775 .34115 Mtetra
.714 .635 .767 r
.6775 .34115 .68342 .35499 .69501 .34807 .68905 .333 Mtetra
.697 .611 .757 r
.68905 .333 .69501 .34807 .70662 .3409 .70064 .32536 Mtetra
.685 .6 .755 r
.70064 .32536 .70662 .3409 .71826 .3337 .7123 .3183 Mtetra
.673 .596 .761 r
.7123 .3183 .71826 .3337 .72994 .32678 .72402 .31196 Mtetra
.665 .599 .771 r
.72402 .31196 .72994 .32678 .74166 .3202 .73582 .30628 Mtetra
.657 .607 .787 r
.73582 .30628 .74166 .3202 .75346 .31413 .7477 .30124 Mtetra
.651 .62 .806 r
.7477 .30124 .75346 .31413 .76532 .30848 .75967 .29673 Mtetra
.646 .638 .828 r
.75967 .29673 .76532 .30848 .77726 .30328 .77172 .29264 Mtetra
.642 .659 .852 r
.77172 .29264 .77726 .30328 .78927 .29839 .78385 .28885 Mtetra
.639 .684 .876 r
.78385 .28885 .78927 .29839 .80134 .29374 .79604 .28523 Mtetra
.638 .713 .901 r
.79604 .28523 .80134 .29374 .81347 .28921 .8083 .28168 Mtetra
.705 .762 .896 r
.15958 .49055 .16646 .49655 .1762 .4928 .16944 .48593 Mtetra
.701 .735 .877 r
.16944 .48593 .1762 .4928 .18597 .48911 .17933 .48128 Mtetra
.693 .708 .859 r
.17933 .48128 .18597 .48911 .19575 .48559 .18924 .47668 Mtetra
.682 .679 .841 r
.18924 .47668 .19575 .48559 .20555 .48236 .19916 .47224 Mtetra
.669 .649 .822 r
.19916 .47224 .20555 .48236 .21534 .47953 .20909 .46803 Mtetra
.652 .618 .802 r
.20909 .46803 .21534 .47953 .22512 .47721 .21902 .46418 Mtetra
.633 .586 .783 r
.21902 .46418 .22512 .47721 .23489 .47552 .22893 .46082 Mtetra
.613 .554 .765 r
.22893 .46082 .23489 .47552 .24465 .47448 .23883 .45807 Mtetra
.591 .524 .748 r
.23883 .45807 .24465 .47448 .2544 .47415 .24871 .45606 Mtetra
.572 .497 .732 r
.24871 .45606 .2544 .47415 .26417 .47438 .25857 .4548 Mtetra
.553 .473 .72 r
.25857 .4548 .26417 .47438 .27395 .47512 .26842 .45436 Mtetra
.537 .455 .711 r
.26842 .45436 .27395 .47512 .28378 .4761 .27828 .45463 Mtetra
.523 .442 .706 r
.27828 .45463 .28378 .4761 .29367 .47712 .28814 .45556 Mtetra
.512 .435 .706 r
.28814 .45556 .29367 .47712 .30365 .47792 .29803 .45698 Mtetra
.503 .434 .711 r
.29803 .45698 .30365 .47792 .31371 .47829 .30798 .45875 Mtetra
.503 .445 .725 r
.30798 .45875 .31371 .47829 .32388 .47796 .318 .46041 Mtetra
.51 .468 .746 r
.318 .46041 .32388 .47796 .33416 .47667 .32811 .4616 Mtetra
.528 .508 .778 r
.32811 .4616 .33416 .47667 .34458 .47385 .33835 .46197 Mtetra
.554 .573 .828 r
.33835 .46197 .34458 .47385 .35514 .46926 .3487 .46131 Mtetra
.534 .661 .917 r
.3487 .46131 .35514 .46926 .36578 .46371 .35912 .46059 Mtetra
.335 .746 .98 r
.35912 .46059 .36578 .46371 .37646 .45782 .36958 .46028 Mtetra
.232 0 0 r
.36958 .46028 .37646 .45782 .38712 .45287 .38007 .46054 Mtetra
.433 0 .045 r
.38007 .46054 .38712 .45287 .39776 .44947 .39061 .46132 Mtetra
.452 .042 .17 r
.39061 .46132 .39776 .44947 .40841 .44701 .40124 .46146 Mtetra
.434 .05 .209 r
.40124 .46146 .40841 .44701 .41909 .44512 .41198 .46041 Mtetra
.402 .026 .206 r
.41198 .46041 .41909 .44512 .42982 .44298 .42282 .45805 Mtetra
.36 0 .183 r
.42282 .45805 .42982 .44298 .44063 .44023 .43375 .45447 Mtetra
.335 0 .156 r
.43375 .45447 .44063 .44023 .45149 .43706 .44473 .45047 Mtetra
.322 0 .135 r
.44473 .45047 .45149 .43706 .46241 .43354 .45575 .44646 Mtetra
.33 0 .129 r
.45575 .44646 .46241 .43354 .47337 .42994 .4668 .44286 Mtetra
.346 0 .136 r
.4668 .44286 .47337 .42994 .48438 .42627 .4779 .43965 Mtetra
.354 0 .15 r
.4779 .43965 .48438 .42627 .49543 .42224 .48904 .43645 Mtetra
.351 0 .164 r
.48904 .43645 .49543 .42224 .50653 .41779 .50024 .43281 Mtetra
.321 0 .166 r
.50024 .43281 .50653 .41779 .51767 .41272 .51148 .42795 Mtetra
.279 0 .152 r
.51148 .42795 .51767 .41272 .52885 .40739 .52277 .42176 Mtetra
.215 0 .109 r
.52277 .42176 .52885 .40739 .54006 .40263 .53408 .41436 Mtetra
.105 0 0 r
.53408 .41436 .54006 .40263 .55132 .39882 .54541 .40629 Mtetra
0 0 0 r
.54541 .40629 .55132 .39882 .56264 .39659 .55675 .39873 Mtetra
.514 .903 .753 r
.55675 .39873 .56264 .39659 .57403 .39531 .56813 .39173 Mtetra
.749 .899 .945 r
.56813 .39173 .57403 .39531 .58549 .39369 .57954 .38515 Mtetra
.731 .735 .855 r
.57954 .38515 .58549 .39369 .59698 .39111 .59097 .37849 Mtetra
.717 .651 .783 r
.59097 .37849 .59698 .39111 .60848 .38671 .6024 .37077 Mtetra
.705 .605 .741 r
.6024 .37077 .60848 .38671 .61998 .38074 .61383 .36219 Mtetra
.695 .576 .717 r
.61383 .36219 .61998 .38074 .63148 .37378 .62526 .35311 Mtetra
.685 .555 .702 r
.62526 .35311 .63148 .37378 .64298 .36608 .6367 .3439 Mtetra
.673 .539 .693 r
.6367 .3439 .64298 .36608 .65447 .35792 .64815 .33502 Mtetra
.664 .53 .69 r
.64815 .33502 .65447 .35792 .66598 .34952 .65964 .32663 Mtetra
.656 .525 .692 r
.65964 .32663 .66598 .34952 .6775 .34115 .67117 .31891 Mtetra
.649 .525 .698 r
.67117 .31891 .6775 .34115 .68905 .333 .68277 .31191 Mtetra
.643 .528 .709 r
.68277 .31191 .68905 .333 .70064 .32536 .69443 .30574 Mtetra
.637 .536 .723 r
.69443 .30574 .70064 .32536 .7123 .3183 .70617 .30035 Mtetra
.631 .547 .741 r
.70617 .30035 .7123 .3183 .72402 .31196 .718 .29571 Mtetra
.626 .561 .762 r
.718 .29571 .72402 .31196 .73582 .30628 .72991 .29169 Mtetra
.621 .58 .786 r
.72991 .29169 .73582 .30628 .7477 .30124 .74192 .28819 Mtetra
.617 .6 .811 r
.74192 .28819 .7477 .30124 .75967 .29673 .754 .28507 Mtetra
.614 .624 .838 r
.754 .28507 .75967 .29673 .77172 .29264 .76617 .28218 Mtetra
.61 .649 .864 r
.76617 .28218 .77172 .29264 .78385 .28885 .7784 .27945 Mtetra
.607 .674 .888 r
.7784 .27945 .78385 .28885 .79604 .28523 .79071 .27678 Mtetra
.606 .701 .911 r
.79071 .27678 .79604 .28523 .8083 .28168 .80308 .27409 Mtetra
.721 .764 .887 r
.15266 .48451 .15958 .49055 .16944 .48593 .1626 .47935 Mtetra
.72 .749 .875 r
.1626 .47935 .16944 .48593 .17933 .48128 .17257 .47408 Mtetra
.717 .732 .862 r
.17257 .47408 .17933 .48128 .18924 .47668 .18258 .46874 Mtetra
.712 .712 .848 r
.18258 .46874 .18924 .47668 .19916 .47224 .19261 .46335 Mtetra
.706 .688 .831 r
.19261 .46335 .19916 .47224 .20909 .46803 .20268 .45793 Mtetra
.695 .661 .812 r
.20268 .45793 .20909 .46803 .21902 .46418 .21275 .45261 Mtetra
.68 .63 .792 r
.21275 .45261 .21902 .46418 .22893 .46082 .22284 .44746 Mtetra
.663 .597 .771 r
.22284 .44746 .22893 .46082 .23883 .45807 .23292 .44264 Mtetra
.643 .563 .749 r
.23292 .44264 .23883 .45807 .24871 .45606 .24299 .43829 Mtetra
.622 .529 .728 r
.24299 .43829 .24871 .45606 .25857 .4548 .25305 .43454 Mtetra
.601 .498 .709 r
.25305 .43454 .25857 .4548 .26842 .45436 .26307 .43151 Mtetra
.583 .471 .692 r
.26307 .43151 .26842 .45436 .27828 .45463 .27308 .42926 Mtetra
.565 .447 .677 r
.27308 .42926 .27828 .45463 .28814 .45556 .28308 .42786 Mtetra
.552 .429 .665 r
.28308 .42786 .28814 .45556 .29803 .45698 .29307 .42718 Mtetra
.542 .414 .656 r
.29307 .42718 .29803 .45698 .30798 .45875 .30307 .42716 Mtetra
.537 .405 .648 r
.30307 .42716 .30798 .45875 .318 .46041 .31311 .42746 Mtetra
.535 .4 .643 r
.31311 .42746 .318 .46041 .32811 .4616 .32321 .42788 Mtetra
.53 .395 .641 r
.32321 .42788 .32811 .4616 .33835 .46197 .33335 .42865 Mtetra
.525 .392 .642 r
.33335 .42865 .33835 .46197 .3487 .46131 .34354 .42985 Mtetra
.515 .392 .65 r
.34354 .42985 .3487 .46131 .35912 .46059 .35376 .43164 Mtetra
.506 .395 .661 r
.35376 .43164 .35912 .46059 .36958 .46028 .36404 .43389 Mtetra
.518 .414 .676 r
.36404 .43389 .36958 .46028 .38007 .46054 .37443 .43527 Mtetra
.546 .439 .683 r
.37443 .43527 .38007 .46054 .39061 .46132 .38497 .43501 Mtetra
.577 .455 .676 r
.38497 .43501 .39061 .46132 .40124 .46146 .39565 .43269 Mtetra
.601 .461 .663 r
.39565 .43269 .40124 .46146 .41198 .46041 .40647 .42826 Mtetra
.605 .453 .649 r
.40647 .42826 .41198 .46041 .42282 .45805 .41735 .42281 Mtetra
.603 .444 .638 r
.41735 .42281 .42282 .45805 .43375 .45447 .42827 .41701 Mtetra
.596 .433 .632 r
.42827 .41701 .43375 .45447 .44473 .45047 .43922 .4116 Mtetra
.586 .424 .629 r
.43922 .4116 .44473 .45047 .45575 .44646 .45017 .40701 Mtetra
.576 .416 .627 r
.45017 .40701 .45575 .44646 .4668 .44286 .46115 .40335 Mtetra
.567 .41 .627 r
.46115 .40335 .4668 .44286 .4779 .43965 .47215 .40062 Mtetra
.56 .405 .629 r
.47215 .40062 .4779 .43965 .48904 .43645 .48319 .39871 Mtetra
.556 .406 .633 r
.48319 .39871 .48904 .43645 .50024 .43281 .49429 .39719 Mtetra
.561 .415 .639 r
.49429 .39719 .50024 .43281 .51148 .42795 .50545 .39535 Mtetra
.576 .433 .65 r
.50545 .39535 .51148 .42795 .52277 .42176 .51667 .39247 Mtetra
.605 .464 .662 r
.51667 .39247 .52277 .42176 .53408 .41436 .52794 .38746 Mtetra
.635 .492 .671 r
.52794 .38746 .53408 .41436 .54541 .40629 .53924 .38035 Mtetra
.656 .51 .673 r
.53924 .38035 .54541 .40629 .55675 .39873 .55055 .37157 Mtetra
.661 .508 .665 r
.55055 .37157 .55675 .39873 .56813 .39173 .56186 .36189 Mtetra
.647 .489 .655 r
.56186 .36189 .56813 .39173 .57954 .38515 .57318 .35266 Mtetra
.634 .473 .646 r
.57318 .35266 .57954 .38515 .59097 .37849 .58452 .344 Mtetra
.625 .461 .64 r
.58452 .344 .59097 .37849 .6024 .37077 .59589 .33577 Mtetra
.621 .457 .639 r
.59589 .33577 .6024 .37077 .61383 .36219 .60727 .32787 Mtetra
.621 .459 .641 r
.60727 .32787 .61383 .36219 .62526 .35311 .61868 .32009 Mtetra
.621 .462 .646 r
.61868 .32009 .62526 .35311 .6367 .3439 .63012 .31262 Mtetra
.619 .466 .653 r
.63012 .31262 .6367 .3439 .64815 .33502 .64161 .30581 Mtetra
.616 .471 .662 r
.64161 .30581 .64815 .33502 .65964 .32663 .65315 .29974 Mtetra
.612 .477 .674 r
.65315 .29974 .65964 .32663 .67117 .31891 .66476 .29453 Mtetra
.608 .487 .69 r
.66476 .29453 .67117 .31891 .68277 .31191 .67646 .29012 Mtetra
.603 .5 .709 r
.67646 .29012 .68277 .31191 .69443 .30574 .68823 .28645 Mtetra
.599 .516 .732 r
.68823 .28645 .69443 .30574 .70617 .30035 .7001 .28341 Mtetra
.595 .536 .759 r
.7001 .28341 .70617 .30035 .718 .29571 .71205 .28084 Mtetra
.591 .559 .787 r
.71205 .28084 .718 .29571 .72991 .29169 .72409 .27862 Mtetra
.588 .585 .817 r
.72409 .27862 .72991 .29169 .74192 .28819 .73621 .27659 Mtetra
.585 .612 .845 r
.73621 .27659 .74192 .28819 .754 .28507 .7484 .27466 Mtetra
.585 .638 .87 r
.7484 .27466 .754 .28507 .76617 .28218 .76066 .2727 Mtetra
.583 .661 .891 r
.76066 .2727 .76617 .28218 .7784 .27945 .77298 .2707 Mtetra
.583 .682 .909 r
.77298 .2707 .7784 .27945 .79071 .27678 .78537 .26863 Mtetra
.583 .701 .923 r
.78537 .26863 .79071 .27678 .80308 .27409 .79782 .26643 Mtetra
.716 .763 .89 r
.14569 .47843 .15266 .48451 .1626 .47935 .15564 .47342 Mtetra
.721 .769 .891 r
.15564 .47342 .1626 .47935 .17257 .47408 .16562 .46825 Mtetra
.726 .774 .891 r
.16562 .46825 .17257 .47408 .18258 .46874 .17565 .46292 Mtetra
.731 .776 .889 r
.17565 .46292 .18258 .46874 .19261 .46335 .18572 .45739 Mtetra
.736 .773 .883 r
.18572 .45739 .19261 .46335 .20268 .45793 .19585 .45163 Mtetra
.738 .764 .874 r
.19585 .45163 .20268 .45793 .21275 .45261 .20601 .44571 Mtetra
.736 .747 .861 r
.20601 .44571 .21275 .45261 .22284 .44746 .2162 .43965 Mtetra
.728 .723 .845 r
.2162 .43965 .22284 .44746 .23292 .44264 .22641 .43359 Mtetra
.716 .691 .826 r
.22641 .43359 .23292 .44264 .24299 .43829 .23664 .42764 Mtetra
.698 .655 .803 r
.23664 .42764 .24299 .43829 .25305 .43454 .24687 .42193 Mtetra
.676 .615 .78 r
.24687 .42193 .25305 .43454 .26307 .43151 .25709 .41663 Mtetra
.653 .575 .755 r
.25709 .41663 .26307 .43151 .27308 .42926 .2673 .41183 Mtetra
.63 .538 .731 r
.2673 .41183 .27308 .42926 .28308 .42786 .27748 .40765 Mtetra
.61 .505 .709 r
.27748 .40765 .28308 .42786 .29307 .42718 .28766 .40406 Mtetra
.593 .477 .69 r
.28766 .40406 .29307 .42718 .30307 .42716 .29784 .40108 Mtetra
.579 .454 .673 r
.29784 .40108 .30307 .42716 .31311 .42746 .30802 .39863 Mtetra
.569 .436 .66 r
.30802 .39863 .31311 .42746 .32321 .42788 .31821 .39667 Mtetra
.556 .419 .65 r
.31821 .39667 .32321 .42788 .33335 .42865 .32841 .3955 Mtetra
.543 .405 .643 r
.32841 .3955 .33335 .42865 .34354 .42985 .33861 .39521 Mtetra
.538 .397 .637 r
.33861 .39521 .34354 .42985 .35376 .43164 .34885 .3953 Mtetra
.539 .394 .632 r
.34885 .3953 .35376 .43164 .36404 .43389 .35916 .39531 Mtetra
.552 .398 .627 r
.35916 .39531 .36404 .43389 .37443 .43527 .36959 .39411 Mtetra
.568 .405 .621 r
.36959 .39411 .37443 .43527 .38497 .43501 .38015 .39116 Mtetra
.576 .407 .615 r
.38015 .39116 .38497 .43501 .39565 .43269 .39082 .38696 Mtetra
.582 .408 .611 r
.39082 .38696 .39565 .43269 .40647 .42826 .40155 .38186 Mtetra
.581 .406 .61 r
.40155 .38186 .40647 .42826 .41735 .42281 .41232 .37679 Mtetra
.577 .405 .611 r
.41232 .37679 .41735 .42281 .42827 .41701 .42311 .37217 Mtetra
.575 .405 .613 r
.42311 .37217 .42827 .41701 .43922 .4116 .43392 .36793 Mtetra
.573 .405 .616 r
.43392 .36793 .43922 .4116 .45017 .40701 .44476 .36408 Mtetra
.572 .406 .617 r
.44476 .36408 .45017 .40701 .46115 .40335 .45564 .36035 Mtetra
.571 .405 .617 r
.45564 .36035 .46115 .40335 .47215 .40062 .46657 .35677 Mtetra
.567 .401 .616 r
.46657 .35677 .47215 .40062 .48319 .39871 .47753 .35356 Mtetra
.563 .396 .613 r
.47753 .35356 .48319 .39871 .49429 .39719 .48853 .35074 Mtetra
.558 .391 .61 r
.48853 .35074 .49429 .39719 .50545 .39535 .49958 .34839 Mtetra
.557 .39 .61 r
.49958 .34839 .50545 .39535 .51667 .39247 .51069 .34606 Mtetra
.565 .396 .611 r
.51069 .34606 .51667 .39247 .52794 .38746 .52185 .34283 Mtetra
.577 .407 .615 r
.52185 .34283 .52794 .38746 .53924 .38035 .53306 .33833 Mtetra
.594 .424 .62 r
.53306 .33833 .53924 .38035 .55055 .37157 .5443 .33205 Mtetra
.609 .438 .626 r
.5443 .33205 .55055 .37157 .56186 .36189 .55556 .32454 Mtetra
.613 .446 .631 r
.55556 .32454 .56186 .36189 .57318 .35266 .56684 .31693 Mtetra
.613 .449 .636 r
.56684 .31693 .57318 .35266 .58452 .344 .57814 .30969 Mtetra
.607 .449 .641 r
.57814 .30969 .58452 .344 .59589 .33577 .58948 .30334 Mtetra
.603 .451 .648 r
.58948 .30334 .59589 .33577 .60727 .32787 .60087 .29779 Mtetra
.602 .458 .658 r
.60087 .29779 .60727 .32787 .61868 .32009 .61231 .29274 Mtetra
.602 .468 .672 r
.61231 .29274 .61868 .32009 .63012 .31262 .62381 .28821 Mtetra
.6 .481 .689 r
.62381 .28821 .63012 .31262 .64161 .30581 .63537 .28431 Mtetra
.598 .497 .711 r
.63537 .28431 .64161 .30581 .65315 .29974 .64701 .28102 Mtetra
.593 .516 .738 r
.64701 .28102 .65315 .29974 .66476 .29453 .65872 .27837 Mtetra
.587 .539 .768 r
.65872 .27837 .66476 .29453 .67646 .29012 .67053 .27624 Mtetra
.579 .566 .803 r
.67053 .27624 .67646 .29012 .68823 .28645 .68241 .27452 Mtetra
.571 .596 .839 r
.68241 .27452 .68823 .28645 .7001 .28341 .69438 .27307 Mtetra
.563 .627 .873 r
.69438 .27307 .7001 .28341 .71205 .28084 .70643 .27174 Mtetra
.557 .657 .902 r
.70643 .27174 .71205 .28084 .72409 .27862 .71855 .2704 Mtetra
.555 .683 .924 r
.71855 .2704 .72409 .27862 .73621 .27659 .73074 .26894 Mtetra
.556 .702 .938 r
.73074 .26894 .73621 .27659 .7484 .27466 .74298 .26731 Mtetra
.563 .717 .944 r
.74298 .26731 .7484 .27466 .76066 .2727 .75528 .26544 Mtetra
.571 .724 .946 r
.75528 .26544 .76066 .2727 .77298 .2707 .76764 .26337 Mtetra
.578 .727 .944 r
.76764 .26337 .77298 .2707 .78537 .26863 .78005 .26112 Mtetra
.586 .726 .94 r
.78005 .26112 .78537 .26863 .79782 .26643 .79252 .25872 Mtetra
.692 .759 .903 r
.13868 .4723 .14569 .47843 .15564 .47342 .14856 .468 Mtetra
.699 .785 .917 r
.14856 .468 .15564 .47342 .16562 .46825 .15849 .46355 Mtetra
.708 .811 .929 r
.15849 .46355 .16562 .46825 .17565 .46292 .16847 .45888 Mtetra
.718 .837 .938 r
.16847 .45888 .17565 .46292 .18572 .45739 .17852 .45394 Mtetra
.73 .86 .942 r
.17852 .45394 .18572 .45739 .19585 .45163 .18862 .44864 Mtetra
.742 .878 .943 r
.18862 .44864 .19585 .45163 .20601 .44571 .19879 .44299 Mtetra
.754 .889 .939 r
.19879 .44299 .20601 .44571 .2162 .43965 .20902 .43696 Mtetra
.764 .891 .934 r
.20902 .43696 .2162 .43965 .22641 .43359 .2193 .43064 Mtetra
.773 .882 .925 r
.2193 .43064 .22641 .43359 .23664 .42764 .22962 .42405 Mtetra
.775 .861 .913 r
.22962 .42405 .23664 .42764 .24687 .42193 .23997 .41733 Mtetra
.77 .826 .896 r
.23997 .41733 .24687 .42193 .25709 .41663 .25034 .41057 Mtetra
.757 .78 .872 r
.25034 .41057 .25709 .41663 .2673 .41183 .26073 .40388 Mtetra
.736 .726 .841 r
.26073 .40388 .2673 .41183 .27748 .40765 .27112 .39738 Mtetra
.711 .67 .807 r
.27112 .39738 .27748 .40765 .28766 .40406 .28151 .39114 Mtetra
.685 .617 .774 r
.28151 .39114 .28766 .40406 .29784 .40108 .29189 .38526 Mtetra
.658 .57 .744 r
.29189 .38526 .29784 .40108 .30802 .39863 .30227 .37988 Mtetra
.634 .53 .719 r
.30227 .37988 .30802 .39863 .31821 .39667 .31263 .37513 Mtetra
.613 .499 .7 r
.31263 .37513 .31821 .39667 .32841 .3955 .32298 .37103 Mtetra
.597 .473 .682 r
.32298 .37103 .32841 .3955 .33861 .39521 .33333 .36752 Mtetra
.593 .457 .665 r
.33333 .36752 .33861 .39521 .34885 .3953 .34374 .36377 Mtetra
.595 .445 .648 r
.34374 .36377 .34885 .3953 .35916 .39531 .35422 .35932 Mtetra
.594 .433 .633 r
.35422 .35932 .35916 .39531 .36959 .39411 .36478 .35421 Mtetra
.592 .424 .623 r
.36478 .35421 .36959 .39411 .38015 .39116 .37538 .3486 Mtetra
.583 .413 .616 r
.37538 .3486 .38015 .39116 .39082 .38696 .38599 .34366 Mtetra
.572 .404 .615 r
.38599 .34366 .39082 .38696 .40155 .38186 .39658 .33987 Mtetra
.563 .399 .618 r
.39658 .33987 .40155 .38186 .41232 .37679 .40717 .33717 Mtetra
.556 .399 .623 r
.40717 .33717 .41232 .37679 .42311 .37217 .41778 .33533 Mtetra
.56 .408 .632 r
.41778 .33533 .42311 .37217 .43392 .36793 .42845 .33337 Mtetra
.569 .42 .639 r
.42845 .33337 .43392 .36793 .44476 .36408 .43919 .33074 Mtetra
.583 .433 .643 r
.43919 .33074 .44476 .36408 .45564 .36035 .45001 .32696 Mtetra
.595 .441 .643 r
.45001 .32696 .45564 .36035 .46657 .35677 .4609 .32205 Mtetra
.6 .441 .638 r
.4609 .32205 .46657 .35677 .47753 .35356 .47183 .31647 Mtetra
.597 .433 .631 r
.47183 .31647 .47753 .35356 .48853 .35074 .4828 .31075 Mtetra
.584 .419 .624 r
.4828 .31075 .48853 .35074 .49958 .34839 .49378 .30588 Mtetra
.572 .406 .618 r
.49378 .30588 .49958 .34839 .51069 .34606 .5048 .30212 Mtetra
.56 .395 .615 r
.5048 .30212 .51069 .34606 .52185 .34283 .51586 .29953 Mtetra
.554 .392 .616 r
.51586 .29953 .52185 .34283 .53306 .33833 .52698 .2976 Mtetra
.561 .402 .623 r
.52698 .2976 .53306 .33833 .5443 .33205 .53815 .29518 Mtetra
.571 .417 .633 r
.53815 .29518 .5443 .33205 .55556 .32454 .54937 .29209 Mtetra
.584 .437 .648 r
.54937 .29209 .55556 .32454 .56684 .31693 .56063 .2883 Mtetra
.593 .457 .665 r
.56063 .2883 .56684 .31693 .57814 .30969 .57194 .28425 Mtetra
.591 .469 .682 r
.57194 .28425 .57814 .30969 .58948 .30334 .58331 .2808 Mtetra
.587 .483 .703 r
.58331 .2808 .58948 .30334 .60087 .29779 .59474 .27802 Mtetra
.581 .499 .727 r
.59474 .27802 .60087 .29779 .61231 .29274 .60624 .27589 Mtetra
.574 .523 .76 r
.60624 .27589 .61231 .29274 .62381 .28821 .61783 .27427 Mtetra
.566 .556 .802 r
.61783 .27427 .62381 .28821 .63537 .28431 .62949 .27303 Mtetra
.554 .598 .853 r
.62949 .27303 .63537 .28431 .64701 .28102 .64123 .27206 Mtetra
.533 .646 .907 r
.64123 .27206 .64701 .28102 .65872 .27837 .65305 .27129 Mtetra
.503 .693 .953 r
.65305 .27129 .65872 .27837 .67053 .27624 .66495 .27061 Mtetra
.468 .731 .983 r
.66495 .27061 .67053 .27624 .68241 .27452 .67692 .26989 Mtetra
.439 .757 .995 r
.67692 .26989 .68241 .27452 .69438 .27307 .68897 .26904 Mtetra
.43 .776 .997 r
.68897 .26904 .69438 .27307 .70643 .27174 .70107 .26793 Mtetra
.441 .791 .997 r
.70107 .26793 .70643 .27174 .71855 .2704 .71324 .26652 Mtetra
.472 .805 .999 r
.71324 .26652 .71855 .2704 .73074 .26894 .72545 .26472 Mtetra
.509 .811 .999 r
.72545 .26472 .73074 .26894 .74298 .26731 .73771 .26255 Mtetra
.548 .81 .994 r
.73771 .26255 .74298 .26731 .75528 .26544 .75001 .26002 Mtetra
.579 .799 .983 r
.75001 .26002 .75528 .26544 .76764 .26337 .76235 .2572 Mtetra
.6 .781 .967 r
.76235 .2572 .76764 .26337 .78005 .26112 .77474 .25415 Mtetra
.614 .759 .948 r
.77474 .25415 .78005 .26112 .79252 .25872 .78718 .25095 Mtetra
.649 .75 .923 r
.13161 .46613 .13868 .4723 .14856 .468 .14138 .46294 Mtetra
.65 .789 .949 r
.14138 .46294 .14856 .468 .15849 .46355 .15121 .45965 Mtetra
.649 .833 .971 r
.15121 .45965 .15849 .46355 .16847 .45888 .16109 .45616 Mtetra
.645 .876 .984 r
.16109 .45616 .16847 .45888 .17852 .45394 .17103 .45241 Mtetra
.635 .913 .981 r
.17103 .45241 .17852 .45394 .18862 .44864 .18105 .4483 Mtetra
.614 .937 .957 r
.18105 .4483 .18862 .44864 .19879 .44299 .19115 .44379 Mtetra
.584 .942 .911 r
.19115 .44379 .19879 .44299 .20902 .43696 .20132 .43883 Mtetra
.546 .929 .849 r
.20132 .43883 .20902 .43696 .2193 .43064 .21156 .43342 Mtetra
.512 .907 .786 r
.21156 .43342 .2193 .43064 .22962 .42405 .22186 .42756 Mtetra
.483 .884 .731 r
.22186 .42756 .22962 .42405 .23997 .41733 .23223 .42131 Mtetra
.47 .869 .696 r
.23223 .42131 .23997 .41733 .25034 .41057 .24265 .41472 Mtetra
.474 .868 .685 r
.24265 .41472 .25034 .41057 .26073 .40388 .25311 .40789 Mtetra
.496 .882 .699 r
.25311 .40789 .26073 .40388 .27112 .39738 .2636 .40092 Mtetra
.535 .909 .738 r
.2636 .40092 .27112 .39738 .28151 .39114 .2741 .39393 Mtetra
.584 .94 .794 r
.2741 .39393 .28151 .39114 .29189 .38526 .28462 .38704 Mtetra
.63 .963 .856 r
.28462 .38704 .29189 .38526 .30227 .37988 .29514 .38044 Mtetra
.669 .969 .914 r
.29514 .38044 .30227 .37988 .31263 .37513 .30564 .37426 Mtetra
.707 .954 .951 r
.30564 .37426 .31263 .37513 .32298 .37103 .31615 .36836 Mtetra
.733 .904 .954 r
.31615 .36836 .32298 .37103 .33333 .36752 .32668 .36261 Mtetra
.747 .826 .913 r
.32668 .36261 .33333 .36752 .34374 .36377 .33726 .35652 Mtetra
.744 .754 .861 r
.33726 .35652 .34374 .36377 .35422 .35932 .34788 .34993 Mtetra
.719 .696 .827 r
.34788 .34993 .35422 .35932 .36478 .35421 .35852 .34362 Mtetra
.693 .663 .816 r
.35852 .34362 .36478 .35421 .37538 .3486 .36914 .33805 Mtetra
.658 .65 .831 r
.36914 .33805 .37538 .3486 .38599 .34366 .37972 .33395 Mtetra
.609 .648 .864 r
.37972 .33395 .38599 .34366 .39658 .33987 .39027 .33153 Mtetra
.568 .668 .905 r
.39027 .33153 .39658 .33987 .40717 .33717 .40083 .33005 Mtetra
.537 .694 .94 r
.40083 .33005 .40717 .33717 .41778 .33533 .41143 .32895 Mtetra
.554 .727 .955 r
.41143 .32895 .41778 .33533 .42845 .33337 .42212 .32736 Mtetra
.602 .76 .955 r
.42212 .32736 .42845 .33337 .43919 .33074 .43288 .32479 Mtetra
.658 .782 .94 r
.43288 .32479 .43919 .33074 .45001 .32696 .44373 .32099 Mtetra
.704 .795 .921 r
.44373 .32099 .45001 .32696 .4609 .32205 .45466 .31596 Mtetra
.735 .799 .903 r
.45466 .31596 .4609 .32205 .47183 .31647 .46563 .30995 Mtetra
.745 .788 .888 r
.46563 .30995 .47183 .31647 .4828 .31075 .47664 .30343 Mtetra
.73 .762 .878 r
.47664 .30343 .4828 .31075 .49378 .30588 .48767 .29729 Mtetra
.696 .717 .866 r
.48767 .29729 .49378 .30588 .5048 .30212 .49873 .29208 Mtetra
.64 .661 .855 r
.49873 .29208 .5048 .30212 .51586 .29953 .50981 .28857 Mtetra
.591 .619 .848 r
.50981 .28857 .51586 .29953 .52698 .2976 .52093 .28655 Mtetra
.565 .604 .851 r
.52093 .28655 .52698 .2976 .53815 .29518 .53212 .28529 Mtetra
.55 .625 .879 r
.53212 .28529 .53815 .29518 .54937 .29209 .54337 .2843 Mtetra
.557 .689 .928 r
.54337 .2843 .54937 .29209 .56063 .2883 .55469 .28283 Mtetra
.54 .766 .981 r
.55469 .28283 .56063 .2883 .57194 .28425 .56606 .28101 Mtetra
.445 .809 .996 r
.56606 .28101 .57194 .28425 .58331 .2808 .57751 .27936 Mtetra
.288 .772 .916 r
.57751 .27936 .58331 .2808 .59474 .27802 .58902 .27798 Mtetra
.105 .66 .763 r
.58902 .27798 .59474 .27802 .60624 .27589 .60061 .27705 Mtetra
.04 0 0 r
.60061 .27705 .60624 .27589 .61783 .27427 .61228 .27643 Mtetra
.128 0 0 r
.61228 .27643 .61783 .27427 .62949 .27303 .62403 .27591 Mtetra
.176 0 0 r
.62403 .27591 .62949 .27303 .64123 .27206 .63585 .27539 Mtetra
.191 0 0 r
.63585 .27539 .64123 .27206 .65305 .27129 .64775 .27473 Mtetra
.18 0 0 r
.64775 .27473 .65305 .27129 .66495 .27061 .65971 .27383 Mtetra
.141 0 0 r
.65971 .27383 .66495 .27061 .67692 .26989 .67173 .27259 Mtetra
.074 0 0 r
.67173 .27259 .67692 .26989 .68897 .26904 .68381 .27095 Mtetra
0 0 0 r
.68381 .27095 .68897 .26904 .70107 .26793 .69593 .26885 Mtetra
.162 .697 .712 r
.69593 .26885 .70107 .26793 .71324 .26652 .70809 .26629 Mtetra
.315 .804 .846 r
.70809 .26629 .71324 .26652 .72545 .26472 .72029 .26325 Mtetra
.452 .87 .943 r
.72029 .26325 .72545 .26472 .73771 .26255 .73252 .25979 Mtetra
.555 .887 .987 r
.73252 .25979 .73771 .26255 .75001 .26002 .74478 .25597 Mtetra
.616 .868 .99 r
.74478 .25597 .75001 .26002 .76235 .2572 .75708 .25186 Mtetra
.647 .833 .972 r
.75708 .25186 .76235 .2572 .77474 .25415 .76942 .24754 Mtetra
.66 .793 .945 r
.76942 .24754 .77474 .25415 .78718 .25095 .7818 .24311 Mtetra
.589 .733 .943 r
.12449 .45992 .13161 .46613 .14138 .46294 .13414 .45793 Mtetra
.576 .773 .972 r
.13414 .45793 .14138 .46294 .15121 .45965 .14384 .45589 Mtetra
.556 .815 .994 r
.14384 .45589 .15121 .45965 .16109 .45616 .1536 .45374 Mtetra
.521 .851 .997 r
.1536 .45374 .16109 .45616 .17103 .45241 .16342 .4514 Mtetra
.465 .867 .963 r
.16342 .4514 .17103 .45241 .18105 .4483 .17331 .4488 Mtetra
.38 .843 .874 r
.17331 .4488 .18105 .4483 .19115 .44379 .18328 .44587 Mtetra
.279 .776 .736 r
.18328 .44587 .19115 .44379 .20132 .43883 .19333 .44253 Mtetra
0 0 0 r
.19333 .44253 .20132 .43883 .21156 .43342 .20347 .43874 Mtetra
.20347 .43874 .21156 .43342 .22186 .42756 .21369 .43446 Mtetra
.21369 .43446 .22186 .42756 .23223 .42131 .22399 .42969 Mtetra
.031 0 0 r
.22399 .42969 .23223 .42131 .24265 .41472 .23436 .42444 Mtetra
.07 0 0 r
.23436 .42444 .24265 .41472 .25311 .40789 .24479 .41878 Mtetra
.1 0 0 r
.24479 .41878 .25311 .40789 .2636 .40092 .25529 .41276 Mtetra
.125 0 0 r
.25529 .41276 .2636 .40092 .2741 .39393 .26582 .40652 Mtetra
.147 0 .003 r
.26582 .40652 .2741 .39393 .28462 .38704 .27638 .40016 Mtetra
.165 0 .026 r
.27638 .40016 .28462 .38704 .29514 .38044 .28697 .39378 Mtetra
.177 0 .038 r
.28697 .39378 .29514 .38044 .30564 .37426 .29758 .38745 Mtetra
.165 0 .03 r
.29758 .38745 .30564 .37426 .31615 .36836 .30823 .38095 Mtetra
.134 0 0 r
.30823 .38095 .31615 .36836 .32668 .36261 .31891 .3742 Mtetra
.093 0 0 r
.31891 .3742 .32668 .36261 .33726 .35652 .32962 .36735 Mtetra
.074 0 0 r
.32962 .36735 .33726 .35652 .34788 .34993 .34034 .36065 Mtetra
.144 0 0 r
.34034 .36065 .34788 .34993 .35852 .34362 .35102 .35506 Mtetra
.258 0 .043 r
.35102 .35506 .35852 .34362 .36914 .33805 .36165 .35105 Mtetra
.349 0 .128 r
.36165 .35105 .36914 .33805 .37972 .33395 .37225 .34836 Mtetra
.404 .015 .183 r
.37225 .34836 .37972 .33395 .39027 .33153 .38286 .34674 Mtetra
.412 .029 .199 r
.38286 .34674 .39027 .33153 .40083 .33005 .39352 .34516 Mtetra
.397 .013 .19 r
.39352 .34516 .40083 .33005 .41143 .32895 .40425 .34309 Mtetra
.367 0 .158 r
.40425 .34309 .41143 .32895 .42212 .32736 .41507 .34043 Mtetra
.327 0 .118 r
.41507 .34043 .42212 .32736 .43288 .32479 .42595 .33709 Mtetra
.294 0 .084 r
.42595 .33709 .43288 .32479 .44373 .32099 .43689 .33328 Mtetra
.274 0 .074 r
.43689 .33328 .44373 .32099 .45466 .31596 .44789 .329 Mtetra
.261 0 .086 r
.44789 .329 .45466 .31596 .46563 .30995 .45895 .32403 Mtetra
.259 0 .107 r
.45895 .32403 .46563 .30995 .47664 .30343 .47005 .31846 Mtetra
.26 0 .127 r
.47005 .31846 .47664 .30343 .48767 .29729 .48119 .3124 Mtetra
.264 0 .131 r
.48119 .3124 .48767 .29729 .49873 .29208 .49236 .30637 Mtetra
.291 0 .128 r
.49236 .30637 .49873 .29208 .50981 .28857 .50356 .30141 Mtetra
.318 0 .111 r
.50356 .30141 .50981 .28857 .52093 .28655 .51479 .29779 Mtetra
.355 0 .09 r
.51479 .29779 .52093 .28655 .53212 .28529 .52606 .29576 Mtetra
.387 0 .085 r
.52606 .29576 .53212 .28529 .54337 .2843 .53741 .29487 Mtetra
.394 0 .091 r
.53741 .29487 .54337 .2843 .55469 .28283 .54882 .29413 Mtetra
.4 0 .112 r
.54882 .29413 .55469 .28283 .56606 .28101 .5603 .29331 Mtetra
.403 0 .136 r
.5603 .29331 .56606 .28101 .57751 .27936 .57185 .29224 Mtetra
.403 0 .148 r
.57185 .29224 .57751 .27936 .58902 .27798 .58347 .29101 Mtetra
.407 0 .152 r
.58347 .29101 .58902 .27798 .60061 .27705 .59516 .28983 Mtetra
.404 0 .145 r
.59516 .28983 .60061 .27705 .61228 .27643 .60692 .28864 Mtetra
.394 0 .128 r
.60692 .28864 .61228 .27643 .62403 .27591 .61875 .28733 Mtetra
.377 0 .101 r
.61875 .28733 .62403 .27591 .63585 .27539 .63064 .2858 Mtetra
.348 0 .061 r
.63064 .2858 .63585 .27539 .64775 .27473 .64259 .28391 Mtetra
.307 0 .003 r
.64259 .28391 .64775 .27473 .65971 .27383 .65458 .2816 Mtetra
.245 0 0 r
.65458 .2816 .65971 .27383 .67173 .27259 .66662 .27879 Mtetra
.157 0 0 r
.66662 .27879 .67173 .27259 .68381 .27095 .6787 .27548 Mtetra
.027 0 0 r
.6787 .27548 .68381 .27095 .69593 .26885 .69081 .27165 Mtetra
0 0 0 r
.69081 .27165 .69593 .26885 .70809 .26629 .70295 .26736 Mtetra
.343 .816 .757 r
.70295 .26736 .70809 .26629 .72029 .26325 .71511 .26264 Mtetra
.514 .912 .903 r
.71511 .26264 .72029 .26325 .73252 .25979 .7273 .25756 Mtetra
.625 .932 .967 r
.7273 .25756 .73252 .25979 .74478 .25597 .73952 .25221 Mtetra
.68 .904 .975 r
.73952 .25221 .74478 .25597 .75708 .25186 .75177 .24665 Mtetra
.702 .859 .957 r
.75177 .24665 .75708 .25186 .76942 .24754 .76405 .24096 Mtetra
.707 .813 .931 r
.76405 .24096 .76942 .24754 .7818 .24311 .77637 .23521 Mtetra
.536 .715 .955 r
.11732 .45366 .12449 .45992 .13414 .45793 .12688 .45251 Mtetra
.518 .74 .975 r
.12688 .45251 .13414 .45793 .14384 .45589 .13649 .45138 Mtetra
.494 .766 .992 r
.13649 .45138 .14384 .45589 .1536 .45374 .14616 .45022 Mtetra
.461 .791 .999 r
.14616 .45022 .1536 .45374 .16342 .4514 .15588 .44898 Mtetra
.412 .807 .986 r
.15588 .44898 .16342 .4514 .17331 .4488 .16566 .44763 Mtetra
.342 .802 .937 r
.16566 .44763 .17331 .4488 .18328 .44587 .17552 .44607 Mtetra
.251 .763 .836 r
.17552 .44607 .18328 .44587 .19333 .44253 .18546 .44425 Mtetra
0 0 0 r
.18546 .44425 .19333 .44253 .20347 .43874 .19547 .4421 Mtetra
.19547 .4421 .20347 .43874 .21369 .43446 .20557 .43956 Mtetra
.043 0 0 r
.20557 .43956 .21369 .43446 .22399 .42969 .21576 .4366 Mtetra
.108 0 0 r
.21576 .4366 .22399 .42969 .23436 .42444 .22603 .43317 Mtetra
.161 0 0 r
.22603 .43317 .23436 .42444 .24479 .41878 .23638 .42933 Mtetra
.201 0 0 r
.23638 .42933 .24479 .41878 .25529 .41276 .2468 .42509 Mtetra
.234 0 .04 r
.2468 .42509 .25529 .41276 .26582 .40652 .25728 .42052 Mtetra
.26 0 .091 r
.25728 .42052 .26582 .40652 .27638 .40016 .26782 .41567 Mtetra
.28 0 .129 r
.26782 .41567 .27638 .40016 .28697 .39378 .27841 .41059 Mtetra
.294 0 .157 r
.27841 .41059 .28697 .39378 .29758 .38745 .28904 .40529 Mtetra
.298 0 .174 r
.28904 .40529 .29758 .38745 .30823 .38095 .29973 .39967 Mtetra
.301 0 .187 r
.29973 .39967 .30823 .38095 .31891 .3742 .31047 .39374 Mtetra
.317 0 .205 r
.31047 .39374 .31891 .3742 .32962 .36735 .32123 .38796 Mtetra
.345 .001 .229 r
.32123 .38796 .32962 .36735 .34034 .36065 .33198 .38268 Mtetra
.385 .045 .261 r
.33198 .38268 .34034 .36065 .35102 .35506 .34271 .37842 Mtetra
.42 .084 .287 r
.34271 .37842 .35102 .35506 .36165 .35105 .35341 .37533 Mtetra
.431 .098 .298 r
.35341 .37533 .36165 .35105 .37225 .34836 .36415 .37256 Mtetra
.428 .095 .296 r
.36415 .37256 .37225 .34836 .38286 .34674 .37494 .36965 Mtetra
.407 .07 .278 r
.37494 .36965 .38286 .34674 .39352 .34516 .38581 .36604 Mtetra
.374 .03 .246 r
.38581 .36604 .39352 .34516 .40425 .34309 .39676 .36161 Mtetra
.348 0 .209 r
.39676 .36161 .40425 .34309 .41507 .34043 .40775 .35699 Mtetra
.332 0 .176 r
.40775 .35699 .41507 .34043 .42595 .33709 .41878 .35253 Mtetra
.34 0 .163 r
.41878 .35253 .42595 .33709 .43689 .33328 .42983 .34871 Mtetra
.362 0 .173 r
.42983 .34871 .43689 .33328 .44789 .329 .44091 .34553 Mtetra
.378 .005 .197 r
.44091 .34553 .44789 .329 .45895 .32403 .45203 .34251 Mtetra
.39 .03 .227 r
.45203 .34251 .45895 .32403 .47005 .31846 .46321 .3393 Mtetra
.387 .042 .252 r
.46321 .3393 .47005 .31846 .48119 .3124 .47445 .33527 Mtetra
.385 .05 .27 r
.47445 .33527 .48119 .3124 .49236 .30637 .48574 .33053 Mtetra
.391 .061 .282 r
.48574 .33053 .49236 .30637 .50356 .30141 .49708 .32565 Mtetra
.398 .069 .286 r
.49708 .32565 .50356 .30141 .51479 .29779 .50846 .32109 Mtetra
.418 .081 .285 r
.50846 .32109 .51479 .29779 .52606 .29576 .51988 .31771 Mtetra
.432 .087 .279 r
.51988 .31771 .52606 .29576 .53741 .29487 .53135 .31537 Mtetra
.436 .083 .267 r
.53135 .31537 .53741 .29487 .54882 .29413 .54288 .31353 Mtetra
.435 .075 .254 r
.54288 .31353 .54882 .29413 .5603 .29331 .55448 .31187 Mtetra
.423 .059 .24 r
.55448 .31187 .5603 .29331 .57185 .29224 .56614 .30989 Mtetra
.41 .041 .224 r
.56614 .30989 .57185 .29224 .58347 .29101 .57786 .30758 Mtetra
.396 .021 .204 r
.57786 .30758 .58347 .29101 .59516 .28983 .58964 .30506 Mtetra
.378 0 .175 r
.58964 .30506 .59516 .28983 .60692 .28864 .60148 .30229 Mtetra
.351 0 .136 r
.60148 .30229 .60692 .28864 .61875 .28733 .61337 .29924 Mtetra
.314 0 .081 r
.61337 .29924 .61875 .28733 .63064 .2858 .6253 .29586 Mtetra
.258 0 .005 r
.6253 .29586 .63064 .2858 .64259 .28391 .63728 .29207 Mtetra
.178 0 0 r
.63728 .29207 .64259 .28391 .65458 .2816 .6493 .28783 Mtetra
.061 0 0 r
.6493 .28783 .65458 .2816 .66662 .27879 .66134 .28312 Mtetra
0 0 0 r
.66134 .28312 .66662 .27879 .6787 .27548 .67341 .27797 Mtetra
.67341 .27797 .6787 .27548 .69081 .27165 .68551 .2724 Mtetra
.477 .894 .813 r
.68551 .2724 .69081 .27165 .70295 .26736 .69763 .26648 Mtetra
.612 .951 .919 r
.69763 .26648 .70295 .26736 .71511 .26264 .70977 .26027 Mtetra
.688 .948 .958 r
.70977 .26027 .71511 .26264 .7273 .25756 .72194 .25385 Mtetra
.723 .917 .96 r
.72194 .25385 .7273 .25756 .73952 .25221 .73413 .24729 Mtetra
.736 .88 .947 r
.73413 .24729 .73952 .25221 .75177 .24665 .74635 .24064 Mtetra
.738 .843 .929 r
.74635 .24064 .75177 .24665 .76405 .24096 .75861 .23394 Mtetra
.734 .81 .911 r
.75861 .23394 .76405 .24096 .77637 .23521 .7709 .22725 Mtetra
.51 .705 .958 r
.1101 .44736 .11732 .45366 .12688 .45251 .11963 .44657 Mtetra
.497 .713 .968 r
.11963 .44657 .12688 .45251 .13649 .45138 .12921 .44584 Mtetra
.482 .723 .977 r
.12921 .44584 .13649 .45138 .14616 .45022 .13883 .44517 Mtetra
.463 .735 .986 r
.13883 .44517 .14616 .45022 .15588 .44898 .1485 .44453 Mtetra
.436 .747 .993 r
.1485 .44453 .15588 .44898 .16566 .44763 .15822 .44392 Mtetra
.403 .76 .994 r
.15822 .44392 .16566 .44763 .17552 .44607 .168 .44327 Mtetra
.355 .768 .98 r
.168 .44327 .17552 .44607 .18546 .44425 .17785 .44254 Mtetra
.289 .762 .936 r
.17785 .44254 .18546 .44425 .19547 .4421 .18776 .44167 Mtetra
.202 .726 .846 r
.18776 .44167 .19547 .4421 .20557 .43956 .19775 .44058 Mtetra
.096 .651 .704 r
.19775 .44058 .20557 .43956 .21576 .4366 .20782 .43924 Mtetra
.009 0 0 r
.20782 .43924 .21576 .4366 .22603 .43317 .21798 .43758 Mtetra
.102 0 0 r
.21798 .43758 .22603 .43317 .23638 .42933 .22821 .4356 Mtetra
.173 0 0 r
.22821 .4356 .23638 .42933 .2468 .42509 .23853 .43328 Mtetra
.226 0 0 r
.23853 .43328 .2468 .42509 .25728 .42052 .24892 .43063 Mtetra
.263 0 0 r
.24892 .43063 .25728 .42052 .26782 .41567 .25938 .42764 Mtetra
.288 0 .058 r
.25938 .42764 .26782 .41567 .27841 .41059 .26992 .4243 Mtetra
.306 0 .106 r
.26992 .4243 .27841 .41059 .28904 .40529 .28053 .42063 Mtetra
.321 0 .143 r
.28053 .42063 .28904 .40529 .29973 .39967 .29119 .41668 Mtetra
.337 0 .177 r
.29119 .41668 .29973 .39967 .31047 .39374 .30191 .41255 Mtetra
.367 .007 .215 r
.30191 .41255 .31047 .39374 .32123 .38796 .31265 .40876 Mtetra
.398 .048 .251 r
.31265 .40876 .32123 .38796 .33198 .38268 .3234 .40552 Mtetra
.418 .077 .278 r
.3234 .40552 .33198 .38268 .34271 .37842 .33417 .40263 Mtetra
.426 .09 .291 r
.33417 .40263 .34271 .37842 .35341 .37533 .34498 .39981 Mtetra
.408 .075 .286 r
.34498 .39981 .35341 .37533 .36415 .37256 .3559 .39604 Mtetra
.372 .038 .263 r
.3559 .39604 .36415 .37256 .37494 .36965 .36692 .39093 Mtetra
.325 0 .224 r
.36692 .39093 .37494 .36965 .38581 .36604 .37803 .38472 Mtetra
.272 0 .171 r
.37803 .38472 .38581 .36604 .39676 .36161 .3892 .37781 Mtetra
.248 0 .125 r
.3892 .37781 .39676 .36161 .40775 .35699 .40037 .37134 Mtetra
.256 0 .097 r
.40037 .37134 .40775 .35699 .41878 .35253 .41154 .36593 Mtetra
.305 0 .102 r
.41154 .36593 .41878 .35253 .42983 .34871 .42269 .36209 Mtetra
.366 0 .132 r
.42269 .36209 .42983 .34871 .44091 .34553 .43383 .35984 Mtetra
.411 .014 .171 r
.43383 .35984 .44091 .34553 .45203 .34251 .44501 .35867 Mtetra
.437 .053 .212 r
.44501 .35867 .45203 .34251 .46321 .3393 .45625 .35794 Mtetra
.433 .067 .242 r
.45625 .35794 .46321 .3393 .47445 .33527 .46756 .35651 Mtetra
.421 .071 .264 r
.46756 .35651 .47445 .33527 .48574 .33053 .47896 .35399 Mtetra
.404 .067 .277 r
.47896 .35399 .48574 .33053 .49708 .32565 .49043 .3501 Mtetra
.39 .06 .28 r
.49043 .3501 .49708 .32565 .50846 .32109 .50195 .34526 Mtetra
.391 .059 .278 r
.50195 .34526 .50846 .32109 .51988 .31771 .51352 .34049 Mtetra
.39 .051 .266 r
.51352 .34049 .51988 .31771 .53135 .31537 .52513 .33607 Mtetra
.389 .04 .247 r
.52513 .33607 .53135 .31537 .54288 .31353 .53679 .33221 Mtetra
.383 .021 .222 r
.53679 .33221 .54288 .31353 .55448 .31187 .5485 .32868 Mtetra
.362 0 .189 r
.5485 .32868 .55448 .31187 .56614 .30989 .56026 .32497 Mtetra
.334 0 .15 r
.56026 .32497 .56614 .30989 .57786 .30758 .57207 .32099 Mtetra
.298 0 .103 r
.57207 .32099 .57786 .30758 .58964 .30506 .58393 .31665 Mtetra
.248 0 .038 r
.58393 .31665 .58964 .30506 .60148 .30229 .59582 .31195 Mtetra
.178 0 0 r
.59582 .31195 .60148 .30229 .61337 .29924 .60776 .3069 Mtetra
.079 0 0 r
.60776 .3069 .61337 .29924 .6253 .29586 .61972 .3015 Mtetra
0 0 0 r
.61972 .3015 .6253 .29586 .63728 .29207 .63172 .29574 Mtetra
.63172 .29574 .63728 .29207 .6493 .28783 .64375 .28965 Mtetra
.437 .863 .737 r
.64375 .28965 .6493 .28783 .66134 .28312 .6558 .28322 Mtetra
.592 .949 .872 r
.6558 .28322 .66134 .28312 .67341 .27797 .66787 .2765 Mtetra
.687 .966 .935 r
.66787 .2765 .67341 .27797 .68551 .2724 .67996 .26956 Mtetra
.733 .945 .951 r
.67996 .26956 .68551 .2724 .69763 .26648 .69207 .26245 Mtetra
.751 .912 .946 r
.69207 .26245 .69763 .26648 .70977 .26027 .70422 .25524 Mtetra
.757 .88 .935 r
.70422 .25524 .70977 .26027 .72194 .25385 .71638 .24799 Mtetra
.755 .852 .923 r
.71638 .24799 .72194 .25385 .73413 .24729 .72858 .24074 Mtetra
.751 .83 .912 r
.72858 .24074 .73413 .24729 .74635 .24064 .74082 .23353 Mtetra
.747 .812 .903 r
.74082 .23353 .74635 .24064 .75861 .23394 .75308 .22635 Mtetra
.742 .796 .896 r
.75308 .22635 .75861 .23394 .7709 .22725 .76539 .21923 Mtetra
.534 .714 .955 r
.10283 .44102 .1101 .44736 .11963 .44657 .11242 .43985 Mtetra
.533 .701 .947 r
.11242 .43985 .11963 .44657 .12921 .44584 .12205 .43878 Mtetra
.531 .689 .94 r
.12205 .43878 .12921 .44584 .13883 .44517 .13172 .4378 Mtetra
.528 .679 .934 r
.13172 .4378 .13883 .44517 .1485 .44453 .14142 .43693 Mtetra
.522 .67 .93 r
.14142 .43693 .1485 .44453 .15822 .44392 .15117 .43619 Mtetra
.517 .664 .928 r
.15117 .43619 .15822 .44392 .168 .44327 .16096 .43555 Mtetra
.512 .663 .93 r
.16096 .43555 .168 .44327 .17785 .44254 .17079 .43499 Mtetra
.508 .668 .934 r
.17079 .43499 .17785 .44254 .18776 .44167 .18069 .43444 Mtetra
.505 .678 .943 r
.18069 .43444 .18776 .44167 .19775 .44058 .19064 .43386 Mtetra
.501 .694 .955 r
.19064 .43386 .19775 .44058 .20782 .43924 .20066 .43318 Mtetra
.497 .718 .97 r
.20066 .43318 .20782 .43924 .21798 .43758 .21075 .43236 Mtetra
.488 .746 .986 r
.21075 .43236 .21798 .43758 .22821 .4356 .22091 .43136 Mtetra
.474 .777 .997 r
.22091 .43136 .22821 .4356 .23853 .43328 .23116 .43012 Mtetra
.449 .806 .997 r
.23116 .43012 .23853 .43328 .24892 .43063 .24148 .42862 Mtetra
.41 .823 .975 r
.24148 .42862 .24892 .43063 .25938 .42764 .25188 .42683 Mtetra
.354 .817 .921 r
.25188 .42683 .25938 .42764 .26992 .4243 .26236 .42474 Mtetra
.279 .782 .83 r
.26236 .42474 .26992 .4243 .28053 .42063 .27291 .42235 Mtetra
.174 .704 .699 r
.27291 .42235 .28053 .42063 .29119 .41668 .28352 .41981 Mtetra
0 0 0 r
.28352 .41981 .29119 .41668 .30191 .41255 .29419 .41721 Mtetra
.083 0 0 r
.29419 .41721 .30191 .41255 .31265 .40876 .3049 .41482 Mtetra
.182 0 0 r
.3049 .41482 .31265 .40876 .3234 .40552 .31564 .41268 Mtetra
.202 0 0 r
.31564 .41268 .3234 .40552 .33417 .40263 .32645 .41018 Mtetra
.164 0 0 r
.32645 .41018 .33417 .40263 .34498 .39981 .33736 .40692 Mtetra
.034 0 0 r
.33736 .40692 .34498 .39981 .3559 .39604 .3484 .40227 Mtetra
0 0 0 r
.3484 .40227 .3559 .39604 .36692 .39093 .35955 .39608 Mtetra
.35955 .39608 .36692 .39093 .37803 .38472 .37077 .38912 Mtetra
.4 .814 .619 r
.37077 .38912 .37803 .38472 .3892 .37781 .38203 .38196 Mtetra
0 0 0 r
.38203 .38196 .3892 .37781 .40037 .37134 .39327 .37548 Mtetra
.39327 .37548 .40037 .37134 .41154 .36593 .4045 .3702 Mtetra
.4045 .3702 .41154 .36593 .42269 .36209 .41572 .36635 Mtetra
.072 0 0 r
.41572 .36635 .42269 .36209 .43383 .35984 .42693 .36393 Mtetra
.17 0 0 r
.42693 .36393 .43383 .35984 .44501 .35867 .43818 .36271 Mtetra
.225 0 0 r
.43818 .36271 .44501 .35867 .45625 .35794 .44947 .3622 Mtetra
.22 0 0 r
.44947 .3622 .45625 .35794 .46756 .35651 .46083 .3615 Mtetra
.195 0 0 r
.46083 .3615 .46756 .35651 .47896 .35399 .47228 .36002 Mtetra
.131 0 0 r
.47228 .36002 .47896 .35399 .49043 .3501 .48382 .357 Mtetra
.074 0 0 r
.48382 .357 .49043 .3501 .50195 .34526 .49543 .35257 Mtetra
.042 0 0 r
.49543 .35257 .50195 .34526 .51352 .34049 .50708 .34736 Mtetra
0 0 0 r
.50708 .34736 .51352 .34049 .52513 .33607 .51878 .34178 Mtetra
.51878 .34178 .52513 .33607 .53679 .33221 .53052 .33646 Mtetra
.53052 .33646 .53679 .33221 .5485 .32868 .54229 .33133 Mtetra
.29 .766 .654 r
.54229 .33133 .5485 .32868 .56026 .32497 .55411 .32615 Mtetra
.435 .872 .802 r
.55411 .32615 .56026 .32497 .57207 .32099 .56597 .3208 Mtetra
.562 .934 .902 r
.56597 .3208 .57207 .32099 .58393 .31665 .57787 .31513 Mtetra
.652 .949 .952 r
.57787 .31513 .58393 .31665 .59582 .31195 .5898 .30915 Mtetra
.705 .932 .963 r
.5898 .30915 .59582 .31195 .60776 .3069 .60175 .30287 Mtetra
.733 .899 .953 r
.60175 .30287 .60776 .3069 .61972 .3015 .61374 .2963 Mtetra
.745 .863 .934 r
.61374 .2963 .61972 .3015 .63172 .29574 .62575 .28948 Mtetra
.749 .83 .914 r
.62575 .28948 .63172 .29574 .64375 .28965 .63779 .28246 Mtetra
.748 .802 .895 r
.63779 .28246 .64375 .28965 .6558 .28322 .64985 .27527 Mtetra
.745 .78 .881 r
.64985 .27527 .6558 .28322 .66787 .2765 .66194 .26798 Mtetra
.742 .764 .871 r
.66194 .26798 .66787 .2765 .67996 .26956 .67405 .26064 Mtetra
.739 .753 .864 r
.67405 .26064 .67996 .26956 .69207 .26245 .68619 .2533 Mtetra
.735 .747 .862 r
.68619 .2533 .69207 .26245 .70422 .25524 .69837 .24602 Mtetra
.732 .745 .862 r
.69837 .24602 .70422 .25524 .71638 .24799 .71058 .23883 Mtetra
.73 .747 .866 r
.71058 .23883 .71638 .24799 .72858 .24074 .72283 .23176 Mtetra
.729 .752 .871 r
.72283 .23176 .72858 .24074 .74082 .23353 .73512 .2248 Mtetra
.728 .76 .878 r
.73512 .2248 .74082 .23353 .75308 .22635 .74745 .21793 Mtetra
.728 .769 .886 r
.74745 .21793 .75308 .22635 .76539 .21923 .75983 .21113 Mtetra
.588 .732 .943 r
.09551 .43462 .10283 .44102 .11242 .43985 .10523 .43255 Mtetra
.589 .704 .922 r
.10523 .43255 .11242 .43985 .12205 .43878 .11498 .43056 Mtetra
.587 .676 .902 r
.11498 .43056 .12205 .43878 .13172 .4378 .12477 .42868 Mtetra
.582 .65 .883 r
.12477 .42868 .13172 .4378 .14142 .43693 .13458 .42696 Mtetra
.574 .627 .866 r
.13458 .42696 .14142 .43693 .15117 .43619 .14442 .42543 Mtetra
.568 .606 .851 r
.14442 .42543 .15117 .43619 .16096 .43555 .15429 .42408 Mtetra
.561 .589 .839 r
.15429 .42408 .16096 .43555 .17079 .43499 .16419 .42291 Mtetra
.556 .575 .828 r
.16419 .42291 .17079 .43499 .18069 .43444 .17413 .42189 Mtetra
.553 .565 .821 r
.17413 .42189 .18069 .43444 .19064 .43386 .18411 .42098 Mtetra
.551 .559 .816 r
.18411 .42098 .19064 .43386 .20066 .43318 .19414 .42013 Mtetra
.55 .557 .814 r
.19414 .42013 .20066 .43318 .21075 .43236 .20423 .41929 Mtetra
.552 .558 .814 r
.20423 .41929 .21075 .43236 .22091 .43136 .21438 .4184 Mtetra
.555 .562 .816 r
.21438 .4184 .22091 .43136 .23116 .43012 .2246 .4174 Mtetra
.56 .569 .82 r
.2246 .4174 .23116 .43012 .24148 .42862 .23489 .41625 Mtetra
.566 .579 .826 r
.23489 .41625 .24148 .42862 .25188 .42683 .24525 .41492 Mtetra
.571 .591 .835 r
.24525 .41492 .25188 .42683 .26236 .42474 .25568 .41343 Mtetra
.576 .606 .846 r
.25568 .41343 .26236 .42474 .27291 .42235 .26618 .41178 Mtetra
.577 .623 .862 r
.26618 .41178 .27291 .42235 .28352 .41981 .27674 .41009 Mtetra
.574 .643 .881 r
.27674 .41009 .28352 .41981 .29419 .41721 .28735 .40841 Mtetra
.573 .668 .903 r
.28735 .40841 .29419 .41721 .3049 .41482 .29802 .40669 Mtetra
.577 .69 .918 r
.29802 .40669 .3049 .41482 .31564 .41268 .30877 .40478 Mtetra
.614 .712 .915 r
.30877 .40478 .31564 .41268 .32645 .41018 .31962 .40201 Mtetra
.658 .72 .894 r
.31962 .40201 .32645 .41018 .33736 .40692 .33059 .39803 Mtetra
.691 .713 .866 r
.33059 .39803 .33736 .40692 .3484 .40227 .34168 .39287 Mtetra
.712 .708 .845 r
.34168 .39287 .3484 .40227 .35955 .39608 .35286 .3867 Mtetra
.714 .71 .845 r
.35286 .3867 .35955 .39608 .37077 .38912 .36407 .38045 Mtetra
.71 .726 .863 r
.36407 .38045 .37077 .38912 .38203 .38196 .37529 .37458 Mtetra
.7 .76 .898 r
.37529 .37458 .38203 .38196 .39327 .37548 .38651 .36935 Mtetra
.676 .793 .937 r
.38651 .36935 .39327 .37548 .4045 .3702 .39774 .36488 Mtetra
.646 .814 .964 r
.39774 .36488 .4045 .3702 .41572 .36635 .40899 .361 Mtetra
.616 .804 .972 r
.40899 .361 .41572 .36635 .42693 .36393 .42027 .35771 Mtetra
.585 .763 .963 r
.42027 .35771 .42693 .36393 .43818 .36271 .43158 .35519 Mtetra
.565 .712 .94 r
.43158 .35519 .43818 .36271 .44947 .3622 .44293 .35331 Mtetra
.556 .667 .911 r
.44293 .35331 .44947 .3622 .46083 .3615 .45433 .35183 Mtetra
.563 .65 .894 r
.45433 .35183 .46083 .3615 .47228 .36002 .4658 .35027 Mtetra
.601 .666 .885 r
.4658 .35027 .47228 .36002 .48382 .357 .47735 .3477 Mtetra
.642 .696 .884 r
.47735 .3477 .48382 .357 .49543 .35257 .48897 .34393 Mtetra
.682 .729 .886 r
.48897 .34393 .49543 .35257 .50708 .34736 .50065 .33894 Mtetra
.708 .745 .88 r
.50065 .33894 .50708 .34736 .51878 .34178 .51238 .33307 Mtetra
.711 .739 .873 r
.51238 .33307 .51878 .34178 .53052 .33646 .52415 .32699 Mtetra
.707 .72 .859 r
.52415 .32699 .53052 .33646 .54229 .33133 .53595 .32087 Mtetra
.7 .695 .842 r
.53595 .32087 .54229 .33133 .55411 .32615 .54779 .31474 Mtetra
.694 .674 .827 r
.54779 .31474 .55411 .32615 .56597 .3208 .55966 .30857 Mtetra
.692 .659 .813 r
.55966 .30857 .56597 .3208 .57787 .31513 .57157 .30223 Mtetra
.691 .648 .802 r
.57157 .30223 .57787 .31513 .5898 .30915 .5835 .29571 Mtetra
.691 .64 .794 r
.5835 .29571 .5898 .30915 .60175 .30287 .59547 .28899 Mtetra
.69 .633 .787 r
.59547 .28899 .60175 .30287 .61374 .2963 .60746 .2821 Mtetra
.69 .629 .783 r
.60746 .2821 .61374 .2963 .62575 .28948 .61949 .2751 Mtetra
.69 .627 .781 r
.61949 .2751 .62575 .28948 .63779 .28246 .63154 .26803 Mtetra
.69 .627 .78 r
.63154 .26803 .63779 .28246 .64985 .27527 .64362 .26095 Mtetra
.69 .629 .783 r
.64362 .26095 .64985 .27527 .66194 .26798 .65573 .25392 Mtetra
.689 .633 .787 r
.65573 .25392 .66194 .26798 .67405 .26064 .66788 .247 Mtetra
.69 .64 .794 r
.66788 .247 .67405 .26064 .68619 .2533 .68007 .24022 Mtetra
.69 .649 .804 r
.68007 .24022 .68619 .2533 .69837 .24602 .69231 .23361 Mtetra
.691 .661 .816 r
.69231 .23361 .69837 .24602 .71058 .23883 .70459 .22718 Mtetra
.692 .677 .831 r
.70459 .22718 .71058 .23883 .72283 .23176 .71692 .22095 Mtetra
.694 .696 .848 r
.71692 .22095 .72283 .23176 .73512 .2248 .72931 .21486 Mtetra
.696 .718 .866 r
.72931 .21486 .73512 .2248 .74745 .21793 .74174 .20888 Mtetra
.699 .743 .885 r
.74174 .20888 .74745 .21793 .75983 .21113 .75422 .20298 Mtetra
.651 .75 .922 r
.08813 .42819 .09551 .43462 .10523 .43255 .09804 .4248 Mtetra
.646 .71 .894 r
.09804 .4248 .10523 .43255 .11498 .43056 .10797 .42148 Mtetra
.639 .673 .867 r
.10797 .42148 .11498 .43056 .12477 .42868 .11793 .41827 Mtetra
.629 .64 .842 r
.11793 .41827 .12477 .42868 .13458 .42696 .12791 .4152 Mtetra
.618 .609 .82 r
.12791 .4152 .13458 .42696 .14442 .42543 .13791 .41234 Mtetra
.607 .582 .8 r
.13791 .41234 .14442 .42543 .15429 .42408 .14793 .40968 Mtetra
.597 .559 .782 r
.14793 .40968 .15429 .42408 .16419 .42291 .15796 .40725 Mtetra
.589 .538 .766 r
.15796 .40725 .16419 .42291 .17413 .42189 .16802 .40503 Mtetra
.581 .521 .752 r
.16802 .40503 .17413 .42189 .18411 .42098 .17811 .40299 Mtetra
.575 .507 .74 r
.17811 .40299 .18411 .42098 .19414 .42013 .18823 .4011 Mtetra
.571 .495 .73 r
.18823 .4011 .19414 .42013 .20423 .41929 .19839 .39932 Mtetra
.568 .486 .722 r
.19839 .39932 .20423 .41929 .21438 .4184 .20859 .39758 Mtetra
.567 .479 .715 r
.20859 .39758 .21438 .4184 .2246 .4174 .21885 .39586 Mtetra
.566 .473 .709 r
.21885 .39586 .2246 .4174 .23489 .41625 .22917 .3941 Mtetra
.566 .47 .704 r
.22917 .3941 .23489 .41625 .24525 .41492 .23954 .39229 Mtetra
.566 .467 .701 r
.23954 .39229 .24525 .41492 .25568 .41343 .24997 .39044 Mtetra
.566 .465 .699 r
.24997 .39044 .25568 .41343 .26618 .41178 .26046 .38853 Mtetra
.566 .464 .697 r
.26046 .38853 .26618 .41178 .27674 .41009 .271 .38662 Mtetra
.566 .463 .696 r
.271 .38662 .27674 .41009 .28735 .40841 .28159 .38469 Mtetra
.57 .464 .694 r
.28159 .38469 .28735 .40841 .29802 .40669 .29226 .38252 Mtetra
.576 .466 .691 r
.29226 .38252 .29802 .40669 .30877 .40478 .30302 .37994 Mtetra
.588 .47 .686 r
.30302 .37994 .30877 .40478 .31962 .40201 .31387 .37653 Mtetra
.601 .475 .681 r
.31387 .37653 .31962 .40201 .33059 .39803 .32484 .37215 Mtetra
.607 .477 .679 r
.32484 .37215 .33059 .39803 .34168 .39287 .33588 .36728 Mtetra
.609 .481 .68 r
.33588 .36728 .34168 .39287 .35286 .3867 .34696 .36227 Mtetra
.605 .484 .688 r
.34696 .36227 .35286 .3867 .36407 .38045 .35805 .35777 Mtetra
.599 .491 .702 r
.35805 .35777 .36407 .38045 .37529 .37458 .36914 .35398 Mtetra
.599 .506 .719 r
.36914 .35398 .37529 .37458 .38651 .36935 .38027 .35047 Mtetra
.604 .523 .736 r
.38027 .35047 .38651 .36935 .39774 .36488 .39145 .34698 Mtetra
.615 .539 .745 r
.39145 .34698 .39774 .36488 .40899 .361 .40269 .34307 Mtetra
.624 .544 .744 r
.40269 .34307 .40899 .361 .42027 .35771 .414 .33871 Mtetra
.619 .531 .734 r
.414 .33871 .42027 .35771 .43158 .35519 .42535 .33438 Mtetra
.608 .51 .718 r
.42535 .33438 .43158 .35519 .44293 .35331 .43673 .33033 Mtetra
.589 .485 .703 r
.43673 .33033 .44293 .35331 .45433 .35183 .44815 .32699 Mtetra
.577 .466 .691 r
.44815 .32699 .45433 .35183 .4658 .35027 .45961 .32417 Mtetra
.577 .46 .683 r
.45961 .32417 .4658 .35027 .47735 .3477 .47112 .32121 Mtetra
.583 .462 .681 r
.47112 .32121 .47735 .3477 .48897 .34393 .4827 .31776 Mtetra
.598 .473 .682 r
.4827 .31776 .48897 .34393 .50065 .33894 .49435 .31332 Mtetra
.611 .485 .684 r
.49435 .31332 .50065 .33894 .51238 .33307 .50604 .30804 Mtetra
.618 .493 .687 r
.50604 .30804 .51238 .33307 .52415 .32699 .51778 .30233 Mtetra
.623 .497 .689 r
.51778 .30233 .52415 .32699 .53595 .32087 .52955 .29637 Mtetra
.623 .499 .69 r
.52955 .29637 .53595 .32087 .54779 .31474 .54136 .29039 Mtetra
.624 .5 .691 r
.54136 .29039 .54779 .31474 .55966 .30857 .55321 .28439 Mtetra
.625 .502 .693 r
.55321 .28439 .55966 .30857 .57157 .30223 .56509 .27833 Mtetra
.627 .505 .695 r
.56509 .27833 .57157 .30223 .5835 .29571 .57702 .27221 Mtetra
.629 .509 .697 r
.57702 .27221 .5835 .29571 .59547 .28899 .58897 .26603 Mtetra
.631 .514 .701 r
.58897 .26603 .59547 .28899 .60746 .2821 .60096 .25981 Mtetra
.634 .52 .706 r
.60096 .25981 .60746 .2821 .61949 .2751 .61299 .25359 Mtetra
.636 .527 .713 r
.61299 .25359 .61949 .2751 .63154 .26803 .62506 .24741 Mtetra
.638 .535 .721 r
.62506 .24741 .63154 .26803 .64362 .26095 .63717 .24133 Mtetra
.64 .544 .73 r
.63717 .24133 .64362 .26095 .65573 .25392 .64932 .23539 Mtetra
.642 .555 .742 r
.64932 .23539 .65573 .25392 .66788 .247 .66152 .22964 Mtetra
.644 .569 .755 r
.66152 .22964 .66788 .247 .68007 .24022 .67378 .22409 Mtetra
.646 .584 .771 r
.67378 .22409 .68007 .24022 .69231 .23361 .68609 .21877 Mtetra
.648 .603 .79 r
.68609 .21877 .69231 .23361 .70459 .22718 .69847 .21366 Mtetra
.649 .624 .811 r
.69847 .21366 .70459 .22718 .71692 .22095 .7109 .20876 Mtetra
.652 .65 .835 r
.7109 .20876 .71692 .22095 .72931 .21486 .7234 .204 Mtetra
.655 .68 .861 r
.7234 .204 .72931 .21486 .74174 .20888 .73595 .19935 Mtetra
.658 .714 .89 r
.73595 .19935 .74174 .20888 .75422 .20298 .74857 .19475 Mtetra
.702 .761 .898 r
.0807 .4217 .08813 .42819 .09804 .4248 .09081 .41691 Mtetra
.692 .72 .871 r
.09081 .41691 .09804 .4248 .10797 .42148 .10095 .41215 Mtetra
.681 .683 .845 r
.10095 .41215 .10797 .42148 .11793 .41827 .11111 .40746 Mtetra
.668 .649 .821 r
.11111 .40746 .11793 .41827 .12791 .4152 .12128 .40291 Mtetra
.655 .618 .8 r
.12128 .40291 .12791 .4152 .13791 .41234 .13147 .39853 Mtetra
.642 .59 .78 r
.13147 .39853 .13791 .41234 .14793 .40968 .14166 .39434 Mtetra
.63 .564 .762 r
.14166 .39434 .14793 .40968 .15796 .40725 .15186 .39038 Mtetra
.619 .542 .746 r
.15186 .39038 .15796 .40725 .16802 .40503 .16208 .38664 Mtetra
.609 .522 .731 r
.16208 .38664 .16802 .40503 .17811 .40299 .17231 .38311 Mtetra
.6 .505 .718 r
.17231 .38311 .17811 .40299 .18823 .4011 .18256 .37977 Mtetra
.593 .49 .707 r
.18256 .37977 .18823 .4011 .19839 .39932 .19284 .3766 Mtetra
.587 .478 .697 r
.19284 .3766 .19839 .39932 .20859 .39758 .20314 .37355 Mtetra
.583 .468 .688 r
.20314 .37355 .20859 .39758 .21885 .39586 .21348 .37059 Mtetra
.579 .459 .68 r
.21348 .37059 .21885 .39586 .22917 .3941 .22386 .3677 Mtetra
.576 .452 .674 r
.22386 .3677 .22917 .3941 .23954 .39229 .23428 .36487 Mtetra
.573 .446 .668 r
.23428 .36487 .23954 .39229 .24997 .39044 .24475 .36209 Mtetra
.571 .44 .664 r
.24475 .36209 .24997 .39044 .26046 .38853 .25526 .35933 Mtetra
.57 .437 .66 r
.25526 .35933 .26046 .38853 .271 .38662 .26581 .35656 Mtetra
.569 .433 .656 r
.26581 .35656 .271 .38662 .28159 .38469 .27643 .35372 Mtetra
.572 .432 .652 r
.27643 .35372 .28159 .38469 .29226 .38252 .28711 .35058 Mtetra
.576 .432 .648 r
.28711 .35058 .29226 .38252 .30302 .37994 .29787 .34702 Mtetra
.58 .431 .644 r
.29787 .34702 .30302 .37994 .31387 .37653 .30871 .343 Mtetra
.582 .432 .642 r
.30871 .343 .31387 .37653 .32484 .37215 .31961 .33865 Mtetra
.578 .429 .642 r
.31961 .33865 .32484 .37215 .33588 .36728 .33053 .33469 Mtetra
.57 .426 .646 r
.33053 .33469 .33588 .36728 .34696 .36227 .34145 .33145 Mtetra
.56 .426 .654 r
.34145 .33145 .34696 .36227 .35805 .35777 .35237 .32915 Mtetra
.552 .429 .666 r
.35237 .32915 .35805 .35777 .36914 .35398 .3633 .32759 Mtetra
.557 .443 .679 r
.3633 .32759 .36914 .35398 .38027 .35047 .37431 .32583 Mtetra
.573 .463 .69 r
.37431 .32583 .38027 .35047 .39145 .34698 .38541 .32328 Mtetra
.597 .484 .695 r
.38541 .32328 .39145 .34698 .40269 .34307 .39663 .31932 Mtetra
.619 .497 .693 r
.39663 .31932 .40269 .34307 .414 .33871 .40794 .31393 Mtetra
.626 .496 .685 r
.40794 .31393 .414 .33871 .42535 .33438 .41932 .30776 Mtetra
.623 .485 .674 r
.41932 .30776 .42535 .33438 .43673 .33033 .43074 .30136 Mtetra
.606 .465 .663 r
.43074 .30136 .43673 .33033 .44815 .32699 .44216 .29572 Mtetra
.59 .446 .654 r
.44216 .29572 .44815 .32699 .45961 .32417 .4536 .291 Mtetra
.577 .431 .646 r
.4536 .291 .45961 .32417 .47112 .32121 .46508 .28703 Mtetra
.571 .424 .643 r
.46508 .28703 .47112 .32121 .4827 .31776 .47659 .28344 Mtetra
.575 .426 .642 r
.47659 .28344 .4827 .31776 .49435 .31332 .48816 .27951 Mtetra
.581 .432 .644 r
.48816 .27951 .49435 .31332 .50604 .30804 .49978 .27512 Mtetra
.587 .439 .648 r
.49978 .27512 .50604 .30804 .51778 .30233 .51146 .2703 Mtetra
.592 .446 .651 r
.51146 .2703 .51778 .30233 .52955 .29637 .52317 .26517 Mtetra
.595 .45 .655 r
.52317 .26517 .52955 .29637 .54136 .29039 .53494 .25996 Mtetra
.596 .454 .659 r
.53494 .25996 .54136 .29039 .55321 .28439 .54674 .25473 Mtetra
.598 .458 .662 r
.54674 .25473 .55321 .28439 .56509 .27833 .55859 .24952 Mtetra
.599 .463 .667 r
.55859 .24952 .56509 .27833 .57702 .27221 .57048 .24436 Mtetra
.601 .468 .672 r
.57048 .24436 .57702 .27221 .58897 .26603 .58241 .23924 Mtetra
.602 .474 .678 r
.58241 .23924 .58897 .26603 .60096 .25981 .59439 .2342 Mtetra
.604 .482 .686 r
.59439 .2342 .60096 .25981 .61299 .25359 .60643 .22925 Mtetra
.606 .49 .695 r
.60643 .22925 .61299 .25359 .62506 .24741 .61851 .22442 Mtetra
.607 .499 .705 r
.61851 .22442 .62506 .24741 .63717 .24133 .63065 .21975 Mtetra
.609 .51 .717 r
.63065 .21975 .63717 .24133 .64932 .23539 .64284 .21527 Mtetra
.609 .523 .731 r
.64284 .21527 .64932 .23539 .66152 .22964 .6551 .21102 Mtetra
.61 .537 .747 r
.6551 .21102 .66152 .22964 .67378 .22409 .66743 .20698 Mtetra
.61 .554 .766 r
.66743 .20698 .67378 .22409 .68609 .21877 .67982 .20317 Mtetra
.611 .573 .787 r
.67982 .20317 .68609 .21877 .69847 .21366 .69228 .19957 Mtetra
.611 .596 .811 r
.69228 .19957 .69847 .21366 .7109 .20876 .70482 .19615 Mtetra
.611 .623 .838 r
.70482 .19615 .7109 .20876 .7234 .204 .71744 .19285 Mtetra
.611 .654 .867 r
.71744 .19285 .7234 .204 .73595 .19935 .73012 .18964 Mtetra
.61 .689 .899 r
.73012 .18964 .73595 .19935 .74857 .19475 .74288 .18646 Mtetra
.734 .766 .878 r
.07322 .41517 .0807 .4217 .09081 .41691 .08351 .40919 Mtetra
.725 .733 .857 r
.08351 .40919 .09081 .41691 .10095 .41215 .09383 .40323 Mtetra
.714 .703 .838 r
.09383 .40323 .10095 .41215 .11111 .40746 .10416 .39731 Mtetra
.702 .674 .82 r
.10416 .39731 .11111 .40746 .12128 .40291 .11451 .39148 Mtetra
.69 .647 .802 r
.11451 .39148 .12128 .40291 .13147 .39853 .12486 .38579 Mtetra
.677 .622 .786 r
.12486 .38579 .13147 .39853 .14166 .39434 .13522 .38026 Mtetra
.665 .598 .77 r
.13522 .38026 .14166 .39434 .15186 .39038 .14559 .37493 Mtetra
.653 .576 .756 r
.14559 .37493 .15186 .39038 .16208 .38664 .15596 .3698 Mtetra
.641 .555 .742 r
.15596 .3698 .16208 .38664 .17231 .38311 .16633 .36489 Mtetra
.631 .537 .729 r
.16633 .36489 .17231 .38311 .18256 .37977 .17672 .36018 Mtetra
.622 .521 .718 r
.17672 .36018 .18256 .37977 .19284 .3766 .18711 .35565 Mtetra
.614 .506 .708 r
.18711 .35565 .19284 .3766 .20314 .37355 .19753 .35128 Mtetra
.608 .494 .698 r
.19753 .35128 .20314 .37355 .21348 .37059 .20797 .34705 Mtetra
.602 .483 .69 r
.20797 .34705 .21348 .37059 .22386 .3677 .21844 .34294 Mtetra
.597 .473 .682 r
.21844 .34294 .22386 .3677 .23428 .36487 .22893 .33892 Mtetra
.592 .465 .675 r
.22893 .33892 .23428 .36487 .24475 .36209 .23946 .33498 Mtetra
.589 .457 .669 r
.23946 .33498 .24475 .36209 .25526 .35933 .25002 .33109 Mtetra
.586 .451 .663 r
.25002 .33109 .25526 .35933 .26581 .35656 .26063 .32721 Mtetra
.584 .445 .658 r
.26063 .32721 .26581 .35656 .27643 .35372 .27127 .32331 Mtetra
.583 .441 .653 r
.27127 .32331 .27643 .35372 .28711 .35058 .28197 .31933 Mtetra
.582 .437 .65 r
.28197 .31933 .28711 .35058 .29787 .34702 .29271 .3153 Mtetra
.578 .433 .648 r
.29271 .3153 .29787 .34702 .30871 .343 .30347 .31152 Mtetra
.571 .429 .65 r
.30347 .31152 .30871 .343 .31961 .33865 .31424 .30826 Mtetra
.557 .424 .655 r
.31424 .30826 .31961 .33865 .33053 .33469 .32499 .30616 Mtetra
.538 .419 .665 r
.32499 .30616 .33053 .33469 .34145 .33145 .33571 .30542 Mtetra
.521 .42 .68 r
.33571 .30542 .34145 .33145 .35237 .32915 .34644 .30567 Mtetra
.511 .429 .699 r
.34644 .30567 .35237 .32915 .3633 .32759 .35722 .30639 Mtetra
.528 .456 .719 r
.35722 .30639 .3633 .32759 .37431 .32583 .36811 .30627 Mtetra
.564 .493 .734 r
.36811 .30627 .37431 .32583 .38541 .32328 .37916 .30455 Mtetra
.613 .529 .736 r
.37916 .30455 .38541 .32328 .39663 .31932 .39036 .30055 Mtetra
.652 .552 .729 r
.39036 .30055 .39663 .31932 .40794 .31393 .4017 .29425 Mtetra
.672 .556 .716 r
.4017 .29425 .40794 .31393 .41932 .30776 .41314 .28634 Mtetra
.674 .545 .7 r
.41314 .28634 .41932 .30776 .43074 .30136 .42461 .27758 Mtetra
.657 .521 .686 r
.42461 .27758 .43074 .30136 .44216 .29572 .43609 .26928 Mtetra
.634 .493 .673 r
.43609 .26928 .44216 .29572 .4536 .291 .44756 .26196 Mtetra
.609 .466 .662 r
.44756 .26196 .4536 .291 .46508 .28703 .45902 .256 Mtetra
.59 .446 .654 r
.45902 .256 .46508 .28703 .47659 .28344 .4705 .2512 Mtetra
.581 .436 .649 r
.4705 .2512 .47659 .28344 .48816 .27951 .48201 .24693 Mtetra
.577 .433 .648 r
.48201 .24693 .48816 .27951 .49978 .27512 .49357 .24291 Mtetra
.578 .435 .65 r
.49357 .24291 .49978 .27512 .51146 .2703 .50518 .23884 Mtetra
.581 .439 .653 r
.50518 .23884 .51146 .2703 .52317 .26517 .51684 .23469 Mtetra
.583 .444 .658 r
.51684 .23469 .52317 .26517 .53494 .25996 .52855 .23052 Mtetra
.584 .45 .663 r
.52855 .23052 .53494 .25996 .54674 .25473 .54031 .22635 Mtetra
.586 .455 .669 r
.54031 .22635 .54674 .25473 .55859 .24952 .55212 .22224 Mtetra
.587 .461 .676 r
.55212 .22224 .55859 .24952 .57048 .24436 .56399 .2182 Mtetra
.588 .467 .683 r
.56399 .2182 .57048 .24436 .58241 .23924 .57591 .21425 Mtetra
.589 .475 .691 r
.57591 .21425 .58241 .23924 .59439 .2342 .58789 .21043 Mtetra
.589 .482 .7 r
.58789 .21043 .59439 .2342 .60643 .22925 .59992 .20674 Mtetra
.59 .491 .711 r
.59992 .20674 .60643 .22925 .61851 .22442 .61202 .20322 Mtetra
.589 .501 .723 r
.61202 .20322 .61851 .22442 .63065 .21975 .62419 .19989 Mtetra
.589 .512 .736 r
.62419 .19989 .63065 .21975 .64284 .21527 .63642 .19676 Mtetra
.587 .525 .752 r
.63642 .19676 .64284 .21527 .6551 .21102 .64873 .19386 Mtetra
.586 .539 .769 r
.64873 .19386 .6551 .21102 .66743 .20698 .66112 .19117 Mtetra
.583 .555 .789 r
.66112 .19117 .66743 .20698 .67982 .20317 .67358 .18868 Mtetra
.581 .574 .81 r
.67358 .18868 .67982 .20317 .69228 .19957 .68613 .18637 Mtetra
.578 .594 .833 r
.68613 .18637 .69228 .19957 .70482 .19615 .69876 .1842 Mtetra
.574 .618 .858 r
.69876 .1842 .70482 .19615 .71744 .19285 .71147 .18213 Mtetra
.57 .644 .885 r
.71147 .18213 .71744 .19285 .73012 .18964 .72426 .18011 Mtetra
.565 .674 .912 r
.72426 .18011 .73012 .18964 .74288 .18646 .73713 .1781 Mtetra
.753 .768 .865 r
.06568 .40859 .07322 .41517 .08351 .40919 .07611 .40181 Mtetra
.746 .746 .852 r
.07611 .40181 .08351 .40919 .09383 .40323 .08656 .39502 Mtetra
.738 .726 .84 r
.08656 .39502 .09383 .40323 .10416 .39731 .09703 .38825 Mtetra
.73 .705 .828 r
.09703 .38825 .10416 .39731 .11451 .39148 .10751 .38154 Mtetra
.72 .685 .816 r
.10751 .38154 .11451 .39148 .12486 .38579 .11799 .3749 Mtetra
.71 .665 .804 r
.11799 .3749 .12486 .38579 .13522 .38026 .12849 .36839 Mtetra
.7 .645 .792 r
.12849 .36839 .13522 .38026 .14559 .37493 .13899 .36203 Mtetra
.689 .626 .78 r
.13899 .36203 .14559 .37493 .15596 .3698 .14948 .35584 Mtetra
.678 .607 .769 r
.14948 .35584 .15596 .3698 .16633 .36489 .15999 .34984 Mtetra
.667 .589 .758 r
.15999 .34984 .16633 .36489 .17672 .36018 .17049 .34403 Mtetra
.658 .572 .747 r
.17049 .34403 .17672 .36018 .18711 .35565 .181 .3384 Mtetra
.649 .556 .737 r
.181 .3384 .18711 .35565 .19753 .35128 .19153 .33294 Mtetra
.64 .542 .727 r
.19153 .33294 .19753 .35128 .20797 .34705 .20206 .32763 Mtetra
.633 .529 .719 r
.20206 .32763 .20797 .34705 .21844 .34294 .21262 .32245 Mtetra
.627 .518 .71 r
.21262 .32245 .21844 .34294 .22893 .33892 .22319 .31737 Mtetra
.621 .507 .702 r
.22319 .31737 .22893 .33892 .23946 .33498 .23379 .31236 Mtetra
.617 .498 .695 r
.23379 .31236 .23946 .33498 .25002 .33109 .24442 .30741 Mtetra
.612 .489 .688 r
.24442 .30741 .25002 .33109 .26063 .32721 .25508 .30251 Mtetra
.608 .481 .682 r
.25508 .30251 .26063 .32721 .27127 .32331 .26577 .29768 Mtetra
.602 .473 .677 r
.26577 .29768 .27127 .32331 .28197 .31933 .27648 .29303 Mtetra
.595 .465 .674 r
.27648 .29303 .28197 .31933 .29271 .3153 .28721 .28872 Mtetra
.583 .456 .673 r
.28721 .28872 .29271 .3153 .30347 .31152 .29791 .28523 Mtetra
.565 .446 .676 r
.29791 .28523 .30347 .31152 .31424 .30826 .30858 .28286 Mtetra
.54 .434 .683 r
.30858 .28286 .31424 .30826 .32499 .30616 .3192 .282 Mtetra
.511 .423 .692 r
.3192 .282 .32499 .30616 .33571 .30542 .32979 .28263 Mtetra
.493 .421 .704 r
.32979 .28263 .33571 .30542 .34644 .30567 .34042 .28401 Mtetra
.491 .428 .714 r
.34042 .28401 .34644 .30567 .35722 .30639 .35112 .28543 Mtetra
.518 .452 .721 r
.35112 .28543 .35722 .30639 .36811 .30627 .36197 .28567 Mtetra
.56 .482 .723 r
.36197 .28567 .36811 .30627 .37916 .30455 .37299 .28402 Mtetra
.607 .511 .72 r
.37299 .28402 .37916 .30455 .39036 .30055 .38418 .27997 Mtetra
.646 .534 .713 r
.38418 .27997 .39036 .30055 .4017 .29425 .39551 .27353 Mtetra
.672 .549 .706 r
.39551 .27353 .4017 .29425 .41314 .28634 .40695 .26517 Mtetra
.685 .553 .699 r
.40695 .26517 .41314 .28634 .42461 .27758 .41844 .25563 Mtetra
.68 .545 .694 r
.41844 .25563 .42461 .27758 .43609 .26928 .42995 .2461 Mtetra
.665 .529 .689 r
.42995 .2461 .43609 .26928 .44756 .26196 .44143 .23731 Mtetra
.639 .505 .683 r
.44143 .23731 .44756 .26196 .45902 .256 .4529 .23001 Mtetra
.615 .483 .678 r
.4529 .23001 .45902 .256 .4705 .2512 .46436 .22422 Mtetra
.596 .466 .674 r
.46436 .22422 .4705 .2512 .48201 .24693 .47584 .21957 Mtetra
.584 .457 .673 r
.47584 .21957 .48201 .24693 .49357 .24291 .48735 .21574 Mtetra
.579 .455 .675 r
.48735 .21574 .49357 .24291 .50518 .23884 .49892 .21226 Mtetra
.577 .457 .679 r
.49892 .21226 .50518 .23884 .51684 .23469 .51053 .20897 Mtetra
.578 .462 .685 r
.51053 .20897 .51684 .23469 .52855 .23052 .5222 .20574 Mtetra
.579 .468 .691 r
.5222 .20574 .52855 .23052 .54031 .22635 .53393 .20257 Mtetra
.58 .475 .699 r
.53393 .20257 .54031 .22635 .55212 .22224 .54572 .19945 Mtetra
.58 .482 .707 r
.54572 .19945 .55212 .22224 .56399 .2182 .55758 .19642 Mtetra
.581 .49 .716 r
.55758 .19642 .56399 .2182 .57591 .21425 .56949 .19348 Mtetra
.58 .498 .726 r
.56949 .19348 .57591 .21425 .58789 .21043 .58147 .19068 Mtetra
.579 .506 .737 r
.58147 .19068 .58789 .21043 .59992 .20674 .59352 .18804 Mtetra
.578 .516 .749 r
.59352 .18804 .59992 .20674 .61202 .20322 .60564 .18557 Mtetra
.575 .526 .763 r
.60564 .18557 .61202 .20322 .62419 .19989 .61783 .1833 Mtetra
.572 .537 .778 r
.61783 .1833 .62419 .19989 .63642 .19676 .6301 .18122 Mtetra
.568 .55 .794 r
.6301 .18122 .63642 .19676 .64873 .19386 .64245 .17934 Mtetra
.564 .563 .811 r
.64245 .17934 .64873 .19386 .66112 .19117 .65489 .17764 Mtetra
.558 .578 .829 r
.65489 .17764 .66112 .19117 .67358 .18868 .66741 .1761 Mtetra
.553 .593 .848 r
.66741 .1761 .67358 .18868 .68613 .18637 .68002 .1747 Mtetra
.547 .61 .867 r
.68002 .1747 .68613 .18637 .69876 .1842 .69272 .17339 Mtetra
.541 .628 .887 r
.69272 .17339 .69876 .1842 .71147 .18213 .70551 .17213 Mtetra
.535 .647 .906 r
.70551 .17213 .71147 .18213 .72426 .18011 .71838 .17091 Mtetra
.528 .666 .924 r
.71838 .17091 .72426 .18011 .73713 .1781 .73134 .16968 Mtetra
.755 .768 .863 r
.05808 .40196 .06568 .40859 .07611 .40181 .06856 .39503 Mtetra
.755 .764 .861 r
.06856 .39503 .07611 .40181 .08656 .39502 .07906 .38806 Mtetra
.753 .76 .858 r
.07906 .38806 .08656 .39502 .09703 .38825 .08958 .38109 Mtetra
.751 .756 .856 r
.08958 .38109 .09703 .38825 .10751 .38154 .10012 .37414 Mtetra
.748 .75 .854 r
.10012 .37414 .10751 .38154 .11799 .3749 .11067 .36722 Mtetra
.744 .743 .851 r
.11067 .36722 .11799 .3749 .12849 .36839 .12123 .36038 Mtetra
.739 .735 .847 r
.12123 .36038 .12849 .36839 .13899 .36203 .1318 .35364 Mtetra
.733 .725 .843 r
.1318 .35364 .13899 .36203 .14948 .35584 .14237 .34703 Mtetra
.726 .714 .839 r
.14237 .34703 .14948 .35584 .15999 .34984 .15294 .34056 Mtetra
.719 .703 .834 r
.15294 .34056 .15999 .34984 .17049 .34403 .16353 .33425 Mtetra
.711 .69 .828 r
.16353 .33425 .17049 .34403 .181 .3384 .17411 .32809 Mtetra
.704 .678 .822 r
.17411 .32809 .181 .3384 .19153 .33294 .18471 .32208 Mtetra
.696 .665 .816 r
.18471 .32208 .19153 .33294 .20206 .32763 .19531 .31623 Mtetra
.689 .653 .809 r
.19531 .31623 .20206 .32763 .21262 .32245 .20593 .31051 Mtetra
.682 .642 .803 r
.20593 .31051 .21262 .32245 .22319 .31737 .21657 .30491 Mtetra
.677 .631 .797 r
.21657 .30491 .22319 .31737 .23379 .31236 .22723 .29941 Mtetra
.671 .622 .791 r
.22723 .29941 .23379 .31236 .24442 .30741 .23791 .29399 Mtetra
.666 .613 .786 r
.23791 .29399 .24442 .30741 .25508 .30251 .24861 .28866 Mtetra
.662 .605 .781 r
.24861 .28866 .25508 .30251 .26577 .29768 .25934 .28343 Mtetra
.655 .597 .777 r
.25934 .28343 .26577 .29768 .27648 .29303 .27008 .27838 Mtetra
.647 .588 .774 r
.27008 .27838 .27648 .29303 .28721 .28872 .28084 .27359 Mtetra
.633 .575 .771 r
.28084 .27359 .28721 .28872 .29791 .28523 .2916 .26931 Mtetra
.616 .557 .765 r
.2916 .26931 .29791 .28523 .30858 .28286 .30235 .26567 Mtetra
.597 .532 .752 r
.30235 .26567 .30858 .28286 .3192 .282 .3131 .26266 Mtetra
.579 .501 .731 r
.3131 .26266 .3192 .282 .32979 .28263 .32388 .26018 Mtetra
.572 .473 .704 r
.32388 .26018 .32979 .28263 .34042 .28401 .3347 .2577 Mtetra
.57 .45 .677 r
.3347 .2577 .34042 .28401 .35112 .28543 .34559 .25495 Mtetra
.569 .432 .654 r
.34559 .25495 .35112 .28543 .36197 .28567 .35657 .25175 Mtetra
.57 .421 .64 r
.35657 .25175 .36197 .28567 .37299 .28402 .36762 .24803 Mtetra
.572 .417 .632 r
.36762 .24803 .37299 .28402 .38418 .27997 .37874 .24393 Mtetra
.576 .419 .632 r
.37874 .24393 .38418 .27997 .39551 .27353 .38991 .23945 Mtetra
.585 .431 .639 r
.38991 .23945 .39551 .27353 .40695 .26517 .40116 .23445 Mtetra
.597 .451 .653 r
.40116 .23445 .40695 .26517 .41844 .25563 .41246 .229 Mtetra
.612 .477 .674 r
.41246 .229 .41844 .25563 .42995 .2461 .42381 .22326 Mtetra
.624 .506 .698 r
.42381 .22326 .42995 .2461 .44143 .23731 .43519 .21752 Mtetra
.628 .53 .724 r
.43519 .21752 .44143 .23731 .4529 .23001 .44659 .21231 Mtetra
.625 .548 .747 r
.44659 .21231 .4529 .23001 .46436 .22422 .45802 .20774 Mtetra
.617 .557 .765 r
.45802 .20774 .46436 .22422 .47584 .21957 .46949 .20381 Mtetra
.608 .561 .777 r
.46949 .20381 .47584 .21957 .48735 .21574 .48099 .20039 Mtetra
.602 .564 .784 r
.48099 .20039 .48735 .21574 .49892 .21226 .49255 .19725 Mtetra
.598 .568 .791 r
.49255 .19725 .49892 .21226 .51053 .20897 .50417 .19429 Mtetra
.597 .572 .797 r
.50417 .19429 .51053 .20897 .5222 .20574 .51585 .19142 Mtetra
.595 .577 .804 r
.51585 .19142 .5222 .20574 .53393 .20257 .52758 .18865 Mtetra
.593 .583 .811 r
.52758 .18865 .53393 .20257 .54572 .19945 .53938 .18597 Mtetra
.591 .59 .82 r
.53938 .18597 .54572 .19945 .55758 .19642 .55125 .18339 Mtetra
.587 .597 .829 r
.55125 .18339 .55758 .19642 .56949 .19348 .56318 .18094 Mtetra
.583 .605 .84 r
.56318 .18094 .56949 .19348 .58147 .19068 .57518 .17863 Mtetra
.578 .613 .851 r
.57518 .17863 .58147 .19068 .59352 .18804 .58725 .17647 Mtetra
.572 .621 .862 r
.58725 .17647 .59352 .18804 .60564 .18557 .5994 .17448 Mtetra
.565 .629 .874 r
.5994 .17448 .60564 .18557 .61783 .1833 .61163 .17265 Mtetra
.557 .636 .885 r
.61163 .17265 .61783 .1833 .6301 .18122 .62394 .17098 Mtetra
.549 .644 .896 r
.62394 .17098 .6301 .18122 .64245 .17934 .63633 .16948 Mtetra
.541 .65 .906 r
.63633 .16948 .64245 .17934 .65489 .17764 .6488 .1681 Mtetra
.534 .656 .914 r
.6488 .1681 .65489 .17764 .66741 .1761 .66137 .16684 Mtetra
.527 .662 .922 r
.66137 .16684 .66741 .1761 .68002 .1747 .67402 .16566 Mtetra
.522 .667 .928 r
.67402 .16566 .68002 .1747 .69272 .17339 .68676 .16453 Mtetra
.518 .671 .933 r
.68676 .16453 .69272 .17339 .70551 .17213 .69958 .16342 Mtetra
.516 .676 .937 r
.69958 .16342 .70551 .17213 .71838 .17091 .7125 .16231 Mtetra
.515 .68 .94 r
.7125 .16231 .71838 .17091 .73134 .16968 .7255 .16118 Mtetra
.746 .767 .87 r
.05043 .39529 .05808 .40196 .06856 .39503 .06088 .38873 Mtetra
.75 .779 .877 r
.06088 .38873 .06856 .39503 .07906 .38806 .07136 .38214 Mtetra
.753 .791 .883 r
.07136 .38214 .07906 .38806 .08958 .38109 .08186 .37552 Mtetra
.756 .802 .89 r
.08186 .37552 .08958 .38109 .10012 .37414 .09239 .36888 Mtetra
.758 .813 .896 r
.09239 .36888 .10012 .37414 .11067 .36722 .10293 .36224 Mtetra
.759 .823 .902 r
.10293 .36224 .11067 .36722 .12123 .36038 .11349 .35563 Mtetra
.759 .831 .908 r
.11349 .35563 .12123 .36038 .1318 .35364 .12407 .34907 Mtetra
.757 .838 .913 r
.12407 .34907 .1318 .35364 .14237 .34703 .13466 .34258 Mtetra
.755 .844 .918 r
.13466 .34258 .14237 .34703 .15294 .34056 .14526 .33619 Mtetra
.751 .847 .922 r
.14526 .33619 .15294 .34056 .16353 .33425 .15588 .3299 Mtetra
.748 .849 .926 r
.15588 .3299 .16353 .33425 .17411 .32809 .1665 .32372 Mtetra
.743 .849 .929 r
.1665 .32372 .17411 .32809 .18471 .32208 .17714 .31767 Mtetra
.738 .848 .931 r
.17714 .31767 .18471 .32208 .19531 .31623 .18779 .31173 Mtetra
.734 .846 .933 r
.18779 .31173 .19531 .31623 .20593 .31051 .19845 .30592 Mtetra
.729 .844 .935 r
.19845 .30592 .20593 .31051 .21657 .30491 .20913 .30023 Mtetra
.724 .841 .937 r
.20913 .30023 .21657 .30491 .22723 .29941 .21983 .29465 Mtetra
.72 .839 .938 r
.21983 .29465 .22723 .29941 .23791 .29399 .23055 .28919 Mtetra
.715 .838 .94 r
.23055 .28919 .23791 .29399 .24861 .28866 .24129 .28383 Mtetra
.711 .837 .942 r
.24129 .28383 .24861 .28866 .25934 .28343 .25205 .27856 Mtetra
.707 .837 .944 r
.25205 .27856 .25934 .28343 .27008 .27838 .26284 .27337 Mtetra
.706 .833 .943 r
.26284 .27337 .27008 .27838 .28084 .27359 .27366 .26821 Mtetra
.707 .822 .936 r
.27366 .26821 .28084 .27359 .2916 .26931 .28453 .26298 Mtetra
.711 .793 .915 r
.28453 .26298 .2916 .26931 .30235 .26567 .29544 .25758 Mtetra
.716 .743 .873 r
.29544 .25758 .30235 .26567 .3131 .26266 .30642 .25166 Mtetra
.709 .676 .816 r
.30642 .25166 .3131 .26266 .32388 .26018 .31747 .24508 Mtetra
.691 .607 .758 r
.31747 .24508 .32388 .26018 .3347 .2577 .3286 .23777 Mtetra
.668 .55 .711 r
.3286 .23777 .3347 .2577 .34559 .25495 .33978 .23 Mtetra
.638 .5 .679 r
.33978 .23 .34559 .25495 .35657 .25175 .35095 .22276 Mtetra
.609 .464 .659 r
.35095 .22276 .35657 .25175 .36762 .24803 .36208 .21667 Mtetra
.579 .435 .649 r
.36208 .21667 .36762 .24803 .37874 .24393 .37314 .21252 Mtetra
.553 .417 .65 r
.37314 .21252 .37874 .24393 .38991 .23945 .38416 .21032 Mtetra
.537 .416 .662 r
.38416 .21032 .38991 .23945 .40116 .23445 .39518 .20928 Mtetra
.53 .431 .687 r
.39518 .20928 .40116 .23445 .41246 .229 .40626 .20878 Mtetra
.542 .474 .729 r
.40626 .20878 .41246 .229 .42381 .22326 .41742 .20783 Mtetra
.564 .541 .787 r
.41742 .20783 .42381 .22326 .43519 .21752 .42868 .20615 Mtetra
.588 .624 .855 r
.42868 .20615 .43519 .21752 .44659 .21231 .44002 .2038 Mtetra
.605 .705 .915 r
.44002 .2038 .44659 .21231 .45802 .20774 .45144 .20095 Mtetra
.605 .761 .953 r
.45144 .20095 .45802 .20774 .46949 .20381 .46292 .19791 Mtetra
.599 .79 .972 r
.46292 .19791 .46949 .20381 .48099 .20039 .47445 .19481 Mtetra
.592 .8 .979 r
.47445 .19481 .48099 .20039 .49255 .19725 .48605 .19175 Mtetra
.585 .801 .982 r
.48605 .19175 .49255 .19725 .50417 .19429 .4977 .18876 Mtetra
.579 .799 .983 r
.4977 .18876 .50417 .19429 .51585 .19142 .50942 .18587 Mtetra
.572 .796 .984 r
.50942 .18587 .51585 .19142 .52758 .18865 .52119 .18309 Mtetra
.564 .794 .985 r
.52119 .18309 .52758 .18865 .53938 .18597 .53303 .18042 Mtetra
.555 .792 .987 r
.53303 .18042 .53938 .18597 .55125 .18339 .54494 .17788 Mtetra
.545 .79 .989 r
.54494 .17788 .55125 .18339 .56318 .18094 .55691 .17546 Mtetra
.536 .787 .99 r
.55691 .17546 .56318 .18094 .57518 .17863 .56895 .17317 Mtetra
.526 .785 .992 r
.56895 .17317 .57518 .17863 .58725 .17647 .58107 .171 Mtetra
.517 .781 .992 r
.58107 .171 .58725 .17647 .5994 .17448 .59326 .16897 Mtetra
.508 .777 .993 r
.59326 .16897 .5994 .17448 .61163 .17265 .60553 .16706 Mtetra
.502 .771 .992 r
.60553 .16706 .61163 .17265 .62394 .17098 .61787 .16525 Mtetra
.498 .765 .991 r
.61787 .16525 .62394 .17098 .63633 .16948 .6303 .16355 Mtetra
.497 .759 .989 r
.6303 .16355 .63633 .16948 .6488 .1681 .64281 .16193 Mtetra
.498 .751 .986 r
.64281 .16193 .6488 .1681 .66137 .16684 .6554 .16037 Mtetra
.502 .743 .981 r
.6554 .16037 .66137 .16684 .67402 .16566 .66808 .15884 Mtetra
.508 .735 .976 r
.66808 .15884 .67402 .16566 .68676 .16453 .68084 .15731 Mtetra
.514 .725 .969 r
.68084 .15731 .68676 .16453 .69958 .16342 .69368 .15577 Mtetra
.522 .715 .96 r
.69368 .15577 .69958 .16342 .7125 .16231 .7066 .15421 Mtetra
.529 .705 .951 r
.7066 .15421 .7125 .16231 .7255 .16118 .71961 .15261 Mtetra
.721 .764 .886 r
.04273 .38856 .05043 .39529 .06088 .38873 .05306 .38295 Mtetra
.728 .794 .904 r
.05306 .38295 .06088 .38873 .07136 .38214 .06343 .37729 Mtetra
.733 .825 .922 r
.06343 .37729 .07136 .38214 .08186 .37552 .07384 .3716 Mtetra
.735 .856 .938 r
.07384 .3716 .08186 .37552 .09239 .36888 .08427 .36586 Mtetra
.734 .887 .95 r
.08427 .36586 .09239 .36888 .10293 .36224 .09474 .36009 Mtetra
.726 .915 .958 r
.09474 .36009 .10293 .36224 .11349 .35563 .10523 .35432 Mtetra
.712 .937 .96 r
.10523 .35432 .11349 .35563 .12407 .34907 .11575 .34855 Mtetra
.689 .953 .953 r
.11575 .34855 .12407 .34907 .13466 .34258 .12629 .3428 Mtetra
.656 .959 .937 r
.12629 .3428 .13466 .34258 .14526 .33619 .13686 .33711 Mtetra
.616 .954 .911 r
.13686 .33711 .14526 .33619 .15588 .3299 .14745 .33146 Mtetra
.57 .94 .875 r
.14745 .33146 .15588 .3299 .1665 .32372 .15806 .32587 Mtetra
.519 .916 .833 r
.15806 .32587 .1665 .32372 .17714 .31767 .16869 .32034 Mtetra
.467 .887 .787 r
.16869 .32034 .17714 .31767 .18779 .31173 .17934 .31489 Mtetra
.417 .854 .741 r
.17934 .31489 .18779 .31173 .19845 .30592 .19002 .3095 Mtetra
.37 .819 .695 r
.19002 .3095 .19845 .30592 .20913 .30023 .20073 .30417 Mtetra
.326 .785 .653 r
.20073 .30417 .20913 .30023 .21983 .29465 .21145 .29892 Mtetra
0 0 0 r
.21145 .29892 .21983 .29465 .23055 .28919 .22221 .29375 Mtetra
.22221 .29375 .23055 .28919 .24129 .28383 .23299 .28866 Mtetra
.23299 .28866 .24129 .28383 .25205 .27856 .24379 .28365 Mtetra
.24379 .28365 .25205 .27856 .26284 .27337 .25464 .27865 Mtetra
.25464 .27865 .26284 .27337 .27366 .26821 .26552 .2736 Mtetra
.26552 .2736 .27366 .26821 .28453 .26298 .27646 .26824 Mtetra
.27646 .26824 .28453 .26298 .29544 .25758 .28748 .26235 Mtetra
.382 .803 .614 r
.28748 .26235 .29544 .25758 .30642 .25166 .2986 .2555 Mtetra
.549 .911 .723 r
.2986 .2555 .30642 .25166 .31747 .24508 .30982 .24755 Mtetra
.703 .983 .818 r
.30982 .24755 .31747 .24508 .3286 .23777 .32113 .23861 Mtetra
.79 .994 .872 r
.32113 .23861 .3286 .23777 .33978 .23 .33248 .22917 Mtetra
.794 .972 .911 r
.33248 .22917 .33978 .23 .35095 .22276 .34378 .22059 Mtetra
.746 .94 .948 r
.34378 .22059 .35095 .22276 .36208 .21667 .355 .21373 Mtetra
.619 .892 .988 r
.355 .21373 .36208 .21667 .37314 .21252 .36611 .20955 Mtetra
.399 .799 .985 r
.36611 .20955 .37314 .21252 .38416 .21032 .37713 .20807 Mtetra
.156 .671 .894 r
.37713 .20807 .38416 .21032 .39518 .20928 .38814 .20831 Mtetra
0 .531 .729 r
.38814 .20831 .39518 .20928 .40626 .20878 .39919 .20944 Mtetra
.118 0 0 r
.39919 .20944 .40626 .20878 .41742 .20783 .41035 .21007 Mtetra
.124 0 0 r
.41035 .21007 .41742 .20783 .42868 .20615 .42162 .20973 Mtetra
.103 0 0 r
.42162 .20973 .42868 .20615 .44002 .2038 .433 .20828 Mtetra
.071 0 0 r
.433 .20828 .44002 .2038 .45144 .20095 .44448 .20587 Mtetra
.053 0 0 r
.44448 .20587 .45144 .20095 .46292 .19791 .45603 .20292 Mtetra
.035 0 0 r
.45603 .20292 .46292 .19791 .47445 .19481 .46765 .19967 Mtetra
.023 0 0 r
.46765 .19967 .47445 .19481 .48605 .19175 .47933 .19636 Mtetra
.012 0 0 r
.47933 .19636 .48605 .19175 .4977 .18876 .49107 .19307 Mtetra
.002 0 0 r
.49107 .19307 .4977 .18876 .50942 .18587 .50286 .18985 Mtetra
0 0 0 r
.50286 .18985 .50942 .18587 .52119 .18309 .51471 .18672 Mtetra
.51471 .18672 .52119 .18309 .53303 .18042 .52663 .18368 Mtetra
.52663 .18368 .53303 .18042 .54494 .17788 .53861 .18071 Mtetra
.53861 .18071 .54494 .17788 .55691 .17546 .55065 .17781 Mtetra
.55065 .17781 .55691 .17546 .56895 .17317 .56276 .17498 Mtetra
.56276 .17498 .56895 .17317 .58107 .171 .57494 .17222 Mtetra
.163 .697 .704 r
.57494 .17222 .58107 .171 .59326 .16897 .58718 .16953 Mtetra
.208 .733 .765 r
.58718 .16953 .59326 .16897 .60553 .16706 .5995 .1669 Mtetra
.259 .769 .827 r
.5995 .1669 .60553 .16706 .61787 .16525 .61189 .16433 Mtetra
.313 .799 .885 r
.61189 .16433 .61787 .16525 .6303 .16355 .62435 .1618 Mtetra
.368 .821 .935 r
.62435 .1618 .6303 .16355 .64281 .16193 .63689 .15931 Mtetra
.42 .832 .972 r
.63689 .15931 .64281 .16193 .6554 .16037 .6495 .15682 Mtetra
.466 .83 .994 r
.6495 .15682 .6554 .16037 .66808 .15884 .66219 .15432 Mtetra
.505 .819 1 r
.66219 .15432 .66808 .15884 .68084 .15731 .67495 .1518 Mtetra
.534 .798 .994 r
.67495 .1518 .68084 .15731 .69368 .15577 .68778 .14923 Mtetra
.555 .772 .979 r
.68778 .14923 .69368 .15577 .7066 .15421 .70069 .14662 Mtetra
.57 .745 .959 r
.70069 .14662 .7066 .15421 .71961 .15261 .71368 .14397 Mtetra
.68 .757 .909 r
.03496 .38178 .04273 .38856 .05306 .38295 .04513 .37744 Mtetra
.684 .798 .935 r
.04513 .37744 .05306 .38295 .06343 .37729 .05534 .37305 Mtetra
.683 .841 .959 r
.05534 .37305 .06343 .37729 .07384 .3716 .0656 .36861 Mtetra
.673 .882 .976 r
.0656 .36861 .07384 .3716 .08427 .36586 .0759 .36411 Mtetra
.651 .915 .979 r
.0759 .36411 .08427 .36586 .09474 .36009 .08623 .35955 Mtetra
.61 .933 .961 r
.08623 .35955 .09474 .36009 .10523 .35432 .09661 .35495 Mtetra
.548 .926 .916 r
.09661 .35495 .10523 .35432 .11575 .34855 .10703 .35033 Mtetra
.468 .892 .843 r
.10703 .35033 .11575 .34855 .12629 .3428 .11748 .34569 Mtetra
.377 .834 .749 r
.11748 .34569 .12629 .3428 .13686 .33711 .12797 .34105 Mtetra
0 0 0 r
.12797 .34105 .13686 .33711 .14745 .33146 .1385 .3364 Mtetra
.1385 .3364 .14745 .33146 .15806 .32587 .14906 .33175 Mtetra
.14906 .33175 .15806 .32587 .16869 .32034 .15965 .32711 Mtetra
.15965 .32711 .16869 .32034 .17934 .31489 .17029 .32247 Mtetra
.17029 .32247 .17934 .31489 .19002 .3095 .18096 .31783 Mtetra
.033 0 0 r
.18096 .31783 .19002 .3095 .20073 .30417 .19166 .31319 Mtetra
.069 0 0 r
.19166 .31319 .20073 .30417 .21145 .29892 .20241 .30855 Mtetra
.099 0 0 r
.20241 .30855 .21145 .29892 .22221 .29375 .21318 .30394 Mtetra
.125 0 0 r
.21318 .30394 .22221 .29375 .23299 .28866 .224 .29937 Mtetra
.147 0 0 r
.224 .29937 .23299 .28866 .24379 .28365 .23485 .29483 Mtetra
.162 0 0 r
.23485 .29483 .24379 .28365 .25464 .27865 .24574 .29028 Mtetra
.171 0 0 r
.24574 .29028 .25464 .27865 .26552 .2736 .25668 .28562 Mtetra
.162 0 0 r
.25668 .28562 .26552 .2736 .27646 .26824 .26769 .28059 Mtetra
.139 0 0 r
.26769 .28059 .27646 .26824 .28748 .26235 .27878 .27495 Mtetra
.09 0 0 r
.27878 .27495 .28748 .26235 .2986 .2555 .28999 .2683 Mtetra
.033 0 0 r
.28999 .2683 .2986 .2555 .30982 .24755 .3013 .26053 Mtetra
0 0 0 r
.3013 .26053 .30982 .24755 .32113 .23861 .3127 .25183 Mtetra
.3127 .25183 .32113 .23861 .33248 .22917 .32414 .24268 Mtetra
.038 0 0 r
.32414 .24268 .33248 .22917 .34378 .22059 .33554 .23437 Mtetra
.137 0 0 r
.33554 .23437 .34378 .22059 .355 .21373 .34687 .22767 Mtetra
.261 0 .057 r
.34687 .22767 .355 .21373 .36611 .20955 .35808 .22348 Mtetra
.36 0 .108 r
.35808 .22348 .36611 .20955 .37713 .20807 .36921 .22179 Mtetra
.415 0 .131 r
.36921 .22179 .37713 .20807 .38814 .20831 .38033 .22174 Mtetra
.439 .016 .137 r
.38033 .22174 .38814 .20831 .39919 .20944 .39149 .22254 Mtetra
.423 0 .121 r
.39149 .22254 .39919 .20944 .41035 .21007 .40275 .22291 Mtetra
.389 0 .098 r
.40275 .22291 .41035 .21007 .42162 .20973 .41412 .22234 Mtetra
.345 0 .07 r
.41412 .22234 .42162 .20973 .433 .20828 .42562 .22065 Mtetra
.302 0 .043 r
.42562 .22065 .433 .20828 .44448 .20587 .4372 .21795 Mtetra
.272 0 .021 r
.4372 .21795 .44448 .20587 .45603 .20292 .44887 .21464 Mtetra
.248 0 0 r
.44887 .21464 .45603 .20292 .46765 .19967 .4606 .21095 Mtetra
.235 0 0 r
.4606 .21095 .46765 .19967 .47933 .19636 .47239 .20716 Mtetra
.224 0 0 r
.47239 .20716 .47933 .19636 .49107 .19307 .48424 .20334 Mtetra
.213 0 0 r
.48424 .20334 .49107 .19307 .50286 .18985 .49614 .19957 Mtetra
.201 0 0 r
.49614 .19957 .50286 .18985 .51471 .18672 .5081 .19583 Mtetra
.186 0 0 r
.5081 .19583 .51471 .18672 .52663 .18368 .52011 .19211 Mtetra
.166 0 0 r
.52011 .19211 .52663 .18368 .53861 .18071 .53219 .18841 Mtetra
.141 0 0 r
.53219 .18841 .53861 .18071 .55065 .17781 .54432 .1847 Mtetra
.109 0 0 r
.54432 .1847 .55065 .17781 .56276 .17498 .55652 .18099 Mtetra
.07 0 0 r
.55652 .18099 .56276 .17498 .57494 .17222 .56877 .17727 Mtetra
.021 0 0 r
.56877 .17727 .57494 .17222 .58718 .16953 .58108 .17356 Mtetra
0 0 0 r
.58108 .17356 .58718 .16953 .5995 .1669 .59346 .16985 Mtetra
.59346 .16985 .5995 .1669 .61189 .16433 .6059 .16614 Mtetra
.6059 .16614 .61189 .16433 .62435 .1618 .6184 .16242 Mtetra
.294 .791 .787 r
.6184 .16242 .62435 .1618 .63689 .15931 .63097 .15868 Mtetra
.39 .848 .884 r
.63097 .15868 .63689 .15931 .6495 .15682 .6436 .15492 Mtetra
.475 .878 .954 r
.6436 .15492 .6495 .15682 .66219 .15432 .65629 .15111 Mtetra
.542 .879 .989 r
.65629 .15111 .66219 .15432 .67495 .1518 .66905 .14723 Mtetra
.587 .857 .995 r
.66905 .14723 .67495 .1518 .68778 .14923 .68187 .1433 Mtetra
.613 .822 .98 r
.68187 .1433 .68778 .14923 .70069 .14662 .69475 .13931 Mtetra
.627 .782 .955 r
.69475 .13931 .70069 .14662 .71368 .14397 .70769 .13525 Mtetra
.621 .742 .933 r
.02714 .37496 .03496 .38178 .04513 .37744 .03712 .37202 Mtetra
.617 .788 .964 r
.03712 .37202 .04513 .37744 .05534 .37305 .04714 .36902 Mtetra
.602 .833 .988 r
.04714 .36902 .05534 .37305 .0656 .36861 .05723 .36595 Mtetra
.572 .87 .995 r
.05723 .36595 .0656 .36861 .0759 .36411 .06736 .36282 Mtetra
.52 .887 .975 r
.06736 .36282 .0759 .36411 .08623 .35955 .07755 .35961 Mtetra
.443 .873 .916 r
.07755 .35961 .08623 .35955 .09661 .35495 .08779 .35633 Mtetra
.346 .824 .82 r
.08779 .35633 .09661 .35495 .10703 .35033 .09808 .353 Mtetra
.242 .747 .699 r
.09808 .353 .10703 .35033 .11748 .34569 .10842 .34962 Mtetra
0 0 0 r
.10842 .34962 .11748 .34569 .12797 .34105 .11881 .34619 Mtetra
.11881 .34619 .12797 .34105 .1385 .3364 .12925 .3427 Mtetra
.013 0 0 r
.12925 .3427 .1385 .3364 .14906 .33175 .13974 .33917 Mtetra
.069 0 0 r
.13974 .33917 .14906 .33175 .15965 .32711 .15028 .33559 Mtetra
.113 0 0 r
.15028 .33559 .15965 .32711 .17029 .32247 .16087 .33195 Mtetra
.148 0 0 r
.16087 .33195 .17029 .32247 .18096 .31783 .17151 .32825 Mtetra
.176 0 0 r
.17151 .32825 .18096 .31783 .19166 .31319 .1822 .32448 Mtetra
.199 0 0 r
.1822 .32448 .19166 .31319 .20241 .30855 .19295 .32066 Mtetra
.219 0 0 r
.19295 .32066 .20241 .30855 .21318 .30394 .20374 .31681 Mtetra
.236 0 .008 r
.20374 .31681 .21318 .30394 .224 .29937 .21457 .31293 Mtetra
.25 0 .031 r
.21457 .31293 .224 .29937 .23485 .29483 .22546 .30903 Mtetra
.26 0 .05 r
.22546 .30903 .23485 .29483 .24574 .29028 .23639 .30508 Mtetra
.267 0 .066 r
.23639 .30508 .24574 .29028 .25668 .28562 .24738 .30101 Mtetra
.265 0 .075 r
.24738 .30101 .25668 .28562 .26769 .28059 .25843 .29665 Mtetra
.257 0 .083 r
.25843 .29665 .26769 .28059 .27878 .27495 .26957 .29183 Mtetra
.243 0 .089 r
.26957 .29183 .27878 .27495 .28999 .2683 .28081 .28631 Mtetra
.232 0 .101 r
.28081 .28631 .28999 .2683 .3013 .26053 .29214 .28001 Mtetra
.233 0 .122 r
.29214 .28001 .3013 .26053 .3127 .25183 .30354 .27307 Mtetra
.249 0 .151 r
.30354 .27307 .3127 .25183 .32414 .24268 .31499 .26583 Mtetra
.288 0 .189 r
.31499 .26583 .32414 .24268 .33554 .23437 .32644 .25909 Mtetra
.33 0 .221 r
.32644 .25909 .33554 .23437 .34687 .22767 .33785 .25334 Mtetra
.373 .028 .246 r
.33785 .25334 .34687 .22767 .35808 .22348 .34921 .24914 Mtetra
.406 .059 .26 r
.34921 .24914 .35808 .22348 .36921 .22179 .36054 .24649 Mtetra
.423 .07 .259 r
.36054 .24649 .36921 .22179 .38033 .22174 .37187 .24485 Mtetra
.428 .067 .248 r
.37187 .24485 .38033 .22174 .39149 .22254 .38325 .24371 Mtetra
.414 .044 .224 r
.38325 .24371 .39149 .22254 .40275 .22291 .39472 .24227 Mtetra
.389 .01 .194 r
.39472 .24227 .40275 .22291 .41412 .22234 .40628 .2402 Mtetra
.357 0 .161 r
.40628 .2402 .41412 .22234 .42562 .22065 .41793 .23735 Mtetra
.324 0 .129 r
.41793 .23735 .42562 .22065 .4372 .21795 .42966 .2338 Mtetra
.299 0 .104 r
.42966 .2338 .4372 .21795 .44887 .21464 .44147 .22978 Mtetra
.279 0 .083 r
.44147 .22978 .44887 .21464 .4606 .21095 .45334 .22545 Mtetra
.266 0 .065 r
.45334 .22545 .4606 .21095 .47239 .20716 .46526 .22102 Mtetra
.253 0 .047 r
.46526 .22102 .47239 .20716 .48424 .20334 .47723 .21652 Mtetra
.241 0 .027 r
.47723 .21652 .48424 .20334 .49614 .19957 .48926 .212 Mtetra
.226 0 .003 r
.48926 .212 .49614 .19957 .5081 .19583 .50134 .20746 Mtetra
.206 0 0 r
.50134 .20746 .5081 .19583 .52011 .19211 .51347 .20287 Mtetra
.183 0 0 r
.51347 .20287 .52011 .19211 .53219 .18841 .52565 .19823 Mtetra
.153 0 0 r
.52565 .19823 .53219 .18841 .54432 .1847 .53789 .19351 Mtetra
.117 0 0 r
.53789 .19351 .54432 .1847 .55652 .18099 .55017 .18873 Mtetra
.073 0 0 r
.55017 .18873 .55652 .18099 .56877 .17727 .56252 .18389 Mtetra
.018 0 0 r
.56252 .18389 .56877 .17727 .58108 .17356 .57491 .17899 Mtetra
0 0 0 r
.57491 .17899 .58108 .17356 .59346 .16985 .58735 .17404 Mtetra
.58735 .17404 .59346 .16985 .6059 .16614 .59985 .16902 Mtetra
.59985 .16902 .6059 .16614 .6184 .16242 .6124 .16395 Mtetra
.34 .811 .739 r
.6124 .16395 .6184 .16242 .63097 .15868 .625 .15882 Mtetra
.449 .882 .851 r
.625 .15882 .63097 .15868 .6436 .15492 .63765 .15362 Mtetra
.543 .92 .932 r
.63765 .15362 .6436 .15492 .65629 .15111 .65035 .14835 Mtetra
.613 .922 .974 r
.65035 .14835 .65629 .15111 .66905 .14723 .6631 .143 Mtetra
.655 .896 .982 r
.6631 .143 .66905 .14723 .68187 .1433 .6759 .13756 Mtetra
.677 .855 .967 r
.6759 .13756 .68187 .1433 .69475 .13931 .68875 .13205 Mtetra
.685 .809 .941 r
.68875 .13205 .69475 .13931 .70769 .13525 .70165 .12647 Mtetra
.546 .718 .953 r
.01926 .36808 .02714 .37496 .03712 .37202 .02904 .36649 Mtetra
.53 .76 .981 r
.02904 .36649 .03712 .37202 .04714 .36902 .03889 .36481 Mtetra
.503 .797 .998 r
.03889 .36481 .04714 .36902 .05723 .36595 .0488 .36306 Mtetra
.459 .822 .995 r
.0488 .36306 .05723 .36595 .06736 .36282 .05877 .36121 Mtetra
.395 .825 .96 r
.05877 .36121 .06736 .36282 .07755 .35961 .06881 .35928 Mtetra
.312 .798 .889 r
.06881 .35928 .07755 .35961 .08779 .35633 .07891 .35727 Mtetra
.219 .742 .785 r
.07891 .35727 .08779 .35633 .09808 .353 .08907 .35517 Mtetra
0 0 0 r
.08907 .35517 .09808 .353 .10842 .34962 .0993 .35299 Mtetra
.0993 .35299 .10842 .34962 .11881 .34619 .10959 .35072 Mtetra
.024 0 0 r
.10959 .35072 .11881 .34619 .12925 .3427 .11995 .34836 Mtetra
.081 0 0 r
.11995 .34836 .12925 .3427 .13974 .33917 .13036 .34591 Mtetra
.126 0 0 r
.13036 .34591 .13974 .33917 .15028 .33559 .14084 .34337 Mtetra
.162 0 0 r
.14084 .34337 .15028 .33559 .16087 .33195 .15138 .34075 Mtetra
.191 0 0 r
.15138 .34075 .16087 .33195 .17151 .32825 .16198 .33803 Mtetra
.216 0 0 r
.16198 .33803 .17151 .32825 .1822 .32448 .17264 .33523 Mtetra
.236 0 0 r
.17264 .33523 .1822 .32448 .19295 .32066 .18337 .33234 Mtetra
.252 0 0 r
.18337 .33234 .19295 .32066 .20374 .31681 .19415 .32935 Mtetra
.266 0 .013 r
.19415 .32935 .20374 .31681 .21457 .31293 .205 .32628 Mtetra
.276 0 .036 r
.205 .32628 .21457 .31293 .22546 .30903 .2159 .32311 Mtetra
.285 0 .056 r
.2159 .32311 .22546 .30903 .23639 .30508 .22687 .31985 Mtetra
.292 0 .073 r
.22687 .31985 .23639 .30508 .24738 .30101 .23789 .3165 Mtetra
.299 0 .089 r
.23789 .3165 .24738 .30101 .25843 .29665 .24897 .31305 Mtetra
.308 0 .109 r
.24897 .31305 .25843 .29665 .26957 .29183 .26011 .30951 Mtetra
.32 0 .134 r
.26011 .30951 .26957 .29183 .28081 .28631 .27131 .30588 Mtetra
.336 0 .167 r
.27131 .30588 .28081 .28631 .29214 .28001 .28256 .30215 Mtetra
.354 0 .203 r
.28256 .30215 .29214 .28001 .30354 .27307 .29388 .29833 Mtetra
.372 .022 .237 r
.29388 .29833 .30354 .27307 .31499 .26583 .30525 .29442 Mtetra
.386 .048 .265 r
.30525 .29442 .31499 .26583 .32644 .25909 .31667 .29041 Mtetra
.395 .065 .284 r
.31667 .29041 .32644 .25909 .33785 .25334 .32815 .2863 Mtetra
.399 .074 .294 r
.32815 .2863 .33785 .25334 .34921 .24914 .33969 .2821 Mtetra
.398 .073 .293 r
.33969 .2821 .34921 .24914 .36054 .24649 .35128 .2778 Mtetra
.391 .062 .283 r
.35128 .2778 .36054 .24649 .37187 .24485 .36293 .27341 Mtetra
.378 .041 .262 r
.36293 .27341 .37187 .24485 .38325 .24371 .37462 .26892 Mtetra
.359 .011 .232 r
.37462 .26892 .38325 .24371 .39472 .24227 .38638 .26433 Mtetra
.336 0 .194 r
.38638 .26433 .39472 .24227 .40628 .2402 .39818 .25965 Mtetra
.31 0 .155 r
.39818 .25965 .40628 .2402 .41793 .23735 .41004 .25486 Mtetra
.286 0 .118 r
.41004 .25486 .41793 .23735 .42966 .2338 .42194 .24998 Mtetra
.265 0 .088 r
.42194 .24998 .42966 .2338 .44147 .22978 .4339 .24501 Mtetra
.247 0 .064 r
.4339 .24501 .44147 .22978 .45334 .22545 .44591 .23993 Mtetra
.231 0 .043 r
.44591 .23993 .45334 .22545 .46526 .22102 .45797 .23476 Mtetra
.214 0 .02 r
.45797 .23476 .46526 .22102 .47723 .21652 .47008 .22948 Mtetra
.195 0 0 r
.47008 .22948 .47723 .21652 .48926 .212 .48223 .22411 Mtetra
.171 0 0 r
.48223 .22411 .48926 .212 .50134 .20746 .49443 .21864 Mtetra
.142 0 0 r
.49443 .21864 .50134 .20746 .51347 .20287 .50668 .21307 Mtetra
.108 0 0 r
.50668 .21307 .51347 .20287 .52565 .19823 .51898 .2074 Mtetra
.067 0 0 r
.51898 .2074 .52565 .19823 .53789 .19351 .53132 .20164 Mtetra
.018 0 0 r
.53132 .20164 .53789 .19351 .55017 .18873 .54371 .19577 Mtetra
0 0 0 r
.54371 .19577 .55017 .18873 .56252 .18389 .55614 .1898 Mtetra
.55614 .1898 .56252 .18389 .57491 .17899 .56861 .18374 Mtetra
.56861 .18374 .57491 .17899 .58735 .17404 .58113 .17757 Mtetra
.58113 .17757 .58735 .17404 .59985 .16902 .59369 .17131 Mtetra
.383 .828 .704 r
.59369 .17131 .59985 .16902 .6124 .16395 .60628 .16494 Mtetra
.485 .897 .806 r
.60628 .16494 .6124 .16395 .625 .15882 .61892 .15848 Mtetra
.576 .941 .888 r
.61892 .15848 .625 .15882 .63765 .15362 .6316 .15192 Mtetra
.646 .955 .94 r
.6316 .15192 .63765 .15362 .65035 .14835 .64432 .14525 Mtetra
.693 .941 .962 r
.64432 .14525 .65035 .14835 .6631 .143 .65708 .13849 Mtetra
.72 .909 .961 r
.65708 .13849 .6631 .143 .6759 .13756 .66987 .13163 Mtetra
.731 .867 .945 r
.66987 .13163 .6759 .13756 .68875 .13205 .6827 .12467 Mtetra
.732 .823 .921 r
.6827 .12467 .68875 .13205 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Sooooo`03ok_Bjol0003ooooo01Gooooo00?o
0000ooooooooool0DOooool0063ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`0Mooooo`?o00000_ooool00ol0003oooooooooo`1Oooooo`?o^m;[00?o
0000ok_Bjoooool05Oooool00ol0003oooooooooo`1@ooooo`00H?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol0000Looooo`;o0000IOooool2ok_Ml@?o^m;[00?o0000ojo?l?ooool05?oo
ool00ol0003oooooo`00001Aooooo`00H?ooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00006_ooool3o`0006Gooooo1OnkgO400onkd^_o[lo`o`000002ojo?l1Kooooo
00?o0000ooooooooool0Coooool0063ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgM
gOmEEEGoooooo`0001Sooooo0_l0001Vooooo`;o^>Sf1?nkgO42ojgJm`03ojo?l?l0003o[lo`00;o
[lo`5_ooool00ol0003oooooooooo`1>ooooo`00H?ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l000005Oooool3o`0000;ooooo00?o0000ooooooooool0HOooool5okSXmP03
ok_MlOn]f_Oo[M[g00?o[M[g00Co0000ojo?l?nPb?CoX<Sd5_ooool00ol0003oooooooooo`1>oooo
o`00H?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000004oooool2o`00
06Oooooo0_nal?H4okSXmP;oYnGk1?n]f_L00onLd_[o0000oj38m003oj38m1Kooooo00?o0000oooo
ooooool0COooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo
00oooooo0ol0001Wooooo`Go/O3f00?o^>SfojOUnonWiO/00onWiO/01On]f_OoW=;joicBn_nLd_[o
000000GoX<Sd5_ooool00ol0003oooooooooo`1<ooooo`00P_ooool2o`0006Sooooo0onUm?02ok7`
mP?oW>ci0onWiO/2oiKKoPCoW=;j00Co0000oj38m?nPb?CoX<Sd0_nA__DFooooo`03o`000?oooooo
oooo04cooooo001oooooo`?o00000_ooool00ol0003oooooooooo`1Sooooo`CoYOC`0_n;jnh2oic/
n@CoR^7m1?nFfoh2oicBnP03ohk5n_l0003oS/Gj00GoTKke5?ooool3o`0004gooooo001looooo`?o
0000JOooool2oi?`h`04ojGdl?n;jnkoRn_^oh_[kPCoNN3d0_n:hOd3oh7Ao`CoR<cn0_n>aOX00ol0
003oS/Gjohk5nP04oi6nmAOooooo00?o0000ooooooooool0B_ooool007[ooooo0_l0001[ooooo`;o
To3S0_mbhMT3of?IhP;oNN3d0omge?h5oh7Ao`CoR<cn0_n>aOX00ol0003oQKOeohNdl`04ohNdlaKo
oooo00?o0000ooooooooool0B_ooool007Oooooo0ol0001/ooooo`03oi?`hombhMWoL^7I00?oHmWR
1?m[e?P4ogODoP;oPM7o0on2_?T4oh>in004ohFgmOl0003oQKOeohFgm@GoQkCc5_ooool00ol0003o
ooooooooo`19ooooo`00MOooool2o`0000;ooooo00?o0000ooooooooool0J?ooool2oeO?_@;oBl[9
1?mNd^l2of_Dn0?oOl3l1?n0__/5oh:ln@CoPkWh00Co0000ohFgmOn5]oGoQKOe0_n7]?<2oh>^l1Oo
oooo00?o0000ooooooooool0B?ooool007;ooooo0ol00005ooooo`03o`000?oooooooooo06?ooooo
00Co0000of;C]?m2a=?o@/CC0_m@c>83ogo3o@CoOl;m1Omo`?`4oh2nn`;oP[ci0_n5Z^d4ohB[kP03
o`000?n4[NooQ:g_00;oQ:g_1?n3[_0Fooooo`03o`000?oooooooooo04Sooooo001`ooooo`;o0000
J_ooool3o`000003of;C]?n2a_koP<Gm00?oP<Gm1Omo`od4ogo2o@;oOl3l0_n8YnT4ohJYk0GoQJ[]
0on4Znh00ol0003oQ:g_ohB]k`03ohB]k`CoPjk`5_ooool00ol0003oooooooooo`17ooooo`00>?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00008?ooool3o`0006Wooooo
00?o1@00o`000?l000000_l00004oh;6oPCoP<Gm0_mo`od2ohbTi@CoRZKW1On8YnT4ohJYk0GoQJ[]
0_n4Znh01?l0003oQ:_^ohB]kon4[Nl2ohRUi`CoQj[/5Oooool3o`0004Sooooo000hooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Noooo
o`;o00000oooool00ol0003oooooooooo`1Pooooo`;o00000_lA00000ol5003o1000o`000002o`00
00;oQ<Om0_n2a_h2oi2Qg`CoSZ;R1On<Y>D4ohZVi`GoR:OY1?n6ZN`2ohFZk@;oS9cM0_n:X><00ol0
003oRZ3SohRUi`04ohRUi`CoQj[/5_ooool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`0Yooooo`00>?ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h07?ooool3o`0006Cooooo0_l00002
oa/000?o4@000_l40002o`0000CoTYkL1On@XMl4ohjRhPGoS:CU1?n:Y^L2ohRWj@;oSY?D1?n=UmT5
ohbLg@04ohZPhol0003oRZ3SohZPh`GoR:GW1?n7Z^`Fooooo`03o`000?oooooooooo00Gooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Zooooo`00>?oo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h06?ooool3o`0006?ooooo
0_l00002ob@000?o6`0000Co4@00oa800?lB003o10000_l00003oi>Lf@CoTYkL1On@XMl4ohjRhP;o
S:CU0_nAS</4oi2@c`GoSY?D1?n=UmT4ohbLg@03ohZPhol0003oRZ3S00;oRZ3S0_n8YNL2oi6ThPGo
T:cY5_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`00
02_ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Eoooo
o`?o0000G_ooool5o`0000;o:P000olT00000olK003o7@00oad00003oa8000;o00000_nEV]L3oi>L
f@GoTYkL0_n@XMl2oi>6``CoTXW71OnAS</4oi2@c`CoSY?D1On=UmT4ohbLg@04o`000?n:X>?oTYkK
oi:Nf`GoTJCR1On@[>TEooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0002cooooo000hooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`0Aooooo`?o00000oooool00ol0003oooooooooo`1Gooooo`Go0000
0_l_0003obX00003ob@00?lW003o9`0000?o7@0000Co4P00o`000?l0003oUYSD1?nEV]L4oi>Lf@;o
TYkL0_nCQ;l5oi>6``CoTXW71?nAS</4oi2@c`GoSY?D0_n=UmT2oiBBc`CoTiSE00?o0000oi:NfonB
W]/00_nBW]/5oi6ThP;oT:cY0_nL/>HFooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002cooooo000hooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@017ooooo0_l0001Looooo`;o0`001?l0
00001Olc003o;`00obl00?l_003o:P0000;o;P001?lW00000olM003o1000o`000004oiJHe0GoUI[G
0_nCW=T00onDPKcoThBooi>4_`03oi>4_`CoThK31?nBRLL4oi6<b`GoT93?0_n>Tm@2oiF>b@GoU9;?
0onCV=D00ol0003oTYkKoi:Nf`03oi:Nf`;oTJCR0_nLYmd5oib`iQKooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;?ooool003Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03_ooool3o`00
05_ooooo00Go1@00o`<00?l3003o0`00o`000002ocH000;o<`0000?o;`00oc@00?ld00001?l^0003
obL000;o10000_nGUm45oiJHe0;oUI[G0_nDOkT4oiB1_0CoThBo1?nCQ/<4oi:9a`GoTHc;0_n@T<l2
oiJ9a0GoUHk91?nDT/l3oi>He@04o`000?nCV=GoTYkKoi:Nf`;oW9oF1OnLYmd5oib`iQCooooo0_l0
0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000/ooooo`00FOoo
ool3o`0005Wooooo0_l80002o`D00003o`<00?li003o>@0000Co=P0000?o>@00oc@00?ld00000_ld
0003obh00004obL00?lA003o4@00o`@000GoUiOA0_nFV=@2oiAm]`GoU7ni0onDPK`4oi>4_`GoThK3
1?nBRLL2oi6<b`;oUXK01OnFRL@4oiF>b@CoU9;?0onCV=D00ol0003oW9S?oibOeP04oibOePCoW:OM
1?nL/>H00onX]^?oooooooooo`0Aooooo`04o`000?ooooooooooo`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02_ooooo001Fooooo`?o00000oooool00ol0003o
ooooooooo`1Booooo`;o3@000ol800000ol5003o?000ocT00003ocT000?o=P000_li0003oc@000;o
;P0000Co6`00oa400?lA003o4@000onGULl2oiNGd@;oU7^d1OnDOKL4oiAo^@CoU86l1?nCQ;l4oi>6
``;oTXW70_nFPk`5oiJ6`0CoUXW41?nES/T5oiBBc`03oi>HeOnLV<oo000000;oW9S?1?nLWmH5oibW
g@03oib`i_nX]^?oZ;KS00;oZ;KS5_ooool00ol0003oooooooooo`10ooooo`00E?ooool2o`0005So
oooo00Go4P00o`d00?l=003o3@00o`P00002ocl000?o?0000oli00000olf003o?@06ocd01P02ocT0
00Co=0000olK00000olA003oV9?=oiRCc@02oiNEc`03oiAi/_nDNkCoU7^d00?oU7^d1?nDOKL4oiAo
^@CoU86l1?nCQ;l2oi>6``;oUX2i1OnFPk`4oiJ6`0CoUXW41OnES/T2oiBBc`;oW9;90_nLV<l00ol0
003oW9S?oibHc`05oibOeP;oW:OM0_nW[]`5ojRfhaKooooo00?o0000ooooooooool0@?ooool0057o
oooo0ol0001Fooooo`05oaX00?lB003o4P00oa800?l=00000_m500D3ocl000?o?00000?o>@00od00
3?m000`01?lm00H2ocT00003oc@00?lT003o900000?o6`000_nHTld2oiAg/0?oU7Vb1OnDNk@4oiAm
]`GoU7ni1?nDPK`2oi>4_`03oiMm]_nFP;WoUX2i00?oUX2i1?nFPk`4oiJ6`0GoUXW40_nES/T2oib=
a0GoW9;900?oW9S?o`000?nLV<l00_nLV<l2oibOeP;oYZKE1OnW[]`3ojRfh`;o/[kR5_ooool00ol0
003oooooooooo`0oooooo`00C_ooool5o`0004?ooooo0_mL01/3ofX08@?oL0@S1Oooool01OlN003o
7`00oal00?lO003o6P0000;oF00A0om=00/4odD01@;o?`0000?o?000od@04?m401001?m000`3ocd0
1P03ocT00?l[003o900000?o900000?o6`00oi=f[onCMZl01?nDMk04oiAi/PCoU7^d1OnDOKL4oiAo
^@;oU86l0_nFNk<4oiMm]PCoUX2i1?nFPk`5oiJ6`0;oUXW40_nLRKl5oib=a0CoW9;900GoW9S?o`00
0?nLV<ooW9S?ojJOc`05ojJVe@CoYjkL00?oZ;KSok:nh_nb_^800onb_^8Fooooo`03o`000?oooooo
oooo03kooooo001<ooooo`;o00001Oooool00ol0003oooooooooo`0mooooo`03od803_mL01_oG00K
00;oG00K0omZ0244og048`?oK00N1?mS01T4oeP04@?oC@0;0om500D00olo003oA`0Eod@04003od@0
40?o@00<0olm00H3ob/000?o90001?nCMZl5oiAg/0?oU7Vb1OnDNk@4oiAm]`;oU7ni0_nFNK04oiIk
/`CoUgff1?nFP;T5oiJ3_0?oUXK000?oVhFkoib9_onLRKl00onLRKl4oib=a0GoW9;900?o0000ojJO
conVWll00_nVWll5ojJVe@;oYjkL0_nb]md4ok:nhP03ok[4h_oooooooooo01Cooooo00?o0000oooo
ooooool0?_ooool004Wooooo0ol00014ooooo`04ob<00?m200ko@P0>od803P?oG00K0omZ0245og04
8`?oK00N1?mS01T3oeP04@?oC@0;00?oA@05od`06_m<01X00om701D3od@040Co@00<00?o?@06oc40
0?l[00000_l[0002ob@000;oTgB]1OnCMZl4oiAg/0?oU7Vb1OnDNk@2oiAm]`;oUWN^1?nFNK05oiIk
/`?oUgff1OnFP;T4oiJ3_003oiJ6`?nKQK_oVhFk00;oVhFk1?nLRKl4oib=a0CoW9;900?oYI[:ojJO
col000000onVWll4ojJVe@03ok6bfOnb]mgo/[OM00?o/[OM00?o/[kRok[4h_nja>800_nja>8Doooo
o`?o0000?oooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Pooooo`;o0000AOooool3ob<0
00;o@P0>0omL01/4ofX08@CoL0@S0om/01h4of<06@?oF00A00?oC@0;oe808OmB02401?m<01X2odL0
5@CoA00@00?o@00<ocH01Olf00D00ola0003ob/000GoTgB]1?nCMZl4oiAg/0CoU7Vb0onDNk@00onF
MZgoUWN^oiIg[P02oiIg[PGoUWV`1?nFNk<4oiMm]PCoUX2i0_nFPk`2oi^2]`GoVhFk1?nLRKl5oib=
a003oibBbOnUV/[oYI[:00;oYI[:00?o0000ojJOconVWll00_nVWll01?nVY]Go/K;Iok6bfOna/]T4
ok:gg@03ok[2h?nja>;o^/CR00Co^/CR5Oooool00ol0003oooooooooo`0mooooo`008_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg01gooooo0ol00002ooooo`03o`000?oooooooooo047ooooo0olS0003
od803P?oG00K1?mZ0243og048`CoK00N1?mS01T00omH017oF`0Yoe808@03oe808@?oC00J0om701D2
od@04003oc/02olf00Go=P0500;o=P050_la00000ol[003oU7B/oiAd[002oiAd[0CoTgB]1?nCMZl5
oiAg/0?oU7Vb00CoU7^doiIf[OnFMZgoUWJ]1OnFMjh4oiIi/0CoUW^c1?nGOKH2oiJ0^@;oVgnd1OnK
P[L4oi^5^`GoW8Vo0_nLSL@2ojFEa@GoYI[:00Go0000ojJOconVWlooYYo?ok6]e005ok6bf@;o/[OM
0onj`^04ok[4hP;o_L_U5Oooool00ol0003oooooooooo`0looooo`008_ooool01Ol@413ooooooooo
oooooooo410@01_ooooo0_l00018ooooo`04o`T00?lS003o8`00od803P;oG`Ln0omW3d84of`A@P?o
KA4o1?mY2cT4of<2<@?oF`0Y0omB0243od`06PCoA`0E0olk00/3ocH01@03oc400?nEM:coUGB/00;o
UGB/0onDM:`4oi=d[@GoTgJ_1?nDMk02oiAi/P03oiIdZonFMZgoUWJ]00?oUWJ]1?nFMjh4oiIi/0Go
UW^c0_nGOKH00onKOK7oVgndoi]o]002oi]o]0GoVh:g1OnKQK/3oib9_`03ojBA`OnUULGoYIG500?o
YIG51?nUV/X00ol0003oYYo?ok6]e002ok6]e0Go/K;I00?o/[OMok[2h?nj`^000onj`^000onja>;o
_L_Uokg;i@03okg;iAGooooo00?o0000ooooooooool0>oooool002;ooooo00Go0000oooooooooooo
ooooo`00000Hooooo`?o0000BOooool00ol9003o8`00ob<00004oel7?P?oI`m21?m/4D83ofdA?`Co
J@/i1?mS0S42oe/0:@CoDP0Q0om<01X00om701Go?`0@ocl04003oc/02`?o=P050_nHMj`4oiEd[0?o
U7B/1?nCM:d5oi=f[`;oU7N`0_nELjT3oiIdZ`GoUWJ]1?nFMjh4oiIi/0GoUW^c00?oUgffoi]m/OnK
OK401OnKOk@4oi^2]`GoVhFk00?oW8VoojBA`OnTTL400_nTTL44ojFEa@CoYI[:00?o0000ok6]e?na
[M@00ona[M@3ok6bf@;o^/3N1?nj`^02oko?i`Co_L_U00?o^loYooooooooool04oooool00ol0003o
ooooooooo`0kooooo`008_ooool01Ol0003ooooooooooooooooo000001Kooooo0ol00019ooooo`05
o`000?l9003o2@00ob<00?mD03P00omO1ch4ofL?@P?oK1521?m]4Cl3ofT;>@CoH`8a0omK02T4oe80
8@03od`06_m301Ko?`0@00?o?`0@0_lk00/2ocH01@CoV7N/1?nEM:`3oiAd[0GoTgB]0onCMZl00onE
LJSoUG>YoiEcZ@02oiEcZ@CoUWB[1?nFMZd4oiIg[PGoUWV`0onFNk<00onJNjooVgfaoi]m/@02oi]m
/@CoVgnd1OnKP[L3oi^5^`03ojB>_OnTTL7oY97100?oY9711OnUULD01OnUV/[o/:W@ok2Yd?l0003o
/:W@00Co/JgD00?o/K;Iok[0g_nj`=h00onj`=h00onj`^3o_loWoko?i`03oko?i`03okg;iOnkcnWo
^loY00;o^loY5Oooool00ol0003oooooooooo`0jooooo`008_ooool01Ol@413ooooooooooooooooo
410@01?ooooo0ol00002ooooo`03o`000?oooooooooo04Kooooo0_l00002o`T00003oe@0>?mO1cko
G`Ln00;oG`Ln0omW3d84of`A@P?oKA4o1?mY2cT3of<2<@CoF`0Y0_mB02401?m901ko@`0Fod<05_m3
01H3ocl040?o>`0;0_nMNjd4oiQg[0CoUGB/1?nDM:`4oi=d[@04oi=f[onELJSoUG6XoiEaZ0GoUG>Y
0onFM:/4oiIf[@GoUWN^1?nFNK001?nFNk?oVW^_oiYk[onJNjl4oi]m/@CoVgnd1OnKP[L00onKQK_o
Y8jmojB>_@02ojB>_@CoY9711?nUULD01_n`Y/go/:W@ok2Yd?n`ZM3o0000ok2Yd0?o/JgD00?o^[oM
ok[0g_nj`=h00onj`=h00oo0e>Wo_loWoko?i`03oko?i`03okcGkOnkcnWo^loY00?o^loY5_ooool0
0ol0003oooooooooo`0iooooo`008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg013ooooo0ol0001=
ooooo`;o000000Co2@00odT0<?mD03SoE00h1?mO1ch3ofL?@P?oK1521?m]4Cl3ofT;>@CoH`8a0omK
02T01?mB027oB@0NodT07_m901h2od<05PCo?`0@00?o>`0;oj>1[_nMNjd00onMNjd3oiQg[0GoUGB/
0onDM:`2oi=d[@;oU72W1OnELJP4oiEcZ@?oUWB[1?nFMZd5oiIg[P;oUWV`0_nJNJd5oiYk[`?oVgfa
1OnKOk@3oi^2]`03oj>;^_nTS[goY8jm00?oY8jm1OnTTL400onUULGo/:K=ok2Vc@02ok2Vc@;o/:W@
00Co0000ok2Yd?n`ZM3o/JgD0onj_md3ok[0gP?o`=CY0onocnL3okcGk@?o^loY0_ndd>hDooooo`;o
0000>oooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`;o0000Coooool2o`0000?o
B@0`0_mD03P3oel7?PCoI`m20om/4D84ofdA?`?oJ@/i00?oH`8aoeH0<OmF03401?m?02L3odT07P?o
@`0F0_lo0104oj>1[PCoWG^]0onHMj`5oiEd[0;oU7B/00?oTfnVoiA`YonDL:L00_nDL:L5oiEaZ0Co
UG>Y0onFM:/5oiIf[@?oUWN^00?oVGN/oiYi[OnJNJd00_nJNJd5oiYk[`?oVgfa1OnKOk@00onKP[Oo
Xh^joj>;^P02oj>;^PCoY8jm1?nTTL400on`Xl_o/:K=ok2Vc@03ok2Vc@;o/:W@00?o0000ok2Yd?nk
_]`01Onj_md00onj`=ko`=CYol3Dj@03ol3Dj@03oko?ionlengo_=O]00?o_=O]00?o^loYokC@k_nd
d>h00_ndd>hEooooo`03o`000?oooooooooo03Sooooo000booooo`Go0000C_ooool00ol0003o?`0V
odT0<002odT0<0;oE00h1?mO1ch3ofL?@PCoK1520om]4Cl2ofT;>@03oe/2>omF037oEP0a00;oEP0a
1?m?02L3odT07P?o@`0F00?oZXN`oj>1[_nSPJh00onSPJh4oiek[@CoV7N/0onEM:`01?nCKZGoTfnV
oi=_Y_nCKjH5oiA`Y`CoUG6X1?nELjT4oiIdZ`CoUWJ]00CoUWN^oiUg[?nIMjcoVGN/1OnJNJd4oiYk
[`CoVgfa0onKOk@00onSR;SoXh^joj>;^P03oj>;^PGoY8jm0_nTTL43ok2Sb`Go/:K=0_l00003ok^n
g0?o^[oM0_o1f^`4ol3Dj@;o_>7b1?nlend00oncfoCo]=3^okC@kP02okC@kP03ojS;lOoooooooooo
01Cooooo00?o0000ooooooooool0=oooool0033ooooo0_l0001Booooo`03o`000?lo02Ko?`0V00?o
B@0`0_mD03P4oel7?P03ofL?@_mU4T_oIA9;00?oI0m81?mP2T<3oe/2>`CoEP0a0om?02L3odT07P;o
@`0F1?nZQk04oj>1[PCoWG^]1?nHMj`01?nEM:coTfjUoi=^YOnCKZD4oi=_YPCoU72W1?nELJP4oiEc
Z@CoUWB[0_nFMZd2oiUfZPGoVGN/1?nJNJd4oiYk[`CoVgfa00?oVgndoj>8^?nSR;P00_nSR;P4oj>;
^PGoY8jm00?oY971ok2Sbon`Xl/00_n`Xl/2ok2Vc@?o000000?o^kkLo`000?nk_]`00_nk_]`00onj
_mgo`M[/ol7Jk003ol7Jk003ol3DjOnlhO;o_>7b00?o_>7b00?o_=O]ok?Km?ncfo@00_ncfo@00ond
d>koZ<_aojS;l@02ojS;lAGooooo00?o0000ooooooooool0=oooool002gooooo0ol0001Booooo`04
o`P00?l0003o?`0Vocl09P?oB@0`0omD03P2oel7?P03ofHBBomU4T_oIA9;00;oIA9;0omT3dP4of0:
@`?oF`8k0omF0343odl09`CoB@0N0_n^Rk44ojZ7/0GoXh6^0onMNjd2oiQg[0;oU6nV1?nCKZD4oi=_
YPCoU72W1?nELJP5oiEcZ@;oUWB[00?oVGFYoiUfZ_nIMZX00_nIMZX5oiUg[0CoVWV]1OnJNjl2oi]m
/@03oj:6]_nSR;SoXhRh00?oXhRh1OnSRkX3ojB>_@03ok2RbOn`Xl_o/:?;00;o/:?;0ol000001on`
Y/go_;oLokbog?nl_mco^kkLo`000?nk_]`00_o1hNl4ol7Jk0?o^N[e0_nlhO83ojkWn@;o/m_d0onU
eOP5ojS;lAGooooo00?o0000ooooooooool0=_ooool002cooooo0_l0001Booooo`?o20000olo02H3
odT0<0;oE00h00CoG`LnofHBBomV4T_oIQ9;1?mU4T/2of@?B0CoH0Y30omK0S/4oeH0<@?oC`0W00?o
B@0NoiQcYonLNZ`01?n^Rk43ojZ7/0GoXh6^0_nMNjd00onGLZOoU6nVoiA_YP02oiA_YPGoTfjU0onC
KjH4oiA`Y`GoUG6X1?nELjT00onFM:_oVGFYoiUeZ@05oiUfZPCoVGN/1?nJNJd5oiYk[`04oi]m/OnR
Q[KoXXJfoj:6]PCoXhRh1OnSRkX00onTS[go/:;9ok2Rb@02ok2Rb@?o00000_n`Xl/00on`Y/go_;oL
okbog003okbog003ok^ng?l0003o`N7_00;o`N7_00?o`M[/okWZmOnij_D00_nij_D2oio^m`;o[^Oi
0onMg_d5ojGEn0;oZ<_a0onM`_8Eooooo`03o`000?oooooooooo03Gooooo000/ooooo`?o0000Cooo
ool01OlG003o2000o`P00?l8003o>`0O00?o?`0V0om903000omD03SoIA18ofHBB`03ofHBB`?oIA9;
0omT3dP4of0:@`?oF`8k1?mF03401Om?02OoV7>WoiQcYonHLjOo[hfb00Go[X^a1?nZQk03oj>1[P04
oi]gZOnGLZOoUg:WoiMbY`GoU6nV1?nCKZD3oi=_YPCoU72W1OnELJP3oiEcZ@03oiQdZ?nIMJWoVGFY
00;oVGFY1?nIMZX4oiUg[0GoVWV]0onJNjl00onRQKCoXXJfoj:6]P02oj:6]PGoXhRh0onSRkX00on`
XLSo/:;9ok2Rb@03o`0000Co/:?;00?o_L3Mokbog?nl_m`00onl_m`01Oo0jO;o`N7_ol7Qkol0003o
`N7_00?o/?;e00Co^N[eoio^monOk_OoWnkg0_n>ho`5oigNo@;oYMGh0onIaoL5oig2lQCooooo00?o
0000ooooooooool0=Oooool002cooooo00Co0000ooooool0003o0000C?ooool3oaL000;o20000_lk
01l2ocl09P;oB@0`00CoHPa3ofD@B?mU44SoIA180omV4T/4ofDBB`?oI0m81?mP2T<3oe/2>`?oEP0a
00CoC`0WoiE^XonHLjOoV7>W0_n_SK85ojj;/@CoZXN`00CoXh6^oi]gZOnKMjWoVgNY1?nGLZL4oiA_
YPCoTfjU0onCKjH5oiA`Y`CoUG6X00CoUG>YoiQdZ?nHM:SoV7BX1?nIMJT4oiUfZPCoVGN/1OnJNJd0
1?nJNjooXXFdoj:5]?nRQK@5oj:6]PCoXhRh00?oXh^jok2Qb?n`XLP00ol00004ok2Rb@03ok2Sbonm
`=go_L3M00;o_L3M0onl_m`3ol3YlP03ol7Qkol0003o/?;e00;o/?;e0on3jNL00onOk_OoS^?lohkS
o002ohkSo0;oWMkm0onDc?/5oiW7m`;oWL;b0_nF^O0Cooooo`03o`000?oooooo000000Sooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<01Wo
oooo000/ooooo`;o00000_ooool00ol0003oooooooooo`17ooooo`06ob<00?lG003o5`00oaL00?l8
003o>`0I0_lk01l3ocl09P03odT0<?mR34?oHPa300?oIA180omV4T/4ofDBB`;oI0m81?mP2T<3oe/2
>`;oEP0a1?nEKZ<00onHLjOo[hfbojn=/P02ojn=/PCo[X^a1?nZQk05oi]gZ@?oUg:W1?nDKjH4oi=^
Y@CoTfnV1?nDL:L2oiEaZ0;oV7>W1OnHM:P3oiUeZ@CoVGJZ1OnIMj`3oiYi[@03oj63/onRQKCoXXFd
00?oXXFd1?nRQ[H3oj>8^004ok2Paol0003o0000o`0000;o/:781?n`X/T00onm`mko_L3Mokg0g@04
okg0g@04okbog?o0jO;o`>Wbol3YlP?oW??[00Co0000oh?Yion3jNOoPnWW0omcg_42ohkSo0CoS<on
1?nDc?/2oiW7m`;oTk[a1OnF^O0Eooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q01Wooooo000[ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0AOooool2ob<000;o5`000olk01T2oc/07`?o
?`0V0omR34<2ofD@B0CoIQ9;0omU4T/3of@?B0CoH0Y30_mK0S/4oi=[X@?oUFjS1On_SK85ojj;/@;o
ZXN`00?oXWj/oi]gZOnKMjT00onKMjT3oiMbY`CoU6nV1?nCKZD4oi=_YP?oU72W00?oUg:VoiQcYonH
LjL00_nHLjL5oiQdZ0?oVGFY1?nIMZX5oiUg[004oiYi[OnQPk?oXH>coj63/`GoXXFd1OnRQ[H01?nS
R;So0000o`000?n`X<L5ok2Qb003ok2RbOnm`mko_L?N00;o_L?N1?nm`=d2ok_al`04ol3Yl_nLln_o
W??[oiccj`;oEm3100CoD<gHo`000?mhc_ooN<ko1On2col2ohc?oP;oT;Oa1?nB^O85oi>jl@CoU[W`
5Oooool00ol0003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003o
oooooooooooooooo000001Wooooo000[ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0@Oooool01_l0003o:@00ob<00?lS003o5`00och05P?o>`0I0olk01l00olo02KoG`Dlof8<@`02
of8<@`?oIA180omV4T/4ofDBB`?oI0m81?mP2T<00onBJZ7oTf^Qoi=[X@03oi=[X@;oUFjS00?o[8bd
ojn=/_n_SK800on_SK85ojj;/@04ojZ7/?nROZcoXWj/oj9n[0CoVgNY0onGLZL4oiA_YPGoTfjU0onC
KjH01?nDL:OoUg:VoiMbY_nGLZH5oiQcY`CoV7BX0onIMJT5oiUfZP?oVGN/00?oXH:boj63/onQPk<0
0onQPk<4oj:5]0?oXXJf0ol00003ok2Pa`Co/:7800?o_/OQokg3g_nm`mh01?nm`mh01Onm`=go^o7c
ok_alonklO?oN^C@00;o000000?oK/Koog3:oom`b_l00_m`b_l01?l0003oN<koogS>oomhc_l2oh;?
o`?oS[?`1?n@]o44oi:ilP;oTk[a0_nE[^P5oiFck1Gooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Iooooo`00:oooool3
o`0000Gooooo00?o0000ooooooooool0?oooool3obT000;o8`000_ln01H3oc/06@;o>`0O00?o?`0V
oel5??mO1C`00omR34<3ofD@B0?oIQ9;1?mU4T/2of@?B0;oH0Y300?oTF^Soi9ZXOnBJZ400_nBJZ44
oi=[X@04oiE^Xon/S;Co[8bdojb<]0Go[hfb0on^Rk400onXQJooXWj/oj9n[002oj9n[0CoVgNY0onG
LZL5oiA_YPCoTfjU0_nCKjH00onFL:GoUg:VoiMbYP03oiMbYPCoV7>W1?nHM:P4oiUeZ@CoVGJZ00Co
VGN/oj62/_nQP[;oXH:b1OnQPk<4oj:5]0?o00001_n`X<L3ok2Qb0?o_/OQ1?nm`mh3ojogk`04ok_a
lom``OkoK/Koofk6o`;oT:3O1?n>Z>H00on>[^co0000ohj^k002ohj^k0GoS[?`0on@]o42oi:ilP;o
UJWT1OnE[^P5oiFck1Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go0000oeEEEOl0003o410@olc<c00Iooooo`00:oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo03cooooo00Ko:`00obT00?lY003o:@00ob<00?m101D2och05P?o>`0I0_lk
01l00omJ03?oG`Dloel5?004of8<@`;oIA181?mV4T/3ofDBB`;oI0m81OnAJj<3oi9ZX@?oTf^Q00?o
YHRfojb<]?n/S;@00_n/S;@5ojn=/P04ojj;/OnXQJooZ8F_ojR5[`CoXWj/1?nKMjT4oiMbY`CoU6nV
1?nCKZD00onCKjKoUW2UoiI`Y@05oiMbYPCoV7>W1?nHM:P4oiUeZ@?oVGJZ00?oX86aoj62/_nQP[80
0onQP[84oj63/`06oj:5]?l0003o0000o`000?nRQKCoXXJf2?n`X<L00on`XLSo_/OQokk7h@03okk7
h@05okg3g_n_mnoo[oO_ojogkonDT<d00onBV=H5oi2Pg`CoSZSV00?oSZk/o`000?n>[^`00_n>[^`2
ohjcl0;oUIcH0onEXmh5oiFYi0GoUJkX0_nE/n`2oi^cjAGooooo00?o0000ooooooooool00oooool0
1Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool06oooool002_ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0iooooo`03o`000?l[003o:`0000;o:@000om101D2
och05P?o>`0I0omJ03<2oel5?0?oHPa30omU44P4ofHBB`;oIA9;00CoTG>]oi5^YonAKZOoTFjW1?nA
Jj<3oi9ZX@04oi=[XOnUR;KoYHRfojF8]PCo[8bd1?n_SK800on/Rk?oZ8F_ojR5[`02ojR5[`CoXWj/
1OnKMjT3oiMbY`CoU6nV0_nCKZD2oiA^Y0CoUW2U1?nGLZH4oiQcY`GoV7BX0onIMJT01?nIMZ[oX86a
oj21/OnPPK45oj62/P;oXH>c0ol00003oj:5]003ok2Qb?n`X<Oo/:3700Ko/:370_nocND4okk7h@;o
Uo;O00?o0000oiB@cOnDT<d00_nDT<d3oi:HePGoT:3O1?n>Z>H01?n>[^co0000oiJEdOnFUM44oiFL
f0CoUJ?N1OnEZN@2oiF^j0;oVjcS1OnK/nTCooooo`?o00001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00?ogMgMoa0@4?nHV9P06oooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0fooooo`06o`000?lY003o:`00ob/00?lY003o@`0C0om101D2och05P;o>`0I
00CoEP0ZoeX0<omJ03?oFP0c0omO1C`3of8<@`?oIA180omV4T/01?mU4T_oTG>]oi5c[OnALjd3oi5^
Y`CoTF^S0_nBJZ400onKP[SoYHRfojF8]P03ojF8]PCo[8bd0_n_SK82ojb;/`CoZ8F_1?nROZ`5oi]g
Z@?oUg:W0_nDKjH2oi=]Y0CoU6jT1?nFL:D4oiMbYPCoV7>W1OnHM:P2oiUeZ@03oin0/OnPPK7oX86a
00?oX86a0onQP[83o`0000?oXH>c00?oXXFdok2Qb?n`XLP00_n`XLP6ok2Pa`Co_lgU00?o_/OQoiOb
gonGl]l00onFRL@4oiB@c@CoTYSF0_n@X=l2oiR9`PCoUho900?oUYGAo`000?nFUM400_nFUM44oiFL
f0CoUJ?N0_nEZN@2oibVg@GoVjcS1OnK/nTEooooo`09o`000?ooooooooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@6Oooool0013ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`?o00002_ooool00ol0003o
ooooooooo`0booooo`04o`000?lU003o:@00obT000?o:`000_m301<3od405@;o?P0F0omF02X3oeX0
<`;oG`Dl1?mR34<2ofD@B0;oIQ9;0_mnJk@3oge]]P04oi5c[OnAKZOoTFjWoi5^Y`;oTF^S0_n?NkT3
oi^2^0GoYHRf1?n/S;@00on_SK;o[8^cojb;/`02ojb;/`CoZ8F_1?nROZ`4oi]gZ@;oUg:W00?oTVbT
oi=]Y?nCKJ@00_nCKJ@5oiA^Y0?oUW2U1?nGLZH5oiQcY`?oV7BX00?oWgn`oin0/OnOP;400_nOP;44
oj21/@?o00000_nQP[83oj63/`03ok2RbOn`XLSo/:7800?o/:781?n`X<L00onoe>Wo_lgUoko=i@02
oko=i@;oKmbl00?oUhBloiJ9a?nFRL@00_nFRL@5oiB@c@;oTYSF00?oVHBkoiR9`_nHRL800onHRL84
oiN?b@04oiJEdOl0003oUYGAoiJEd@CoUIcH0_nEXmh2oifOePGoW:KM1OnK[><2oi^cj@;oXkKV5Ooo
ool00ol0003oooooooooo`0_ooooo`002?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400;ooooo`Go00001Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02oooooo00Ko
0000obD00?lU003o9@00obT00?l[0002od@040;o@`0C0om101D00oln01KoD@0RoeH0:P02oeH0:P?o
FP0c0omO1C`3of8<@`;oIA180_n2K;43ogi[]0CoOFff0on4LkP4ohmk^@CoVh:h1?nUR;H4ojb<]0Go
[8^c1?nXQJl4oj9n[0?oVgNY00CoTfjUoi9/Y?nBK:CoTVbT1?nCKJ@5oiA^Y0?oUW2U1OnGLZH4oiQc
Y`04oiQdZ?nOOk3oWgn`oimo/0CoWh2a0_nPPK42o`0000GoXH:b00?oXH>cok2RbOn`X/T00_n`X/T5
ok2Qb003ok2Paonoe>Wo_mCY00;o_mCY00?o_lgUofoL_?m_g;`00onGQ;`5oiJ9a0;oU93=0_nJOkD4
oiV4^`CoV8W21?nGSlT2oiJEd@03o`000?nFUM7oUYGA00;oUIcH00?oWIW?oifOe_nMWmH00onMWmH5
oibVg@;oVjcS0_nS[n05oj>fiQGooooo00?o0000ooooooooool0;_ooool0013ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0/ooooo`03o`000?lO003o9@0000;o9@0000?o@P0<od@04?m401000_m4
01000om301?o@@0Eod405@02od405@;oD@0R0omF02X3oeX0<`?oG`Dl0_mR34<2ohY_[PCoPVba0omn
Jk@4oge]]P?oQ7>h1?n?NkT3oi^2^0GoYHRf0_n/S;@00on/S[Oo[8^cojb;/`03ojb;/`CoZ8F_1?nR
OZ`01?nKMjWoTfjUoi=^YOnCKZD3oi9/Y0GoTffT1?nDKZ@3oiI`Y@GoUg:V0onHLjL6oimo/0;oWh2a
0ol00003oj21/@?oXH:b00?o/:?;ok2RbOn`X/T00on`X/T4ok2Qb0;o_]c_0onoe>T00ol0003oVGnf
oiUo]P04oiN4_0CoUXW400?oVgb`oiYo]OnJOkD00_nJOkD4oiV4^`CoV8W21OnGSlT01?nFUM7o0000
oijDbOnNU<T4oifIc`GoWIoF0_nLY]d2ojBXfPGoXjoP0_nS]^H3oj^liQGooooo00?o0000oooooooo
ool0;Oooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`00
00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Yooooo`03oaT00?lO003o7`00
00?o9@000_m200`3od@040;o@`0C00?o@@0Eodh06om>01/00_mA0283oeH0:P?oFP0c0omO1C`00omR
34?oT7:]ohY_[P02ohY_[PCoPVba0omnJk@4oge]]P?oQ7>h1?n?NkT3oi^2^0GoYHRf00Co[8bdojb>
]on/S[Oo[8jg1?n/Rk<4ojR5[`;oXWj/0_nGLZL4oi=^Y@CoTVbT1?nCKJ@4oiA^Y0CoUW2U1?nGLZH0
0onHLjOoWgn`oimo/005oimo/0?o00000_nOP;44oj21/@03oj62/_n`Xl_o/:?;00;o/:?;1On`X/T0
0on`XLSo_]c_okkLk`03okkLk`03okoDjOnINk3oVGnf00?oVGnf1?nGQ;`01?nFRLCoVgb`oi]l/?nK
O;04oiYo]@CoVHBk1OnHRL82oiN?b@;oX8o30_nNU<T00ol0003oWYC9oifIc`04oifIc`;oWIoF0_nU
Xm<5ojBXfP?oXjoP00?o[;ORoj^li_n[_>H01?n[_>HDooooo`03o`000?oooooooooo02gooooo000@
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`;o00003ooo
ool2o`0002Oooooo0olI00001?lO003o9@00ocl01olo00L2od8030?oA00@00?o@`0Cod`05_m>01/0
0om>01/2oe408P?oEP0Z0omJ03<00omO1CcoT7:]oi1b[@02oi1b[@?oRVn^1?n2K;43ogi[]0CoOFff
0on4LkP4ohmk^@CoVh:h0onUR;H00onVSK[o[8jgojb>]`02ojb>]`Go[8^c0_nXQJl00onKMjWoUg:W
oiMbY`02oiMbY`GoTfjU0onBK:@4oi=]Y0CoU6jT1?nFL:D3oiMbYPKoWgn`0ol000000onOOk3oWh2a
oin0/@02oin0/@?oX86a00?o/:G=ok2Sbon`Xl/00on`Xl/4ok2Rb@;o^nKc1?nng>l3oiUk/0CoVGnf
0_nGQ;`2oiaj[0GoVgb`1?nJOkD4oiV4^`?oV8W200?oXHbmoj2?`onPSl<00onPSl<2oijDb@03o`00
0?nNU<WoWIW?00;oWIW?00?oYYk>ojFSdonUXm<00onUXm<5ojBXfP04oj>_h?n/]n;o[;ORojbghPCo
ZkcV00?o/L?Wooooooooool04oooool00ol0003oooooooooo`0/ooooo`004?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo02;ooooo00Go4@00oaT00?lI003o6@00oc`00P04ocl01`03od803?m4013oA00@
00;oA00@0_m<01H3odh06`;oD@0R1?mF02X00omJ03?oUGB/oiEd[002oiEd[0?oT7:]1?n:Kjh4oh9/
/@?oOV^d1?mmKKH3ohAc^0CoSg^i0onKP[P00onUR;KoYXfjojJ=^P02ojJ=^P?o[8jg1On/Rk<00onX
QJooVgNYoi]gZ@05oiMbY`CoTfjU0onBK:@4oi=]Y0GoU6jT0onFL:D00onGLZKoWgn`oimo/003oimo
/0?o00001?nOOk05oin0/@04oj21/On`YLgo/:G=ok2Uc@Go/:?;00?o/:;9ok_Vlonki_<00onki_<0
0onng>ooVWN/oiUk/004oiUk/0;oVGnf00?oWGRYoiaj[?nLNZ`00_nLNZ`5oi]l/0CoVWne1?nIQ;/0
0onHRL;oXHbmoj6<_@02oj6<_@CoX8o30onNU<T00ol0003oWIW?ojJNcP03ojJNcPGoYJ?C0_nTZ=X2
ojfcg@Go[;OR00?oZkcVok73iona`nL00_na`nLCooooo`;o0000;_ooool0013ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Pooooo`04oa400?lI003o6@00oaT000;o?0020olo00L2od803003od@04?m:
01;oBP0B00;oC00F0om>01/3oe408P03oeH0:_nJNJgoV7N/00;oV7N/1?nEM:`4oi1b[@?oRVn^1?n2
K;43ogi[]0CoOFff0on4LkP4ohmk^@;oVh:h00?oW8NlojJ=^_nVSKX00onVSKX4ojb>]`?o[8^c00?o
Wgb/oi]gZOnKMjT00_nKMjT4oiMbY`CoTfjU0onBK:@4oi=]Y0GoU6jT0_nFL:D01?nNOZooWgn`oimo
/?nOOk03o`0000SoWgn`0onOP;400onaZ=3o/:G=ok2Uc@02ok2Uc@Co/:?;0_ndk_H4ok_Vl`?oVWN/
1OnINk000onIOkKoWGRYoiehZ@05oiaj[0CoVgb`1?nJOkD2oiV4^`;oXhVi1OnQS;d5oj2?``;oWYC9
00?o0000ojJNc_nVW/h00onVW/h4ojFSd`03ojjaf_n]/mgo[K?M00?o[K?M0on/]n82ok;3iPCo/L?W
5Oooool00ol0003oooooooooo`0[ooooo`00:Oooool2o`0001Cooooo00?o0000ooooooooool07?oo
ool01?mNdK7o2000oa400?lI0002ocP000;o?0020olo00L00om200coB00>odX04P03odX04P;oC00F
0om>01/00omA02;oVWV]oiYi[@02oiYi[@?oV7N/1?nEM:`4oi1b[@;oRVn^00?oSVbWohU[Z_n9JjX0
0_n9JjX3ohE[[PCoPVfb0on7M;P4oi1n^`CoW8Nl1?nVSKX4ojb>]`04ojb;/onOO:coWgb/oiml[0Co
VgNY1?nGLZL4oi=^Y@?oTVbT1OnCKJ@4oiA^Y003oiI`YOnNOZooWWj_00?o00002onOOk000onOP;7o
/JS@ok6Xd002ok6Xd0Co/:G=00?o/:?;okC^m_ndk_H00ondk_H00onki_?oVWFXoiYg[004oiYg[0?o
VG^`00?oWWNWoiehZOnMN:T00_nMN:T4oiaj[0GoVgb`0_nJOkD00onTQkGoXhVioj>9^@03oj>9^@Co
XHbm1?nPSl<01OnZVLGoZ9_9ojRKbOnXVlWo000000GoYYk>00?oYJ?Cojjaf_n^/MX00_n^/MX4ojfc
g@03ojbgh_nb`nKo//?V00?o//?V0_na`nL2ok;7jAGooooo00?o0000ooooooooool0:_ooool002Wo
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Iooooo`04o`000?l8003o2000oc80
00Co>00000Co?002ocl01olo00OoAP090om800h3odX04P;oC00F0_m>01/3oi]k[PCoVWV]1?nHMj`3
oiEd[0;oT7:]0_nBKJH3ohi/Y`CoRF^Z0on5Jjh4oh9]/P?oQgBh1?n@O[/4oib7_0GoYXfj0_n/S[L0
0onPOZooWgb/oiml[003oiml[0?oVgNY1?nGLZL4oi=^Y@CoTVbT1?nCKJ@3oiA^Y005oial[onNOZoo
0000o`000?nNOZl03?nOOk000ona[=?o/JS@ok6Xd003ok6Xd0?o/:G=0onVl_<2okC^mP04oiYcYOnJ
MJSoVWFXoiYeZ0GoVWN/00CoVG^`oiigYonNMjOoWWNW1?nMN:T4oiaj[0GoVgb`00CoVWneojB7]OnT
QkGoY8Ne1?nSRKT5oj6<_@04oj2?`onZVLGoZYW5ojZIa@CoZ9_900Go0000ojJNc_nVW/koYYk>ok6`
e`05ojjafP;o[K?M0onda>H4ok;3iP03ok?<k?nbanWo//OY00?o//OY5?ooool00ol0003ooooooooo
o`0Zooooo`00:Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Kooooo0_l00002
o`P000;o<P000olh0002oc`00P?oAP090_m800h3odX04P?oC00F0_nLOK04oi]k[P?oVWV]1?nHMj`2
oiEd[003oi=^YOnBKJKoTVfV00;oTVfV1?n>K:L4ohU[ZP?oQF^^0on2KK84ohMd^0?oT7jk1?nLQk`5
ojJ=^P03ojb>]onPOZooX7j_00GoWgb/0onKMjT4oiMbY`GoTfjU0onBK:@4oi=]Y003oiA^Y?nLO:oo
000000;o00000onNOZl:oimo/0Co/JcC1OnaZ=001?n`YLgoY_;cojKblonVl_<4oiYcY@?oVWFX1?nJ
Mj`00onNMZGoWWNWoiigY`03oiigY`?oWGRY1OnLNZ`3oi]l/003ojJ6/_nTQkGoY8Ne00;oY8Ne1?nS
RKT4oj6<_@03ojbH`_nZVLGoZYW500?oZYW51?nXVlT00ol0003o/K3Gok6`e`02ok6`e`?o[[7J00?o
]/OWokC4i_nda>H01?nda>H00onb`nKo/lc/ok?<k002ok?<k0?o//OY0_n_bNdDooooo`03o`000?oo
oooooooo02Wooooo000Yooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04oooool3
o`000004o`P00?l]003o<P00oc8000?o>00000?o?002od@00om600T00_m600T2odP03PCoBP0B00?o
C00Foieo/OnLOK000_nLOK04oi]k[PCoVWV]0_nHMj`01?nDKjKoTfjUoi=^YOnCKZD5oi9]YP?oSVbW
1?n9JjX3ohE[[PCoPVfb0on7M;P4oi1n^`CoW8Nl0onVSKX00onNOk7oX7j_oj1n[`02oj1n[`CoWgb/
0onKMjT5oiMbY`CoTfjU0onBK:@2oi=]Y004oiUi[_l0003o0000o`0000?oW7b_0onNOZl8oimo/003
ok>aeona[=?o/JcC00?o/JcC1?naZ=02oho_iP03ojKblonKLZCoVg:T00CoVW>U1?nJMJP2oiYg[0;o
WWJU1OnNMjL3oiehZ@GoW7Z/00CoVgb`ojJ6/_nVQ[;oYXJb1?nTQkD5oj>9^@03oj6<_On/V<;o[9S2
00;o[9S21?nZVLD3ojRKb@03ok>`eOl0003o/K3G00Co/K3G00Co[[7JokK7ionfanOo]/OW1?nda>H0
0onddNoo/lc/ok?<k003ok?<k003ok;7jOn_bNgo[lW]00?o[lW]5?ooool00ol0003oooooooooo`0X
ooooo`00:Oooool3o`0001Oooooo00?o0000ooooooooool04Oooool2o`000003obD00?l]003o;@00
00;o<P0000?o>000od000?m000000om400<2odH02@?oB00>00?oBP0Boij1/onMOk400onMOk43oiam
/0CoVg^^1?nJNJd00onHMjcoU6nVoiA_YP04oi=^Y@CoTVfV0on>K:L4ohU[ZP?oQF^^1?n2KK83ohMd
^0CoT7jk1?nLQk`01?nVSK[oWWnaoiio/OnNOk44oj1n[`CoWgb/1?nKMjT4oiMbY`CoTfjU0_nBK:@0
1OnEMZko0000o`000?l0003oVGV^00GoW7b_0onNOZl6oimo/0Co/k7G1Ona[=<01OnaZ=3oSnoVoho_
i_n?knKoW7:R00?oVg:T1?nJLjD4oiYeZ003oiYg[?nNMZGoWWJU00;oWWJU1?nNMjL3oiehZ@CoW7Z/
00?oYhJaojJ6/_nVQ[800onVQ[84ojB7]@?oXhVi00?o[iW1ojbH`_n/V<800on/V<84ojZIa@03ojRK
bOnc/=Go/k3E00;o/k3E00Go0000ok6`eona/=Oo/K3GokW>jP05okK7i`03okC4i_nddNoo]=7_00;o
]=7_0_ncc>`3ojoAl@Co[lW]00?oZLK^ooooooooool04Oooool2o`0002[ooooo000Yooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool03_ooool2o`0000;o9@000_l]00000olb003o?000
od000003od0000;oA0030om600T00om800koWX6coij1/`02oij1/`CoWGna1?nLOK03oi]k[P;oVWV]
0_nEL:L4oiA_YP?oTfjU1?nBKJH3ohi/Y`CoRF^Z0on5Jjh4oh9]/PCoQgBh0on@O[/2oib7_0;oV7^a
1OnNOk43oj1n[`CoWgb/1?nKMjT4oiMbY`;oTfjU0_nCMJh3o`0000GoVGV^1?nLO:l4oiin[`?oWgn`
00?o];SKok>aeonc/ML00onc/ML4ok6/d`03ofoOcOnLLZ;oW7:R00?oW7:R0onKLZ@5oiYcY@;oVWFX
00?oWWFToiifYOnNMZD00onNMZD4oiigY`CoWGRY0_nLNZ`2ojN6/@GoYXJb1?nTQkD00onSRKWo[iW1
ojnI`@02ojnI`@Co[9S20onZVLD00ong/mKo/k3Eok>`e@04ok>`e@03o`000?nic^[o^LkZ00;o^LkZ
0onfanL2ok?Il`?o]=7_0_n]fOL5ojoAl@03ojo9kOnYa^koZLK^00;oZLK^5?ooool00ol0003ooooo
ooooo`0Wooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
1Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo0_l000001OlL003o9@00
obD00?l]003o=`0000?o?0000om00002od@00`03odH02OnRQkSoX8Be00?oX8Be0onNPK<5oieo/@?o
W7f`0_nKNjh00onELJSoUG2WoiE`Y`02oiE`Y`CoU6nV0onCKZD4oi9]YP?oSVbW1On9JjX3ohE[[P?o
PVfb1?n7M;P2oi1n^`03oi9f/?nHNk7oV7^a00;oV7^a1OnNOk43oj1n[`GoWgb/0onKMjT2oiMbY`;o
TgN`00CoTgF^o`000?l0003o00001?nEMZh4oiUi[PCoW7b_1?nNOZl00onOOk3o];SKokBhf`02okBh
f`Go/k7G00Co/JcCoiabXOnLLZ7oW7:Q1OnLLZ83oi]bY0GoVW>U00?oVWFXoiieY?nNMJ@01OnNMZD4
oiigY`CoWGRY00?oW7Z/ojN6/OnWQ[400_nWQ[44ojJ6/PCoY8Ne1On_VL45ojbH`P04ojZIaOng/mKo
]k?FokNcePCo/k3E00?o^mS_o`000?nic^X00onic^X00onfanOo/mWcok?Il`03ok?Il`03okCAkon]
fOOo[MWg00;o[MWg0_n_dO42ojO<l`GoZLK^5Oooool00ol0003oooooooooo`0Vooooo`003_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo00Ko0000oa400?lL003o
7000obD00?l`0003ocL000;o?0000om000000om400?oXXNhoj:7^003oj:7^0?oX8Be0onNPK<5oieo
/@;oW7f`00CoUW>YoiEaZ?nELJSoUG6X1?nEL:L4oiA_YP?oTfjU1?nBKJH4ohi/Y`CoRF^Z0on5Jjh2
oh9]/P03ohe]Z_n>LJgoSW6]00;oSW6]0onBM[05oiQk/@CoWWna1?nPOZl4oiml[0;oVgNY00?oUWbc
oi=g/?nCMk000ol00004oi=e[P?oUGJ^1?nINJh5oial[`;oWWj_0_nf_Ml5okBhf`;o/k7G00?oB/BW
oi]`X?nLLZ401?nLLZ44oiabXPCoVg:T0onJLjD00onNM:?oWWFToiieY002oiieY0CoWWJU1OnNMjL3
oiehZ@GoYhJa1OnVQ[82ojB7]@;o/Yc11?n_VL44ojbH`P03okZif?ng/mKo]k?F00?o]k?F00?o/k3E
ok_Hkonkf>l00_nkf>l00ol0003o^LkZokW>jP03ok7Sn0;o/mWc0onVhO/2ojgIm`?oY=7g1?nWc?<2
ojW6kP?oXl7^5?ooool00ol0003oooooooooo`0Vooooo`001_ooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0_l0000Mooooo`03o`000?oooooo
oooo00Cooooo0ol000000olA003o7000oa`00002oc0000?o=`000_ll00000om0003o]:gBok:Zd003
oj>:^PCoXXNh0onPQ;D4oij1/`?oWGna00CoUWB[oiIcZOnFLjWoUW>Y1?nELJP3oiE`Y`CoU6nV0onC
KZD5oi9]YP?oSVbW0_n9JjX2oi5]Y@?oSffW0on=KJX4ohia[@CoTWJ`1?nHNk44oiio/@CoX7j_0_nO
O:`2oi^2]`?oUWbc0_l00003oi=g/0CoTgF^0onEMZh4oiUi[PGoW7b_00?oWWj_okJmgonf_Ml00_nf
_Ml3okBhf`03o`000?n?IYooTVZR00;oVg2P1OnLLZ44oiabXPCoVg:T0_nJLjD2oiidX`CoWWFT1?nN
MZD5oiigY`;oWGRY00?oZHN`ojN6/OnWQ[400onWQ[45ojJ6/P04ojB7]OnbW<7o/Yc1ok:L`@Go[iW1
00?o[9S2okZif?nj^MP00_nj^MP3okNceP;o^^Od1?nkf>l01?nUk?Wo0000ok7Sn?nahoP4oiOWn`;o
Y^7k0_nMeO/5ojCAm`;oYlcc0_nR`o45oj?1kQCooooo00?o0000ooooooooool09Oooool000kooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`02ooooo`05o`000?l3003o4@00oa400?lL00000ol`0003ocL0
0005oc`00?nd[M;o]:gBokB]d_nVS[`01?nSR[X4oj:7^0CoX8Be0onNPK<01?nMOk7oUWB[oiIdZonF
M:/4oiIcZ@?oUG6X1?nEL:L3oiA_YPCoTfjU1?nBKJH2ohi/Y`03oi=]Y?nAKJGoTFfU00;oTFfU0on?
KJL4ohe]ZPCoSW6]0onBM[04oiQk/@GoWWna0_nPOZl00onNQk_oVh:goi^2]`02oi^2]`?o000000?o
UWbcoi=g/?nCMk000_nCMk04oi=e[P?oUGJ^1OnINJh3oial[`03okFnhOnf_Moo][gO00Co][gO00Co
];SKohmVWon?IYooV6bN1?nKL:04oiabX@GoW7:R0onKLZ@01?nJLjGoWWBSoiidXonNM:<4oiieY0Go
WWJU1?nNMjL01?nMN:WoZHN`ojV7/?nYQk05ojN6/@?oYXJb00?o]Z;4ok:L`OnbW<400_nbW<44ojnI
`@03oko4g_nj^MSo^[WH00Co^[WH00?o]k?Fok[Wm?njio@00_njio@01onkf>ooYNciojG/nOnUk?Wo
N^;ao`000?mjh_400_nGio/2oi;GoPGoWMGk0_nTdOL2oio4lPGoX/?a0_nS`Nh2oj6lkAGooooo00?o
0000ooooooooool09?ooool000kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00Cooooo00?o0000ooooooooool07_ooool2o`0000?o0`0000Co4@00obT00?lY003o<000
0onh/mD5okJ`d`04okB]d_nVS[coYXjlojJ>_0?oXhZj1OnRQkP3oj24]@;oWX6c00?oUgN/oiIdZonF
M:/00_nFM:/4oiIcZ@?oUG6X1?nEL:L4oiA_YP?oTfjU1?nBKJH00on>K:OoTffToi=]Y004oi5]Y@Co
SffW0on=KJX4ohia[@?oTWJ`1OnHNk44oiio/@04oj1n[onNQk_oWXNkoi^2]`?o000000CoVh:goiIl
/onFO;?oUWbc1?nCMk04oi=e[PCoUGJ^1?nINJh00onLO:oo]KkQokFnh@02okFnh@Co][gO00?oSFBM
ohmVWonHK9h00_nHK9h4oi]`X0CoW7:Q1OnLLZ82oi]bY003oimfXonNM:?oWWBS00?oWWBS1?nNMJ@4
oiifY@?oWWNW00?o[8VaojV7/?nYQk000_nYQk05ojN6/@03ojJ6/_nfX/Co]Z;400;o]Z;41?nbW<40
0on_VL7o_lCNoko4gP02oko4gPCo^[WH0_n[m?82ok[Wm0?oQNW[00GoYNciog[RlOmjh_7oN^;ao`00
0002ohKEo`CoT]On0_nMeO/2oi_3l`GoWlCb0_nR`o43oinkk0CoXKc]4oooool2o`0000Sooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Wo
oooo000>ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`;o
00007_ooool2o`000007o`<00?lD003o8000ob000?lY003o`MS[okVfeP05okRce@;o][3C0_nXT[l4
ojJ>_0CoXhZj1?nRQkP2oj24]@04oiQi[_nGMjcoUgN/oiMg[0CoUWB[1?nFLjT3oiEaZ0CoUG2W1?nD
KjH3oi=^Y@;oTVfV0_nDKZ@3oi=]Y0CoTFfU1?n?KJL3ohe]ZPCoSW6]1?nBM[04oiQk/@;oWWna0_nO
Rkh01?nNQk_o0000o`000?l00004oi^2]`?oUWbc1?nCMk04oi=e[PCoUGJ^0_nINJh3ojjjhPGo]KkQ
00Co][gOoheTWOn=I9goTfRM1?nHK9h4oi]`X0CoW7:Q1OnLLZ800onKLZCoWgJSoimfX`05oiidX`Co
WWFT1?nNMZD01?nNMjOo[8Vaojb9/On/RK44ojV7/0CoYhJa00?o_:c:okJRa?nfX/@00onfX/@4ok:L
`@Ko_lCN00Co^[WHoj_dl_n[m?;oZoCb0om7a[/2ohGYj`03odg<eOmicoooNLoo00;oNLoo00?oQ]Go
o`000?nE^>l01OnG__<4oi_3l`;oWlCb0onN^N/5oinkk0;oXKc]0_nQ^^/Dooooo`03o`000?oooooo
oooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Wooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo0_l0000Nooooo`07o`000?lD003o5000oa@00?lP003o`MKYol7Hj`04
okVfeP?o^;?E00?oZYK2ojRB_onXT[l00onXT[l3ojJ>_0CoXhZj0_nRQkP2oiYk/0?oV7V^1?nGMj`4
oiIdZ`?oUW>Y0onELJP4oiE`Y`CoU6nV0_nCKZD5oiA^Y0CoTffT0onAKJD4ohm]Y`?oSFfZ1On>LJd3
oi9f/0;oV7^a0_nMRKh2oin;_P?o00000onNQk/4oi^2]`?oUWbc1OnCMk04oi=e[P;oUGJ^00?oY;;R
ojjjh_n^^^801?n^^^82okFnh@03ohmUWOn@IIcoT6FL00?oTfRM1OnHK9h3oi]`X0GoW7:Q0onLLZ80
1?nRNJGoWgJSoimfXonOMZ<5oiidX`CoWWFT1?nNMZD5ojb9/@CoZHN`0_nWQ[43okb/bPCo]Z;40onb
W<42ol?Fj0Co_lCN0_maglH00on[m?;oNKckogVln`02ogVln`CoMLOo0_micol2oiB]j0;oUKS_00?o
0000oiFhkonG__<01?nG__<2oi_3l`;oW[GY1OnN^N/2oinkk0;oXKKX1OnQ^^/Dooooo`03o`000?oo
oooooooo00Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
00002Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool00ol0003oooooooooo`0Jooooo`05ocfo/_l6003o1P00oa@00?n`lo<00oo1e^T2
ok^ie`Go^KKF00Co^;?EojZF`_nZU/;oZYK21?nXT[l4ojJ>_0;oXhZj00?oVgjboiYk/?nJNk000_nJ
Nk04oiQi[P?oUgN/1?nFM:/3oiIcZ@CoUG6X0onEL:L2oiA_YP;oTfjU1onDKZ@4oi=]Y0CoTFfU0on?
KJL3ohe]ZPGoSW6]0_nBM[001?nJQKcoWHVnoif9__nMRKh3o`0000?oWh^n0onNQk/5oi^2]`?oUWbc
1?nCMk04oi=e[P04oiEf[_nT/^;oY;;RojBbhPCo[[[R00?oTVNNohiSW?n@II`00on@II`3oi=XW@Go
V6bN0onKL:05oiabX@;oW7:R0_nRNJD4oimfX`CoWWBS1OnNMJ@2oiifY@03ojn>/on/RK7o[8Va00?o
[8Va1?nYQk000onWQ[7o_:c:okb/bP02okb/bPGo]Z;400?o/Yc1ol?Fj?o3e^P00_o3e^P00onoa=ko
SicLohF]k`03ohF]k`;oNKck0_nHU]04oiJRg@GoU:gX0_nE^>l01?l0003oUKS_oiNnlonG__<2oif_
i0GoW[GY0_nN^N/2oj6bi0GoXKKX0onQ^^/00onT^nWoooooooooo`0Booooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S802Ooo
ool002Oooooo00?o0000ooooooooool05oooool3o`000003o`H00?nfkoGo]^oe00?o`]CX00?o`MKY
ok^ieonk^ML00_nk^ML3okVfeP03ojfKa?nZU/;oZYK200;oZYK21?nXT[l4ojJ>_003oj>:^_nKO[;o
Vgjb00CoVW^`1?nHNJh3oiMg[0CoUWB[1?nFLjT3oiEaZ0;oUG2W00?oTVjVoi=^YOnCKZD00_nCKZD7
oiA^Y0CoTffT1?nAKJD3ohm]Y`CoSFfZ0on>LJd01?nIPKSoVXFloiZ5_?nJQK`3o`0000;oWHVn1?nO
Rkh4oij7^`CoVh:g0onFO;<2oi=g/0;oT:KT1?nIZ^85ojBbhP03ojjjh_n>I9coSV>L00;oSV>L1?n@
II`4oi=XW@CoV6bN0onKL:05oiabX@04oiabX_nRNJGoXWVUoj9iY@CoWgJS1?nNM:<5oiieY004oiif
YOn_S[?o[hjcojn>/`Co[8Va1?nYQk05okb/bPCo]Z;40_noko82ol?Fj0GoSicL0_n5[Nl00onKSLCo
V9K@oiRFd003oiRFd0CoUZ;M0_nD[NP2oinRe`;oWZWN00?o0000oijYg_nNZMh01?nM[n@2oijej@;o
XZkP1OnQ/^@4oj6fj003oj6jjonT^nWoY;_Y00;oY;_Y5?ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Wooooo000Woooo
o`;o00005Oooool00ol0003oF=;Aohc]jP02ohc]jP;o]^oe1Oo2e>P6ok^ie`04okVfe_n]VlCo[I_4
ojfKa0?oZYK21OnXT[l2ojJ>_003oif1]OnKO[;oVgjb00;oVgjb0onJNk04oiQi[P?oUgN/1?nFM:/4
oiIcZ@;oUG6X00CoTFjWoi9^Y_nBKZKoTVjV1?nCKZD7oiA^Y0CoTffT1?nAKJD4ohm]Y`?oSFfZ00?o
SW6]oiV1^?nIPKP00_nIPKP2o`000003oiZ5_?nMRKkoWHVn00;oWHVn1OnORkh3oij7^`;oVh:g0_n@
]_03ohjZj@GoT:KT1?nIZ^83ojBbhP?oSVBL0on>Hi`5oi1UW0?oTfRM1?nHK9h4oi]`X0?oW7:Q00?o
YGfWoj9iYOnRNJD00onRNJD3oimfX`GoWWBS0onNMJ@00onaTkOo[hjcojn>/`02ojn>/`Go[8Va0_nY
Qk02olBoePGo_:c:00Co]Z;4oko_l_noko;o_nob1?nGSlT2ohnLg0;oWXNj1?nKSL@5oiRFd0;oUZ;M
00?oXYc>oinReonOX]L00onOX]L2oijYgP03o`000?nNZMkoWZWN00;oWJoT00?oXZSKoj:^h?nR[^00
0onR[^04oj6bi0;oXKKX0onU^>H4ojBkjAGooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4009ooooo`009oooool00ol0003o
ooooooooo`0Aooooo`?oLMoZ0_nLk_H3okWZm@?o`];V0oo2e>P2okflf0Co^kWG00?o/:37ojfKa?n]
Vl@00_n]Vl@4ojZF`P?oZ9:o00CoWhFgoif1]OnMPKGoWH6e1?nKO[84oiYk/0?oV7V^1?nGMj`3oiId
Z`;oUW>Y0_nAKjP3oi5^Y`?oTVjV1?nCKZD8oiA^Y0?oTffT1?nAKJD4ohm]Y`;oSFfZ00?oVGfcoiV1
^?nIPKP00ol00003oiZ5_0GoWHVn1?nORkh2oij7^`;oUL?f1?n@]_03ohjZj@GoT:KT1?nIZ^800onT
/^;oSVBLohiTW002ohiTW0?oSV>L1On@II`3oi=XW@CoV6bN1?nKL:02oiabX@;oYGfW1OnRNJD3oimf
X`GoWWBS0_nNMJ@2ok6C]`Co[hjc1On/RK401?nYQk3oa;oFolBoe_o4_mH4okb/bP?oSNkH00?o_nob
oib6^onGSlT00_nGSlT00onRQ;?oWXNjoij7^P02oij7^PCoVhg41?nHU]000onUUlOoXYc>oj:LcP02
oj:LcPGoWj;G0_nNZMh00ol0003oY:CEoj:Xf`03oj:Xf`GoXZkP0_nQ/^@2ojJdh`GoYKSV0_nT^nT2
ojRnjA;ooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonj^[[o000000Wooooo000Wooooo`03o`000?oooooooooo00_ooooo0omUdoD3ohGSn@;oY^[j1?nk
ho<00onij_Go`];Vol;BiP03ol;BiP03ol;Dj?nm_=So_KcH00;o_KcH00?o^kWGok2Paon`X<L00_n`
X<L3ojfKa0CoZYK200CoZ9:ooin5]onOQKOoWhFg1?nMPKD3oi]n/PCoVW^`1?nHNJh3oiMg[0;oUWB[
00?oTW2Yoi5_Z?nAKjP00_nAKjP4oi5^Y`?oTVjV0onCKZD8oiA^Y0CoTffT0onAKJD2ohm]Y`;oVW^`
0_nIOK<3o`0000?oVH6h1?nJQK`4oif9_P;oWh^n0onMcOP4oiG3mPCoT;K`0on>Z^T2oi2Vi0CoTFJM
0on@II`4ohiTW0CoSV>L1?n@II`3oi=XW@CoV6bN1?nKL:000onLLZ7oYGfWojEmY`02ojEmY`CoXWVU
0onOMZ<5oiidX`03oiieY?naTkOo/I>g00;o/I>g1?n_S[<3ojb9/@03ol_Rj?o4_mKoa;oF00?oa;oF
00Co_:c:ohg^f?n=k]SoSNkH1?nLQ[/00onGSlWoXXBcoj:4/`02oj:4/`CoWXNj1?nKSL@00onHU]3o
YIO7ojFGa`02ojFGa`?oXYc>1?nOX]L01?nWX<ooY:CEojBTeOl00002ojBTe@CoXZSK0_nR[^02ojNa
g`GoY[CS0_nU^>H2ojVki`GoZ;kY5?ooool02Ol0003oooooooooooooooook^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT02Oooool002Kooooo0ol00006ooooo`?oP<co
0_med_h4oi;NoP04ohGSnOnVj_[oY^[jojKZnPCo^n?c0_o2d>D4ol;BiP;o_[kI0onm_=P00oncYL[o
/:37ok2Pa`03ok2Pa`Co[I_40_nZU/800onQRK[oWhFgoin5]`02oin5]`CoWH6e0onKO[84oiYk/0Co
V7V^0_nGMj`01?nBLZ_oTW2Yoi9`ZOnBL:T4oi5_Z0CoTFjW0onBKZH4oi=^Y@OoU6jT1?nCKJ@2oi5]
Y@04oi]k[_nJNk3oVW^`oiYk/0?o00000_nIOK<5oiV1^0?oVXFl0_nMRKh4ojG@mPCoWLgh0_nE`oH3
oi5[X`;oUFjT1OnBIid4oi5VW@CoT6FL1?n>I9`3ohiSW0CoT6FL0onCJ9d5oiQ/WP?oVg2P1OnUOJL4
oj9iY@CoWgJS0onNM:<00ondV[go/I>gok6C]`03ok6C]`Co[hjc00?o[8Vaol_Rj?o;h^P00_o;h^P3
olBoeP03ojJ1[?nQP[;oXH:b00?oXH:b0_nLQ[/00onWQ:ooXXBcoj:4/`03oj:4/`CoWXNj0onKSL@0
0onYU<7oYIO7ojFGa`03ojFGa`CoXYc>00?oWj;GojNPconWX<l00_nWX<l2ojBTe@04o`000?nTY=Go
XZSKoj:Xf`;oZJoL1OnW/Ml2ojJdh`;oZ[[U1OnY^nL2ojRnj@;oZl7Z5Oooool00ol0003ooooooooo
o`0Nooooo`009_ooool00ol0003oooooooooo`02ooooo`CoQl;k0_n0c?l4oi[Eo0;oT]kn0on/hOT4
okcKl003ok_Sloo2d>Go`]3U00;o`]3U00?o`];VokjnfOnn_]T00onn_]T01?nm_=So/jG:ok>Ub_nc
YLX4ok2Pa`?o[I_400?oY8jmoj69^_nQRKX00_nQRKX4oin5]`?oWH6e1?nKO[83oiYk/0;oV7V^0_nC
Lj`3oi9bZ`CoTW2Y0onAKjP4oi5^Y`?oTVjV1?nCKZD7oiA^Y0CoTffT00?oTFfUoi]k[_nKNjh00ol0
0002oiYk/0?oVGfc1OnIPKP2oiZ5_0?o[L__0onUd?H3ohiVW`CoSfRQ0_nAJj<9oi9WW@?oTFJM1?n@
II`4ohiTW0?oSV>L1?n@II`3oi=XW@GoV6bN0_nKL:000onYPZ[oYGfWojEmY`03ojEmY`CoXWVU1?nO
MZ<2oiidX`?o]9Zm1?naTkL4ojn>/`03oj;fe?o;h^Sobn;X00?obn;X00?oa;oFojJ1[?nVPJ`01OnQ
P[801?nLQ[_oYhB_ojN4[onWQ:l4oj:4/`CoWXNj00?oVhg4ojVD`OnYU<400_nYU<45ojFGa`;oXYc>
00?oZio;ojNPconWX<l00onWX<l3ojBTe@03o`000?nY[mcoZJoL00?oZJoL0onW/Ml00on/^N?oZ[[U
ojZji@03ojZji@?oZK_W0_n/`NT4oj_1jQCooooo00?o0000ooooooooool07_ooool001_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?ooooooRkOc00?oRkOc0_n7`_/3oig9mP?oV]Gl
1?n^eoD00on/hOWo_=_`okcKl002okcKl0;o`LgS0oo2d>D3oknofP?o_[kI00?o]J[=ok>Ub_ncYLX0
0_ncYLX5ok2Pa`04ojfKa?nTS[goY8jmojB>_@?oXHVj1?nOQKL4oif1]@?oVgjb0_nJNk000onDMJko
Tg>/oi=c[002oi=c[0CoTW:[0onBL:T3oi5_Z0CoTFjW0onBKZH4oi=^Y@OoU6jT0_nCKJ@2oi]j[@?o
000000?oVg^^oiYk/?nJNk000_nJNk04oiUm/`?oVH6h0_nc`^D5ojg;k`03ojG@m_n@IYkoSVJO00;o
SVJO0_n?J:42oi=WW0_oTVNM0onAIYd4oi1UW0CoSVBL0on>Hi`4oi1UW0?oTfRM1OnHK9h01?nKL:3o
ZH:ZojV2Z_nYPZX4ojEmY`GoXWVU0onOMZ<00onNM:?o]9ZmokBJ_@02okBJ_@Go/I>g0_n_S[<3oj;f
e0;obn;X0_n[PZT3ojJ1[0CoXH:b00?o[8N]ojN4[onWQ:l00_nWQ:l5oj:4/`;oWXNj00?o[YFlojVD
`OnYU<400onYU<44ojFGa`03ojnPb?n[Wl_oZio;00;oZio;1OnWX<l01?nTY=Go[:kIojb^fOl00005
ojV_g004ojNagon/^N?o[;WSojbih`GoZ[[U00?oZK_Wojc1jOn/`NT00_n/`NT2oj_1jP;oZl?[5?oo
ool00ol0003oooooooooo`0Mooooo`006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o
0000ooooooooool00_n;]o<3oijmkPCoWLWf00?oV]GlojkGmOn^eoD00_n^eoD3ok_Ck003okcKl?o1
cN?o`LgS00?o`LgS00?o`]3Uoknof_no_mX00ono_mX01?nn_]Wo]J[=okFZcOneZ/d4ok>UbP;o/:37
0_nWTl44ojB>_@?oXHVj1?nOQKL4oif1]@;oVgjb00CoUGN`oiAe[_nDMJkoU7F^1?nCLj`4oi9bZ`?o
TW2Y1?nAKjP3oi5^Y`?oTVjV1?nCKZD6oiA^Y003oiUi[_nKNZgo000000;o00001?nKNjh4oiYk/0Co
VGfc00?oVH6hok?2iOnc`^D00onc`^D2ojg;k`04oi9WWOn@IYkoT6JNoi1VWP;oSVJO1OnCIi`;oi9W
W@?oTFJM1?n@II`4ohiTW0?oSV>L1?n@II`4oi=XW@?oV6bN00?oYh:/ojV2Z_nYPZX00_nYPZX4ojEm
Y`GoXWVU0_nOMZ<00ongY/So]9ZmokBJ_@03okBJ_@Go/I>g00Go[hjcoj;fe?nRm]CoUfjRoiAbZ@04
oj^2Z@CoYX6/0_nQP[82ojb7[@CoYhB_1OnRQ;<01?nNQk[o[YFlojjE_?n^UK`5ojVD`@04ojFGaon_
X<So[j38ojnPb0GoZio;0_nWX<l2ok2_e`?o[:kI00Co0000ojb^fOnY[mcoZJoL0_n^^^85ojbih`;o
Z[[U0_n]`NT4ojc1j@03ojc5k?n[`n_oZl?[00?oZl?[4oooool2o`0001kooooo000Kooooo`05oa0@
4?ooooooooooooooool@41001_ooool2o`0000;ooooo1OnN_Nh2oig9mP?o[lc_00?o[]Oeok_Ck?nk
dn`00_nkdn`3ol3:hP?o`LgS0_o0`M/4oknofP03okR_d?neZ/go]J[=00;o]J[=0oncYLX00onZVLGo
Yi?1ojNC`@03ojNC`@?oY8jm1?nQRKX3oin5]`;oWH6e0_nFN[83oiEg/0CoU7F^0onCLj`4oi9bZ`?o
TW2Y1?nAKjP4oi5^Y`?oTVjV0onCKZD5oiA^Y0?o00001?nKNZd3oi]k[PGoVW^`0_nIOK<2okFig0Co
/l;U00Co0000oi9WWOnBIigoTVNM0on@IYh00on>IYooTfNLoi=WW004oi=WW0_oTVNM1?nAIYd3oi1U
W0CoSVBL0on>Hi`5oi1UW0?oTfRM0_nHK9h2ojN2[0CoZH:Z1OnUOJL4oj9iY@04oimfXongY/So]jK8
okNVb0Go]9Zm0onaTkL00onIKIkoUfjRoiM^XP02oiM^XPGoZh:Y1?nVPJ`00onQP[;o[8N]ojb7[@02
ojb7[@CoYhB_0onRQ;<00oncV;co[YFlojjE_002ojjE_0CoZIC100?o]JG9ojnPb?n_X<P00on_X<P3
oj^Ob`03okBceon`[mOo/:oG00?o/:oG0on/[]T00ol0003o[[[RojjjhP03ojjjhP;o[;WS0_n^`nT5
ojg1j@03ojc1jOn/aNco[<G/00;o[<G/0on[`n/00onZ`ncoooooooooo`0@ooooo`03o`000?oooooo
000001kooooo000Kooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02
ooooo`;oW[g^0on^`NP3ojo<k`Co^/_W00?o^m?/ol3:h_o0b^800oo0b^800oo1cN?o`<7Kol31f`02
ol31f`03oknof_nh[m3o^:o@00;o^:o@1?neZ/d01?ncYL[oZYW5ojZIaOnZVLD4ojNC`@CoY8jm0onQ
RKX2oin5]`03oiMm]?nFN[;oUWZb00;oUWZb1?nEMk03oiAe[PCoTg>/0onBLZ/3oi9`Z@CoTFnX1?nA
KZL3oi9^YP?oTfjU0_nDKZ@00onFN:oo0000o`000003oiUi[PCoVgZ]0onKNjh5oiYk/003oiUm/one
^Mco]KWL00;o]KWL00?o/l;Uo`000?nEJId01?nBIid2oi1VWP03oiAWW?nCIicoTfNL00KoTfNL2_nB
Iid4oi5VW@?oT6FL1?n>I9`3ohiSW0GoT6FL0onCJ9d00onHK9koYh:/ojN2[002ojN2[0?oZH:Z1OnU
OJL3oj9iY@03ok^lf_ngY/So]jK800;o]jK81OndV[d00onaTkOoVFfNoiU]WP02oiU]WP?oUfjR1On[
PZT4ojJ1[0Go[8N]1?nWQ:l00onRQ;?o/iRlok>H_002ok>H_0Co[YFl00?oZIC1okFUbOneYLT00_ne
YLT4ojnPb003oj^Obond/mOo];?G00;o];?G1?n`[mL01On/[]Wo/KkSok6nhona_^?o000000?o[[[R
0_n_an/4ojk3j@;o[L7Y0on/and4ojc5k003oj_3jonZ`ncoZ/?/00;oZ/?/5?ooool00ol0003ooooo
ooooo`0Kooooo`006oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
0oooool5ojk1j003ojo<konjbnOo^/_W00?o^/_W00?o_lOPol3:h_o0b^800_o0b^82ol32f`?o`<7K
0_nj]=<4okR_d0?o]J[=00?o[Io9ojZIaOnZVLD00_nZVLD4ojNC`@CoY8jm0_nQRKX01?nIPKOoUgfd
oiMm]?nGOK@4oiIj/PCoUGN`0onDMJh4oi=c[0?oTW:[1?nBL:T3oi5_Z0CoTFjW0onBKZH2oi=^Y@05
oi=g/?l0003o0000o`000?nFN:l01?nINJh4oi]j[@CoVg^^0onJNk000onf]MSo]KWLokFig003okFi
g0?oUFVM0onBIid01?nDJ9coU6NLoiAWW?nDIi`8oi=WW0[oTVNM1?nAIYd3oi1UW0CoSVBL1?n>Hi`4
oi1UW0;oTfRM00?oXWf[ojN2[?nWPZ`00onWPZ`3ojV2ZPGoYGfW00?oXWVUok^lf_nk_=X00_nk_=X3
okNVb0Co]9Zm00?oW6jLoiU]W_nIKIh00onIKIh2oiM^XP;o/HNX1?n[PZT4ojJ1[0Go[8N]1?nWQ:l5
ok>H_0Co[YFl1OneYLT3ojnPb003okZkfond/mOo];?G00?o];?G0on`[mL2okG5iP?o/KkS00?o0000
ojjjh_n_an/01?n_an/2ojk3j@;o[<_`1On/and2ojc5k0;oZ/G]0onZ`n`00onX`^coooooooooo`0C
ooooo`03o`000?oooooooooo01[ooooo000Kooooo`05oa0@4?ooooooooooooooool@41001Oooool0
0ol0003oooooooooo`05ooooo`?o[/7X0onh`n83ok[;i`?o_lOP00?o`<[Rol32foo0`]/00oo0`]/0
0oo0`M_o^[CCokZdd`02okZdd`Co^:o@00Co]J[=ojfObOn]WlWo[Io90onZVLD5ojNC`@;oY8jm00?o
VhFkoiV1]onIPKL00_nIPKL3oiMm]0CoUWZb0onEMk03oiAe[PCoTg>/1?nBLZ/3oi9`Z@?oTFnX0_nA
KZL2oi1f/P?oTGJa0ol00005oiIh[`?oVGV^1?nKNZd4oi]k[P03oiYk/?nf]MSo][GH00;o][GH0one
^M`01OnGK9ooUFVMoiEYWOnEJIgoTVNM00?oU6RL0onDIi`8oi=WW0[oTVNM1?nAIYd4oi1UW0CoSVBL
0on>Hi`4oi1UW003oi=XWOnROJ_oXWf[00GoYh:/1?nYPZX3ojEmY`03okoVlOnk_=[o^kcJ00?o^kcJ
1?ngY/P01?ndV[goW6jLoia^W?nLKY`5oiU]WP04oiM^X_naQjSo/HNXok67Z0GoZh:Y0_nVPJ`2okB?
[`Co[8N]1?nWQ:l00onkXKko/iRlok>H_002ok>H_0?o[YFl0_nn/Lh5okFUb@04ojnPb?nj^m_o^[_K
okZkf`Go];?G00?o/:oGokG5i_neaNH00_neaNH2ok6nh`03ojo=kol0003o[lO[00?o[lO[00?oZm3c
ojc;l?n/bo000on/bo02ojc7k@;oZLS_1OnZaNd01?nZ`ncoZ<;/ojS2k?nX`^`Dooooo`03o`000?oo
oooooooo01[ooooo000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000Oooooo00?o
[/7XokS3h_nh`n800onh`n800onjbnOo_lOPoko7h002oko7h003ol73g?o0`]_o`<;K00?o`<;K1_nj
]=<2okR_d003ok2UcOn]WlWo[Io900;o[Io91?nZVLD2ojNC`@;oWXZn1?nKQK/3oiV1]`?oUgfd1?nF
N[83oiEg/0CoU7F^0onCLj`4oi9bZ`?oTW2Y0_nAKjP5oi1f/P?o00001?nCMk04oiIh[`?oVGV^1OnK
NZd2oi]k[POo][GH00?o]KWLoiM/WonGK9l00_nEJId00onCJ9goU6RLoiAXW002oiAXW0CoU6NL1onC
Ii`;oi9WW@?oTFJM1?n@II`4ohiTW0?oSV>L0on@II`00onJMZWoXWf[oj9mZ`02oj9mZ`CoYh:/1?nY
PZX2ojEmY`?o_nKa1Onk_=X2okNVb0;oXW:M1?nLKY`4oiU]WPCo/HNX1On[PZT01?nVPJco]8n_okB?
[ondSjl5ojb7[@;oYhB_0_nkXKh5ok>H_004ojjE_?nn/Lko_[7>okjacPCo]JG900?o_L_TokZkfonj
^m/00onj^m/2okBce`;o]m7^1?neaNH00on^eOCo[lg_ojo=k`02ojo=k`03o`000?n_an_oZm3c00?o
Zm3c0_n/bo02ojS:lPGoZLS_0_nZaNd2ojS4kPGoZ<;/5?ooool00ol0003oooooooooo`0Iooooo`00
6oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool01oooool4okS3hP;o
_/CN0onoan03ol73g0?o`<;K0_nl^ML4okZdd`03ok>/dOn`YLgo/:G=00;o/:G=1?n]WlT2ojZIa@03
oj6@`onNR[koWXZn00?oWXZn0onKQK/3oiV1]`?oUgfd1?nFN[84oiEg/0?oU7F^0onCLj`2oi9bZ`;o
T7Nc0on@Mk84oi1f/P?o00001?nAM[43oi=g/0CoUWR_0onINJh5oi]j[@03oi]k[_nf]MSo][GH00Go
][GH0_nGK9l2oi5WWP?oTfRM1?nDJ9`4oiAWW0OoTfNL2onBIid3oi5VW@CoT6FL1?n>I9`3ohiSW004
oi1UW?nJMZWoVWJYoiYfZ@CoXWf[1?nWPZ`4ojV2ZP03ojEmYonoi_7o_nKa00?o_nKa0_nk_=X2ojam
X@CoXW:M1?nLKY`3oiU]WP03okJ=ZonaQjSo/HNX00;o/HNX1On[PZT4okB?[`Go[8N]00CoYhB_ok^Q
__nkXKko^j6n1?ncV;`00oo8b]co_[7>okjacP03okjacP03okFUbOnmbnCo_L_T00;o_L_T0onj^m/2
ok?Sm`Co]m7^00?o]LGVojkEm?n^eO@00_n^eO@2ojo=k`;oYmGh00Co0000ojOEn?n[d??oZm3c0_nU
cO@4ojS:lP;oZLS_0onWa^l4ojS4kP;oZ<;/0_nV`>`Dooooo`03o`000?oooooooooo01Wooooo000U
ooooo`03o`000?oooooooooo00Sooooo00?o^<?Rokk4g_nna=h00onna=h00onoan3o`L?Lol73g003
ol73g003ol32fonl^MOo_;WG00;o_;WG00?o^[CCok>/dOnc[=400_nc[=43ok2Uc@?o[Io900?oY9O7
oj6@`onQT<<00_nQT<<4oij:_P?oVhFk1?nIPKL3oiMm]0?oUWZb1?nEMk02oiAe[P04oi1i]On@N;Co
T7Rdoi1h]0CoT7Nc0on@Mk801?n@M[;o0000o`000?l00003oi1f/PCoTGJa0onCMk04oiIh[`CoVGV^
0onKNZd00on`]]go][GHokJef004okJef003oiQ^X_n=IJ3oTFNN00?oTFNN0onCJ9d4oiAXW0CoU6NL
1onCIi`;oi9WW@?oTFJM1?n@II`4ohiTW0;oSV>L00?oTfjVoiYfZOnJMZT00onJMZT3oj9mZ`GoYh:/
0_nYPZX3oh?W`0;o_nKa0_nXNj84ojamX@CoXW:M1?nLKY`2oiU]WP?o]Xf[0onaQjP4oj^2Z@;o`J:i
0ondSjl4ojb7[@03olFcbOnkXKko^j6n00?o^j6n0_ncV;`3olS:g0?o_[7>0_nki?<4okg;i003okZk
fonchoOo/n?g00?o/n?g0_ngdNh3ojGNn`;o[]Gd0onNf_`2ojOEn003o`000?nQc_SoYLgd00CoYLgd
0_nXb_82ojG7l@GoYlK_0_nXa>h2ojK1k@CoY/3/4_ooool00ol0003oooooo`00000Jooooo`009Ooo
ool00ol0003oooooooooo`0:ooooo`?o_/CN0_o1a=`4ol73g0;o_[kJ0onl^ML00onf/mKo/jcAok>/
d@03ok>/d@Co/:G=00Co[Io9ojBGaonTUlOoY9O70onQT<<4oij:_PCoVhFk0onIPKL3oiMm]0;oUWZb
00?oTGbhoi5j]onAN[L00_nAN[L3oi1i]@?oT7Rd1?n@Mk<01?n@Mk;o0000o`000?l00007oi1f/P?o
TGJa0onCMk05oiIh[`?oVGV^00?oVgZ]ok2fgOn`]]d00_n`]]d3okJef004ohUTXOn=IJ3oSFFPoheU
X0CoTFNN0onCJ9d4oiAXW0CoU6NL1onCIi`;oi9WW@?oTFJM0_n@II`2ohiWXPCoSfZS0onCKZH5oiYf
Z@?oXWf[1OnWPZ`00onYPZ[oZ7VPojQiX002ojQiX0CoZ7^R1?n/OJ44oj9bW@CoW6jL00?oVFfNokJ=
ZonfSJ/00_nfSJ/4ok67Z0;oZh:Y0oo1X[T4okB?[`;o[8N]0oo5/lT4ok^Q_P03ok>H_?o8b]cob<[L
00?ob<[L00?o_[7>ok_Tlonki?<00_nki?<2okg;i0?oT^cd0_nchoL3ohgRo0;oYMkk0on@fol2oikJ
o0;oV/kj0onQc_P01?l0003oXLkhojG=m?nUcO@2oj;7lPGoYLOa0_nWa^l2ojG1k@GoY/7]0_nV`>`2
ojJok1Cooooo00?o0000ooooooooool05oooool002Gooooo0_l0000<ooooo`03okk4g_o1a=co`LCL
00;o`LCL00?o`L?Lokjnf_nn_]X00onn_]X01?nl^MOo][?FokJce_nf/mH5ok>/d@;o/:G=00?oYik<
ojBGaonTUlL00_nTUlL3oj6@``GoWXZn0onKQK/2oiV1]`04oi>1_OnBO[[oTWjjoi9n^P?oTGbh1?nA
N[L4oi1i]@?oT7Rd0_n@Mk<2o`0000?oT7Nb1on@M[84oi5f/@?oTgN`1?nFN:l2oiUi[P;oZ;ST1On`
]]d00onf]MSoRFBQohUTX@03oheUX0CoTFNN1?nCJ9d3oiAXW0CoU6NL2?nCIi`9oi9WW@04oi5XX?n?
Ij7oSfNQohmWX@CoSVNR1?n?JZ<4oi=^YPCoVWJY1?nROJ/3ojN2[0;oYGNO1?nXNJ03ojQkXP03okfD
[?n/OJ7o[7fQ00;o[7fQ1OnRLYd3oia^W0Go]Xf[1?naQjP00on[PZWo`J:iol6R^@02ol6R^@Co]8n_
00?o[8N]olFcbOo5/lT00_o5/lT3ok^Q_P;oa?S/1?o8b]`2ohCYi`;o^nCc0old^K82oi;/m0?oHMC_
0_n=h_`4og_EoP;oT=_o0_nCb_X4oi[>nP;oXLkh00?oWlGco`000?nOaO<01?nRao82ojG7l@;oY<7^
1OnU`Nd2ojK1k@;oYKk/1OnV_n`Cooooo`03o`000?oooooooooo01Oooooo000Tooooo`03o`000?oo
oooooooo00gooooo0oo1a=`3ol34g@?o_[kJ00?o^K_KokJce_nf/mH00_nf/mH4ok>/d@03oj^Vd_nW
W/coYik<00;oYik<0onTUlL4oj6@``CoWXZn0_nKQK/01?nDQL3oTh6moi>1_OnCPKd4oi9n^P?oTGbh
0onAN[L4oi1i]@;oT7Rd0ol00002oi1g/`?oT7Nb1on@M[84oi5f/@?oTgN`0_nFN:l3oiffjPCoZ;ST
0_n`]]d2ohUUX`?oRFBQ1?n=IJ03oi5WWPCoTfRM1?nDJ9`3oiAWW0SoTfNL1OnBIid2oi=ZX0?oTFRP
0on?Ij44ohiWXPCoSfZS1?nCKZH4oiYfZ@CoXWf[00?oYh:/ojEgWonUMil00_nUMil4ojQiX0;oZ7^R
0onmU:`3ojamX@GoXW:M0onLKY`5okJ=Z`Co/HNX1_o1X[T2okB?[`03om3Mh_o5/lWoaK?900CoaK?9
00?o^j6nolChk?o4n>`00_o4n>`01?o8b]coQ>WWohCYionBV=H5oh>[kPCoL;_m1?m_bol2og_EoP;o
S/;h1OnCb_X2oi[>nP;oW<7b0onOaO<01?l0003oWlGcoj;7l_nRao82oj:ok@CoY<7^0_nU`Nd3ojFm
j`CoYKk/0_nV_n`2ojJnjaCooooo00?o0000ooooooooool05_ooool002Cooooo00?o0000oooooooo
ool03_ooool00oo1a=co`<CMol34g@03ol34g@04okjnf_ni^m_o^K_KokVkf`Co][?F00?o/jcAoj^V
d_n[Y]800_n[Y]83ojNNc0CoY9O70_nQT<<00onHSlSoUXW4oiJ9a002oiJ9a0CoU8G00onCPKd3oi9n
^P?oTGbh1?nAN[L2oi1i]@?o000000?oT7Rdoi1g/on@Mk<00_n@Mk<4oi1g/PKoT7Jb0_nAM[42oi:[
i`CoTk3[1OnM]^X2ojRhi0;oRfNT0on9IJ<4ohUTX@?oSFFP0onAIih4oi=XW@CoU6RL0onDIi`8oi=W
W0;oTVNM00?oUVbQoi=ZX?nCJZ000_nCJZ03oi5XX0?oSfNQ1On>Ij83ohmZX`CoTfjV1?nJMZT4oj9m
Z`;oXGBO0onUMil4ojQiX003ojQkX_nmU:co_IB/00;o_IB/0on/OJ45oj9bW@;oW6jL0_nmVK<5okJ=
Z`;o/HNX0_oQgm85ol6R^@04okB?[oo@gN;od=gRom3MhPCoaK?90onGU<h2ogVTk@;oWi341?nBV=H5
oh>[kP;oL;_m0_nGZn@4oi6hl@CoS/;h0_nCb_X2oi^jkPGoW<7b0_nOaO<00ol0003oX[c/oj:ok@04
oj:ok@;oY<7^0_nT_>X5ojFmj`;oYKk/0_nU_N/4ojJnjaCooooo00?o0000ooooooooool05Oooool0
02Cooooo0ol0000?ooooo`Co`<CM00?o^lCPokVkfoni^m/00oni^m/2okJceP;o[ZkH1?n[Y]84ojNN
c0;oY9O700?oViC<oiR?b?nHSlP00_nHSlP3oiJ9a0CoU8G00onCPKd3oi9n^P?oTGbh0onAN[L3o`00
00;oT7Ve0on@N;@3oi1g/`CoT7Nb0_n@M[800onCWmcoTZCQoi:Th@02oi:Th@CoTZ_W1?nC/>/2oiff
jP?oSV^V0on;Ij@3ohUUX`CoRFBQ0on=IJ03oi5WWPCoTfRM1?nDJ9`4oiAWW0OoTfNL00?oTVNMoiI/
XOnFK:401?nCJZ04oi5XX0?oSfNQ1?n>Ij83ohmZX`CoTfjV1OnJMZT2oj9mZ`?oXGBO0onUMil4ojQi
X0Go_IB/1?n/OJ44oj9bW@04oia^W?nmVK?o_IVcokfI/`Go]Xf[00Co/HNXon7Od_oQgm;ohMoB1?o1
X[T2ofGE/PCod=gR00?oaK?9ojJ>_?nGU<h00_nGU<h00on[T;[oWi34oin@a003oin@a0CoTYSF0_n3
Znh2oj2RePGoUj_T0_nA^?400onPZMgoW;7VoibaiP03oibaiPCoVk[^0_nL`O82oj6hj0?oX[c/00Co
0000oj:lk?nR_ngoX[o]0_nT^^P5ojBljP;oYKg[0_nV_>T5ojFmj`CoY[k[4_ooool2o`0000Wooooo
1?l000000ol@413oooooooooo`07ooooo`009?ooool00ol0003oooooooooo`0@ooooo`03ol34gOnk
a>3o^lCP00;o^lCP0oni^m/00ona^=ko[ZkHojj^f003ojj^f0CoZjKB0_nWW/`00onNVm7oViC<oi^D
c002oi^Dc0?oV8o81?nFRL@3oiB5`0?oTh6m1?nBO[X2oi5l^0?o000000?oTGZgoi1i]On@NKD00_n@
NKD3oi1h]0;oT7Nc00?oTYOEoi>Kf?nCVmP00_nCVmP4oi>Og0CoTZCQ1?nBZnL2oi>`j`?oTFnX0on>
JjH4oh]WY0?oRFFS0on9I:43oheUX0CoTFNN0onCJ9d4oiAXW0CoU6NL1_nCIi`01?nHKZ7oUVbQoiI/
XOnFK:44oi=ZX0CoTFRP0on?Ij44ohiWXPCoSfZS0onCKZH5oiYfZ@03oj9mZonQM9ooXGBO00;oXGBO
0onUMil4ojQiX0Go_IB/1?n/OJ43oj9bW@03olBbb?nmVK?o_IVc00;o_IVc1OnfSJ/00ol0003ohMoB
on7OdP02on7OdP03ol6R^OmUeK;oIMFb00?oIMFb0_o@gN84ojJ>_004oiNDc_n[T;[oZi2joj^@^PGo
Wi340_nBV=H00onYW<WoX:;Foj2ReP03oj2ReP;oUj_T0_nUXm<4oj2Yg@GoW;7V0_nK^^h2oj>ci0Co
XKSX0_nR_>`00onU]nKo0000ojFgiP04ojBjj0;oY;cZ0_nV^nP5ojJlj@;oYKg[0_nV_NX5ojJnja?o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`002Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`0Booooo`Co
^lCP00Co^K_Kok6hg_na^=ko/KSN1On^[]P2oj^VdP03oj6SeonNVm7oWY_A00;oWY_A0onKU<`3oiR?
b0CoUXW41?nDQL03oi>1_@;oTWjj0ol000001?nAO;SoTGZgoi5j]onAN[L2oi1i]@;oSi7A0on@U=<4
oi:Ge@CoTi_H1?nCWm`4oi:Th@;oTZ_W0onDM:`3oi5_Z0?oSV^V1?n;Ij@3ohUUX`?oRFBQ0on=IJ04
oi5WWP?oTfRM1?nDJ9`4oiAWW0CoTfNL0onHKZ44oiI/X@?oTfZP1?nAJ:03ohmWX@CoSVNR1?n?JZ<4
oi=^YP?oVWJY00?oWW:Poj5dWonQM9l00onQM9l4ojEgW`;oZ7VP0_oWf<H4okfD[0Co[7fQ0_nRLYd3
olBbb0?o_IVc1?nfSJ/2ok27ZP03o`000?oQgm;ohMoB00CoXWn]1OnbTK<3ojJ>_003okFF]on[T;[o
Zi2j00;oZi2j1?nOT<@00onaWL;oZIc9ojVLb@02ojVLb@?oX:;F00?o[:7<ojFSdonUXm<00onUXm<4
oj2Yg@;oW;7V0_nU[]h5oj>ci0;oXKSX0_nU/n<2ojFgiP03o`000?nU]nKoYKOV00;oY;[X0_nV^NH4
ojJkj0;oY[cY0_nW_>T5ojJmjP;oY[k[0_nW_n/Dooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02Oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool04oooool2ok_4h0;o/l;U1?na
^=h2ojj^f0;oXjcM1?nQXmL3oijKd@?oViC<1?nHSlP3oiJ9a0CoU8G00_nCPKd3o`000004ohb>d?n=
S]3oSHk@ohf>d0?oSXo@1On?TM43oi2Dd`?oTYOE1OnCVmP2oi>Og003obbd/_nLPKGoW86e00CoUgZ`
0onDM:`4oi5_Z0?oSV^V0on;Ij@3ohUUX`?oRFBQ0on=IJ04oi5WWP?oTfRM1?nDJ9`4oiAWW0;oTfNL
00?oVW6SoiQ^XOnHKZ400_nHKZ44oiI/X@?oTfZP1?nAJ:03ohmWX@CoSVNR1?n?JZ<4oi=^YP03oiYf
ZOnNLZ3oWW:P00;oWW:P1?nQM9l4ojEgW`04ojQiX?oWf<KoimS6onOHaPGo_IB/0on/OJ400onRLYgo
a;;8olBbb002olBbb0Co_IVc0_nfSJ/00onYQZoo/8NZok27ZP03ok27ZPCoXWn]00?o^IJcok:A/onb
TK<00_nbTK<2ojJ>_0?o]IJg1?n[T;X01?nOT<Co/Ig2ok6M`_naWL85ojVLb@04oj2Re_n/XLco[:7<
ojbQc0CoYJ?C0_nPZMd3ojZ/f0CoYJkN0_nS/n@2ojRag`GoYK?S0_nU]nH00ol0003oZ;SUojJiiP04
ojJiiP;oY[_X0_nW^nL4ojNlj@;oY[gZ0onX_^X4ojNoja?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`09ooooo`002Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RH
ob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0Eooooo`Co/l;U0_na^=h2ojFei0CoXjcM0onQXmL4
oijKd@?oViC<0_nHSlP01?n?U]KoSY?CohjCdon>Tm<4ohf@dP;o000000?oSHo@ohb>d?n<S]000_n<
S]03ohf>d0?oSXo@1?n?TM43oi2Dd`CoTYOE0_nCVmP3odO8e0;oXHVk0onLPKD3oiMj/0CoU7B/0onA
KjP3ohi[YP?oRfNT0on9IJ<3ohUTX@?oSFFP1?nAIih4oi=XW@?oU6RL0onDIi`01?nJLjKoVW6SoiYa
XonJLJ<4oiQ^X@CoUVbQ1?nCJZ03oi5XX0?oSfNQ1?n>Ij84ohmZX`?oTfjV0_nJKj44oiibX0CoXGBO
1?nUMil01?nXNJ3oimS6onOHa_oWf<H5okfD[0;o[7fQ00?oZ^gholBbb?o4//P00oo4//P4okfI/`04
okJ=ZonYQZoo^Y:^okZB[PGo/8NZ0_nROjd2okVF/`Co/Y6c00?oYXjlokFF]oneU[L00_neU[L4oj^@
^PGo/Ig20onYW<T00oneYLSo[:7<ojbQc002ojbQc0?oYJ?C00?o/:_CojZ/f?nZ[=P01?nZ[=P2ojF^
gP03oj^`fonX/MooZ;7O00?oZ;7O0onU/n<01_nY]n;oZ;SUojRhiOnX^>Go0000ojRhi@?oY[WV00?o
Z;[VojNkionW^nL00onW^nL2ojNlj@;oZ;kY1OnX_^X2ojNoj`;oZ<3[4oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP05ooooo`?o00005_ooool2ok?2i@?oY[o/0onU]N@4oj>/g@?oXJ?G0_nN
Vm401?nBX=goTI_Ioi6KfOnAVmT4ohnFeP?oSY?C0ol000001?n=T=;oSHo@ohf?d?n=Sm03ohb>d0?o
SHk@1?n>Sm04ohnAd@?oT9CC0_nBUmD3oe[Aj`;oYi?10onQRK/3oib1]@?oUgZ`1?nDM:`3oi5_Z0?o
SV^V0on;Ij@3ohUUX`CoRFBQ0on=IJ03oi5WWPCoTfRM0onDJ9`01?nDIicoVW>VoiYcY_nJLjH3oiYa
X`CoV6jQ1?nFK:44oi=ZX0?oTFRP0on?Ij45ohiWXP?oSfZS00?oTfjVoiY_XOnJKj400onJKj43oiib
X0CoXGBO1?nUMil00onXRkKo0000onOHaP02onOHaPCo_IB/00Co[7fQoj[]n?nZkOSoZ^gh1Oo4//P2
okfI/`03ok28ZonYQZoo^Y:^00;o^Y:^1On`QjX01?nROjgo^IJcokVF/oniU[<4ok:A/`Go]IJg0on[
T;X2okfT`@Co/Ig200CoZIc9okFUb?neYLSo]JG81On/XL`01?nUXm?o/:_Cok2[don`Zm<4ojZ/f003
ojnafOn[/=_oZk3K00;oZk3K1?nX/Ml00onU/n?oZKORojVghP02ojVghP?oZ;SU00?o0000ojJii_nX
^^H00onX^^H3ojNki`03ojVmj?nX_^WoZ;kY00?oZ;kY0_nX_^X2ojRojPGoZ<3[4Oooool3o`0000Oo
oooo00?o0000ooooooooool02Oooool000Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool06?ooool4ojJok0?oYKGT0_nS[=d01?nF[NKo
U:KRoiBVh_nDY^84oi:Pg@?oTI_I0on?U]H3o`000004ohjCdon=T=;oSI3Bohf@dP?oSHo@1?n<S]03
ohf>d0CoSXo@0_n?TM43og;>o`;oJ=;i0on]WLL2ojNC`@04oiEh/On@LZgoT7:]oi1b[@?oSFfZ0on:
JJL4ohUWY@?oR6JT0on7IJ@3ohITY0?oRFFS1?n9I:43oheUX0?oTFNN1?nCJ9d2oiAXW003oiUfZOnJ
LjKoVW>V00;oVW>V1?nJLJ<3oiQ^X@CoUVbQ1?nCJZ03oi5XX0CoSfNQ1?n>Ij82ohmZX`;oV6jQ1OnJ
Kj43oiibX0GoXGBO0onUMil5ojf4Z@;o_IB/00CoZ7fTojAhXonTN:?oY7RS0_nZkOP5olBbb003okfI
/on`R:_o/8R[00Co^Y:^1On`QjX5okVF/`;o/Y6c0_o5Yk`5okFF]`04oj^@^_nmY<7o_JC1okfT`@?o
/Ig200?o_Jk;okFUb?neYLP00oneYLP3ojbQc003okF_d_n`Zm?o/:_C00?o/:_C00?oZZcHojnafOn_
/MT00_n_/MT4oj^`f`;oZ;7O0_n/]n44ojVghP;oZ;SU00?oZ[[Uo`000?nZ^^D01?nX^^H00onW^nOo
ZKgXojVmj002ojVmj0?oZ;kY00?oZKoZojRoj_nX_nX00onX_nX2ojS0j`;oZL7[3_ooool4o`000003
ooooool0003ooooo00Kooooo00?o0000ooooooooool02Oooool000Wooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06Oooool2ojJok003
oiJklOnF]>coU[C/00;oU[C/0onF[NH3oiBVhP?oTZ3M0onAVmT3o`000003ohnFe_n>Tm?oSY?C00;o
SY?C0on=T=83ohf?d0;oS8k@0_mo]oP5ogbno0?oNLKo0_mbc_l3ok:Wc@;o[Ig700CoVGneoiEh/OnE
N;7oUGRa0on@LZd3ohe]ZP?oRVVW1?n9IjD3ohQVY0?oQfFT0on6I:@3oh=TYP?oPFFY00CoRFBQoheU
X?n=IJ3oSFFP0onAIih4oi=XW@03oiAXW?nIMZWoVGJY00CoVW>V1?nJLJ<4oiQ^X@?oUVbQ1?nCJZ04
oi5XX0?oSfNQ1?n>Ij800on?JZ?oV6jQoiQ^X@02oiQ^X@CoVVnQ0onNLZ05oj5dW`;oYGNO00?o/8b`
ojf4ZOn]Q:T00on]Q:T4ojQmY0?oY7RS0_ncS:`2olBbb003ok><[?n`R:_o/8R[00;o/8R[1?njTZh4
ok27ZP;o`jFk1?niU[<01?nbTK?oaJNlolFW_?o5Yk`4okFF]`03olBbb?nmY<7o_JC100?o_JC100Co
/Ig2okf^bonm[/_o_Jk;1?neYLP00on/XLco]JoBokF_dP02okF_dP?o/:_C00?o]KOJojnafOn_/MT0
0on_/MT2oj^`f`;o[kWP1On/]n42ojVghP;o[;_U0onZ^^D01?l0003oZ[[UojRji_nX^^H2ojZnj0Co
ZKgX00?oZ;kYojVoj_nY_nX00_nY_nX2ojRojPOoZL7[2_ooool3o`0000Gooooo00?o0000oooooooo
ool00oooool00omEEEGoIVIVo`00000;ooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`;o00006oooool3oiJkl@CoU[C/0onF[NH3oiBV
hP;oTZ3M0ol00002ohBYk@?oPjW^1?n2Znl3oh6]l@?oP;7d1?mo]oP2ogbno003okZif?ng/=?o]k3C
00?o]k3C0_nbYld2oin7^P?oVGne1?nEN;43oi1b[@?oSFfZ0on:JJL3ohUWY@?oR6JT0on7IJ@3ohIT
Y0?oPfBV1?n1IJT3ohAY[@?oRg2^1?nCM:d4oiUfZ@?oVW>V1?nJLJ<4oiQ^X@?oUVbQ1?nCJZ04oi5X
X0?oSfNQ0_n>Ij83oiI]X@CoV6jQ1?nJKj43oiibX0GoXGBO00CoYGNOok2</?n`S;3o/8b`1?n]Q:T4
ojQmY0;oY7RS0_nfU;<5ok><[0;o/8R[0_o:[;/4okZB[P;o/8NZ0oo3YK/4okVF/`CoaJNl0oneU[L2
olBbb0Co_JC100?obLGGokf^bonm[//00_nm[//3okFUb003okfieOne[m;o]JoB00Co]JoB00Co/:_C
okFgf_ne]m[o]KOJ0on_/MT00onb_>;o[kWPojnih003ojnih0;o[;OQ0_n^_ND5ojbki@;oZ[[U00?o
ZkkXo`000?nZ_^P01?nZ_^P2ojVmj0;oZL3Z0onY_nX8ojW1j`;oZ<7[1_ooool4o`0000Sooooo00?o
0000ooooooooool04Oooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`0Kooooo`?oU[_a0_nF]>`00on8/o;oQk3`
ohN`l002ohN`l004ohN]kol0003o0000o`0000;oQJ_^1?n4ZNd3oh>YkPCoPZ__0on1[O43oh2am0;o
OkOh00?o`N?`ol?Tkonj^MP00_nj^MP3okN`d`03ojB@_onOQk[oWhNj00;oWhNj0onIOkD4oiEh/@?o
T7:]0on=KJX3ohYYY`?oRFNU0on8IZ@4ohMUY0?oQVBT0on3I:H3oh5UZ@?oQ6V]0on;L:h4oi=d[@Co
VGJY0onJLjH4oiYaX`CoV6jQ1?nFK:43oi=ZX0CoTFRP0_n?Ij42oiA/X@GoUVfQ0onHKZ44oiY_X@Co
WW:P0onQM9l00onaU[[o/8b`ok2</002ok2</0Go[HBY0onXOJ@01?nTN:?o]YBcokJD/onfU;<5ok><
[004ok28Zoo:[;_obZbkolZ/^`Co^Y:^00?o/8NZol>U^oo3YK/00_o3YK/4okVF/`03om;7coo5Ykco
aJNl00;oaJNl00?o]IJgolBbb?o4//P00_o4//P2okfT`@?obLGG1?nm[//01?neYLSo_KWEokfieOnm
^MD4okF_dP03okW0gone]m[o]KOJ00?o]KOJ00Co[k7Iok:lh_nb_>;o/[cR0on_^N000on``NOo[[gU
ojjmi@03ojjmi@;o[;_U0_n/`>T3oj^nj004o`000?n[_^SoZ[kXojZnj0;oZ/7Z1OnY`>X00onY_n[o
ZL7[ojW1j`06ojW1j`CoZ<7[0_ooool3o`0000cooooo00?o0000ooooooooool04Oooool002;ooooo
00?o0000ooooooooool07Oooool3ohRfm0?oR;?b00CoQk3`o`000?l0003o00000on7[Nl3ohF[kPCo
Q:W]0on3ZNh2oh:[k`;oBL?_0_l000000onElNWo`N?`ol7Sl002ol7Sl0;o_;oL1?nj^MP01?ng/=?o
Y92oojB@_onTT;l3oin7^PCoVGne0onEN;43oi1b[@?oSFfZ0on:JJL3ohUWY@?oR6JT1?n7IJ@3ohIT
Y0?oPfBV0on1IJT4ohAY[@?oRg2^1?nCM:d3oiUfZ@CoVW>V0onJLJ<4oiQ^X@CoUVbQ0onCJZ02oi5X
X0?oTf^Q1?nDK:44oiI]X@?oV6jQ1?nJKj44oiibX0;oXGBO0onaU[X3ok2</0Go[HBY0_nXOJ@00oni
X/;o]YBcokJD/`02okJD/`Go/hb/1?o:[;/4okZB[PKo`jFk0_niU[<2om;7c`CoaJNl1Oo4//P00onm
Y<7obLGGolW5e`02olW5e`?o_Jk;0_o0b>44okfie@03okF_d_ni`=oo^L3O00;o^L3O0_ne]mX2okG4
iPGo/[cR00Co[kWPok31ion``NOo/<7W0on^_ND2ojc3jPCo[<3Y0_n[_^P00onZ`^_o0000oj[2j`04
oj[1jP;oZL3Z0_nY`^/4ojW1j`03ojW2k?nY`N_oZL7[00?oZL7[1?nX`N/00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo01kooooo0on8]_@00on8
/o;o0000o`000002ohN`l0?oNkWj0omf_?`4ofnooP?oIl;n0_mJa?X2od33eP;oWNod1?nmh?400oo1
ho3o_;oLokbog002okbog0;o^[WH00?oZIS5ojB@_onTT;l00_nTT;l4oin7^P?oVGne0onEN;43oi1b
[@?oSFfZ0on:JJL4ohUWY@?oR6JT0on7IJ@3ohITY0?oPfBV0on1IJT4ohAY[@?oRg2^1?nCM:d3oiUf
Z@CoVW>V1?nJLJ<3oiQ^X@CoUVbQ0_nCJZ02oi1YX@GoTf^Q0onDK:44oiI]X@?oV6jQ1?nJKj44oiib
X003oj5dWonaU[[o/IJj00;o/IJj0on`S;05ojf4Z@04ojQmY?niX/;o^J;2okVR`P?o]YBc1?ncS:`0
0ooKiMcobZbkolZ/^`03olZ/^`;o^Y:^0_o<aM@5ol>U^`04okVF/ooBalood/O?om;7c`?oaJNl0_o;
e>03olBbb0;o`nW`1Oo9aML00onm[/_o`<SQol38h@02ol38h@;o_KWE0_nkdNX3okW0g`;o//k^1?ne
a>H2ok:lhP;o/<O[1On``NL00on^_NGo[<?Zojc3jP02ojc3jP;o[<3Y0_n[a>`3oj[2j`04o`000?nZ
`^_oZ/7Zoj[1jP;oZL?/1?nY`^/00onY`N_oZL;/ojW2k002ojW2k0;oZL7[0_nX`N`5ojS1ja3ooooo
00?o0000ooooooooool04?ooool002;ooooo0_l0000Pooooo`?o00001Omo]_L3og^inP?oM[cl0_m_
_oh3ofW>o0;oElg_0onRjO/00onMkoCo_N3aokgPl@02okgPl@;o_<?O0onl_m`00on^XL[oZIS5ojVH
a@02ojVHa@?oY92o1?nOQkX3oiUo]@CoUGRa0_n@LZd3ohe]ZP?oRVVW1?n9IjD3ohQVY0?oQfFT0on6
I:@3oh=TYPCoPFFY0on4JJd3oh]`[PCoTgB]0onIMZT4oiYcYPCoVW6S0onHKZ42oiI/X@?oSFJP1?n@
JJ44oi=[X@?oU6bQ1?nFKJ43oiQ^X@GoVVnQ0onNLZ000onaWlKo/IJjok6F^P02ok6F^PCo/8b`0on]
Q:T00ong^mco^J;2okVR`P02okVR`PCo]YBc0_ncS:`3om_Ug0CobZbk00Co^Y:^olc5e?o<aMCoc<GD
1?o3YK/00on_n^;od/O?om;7c`03om;7c`03olFW_?o;e>3obmCP00;obmCP00?oa;;8ol?Yl?o3jO00
0_o3jO02olW5e`;o]N;f1?o0b>400on[h_[o^m7Zok_AjP03ok_AjP03okW0gonbc^ko//k^00;o//k^
0_nea>H2ojk?l@Co/<O[0_n``NL3ojc7k@;o[<?Z0_nZa^h5oj_4k0;oZ/;[00?oZLC]o`000?nY`n`0
1?nY`n`2ojW2j`;oZ<;/0onY`^`2ojS2k0CoZ<7/1?nX`N/@ooooo`03o`000?oooooooooo013ooooo
000Rooooo`03o`000?oooooooooo01cooooo0ol000001?ooooooP[Ceoh:dmOn2]?D2ognfm`?oQ;gi
1?mna?d2ogK:o`?oQMWo00?oMmgfoj;YnonRjO/00_nRjO/3ok[Ll@03okgPlOnl`moo_<?O00?o_<?O
00Co_;oLojjQb_n^XL[o[Z7:0onYV<D4ojB@_`?oWhNj0onIOkD4oiEh/@?oT7:]0on=KJX3ohYYY`?o
RFNU0on8IZ@3ohMUY0?oQVBT0on3I:H4oh5UZ@?oQ6V]0on;L:h4oi=d[@CoVGJY0onJLjH4oiYaX`;o
V6jQ0on8Hj04oheVX0?oT6VQ1?nCJj43oiA/X@CoUVfQ0onHKZ45oiY_X@;oWW:P0_naWlH5ok6F^P?o
/8b`00Co[HBYokNkg?ng^mco]k_L1?niX/84okJD/`03ok><[?oKiMcofnGL00;ofnGL0_o:[;/3ohg]
k0Coc<GD00?o`jFkojojh_n_n^800_n_n^82om;7c`?oRnc[0_o;e>04od;4`@;o`nW`0omXfNh3okGR
mP03ol38hOn[h_[oZn;j00;oZn;j0_nkdNX3ojKHn@;o//k^0_nTe?T5ojk?l@;o/<O[0_nYbo43ojc7
k@;oZ<Wa1?nZa^h2oj_4k0;oZ<G^0onYa>d01?l0003oZLC]ojW3k?nY`n`2ojS3k@GoZ<;/00?oZL;/
ojS2k?nX`^`00_nX`^`4ojS1k0CoZ<7[3oooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0
003oooooooooo`0Iooooo`?o00001_ooool3ohVgm0CoQ;gi0_mna?d3ohk@oP;oQMWo0onUh?/3okOF
l0;o^]ca0onlaN83okc3g`03ok6Ycon^XL[o[Z7:00;o[Z7:0onYV<D4ojB@_`?oWhNj0_nIOkD00on=
NKSoRGBfohUd]P02ohUd]P?oQG6d0on=KJX3ohYYY`?oRFNU0on8IZ@4ohMUY0?oQVBT0on3I:H3oh5U
Z@CoQ6V]0_n;L:h4oi=d[@CoVGJY0onJLjH3oiYaX`?oPenP0on8Hj04oheVX0?oT6VQ1?nCJj43oiA/
X@CoUVfQ1?nHKZ44oiY_X@04oiibX?naWlKo/Io6ok6OaPGo/IJj0_n`S;02ojONnPCo]k_L1?niX/82
okJD/`03ojfD_?nZU;ooZYBo00;ofnGL1?nSUlT00onaVl7oZIc8ohg]k002olc5e0?oW:;H00?o[Yk7
oinNdonOW]<00_nOW]<5ohFTj0?oC:Gh0_l>U=d2ofSIkP?o9:gI1?m/eoH2oj_RnP?oR=So0_nVf?T2
oi3DoPCoY=Ci0_n^co42oj?>mPGoZL_a00?o[<O]ojS9lOnXbO400_nXbO42oj[6kP;oYlK`1?nXaNh2
ojW4k@03ojO4k_l0003oZ<?]00CoZ<?]2?nX`^`00onW`NcoZ<7/ojS1k003ojS1k0;oZ<7[00?oYl3[
ooooooooool03Oooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0Foooo
o`?o00002_ooool3ohVgm0;oQ;gi0onCaOP2ohk@oPCoY]Gh00CoYN3kokOFl?nge_3o]mK`0_nka^<5
okc5hP04okc3gonaZLoo/JW?ok6Yc`Co[Z7:0onYV<D2ojB@_`04oiN6_onBOk_oTWnkoi9o^`?oSGVh
1?n9M;H3ohEa]0?oPfnd0on0KkH3ohUWY@?oR6JT1?n7IJ@3ohITY0?oPfBV0on1IJT4ohAY[@?oRg2^
1?nCM:d3oiUfZ@?oVW>V00?oVW6SogaKXOmlFj400on3Gj03ohQSX0CoSFJP0on@JJ44oi=[X@?oU6bQ
1OnFKJ43oiQ^X@?oVVnQ0_n/Y<l4ok6OaP;o/IJj0omWf^L4ojONnP?o]k_L0_niX/82ojRF``04ojFL
c?n]U;co[IBlojfD_0CoZYBo00CoXiO9ok6K`OnaVl7o/I_11OnYW<P01?nLX]So[Yk7ojjNaon^W/L4
oinNd`;oQJCX0_nTYMH5ohjYj0?oK:oh1?mD^?/3oe_4n`;oR=So0ommc?l4oi3DoP;oY=Ci0onJc_X3
oj?>mP;oZL_a0onTbo@2ojS9l@;oY<Ob1OnWa_02ojS5kP;oY/G_0onWa>h00ol0003oZ<?]ojS3k@02
ojO2k@KoZ<;/1?nW`N`2ojS1k0;oYl3/1?nW`>/>ooooo`03o`000?oooooooooo013ooooo000Roooo
o`;o00005?ooool3o`0000kooooo1?nF^o42oi?5n0CoY/Wb0_nVeOP3okG?k@03okOFl?nka^?o^lKS
00;o^lKS0_nlaN82okB`e0Co/JW?0on^XLX01?nRU/SoW8g3oib=`onLSL<4oiN6_`?oTWnk0on=NKP3
ohUd]P?oQG6d0on3Kk@3oh1_]P?oP76i0on2Mkh4ohMUY0?oQVBT0_n3I:H3ohRYjP04oeFnn_n=Ij;o
SFNRoheWXP;oQUnM0_n0FI/4oi=d[@;oVGJY00CoKU:QoeIC/_mhFJ;oN5VR0omlFj43oh=OX0CoR6>P
0on=IZ03oi1YX@CoTf^Q1?nDK:44oiI]X@?oV6jQ00?oVVnQojBQd_n/Y<l00on/Y<l2ok6OaP;o0000
0onSULL01?nRV<[oYY2nojJ@__nVT;h4ojRC_`?oZ9K300?o[Y>kojfD_?n]U;`00_n]U;`4ojZD_`Go
/I_10onYW<P00ondWl;o[Yk7ojjNa`02ojjNa`?oWikC00?o[j?<ojBUe_nTYMH00onTYMH2ohjYj0;o
Y:OH1?nDZnH4oh6dm@CoL[gm0_mmc?l2oh[1n@CoSLSl0_nJc_X2oiS7m`GoWL[g0_nTbo@2oj76l`Co
Y<Ob0_nWa_02ojG5l0GoY/G_0_nWa>h00onW`nko0000ojO2k@03ojO2k@;oZ<;/1OnW`N`7ojO0k0Co
Yl3[3Oooool00ol0003oooooooooo`0@ooooo`008Oooool2o`0001;ooooo0ol0000Booooo`;oU[_a
0_nV_n`4ojK9lP;o//SZ0onecnd2okW6i0?o^lKS00?o][KIokB`e?nd/=@00ond/=@4ok6Yc`04ojjQ
b_nRU/SoXYK8oj:Fb0?oW8g30onGQ[l3oi9o^`?oSGVh1?n9M;H2ohEa]0CoPfnd0on0KkH3oh1a^@;o
PWNn1?n7P/L4ohfBd`?oR:WZ00?oUG:YoheWX_n=Ij800_n=Ij83ohIOW@;oP5VK1?mhE9/2ofiBX@;o
EU>b00CoN5VRogaKXOmlFj7oO5^Q0on3Gj04ohQSX0?oSFJP0on@JJ45oi=[X@?oU6bQ1?nFKJ42oiQ^
X@?oY:7B0_n/Y<l2oj>HbPKoXiG700?oXhjnojJ@__nVT;h00_nVT;h4ojRC_`03ojRF`on^Tk_o[Y>k
00;o[Y>k0on]U;`3ojZD_`;o/i^o1?naVl401?nYW<So]9o2okBO`_ndWl85ojjNa`04oinNdon_Xlco
[j?<ojnSc0?oY:GF00?o/JO?ojBWf?nTYmP00onTYmP4oiB[iP;oPKCe0_nI/>L4ohfglPCoR/7i0_n=
b?`2oiC0m@CoV<Og0_nMb_L2oig4l`GoXLKc0_nTao82oj?4l0CoYLG`0_nVaNl2ojK3kP?oYl?^00?o
0000ojO3k_nW`^d00onW`^d3ojO1k0SoYl3/1onW`>/<ooooo`03o`000?oooooooooo013ooooo0007
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`03ooooo`03o`000?oooooooooo00oooooo0_l0000Fooooo`CoY[o/00?oY/Wbok;8j_nbb>X00onb
b>X00onecngo^LKTokW6i002okW6i004ok_6honf]]Wo][KIokJff@Go];3D0_naZLl00onVW/goXYK8
oj:Fb002oj:Fb0?oW8g30onGQ[l3oi9o^`?oSGVh1?n9M;H3ohEa]0?oPfnd0on0KkH3oh1a^@?oPWNn
1?n7P/L4ohfBd`04ohRYj_nELZWoUG:YoiEbZ@?oSFNR0on6Gid3oh1IV`?oN5BK0om^DZ42oeIC/PCo
O5^Q0_n3Gj04ohQSX0?oSFJP1?n@JJ44oi=[X@?oU6bQ0_nFKJ44oi^Dc0;oY:7B00?oYZ7@oj>Hb_nS
V<X00_nSV<X2oj>Ea`;oX8bo1?nSS[h3ojJ@_P?oZ9>o00?o[9>lojjC^on^Tk/00on^Tk/4ojfD_004
ojZD_oncVkoo/i^ook>K_`Co/I_11OndWl83ojjNa`03okRVaon_Xlco[j?<00?o[j?<00CoY:GFok6W
conaYloo/JO?1?nTYmP2oiB[iP;oYZgL1OnI/>L2ohfglP;oWK;W1?nG^Nl4oiC0m@;oV<Og0_nL`?44
oig4l`;oXLKc0_nQ`_05oj?4l0;oYLG`0_nU`^h4ojK3kP;oYl?^00?oY/7]o`000?nW`^d01?nW`^d0
0onW`NcoYl3/ojO0k004ojO0k0[oYl3[3Oooool00ol0003oooooooooo`0?ooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool03?ooool3o`0001Wooooo0_nV_n`4ok72i`;o//SZ0_nha>@3okW6i0;o]k_L1?nf]]T2
okB`e0;oZjKB1?nVW/d3oj:Fb0?oW8g31?nGQ[l3oi9o^`?oSGVh0on9M;H3ohEa]0?oPfnd0on0KkH3
oh1a^@?oPWNn1?n7P/L3ohfBd`;oOFJ^0_maG:/01?nELZWoSFNRoheWX_n=Ij83ohIOW@?oP5VK0omh
E9/3ofiBX@CoEU>b0_mlFj43oh=OX0?oR6>P1?n=IZ03oi1YX@CoTf^Q0_nDK:44oi23`@;oViC<00?o
C/ZlojJQd?nVXM000_nVXM02oj>HbP03oif;`?nPS;ooX8bo00;oX8bo1?nSS[h4ojJ@_P04ojRC_on/
Tkco[9>lojbC_0Co[Y>k0on]U;`00ondWL3o/i^ook>K_`02ok>K_`?o/I_10_niX/84okBO`P03ojjN
aonhY/Oo^:K700;o^:K70on_Xl`00ongZL_o/JO?ok6Wc`03ok6Wc`;oY:OH0_n_Zm@4ojJ]g0;oVK3W
0_nU[ml5oifbi`;oUkW_0_nQ]^P3oibkkPGoW<3a0_nMa?<2oj2ok`CoXL;`0_nSa?02ojC1kPGoYL;^
0_nV`nh5ojK1k@03o`000?nW`^goYl;]00GoYl3/0_nW_n/7ojO0j`;oYko[1?nW`>/<ooooo`03o`00
0?oooooooooo00oooooo0007ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo
0_l0000:ooooo`?o00007Oooool4ok72i`;o]l?S1?nha>@00onia^Co]k_LokNkg002okNkg0;o][KI
00?o[ZgGoj^Vd_n[Y]800on[Y]83ojJNc@CoXYK80onLSL<3oiN6_`?oTWnk0on=NKP3ohUd]P?oQG6d
1?n3Kk@3oh1_]P?oP76i0on2Mkh4ohN2a`04ohfBdommIZkoOFJ^ogeV[P?oLEb[0on=Ij83ohIOW@?o
P5VK0omhE9/3ofiBX@CoEU>b0_mfIK83oh=OX0?oR6>P1?n=IZ03oi1YX@;oTf^Q1?n8M;H3oi23`@;o
Q^W]0on^/MX2ojJQd003oiZ;`onMRl3oWH_000;oWH_01?nPS;l3oj>>_P?oYY2n00?oZI:nojbC_?n/
Tk`00_n/Tk`5ojjC^`04ojfD_?ndWL3o]9g0okBM`0Co/i^o00Co/I_1okVR`_niX/;o^J;20ondWl80
0onkZLOo^:K7okRVa`03okRVa`03ojnSc?ngZL_o]jW;00;o]jW;0onaYll00onh[]3o[j_Dojn[e003
ojn[e0;oYZgL00?o[joHojF_gonU[ml00onU[ml2oifbi`;oY[?R1OnQ]^P3oibkkP;oW<3a0_nQ_>`5
oj2ok`;oXL;`0_nS_nd4ojC1kP;oYL;^0_nU`>`7ojK1k@03o`000?nV`>coY/3/00;oYl3/1_nW_n/2
ojO0j`OoYko[1?nW`>/;ooooo`03o`000?oooooooooo00oooooo0007ooooo`05o`000?oooooooooo
ooooool000002oooool01?m4A4CogMgMooooool00006ooooo`03o`000?oooooooooo00Kooooo0ol0
000Qooooo`03ok72iong`n?o]l?S00?o]l?S0_nha>@2okRog`?o]k_L00?o/KGKojj]eon^[ML00_n^
[ML5oj^VdP?oYYk=0_nRU/P01?nGT/goTXc:oi:<b_nBS<X3ohb7b@?oQhC80on3Pl/3ogn6d0?oNXkK
1?n3Kk@3oh1_]P?oP76i0_n2Mkh4oiJ3_0;oR7:d1?mmIZh2og5LZ`;oKEZ[00CoSFNRohIOWOn6Gigo
QUnM0on0FI/3ogQDV`CoKU:Q0_mFDk83ogIU/P?oMV:_0on8Hj04oheVX0;oT6VQ1?n2J:`3ohQd]P04
oi23`On6jNgoQ^W]oibHcPCoVHk71?nJRl<3oif;`0CoX8bo1?nSS[h01?nVT;koZI:nojVB__nYT[h3
ojbC_0Co[Y>k00?o/ik3okBM`?ndWL000_ndWL03ok>K_`03okZVa_niX/;o^J;200?o^J;200Co]9o2
ok^YaonkZLOo^jW70onhY/L00onm[lco]jW;okNYb`04okNYb`04ok6Wconh[]3o^:k@okR^d0?o[j_D
00?o]K7Dojn_f?n_[mP00_n_[mP3ojF_g`03ojfbg?nV/n;oY[?R00?oY[?R0_nQ]^P2ojNfh`CoXkSX
1?nQ_>`2oj2ok`;oXkc[1OnS_nd2ojC1kP;oYKk/1?nU`>`2ojK1k@?oY[o[0_nV`>`00ol0003oYko[
ojNoj`0@ojNoj`GoYl3[2_ooool00ol0003oooooooooo`0?ooooo`001oooool01Ol0003ooooooooo
oooooooo000000_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003oooooooooo`03ooooo`?o
00009_ooool3okO3h`;o^<?S1?nh_ml01?ng^mco/KGKok6efona]M/4ojj]e`;oZjKB0_nQXMD3oibJ
d0CoUi;=0onBS<X3ohb7b@?oQhC80on3Pl/3ogn6d0?oNXkK1Om`Wnd01?m<]?Wo/ZcBok:/d_nb[=83
ojBFa`?oUX>l0on8L[@3ogeV[P;oLEb[0om]FZ/3ohIOW@?oP5VK1?mhE9/3ofiBX@03oeIC/_nek_Ko
QWZo00;oMVFb0omfHZl2ogaY/P04ohETY?n=IZ3oSFJPoh1PX`CoOf6V0on2J:`2ohQd]P;oY]gk1?nL
V<h4oiV>a`?oVX_30onMRl04oj2<_`;oXhjn0_nUTL04ojVB_PCo[9>l00Co[Y>kok>N`oncW/?o/ik3
1OndWL001?ncVkoo^ZK6okZVa_njY/H4okVR`PGo^jW700Co^:K7okf_c?nm[lco_Jo<1?ngZL/00onl
/]3o^:k@okR^d003okR^d004ojn[e?ne/MCo]K7DokFae0Co[joH00CoYJoOojfbg?n]/]co[K;L0onV
/n800on/]MooYkKSojNfh`03ojNfh`CoXkSX0_nQ_>`2ojFjj0CoXkc[0_nS_nd2ojFmjPGoYKk/0_nU
`>`2ojJnj`?oY[o[0_nW_^X2ojNoj`03o`000?nW_n_oYko[013oYko[1?nW`>/:ooooo`03o`000?oo
oooooooo00oooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00
0005ooooo`04o`000?ooooooooooooooo`?o0000:_ooool00ong`n?o^<?SokS3h`02okS3h`;o^;oO
0_nc_>04ok6ef`;o[ZgG00?oYJWIoj6QeOnQXMD00onQXMD3oibJd0?oUi;=0onBS<X3ohb7b@?oQhC8
0on3Pl/3ogn6d0CoNXkK0_m`Wnd3okk2g@;o/ZcB00CoUH:lohYe]_n:MKKoRWFf0onFPk`3ohQb]0?o
OFJ^0omaG:/2ofeJZ`;oKEj`00CoQUnMoh1IVon0FI_oP5VK1?mhE9/2ofiBX@;o]Nkf0_n6N[l3ogIU
/P;oMV:_0omlJK83oh1PX`CoOf6V0_n2J:`3oj:ci@03ojKMnonUZm_oYJ_K00?oW9S>1?nIS/L3oiZ;
``CoWH_00_nPS;l00onQS/7oYI70ojFA`003ojFA`0?oZI:n0on/Tk`00on`X<Oo/ik3ok>N``03ok>N
``?o]9g000?o^J_<okZVa_njY/H00_njY/H3okVR`P;o_Jk<1?nkZLL5okf_c003okNYbonl/]3o_;;@
00;o_;;@0onh[]000onk]]Co]K7DokFae003okFae0;o[joH0_nc]=T4ojfbg004ojJch_n/]Moo[;GO
ojbeg`CoYkKS0_nS^>P2ojNhi@GoYK[X0_nS_>/2ojJkj0CoYKgZ0_nU_^`2ojJmjPGoY[k[00?oY[o[
ojNnj_nW_^X00_nW_^X2ojNoj`03o`000?nW_n_oYko[00ooYko[1OnW`>/9ooooo`03o`000?oooooo
oooo00oooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000005
ooooo`Co0000;_ooool3okS3h`03okC3iOnc_>3o/kcP00?o/kcP0_na]M/00onY/MkoYJWIojFYf@02
ojFYf@CoXJ7E0onLV]04oiNBc@?oTXc:0on<QlT3ohN4b0?oPh?;0omoQ]02ogZ>f`?oa=?V0_nn`]d0
1?nPT<?oUH:loiF2_?nEP[`3ohYe]P?oPFbb0_mgIK401?n8L[CoOFJ^ogeV[_mmIZh3og5LZ`;oKEZ[
0om]G[03oh1IV`CoN5BK00?oKU:QokG^m_nek_H00_m]G:d01?n6N[ooMVFbogIU/_mfIK83ogIR[`;o
O6Vb0on5Mk`5oiB@c@?oX[?U00?o^LkZojF[fonUZm/00_nUZm/3oibHcPCoVHk70onJRl<2oif;`003
oib;`OnQS/7oXHk100;oXHk11?nUTL04ojVB_P04ojbC_?n`X<Oo/:37ok2Pa`Co/ik300Co]9g0okV[
c?niZlco^J_<1OnjY/H01?niX/;o_Jk<okf^c?nm[/`3ok^Ya`;o_kGA1?nm[l`5okbbd003okR^d?nk
]]Co^kKD00;o^kKD0one/M@00onh]mWo/kCIok>df@03ok>df@;o[K;L00?o/KKMojbegon/]Ml00on/
]Ml2ojNfh`;oZkOR1?nW^>D2ojFjj0;oZ;[V1OnV^nP2ojFmjP;oYkcX1?nV_NX2ojJnj`?oYkgY0_nW
_^X2ojNnj@;oYkkZ00Co0000ojNnj_nW_n_oYko[0_nW_nX=ojNoj`;oYl3[0_nX`>/9ooooo`03o`00
0?oooooooooo00oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000
ooooo`04ooooo`;o0000<Oooool01?nh`n?o]<?UokC3iOnd`nD3ok>lh003oj^ihonY/MkoZK7N00;o
ZK7N0onUZMT5oj6Qe@?oW9[@0_nGT/d01?n=X>7oR:3SohRPhon8X><4oh:Sj@?oO:cb1?mb^o`00omI
b?Ooa=o/olCOk002olCCiP03ojZOc?nPT<?oX93300;oX9330onEP[`2ohYe]P?oPFbb0omgIK44ogeV
[P;oLEb[0om]FZ/2ofeN/0?oNW:n1_nIX=T01?mgHjkoKEb]ofeL[Om]G:d3ogIU/P?oMV:_0omlJK83
ohEg_0GoU93=00CoX[?UokW>j_nic^[o^LkZ0_nUZm/01?n?Q/GoSh?2ohn3`_n?Pl84oi:4`@?oUXO1
1?nLRl43oj6>`@CoYI700onYT[h00on]XL_o/:37ok2Pa`02ok2Pa`?o/ik300?o]k7CokV[c?niZl`0
0oniZl`3okZVaP03okbed_nm[/co_Jk<00?o_Jk<00Co^jW7oknedOno]M7o_kGA0onm[l`2okjie@?o
_;;@00?o_K_Hok^fe?nk]]@00onk]]@00one/MCo^;OIokRgf@02okRgf@?o/kCI00?o]KWLok6fgOna
]]d00_na]]d2ojbeg`;o[kSP1On[]n82ojNhi@;oZkWT1?nX^^H2ojJkj0;oZ;_W1OnW_>P2ojJmjPGo
YkgY00?oZ;gYojNnjOnW_^T00onW_^T2ojNnjP03o`000?nX_^[oYkoZ00?oYkoZ0_nW_n/2ojRojPOo
Yko[0_nX_n/4ojS0j`Sooooo00?o0000ooooooooool03oooool002;ooooo00?o0000ooooooooool0
;oooool4okC3i@04ok>lh?n[^N?oZkWSoj^ih`CoZK7N0onUZMT2oj6Qe@;oUjOQ1?nCXn03ohfPh@?o
R:3S1?n2XnT3ogb/lP;oL[_l0oo4gn`00onb[]CoZYo<ojZOc002ojZOc0?oX9330onEP[`3ohYe]P?o
PFbb0_mgIK43ofeS]P03ogeV[_maG:_oLEb[00?oKEZ[0om]G[03ogYb_PCoVJ3I0omgHjh2ofeL[@;o
Iene0_mfIK82ogIR[`?oO6Vb0on5Mk`4oiB@c@;oYZSG0onGTL`4ohn6a@?oSh?20onBQ<44oiJ7`@?o
W8_10onQS/45ojFA`004ojVB__n]XL_o[J7;ojfQb`Co/:3700Co/ik3okNadong/M?o]k7C1?niZl`0
0onjY/Ko_;GBokbedP02okbedP?o_Jk<00?o_KgIoknedOno]M400ono]M400onm[lco_[WEokjie@02
okjie@04okbbd?nm^mSo_K_Hokfkf0?o^kKD0_nj_M/4okRgf@03ok>dfOne^Mco]KWL00;o]KWL0_na
]]d2ok:jg`Co[kSP0_n[]n82ojfihPGoZkWT0_nX^^H2ojZkiPCoZ;_W0_nW_>P2ojRlj0KoYkgY0onX
_NT2ojNnj@;oZ;kY0onX_^X01?l0003oZ;kZojNoj_nW_nX6ojRojP;oYko[1onX_n/3ojS0j`Wooooo
00?o0000ooooooooool03_ooool002?ooooo00?o0000ooooooooool0;oooool2okC3i@;o[L7Y1?n[
^N<2ojVagP03oinci_nL[N?oW:gS00?oW:gS0onGYn44oi>Sh0?oSJ3Q0on8X><2oh:Sj@;oBlSV0_nF
lNP3ol3Tl@04olCOk?nb[]Co/ZkDok:^e0?oZYo<0onPT<<3oiF2_0?oRWFf0on1K;83ogMU/@?oKF>f
0_mGIlL00omaG:_oKEZ[ofeJZ`03ofeN/0?oNW:n0onIX=T01?nAO;SoMf>^ogMS[_mgHjh2ofeL[@Co
Iene0_mfHZl3ogaY/PCoQGNl00?oU93=ojJXeonVZ=L00_nVZ=L4oiNAc0?oShK50on?Pl84oi:4`@?o
UXO10onLRl44oj6>`@;oYI700_nYX<h4ojfQb`?o/:3700?o/kGJokNadong/M<00_ng/M<3okV[c0;o
^KcL1?nl]M800onm[/co_KgIokfmf@02okfmf@;o_kGA0_nm`=`4okjie@03ok_3gonm^mSo_K_H00?o
_K_H00?o^kKDokZmfonj_M/00_nj_M/2okRgf@;o^;gN1?ne^M`00ona]]go/[[Ook:jg`02ok:jg`;o
[kSP0_n`^n84ojfihP;oZkWT0_n/^n@5ojZkiP;oZ;_W0_nZ_>L4ojRlj0;oYkgY0_nX_NP3ojRmj@Ko
Z;kY0_nX_^X00ol0003oZ;oZojRojP08ojRojPKoZ;o[1_nX`>/8ooooo`03o`000?oooooooooo00ko
oooo000Tooooo`03o`000?oooooooooo02oooooo1?n]`NT2oj^ih`;oXKWY0onO/nH5oib]h`?oUjOQ
0_nCXn02ohNmn@CoO<Cn0_m/c?h00ombh>WoU_7XoiKaj003ol3Tl@;o]k[L1?nb[]@4ojZOc0?oX933
0onEP[`2ohYe]P?oPFbb0omgIK43ofeS]P?oEfO70om]FZ/2ofeN/0CoNW:n00?oVJ3Ioi5l^?nAO;P0
0omgHjh3ofeL[@?oIene0_mWN]801?mfHZooO6VbogaY/_mlJK82ohEg_0?o`/oT1?nVZ=L3oiNAc0?o
ShK50on?Pl84oi:4`@?oUXO11?nLRl42oj6>`@03ojBNconYX<koZJ3>00?oZJ3>1?n]XL/01?n`X<Oo
/kGJok>ef_nc]MX4okNad`03okV[c?ni_=co^KcL00;o^KcL0_nl]M82okW5h`?o_KgI00?o]lOVokg0
g?nm`=`00onm`=`00onn^MGo^l?Ook_3g`02ok_3g`?o_K_H00?o^/?QokZmfonj_M/00_nj_M/00onh
`n;o^;gNokRmgP03okRmgP;o]KWL0_ne_^43ok:jg`03ok:nhon`^n;o/;_R00?o/;_R0_n]^N82ojjl
i0Co[;_T0_nZ^nH2oj^liPGoZ[cW0_nX_>P2ojVmj0CoZ;gX00?oZ;gYojRnjOnX_^T01_nX_^T2ojRo
jP03o`000?nX_n[oZ;oZ00SoZ;oZ0_nX_n/:ojS0j`Oooooo00?o0000ooooooooool03_ooool002Go
oooo0_l0000`ooooo`;o[L7Y0_nR_^d4oj6ij@?oWk?V0_nL[N<3oi:il@CoSK[d0on7_OT2ogc4oP;o
Omkk0_nFkO@2ok[Sl`03okW3h_ng^]co]k[L00?o]k[L1?nb[]@2ojZOc004oiN?b_n<Q<KoS8C6ohb4
aP?oPWc40on:MKH3oh5//P;oMfFa1?m]HkH4oeMWa`04o`1`com]G[3oKEj`ofeN/0;oNW:n0_mjM<42
ofmX^P03oi5l^?mgHjkoMf>^00?oKEb]0omWGkD3ofMjdP;oO6Vb0_mWaoh00ooEm^Co`/oTol;?i002
ol;?i0?oYZSG1?nGTL`3ohn6a@?oSh?20onBQ<44oiJ7`@;oW8_100?oWi[?ojBNconTW/l00_nTW/l4
ojVPcP;o[J7;0_n_^>05ok>efP;o]k7C0_nd`^D3okVlg0;o//c]1?niaN<01?nm_MWo]lOVokO7i_ng
anH3okg0g0;o]lWX1?nk`ml00onm^mSo^/?Qok[3h@02ok[3h@03okZmfonh`n;o^<?R00;o^<?R0onh
_Mh00one`^Co]KkQokFnh@03okFnh@04ok:jgonb_^?o/[kSok:nh`?o/;_R00?o/;kTojjli?n^_>@0
0on^_>@2ojbki0;o[KgV1?n[_>H2ojZli`;oZkgW1OnY_NP2ojRmj0;oZKkX0_nX_^T2ojVnj@GoZ;kY
0_nX_nX00ol0003oZ;oZojRojP05ojRojP;oZ;o[3OnX`>/6ooooo`03o`000?oooooooooo00kooooo
000Wooooo`03o`000?oooooooooo02kooooo1?nR_^d2oj6ij@?oV;_`0onF^O04oi:il@;oSK[d0on=
cOd2ohSFo`;oUnKl0oncgoH01?njho?o^L?RokW3h_ni`n85okNjg0;o/ZkD00?oX9_?oiN?b_nGSlX0
0_nGSlX3ohb4aP;oPWc40omgMlD3oh5//P?oMfFa0om]HkH3oeMWa`?o]kgN1?nIULh2ogYd`@?oKfRj
0omgHjh2ofeL[@CoIene1?mWN]801?mWaokoeOKTomGfi?oEm^@2ol;?i004oifRf?n=SLooSHg?ohf=
c`CoR8G:0on9Q<P3ohf8b@?oThk<1?nIU<h4oinJc`CoY9k?0_nYX<h2oj^ii0Co[kSP0_nc]MX2ojk7
k0Go]<;U00?o^KcLok;<kOnbc>d00_nbc>d2okW5h`;o/<k_1?nganH00onm`=co]lWXokO9j002okO9
j0;o^l?O0_neb>P3ok[3h@;o]LSX1?nh`n800onh_Mko]L;TokG2i002okG2i0;o]KkQ0_nc`ND5ok:n
h`04ok2kh_n`_^Co/;kTok2ni0;o[[cT0_n^_^H5ojfmiP;oZkcV0_n[_^L4oj^mi`;oZKgX0_nZ_^P3
ojVnj0;oZKoY1?nY_^T2ojRnj@;oZKoZ0onX_nX00ol0003oZ;oZojRojP02ojRojPGoZ;o[3?nX`>/6
ooooo`03o`000?oooooooooo00kooooo000Xooooo`03o`000?oooooooooo02kooooo0_nR_^d3oiZl
l0CoV;_`0onF^O02oi:il@?oTLKi0_n=cOd3oiSLoP04oiOVo?ncgoKo/mofok?OmP;o^<SW1?ni`n82
okNjg0;oYjKD1?nPVll3oiN?bP?oS8C60on2O<@2ogMga@?oLW_<0om_SMl3ofeS]P04oeMWaoo<gnOo
c=oWolcOi`?o]kgN0onIULh2ogYd`@?oKfRj0om[Ik`3ofeL[@?oIene0_mWN]800onVmNko/?:/omGf
i002omGfi0;o/l;U0onMX]P3ohf=c`?oR8G:1?n9Q<P3ohf8b@?oThk<1?nIU<h4oinJc`;oY9k?0_nW
^>D4oj^ii0;o[kSP0_nZb_44ojk7k0;o]<;U0onZdO@2ok;<k@;oY]7f1On`c^l2okO7iP?o[/ka0_ng
bNP2ojo=l0Co]LSX00?o^/?QokG8j?neb>P00_neb>P2okS3hP;o/lKX0one`^@2ok;5j0Co/l7U0_nb
_^<2ok31iP?o/;kT0_n_`NL4ojjniP;o[KgV0_n/_nL5oj^ni`;oZkgW0_n[_^P4ojZnj003ojVnj?nY
_nWoZKoY00;oZKoY0_nY_^T6ojVojP;oZ;oZ00?o0000ojS0j_nX_nX00onX_nX2ojRoj`ooZ<3[1Ooo
ool00ol0003oooooooooo`0>ooooo`00:Oooool00ol0003oooooooooo`0_ooooo`CoV[c`0_nH^o02
oiJnl`CoU<;f0_nAa_T3oiWCo0;oV=cn0on^fOH00oncgoKo^<SWokS8i`02okS8i`;o^L?R00?o[JoI
ojNVe?nWY]@00onWY]@3oj2Kc`?oUho:0on<Q<H3oh9la0?oMgO50ombNl`4ofn=g`05og[5o_o<gnOo
c=oWolcOionXXm400on?QlL3ogad_`?oNWC10om_J;X2of]W_0?oMgk=0_mWGkD3oiZfj`04ok3g_Oo?
olkocNCXolgTj0Co/l;U0_nMX]P3ohf=c`CoR8G:0on9Q<P3ohf8b@?oThk<1?nIU<h2oinJc`;oXkCT
1OnW^>D2oj^ii0;oYlcc1?nZb_42ojk7k0?oXm?i0_nZdO@2oioCnPCoY]7f0_n`c^l3ojGAm`;o[/ka
0_nUc_D5ojo=l0;o]LSX0on^bnl2okG8j0;o[lW]1?nca^P00one`^Co//GXok;5j002ok;5j0;o/l7U
0_n`a>P4ok31iP03ok2ni?n_`NOo[l7W00;o[l7W0_n^_^H2ojg0j0Co[;oW0_n[_^L2oj^oj0GoZkkX
0_nZ_^P2ojZoj@;oZKoY2OnY_nX01_nY`>[oZ<3ZojS0j_nX`>[o0000ojS0jP;oZ;oZ4onX`>/4oooo
o`03o`000?oooooooooo00kooooo000Zooooo`;o0000<Oooool3oiVll0CoU[kc0_nD`_H3oi[:n0;o
VM?l0onZd_D2ojkImP?o]L[Z0_nhb>L00on`]mko[JoIojf_f@02ojf_f@CoYjKD1?nPVll3oiN?bP?o
S8C60on2O<@2ogMga@CoLW_<0_m_SMl3om7ci`04olcOionXXm7oZ:?AojRSd@?oShO70_mlM;l2ofMX
_`04ogYd`Om_J;[oKfRjofmX^P?oJfNl0omgO/d3oiZfj`03ok3g_Oo=i>SocNCX00?ocNCX0_nc`^D0
1?nFV]KoRH_?ohV;con9Rll3ohf=c`?oR8G:0on9Q<P4ohf8b@?oThk<0_nIU<h2oij]hPCoXkCT0onW
^>D00onVbo?oYlccojO<l`03ojO<l`;oZ/[a0onPeOX2oj?Cn@;oW=Ck1?nOdoX2ojKAmP?oWM7j0_nU
dOL2oik?n@CoYLke0_n_cO03ojO=m0;o[/__0_nXbo85ojo9k@;o/lKX0_n^b>`2ok;5j0;o[/K/1On`
a>P2ok31iP;o[/?Y0on_`NL00on]`^Wo[L3Xojg0j003ojg0j0;o[;oW0_n/`NT4oj^oj0;oZkkX0_nZ
`>T3ojZoj@;oZ/3Z1_nY_nX6ojW0jP;oZ<3Z00?oZ<3[o`000?nX`>/05OnX`>/3ooooo`03o`000?oo
oooooooo00kooooo000/ooooo`03o`000?oooooooooo02oooooo0onI_?02oiJnl`?oVl?c0_nJb_P3
ojO;l`;oZ];e0_nbbN`3okG:jP03ok:lhOn`]mko/;ON00;o/;ON1?n][mT2ojNVe003oi^KdonCTm7o
Ti?A00;oTi?A0on;S]43oh2;e@CoN9;P0_mYZ?D2og9kc003oc^mh_nEkK[odO?W00;odO?W00?o_<3M
ojRSdOnXXm400_nXXm43ohn7a`?oO7Bo0_mWJ;l3ofmX^P?oJfNl1?mgO/d01?nJ]^_o/?NmomKhhOoF
n>42olgTj0;o[kKN0onFV]H3ohV;c`?oPXG=0on3Qll3ohV?d`04ohV4b?n=R<WoSHS9oi2If0CoV:CM
1?nN[N83oj>di003ojNhiOnVbo?oY/_c00;oY/_c0_nWc?<3oj3Fn`;oX=Gj0onKeO`4oicDn`;oWm?j
0onId_/2oigAnP;oV/kj1?nNcoT2ojG>m@?oWlgg0_nWcO@2oj;;m@CoZ<_b0_n_bNd2oj[9l0?o[/S/
0_nZanl4ojk6k0;o/<CX0_n]aN/5ojk3j@04ojo1ion]`^Wo[L;Yojg2j@;o[L3X0_n/`^X5ojc1j@;o
ZkoX0_n[`NT4oj[0j@03ojZojOnZ`>[oZ/3Z00;oZ/3Z0_nY_nX8ojW0jP;oZL3[0onX`>/00ol0003o
Z<3[ojS0j`0DojS0j`?ooooo00?o0000ooooooooool03Oooool002gooooo00?o0000ooooooooool0
;oooool4oifmk`;oVl?c0_nVaNl3ojO;l`;o[lO/1?nbbN`01?neb^[o/[cQok:lhOnb_>44ok2ggP;o
[JoI00?oXZ?Foi^KdonKVm<00_nKVm<4oi>Cd@?oRhkA0on0RmD4ogRBh0;oJJSe00?oS>g[olGhk?o5
n>`00_o5e^L3okc0g@?oZ:?A0on?QlL3ogad_`;oIfRo0omUMLh01?m_J;[oJfNlof]W_?m[Ik`2ogMn
c@04ogCRgoo0o<;oe_SQomKhh@;oaMGV1?n_]]h3oiJJeP?oRH_?0on2QLd3oh>7c`?oRHoC1?n@VMP4
oiRTg@;oWZgR0_nS`o04ojG9lP;oY/_c0onQeo/2oj3Fn`?oW]Kk0_nKeO`2oi_Cn`CoVM;l0_nId_/3
oiW>nPCoV/kj0_nNcoT3oic<n0;oWlgg00?oW/[foj;;mOnRboD00onRboD2ojS;lP;oY<Wc1?nZbO00
0on^b>coZ/O_oj[7k`02oj[7k`;o[/K/0_n[a^h4ojg5j`;o[/?Y0on/a>/2ojg2j@;oZl?[1?n/`^X2
ojc1j@;oZl7Z1On[`NT2oj[0j@;oZ/7Z0_nZ`>X2ojW1j`OoZL3Z00?oZL7[ojW0jonY`>/00onY`>/2
ojS0j`03o`000?nX`N_oZ<3[00GoZ<3[0_nX`N/=ojS0j`?ooooo00?o0000ooooooooool03Oooool0
02kooooo00?o0000ooooooooool0;oooool2oifmk`;oYKo/1?nVaNl00onWbo?o[lO/ojo7k002ojo7
k0;o//W/0_na_n@4ok:lh@;o/;ON00?oYj_Ioj:Se_nRXmH00_nRXmH3oi^Kd`CoTi?A0on;S]44oh2;
e@;oN9;P0_n;e_l00on5j];oaOS/olGhk004olGFi`?o_<3M0onXXm43ohn7a`;oO7Bo0omWJ;l3ofEe
cPCoMjSa00Co_?W/ol3l`_oFn>7oe_SQ1?o5eNH3ojnfgP?oUY[F0on9Rll3oh:5c@?oPhO?1?n9Sm<4
oi2If0;oV:CM0_nO^nd4oj?3l0;oYLWb0onSe_X5oj7Gn`;oW]Kk0onOe?X3oi_Cn`;oVM;l0onKc_T2
oiW>nP;oVl_h1?nJboP2oic<n0;oW<Wg1?nNb_H2oj;;m@?oX<We1?nTbO<2oj[9l0?oY/Sa0_nZanl0
0onWao3oZlK^oj_6kP03oj_6kP;o[LG[0on[aNd2ojc4j`;oZ/C]1?n[`n/2ojc2jP;oZl;[1?n[`NX2
oj_1j@?oZ/7[0_nZ`NX6ojW1j`;oZL3Z1_nY`N/2ojW0j`GoZ<7[00Co0000ojS1jonX`>_oZ<3[1_nX
`N/2ojS0j`?oZ<7[2?nX`>/2ooooo`03o`000?oooooooooo00gooooo000_ooooo`03o`000?oooooo
oooo02oooooo1?nU_n`2ojK5k`?o[LC[0_n_an`2ok31iPCo/KoT0_nb_>42oj^ag@?oYj_I1?nRXmH3
oi^Kd`;oTi?A00?oSJ?SohVYj_n9ZNX00_n9ZNX5ohNhmP03oh_Foonjm?;o^_Cb00;oa^C]0oo5e^L0
1?n^]=koWJ7GoifQeonMXML3ohb>d0?oMgg=0omlM;l2ofMX_`CoIGG>00CoMjSaokcik?nlnNco[O[O
0_o@o>42om;[iP;oaMGV00CoZKKRoiNOf_nGWm[oUioJ0on6SmD3oh6;e004ohV;con2QLgoPXG=oh:5
c@?oPhO?0on9Sm<2oi2If0;oVK3W1OnO^nd2oj?3l0?oY=Ch0_nSe_X3ojCHnP;oXMOk0_nReOT2oioD
nP;oXLoh1OnNcoT2oi_>n@?oW/_g0onKboP2oi[;n0?oW<Sf0onLbOL2oik:mP?oW/Oe0_nPbOD2oj37
l`CoX/Oc0_nVb?42ojC7l@CoYlO`0_n[a^h3ojS6k`;oZlG]0_nXaNh5oj[4k@;oZl?[00?oZ/?/oj_2
jon[`^/00on[`^/2oj_1jP;oZ/;[0onZ`N/00onY`^_oZL7[ojW1j`0=ojW1j`WoZ<7[00?o0000ojS1
jonX`N/02onX`N/8ojS0j`;ooooo00?o0000ooooooooool03Oooool0033ooooo0_l0000`ooooo`;o
YKo/0_n/`NT3ojg4j`;o/<7W1?n``NH2ok6oi0;o[KOP1?n[/Md3ojN[f@;oXZ?F00?oVJOOoiBTgonD
Y=l00_nDY=l3ohfSh`CoRJWZ0_n7^?H2oh_Xm@;o^_Cb1?o6i>d01?o5e^Oo[[CNojjdg_n^]=h3oifQ
e`?oS8k@0_mgOLd3og=nd0?oNY7N0_mUMLh2oiO6m`;o[O[O0_o@o>42om;[iP03oko>i_nY]^;oZKKR
00;oZKKR0onGWmX3ohJ?e@?oPH_D0on3S]H3ohRGf`CoTJCQ1?nI/>L2oinkk@?oY<of0_nTe?P3ojOH
n@;oY=Sj0onVe_T2oj;En@;oY=3g1?nQcoP2oik?n@?oX<_f0_nNboL2oj37m0GoW/Oe0_nLb?H00onN
a_CoWLKeoig6m@03oig6m@;oW/Oe0_nOa_<4oj37l`;oX/Oc0_nRa_84ojC7l@;oYlO`0onVa_02ojS6
k`;oYlG_1?nXaNh2oj[4k@;oZ<C]1?nZ`n`2oj_2j`;oZL?/1OnZ`^/01?nZ`N_oZL;[ojW2jonY`^/2
ojW1j`;oZL;/1onY`N/00onX`NcoZ<7[ojS1j`09ojS1j`03o`000?nX`N_oZ<7[00KoZ<7[00?oZ<7/
ojS1jonX`N/00onX`N/8ojS0j`03ooooool0003ooooo00kooooo000booooo`03o`000?oooooooooo
02kooooo1?n/`NT00on]a>_o/<7Wok31i`02ok31i`;o/<7V0_n^^n<4ojfgh0;oZk7M00?oY;3Qoin[
gonOZml00_nOZml3oiVWg`CoU:CO0on=Xn<2ohVYjP?oSMSo0_n/joT3okcXl`;oa^C]0_nhaN@4ojjd
gP?oWJ7G0_n<S]03ogMmc@?oLgk@1?mjTMh00onGa_Oo[O[Oojgjg`02om3lh@;od^_V0onoc^H4ojVf
hP?oUioJ0_n6SmD4oh6;e0?oPhkF0on8Um/4oi6Th@;oVK3W0onQao<2ojC?mP?oZ=Kh0_nWf?T3ojSG
n0;oY]Ki0_nWdOH4ojC@m`;oXLoh0onSbo@2oj3;mP;oX/Oc1?nPao@2oik7m@;oX<Gc1?nNa_@2oig6
m@;oWlGc1OnOa_<2oj37l`03oj75l_nRa_;oX/Kb00?oX/Kb0_nTao43ojC5l@;oY/K`00?oYLG`ojO5
konWaNl00onWaNl2ojS5kP;oYlC^1?nXa>d2oj[3k0;oZ<?]1?nY`n`2oj[2j`?oZL;/0_nY`^/2ojS2
k0CoZL;/0_nY`N/2ojS2k0CoZ<7/0_nX`N/2ojS1k0OoZ<7[00Co0000ojS1k?nX`N_oZ<7[1_nX`N`4
ojS1j`OoZ<3[00?oYl3[ooooool000003oooool003?ooooo00?o0000ooooooooool0;_ooool2ojc1
j@?o[/7X0_n``NL2ojnniPCo[[_S0_n]]n000onW]N?oY;3QojB`h@02ojB`h@CoWj_O0onIYml2oiBT
g`;oTk[b1?n>aOX00on=f?oo[>_iojc[n@04okcXl`03ok[?j_nhaNCo^<GT00?o^<GT0_n^]=h01?nK
W]KoRi7Doh^Ae?n;TM@3oh2;e0?oMgg=0omcO]02ogZAgP;oX>3l0_o7mn`2om;eiP;obn7X1?noc^H2
ojVfhP04oiJQg?n:UMWoRYGIohZEf@?oPI3I0on1Rm@4oh>>eP?oR9OK0_nAY>43oi^kk`;oXLOc0_nW
dOH3ojSFn0;oZ]Og0onXeoP2oj[Bm@CoYm7f0_nTd?L3ojG<m0;oXl_d0_nTb?84oj;7l`;oX<Od0_nR
aO44oj35l`;oW/Kd0onQa?83oio5l`;oWlKc0onPa?83oj75lP;oX/Kb0onRa?42ojC5l@;oXlC`1?nU
aO02ojO5k`;oY/C_1OnWa>h2ojS4k@03ojO4k_nX`ngoZ<?]00?oZ<?]0_nY`n`3ojS3k@;oZL;/1_nX
`^`2ojW2k0KoZ<;/0_nX`N`2ojS2k0CoZ<7/0_nX`N/5ojS1k003o`000?nX`NcoZ<7/00OoZ<7/1?nX
`N/2ojS0j`KoYl3[00?o0000ooooooooool03Oooool003Cooooo00?o0000ooooooooool0;_ooool5
ojk1j0Co[kkV0_n^^n<2ojVii@?oYkGS1?nT/>42oin[g`;oVkCY0onF]>d4oi>jlP;oS/Gj0_nSgO/3
ok?Tm`03okcXlonjcn[o^/oZ00;o^/oZ0_nhaN@2ojN/f`?oVikF0on;TM@3oh2;e0CoM8cL1?moZo00
0onPh?coaoO/olOgk002om;eiPCobn7X0_noc^H2ojZdh0?oUZ7L0on:UMT2oh6@f@CoPYCL0on9Wn85
oi6]j@;oVk__0_nTb_@4ojOAmP03ojSFn?nZeoOoZ]Og00;oZ]Og00?oZ=Ohoj[BmOnZd_D00_nZd_D2
ojOAmP?oZ<gc0_nUc?@00onVb?7oY<SbojC8lP03ojC8lP;oX/Oc0onTaO43oj;5l@;oX<Gc0onRa?42
oj74lP;oX/?`1?nQ`o42oj34lP;oX/?`1_nRa?42oj?3l0CoXlC`0_nUaO02ojC4k`CoY/C_0_nWa>h2
ojK4kPCoYlC^2OnX`ndEojS2k0_oZ<7/00?o0000ojS1k?nX`N`01onX`N`2ojS1j`03ojO1k?nW`>_o
Yl3[00GoYl3[00?oooooo`000?ooool03_ooool003Gooooo0_l0000_ooooo`Go[/7X0_n__^H2oj^m
i`CoZKWU0onW]N<2ojB`h@;oW[GX1?nK]>T3oiJdk@;oTk[b0onNd?T01?nSgO_o/nCgok?Tmonci?L3
okWDkP;o^/oZ0_n_^>04ojN/f`?oVikF0on;TM@3oh2;e0CoM8cL0_moZo02oj_Nn@;o`O;a0_o9j>`2
ol_Qj0;o^/SU1OnZ]>03oiJQg0?oRYGI0_n1T=T4oh:Dg0?oRIoR0_nA[NT2oibol@GoY<[d0_nWdOH2
oj_FmP;oZ]Og0on/doD2oj[Bm@?oZ/kc0_nXcO<2ojS9l@CoY/Sa0_nTb?83ojG5l0;oY<Ga0_nU`nl4
oj?3l0;oX/Ca0_nS`^l5oj;3l0;oXL?a00?oX/;`oj;3l?nR`o000onR`o02oj;4l@KoXl?`0_nSa?02
ojC3k`CoY<C_0_nVa>l2ojG3k`CoY/C^0_nWa>h3ojO3kP;oZ<?]0_nW`nd4ojS3k@;oZ<;/0_nX`^dA
ojS2k0;oZ<7/0_nX`^`6ojS1k003o`000?nX`NcoZ<7/00GoZ<7/1_nW`N`2ojO0j`Kooooo00?o0000
ooooooooool03?ooool003Oooooo00?o0000ooooooooool0;_ooool2ojk1j0;oZl7Z1?n[_NL2ojVi
i@;oYK[X0onR]nP4oijej0;oVkCY0_nL`O84oi_6mP;oW]3i0_nZgOT3okCEl@;o^MC^0_nc`^D4ojnh
h0?oYjcK0onKW]H3oh^Ae0CoP8_D0_mdS=`3oi:jlP03oj_NnOo1l_7o`O;a00;obNS/0_o3enT4ok[8
i@;oZ[CP0_nKZ=l3ohbLgP?oQYSN0on5Vn42oh:Dg003ohZUi_nD/^coU;;/00;oU;;/1?nL_o42ojC:
m0?oZM;e0_n[e_H3ojgDm0;o[=?e0on/d?<2oj[>l`;oZ/[a1?nXbO42ojK8l@?oYlK_0_nUaO02ojK3
kPCoYL?_0_nS`o02ojG2kPCoXl;_0_nR`o02oj?2k`CoX/;`0_nR`o02oj?2k`OoXl?`00?oXl?_ojC3
konT`nl00onT`nl2ojC4k`KoYL?_0_nVa>h3ojK3kP;oYl?^00?oY/?^ojO3kOnW`nd00onW`nd2ojS3
k@03ojO2kOnX`^goZ<;]00?oZ<;]0_nX`^`2ojS2kA7oZ<;/1_nX`N`01?l0003oZ<7/ojS1k?nX`N`8
ojO1k0Wooooo00?o0000ooooooooool03?ooool003Sooooo00?o0000ooooooooool0;_ooool4oj_1
jP;oZkgW0_nV_NX4ojFjj0?oX[OX0_nN]NP2oifnk`CoW<7b0_nKa_H3ojCDn004oj[MnOndeO7o]=Ga
okCEl@;o/lOY1?nc`^D2ojnhh004oj>^gonIYMgoVJGMoiVUg@CoTIkL0on6V]l3ohNSi`CoT[[b0_n_
hOP00oo1l_7obNS/olWXk004ol?Gj@;o^/SU0_nY]n<4oi^Xg`?oS9cN0on6V=h3ohFKh@?oRZGV1?nD
/^`2oibol@?oY<_d0_nYd_D3ojgCm0;o[MCd0on]dO<2ojc@l`;o[<ca1?nZb_42ojS9l@?oZ<K_0_nW
a^l2ojO4kPCoY/?^0_nU`nl6ojG2kP;oXl;_0_nT`^h4oj?2k`;oX/;`0_nT`^h4oj?2k`;oXl?`0onT
`^l3oj?3k`;oY<?_0onT`^l2ojG3k`;oYL;^1?nU`nh2ojK3kP;oY/;^1?nV`nh2ojO3k@KoYl;]0_nX
`^d2ojO2k@GoZ<;]4?nX`^`6ojS1k003ojO1k?l0003oYl7/00KoYl7/3?ooool00ol0003ooooooooo
o`0<ooooo`00>Oooool00ol0003oooooooooo`0^ooooo`;oZl7Z0_nW`>/4ojJmjP;oYK[X0_nQ_Nd4
oj2mk@?oWKk_0_nL`O83oj;=mP;oY=Ch0on_d_800ondeO7o/lOYok?7j@02ok?7j@;o/l;U00?oZKKR
oj>^gonS[]l00_nS[]l3oiVUg@CoTIkL0on6V]l3ohNSi`04oi:jl_n_hOSo[n7hojoQn0;o`NK`0oo4
gn`2ol?Gj@;o]/GV1?nY]n<3oi^Xg`?oS9cN1?n6V=h3ohFKh@?oRZGV0_nD/^`3oik2lP;oY<_d0onZ
d?@2ojgCm0?o[]7c0_n]dO<2ojg=l@Co[<ca0_nZb_43ojW7k`;oZ<K_00?oZ<C^ojO4k_nWa>h00onW
a>h2ojK3kP;oY/;]1_nU`^h3ojG1k@?oY<;^0_nS`^l3ojC1kP?oY<;^0_nS`^l3ojC1kP;oY<;_0_nT
`Nh4ojC2kP;oY<;_1_nU`^h2ojG3kPKoY/;^0_nV`nh2ojK2k@coYl;]0_nX`^d3ojO2k@;oZ<;/0_nW
`^d6ojS2k0;oYl;/1?nX`^`2ojS1k0GoYl7/00?o0000ojO1k?nW`N`04?ooool00ol0003ooooooooo
o`0<ooooo`00>_ooool2o`0002oooooo1?nW`>/2ojJmjP;oXkk]1?nQ_Nd2oj2mk@;oXL?a1?nPao@2
oj;=mP?oZ/kc0_n_d_83ok7:k0;o/lOY0_n]_>D3ojVfhPCoXjkO0onIYMd2oi6Ng003oi2Xi_n>/Nko
S[7^00;oS[7^0onIaoL3ok3JmP04ol7Vl?o4gncoa=o/olCOk0;o_=3Y1?nfaNH2ojVgh`04oif/h_nC
Xn3oTj?Poi>Sh0?oRYkQ1?n8XN@3ohfYj@GoU;G^0_nN`_82ojG:l`?oZ]3d00?o[M3cojkAlon^dO<0
0_n^dO<00on^c_7o[Lgaojg=l@03ojg=l@;o[<ca0_n[b>l2ojW7k`;oZLG^1?nXa>h2ojO4kP;oYl;]
1OnV`^d2ojG2kP;oY/7]0_nU`Nd2ojK1k@CoYL7]0_nT`Nh2ojG1k@KoY<7^0_nU`Nd5ojC1kP;oY<;^
00?oYL7^ojG2k_nU`^h01_nU`^h7ojK2kPKoY/;]5OnW`^d2ojS2k003ojO2kOnW`^coYl;/00?oYl;/
0_nX`^`00onW`^coYl7/ojO1k005ojO1k003o`000?oooooooooo013ooooo00?o0000ooooooooool0
3?ooool003cooooo00?o0000ooooooooool0;Oooool2ojO0j`;oY;o]1?nS_^d2oj6mk@;oXL7`1?nQ
`o42oj37m0?oYl[b0_nZc_<2ojk:kP?o/L[/0_n^`>L4ojfli@?oZKKR0_nS[]l00onLZ^7oU:KRoiBV
hP02oiBVhP?oT:SV1?n>/Nh01?nIaoOo/=[fok3Jm_n`f_H3ok[NlP03olCOk?nld>Wo_=3Y00;o_=3Y
0_nfaNH2ojZhh`?oWJcR0onCXn03ohZNh@CoR:7T0on=ZNT2oiBekP;oW/7a1OnUb_<01OnZd?Co[M3c
ojg@lon]d??o[]7c00Co[/ka0_n]cO43ojc:k`;oZlS_0_nZa^h4ojW5kP;oZ<C^0_nX`nd4ojO2k@;o
Y/;]0onW`Nd2ojK1k@;oY/7/1?nV`Nd2ojG1k@;oY/7]1?nU`Nd2ojC1kPKoYL7]0_nT`Nh2ojG1k@Co
YL7^0_nU`^h2ojG1k@CoYL;^0_nV`^h;ojK2kASoYl;]2?nW`^`2ojO1k0Gooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0<ooooo`00?Oooool00ol0003oooooooooo`0]ooooo`CoY;o]
0_nS_^d2oj:okPCoXL7`0_nQ`o43ojG6l@;oYl[b0_n[b>l4ojk:kP03ok7:k?n^`>Oo[/3W00;o[/3W
0_n]_>D00onV]>;oXZoQoj:_h@02oj:_h@?oW:[Q1?nDY^83oi2XiP;oS[7^0onRb?@01?n`f_Ko^]kb
ok[Nl_njg_83ok_Ek@;o_=3Y0_nb`nH4ojZhh`?oWJcR0onCXn03ohZNh@;oR:7T0_n?[NX3oiJgkPCo
W/7a0_nUb_<3oj[>l`;o[M3c0on^co42ojk>l@?o[L__0_n/b^l2oj_7kPCoZ/K^0_nYaNh3ojW3k@?o
Z<?]0_nW`^d3ojO2k0;oYl7]0_nW`N`4ojK1k0;oY/7]0_nV`N`4ojK1k@;oYL7]0_nV`Nd<ojG1k@;o
YL7^1_nU`Nd2ojG2kP?oY/7]3?nV`^dIojO2k@GoYl;/2Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00cooooo000nooooo`03o`000?oooooooooo02gooooo0_nT_nd3oj>ok@?oX[o^
0_nQ`O03ojC3k`;oYLKa0_nYa^l4oj_8k`;o[/[^0on^`^T2ojk0i`03ojVii?nV]>;oY[CR00;oY[CR
1?nR[n43oibZh@;oU:KR0_nG/n/4oiZkk`;oX/Sd0on`eo@01?njg_;o^mG]ok_EkOnkeNd2okK;j@Co
//?V0_nZ^><00onQ/NCoUjWSoiNYh`02oiNYh`?oTJKT0on=YnH4ohn]jP?oU[O^0_nN`O43ojC8lP;o
Z/kc0on/c_42ojk?l@?o[/c`0_n]bnl2ojc9kPCoZlO^0_nZa^h3ojW4k@;oZL?]1_nX`^`2ojO2k0Ko
Yl7/0_nV`N`00onW`NcoY/7/ojK1k003ojK1k0;oY/7]00?oY/3/ojK1kOnV`Nd00onV`Nd2ojG1k@03
ojK1kOnU`NgoYL7]00GoYL7]0_nV`Nd6ojG1k@_oY/7]0_nV`^d00onV`NgoY/;]ojK2k@03ojK2kAKo
Yl;]4?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo000oooooo`;o0000
;oooool2oj>ok@;oY;o/1?nT`Nh2ojC3k`;oYlC^1?nYa^l2oj_8k`?o[L?Z0_n^`^T2oj^liP?oZKWT
1?nV]>82oj:_h@;oWK7V0onJ/NL4oiNcj`;oV[__0onUc?@2ok3Gm0?o]mG`00?o^mG]okK;jOnfbnT0
0_nfbnT2ok;3iP;oZK[U0onQ/N@4oiNYh`?oTJKT0on=YnH2ohn]jP;oUkS^1?nN`O42ojC8lP?oZL_a
0_n/c_42ojg=l0?o[/c`0_n]b^l4ojc9kP;oZlO^0_n[aNd2ojW4k@;oZL?/1_nX`^`2ojS1k0coYl7/
0_nV`N`2ojO0k0CoY/3/0_nV`Nd2ojK0k0CoY/7]0_nU`Nd3ojK1k0;oY/7]0_nV`N`DojK1k@;oY/;]
5OnW`^dDooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool0047ooooo00?o
0000ooooooooool0;Oooool4ojBok0;oY<7^0_nV`^d4ojO4kP;oZLK_0on[`n/2ojg3jP;oZkkW1?n[
_>H3ojVii0;oY[CR0_nR]>D4oifaiP?oV[7W0_nG/n/3oik1l@;oYLcd0on^d?82okOEl0?o]lo]0_nf
bnT00on_`NOoZK[UojVji@03ojVji@?oXK7T0_nGZN<00onEZnKoTZcXoi:/j002oi:/j0?oTk3[1?nG
^>h2oik1l@?oY<Ka0_nYbo42oj_;l@Co[Lg`00?o[/c`ojg:kon]b^l00_n]b^l2ojc9kP;oZlK]0_n[
aNd2oj[4k@CoZL?/1?nX`^`4ojS1k0[oYl7/1_nW`>`8ojK0k0;oY/7]0onV`>`2ojK1k0;oY/3/1?nV
`N`2ojK1k@;oY/7/3_nV`Nd2ojO1kA?oYl;]6?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00_ooooo0012ooooo`03o`000?oooooooooo02gooooo0_nT_n`2ojJok0CoY/;]0_nWa>h3
oj[2j`;oZl?[0_n[_nT4oj^ni`;oZkcV0_nW^^H3ojFgiPCoX[CU0_nM/NH2oijhj`CoWK_]0_nN`O43
ojS:l@;o[]3b0_nbd>l3okO?k@03ok;7jOn_`NOo[l7W00;o[l7W0_nY^^D2oj:di@?oW:oU1?nEZnH4
oi:/j0?oTk3[0_nG^>h3oijol0;oY<Ka00?oZ<Waoj_;lOn[bo400on[bo42ojg=l0;o[L__0_n]b^l2
ojc8kP?oZlK]0_n[aNd4oj[4k@;oZL?/0_nY`^`4ojS2k0CoZ<7/1_nW`N`;ojO0k0;oY/3/0_nW`>`<
ojK0k0;oY/7/00?oY/3/ojK1k?nV`N`00onV`N`2ojK1k@03ojK1k?nV`NgoY/7]00GoY/7]00?oYl7/
ojO1kOnW`Nd00onW`Nd2ojO2k@;oYl7]2_nW`^dMooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool004?ooooo00?o0000ooooooooool0;Oooool4ojJok0;oY/;]0_nY`N/3oj[2
j`;oZl3Y1?n[_nT2oj^ni`;oZKcW1?nW^^H3ojFgiP;oX[CU0_nQ]nP4oijhj`;oWK_]0_nSa?03ojS:
l@03ojg=lOnbd>oo/]3_00?o/]3_00Co]lo]ok;7jOnbanWo//OY0_n_`NL2ojRjiPCoX[CU0onL[nD3
oiF[iP;oTZcX0_nG/n/4oiVhkP;oW[o`0_nSa?04ojS9l@;oZl_a0on/b_02ojg;k`Ko[<S^00?oZlK]
oj_5kOn[aNd00_n[aNd2oj[4k@;oZL?/1?nY`^`2ojS2k0KoZ<7/0_nW`N`CojO0k0;oY/3/00?oYl3/
ojK0k?nV`>`02_nV`>`8ojK1k0;oY/7]1_nW`N`2ojO1k@?oYl7/0_nW`Nd2ojO1k0KoYl;]8?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0014ooooo`03o`000?oooooooooo
02gooooo0_nV_n`2ojS0j`CoZL7[00?oZ/;[oj_0jOn[`>T00_n[`>T2oj^oj@;oZKgX1?nY_>L2ojNj
iP;oYKWW0onS^>P4oj6gj0;oW[S[0_nQ_nh4oj?4l004ojS:lOn]cO7o[Lgaojg=l@;o/]3_0onabN`2
ok;7j@;o[L3X1?nX^^H2oj:di@03oijci_nJ/>OoV[3W00;oV[3W0onG/>T4oiNcj`;oVKS^0_nO_nl4
oj?4l0;oZ<Wa0onZbO02ojc:l0;o[<W_1_n/b>h3oj_6k@;oZlG]0_nZa>`4ojW3k0;oZL;/0_nX`^`6
ojS1k0;oYl7/0_nW`>`2ojO0j`KoYl3/0_nW`>/<ojO0k0;oY/3/0_nW`>`6ojK0k0;oYl3/1_nV`N`C
ojO1k0;oYl;]9?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0015oooo
o`;o0000;oooool3ojS0j`;oZL7[0onZ`>X2oj_0j@;oZ[oY1?nY_NP2ojVli`;oY[_X1?nU^NL3oj>h
j0;oXKOX0_nR_N`4oj6okP;oXlC`0_nXbO42ojg=l@?o[l[^0_nabN`2ojk4jPCo[L3X0_nX^^H2ojBg
iP?oW[?V1?nJ/>L3oiN`j@;oUk?[0_nK^Nd4oinok`;oXlC`0onVa_02oj[9l0;oZlW_1?n/bNl2ojc8
kP?o[<O]0_n[a^d00on[a>goZ/C/oj[4k003oj[4k0;oZL?/0_nY`^`4ojS2k0CoZ<7/0_nW`N`6ojO0
j`;oYl3/1_nW`>/2ojO0k0;oYl3[3?nW`>`2ojK0k0KoYl3/0_nV`N`3ojO0k17oYl7/:Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo0017ooooo`03o`000?oooooooooo02go
oooo1?nY`>X2oj[0jP;oZ/3Y1?nZ_nT2ojVmj0;oYkcX1?nV^nP2ojFii`03ojBlj_nR_>_oX[c[00;o
X[c[0_nR_N`2ojC2k`CoYLG`0_nXbO43ojc9k`;o[l[^0_n^a^/4ojk4jP;o[L3X0_nX^nL4ojBgiP?o
W[?V0_nJ/>L2oi^dj@CoV[G[0onK^Nd2oinok`?oXl?_0_nVa_02ojS7k`CoZlW_0_n/bNl3ojc7kP;o
[<O]00?oZlG]oj_4kOn[a>d00_n[a>d2oj[4k0?oZL?/0_nY`^`8ojS1k0;oZ<7[5?nW`>/2ojO0k0;o
Yl3[5?nW`>`>ojO1k2cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`00
B?ooool00ol0003oooooooooo`0]ooooo`CoZL3Z1?nZ`>T2ojZoj@;oZ;kY1?nW_>P2ojJkj003ojFl
j_nT_>[oY;cZ00;oY;cZ0_nR_>/2oj?0k@CoY<;_0_nUaO03ojW7k`;o[<W_0_n]and4ojk6j`;o[/CZ
0_n[_nP4ojRki`;oY;OV0_nQ]^L3oifdj0CoVkCY0_nJ]N/2oifjk@CoWkk^0_nS`nl2ojK5k`CoZ<O_
0_n[bNl2oj_7kP;o[<O^0_n[a^d4oj_5k@;oZlC]0onZ`n`2ojW3k0;oZL;/1_nX`N`6ojS1jaSoYl3[
0_nW`>`2ojO0j`;oYl3/0_nW`>/<ojO0k0[oYl7/<?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00_ooooo0019ooooo`03o`000?oooooooooo02gooooo1?nY`>X2oj[0j@;oZ;oZ1?nX
_^T2ojNlj003ojJmj_nU_>[oYKcZ00;oYKcZ0_nT_>X2ojBok0CoXl3]0_nT`^l3ojO5k`;oZLO_0_n[
a^h4ojg7k@;o[/K[0_n/`^T4oj^oj0;oZ;_W0_nT^>L4oj6fi`?oWKCX0_nK]>T2oifhj`CoWK[]0_nO
_^h00onS`^ooY/G_ojK5k`03ojK5k`;oZ<O_0_nYanl2oj_7kP;oZlK^1?n[a^d2oj_5k@?oZ/C/0_nZ
`n`6ojW2k0CoZ<7/1_nX`N/00onX`>_oYl3[ojO0j`0OojO0j`_oYl3/1onW`N`dooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool004[ooooo0_l0000^ooooo`;oZL3Z0_nX`>/4
ojRojP;oZ;kY0_nW_^X3ojJmjP;oYKcZ0_nT_^`4ojBok0;oXl3]0onV`nh2ojO5k`;oZLG^1?n[a^h2
ojg7k@;o[<?[1?n/`^T2oj^oj0;oYk_X1?nT^>L2oj6fi`03oj2gjOnN]n[oW[OZ00?oW[OZ0onM^>/2
oifjk@03oj6nk_nS`^ooXl;_00;oXl;_0_nVaNl3ojS5k`;oZLO_0_nZa^h4oj_6kP;oZlK]0on[aNd2
oj[4k0;oZL?/1_nY`^`6ojS1k0?oZ<7[1?nX`>/PojO0j`coYl3/0_nW`N`iooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02_ooool004cooooo00?o0000ooooooooool0;?ooool4ojS0
j`;oZ;oZ0onW_n/3ojNnjP04ojJmj_nU_^_oYKk[ojFnj`?oY;k/0_nT_n`3ojG1k@;oY/?^0_nWa>h4
ojW5kP;oZlK^0_n[a>`4ojc3j`;o[<;Y0onY_^T3ojNkj0;oY;SW00?oX[SXoj2gjOnP]nT00_nP]nT2
oijgjP;oWk[[1?nO^nd3oj6nkP;oXl;_0onU`nl2ojS5k`;oZLK^1?nZa^h2oj_6kPGoZlG]00?oZ/C/
ojW3k?nY`n`00onY`n`3ojW2k0KoZ<7/1_nX`N/2ojS0jb;oYl3[0_nW`>`3ojO0j`GoYl3/??ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo001=ooooo`03o`000?oooooooooo
02cooooo0_nX`>/3ojO0j`;oYko[1OnV_n/2ojFnj`;oYL3/1?nU`>d2ojG1k@;oY/?^1?nWa>h2ojW5
kP;oZ/C]1?n[a>`2ojc3j`?oZ/3Y0_nY_^T00onW_>SoYK[XojFjj002ojFjj0?oX[SX0_nP]nT2oj2i
jPCoWk[[0_nO^nd2oj:nk@CoXl7^0_nU`nl2ojO4kPCoZLK^0_nZa^h3oj[5k@;oZlG]00?oZ/C]oj[4
k?nZa>`00_nZa>`2ojW3k0KoZL;/0_nX`N`7ojS1j`CoZ<3[9_nW`>]3ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02_ooool004kooooo00?o0000ooooooooool0;Oooool2ojO0j`03
ojJok?nV_n_oY[o[00CoY[o[0_nU_n`4ojG0k0;oYL3]0_nV`^d4ojK3kP;oYlC^0onY`nd3oj[4k@;o
ZlC/0onZ`N/2oj[0j@03ojRnjOnW_>SoYkcX00;oYkcX0_nU^^P2ojBjj@?oX[WY1?nP^NX2oinjj`;o
XKc/1?nR_^d2oj?1kP;oYL?^1?nWa>h2ojW6kP?oZLG^0onZaNd4oj[4k@;oZ/C/0_nY`n`6ojW2k0?o
Z<7/2?nX`N/3ojS0jb?oYl3[Aoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[o
oooo001?ooooo`;o0000;_ooool3ojJok0;oY[o[0_nV_n`4ojFok0;oYL3/0_nV`Nd4ojK2k@;oY/?^
0onX`nd2ojW3k@;oZL;/1?nZ`^/2oj[1j`03ojVoj_nX_^WoZ;kY00;oZ;kY0_nW_>P2ojFkj@CoY;[Y
0onR^NT2oj2ijP;oXK_[1?nQ_>`2oj:nk@;oY<7^1?nU`nh2ojO4kP?oZ<C^0_nYaNh00onYaNgoZ/G]
oj[5k@02oj[5k@;oZ/C]1_nY`n`5ojW2k0;oZ<7/2?nX`N/5ojS0jakoYl3[C?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00[ooooo001Aooooo`03o`000?oooooooooo02cooooo1onV
_n`2ojFok0;oY/3/1?nV`Nd2ojK2k@?oYl;]0_nX`nd2ojS2k0CoZL;/0_nZ`^/00onY`>[oZKoZojVo
jP02ojVojP;oZ;kY0_nW_>T4ojFkj@;oY;[Y0_nS^nX4oj:kj`?oXK_[0_nQ_>`3oj>ok@?oY<7^0_nU
`nh2ojO3kPCoZ<C^1?nYaNd2oj[5k@?oZLC]1?nY`n`6ojW2k003ojS1k?nX`N_oZ<7[00KoZ<7[1_nX
`>/LojO0jdoooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`00D_ooool0
0ol0003oooooooooo`0[ooooo`KoY[o/1_nV`>`2ojK1k@?oYl7/0_nW`^d6ojS2k0;oZL;/00?oZL7[
ojW0j_nY`>X00_nY`>X2ojVojP;oYkkY1?nW_>T2ojFkj@;oY;_Y1?nS^nX2oj:kj`;oXkc[1?nS_N`2
oj>ok@03ojC0kOnU`^koYL;^00;oYL;^0_nW`nh2ojO4kPCoZ<C^0_nYaNd5ojW4k@KoZL?/0_nY`^`0
0onX`^coZ<7/ojS1k002ojS1k0SoZ<7[1OnX`>/IojO0je?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0:ooooo`00Doooool00ol0003oooooooooo`0[ooooo`GoY[o/1?nV`>`4ojK1
k0CoYl7/1_nX`^`00onX`N_oZL7[ojW1j`02ojW1j`;oZL3Z0_nX_^X4ojNnj@;oYkcY0_nV_>T4ojBk
j@;oXk_Z1_nS_>/2oj>mk003ojBokOnT`>goY<3]00;oY<3]0_nU`^h2ojK3kPCoYlC^0_nXa>h5ojW4
k@03ojW3kOnY`ncoZL?/00GoZL?/00?oZL;/ojS2k?nX`^`00_nX`^`5ojS1k0GoZ<7[1OnX`>/GojO0
jeOooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`00E?ooool2o`0002go
oooo1?nV_n`4ojK0k0;oY/7/1_nW`N`2ojS2k0GoZ<7[0_nY`N/3ojRojP?oZ;kZ0_nW_^T3ojJmj@?o
Y[cY0_nT^nT2ojBljPKoXkc[00?oY;k/ojBokOnT_nd00_nT_nd2ojC0k@;oY/;]1?nV`nh2ojO4kP?o
Z<?]0_nYa>d5ojW3k@;oZL?/1_nY`^`2ojS2k0GoZ<7/1_nX`N/3ojS0jaKoYl3[F_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Wooooo001Fooooo`03o`000?oooooooooo02_ooooo
1?nV_n`2ojK0k0;oYl3/1_nW`N`7ojS1j`?oZ<3[0_nX_nX6ojNnjP;oY[gY0_nV_NX4ojFljP?oY;cZ
0_nS_>/2ojBmk0?oY;k/0_nT_nd3ojG1k@?oY/;]0_nV`nh3ojO3k@?oZ<?]1_nY`nd3ojW3k0GoZL;/
0onX`^`3ojS1k0OoZ<7[1OnX`>/BojO0jekooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`09ooooo`00Eoooool00ol0003oooooooooo`0[ooooo`;oY[o/0onW`>/3ojO0k0;oYl7/0onW
`>/2ojS1j`OoZ<3[0_nX_nX6ojNnjPKoY[gZ0_nU_>X00onU_N_oY;g[ojBmj`02ojBmj`;oY;g/0_nT
_n`4ojFok@;oYL7]0_nV`Nd4ojK2k@;oYl?]1OnX`nd2ojW3k@?oZ<?]0_nY`n`8ojS2k0GoZ<7/1?nX
`N/6ojS0j`coYl3[I_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo001H
ooooo`03o`000?oooooooooo02cooooo2_nW`>/7ojS0j`;oZ;o[1?nX_nX4ojNnjPKoY[gZ1OnU_N/2
ojBmj`;oYKk/1?nT_n`2ojFok@;oYL7]1?nV`Nd2ojK2k@03ojO2kOnX`ngoZ<?]00WoZ<?]2OnX`^`8
ojS1k0CoZ<7[0_nX`>/<ojO0jf[ooooo00Go0000ooooooooooooooooo`00000;ooooo`00FOooool0
0ol0003oooooooooo`0/ooooo`KoYl3[1onX`>/6ojRoj`;oZ;oZ1_nW_^X2ojJmjP03ojJnjonU_N_o
YKg[00CoYKg[0_nU_^/4ojFnk0;oY;o/0_nU`>`4ojG1k@;oY/7]0_nV`^d3ojO2k@OoZ<?]0_nX`^d;
ojS2k0SoZ<7/0_nX`N/3ojS0j`WoYl3[KOooool01Ol0003ooooooooooooooooo000000_ooooo001J
ooooo`;o0000;Oooool4ojO0j`OoZ<3[1_nX_n/3ojNoj`GoYkkZ1OnV_^/2ojFmj`KoYKk[0_nU_^`3
ojFok0?oYL3/0_nU`Nd2ojK1k@;oY/;]1_nW`^d2ojS3k@KoZ<;]2OnX`^`;ojS1k0;oZ<3[1onW`>]a
ooooo`04o`000?ooooooooooo`0000_ooooo001Looooo`03o`000?oooooooooo02_ooooo1?nW`>/7
ojS0j`;oZ;o[1onW_n/4ojNnj`OoY[k[0_nU_^/8ojFok003ojK0k?nV`NgoY/7]00CoY/7]0_nV`^d8
ojO2k@KoZ<;]1_nX`^`>ojS1k003ojO1k?nW`>_oYl3[00CoYl3[MOooool00ol0003oooooo`00000;
ooooo`00GOooool00ol0003oooooooooo`0[ooooo`;oYl3[1_nX`>/<ojNoj`;oYkk[00?oY[o[ojJn
jonV_^/01?nV_^/2ojJoj`KoYKo/1OnV`>`4ojK1k@CoY/;]2?nW`^d4ojS2k@SoZ<;/2_nX`N`5ojO1
k0;oYl3[N?ooool01?l0003oooooooooool0000:ooooo`00G_ooool00ol0003oooooooooo`0[oooo
o`;oZ<3[0_nW`>/4ojS0j`_oYko[1?nV_n/2ojJnj`KoY[o[0_nU_n`00onV_ncoY/3/ojK0k004ojK0
k0KoY/7]0_nV`^d6ojO2k@KoZ<;]2?nX`^`7ojS1k0SoYl7/O?ooool00ol0003oooooo`00000:oooo
o`00Goooool2o`0002cooooo1?nW`>/2ojS0j`;oYl3[2onW_n/:ojJoj`GoY[o/1OnV`>`4ojK1k@_o
Yl;]0_nX`^d2ojO2k@SoZ<;/1OnX`N`5ojO1k8?ooooo0_l0000:ooooo`00HOooool00ol0003ooooo
ooooo`0Zooooo`SoYl3[2OnW_n/7ojJoj`KoY[o/1onV`>`6ojK1k@ooYl;]0_nX`^`2ojO2k0;oZ<;/
0_nW`^`6ojO1k8Gooooo0ol0000:ooooo`00H_ooool00ol0003oooooooooo`0[ooooo`CoYl3[2onW
_n/8ojJoj`;oY[o/1onV`>`2ojK1k0KoY/7]00?oYl7]ojO2kOnW`^d03onW`^d7ojO2k0;oYl7/Q?oo
ool4o`0000gooooo001Sooooo`03o`000?oooooooooo02_ooooo1?nW`>/9ojNoj`SoY[o[2_nV`>`3
ojK1k0CoY/7]0onW`Nd@ojO2k@KoYl;/Poooool4o`00017ooooo001Tooooo`;o0000;?ooool3ojO0
j`WoYko[1OnV_n/<ojK0k0KoY/7/00?oY/7]ojO1kOnW`Nd04onW`^d2ojO2k8?ooooo0ol0000Eoooo
o`00I_ooool00ol0003oooooooooo`0[ooooo`;oYl3[1onW_n/?ojK0k0SoY/7/1OnW`Nd>ojO2kHGo
oooo1?l0000Hooooo`00Ioooool00ol0003oooooooooo`0Zooooo`CoYl3[0_nW_n/2ojO0k0ooY/3/
1_nV`N`2ojO1k0GoYl7]3?nW`^f4ooooo`Co00007?ooool006Sooooo00?o0000ooooooooool0:_oo
ool4ojO0j`CoYl3/3onV`>`2ojK1k0[oYl7/2OnW`^f3ooooo`Co00008?ooool006Wooooo0_l0000/
ooooo`?oYl3[1OnW`>`4ojK0k0?oYl3/0_nV`>`2ojO0k0koYl7/1_nW`^f2ooooo`Co00009?ooool0
06_ooooo00?o0000ooooooooool0:_oooolCojO0k0koYl7/0_nW`^f2ooooo`?o0000:?ooool006co
oooo00?o0000ooooooooool0:_ooool2ojO0k003ojO0jonW`>coYl3/00coYl3/3?nW`Nb3ooooo`Co
0000:oooool006gooooo00?o0000ooooooooool0:oooool2ojO0j`coYl3/2_nW`Nb2ooooo`Co0000
;oooool006kooooo00?o0000ooooooooool0:_ooool4ojO0j`;oYl3/0_nW`>/7ojO0k0KoYl7/POoo
ool4o`0003?ooooo001_ooooo`;o0000:oooool8ojO0j`OoYl3/0_nW`Nb0ooooo`Co0000=oooool0
077ooooo00?o0000ooooooooool0:_ooool7ojO0j`;oYl3/P_ooool4o`0003_ooooo001booooo`03
o`000?oooooooooo02[ooooo1OnW`>^2ooooo`?o0000?oooool007?ooooo00?o0000ooooooooool0
:_ooool00onW`>_oooooooooo`1oooooo`Co0000@_ooool007Cooooo0_l0000Zooooo`03o`000?oo
oooooooo07_ooooo1?l00016ooooo`00M_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo07Sooooo1?l0001:ooooo`00Moooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
07Cooooo1?l0001>ooooo`00N?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo077o
oooo0ol0001Booooo`00NOooool2o`0002Cooooo00?o0000ooooooooool0KOooool4o`0005Gooooo
001kooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0JOooool4o`0005Wooooo001l
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0IOooool4o`0005gooooo001moooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0HOooool4o`00067ooooo001nooooo`;o
00007oooool00ol0003oooooooooo`1Mooooo`Co0000IOooool0083ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`1Jooooo`?o0000JOooool0087ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`1Fooooo`Co0000K?ooool008;ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`1Booooo`Co0000L?ooool008?ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`1>ooooo`Co0000M?ooool008Cooooo0_l0000Iooooo`03o`000?oooooooooo04[o
oooo1?l0001hooooo`00Q_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Kooooo
1?l0001looooo`00Qoooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04?ooooo0ol0
0020ooooo`00R?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03oooooo1?l00023
ooooo`00ROooool2o`0001Cooooo00?o0000ooooooooool0>oooool4o`0008Oooooo002;ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0=oooool4o`0008_ooooo002<ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0<oooool4o`0008oooooo002=ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0<?ooool3o`0009?ooooo002>ooooo`;o00003oooool0
0ol0003oooooooooo`0/ooooo`Co0000U_ooool0093ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Xooooo`Co0000V_ooool0097ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Tooooo`Co0000W_ooool009;ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Qooooo`Co0000X_ooool009?ooooo0_l00009ooooo`03o`000?oooooooooo01gooooo1?l0
002Vooooo`00UOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo0ol0002Z
ooooo`00U_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo1?l0002]oooo
o`00Uoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo1?l0002aooooo`00
V?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0002eooooo`00VOoo
ool2o`0000?ooooo00?o0000ooooooooool02_ooool4o`000;Wooooo002Kooooo`04o`000?oooooo
ooooo`0000Wooooo0ol0002mooooo`00W?ooool00ol0003oooooo`000005ooooo`Co0000`?ooool0
09gooooo0_l000000ooooooo0000o`000002o`000<Cooooo002Nooooo`;o0000b?ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00:kooooo00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o410@olc<c0Gooooo0_lQ8B6Hooooo`00[_ooool01Ol@413o
^[Zjonk^k_mgMgOo410@00;ooooo1_l00004ooooo`03o`000?oooooooooo00;ooooo00GoEEEEogMg
MoooooooV9RHob4Q8@05ooooo`;o8B4QV?ooool00:kooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000Woooool00:kooooo00?o0000oooo
ooooool01?ooool6o`0000Cooooo00?o0000ooooooooool00_ooool01Ol0003oV9RHoooooonHV9So
8B4Q09oooooo002^ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool01Ol0
003oEEEEo`000?l@413oc<c<09oooooo002/ooooo`03oa0@4?l0003o000000?o00003Oooool00ol0
003oooooooooo`02ooooo`03oeEEEOn7QhOooooo0:7ooooo002^ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00_ooool00ooMgMgo410@oiRHV02Qooooo`00[_ooool00ol0003ooooo
ooooo`0<ooooo`03oeEEEOmVIVKo000000Gooooo00Coc<c<odA4A?l0003o410@Woooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -20 0 ]
[.5 .82364 20 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16.8) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.655 .751 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69468 Mtetra
.655 .752 .921 r
.4053 .69468 .41061 .69934 .41957 .69681 .41427 .69215 Mtetra
.41427 .69215 .41957 .69681 .42855 .69428 .42327 .68961 Mtetra
.42327 .68961 .42855 .69428 .43756 .69174 .4323 .68706 Mtetra
.655 .753 .922 r
.4323 .68706 .43756 .69174 .4466 .68919 .44137 .68451 Mtetra
.44137 .68451 .4466 .68919 .45567 .68663 .45046 .68196 Mtetra
.654 .754 .923 r
.45046 .68196 .45567 .68663 .46478 .68407 .45958 .6794 Mtetra
.654 .755 .924 r
.45958 .6794 .46478 .68407 .47391 .68149 .46873 .67684 Mtetra
.654 .756 .925 r
.46873 .67684 .47391 .68149 .48307 .67891 .47791 .67427 Mtetra
.654 .757 .926 r
.47791 .67427 .48307 .67891 .49227 .67632 .48713 .67169 Mtetra
.654 .758 .927 r
.48713 .67169 .49227 .67632 .50149 .67371 .49637 .6691 Mtetra
.653 .76 .927 r
.49637 .6691 .50149 .67371 .51075 .6711 .50565 .66651 Mtetra
.653 .761 .928 r
.50565 .66651 .51075 .6711 .52004 .66849 .51496 .6639 Mtetra
.654 .762 .929 r
.51496 .6639 .52004 .66849 .52936 .66586 .5243 .66127 Mtetra
.654 .763 .93 r
.5243 .66127 .52936 .66586 .53871 .66322 .53367 .65863 Mtetra
.53367 .65863 .53871 .66322 .54809 .66058 .54308 .65597 Mtetra
.655 .764 .93 r
.54308 .65597 .54809 .66058 .55751 .65792 .55252 .65329 Mtetra
.655 .763 .929 r
.55252 .65329 .55751 .65792 .56695 .65526 .56199 .6506 Mtetra
.656 .763 .929 r
.56199 .6506 .56695 .65526 .57643 .65259 .57149 .64788 Mtetra
.656 .762 .928 r
.57149 .64788 .57643 .65259 .58595 .6499 .58102 .64515 Mtetra
.656 .761 .927 r
.58102 .64515 .58595 .6499 .59549 .64721 .59059 .64241 Mtetra
.656 .759 .926 r
.59059 .64241 .59549 .64721 .60507 .64451 .60019 .63966 Mtetra
.656 .758 .925 r
.60019 .63966 .60507 .64451 .61468 .6418 .60982 .6369 Mtetra
.656 .757 .924 r
.60982 .6369 .61468 .6418 .62432 .63908 .61949 .63414 Mtetra
.656 .756 .923 r
.61949 .63414 .62432 .63908 .634 .63636 .62919 .63137 Mtetra
.656 .755 .922 r
.62919 .63137 .634 .63636 .64371 .63362 .63892 .6286 Mtetra
.656 .754 .922 r
.63892 .6286 .64371 .63362 .65345 .63087 .64868 .62582 Mtetra
.656 .753 .922 r
.64868 .62582 .65345 .63087 .66323 .62811 .65849 .62304 Mtetra
.656 .753 .921 r
.65849 .62304 .66323 .62811 .67304 .62535 .66832 .62025 Mtetra
.66832 .62025 .67304 .62535 .68289 .62257 .67819 .61745 Mtetra
.655 .753 .921 r
.67819 .61745 .68289 .62257 .69277 .61979 .6881 .61465 Mtetra
.655 .753 .922 r
.6881 .61465 .69277 .61979 .70269 .61699 .69804 .61185 Mtetra
.69804 .61185 .70269 .61699 .71264 .61418 .70801 .60904 Mtetra
.70801 .60904 .71264 .61418 .72262 .61137 .71802 .60622 Mtetra
.654 .754 .923 r
.71802 .60622 .72262 .61137 .73264 .60854 .72807 .6034 Mtetra
.654 .755 .924 r
.72807 .6034 .73264 .60854 .7427 .60571 .73815 .60058 Mtetra
.654 .756 .925 r
.73815 .60058 .7427 .60571 .75279 .60286 .74827 .59775 Mtetra
.654 .757 .926 r
.74827 .59775 .75279 .60286 .76291 .60001 .75842 .59491 Mtetra
.654 .759 .927 r
.75842 .59491 .76291 .60001 .77308 .59714 .76861 .59206 Mtetra
.653 .76 .928 r
.76861 .59206 .77308 .59714 .78328 .59427 .77884 .5892 Mtetra
.654 .761 .929 r
.77884 .5892 .78328 .59427 .79351 .59138 .7891 .58632 Mtetra
.654 .762 .929 r
.7891 .58632 .79351 .59138 .80378 .58849 .7994 .58342 Mtetra
.654 .763 .93 r
.7994 .58342 .80378 .58849 .81409 .58558 .80974 .5805 Mtetra
.654 .764 .93 r
.80974 .5805 .81409 .58558 .82443 .58267 .82011 .57756 Mtetra
.655 .764 .93 r
.82011 .57756 .82443 .58267 .83482 .57974 .83052 .5746 Mtetra
.655 .763 .929 r
.83052 .5746 .83482 .57974 .84523 .5768 .84096 .57163 Mtetra
.656 .763 .928 r
.84096 .57163 .84523 .5768 .85569 .57385 .85145 .56863 Mtetra
.656 .762 .927 r
.85145 .56863 .85569 .57385 .86618 .57089 .86196 .56562 Mtetra
.656 .76 .927 r
.86196 .56562 .86618 .57089 .87672 .56792 .87252 .5626 Mtetra
.656 .759 .926 r
.87252 .5626 .87672 .56792 .88729 .56494 .88312 .55957 Mtetra
.656 .758 .925 r
.88312 .55957 .88729 .56494 .89789 .56195 .89375 .55653 Mtetra
.656 .757 .924 r
.89375 .55653 .89789 .56195 .90854 .55895 .90442 .55348 Mtetra
.656 .756 .923 r
.90442 .55348 .90854 .55895 .91923 .55594 .91513 .55042 Mtetra
.656 .755 .922 r
.91513 .55042 .91923 .55594 .92995 .55292 .92588 .54736 Mtetra
.656 .754 .922 r
.92588 .54736 .92995 .55292 .94071 .54988 .93667 .54429 Mtetra
.656 .753 .921 r
.93667 .54429 .94071 .54988 .95152 .54684 .9475 .54121 Mtetra
.9475 .54121 .95152 .54684 .96236 .54378 .95838 .53812 Mtetra
.656 .752 .921 r
.95838 .53812 .96236 .54378 .97324 .54071 .96929 .53502 Mtetra
.656 .752 .92 r
.96929 .53502 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.655 .751 .92 r
.391 .69252 .39636 .6972 .4053 .69468 .39996 .68999 Mtetra
.655 .751 .921 r
.39996 .68999 .4053 .69468 .41427 .69215 .40895 .68745 Mtetra
.655 .752 .921 r
.40895 .68745 .41427 .69215 .42327 .68961 .41797 .6849 Mtetra
.41797 .6849 .42327 .68961 .4323 .68706 .42702 .68235 Mtetra
.654 .752 .922 r
.42702 .68235 .4323 .68706 .44137 .68451 .4361 .6798 Mtetra
.654 .753 .922 r
.4361 .6798 .44137 .68451 .45046 .68196 .44521 .67724 Mtetra
.654 .753 .923 r
.44521 .67724 .45046 .68196 .45958 .6794 .45435 .67469 Mtetra
.653 .754 .924 r
.45435 .67469 .45958 .6794 .46873 .67684 .46352 .67213 Mtetra
.653 .755 .925 r
.46352 .67213 .46873 .67684 .47791 .67427 .47272 .66958 Mtetra
.652 .756 .926 r
.47272 .66958 .47791 .67427 .48713 .67169 .48196 .66702 Mtetra
.652 .757 .927 r
.48196 .66702 .48713 .67169 .49637 .6691 .49122 .66445 Mtetra
.652 .759 .928 r
.49122 .66445 .49637 .6691 .50565 .66651 .50052 .66187 Mtetra
.652 .76 .929 r
.50052 .66187 .50565 .66651 .51496 .6639 .50985 .65927 Mtetra
.653 .761 .929 r
.50985 .65927 .51496 .6639 .5243 .66127 .51921 .65665 Mtetra
.653 .763 .93 r
.51921 .65665 .5243 .66127 .53367 .65863 .52861 .65401 Mtetra
.654 .763 .93 r
.52861 .65401 .53367 .65863 .54308 .65597 .53804 .65134 Mtetra
.655 .764 .93 r
.53804 .65134 .54308 .65597 .55252 .65329 .5475 .64864 Mtetra
.656 .764 .929 r
.5475 .64864 .55252 .65329 .56199 .6506 .55699 .64591 Mtetra
.657 .764 .928 r
.55699 .64591 .56199 .6506 .57149 .64788 .56651 .64316 Mtetra
.657 .763 .927 r
.56651 .64316 .57149 .64788 .58102 .64515 .57607 .64038 Mtetra
.658 .762 .926 r
.57607 .64038 .58102 .64515 .59059 .64241 .58566 .63759 Mtetra
.658 .76 .925 r
.58566 .63759 .59059 .64241 .60019 .63966 .59528 .63479 Mtetra
.658 .759 .924 r
.59528 .63479 .60019 .63966 .60982 .6369 .60493 .63198 Mtetra
.658 .757 .923 r
.60493 .63198 .60982 .6369 .61949 .63414 .61462 .62917 Mtetra
.657 .756 .923 r
.61462 .62917 .61949 .63414 .62919 .63137 .62434 .62636 Mtetra
.657 .755 .922 r
.62434 .62636 .62919 .63137 .63892 .6286 .6341 .62355 Mtetra
.657 .754 .922 r
.6341 .62355 .63892 .6286 .64868 .62582 .64389 .62074 Mtetra
.656 .753 .921 r
.64389 .62074 .64868 .62582 .65849 .62304 .65371 .61792 Mtetra
.65371 .61792 .65849 .62304 .66832 .62025 .66357 .61511 Mtetra
.66357 .61511 .66832 .62025 .67819 .61745 .67346 .6123 Mtetra
.655 .753 .921 r
.67346 .6123 .67819 .61745 .6881 .61465 .68339 .60949 Mtetra
.655 .753 .922 r
.68339 .60949 .6881 .61465 .69804 .61185 .69336 .60667 Mtetra
.654 .753 .922 r
.69336 .60667 .69804 .61185 .70801 .60904 .70336 .60386 Mtetra
.654 .753 .923 r
.70336 .60386 .70801 .60904 .71802 .60622 .71339 .60105 Mtetra
.653 .754 .923 r
.71339 .60105 .71802 .60622 .72807 .6034 .72346 .59823 Mtetra
.653 .755 .924 r
.72346 .59823 .72807 .6034 .73815 .60058 .73357 .59542 Mtetra
.653 .756 .925 r
.73357 .59542 .73815 .60058 .74827 .59775 .74372 .5926 Mtetra
.652 .757 .926 r
.74372 .5926 .74827 .59775 .75842 .59491 .7539 .58978 Mtetra
.652 .758 .927 r
.7539 .58978 .75842 .59491 .76861 .59206 .76412 .58695 Mtetra
.652 .76 .928 r
.76412 .58695 .76861 .59206 .77884 .5892 .77438 .58409 Mtetra
.652 .761 .929 r
.77438 .58409 .77884 .5892 .7891 .58632 .78467 .58122 Mtetra
.653 .762 .93 r
.78467 .58122 .7891 .58632 .7994 .58342 .795 .57832 Mtetra
.654 .763 .93 r
.795 .57832 .7994 .58342 .80974 .5805 .80536 .57539 Mtetra
.655 .764 .93 r
.80536 .57539 .80974 .5805 .82011 .57756 .81576 .57243 Mtetra
.655 .764 .929 r
.81576 .57243 .82011 .57756 .83052 .5746 .82619 .56943 Mtetra
.656 .764 .929 r
.82619 .56943 .83052 .5746 .84096 .57163 .83666 .56641 Mtetra
.657 .763 .928 r
.83666 .56641 .84096 .57163 .85145 .56863 .84717 .56337 Mtetra
.657 .762 .927 r
.84717 .56337 .85145 .56863 .86196 .56562 .85771 .5603 Mtetra
.658 .76 .926 r
.85771 .5603 .86196 .56562 .87252 .5626 .8683 .55723 Mtetra
.658 .759 .925 r
.8683 .55723 .87252 .5626 .88312 .55957 .87892 .55414 Mtetra
.658 .758 .924 r
.87892 .55414 .88312 .55957 .89375 .55653 .88958 .55105 Mtetra
.657 .756 .923 r
.88958 .55105 .89375 .55653 .90442 .55348 .90027 .54796 Mtetra
.657 .755 .922 r
.90027 .54796 .90442 .55348 .91513 .55042 .91101 .54486 Mtetra
.657 .754 .922 r
.91101 .54486 .91513 .55042 .92588 .54736 .92179 .54176 Mtetra
.657 .754 .921 r
.92179 .54176 .92588 .54736 .93667 .54429 .93261 .53865 Mtetra
.657 .753 .921 r
.93261 .53865 .93667 .54429 .9475 .54121 .94346 .53554 Mtetra
.656 .752 .921 r
.94346 .53554 .9475 .54121 .95838 .53812 .95436 .53242 Mtetra
.656 .752 .92 r
.95436 .53242 .95838 .53812 .96929 .53502 .9653 .5293 Mtetra
.9653 .5293 .96929 .53502 .98024 .53192 .97628 .52616 Mtetra
.655 .751 .921 r
.38561 .68781 .391 .69252 .39996 .68999 .39458 .68527 Mtetra
.39458 .68527 .39996 .68999 .40895 .68745 .40359 .68271 Mtetra
.40359 .68271 .40895 .68745 .41797 .6849 .41263 .68015 Mtetra
.654 .751 .921 r
.41263 .68015 .41797 .6849 .42702 .68235 .4217 .6776 Mtetra
.654 .752 .921 r
.4217 .6776 .42702 .68235 .4361 .6798 .4308 .67504 Mtetra
.653 .752 .922 r
.4308 .67504 .4361 .6798 .44521 .67724 .43993 .67248 Mtetra
.653 .752 .923 r
.43993 .67248 .44521 .67724 .45435 .67469 .44909 .66993 Mtetra
.652 .753 .923 r
.44909 .66993 .45435 .67469 .46352 .67213 .45828 .66738 Mtetra
.652 .754 .924 r
.45828 .66738 .46352 .67213 .47272 .66958 .4675 .66483 Mtetra
.651 .755 .925 r
.4675 .66483 .47272 .66958 .48196 .66702 .47675 .66228 Mtetra
.651 .756 .926 r
.47675 .66228 .48196 .66702 .49122 .66445 .48604 .65973 Mtetra
.651 .757 .927 r
.48604 .65973 .49122 .66445 .50052 .66187 .49536 .65717 Mtetra
.651 .759 .928 r
.49536 .65717 .50052 .66187 .50985 .65927 .50471 .65459 Mtetra
.651 .76 .929 r
.50471 .65459 .50985 .65927 .51921 .65665 .51409 .65199 Mtetra
.652 .762 .93 r
.51409 .65199 .51921 .65665 .52861 .65401 .52351 .64935 Mtetra
.653 .763 .93 r
.52351 .64935 .52861 .65401 .53804 .65134 .53296 .64668 Mtetra
.655 .764 .93 r
.53296 .64668 .53804 .65134 .5475 .64864 .54244 .64396 Mtetra
.656 .764 .929 r
.54244 .64396 .5475 .64864 .55699 .64591 .55195 .64121 Mtetra
.657 .764 .928 r
.55195 .64121 .55699 .64591 .56651 .64316 .5615 .63842 Mtetra
.658 .764 .927 r
.5615 .63842 .56651 .64316 .57607 .64038 .57108 .6356 Mtetra
.659 .763 .926 r
.57108 .6356 .57607 .64038 .58566 .63759 .58069 .63275 Mtetra
.659 .761 .925 r
.58069 .63275 .58566 .63759 .59528 .63479 .59033 .6299 Mtetra
.659 .76 .924 r
.59033 .6299 .59528 .63479 .60493 .63198 .60001 .62704 Mtetra
.659 .758 .923 r
.60001 .62704 .60493 .63198 .61462 .62917 .60972 .62418 Mtetra
.658 .757 .923 r
.60972 .62418 .61462 .62917 .62434 .62636 .61946 .62132 Mtetra
.658 .756 .922 r
.61946 .62132 .62434 .62636 .6341 .62355 .62924 .61847 Mtetra
.657 .755 .922 r
.62924 .61847 .6341 .62355 .64389 .62074 .63906 .61563 Mtetra
.657 .754 .921 r
.63906 .61563 .64389 .62074 .65371 .61792 .6489 .61279 Mtetra
.656 .753 .921 r
.6489 .61279 .65371 .61792 .66357 .61511 .65878 .60995 Mtetra
.65878 .60995 .66357 .61511 .67346 .6123 .6687 .60712 Mtetra
.655 .753 .922 r
.6687 .60712 .67346 .6123 .68339 .60949 .67866 .6043 Mtetra
.654 .753 .922 r
.67866 .6043 .68339 .60949 .69336 .60667 .68864 .60147 Mtetra
.654 .753 .923 r
.68864 .60147 .69336 .60667 .70336 .60386 .69867 .59866 Mtetra
.653 .753 .923 r
.69867 .59866 .70336 .60386 .71339 .60105 .70873 .59585 Mtetra
.652 .754 .924 r
.70873 .59585 .71339 .60105 .72346 .59823 .71883 .59304 Mtetra
.652 .755 .925 r
.71883 .59304 .72346 .59823 .73357 .59542 .72897 .59024 Mtetra
.651 .756 .926 r
.72897 .59024 .73357 .59542 .74372 .5926 .73914 .58744 Mtetra
.651 .757 .927 r
.73914 .58744 .74372 .5926 .7539 .58978 .74935 .58464 Mtetra
.651 .758 .928 r
.74935 .58464 .7539 .58978 .76412 .58695 .7596 .58182 Mtetra
.651 .76 .929 r
.7596 .58182 .76412 .58695 .77438 .58409 .76988 .57897 Mtetra
.652 .761 .93 r
.76988 .57897 .77438 .58409 .78467 .58122 .7802 .5761 Mtetra
.653 .763 .93 r
.7802 .5761 .78467 .58122 .795 .57832 .79056 .57319 Mtetra
.654 .764 .93 r
.79056 .57319 .795 .57832 .80536 .57539 .80095 .57024 Mtetra
.655 .764 .93 r
.80095 .57024 .80536 .57539 .81576 .57243 .81138 .56724 Mtetra
.656 .764 .929 r
.81138 .56724 .81576 .57243 .82619 .56943 .82184 .56421 Mtetra
.658 .763 .928 r
.82184 .56421 .82619 .56943 .83666 .56641 .83233 .56114 Mtetra
.658 .762 .927 r
.83233 .56114 .83666 .56641 .84717 .56337 .84286 .55804 Mtetra
.659 .761 .925 r
.84286 .55804 .84717 .56337 .85771 .5603 .85343 .55492 Mtetra
.659 .76 .924 r
.85343 .55492 .85771 .5603 .8683 .55723 .86404 .55179 Mtetra
.659 .758 .923 r
.86404 .55179 .8683 .55723 .87892 .55414 .87468 .54865 Mtetra
.659 .757 .923 r
.87468 .54865 .87892 .55414 .88958 .55105 .88537 .54551 Mtetra
.658 .756 .922 r
.88537 .54551 .88958 .55105 .90027 .54796 .89609 .54237 Mtetra
.658 .755 .921 r
.89609 .54237 .90027 .54796 .91101 .54486 .90686 .53923 Mtetra
.658 .754 .921 r
.90686 .53923 .91101 .54486 .92179 .54176 .91766 .5361 Mtetra
.657 .753 .921 r
.91766 .5361 .92179 .54176 .93261 .53865 .92851 .53296 Mtetra
.657 .753 .92 r
.92851 .53296 .93261 .53865 .94346 .53554 .9394 .52982 Mtetra
.657 .752 .92 r
.9394 .52982 .94346 .53554 .95436 .53242 .95032 .52668 Mtetra
.656 .752 .92 r
.95032 .52668 .95436 .53242 .9653 .5293 .96129 .52353 Mtetra
.96129 .52353 .9653 .5293 .97628 .52616 .9723 .52037 Mtetra
.655 .751 .921 r
.38018 .68308 .38561 .68781 .39458 .68527 .38918 .68051 Mtetra
.38918 .68051 .39458 .68527 .40359 .68271 .3982 .67794 Mtetra
.3982 .67794 .40359 .68271 .41263 .68015 .40726 .67537 Mtetra
.654 .751 .921 r
.40726 .67537 .41263 .68015 .4217 .6776 .41635 .6728 Mtetra
.41635 .6728 .4217 .6776 .4308 .67504 .42546 .67023 Mtetra
.653 .751 .922 r
.42546 .67023 .4308 .67504 .43993 .67248 .43461 .66766 Mtetra
.652 .751 .922 r
.43461 .66766 .43993 .67248 .44909 .66993 .44379 .6651 Mtetra
.652 .751 .923 r
.44379 .6651 .44909 .66993 .45828 .66738 .453 .66256 Mtetra
.651 .752 .924 r
.453 .66256 .45828 .66738 .4675 .66483 .46225 .66002 Mtetra
.65 .753 .925 r
.46225 .66002 .4675 .66483 .47675 .66228 .47152 .65748 Mtetra
.649 .754 .926 r
.47152 .65748 .47675 .66228 .48604 .65973 .48083 .65495 Mtetra
.649 .755 .927 r
.48083 .65495 .48604 .65973 .49536 .65717 .49016 .65241 Mtetra
.649 .756 .928 r
.49016 .65241 .49536 .65717 .50471 .65459 .49954 .64985 Mtetra
.65 .758 .929 r
.49954 .64985 .50471 .65459 .51409 .65199 .50894 .64727 Mtetra
.651 .76 .929 r
.50894 .64727 .51409 .65199 .52351 .64935 .51838 .64465 Mtetra
.652 .762 .93 r
.51838 .64465 .52351 .64935 .53296 .64668 .52785 .64198 Mtetra
.654 .763 .93 r
.52785 .64198 .53296 .64668 .54244 .64396 .53735 .63926 Mtetra
.656 .764 .929 r
.53735 .63926 .54244 .64396 .55195 .64121 .54689 .63649 Mtetra
.658 .765 .929 r
.54689 .63649 .55195 .64121 .5615 .63842 .55646 .63367 Mtetra
.659 .765 .928 r
.55646 .63367 .5615 .63842 .57108 .6356 .56606 .6308 Mtetra
.66 .764 .927 r
.56606 .6308 .57108 .6356 .58069 .63275 .57569 .62791 Mtetra
.661 .763 .926 r
.57569 .62791 .58069 .63275 .59033 .6299 .58536 .625 Mtetra
.661 .761 .924 r
.58536 .625 .59033 .6299 .60001 .62704 .59506 .62208 Mtetra
.66 .76 .924 r
.59506 .62208 .60001 .62704 .60972 .62418 .60479 .61917 Mtetra
.66 .758 .923 r
.60479 .61917 .60972 .62418 .61946 .62132 .61456 .61627 Mtetra
.659 .757 .922 r
.61456 .61627 .61946 .62132 .62924 .61847 .62436 .61337 Mtetra
.658 .755 .922 r
.62436 .61337 .62924 .61847 .63906 .61563 .63419 .61049 Mtetra
.657 .754 .922 r
.63419 .61049 .63906 .61563 .6489 .61279 .64406 .60762 Mtetra
.656 .754 .922 r
.64406 .60762 .6489 .61279 .65878 .60995 .65397 .60477 Mtetra
.656 .753 .922 r
.65397 .60477 .65878 .60995 .6687 .60712 .66391 .60192 Mtetra
.655 .753 .922 r
.66391 .60192 .6687 .60712 .67866 .6043 .67389 .59908 Mtetra
.654 .753 .922 r
.67389 .59908 .67866 .6043 .68864 .60147 .6839 .59625 Mtetra
.653 .753 .923 r
.6839 .59625 .68864 .60147 .69867 .59866 .69395 .59343 Mtetra
.652 .753 .924 r
.69395 .59343 .69867 .59866 .70873 .59585 .70404 .59063 Mtetra
.651 .754 .925 r
.70404 .59063 .70873 .59585 .71883 .59304 .71417 .58783 Mtetra
.65 .755 .926 r
.71417 .58783 .71883 .59304 .72897 .59024 .72433 .58505 Mtetra
.649 .756 .927 r
.72433 .58505 .72897 .59024 .73914 .58744 .73453 .58227 Mtetra
.649 .758 .929 r
.73453 .58227 .73914 .58744 .74935 .58464 .74477 .57948 Mtetra
.649 .759 .93 r
.74477 .57948 .74935 .58464 .7596 .58182 .75505 .57668 Mtetra
.65 .761 .93 r
.75505 .57668 .7596 .58182 .76988 .57897 .76536 .57384 Mtetra
.651 .762 .931 r
.76536 .57384 .76988 .57897 .7802 .5761 .77571 .57096 Mtetra
.653 .763 .931 r
.77571 .57096 .7802 .5761 .79056 .57319 .78609 .56803 Mtetra
.654 .764 .93 r
.78609 .56803 .79056 .57319 .80095 .57024 .79651 .56505 Mtetra
.656 .764 .929 r
.79651 .56505 .80095 .57024 .81138 .56724 .80696 .56201 Mtetra
.658 .764 .928 r
.80696 .56201 .81138 .56724 .82184 .56421 .81745 .55892 Mtetra
.659 .763 .926 r
.81745 .55892 .82184 .56421 .83233 .56114 .82797 .55579 Mtetra
.66 .762 .925 r
.82797 .55579 .83233 .56114 .84286 .55804 .83852 .55263 Mtetra
.661 .76 .924 r
.83852 .55263 .84286 .55804 .85343 .55492 .84912 .54945 Mtetra
.661 .759 .923 r
.84912 .54945 .85343 .55492 .86404 .55179 .85975 .54626 Mtetra
.66 .757 .922 r
.85975 .54626 .86404 .55179 .87468 .54865 .87042 .54308 Mtetra
.66 .756 .921 r
.87042 .54308 .87468 .54865 .88537 .54551 .88113 .53989 Mtetra
.659 .755 .921 r
.88113 .53989 .88537 .54551 .89609 .54237 .89188 .53671 Mtetra
.659 .754 .92 r
.89188 .53671 .89609 .54237 .90686 .53923 .90267 .53354 Mtetra
.658 .753 .92 r
.90267 .53354 .90686 .53923 .91766 .5361 .91351 .53038 Mtetra
.657 .752 .92 r
.91351 .53038 .91766 .5361 .92851 .53296 .92438 .52721 Mtetra
.92438 .52721 .92851 .53296 .9394 .52982 .9353 .52405 Mtetra
.9353 .52405 .9394 .52982 .95032 .52668 .94626 .52089 Mtetra
.656 .752 .92 r
.94626 .52089 .95032 .52668 .96129 .52353 .95725 .51772 Mtetra
.95725 .51772 .96129 .52353 .9723 .52037 .96829 .51454 Mtetra
.655 .751 .92 r
.37472 .67831 .38018 .68308 .38918 .68051 .38373 .67572 Mtetra
.38373 .67572 .38918 .68051 .3982 .67794 .39278 .67313 Mtetra
.39278 .67313 .3982 .67794 .40726 .67537 .40185 .67054 Mtetra
.40185 .67054 .40726 .67537 .41635 .6728 .41096 .66795 Mtetra
.654 .75 .92 r
.41096 .66795 .41635 .6728 .42546 .67023 .4201 .66536 Mtetra
.653 .75 .921 r
.4201 .66536 .42546 .67023 .43461 .66766 .42927 .66278 Mtetra
.652 .75 .921 r
.42927 .66278 .43461 .66766 .44379 .6651 .43847 .66021 Mtetra
.651 .75 .922 r
.43847 .66021 .44379 .6651 .453 .66256 .4477 .65765 Mtetra
.65 .75 .922 r
.4477 .65765 .453 .66256 .46225 .66002 .45696 .65511 Mtetra
.649 .75 .923 r
.45696 .65511 .46225 .66002 .47152 .65748 .46625 .65259 Mtetra
.648 .751 .924 r
.46625 .65259 .47152 .65748 .48083 .65495 .47558 .65007 Mtetra
.648 .752 .925 r
.47558 .65007 .48083 .65495 .49016 .65241 .48494 .64755 Mtetra
.647 .754 .927 r
.48494 .64755 .49016 .65241 .49954 .64985 .49433 .64503 Mtetra
.648 .756 .928 r
.49433 .64503 .49954 .64985 .50894 .64727 .50375 .64248 Mtetra
.649 .758 .929 r
.50375 .64248 .50894 .64727 .51838 .64465 .51321 .63989 Mtetra
.651 .76 .93 r
.51321 .63989 .51838 .64465 .52785 .64198 .52271 .63724 Mtetra
.653 .763 .93 r
.52271 .63724 .52785 .64198 .53735 .63926 .53223 .63453 Mtetra
.656 .764 .93 r
.53223 .63453 .53735 .63926 .54689 .63649 .54179 .63176 Mtetra
.658 .766 .929 r
.54179 .63176 .54689 .63649 .55646 .63367 .55138 .62891 Mtetra
.66 .766 .928 r
.55138 .62891 .55646 .63367 .56606 .6308 .56101 .62601 Mtetra
.661 .766 .927 r
.56101 .62601 .56606 .6308 .57569 .62791 .57066 .62307 Mtetra
.662 .765 .926 r
.57066 .62307 .57569 .62791 .58536 .625 .58035 .6201 Mtetra
.662 .763 .925 r
.58035 .6201 .58536 .625 .59506 .62208 .59007 .61713 Mtetra
.662 .761 .924 r
.59007 .61713 .59506 .62208 .60479 .61917 .59983 .61416 Mtetra
.661 .76 .923 r
.59983 .61416 .60479 .61917 .61456 .61627 .60962 .6112 Mtetra
.66 .758 .922 r
.60962 .6112 .61456 .61627 .62436 .61337 .61944 .60826 Mtetra
.659 .756 .922 r
.61944 .60826 .62436 .61337 .63419 .61049 .6293 .60534 Mtetra
.658 .755 .922 r
.6293 .60534 .63419 .61049 .64406 .60762 .63919 .60244 Mtetra
.657 .754 .922 r
.63919 .60244 .64406 .60762 .65397 .60477 .64912 .59956 Mtetra
.656 .754 .922 r
.64912 .59956 .65397 .60477 .66391 .60192 .65909 .59669 Mtetra
.654 .753 .922 r
.65909 .59669 .66391 .60192 .67389 .59908 .66909 .59384 Mtetra
.653 .753 .923 r
.66909 .59384 .67389 .59908 .6839 .59625 .67913 .59101 Mtetra
.652 .753 .924 r
.67913 .59101 .6839 .59625 .69395 .59343 .68921 .58819 Mtetra
.651 .754 .925 r
.68921 .58819 .69395 .59343 .70404 .59063 .69932 .5854 Mtetra
.649 .754 .926 r
.69932 .5854 .70404 .59063 .71417 .58783 .70948 .58262 Mtetra
.648 .755 .928 r
.70948 .58262 .71417 .58783 .72433 .58505 .71967 .57986 Mtetra
.647 .757 .929 r
.71967 .57986 .72433 .58505 .73453 .58227 .7299 .5771 Mtetra
.647 .758 .93 r
.7299 .5771 .73453 .58227 .74477 .57948 .74016 .57433 Mtetra
.647 .76 .931 r
.74016 .57433 .74477 .57948 .75505 .57668 .75047 .57154 Mtetra
.649 .762 .932 r
.75047 .57154 .75505 .57668 .76536 .57384 .76081 .5687 Mtetra
.65 .763 .932 r
.76081 .5687 .76536 .57384 .77571 .57096 .77119 .56581 Mtetra
.653 .764 .931 r
.77119 .56581 .77571 .57096 .78609 .56803 .7816 .56285 Mtetra
.655 .765 .93 r
.7816 .56285 .78609 .56803 .79651 .56505 .79204 .55981 Mtetra
.658 .764 .928 r
.79204 .55981 .79651 .56505 .80696 .56201 .80251 .55671 Mtetra
.66 .763 .926 r
.80251 .55671 .80696 .56201 .81745 .55892 .81302 .55355 Mtetra
.661 .762 .925 r
.81302 .55355 .81745 .55892 .82797 .55579 .82357 .55035 Mtetra
.662 .76 .923 r
.82357 .55035 .82797 .55579 .83852 .55263 .83415 .54713 Mtetra
.662 .758 .921 r
.83415 .54713 .83852 .55263 .84912 .54945 .84477 .54389 Mtetra
.662 .757 .92 r
.84477 .54389 .84912 .54945 .85975 .54626 .85542 .54064 Mtetra
.661 .755 .92 r
.85542 .54064 .85975 .54626 .87042 .54308 .86612 .53741 Mtetra
.661 .754 .919 r
.86612 .53741 .87042 .54308 .88113 .53989 .87686 .53419 Mtetra
.66 .753 .919 r
.87686 .53419 .88113 .53989 .89188 .53671 .88764 .53098 Mtetra
.659 .752 .919 r
.88764 .53098 .89188 .53671 .90267 .53354 .89846 .52778 Mtetra
.658 .752 .919 r
.89846 .52778 .90267 .53354 .91351 .53038 .90932 .52459 Mtetra
.657 .751 .919 r
.90932 .52459 .91351 .53038 .92438 .52721 .92022 .52141 Mtetra
.92022 .52141 .92438 .52721 .9353 .52405 .93117 .51823 Mtetra
.657 .751 .92 r
.93117 .51823 .9353 .52405 .94626 .52089 .94216 .51505 Mtetra
.656 .751 .92 r
.94216 .51505 .94626 .52089 .95725 .51772 .95319 .51186 Mtetra
.95319 .51186 .95725 .51772 .96829 .51454 .96426 .50866 Mtetra
.36922 .67351 .37472 .67831 .38373 .67572 .37826 .67091 Mtetra
.37826 .67091 .38373 .67572 .39278 .67313 .38732 .66829 Mtetra
.655 .751 .92 r
.38732 .66829 .39278 .67313 .40185 .67054 .39642 .66567 Mtetra
.655 .75 .92 r
.39642 .66567 .40185 .67054 .41096 .66795 .40554 .66305 Mtetra
.654 .75 .92 r
.40554 .66305 .41096 .66795 .4201 .66536 .4147 .66044 Mtetra
.654 .749 .92 r
.4147 .66044 .4201 .66536 .42927 .66278 .42389 .65784 Mtetra
.653 .749 .92 r
.42389 .65784 .42927 .66278 .43847 .66021 .43311 .65525 Mtetra
.652 .748 .92 r
.43311 .65525 .43847 .66021 .4477 .65765 .44236 .65267 Mtetra
.65 .748 .921 r
.44236 .65267 .4477 .65765 .45696 .65511 .45164 .65012 Mtetra
.649 .748 .922 r
.45164 .65012 .45696 .65511 .46625 .65259 .46095 .6476 Mtetra
.647 .748 .923 r
.46095 .6476 .46625 .65259 .47558 .65007 .4703 .64509 Mtetra
.646 .749 .924 r
.4703 .64509 .47558 .65007 .48494 .64755 .47968 .64259 Mtetra
.646 .75 .925 r
.47968 .64259 .48494 .64755 .49433 .64503 .48909 .6401 Mtetra
.646 .752 .927 r
.48909 .6401 .49433 .64503 .50375 .64248 .49854 .63759 Mtetra
.647 .755 .928 r
.49854 .63759 .50375 .64248 .51321 .63989 .50802 .63505 Mtetra
.648 .758 .929 r
.50802 .63505 .51321 .63989 .52271 .63724 .51753 .63244 Mtetra
.651 .761 .93 r
.51753 .63244 .52271 .63724 .53223 .63453 .52708 .62976 Mtetra
.654 .764 .93 r
.52708 .62976 .53223 .63453 .54179 .63176 .53666 .627 Mtetra
.657 .766 .93 r
.53666 .627 .54179 .63176 .55138 .62891 .54627 .62415 Mtetra
.66 .767 .929 r
.54627 .62415 .55138 .62891 .56101 .62601 .55592 .62123 Mtetra
.662 .768 .928 r
.55592 .62123 .56101 .62601 .57066 .62307 .5656 .61825 Mtetra
.664 .767 .927 r
.5656 .61825 .57066 .62307 .58035 .6201 .57531 .61523 Mtetra
.664 .766 .926 r
.57531 .61523 .58035 .6201 .59007 .61713 .58506 .61219 Mtetra
.663 .764 .925 r
.58506 .61219 .59007 .61713 .59983 .61416 .59484 .60916 Mtetra
.662 .762 .924 r
.59484 .60916 .59983 .61416 .60962 .6112 .60465 .60614 Mtetra
.661 .76 .923 r
.60465 .60614 .60962 .6112 .61944 .60826 .6145 .60315 Mtetra
.66 .758 .923 r
.6145 .60315 .61944 .60826 .6293 .60534 .62438 .60019 Mtetra
.658 .756 .922 r
.62438 .60019 .6293 .60534 .63919 .60244 .63429 .59725 Mtetra
.657 .755 .922 r
.63429 .59725 .63919 .60244 .64912 .59956 .64425 .59434 Mtetra
.655 .754 .923 r
.64425 .59434 .64912 .59956 .65909 .59669 .65424 .59145 Mtetra
.654 .754 .923 r
.65424 .59145 .65909 .59669 .66909 .59384 .66426 .58859 Mtetra
.652 .754 .924 r
.66426 .58859 .66909 .59384 .67913 .59101 .67433 .58576 Mtetra
.651 .754 .925 r
.67433 .58576 .67913 .59101 .68921 .58819 .68443 .58295 Mtetra
.649 .754 .926 r
.68443 .58295 .68921 .58819 .69932 .5854 .69457 .58017 Mtetra
.647 .755 .928 r
.69457 .58017 .69932 .5854 .70948 .58262 .70475 .57741 Mtetra
.646 .756 .929 r
.70475 .57741 .70948 .58262 .71967 .57986 .71497 .57468 Mtetra
.645 .758 .931 r
.71497 .57468 .71967 .57986 .7299 .5771 .72523 .57194 Mtetra
.645 .76 .932 r
.72523 .57194 .7299 .5771 .74016 .57433 .73553 .56919 Mtetra
.646 .761 .933 r
.73553 .56919 .74016 .57433 .75047 .57154 .74586 .5664 Mtetra
.648 .763 .933 r
.74586 .5664 .75047 .57154 .76081 .5687 .75623 .56355 Mtetra
.651 .764 .932 r
.75623 .56355 .76081 .5687 .77119 .56581 .76663 .56063 Mtetra
.654 .765 .931 r
.76663 .56063 .77119 .56581 .7816 .56285 .77707 .55761 Mtetra
.657 .765 .929 r
.77707 .55761 .7816 .56285 .79204 .55981 .78753 .55451 Mtetra
.66 .764 .927 r
.78753 .55451 .79204 .55981 .80251 .55671 .79803 .55133 Mtetra
.663 .762 .924 r
.79803 .55133 .80251 .55671 .81302 .55355 .80857 .54809 Mtetra
.664 .76 .922 r
.80857 .54809 .81302 .55355 .82357 .55035 .81913 .54481 Mtetra
.664 .758 .92 r
.81913 .54481 .82357 .55035 .83415 .54713 .82974 .54151 Mtetra
.664 .756 .919 r
.82974 .54151 .83415 .54713 .84477 .54389 .84038 .53821 Mtetra
.663 .754 .918 r
.84038 .53821 .84477 .54389 .85542 .54064 .85106 .53491 Mtetra
.662 .753 .917 r
.85106 .53491 .85542 .54064 .86612 .53741 .86178 .53164 Mtetra
.661 .752 .917 r
.86178 .53164 .86612 .53741 .87686 .53419 .87255 .52839 Mtetra
.66 .751 .918 r
.87255 .52839 .87686 .53419 .88764 .53098 .88336 .52516 Mtetra
.659 .751 .918 r
.88336 .52516 .88764 .53098 .89846 .52778 .89421 .52195 Mtetra
.658 .75 .918 r
.89421 .52195 .89846 .52778 .90932 .52459 .9051 .51874 Mtetra
.657 .75 .919 r
.9051 .51874 .90932 .52459 .92022 .52141 .91603 .51555 Mtetra
.91603 .51555 .92022 .52141 .93117 .51823 .92701 .51236 Mtetra
.656 .751 .919 r
.92701 .51236 .93117 .51823 .94216 .51505 .93803 .50916 Mtetra
.656 .751 .92 r
.93803 .50916 .94216 .51505 .95319 .51186 .94909 .50596 Mtetra
.94909 .50596 .95319 .51186 .96426 .50866 .9602 .50275 Mtetra
.36369 .66869 .36922 .67351 .37826 .67091 .37275 .66605 Mtetra
.37275 .66605 .37826 .67091 .38732 .66829 .38183 .66341 Mtetra
.38183 .66341 .38732 .66829 .39642 .66567 .39095 .66077 Mtetra
.656 .75 .919 r
.39095 .66077 .39642 .66567 .40554 .66305 .40009 .65812 Mtetra
.655 .75 .919 r
.40009 .65812 .40554 .66305 .4147 .66044 .40927 .65547 Mtetra
.654 .749 .919 r
.40927 .65547 .4147 .66044 .42389 .65784 .41848 .65284 Mtetra
.654 .748 .919 r
.41848 .65284 .42389 .65784 .43311 .65525 .42771 .65021 Mtetra
.652 .747 .919 r
.42771 .65021 .43311 .65525 .44236 .65267 .43698 .64761 Mtetra
.651 .746 .919 r
.43698 .64761 .44236 .65267 .45164 .65012 .44629 .64504 Mtetra
.649 .745 .92 r
.44629 .64504 .45164 .65012 .46095 .6476 .45562 .6425 Mtetra
.647 .745 .921 r
.45562 .6425 .46095 .6476 .4703 .64509 .46498 .63999 Mtetra
.645 .745 .922 r
.46498 .63999 .4703 .64509 .47968 .64259 .47438 .63751 Mtetra
.644 .746 .923 r
.47438 .63751 .47968 .64259 .48909 .6401 .48382 .63506 Mtetra
.643 .748 .925 r
.48382 .63506 .48909 .6401 .49854 .63759 .49328 .6326 Mtetra
.643 .751 .927 r
.49328 .6326 .49854 .63759 .50802 .63505 .50278 .63011 Mtetra
.645 .754 .929 r
.50278 .63011 .50802 .63505 .51753 .63244 .51232 .62758 Mtetra
.648 .758 .93 r
.51232 .62758 .51753 .63244 .52708 .62976 .52189 .62495 Mtetra
.652 .763 .931 r
.52189 .62495 .52708 .62976 .53666 .627 .53149 .62223 Mtetra
.656 .766 .931 r
.53149 .62223 .53666 .627 .54627 .62415 .54113 .6194 Mtetra
.66 .769 .93 r
.54113 .6194 .54627 .62415 .55592 .62123 .5508 .61647 Mtetra
.663 .77 .929 r
.5508 .61647 .55592 .62123 .5656 .61825 .56051 .61345 Mtetra
.665 .77 .928 r
.56051 .61345 .5656 .61825 .57531 .61523 .57024 .61037 Mtetra
.666 .769 .927 r
.57024 .61037 .57531 .61523 .58506 .61219 .58001 .60727 Mtetra
.665 .767 .925 r
.58001 .60727 .58506 .61219 .59484 .60916 .58981 .60417 Mtetra
.664 .764 .924 r
.58981 .60417 .59484 .60916 .60465 .60614 .59965 .60109 Mtetra
.663 .762 .924 r
.59965 .60109 .60465 .60614 .6145 .60315 .60952 .59804 Mtetra
.661 .76 .923 r
.60952 .59804 .6145 .60315 .62438 .60019 .61942 .59503 Mtetra
.659 .758 .923 r
.61942 .59503 .62438 .60019 .63429 .59725 .62936 .59205 Mtetra
.657 .757 .923 r
.62936 .59205 .63429 .59725 .64425 .59434 .63934 .58911 Mtetra
.655 .755 .923 r
.63934 .58911 .64425 .59434 .65424 .59145 .64935 .5862 Mtetra
.653 .755 .924 r
.64935 .5862 .65424 .59145 .66426 .58859 .65941 .58333 Mtetra
.651 .755 .925 r
.65941 .58333 .66426 .58859 .67433 .58576 .6695 .5805 Mtetra
.649 .755 .926 r
.6695 .5805 .67433 .58576 .68443 .58295 .67962 .57771 Mtetra
.647 .755 .928 r
.67962 .57771 .68443 .58295 .69457 .58017 .68979 .57495 Mtetra
.645 .756 .93 r
.68979 .57495 .69457 .58017 .70475 .57741 .7 .57222 Mtetra
.644 .758 .932 r
.7 .57222 .70475 .57741 .71497 .57468 .71025 .56952 Mtetra
.643 .759 .933 r
.71025 .56952 .71497 .57468 .72523 .57194 .72054 .56681 Mtetra
.643 .761 .935 r
.72054 .56681 .72523 .57194 .73553 .56919 .73086 .56407 Mtetra
.645 .763 .935 r
.73086 .56407 .73553 .56919 .74586 .5664 .74123 .56129 Mtetra
.648 .765 .934 r
.74123 .56129 .74586 .5664 .75623 .56355 .75162 .55841 Mtetra
.652 .766 .933 r
.75162 .55841 .75623 .56355 .76663 .56063 .76205 .55543 Mtetra
.657 .767 .931 r
.76205 .55543 .76663 .56063 .77707 .55761 .77251 .55233 Mtetra
.661 .766 .928 r
.77251 .55233 .77707 .55761 .78753 .55451 .783 .54914 Mtetra
.664 .764 .924 r
.783 .54914 .78753 .55451 .79803 .55133 .79352 .54585 Mtetra
.666 .761 .921 r
.79352 .54585 .79803 .55133 .80857 .54809 .80407 .54251 Mtetra
.667 .758 .919 r
.80407 .54251 .80857 .54809 .81913 .54481 .81466 .53913 Mtetra
.667 .756 .917 r
.81466 .53913 .81913 .54481 .82974 .54151 .82529 .53576 Mtetra
.666 .753 .916 r
.82529 .53576 .82974 .54151 .84038 .53821 .83595 .5324 Mtetra
.664 .751 .915 r
.83595 .5324 .84038 .53821 .85106 .53491 .84666 .52907 Mtetra
.663 .75 .915 r
.84666 .52907 .85106 .53491 .86178 .53164 .85741 .52577 Mtetra
.661 .749 .915 r
.85741 .52577 .86178 .53164 .87255 .52839 .86821 .5225 Mtetra
.66 .749 .916 r
.86821 .5225 .87255 .52839 .88336 .52516 .87905 .51927 Mtetra
.658 .749 .917 r
.87905 .51927 .88336 .52516 .89421 .52195 .88993 .51605 Mtetra
.657 .749 .918 r
.88993 .51605 .89421 .52195 .9051 .51874 .90085 .51284 Mtetra
.90085 .51284 .9051 .51874 .91603 .51555 .91182 .50964 Mtetra
.656 .75 .919 r
.91182 .50964 .91603 .51555 .92701 .51236 .92283 .50644 Mtetra
.92283 .50644 .92701 .51236 .93803 .50916 .93388 .50323 Mtetra
.656 .751 .92 r
.93388 .50323 .93803 .50916 .94909 .50596 .94497 .50002 Mtetra
.94497 .50002 .94909 .50596 .9602 .50275 .9561 .4968 Mtetra
.656 .752 .92 r
.35813 .66383 .36369 .66869 .37275 .66605 .3672 .66118 Mtetra
.656 .751 .92 r
.3672 .66118 .37275 .66605 .38183 .66341 .3763 .65851 Mtetra
.3763 .65851 .38183 .66341 .39095 .66077 .38544 .65584 Mtetra
.656 .751 .919 r
.38544 .65584 .39095 .66077 .40009 .65812 .3946 .65316 Mtetra
.656 .75 .919 r
.3946 .65316 .40009 .65812 .40927 .65547 .4038 .65048 Mtetra
.655 .749 .919 r
.4038 .65048 .40927 .65547 .41848 .65284 .41303 .6478 Mtetra
.655 .748 .919 r
.41303 .6478 .41848 .65284 .42771 .65021 .42229 .64514 Mtetra
.653 .747 .918 r
.42229 .64514 .42771 .65021 .43698 .64761 .43158 .64249 Mtetra
.652 .745 .918 r
.43158 .64249 .43698 .64761 .44629 .64504 .4409 .63988 Mtetra
.65 .744 .918 r
.4409 .63988 .44629 .64504 .45562 .6425 .45025 .6373 Mtetra
.647 .742 .919 r
.45025 .6373 .45562 .6425 .46498 .63999 .45964 .63478 Mtetra
.645 .742 .92 r
.45964 .63478 .46498 .63999 .47438 .63751 .46906 .6323 Mtetra
.642 .742 .921 r
.46906 .6323 .47438 .63751 .48382 .63506 .47851 .62987 Mtetra
.641 .743 .923 r
.47851 .62987 .48382 .63506 .49328 .6326 .488 .62746 Mtetra
.64 .745 .925 r
.488 .62746 .49328 .6326 .50278 .63011 .49752 .62506 Mtetra
.641 .749 .927 r
.49752 .62506 .50278 .63011 .51232 .62758 .50707 .6226 Mtetra
.644 .754 .929 r
.50707 .6226 .51232 .62758 .52189 .62495 .51667 .62007 Mtetra
.648 .76 .931 r
.51667 .62007 .52189 .62495 .53149 .62223 .52629 .61742 Mtetra
.653 .765 .931 r
.52629 .61742 .53149 .62223 .54113 .6194 .53595 .61463 Mtetra
.658 .769 .931 r
.53595 .61463 .54113 .6194 .5508 .61647 .54565 .61172 Mtetra
.663 .772 .931 r
.54565 .61172 .5508 .61647 .56051 .61345 .55538 .60868 Mtetra
.666 .773 .929 r
.55538 .60868 .56051 .61345 .57024 .61037 .56514 .60556 Mtetra
.667 .772 .928 r
.56514 .60556 .57024 .61037 .58001 .60727 .57493 .6024 Mtetra
.667 .77 .927 r
.57493 .6024 .58001 .60727 .58981 .60417 .58475 .59923 Mtetra
.666 .768 .926 r
.58475 .59923 .58981 .60417 .59965 .60109 .59461 .59607 Mtetra
.665 .765 .925 r
.59461 .59607 .59965 .60109 .60952 .59804 .6045 .59295 Mtetra
.662 .762 .924 r
.6045 .59295 .60952 .59804 .61942 .59503 .61443 .58988 Mtetra
.66 .76 .924 r
.61443 .58988 .61942 .59503 .62936 .59205 .6244 .58686 Mtetra
.658 .758 .924 r
.6244 .58686 .62936 .59205 .63934 .58911 .6344 .58389 Mtetra
.655 .757 .925 r
.6344 .58389 .63934 .58911 .64935 .5862 .64444 .58096 Mtetra
.653 .756 .926 r
.64444 .58096 .64935 .5862 .65941 .58333 .65452 .57809 Mtetra
.65 .756 .927 r
.65452 .57809 .65941 .58333 .6695 .5805 .66463 .57526 Mtetra
.647 .756 .928 r
.66463 .57526 .6695 .5805 .67962 .57771 .67479 .57249 Mtetra
.645 .757 .93 r
.67479 .57249 .67962 .57771 .68979 .57495 .68498 .56976 Mtetra
.642 .758 .933 r
.68498 .56976 .68979 .57495 .7 .57222 .69522 .56707 Mtetra
.641 .76 .935 r
.69522 .56707 .7 .57222 .71025 .56952 .7055 .5644 Mtetra
.64 .762 .936 r
.7055 .5644 .71025 .56952 .72054 .56681 .71582 .56172 Mtetra
.642 .764 .937 r
.71582 .56172 .72054 .56681 .73086 .56407 .72617 .55899 Mtetra
.645 .766 .937 r
.72617 .55899 .73086 .56407 .74123 .56129 .73656 .55618 Mtetra
.649 .768 .935 r
.73656 .55618 .74123 .56129 .75162 .55841 .74698 .55325 Mtetra
.655 .768 .933 r
.74698 .55325 .75162 .55841 .76205 .55543 .75743 .55018 Mtetra
.66 .767 .929 r
.75743 .55018 .76205 .55543 .77251 .55233 .76791 .54697 Mtetra
.665 .765 .925 r
.76791 .54697 .77251 .55233 .783 .54914 .77842 .54365 Mtetra
.668 .762 .921 r
.77842 .54365 .783 .54914 .79352 .54585 .78896 .54024 Mtetra
.67 .759 .917 r
.78896 .54024 .79352 .54585 .80407 .54251 .79953 .53678 Mtetra
.67 .755 .915 r
.79953 .53678 .80407 .54251 .81466 .53913 .81015 .53331 Mtetra
.668 .752 .913 r
.81015 .53331 .81466 .53913 .82529 .53576 .8208 .52987 Mtetra
.666 .75 .912 r
.8208 .52987 .82529 .53576 .83595 .5324 .83149 .52647 Mtetra
.664 .748 .913 r
.83149 .52647 .83595 .5324 .84666 .52907 .84223 .52312 Mtetra
.662 .747 .913 r
.84223 .52312 .84666 .52907 .85741 .52577 .85301 .51981 Mtetra
.66 .747 .914 r
.85301 .51981 .85741 .52577 .86821 .5225 .86383 .51655 Mtetra
.659 .747 .916 r
.86383 .51655 .86821 .5225 .87905 .51927 .8747 .51332 Mtetra
.657 .748 .917 r
.8747 .51332 .87905 .51927 .88993 .51605 .88562 .5101 Mtetra
.657 .749 .918 r
.88562 .5101 .88993 .51605 .90085 .51284 .89657 .5069 Mtetra
.656 .749 .919 r
.89657 .5069 .90085 .51284 .91182 .50964 .90757 .50369 Mtetra
.656 .75 .919 r
.90757 .50369 .91182 .50964 .92283 .50644 .91861 .50048 Mtetra
.655 .75 .92 r
.91861 .50048 .92283 .50644 .93388 .50323 .92969 .49727 Mtetra
.655 .751 .92 r
.92969 .49727 .93388 .50323 .94497 .50002 .94082 .49404 Mtetra
.94082 .49404 .94497 .50002 .9561 .4968 .95198 .4908 Mtetra
.656 .752 .92 r
.35253 .65894 .35813 .66383 .3672 .66118 .36162 .65627 Mtetra
.36162 .65627 .3672 .66118 .3763 .65851 .37074 .65359 Mtetra
.657 .752 .92 r
.37074 .65359 .3763 .65851 .38544 .65584 .3799 .65089 Mtetra
.657 .751 .92 r
.3799 .65089 .38544 .65584 .3946 .65316 .38908 .64819 Mtetra
.657 .751 .919 r
.38908 .64819 .3946 .65316 .4038 .65048 .3983 .64547 Mtetra
.657 .75 .919 r
.3983 .64547 .4038 .65048 .41303 .6478 .40755 .64275 Mtetra
.656 .749 .918 r
.40755 .64275 .41303 .6478 .42229 .64514 .41683 .64003 Mtetra
.655 .747 .918 r
.41683 .64003 .42229 .64514 .43158 .64249 .42614 .63733 Mtetra
.654 .745 .917 r
.42614 .63733 .43158 .64249 .4409 .63988 .43548 .63465 Mtetra
.652 .743 .917 r
.43548 .63465 .4409 .63988 .45025 .6373 .44486 .63202 Mtetra
.649 .741 .917 r
.44486 .63202 .45025 .6373 .45964 .63478 .45426 .62945 Mtetra
.645 .739 .917 r
.45426 .62945 .45964 .63478 .46906 .6323 .4637 .62695 Mtetra
.641 .737 .918 r
.4637 .62695 .46906 .6323 .47851 .62987 .47317 .62453 Mtetra
.639 .737 .92 r
.47317 .62453 .47851 .62987 .488 .62746 .48268 .62217 Mtetra
.636 .739 .923 r
.48268 .62217 .488 .62746 .49752 .62506 .49222 .61984 Mtetra
.636 .743 .926 r
.49222 .61984 .49752 .62506 .50707 .6226 .5018 .61749 Mtetra
.638 .748 .929 r
.5018 .61749 .50707 .6226 .51667 .62007 .51141 .61508 Mtetra
.642 .755 .931 r
.51141 .61508 .51667 .62007 .52629 .61742 .52106 .61255 Mtetra
.648 .763 .932 r
.52106 .61255 .52629 .61742 .53595 .61463 .53074 .60985 Mtetra
.655 .769 .933 r
.53074 .60985 .53595 .61463 .54565 .61172 .54046 .60699 Mtetra
.661 .773 .933 r
.54046 .60699 .54565 .61172 .55538 .60868 .55021 .60396 Mtetra
.666 .776 .931 r
.55021 .60396 .55538 .60868 .56514 .60556 .56 .60081 Mtetra
.669 .776 .93 r
.56 .60081 .56514 .60556 .57493 .6024 .56981 .59758 Mtetra
.669 .774 .928 r
.56981 .59758 .57493 .6024 .58475 .59923 .57966 .59433 Mtetra
.669 .772 .927 r
.57966 .59433 .58475 .59923 .59461 .59607 .58955 .5911 Mtetra
.667 .769 .926 r
.58955 .5911 .59461 .59607 .6045 .59295 .59946 .5879 Mtetra
.664 .766 .926 r
.59946 .5879 .6045 .59295 .61443 .58988 .60941 .58477 Mtetra
.661 .763 .925 r
.60941 .58477 .61443 .58988 .6244 .58686 .6194 .58169 Mtetra
.658 .761 .926 r
.6194 .58169 .6244 .58686 .6344 .58389 .62943 .57868 Mtetra
.655 .759 .926 r
.62943 .57868 .6344 .58389 .64444 .58096 .63949 .57574 Mtetra
.652 .758 .927 r
.63949 .57574 .64444 .58096 .65452 .57809 .6496 .57286 Mtetra
.648 .758 .929 r
.6496 .57286 .65452 .57809 .66463 .57526 .65974 .57005 Mtetra
.645 .758 .931 r
.65974 .57005 .66463 .57526 .67479 .57249 .66992 .5673 Mtetra
.642 .759 .933 r
.66992 .5673 .67479 .57249 .68498 .56976 .68015 .56461 Mtetra
.639 .76 .936 r
.68015 .56461 .68498 .56976 .69522 .56707 .69041 .56197 Mtetra
.637 .762 .938 r
.69041 .56197 .69522 .56707 .7055 .5644 .70072 .55933 Mtetra
.638 .764 .94 r
.70072 .55933 .7055 .5644 .71582 .56172 .71107 .55668 Mtetra
.64 .767 .94 r
.71107 .55668 .71582 .56172 .72617 .55899 .72145 .55394 Mtetra
.645 .769 .939 r
.72145 .55394 .72617 .55899 .73656 .55618 .73186 .55109 Mtetra
.652 .771 .936 r
.73186 .55109 .73656 .55618 .74698 .55325 .74231 .54807 Mtetra
.659 .77 .932 r
.74231 .54807 .74698 .55325 .75743 .55018 .75278 .54487 Mtetra
.666 .768 .926 r
.75278 .54487 .75743 .55018 .76791 .54697 .76328 .54151 Mtetra
.671 .765 .921 r
.76328 .54151 .76791 .54697 .77842 .54365 .7738 .53802 Mtetra
.673 .76 .916 r
.7738 .53802 .77842 .54365 .78896 .54024 .78436 .53446 Mtetra
.674 .755 .912 r
.78436 .53446 .78896 .54024 .79953 .53678 .79496 .53087 Mtetra
.672 .751 .91 r
.79496 .53087 .79953 .53678 .81015 .53331 .80559 .52732 Mtetra
.67 .748 .909 r
.80559 .52732 .81015 .53331 .8208 .52987 .81627 .52383 Mtetra
.666 .746 .909 r
.81627 .52383 .8208 .52987 .83149 .52647 .82699 .52041 Mtetra
.663 .745 .911 r
.82699 .52041 .83149 .52647 .84223 .52312 .83776 .51707 Mtetra
.661 .745 .912 r
.83776 .51707 .84223 .52312 .85301 .51981 .84857 .51378 Mtetra
.659 .745 .914 r
.84857 .51378 .85301 .51981 .86383 .51655 .85943 .51054 Mtetra
.657 .746 .916 r
.85943 .51054 .86383 .51655 .8747 .51332 .87033 .50733 Mtetra
.656 .747 .917 r
.87033 .50733 .8747 .51332 .88562 .5101 .88128 .50413 Mtetra
.655 .749 .918 r
.88128 .50413 .88562 .5101 .89657 .5069 .89227 .50093 Mtetra
.655 .75 .919 r
.89227 .50093 .89657 .5069 .90757 .50369 .9033 .49772 Mtetra
.655 .75 .92 r
.9033 .49772 .90757 .50369 .91861 .50048 .91437 .4945 Mtetra
.655 .751 .92 r
.91437 .4945 .91861 .50048 .92969 .49727 .92548 .49127 Mtetra
.92548 .49127 .92969 .49727 .94082 .49404 .93664 .48802 Mtetra
.93664 .48802 .94082 .49404 .95198 .4908 .94784 .48476 Mtetra
.656 .751 .92 r
.34689 .65403 .35253 .65894 .36162 .65627 .356 .65134 Mtetra
.656 .752 .92 r
.356 .65134 .36162 .65627 .37074 .65359 .36515 .64865 Mtetra
.36515 .64865 .37074 .65359 .3799 .65089 .37432 .64594 Mtetra
.657 .752 .92 r
.37432 .64594 .3799 .65089 .38908 .64819 .38353 .64321 Mtetra
.38353 .64321 .38908 .64819 .3983 .64547 .39276 .64047 Mtetra
.39276 .64047 .3983 .64547 .40755 .64275 .40203 .63771 Mtetra
.658 .751 .919 r
.40203 .63771 .40755 .64275 .41683 .64003 .41133 .63493 Mtetra
.657 .749 .918 r
.41133 .63493 .41683 .64003 .42614 .63733 .42067 .63216 Mtetra
.656 .747 .917 r
.42067 .63216 .42614 .63733 .43548 .63465 .43003 .62941 Mtetra
.654 .744 .916 r
.43003 .62941 .43548 .63465 .44486 .63202 .43943 .62669 Mtetra
.651 .741 .915 r
.43943 .62669 .44486 .63202 .45426 .62945 .44885 .62405 Mtetra
.647 .738 .915 r
.44885 .62405 .45426 .62945 .4637 .62695 .45831 .62149 Mtetra
.642 .735 .916 r
.45831 .62149 .4637 .62695 .47317 .62453 .4678 .61904 Mtetra
.638 .733 .917 r
.4678 .61904 .47317 .62453 .48268 .62217 .47733 .61669 Mtetra
.633 .733 .92 r
.47733 .61669 .48268 .62217 .49222 .61984 .48689 .61444 Mtetra
.631 .735 .923 r
.48689 .61444 .49222 .61984 .5018 .61749 .49648 .61221 Mtetra
.631 .741 .927 r
.49648 .61221 .5018 .61749 .51141 .61508 .50612 .60995 Mtetra
.635 .748 .93 r
.50612 .60995 .51141 .61508 .52106 .61255 .51579 .60757 Mtetra
.642 .757 .933 r
.51579 .60757 .52106 .61255 .53074 .60985 .52549 .60501 Mtetra
.65 .766 .934 r
.52549 .60501 .53074 .60985 .54046 .60699 .53524 .60225 Mtetra
.658 .774 .934 r
.53524 .60225 .54046 .60699 .55021 .60396 .54501 .59927 Mtetra
.665 .778 .934 r
.54501 .59927 .55021 .60396 .56 .60081 .55482 .59612 Mtetra
.67 .78 .932 r
.55482 .59612 .56 .60081 .56981 .59758 .56467 .59284 Mtetra
.671 .779 .931 r
.56467 .59284 .56981 .59758 .57966 .59433 .57454 .58952 Mtetra
.671 .777 .929 r
.57454 .58952 .57966 .59433 .58955 .5911 .58445 .5862 Mtetra
.669 .774 .928 r
.58445 .5862 .58955 .5911 .59946 .5879 .59439 .58292 Mtetra
.666 .77 .928 r
.59439 .58292 .59946 .5879 .60941 .58477 .60436 .57971 Mtetra
.662 .767 .928 r
.60436 .57971 .60941 .58477 .6194 .58169 .61438 .57658 Mtetra
.659 .764 .928 r
.61438 .57658 .6194 .58169 .62943 .57868 .62443 .57353 Mtetra
.655 .762 .929 r
.62443 .57353 .62943 .57868 .63949 .57574 .63452 .57057 Mtetra
.651 .761 .93 r
.63452 .57057 .63949 .57574 .6496 .57286 .64464 .56769 Mtetra
.646 .76 .932 r
.64464 .56769 .6496 .57286 .65974 .57005 .65481 .5649 Mtetra
.642 .761 .935 r
.65481 .5649 .65974 .57005 .66992 .5673 .66503 .56218 Mtetra
.638 .761 .937 r
.66503 .56218 .66992 .5673 .68015 .56461 .67528 .55954 Mtetra
.635 .763 .94 r
.67528 .55954 .68015 .56461 .69041 .56197 .68558 .55694 Mtetra
.634 .765 .942 r
.68558 .55694 .69041 .56197 .70072 .55933 .69591 .55435 Mtetra
.635 .768 .943 r
.69591 .55435 .70072 .55933 .71107 .55668 .70629 .5517 Mtetra
.64 .771 .943 r
.70629 .5517 .71107 .55668 .72145 .55394 .7167 .54893 Mtetra
.647 .773 .94 r
.7167 .54893 .72145 .55394 .73186 .55109 .72714 .54599 Mtetra
.657 .774 .935 r
.72714 .54599 .73186 .55109 .74231 .54807 .7376 .54282 Mtetra
.666 .772 .929 r
.7376 .54282 .74231 .54807 .75278 .54487 .74809 .53945 Mtetra
.673 .768 .922 r
.74809 .53945 .75278 .54487 .76328 .54151 .75861 .53588 Mtetra
.677 .762 .915 r
.75861 .53588 .76328 .54151 .7738 .53802 .76915 .5322 Mtetra
.678 .756 .91 r
.76915 .5322 .7738 .53802 .78436 .53446 .77972 .52848 Mtetra
.677 .751 .907 r
.77972 .52848 .78436 .53446 .79496 .53087 .79034 .52478 Mtetra
.673 .746 .906 r
.79034 .52478 .79496 .53087 .80559 .52732 .801 .52117 Mtetra
.669 .743 .906 r
.801 .52117 .80559 .52732 .81627 .52383 .8117 .51767 Mtetra
.665 .742 .908 r
.8117 .51767 .81627 .52383 .82699 .52041 .82245 .51427 Mtetra
.661 .742 .91 r
.82245 .51427 .82699 .52041 .83776 .51707 .83325 .51097 Mtetra
.658 .743 .913 r
.83325 .51097 .83776 .51707 .84857 .51378 .8441 .50773 Mtetra
.656 .745 .915 r
.8441 .50773 .84857 .51378 .85943 .51054 .855 .50453 Mtetra
.655 .747 .917 r
.855 .50453 .85943 .51054 .87033 .50733 .86593 .50135 Mtetra
.654 .748 .919 r
.86593 .50135 .87033 .50733 .88128 .50413 .87691 .49816 Mtetra
.654 .75 .92 r
.87691 .49816 .88128 .50413 .89227 .50093 .88793 .49496 Mtetra
.654 .751 .921 r
.88793 .49496 .89227 .50093 .9033 .49772 .899 .49175 Mtetra
.655 .752 .921 r
.899 .49175 .9033 .49772 .91437 .4945 .9101 .48851 Mtetra
.9101 .48851 .91437 .4945 .92548 .49127 .92124 .48525 Mtetra
.92124 .48525 .92548 .49127 .93664 .48802 .93243 .48198 Mtetra
.656 .752 .921 r
.93243 .48198 .93664 .48802 .94784 .48476 .94366 .47868 Mtetra
.655 .751 .921 r
.34122 .64908 .34689 .65403 .356 .65134 .35035 .6464 Mtetra
.655 .752 .921 r
.35035 .6464 .356 .65134 .36515 .64865 .35951 .6437 Mtetra
.656 .753 .921 r
.35951 .6437 .36515 .64865 .37432 .64594 .3687 .64099 Mtetra
.656 .754 .922 r
.3687 .64099 .37432 .64594 .38353 .64321 .37793 .63826 Mtetra
.657 .754 .922 r
.37793 .63826 .38353 .64321 .39276 .64047 .38719 .63549 Mtetra
.658 .754 .921 r
.38719 .63549 .39276 .64047 .40203 .63771 .39648 .6327 Mtetra
.659 .754 .92 r
.39648 .6327 .40203 .63771 .41133 .63493 .4058 .62988 Mtetra
.659 .753 .919 r
.4058 .62988 .41133 .63493 .42067 .63216 .41515 .62704 Mtetra
.659 .751 .918 r
.41515 .62704 .42067 .63216 .43003 .62941 .42454 .62419 Mtetra
.658 .748 .916 r
.42454 .62419 .43003 .62941 .43943 .62669 .43396 .62137 Mtetra
.655 .743 .915 r
.43396 .62137 .43943 .62669 .44885 .62405 .44341 .6186 Mtetra
.651 .738 .913 r
.44341 .6186 .44885 .62405 .45831 .62149 .45289 .61593 Mtetra
.645 .733 .913 r
.45289 .61593 .45831 .62149 .4678 .61904 .4624 .6134 Mtetra
.639 .729 .914 r
.4624 .6134 .4678 .61904 .47733 .61669 .47195 .61102 Mtetra
.631 .726 .916 r
.47195 .61102 .47733 .61669 .48689 .61444 .48152 .60881 Mtetra
.626 .727 .919 r
.48152 .60881 .48689 .61444 .49648 .61221 .49114 .60669 Mtetra
.623 .731 .924 r
.49114 .60669 .49648 .61221 .50612 .60995 .50079 .60461 Mtetra
.626 .739 .929 r
.50079 .60461 .50612 .60995 .51579 .60757 .51048 .60244 Mtetra
.632 .75 .933 r
.51048 .60244 .51579 .60757 .52549 .60501 .52021 .60009 Mtetra
.641 .762 .936 r
.52021 .60009 .52549 .60501 .53524 .60225 .52998 .5975 Mtetra
.653 .773 .937 r
.52998 .5975 .53524 .60225 .54501 .59927 .53978 .59461 Mtetra
.662 .78 .937 r
.53978 .59461 .54501 .59927 .55482 .59612 .54962 .5915 Mtetra
.669 .785 .935 r
.54962 .5915 .55482 .59612 .56467 .59284 .55948 .5882 Mtetra
.673 .785 .934 r
.55948 .5882 .56467 .59284 .57454 .58952 .56938 .58481 Mtetra
.673 .783 .932 r
.56938 .58481 .57454 .58952 .58445 .5862 .57931 .5814 Mtetra
.672 .78 .931 r
.57931 .5814 .58445 .5862 .59439 .58292 .58928 .57803 Mtetra
.668 .776 .93 r
.58928 .57803 .59439 .58292 .60436 .57971 .59928 .57473 Mtetra
.664 .772 .93 r
.59928 .57473 .60436 .57971 .61438 .57658 .60932 .57154 Mtetra
.659 .769 .931 r
.60932 .57154 .61438 .57658 .62443 .57353 .61939 .56845 Mtetra
.654 .767 .932 r
.61939 .56845 .62443 .57353 .63452 .57057 .62951 .56547 Mtetra
.649 .765 .934 r
.62951 .56547 .63452 .57057 .64464 .56769 .63966 .56259 Mtetra
.644 .764 .936 r
.63966 .56259 .64464 .56769 .65481 .5649 .64986 .55983 Mtetra
.638 .764 .939 r
.64986 .55983 .65481 .5649 .66503 .56218 .6601 .55716 Mtetra
.634 .765 .942 r
.6601 .55716 .66503 .56218 .67528 .55954 .67039 .55457 Mtetra
.631 .767 .945 r
.67039 .55457 .67528 .55954 .68558 .55694 .68071 .55202 Mtetra
.63 .77 .947 r
.68071 .55202 .68558 .55694 .69591 .55435 .69108 .54946 Mtetra
.634 .773 .947 r
.69108 .54946 .69591 .55435 .70629 .5517 .70148 .5468 Mtetra
.642 .776 .945 r
.70148 .5468 .70629 .5517 .7167 .54893 .71192 .54395 Mtetra
.652 .778 .94 r
.71192 .54395 .7167 .54893 .72714 .54599 .72238 .54087 Mtetra
.665 .777 .933 r
.72238 .54087 .72714 .54599 .7376 .54282 .73286 .53749 Mtetra
.675 .773 .924 r
.73286 .53749 .7376 .54282 .74809 .53945 .74336 .53387 Mtetra
.682 .766 .915 r
.74336 .53387 .74809 .53945 .75861 .53588 .75389 .53005 Mtetra
.684 .758 .908 r
.75389 .53005 .75861 .53588 .76915 .5322 .76444 .52614 Mtetra
.682 .751 .903 r
.76444 .52614 .76915 .5322 .77972 .52848 .77504 .52227 Mtetra
.679 .745 .901 r
.77504 .52227 .77972 .52848 .79034 .52478 .78567 .51848 Mtetra
.673 .74 .901 r
.78567 .51848 .79034 .52478 .801 .52117 .79636 .51487 Mtetra
.667 .738 .903 r
.79636 .51487 .801 .52117 .8117 .51767 .8071 .5114 Mtetra
.661 .739 .907 r
.8071 .5114 .8117 .51767 .82245 .51427 .81789 .50808 Mtetra
.657 .74 .911 r
.81789 .50808 .82245 .51427 .83325 .51097 .82872 .50486 Mtetra
.655 .743 .915 r
.82872 .50486 .83325 .51097 .8441 .50773 .83961 .50169 Mtetra
.653 .746 .918 r
.83961 .50169 .8441 .50773 .855 .50453 .85054 .49855 Mtetra
.653 .749 .92 r
.85054 .49855 .855 .50453 .86593 .50135 .86151 .4954 Mtetra
.653 .751 .922 r
.86151 .4954 .86593 .50135 .87691 .49816 .87253 .49223 Mtetra
.654 .752 .922 r
.87253 .49223 .87691 .49816 .88793 .49496 .88358 .48902 Mtetra
.654 .753 .922 r
.88358 .48902 .88793 .49496 .899 .49175 .89467 .48578 Mtetra
.655 .754 .922 r
.89467 .48578 .899 .49175 .9101 .48851 .9058 .48251 Mtetra
.656 .753 .922 r
.9058 .48251 .9101 .48851 .92124 .48525 .91698 .47922 Mtetra
.656 .753 .921 r
.91698 .47922 .92124 .48525 .93243 .48198 .92819 .4759 Mtetra
.656 .752 .921 r
.92819 .4759 .93243 .48198 .94366 .47868 .93945 .47256 Mtetra
.654 .751 .921 r
.33552 .6441 .34122 .64908 .35035 .6464 .34466 .64143 Mtetra
.654 .752 .922 r
.34466 .64143 .35035 .6464 .35951 .6437 .35384 .63874 Mtetra
.654 .753 .922 r
.35384 .63874 .35951 .6437 .3687 .64099 .36305 .63604 Mtetra
.655 .754 .923 r
.36305 .63604 .3687 .64099 .37793 .63826 .3723 .63331 Mtetra
.656 .755 .923 r
.3723 .63331 .37793 .63826 .38719 .63549 .38157 .63055 Mtetra
.657 .756 .923 r
.38157 .63055 .38719 .63549 .39648 .6327 .39088 .62774 Mtetra
.659 .757 .922 r
.39088 .62774 .39648 .6327 .4058 .62988 .40023 .62489 Mtetra
.661 .757 .921 r
.40023 .62489 .4058 .62988 .41515 .62704 .4096 .62199 Mtetra
.662 .756 .92 r
.4096 .62199 .41515 .62704 .42454 .62419 .41901 .61905 Mtetra
.662 .753 .918 r
.41901 .61905 .42454 .62419 .43396 .62137 .42846 .61611 Mtetra
.661 .749 .916 r
.42846 .61611 .43396 .62137 .44341 .6186 .43793 .6132 Mtetra
.657 .743 .913 r
.43793 .6132 .44341 .6186 .45289 .61593 .44743 .61037 Mtetra
.651 .736 .912 r
.44743 .61037 .45289 .61593 .4624 .6134 .45697 .60769 Mtetra
.642 .729 .911 r
.45697 .60769 .4624 .6134 .47195 .61102 .46653 .60521 Mtetra
.632 .722 .912 r
.46653 .60521 .47195 .61102 .48152 .60881 .47613 .60297 Mtetra
.624 .719 .915 r
.47613 .60297 .48152 .60881 .49114 .60669 .48576 .60091 Mtetra
.616 .72 .92 r
.48576 .60091 .49114 .60669 .50079 .60461 .49543 .599 Mtetra
.615 .726 .925 r
.49543 .599 .50079 .60461 .51048 .60244 .50514 .59707 Mtetra
.62 .738 .931 r
.50514 .59707 .51048 .60244 .52021 .60009 .51489 .59499 Mtetra
.63 .752 .936 r
.51489 .59499 .52021 .60009 .52998 .5975 .52468 .59264 Mtetra
.644 .768 .938 r
.52468 .59264 .52998 .5975 .53978 .59461 .53451 .58994 Mtetra
.656 .779 .939 r
.53451 .58994 .53978 .59461 .54962 .5915 .54437 .58694 Mtetra
.667 .788 .938 r
.54437 .58694 .54962 .5915 .55948 .5882 .55426 .58366 Mtetra
.673 .791 .937 r
.55426 .58366 .55948 .5882 .56938 .58481 .56419 .58023 Mtetra
.675 .791 .936 r
.56419 .58023 .56938 .58481 .57931 .5814 .57415 .57674 Mtetra
.674 .788 .935 r
.57415 .57674 .57931 .5814 .58928 .57803 .58414 .57327 Mtetra
.67 .784 .934 r
.58414 .57327 .58928 .57803 .59928 .57473 .59416 .56989 Mtetra
.665 .779 .934 r
.59416 .56989 .59928 .57473 .60932 .57154 .60423 .56662 Mtetra
.659 .776 .935 r
.60423 .56662 .60932 .57154 .61939 .56845 .61433 .56349 Mtetra
.653 .773 .936 r
.61433 .56349 .61939 .56845 .62951 .56547 .62447 .56048 Mtetra
.647 .77 .939 r
.62447 .56048 .62951 .56547 .63966 .56259 .63465 .55762 Mtetra
.64 .769 .942 r
.63465 .55762 .63966 .56259 .64986 .55983 .64488 .55489 Mtetra
.634 .769 .945 r
.64488 .55489 .64986 .55983 .6601 .55716 .65515 .55227 Mtetra
.628 .77 .948 r
.65515 .55227 .6601 .55716 .67039 .55457 .66546 .54973 Mtetra
.626 .773 .951 r
.66546 .54973 .67039 .55457 .68071 .55202 .67582 .54723 Mtetra
.628 .776 .952 r
.67582 .54723 .68071 .55202 .69108 .54946 .68622 .54466 Mtetra
.634 .779 .951 r
.68622 .54466 .69108 .54946 .70148 .5468 .69665 .54195 Mtetra
.647 .782 .946 r
.69665 .54195 .70148 .5468 .71192 .54395 .7071 .53895 Mtetra
.661 .781 .938 r
.7071 .53895 .71192 .54395 .72238 .54087 .71758 .53564 Mtetra
.676 .778 .927 r
.71758 .53564 .72238 .54087 .73286 .53749 .72807 .53198 Mtetra
.686 .771 .916 r
.72807 .53198 .73286 .53749 .74336 .53387 .73859 .52803 Mtetra
.691 .761 .906 r
.73859 .52803 .74336 .53387 .75389 .53005 .74912 .52394 Mtetra
.69 .752 .899 r
.74912 .52394 .75389 .53005 .76444 .52614 .75969 .51981 Mtetra
.685 .743 .896 r
.75969 .51981 .76444 .52614 .77504 .52227 .77031 .51583 Mtetra
.678 .738 .896 r
.77031 .51583 .77504 .52227 .78567 .51848 .78097 .51203 Mtetra
.669 .735 .899 r
.78097 .51203 .78567 .51848 .79636 .51487 .79169 .50848 Mtetra
.662 .735 .904 r
.79169 .50848 .79636 .51487 .8071 .5114 .80247 .50513 Mtetra
.656 .738 .91 r
.80247 .50513 .8071 .5114 .81789 .50808 .8133 .50193 Mtetra
.652 .741 .915 r
.8133 .50193 .81789 .50808 .82872 .50486 .82417 .49882 Mtetra
.65 .746 .919 r
.82417 .49882 .82872 .50486 .83961 .50169 .8351 .49574 Mtetra
.65 .749 .922 r
.8351 .49574 .83961 .50169 .85054 .49855 .84607 .49264 Mtetra
.651 .752 .924 r
.84607 .49264 .85054 .49855 .86151 .4954 .85707 .48951 Mtetra
.652 .754 .925 r
.85707 .48951 .86151 .4954 .87253 .49223 .86812 .48633 Mtetra
.654 .755 .924 r
.86812 .48633 .87253 .49223 .88358 .48902 .8792 .4831 Mtetra
.655 .756 .924 r
.8792 .4831 .88358 .48902 .89467 .48578 .89032 .47982 Mtetra
.656 .755 .923 r
.89032 .47982 .89467 .48578 .9058 .48251 .90148 .4765 Mtetra
.657 .755 .922 r
.90148 .4765 .9058 .48251 .91698 .47922 .91268 .47315 Mtetra
.657 .754 .921 r
.91268 .47315 .91698 .47922 .92819 .4759 .92393 .46978 Mtetra
.657 .753 .921 r
.92393 .46978 .92819 .4759 .93945 .47256 .93521 .46639 Mtetra
.653 .751 .922 r
.32977 .63908 .33552 .6441 .34466 .64143 .33894 .63643 Mtetra
.652 .752 .923 r
.33894 .63643 .34466 .64143 .35384 .63874 .34813 .63376 Mtetra
.653 .753 .923 r
.34813 .63376 .35384 .63874 .36305 .63604 .35736 .63108 Mtetra
.653 .755 .924 r
.35736 .63108 .36305 .63604 .3723 .63331 .36662 .62837 Mtetra
.654 .757 .925 r
.36662 .62837 .3723 .63331 .38157 .63055 .37592 .62563 Mtetra
.656 .759 .925 r
.37592 .62563 .38157 .63055 .39088 .62774 .38525 .62284 Mtetra
.658 .76 .925 r
.38525 .62284 .39088 .62774 .40023 .62489 .39461 .61998 Mtetra
.661 .762 .925 r
.39461 .61998 .40023 .62489 .4096 .62199 .40401 .61706 Mtetra
.664 .762 .923 r
.40401 .61706 .4096 .62199 .41901 .61905 .41345 .61406 Mtetra
.665 .761 .921 r
.41345 .61406 .41901 .61905 .42846 .61611 .42291 .611 Mtetra
.667 .757 .918 r
.42291 .611 .42846 .61611 .43793 .6132 .43241 .60791 Mtetra
.664 .751 .915 r
.43241 .60791 .43793 .6132 .44743 .61037 .44194 .60488 Mtetra
.659 .742 .911 r
.44194 .60488 .44743 .61037 .45697 .60769 .4515 .60196 Mtetra
.65 .732 .909 r
.4515 .60196 .45697 .60769 .46653 .60521 .46109 .59927 Mtetra
.637 .721 .908 r
.46109 .59927 .46653 .60521 .47613 .60297 .47071 .5969 Mtetra
.624 .713 .91 r
.47071 .5969 .47613 .60297 .48576 .60091 .48036 .59483 Mtetra
.611 .708 .914 r
.48036 .59483 .48576 .60091 .49543 .599 .49004 .59306 Mtetra
.605 .712 .92 r
.49004 .59306 .49543 .599 .50514 .59707 .49977 .59138 Mtetra
.605 .722 .927 r
.49977 .59138 .50514 .59707 .51489 .59499 .50954 .58964 Mtetra
.614 .739 .934 r
.50954 .58964 .51489 .59499 .52468 .59264 .51935 .58764 Mtetra
.631 .759 .939 r
.51935 .58764 .52468 .59264 .53451 .58994 .5292 .58523 Mtetra
.646 .776 .942 r
.5292 .58523 .53451 .58994 .54437 .58694 .53909 .58242 Mtetra
.662 .789 .942 r
.53909 .58242 .54437 .58694 .55426 .58366 .54901 .57922 Mtetra
.671 .796 .941 r
.54901 .57922 .55426 .58366 .56419 .58023 .55896 .5758 Mtetra
.676 .798 .94 r
.55896 .5758 .56419 .58023 .57415 .57674 .56895 .57225 Mtetra
.676 .797 .939 r
.56895 .57225 .57415 .57674 .58414 .57327 .57897 .56869 Mtetra
.672 .793 .939 r
.57897 .56869 .58414 .57327 .59416 .56989 .58902 .56522 Mtetra
.667 .788 .939 r
.58902 .56522 .59416 .56989 .60423 .56662 .59911 .56187 Mtetra
.66 .784 .94 r
.59911 .56187 .60423 .56662 .61433 .56349 .60923 .55869 Mtetra
.652 .78 .942 r
.60923 .55869 .61433 .56349 .62447 .56048 .6194 .55567 Mtetra
.644 .778 .945 r
.6194 .55567 .62447 .56048 .63465 .55762 .62961 .55281 Mtetra
.635 .776 .948 r
.62961 .55281 .63465 .55762 .64488 .55489 .63987 .55012 Mtetra
.628 .776 .952 r
.63987 .55012 .64488 .55489 .65515 .55227 .65017 .54755 Mtetra
.623 .777 .955 r
.65017 .54755 .65515 .55227 .66546 .54973 .66051 .54507 Mtetra
.621 .78 .957 r
.66051 .54507 .66546 .54973 .67582 .54723 .6709 .54259 Mtetra
.626 .784 .957 r
.6709 .54259 .67582 .54723 .68622 .54466 .68132 .53998 Mtetra
.638 .786 .953 r
.68132 .53998 .68622 .54466 .69665 .54195 .69178 .53714 Mtetra
.656 .788 .945 r
.69178 .53714 .69665 .54195 .7071 .53895 .70225 .5339 Mtetra
.674 .785 .933 r
.70225 .5339 .7071 .53895 .71758 .53564 .71274 .53026 Mtetra
.69 .777 .918 r
.71274 .53026 .71758 .53564 .72807 .53198 .72324 .52621 Mtetra
.698 .766 .905 r
.72324 .52621 .72807 .53198 .73859 .52803 .73376 .52187 Mtetra
.699 .754 .894 r
.73376 .52187 .73859 .52803 .74912 .52394 .74431 .51747 Mtetra
.694 .743 .889 r
.74431 .51747 .74912 .52394 .75969 .51981 .75489 .51316 Mtetra
.684 .734 .888 r
.75489 .51316 .75969 .51981 .77031 .51583 .76553 .50915 Mtetra
.674 .73 .892 r
.76553 .50915 .77031 .51583 .78097 .51203 .77623 .50545 Mtetra
.663 .73 .899 r
.77623 .50545 .78097 .51203 .79169 .50848 .78699 .50207 Mtetra
.654 .733 .907 r
.78699 .50207 .79169 .50848 .80247 .50513 .79781 .49892 Mtetra
.649 .738 .915 r
.79781 .49892 .80247 .50513 .8133 .50193 .80869 .49589 Mtetra
.646 .744 .921 r
.80869 .49589 .8133 .50193 .82417 .49882 .81961 .49292 Mtetra
.646 .751 .925 r
.81961 .49292 .82417 .49882 .8351 .49574 .83057 .48992 Mtetra
.647 .755 .928 r
.83057 .48992 .8351 .49574 .84607 .49264 .84157 .48685 Mtetra
.65 .758 .928 r
.84157 .48685 .84607 .49264 .85707 .48951 .85261 .4837 Mtetra
.652 .759 .928 r
.85261 .4837 .85707 .48951 .86812 .48633 .86369 .48048 Mtetra
.654 .759 .927 r
.86369 .48048 .86812 .48633 .8792 .4831 .8748 .47719 Mtetra
.656 .759 .925 r
.8748 .47719 .8792 .4831 .89032 .47982 .88595 .47385 Mtetra
.657 .758 .924 r
.88595 .47385 .89032 .47982 .90148 .4765 .89713 .47047 Mtetra
.658 .756 .923 r
.89713 .47047 .90148 .4765 .91268 .47315 .90836 .46706 Mtetra
.658 .755 .921 r
.90836 .46706 .91268 .47315 .92393 .46978 .91963 .46363 Mtetra
.658 .754 .92 r
.91963 .46363 .92393 .46978 .93521 .46639 .93095 .46018 Mtetra
.652 .75 .922 r
.32399 .63404 .32977 .63908 .33894 .63643 .33318 .63139 Mtetra
.651 .751 .923 r
.33318 .63139 .33894 .63643 .34813 .63376 .34239 .62874 Mtetra
.651 .752 .924 r
.34239 .62874 .34813 .63376 .35736 .63108 .35164 .62607 Mtetra
.651 .754 .925 r
.35164 .62607 .35736 .63108 .36662 .62837 .36092 .62339 Mtetra
.652 .756 .926 r
.36092 .62339 .36662 .62837 .37592 .62563 .37023 .62068 Mtetra
.653 .758 .927 r
.37023 .62068 .37592 .62563 .38525 .62284 .37958 .61793 Mtetra
.655 .761 .927 r
.37958 .61793 .38525 .62284 .39461 .61998 .38896 .61512 Mtetra
.659 .764 .927 r
.38896 .61512 .39461 .61998 .40401 .61706 .39838 .61221 Mtetra
.663 .766 .927 r
.39838 .61221 .40401 .61706 .41345 .61406 .40784 .6092 Mtetra
.667 .768 .925 r
.40784 .6092 .41345 .61406 .42291 .611 .41733 .60607 Mtetra
.672 .767 .922 r
.41733 .60607 .42291 .611 .43241 .60791 .42685 .60284 Mtetra
.672 .762 .918 r
.42685 .60284 .43241 .60791 .44194 .60488 .43641 .59958 Mtetra
.67 .754 .913 r
.43641 .59958 .44194 .60488 .4515 .60196 .44599 .59637 Mtetra
.661 .741 .909 r
.44599 .59637 .4515 .60196 .46109 .59927 .45561 .59338 Mtetra
.647 .727 .907 r
.45561 .59338 .46109 .59927 .47071 .5969 .46525 .59073 Mtetra
.63 .712 .906 r
.46525 .59073 .47071 .5969 .48036 .59483 .47492 .58851 Mtetra
.61 .7 .908 r
.47492 .58851 .48036 .59483 .49004 .59306 .48463 .58676 Mtetra
.597 .697 .913 r
.48463 .58676 .49004 .59306 .49977 .59138 .49437 .58528 Mtetra
.59 .702 .921 r
.49437 .58528 .49977 .59138 .50954 .58964 .50415 .5839 Mtetra
.596 .719 .93 r
.50415 .5839 .50954 .58964 .51935 .58764 .51398 .58232 Mtetra
.612 .741 .937 r
.51398 .58232 .51935 .58764 .5292 .58523 .52386 .58032 Mtetra
.631 .765 .943 r
.52386 .58032 .5292 .58523 .53909 .58242 .53377 .57784 Mtetra
.652 .786 .945 r
.53377 .57784 .53909 .58242 .54901 .57922 .54372 .57484 Mtetra
.666 .798 .946 r
.54372 .57484 .54901 .57922 .55896 .5758 .5537 .5715 Mtetra
.675 .805 .945 r
.5537 .5715 .55896 .5758 .56895 .57225 .56371 .56794 Mtetra
.677 .806 .944 r
.56371 .56794 .56895 .57225 .57897 .56869 .57376 .56433 Mtetra
.674 .804 .945 r
.57376 .56433 .57897 .56869 .58902 .56522 .58384 .56078 Mtetra
.668 .8 .945 r
.58384 .56078 .58902 .56522 .59911 .56187 .59395 .55736 Mtetra
.659 .795 .947 r
.59395 .55736 .59911 .56187 .60923 .55869 .60411 .55412 Mtetra
.65 .791 .95 r
.60411 .55412 .60923 .55869 .6194 .55567 .61431 .55108 Mtetra
.64 .788 .953 r
.61431 .55108 .6194 .55567 .62961 .55281 .62455 .54823 Mtetra
.63 .786 .957 r
.62455 .54823 .62961 .55281 .63987 .55012 .63483 .54558 Mtetra
.622 .785 .96 r
.63483 .54558 .63987 .55012 .65017 .54755 .64516 .54305 Mtetra
.617 .786 .963 r
.64516 .54305 .65017 .54755 .66051 .54507 .65554 .54059 Mtetra
.619 .789 .963 r
.65554 .54059 .66051 .54507 .6709 .54259 .66595 .53808 Mtetra
.63 .792 .96 r
.66595 .53808 .6709 .54259 .68132 .53998 .6764 .53534 Mtetra
.647 .793 .952 r
.6764 .53534 .68132 .53998 .69178 .53714 .68687 .53226 Mtetra
.671 .792 .939 r
.68687 .53226 .69178 .53714 .70225 .5339 .69736 .52866 Mtetra
.691 .784 .922 r
.69736 .52866 .70225 .5339 .71274 .53026 .70785 .52456 Mtetra
.705 .771 .904 r
.70785 .52456 .71274 .53026 .72324 .52621 .71836 .52003 Mtetra
.709 .757 .89 r
.71836 .52003 .72324 .52621 .73376 .52187 .72888 .51528 Mtetra
.704 .742 .882 r
.72888 .51528 .73376 .52187 .74431 .51747 .73944 .51064 Mtetra
.694 .732 .88 r
.73944 .51064 .74431 .51747 .75489 .51316 .75005 .50626 Mtetra
.679 .725 .885 r
.75005 .50626 .75489 .51316 .76553 .50915 .76072 .50237 Mtetra
.665 .724 .893 r
.76072 .50237 .76553 .50915 .77623 .50545 .77147 .4989 Mtetra
.652 .728 .905 r
.77147 .4989 .77623 .50545 .78699 .50207 .78228 .49579 Mtetra
.643 .735 .915 r
.78228 .49579 .78699 .50207 .79781 .49892 .79315 .49291 Mtetra
.64 .744 .924 r
.79315 .49291 .79781 .49892 .80869 .49589 .80407 .49007 Mtetra
.639 .751 .93 r
.80407 .49007 .80869 .49589 .81961 .49292 .81503 .48721 Mtetra
.643 .758 .932 r
.81503 .48721 .81961 .49292 .83057 .48992 .82603 .48423 Mtetra
.646 .761 .933 r
.82603 .48423 .83057 .48992 .84157 .48685 .83706 .48114 Mtetra
.651 .763 .931 r
.83706 .48114 .84157 .48685 .85261 .4837 .84813 .47793 Mtetra
.654 .763 .929 r
.84813 .47793 .85261 .4837 .86369 .48048 .85923 .47462 Mtetra
.657 .761 .927 r
.85923 .47462 .86369 .48048 .8748 .47719 .87036 .47125 Mtetra
.658 .76 .925 r
.87036 .47125 .8748 .47719 .88595 .47385 .88154 .46783 Mtetra
.659 .758 .923 r
.88154 .46783 .88595 .47385 .89713 .47047 .89275 .46438 Mtetra
.659 .756 .922 r
.89275 .46438 .89713 .47047 .90836 .46706 .90401 .46091 Mtetra
.66 .755 .921 r
.90401 .46091 .90836 .46706 .91963 .46363 .91531 .45742 Mtetra
.659 .754 .92 r
.91531 .45742 .91963 .46363 .93095 .46018 .92665 .45393 Mtetra
.651 .75 .922 r
.31818 .62896 .32399 .63404 .33318 .63139 .32738 .6263 Mtetra
.651 .75 .923 r
.32738 .6263 .33318 .63139 .34239 .62874 .33661 .62365 Mtetra
.65 .751 .923 r
.33661 .62365 .34239 .62874 .35164 .62607 .34588 .62099 Mtetra
.65 .752 .924 r
.34588 .62099 .35164 .62607 .36092 .62339 .35517 .61833 Mtetra
.649 .753 .925 r
.35517 .61833 .36092 .62339 .37023 .62068 .3645 .61567 Mtetra
.65 .756 .927 r
.3645 .61567 .37023 .62068 .37958 .61793 .37387 .61298 Mtetra
.651 .759 .929 r
.37387 .61298 .37958 .61793 .38896 .61512 .38327 .61025 Mtetra
.654 .764 .93 r
.38327 .61025 .38896 .61512 .39838 .61221 .39271 .60743 Mtetra
.659 .769 .931 r
.39271 .60743 .39838 .61221 .40784 .6092 .40218 .60448 Mtetra
.665 .774 .931 r
.40218 .60448 .40784 .6092 .41733 .60607 .41169 .60136 Mtetra
.674 .777 .928 r
.41169 .60136 .41733 .60607 .42685 .60284 .42124 .59805 Mtetra
.679 .776 .924 r
.42124 .59805 .42685 .60284 .43641 .59958 .43083 .5946 Mtetra
.682 .77 .918 r
.43083 .5946 .43641 .59958 .44599 .59637 .44045 .59106 Mtetra
.676 .757 .911 r
.44045 .59106 .44599 .59637 .45561 .59338 .45009 .58765 Mtetra
.664 .739 .906 r
.45009 .58765 .45561 .59338 .46525 .59073 .45976 .58455 Mtetra
.644 .718 .902 r
.45976 .58455 .46525 .59073 .47492 .58851 .46946 .58197 Mtetra
.617 .697 .902 r
.46946 .58197 .47492 .58851 .48463 .58676 .47918 .58007 Mtetra
.595 .684 .904 r
.47918 .58007 .48463 .58676 .49437 .58528 .48894 .57867 Mtetra
.577 .68 .911 r
.48894 .57867 .49437 .58528 .50415 .5839 .49874 .57765 Mtetra
.576 .693 .921 r
.49874 .57765 .50415 .5839 .51398 .58232 .50858 .57656 Mtetra
.588 .717 .933 r
.50858 .57656 .51398 .58232 .52386 .58032 .51847 .57511 Mtetra
.609 .747 .943 r
.51847 .57511 .52386 .58032 .53377 .57784 .52841 .57312 Mtetra
.636 .776 .948 r
.52841 .57312 .53377 .57784 .54372 .57484 .53839 .57046 Mtetra
.655 .797 .95 r
.53839 .57046 .54372 .57484 .5537 .5715 .5484 .56733 Mtetra
.67 .81 .951 r
.5484 .56733 .5537 .5715 .56371 .56794 .55844 .56384 Mtetra
.675 .816 .951 r
.55844 .56384 .56371 .56794 .57376 .56433 .56852 .56021 Mtetra
.673 .816 .952 r
.56852 .56021 .57376 .56433 .58384 .56078 .57862 .5566 Mtetra
.667 .813 .953 r
.57862 .5566 .58384 .56078 .59395 .55736 .58877 .55312 Mtetra
.658 .808 .955 r
.58877 .55312 .59395 .55736 .60411 .55412 .59895 .54984 Mtetra
.646 .804 .958 r
.59895 .54984 .60411 .55412 .61431 .55108 .60918 .54678 Mtetra
.635 .8 .962 r
.60918 .54678 .61431 .55108 .62455 .54823 .61945 .54394 Mtetra
.623 .797 .966 r
.61945 .54394 .62455 .54823 .63483 .54558 .62976 .54131 Mtetra
.615 .797 .969 r
.62976 .54131 .63483 .54558 .64516 .54305 .64013 .5388 Mtetra
.613 .797 .97 r
.64013 .5388 .64516 .54305 .65554 .54059 .65053 .53631 Mtetra
.62 .799 .968 r
.65053 .53631 .65554 .54059 .66595 .53808 .66097 .53369 Mtetra
.639 .802 .961 r
.66097 .53369 .66595 .53808 .6764 .53534 .67144 .53071 Mtetra
.664 .8 .948 r
.67144 .53071 .6764 .53534 .68687 .53226 .68193 .52724 Mtetra
.692 .793 .928 r
.68193 .52724 .68687 .53226 .69736 .52866 .69241 .5231 Mtetra
.71 .779 .906 r
.69241 .5231 .69736 .52866 .70785 .52456 .70291 .5184 Mtetra
.719 .761 .886 r
.70291 .5184 .70785 .52456 .71836 .52003 .71341 .51333 Mtetra
.717 .744 .873 r
.71341 .51333 .71836 .52003 .72888 .51528 .72394 .50817 Mtetra
.704 .728 .869 r
.72394 .50817 .72888 .51528 .73944 .51064 .73451 .5034 Mtetra
.689 .719 .873 r
.73451 .5034 .73944 .51064 .75005 .50626 .74516 .49913 Mtetra
.668 .715 .884 r
.74516 .49913 .75005 .50626 .76072 .50237 .75588 .49556 Mtetra
.65 .719 .899 r
.75588 .49556 .76072 .50237 .77147 .4989 .76668 .49252 Mtetra
.637 .729 .915 r
.76668 .49252 .77147 .4989 .78228 .49579 .77755 .4898 Mtetra
.629 .741 .928 r
.77755 .4898 .78228 .49579 .79315 .49291 .78848 .48721 Mtetra
.63 .754 .936 r
.78848 .48721 .79315 .49291 .80407 .49007 .79944 .48453 Mtetra
.634 .762 .94 r
.79944 .48453 .80407 .49007 .81503 .48721 .81044 .48171 Mtetra
.642 .768 .939 r
.81044 .48171 .81503 .48721 .82603 .48423 .82147 .47868 Mtetra
.649 .769 .937 r
.82147 .47868 .82603 .48423 .83706 .48114 .83253 .47548 Mtetra
.655 .768 .933 r
.83253 .47548 .83706 .48114 .84813 .47793 .84361 .47214 Mtetra
.658 .765 .929 r
.84361 .47214 .84813 .47793 .85923 .47462 .85473 .46871 Mtetra
.66 .762 .926 r
.85473 .46871 .85923 .47462 .87036 .47125 .86589 .46523 Mtetra
.661 .759 .923 r
.86589 .46523 .87036 .47125 .88154 .46783 .87709 .46172 Mtetra
.661 .757 .921 r
.87709 .46172 .88154 .46783 .89275 .46438 .88833 .4582 Mtetra
.66 .755 .92 r
.88833 .4582 .89275 .46438 .90401 .46091 .89962 .45468 Mtetra
.66 .754 .92 r
.89962 .45468 .90401 .46091 .91531 .45742 .91095 .45115 Mtetra
.66 .753 .919 r
.91095 .45115 .91531 .45742 .92665 .45393 .92232 .44763 Mtetra
.652 .75 .922 r
.31232 .62385 .31818 .62896 .32738 .6263 .32154 .62116 Mtetra
.651 .75 .922 r
.32154 .62116 .32738 .6263 .33661 .62365 .3308 .61847 Mtetra
.65 .749 .922 r
.3308 .61847 .33661 .62365 .34588 .62099 .34008 .61579 Mtetra
.649 .748 .922 r
.34008 .61579 .34588 .62099 .35517 .61833 .3494 .61313 Mtetra
.648 .749 .923 r
.3494 .61313 .35517 .61833 .3645 .61567 .35875 .61049 Mtetra
.647 .75 .924 r
.35875 .61049 .3645 .61567 .37387 .61298 .36813 .60786 Mtetra
.646 .753 .927 r
.36813 .60786 .37387 .61298 .38327 .61025 .37754 .60523 Mtetra
.648 .758 .929 r
.37754 .60523 .38327 .61025 .39271 .60743 .387 .60253 Mtetra
.652 .764 .932 r
.387 .60253 .39271 .60743 .40218 .60448 .39649 .59973 Mtetra
.659 .773 .933 r
.39649 .59973 .40218 .60448 .41169 .60136 .40602 .59674 Mtetra
.67 .781 .933 r
.40602 .59674 .41169 .60136 .42124 .59805 .41559 .59349 Mtetra
.68 .787 .93 r
.41559 .59349 .42124 .59805 .43083 .5946 .4252 .58997 Mtetra
.691 .787 .924 r
.4252 .58997 .43083 .5946 .44045 .59106 .43485 .58617 Mtetra
.692 .778 .917 r
.43485 .58617 .44045 .59106 .45009 .58765 .44453 .58234 Mtetra
.686 .761 .909 r
.44453 .58234 .45009 .58765 .45976 .58455 .45423 .57865 Mtetra
.665 .736 .902 r
.45423 .57865 .45976 .58455 .46946 .58197 .46396 .57549 Mtetra
.634 .707 .899 r
.46396 .57549 .46946 .58197 .47918 .58007 .4737 .57315 Mtetra
.603 .681 .897 r
.4737 .57315 .47918 .58007 .48894 .57867 .48348 .57158 Mtetra
.57 .663 .901 r
.48348 .57158 .48894 .57867 .49874 .57765 .49329 .57076 Mtetra
.559 .666 .909 r
.49329 .57076 .49874 .57765 .50858 .57656 .50315 .57014 Mtetra
.562 .683 .921 r
.50315 .57014 .50858 .57656 .51847 .57511 .51306 .56933 Mtetra
.581 .715 .935 r
.51306 .56933 .51847 .57511 .52841 .57312 .52301 .56798 Mtetra
.612 .753 .945 r
.52301 .56798 .52841 .57312 .53839 .57046 .53302 .56586 Mtetra
.637 .784 .952 r
.53302 .56586 .53839 .57046 .5484 .56733 .54306 .56312 Mtetra
.659 .807 .954 r
.54306 .56312 .5484 .56733 .55844 .56384 .55313 .55984 Mtetra
.668 .82 .956 r
.55313 .55984 .55844 .56384 .56852 .56021 .56324 .55631 Mtetra
.67 .825 .958 r
.56324 .55631 .56852 .56021 .57862 .5566 .57338 .55271 Mtetra
.664 .825 .961 r
.57338 .55271 .57862 .5566 .58877 .55312 .58355 .5492 Mtetra
.654 .822 .964 r
.58355 .5492 .58877 .55312 .59895 .54984 .59377 .54588 Mtetra
.642 .818 .968 r
.59377 .54588 .59895 .54984 .60918 .54678 .60402 .54281 Mtetra
.628 .814 .971 r
.60402 .54281 .60918 .54678 .61945 .54394 .61432 .53996 Mtetra
.617 .811 .975 r
.61432 .53996 .61945 .54394 .62976 .54131 .62467 .53731 Mtetra
.611 .809 .976 r
.62467 .53731 .62976 .54131 .64013 .5388 .63506 .53476 Mtetra
.614 .809 .975 r
.63506 .53476 .64013 .5388 .65053 .53631 .64549 .53214 Mtetra
.63 .809 .969 r
.64549 .53214 .65053 .53631 .66097 .53369 .65595 .52927 Mtetra
.659 .808 .955 r
.65595 .52927 .66097 .53369 .67144 .53071 .66643 .52585 Mtetra
.688 .799 .934 r
.66643 .52585 .67144 .53071 .68193 .52724 .67692 .5218 Mtetra
.715 .785 .907 r
.67692 .5218 .68193 .52724 .69241 .5231 .68741 .51696 Mtetra
.727 .765 .882 r
.68741 .51696 .69241 .5231 .70291 .5184 .6979 .51156 Mtetra
.727 .743 .865 r
.6979 .51156 .70291 .5184 .71341 .51333 .7084 .50598 Mtetra
.718 .727 .857 r
.7084 .50598 .71341 .51333 .72394 .50817 .71894 .50057 Mtetra
.697 .713 .861 r
.71894 .50057 .72394 .50817 .73451 .5034 .72955 .49593 Mtetra
.675 .709 .873 r
.72955 .49593 .73451 .5034 .74516 .49913 .74024 .49207 Mtetra
.649 .711 .893 r
.74024 .49207 .74516 .49913 .75588 .49556 .75103 .48905 Mtetra
.627 .721 .914 r
.75103 .48905 .75588 .49556 .76668 .49252 .7619 .48657 Mtetra
.617 .738 .933 r
.7619 .48657 .76668 .49252 .77755 .4898 .77283 .48424 Mtetra
.614 .753 .944 r
.77283 .48424 .77755 .4898 .78848 .48721 .78381 .48187 Mtetra
.624 .767 .948 r
.78381 .48187 .78848 .48721 .79944 .48453 .79481 .47922 Mtetra
.636 .774 .947 r
.79481 .47922 .79944 .48453 .81044 .48171 .80583 .4763 Mtetra
.648 .775 .941 r
.80583 .4763 .81044 .48171 .82147 .47868 .81688 .4731 Mtetra
.656 .772 .935 r
.81688 .4731 .82147 .47868 .83253 .47548 .82795 .4697 Mtetra
.661 .767 .929 r
.82795 .4697 .83253 .47548 .84361 .47214 .83905 .46619 Mtetra
.663 .763 .924 r
.83905 .46619 .84361 .47214 .85473 .46871 .85019 .46261 Mtetra
.663 .758 .921 r
.85019 .46261 .85473 .46871 .86589 .46523 .86138 .45903 Mtetra
.663 .755 .919 r
.86138 .45903 .86589 .46523 .87709 .46172 .8726 .45545 Mtetra
.661 .753 .918 r
.8726 .45545 .87709 .46172 .88833 .4582 .88387 .4519 Mtetra
.661 .752 .918 r
.88387 .4519 .88833 .4582 .89962 .45468 .89519 .44835 Mtetra
.66 .752 .918 r
.89519 .44835 .89962 .45468 .91095 .45115 .90655 .44481 Mtetra
.659 .752 .919 r
.90655 .44481 .91095 .45115 .92232 .44763 .91796 .44128 Mtetra
.654 .751 .921 r
.30643 .61871 .31232 .62385 .32154 .62116 .31567 .61595 Mtetra
.654 .749 .92 r
.31567 .61595 .32154 .62116 .3308 .61847 .32495 .61319 Mtetra
.653 .747 .919 r
.32495 .61319 .3308 .61847 .34008 .61579 .33426 .61045 Mtetra
.651 .745 .918 r
.33426 .61045 .34008 .61579 .3494 .61313 .34359 .60775 Mtetra
.648 .743 .919 r
.34359 .60775 .3494 .61313 .35875 .61049 .35296 .60509 Mtetra
.646 .743 .92 r
.35296 .60509 .35875 .61049 .36813 .60786 .36236 .60249 Mtetra
.642 .743 .922 r
.36236 .60249 .36813 .60786 .37754 .60523 .37179 .59994 Mtetra
.641 .747 .926 r
.37179 .59994 .37754 .60523 .387 .60253 .38126 .5974 Mtetra
.641 .754 .93 r
.38126 .5974 .387 .60253 .39649 .59973 .39076 .59484 Mtetra
.647 .765 .935 r
.39076 .59484 .39649 .59973 .40602 .59674 .4003 .5921 Mtetra
.658 .779 .938 r
.4003 .5921 .40602 .59674 .41559 .59349 .40989 .5891 Mtetra
.673 .793 .939 r
.40989 .5891 .41559 .59349 .4252 .58997 .41952 .58571 Mtetra
.693 .803 .933 r
.41952 .58571 .4252 .58997 .43485 .58617 .4292 .58183 Mtetra
.705 .803 .926 r
.4292 .58183 .43485 .58617 .44453 .58234 .43891 .57764 Mtetra
.71 .791 .914 r
.43891 .57764 .44453 .58234 .45423 .57865 .44865 .57328 Mtetra
.694 .763 .905 r
.44865 .57328 .45423 .57865 .46396 .57549 .45842 .56932 Mtetra
.664 .727 .897 r
.45842 .56932 .46396 .57549 .4737 .57315 .4682 .56617 Mtetra
.624 .689 .89 r
.4682 .56617 .4737 .57315 .48348 .57158 .47799 .56407 Mtetra
.576 .654 .889 r
.47799 .56407 .48348 .57158 .49329 .57076 .48782 .56317 Mtetra
.549 .64 .893 r
.48782 .56317 .49329 .57076 .50315 .57014 .49769 .56287 Mtetra
.536 .645 .904 r
.49769 .56287 .50315 .57014 .51306 .56933 .50761 .56275 Mtetra
.548 .674 .921 r
.50761 .56275 .51306 .56933 .52301 .56798 .51758 .5622 Mtetra
.579 .717 .937 r
.51758 .5622 .52301 .56798 .53302 .56586 .52761 .56085 Mtetra
.61 .759 .95 r
.52761 .56085 .53302 .56586 .54306 .56312 .53767 .55872 Mtetra
.64 .795 .957 r
.53767 .55872 .54306 .56312 .55313 .55984 .54778 .55584 Mtetra
.655 .818 .962 r
.54778 .55584 .55313 .55984 .56324 .55631 .55792 .55255 Mtetra
.662 .831 .965 r
.55792 .55255 .56324 .55631 .57338 .55271 .56809 .54905 Mtetra
.658 .836 .968 r
.56809 .54905 .57338 .55271 .58355 .5492 .5783 .54558 Mtetra
.648 .835 .972 r
.5783 .54558 .58355 .5492 .59377 .54588 .58854 .54226 Mtetra
.635 .832 .976 r
.58854 .54226 .59377 .54588 .60402 .54281 .59883 .53916 Mtetra
.622 .828 .98 r
.59883 .53916 .60402 .54281 .61432 .53996 .60916 .53629 Mtetra
.612 .824 .982 r
.60916 .53629 .61432 .53996 .62467 .53731 .61954 .53357 Mtetra
.612 .822 .981 r
.61954 .53357 .62467 .53731 .63506 .53476 .62996 .53087 Mtetra
.625 .821 .975 r
.62996 .53087 .63506 .53476 .64549 .53214 .64041 .52797 Mtetra
.651 .817 .963 r
.64041 .52797 .64549 .53214 .65595 .52927 .65089 .52465 Mtetra
.688 .809 .94 r
.65089 .52465 .65595 .52927 .66643 .52585 .66138 .52057 Mtetra
.716 .792 .911 r
.66138 .52057 .66643 .52585 .67692 .5218 .67186 .5157 Mtetra
.736 .769 .88 r
.67186 .5157 .67692 .5218 .68741 .51696 .68234 .51 Mtetra
.739 .744 .856 r
.68234 .51 .68741 .51696 .6979 .51156 .69281 .50387 Mtetra
.729 .721 .843 r
.69281 .50387 .6979 .51156 .7084 .50598 .70332 .4979 Mtetra
.712 .706 .843 r
.70332 .4979 .7084 .50598 .71894 .50057 .71389 .49253 Mtetra
.681 .696 .857 r
.71389 .49253 .71894 .50057 .72955 .49593 .72455 .48838 Mtetra
.65 .698 .881 r
.72455 .48838 .72955 .49593 .74024 .49207 .73532 .48531 Mtetra
.618 .71 .911 r
.73532 .48531 .74024 .49207 .75103 .48905 .74619 .48306 Mtetra
.594 .728 .938 r
.74619 .48306 .75103 .48905 .7619 .48657 .75714 .48124 Mtetra
.593 .755 .955 r
.75714 .48124 .7619 .48657 .77283 .48424 .76812 .47923 Mtetra
.603 .773 .962 r
.76812 .47923 .77283 .48424 .78381 .48187 .77913 .47691 Mtetra
.627 .785 .958 r
.77913 .47691 .78381 .48187 .79481 .47922 .79015 .47409 Mtetra
.646 .786 .949 r
.79015 .47409 .79481 .47922 .80583 .4763 .80119 .47086 Mtetra
.659 .78 .938 r
.80119 .47086 .80583 .4763 .81688 .4731 .81224 .46736 Mtetra
.667 .772 .928 r
.81224 .46736 .81688 .4731 .82795 .4697 .82332 .46367 Mtetra
.668 .762 .921 r
.82332 .46367 .82795 .4697 .83905 .46619 .83444 .45996 Mtetra
.668 .756 .916 r
.83444 .45996 .83905 .46619 .85019 .46261 .8456 .45624 Mtetra
.665 .751 .914 r
.8456 .45624 .85019 .46261 .86138 .45903 .85681 .45259 Mtetra
.663 .748 .913 r
.85681 .45259 .86138 .45903 .8726 .45545 .86806 .44898 Mtetra
.661 .747 .914 r
.86806 .44898 .8726 .45545 .88387 .4519 .87937 .44543 Mtetra
.659 .747 .915 r
.87937 .44543 .88387 .4519 .89519 .44835 .89072 .4419 Mtetra
.658 .749 .917 r
.89072 .4419 .89519 .44835 .90655 .44481 .90212 .4384 Mtetra
.657 .75 .918 r
.90212 .4384 .90655 .44481 .91796 .44128 .91357 .43489 Mtetra
.657 .752 .92 r
.3005 .61354 .30643 .61871 .31567 .61595 .30977 .61069 Mtetra
.657 .749 .918 r
.30977 .61069 .31567 .61595 .32495 .61319 .31907 .60784 Mtetra
.656 .746 .916 r
.31907 .60784 .32495 .61319 .33426 .61045 .3284 .60501 Mtetra
.654 .743 .915 r
.3284 .60501 .33426 .61045 .34359 .60775 .33776 .60221 Mtetra
.651 .74 .914 r
.33776 .60221 .34359 .60775 .35296 .60509 .34715 .59948 Mtetra
.647 .736 .914 r
.34715 .59948 .35296 .60509 .36236 .60249 .35657 .59683 Mtetra
.642 .734 .916 r
.35657 .59683 .36236 .60249 .37179 .59994 .36602 .5943 Mtetra
.638 .734 .918 r
.36602 .5943 .37179 .59994 .38126 .5974 .3755 .59186 Mtetra
.633 .737 .923 r
.3755 .59186 .38126 .5974 .39076 .59484 .38501 .5895 Mtetra
.634 .746 .929 r
.38501 .5895 .39076 .59484 .4003 .5921 .39456 .58708 Mtetra
.64 .76 .936 r
.39456 .58708 .4003 .5921 .40989 .5891 .40415 .58449 Mtetra
.656 .782 .941 r
.40415 .58449 .40989 .5891 .41952 .58571 .41379 .58148 Mtetra
.682 .804 .94 r
.41379 .58148 .41952 .58571 .4292 .58183 .42349 .57785 Mtetra
.706 .82 .936 r
.42349 .57785 .4292 .58183 .43891 .57764 .43323 .57361 Mtetra
.729 .821 .922 r
.43323 .57361 .43891 .57764 .44865 .57328 .44302 .56875 Mtetra
.725 .802 .912 r
.44302 .56875 .44865 .57328 .45842 .56932 .45283 .56395 Mtetra
.704 .767 .902 r
.45283 .56395 .45842 .56932 .4682 .56617 .46265 .55968 Mtetra
.66 .718 .892 r
.46265 .55968 .4682 .56617 .47799 .56407 .47248 .55659 Mtetra
.6 .666 .886 r
.47248 .55659 .47799 .56407 .48782 .56317 .48233 .5551 Mtetra
.556 .631 .881 r
.48233 .5551 .48782 .56317 .49769 .56287 .49221 .5547 Mtetra
.522 .613 .884 r
.49221 .5547 .49769 .56287 .50761 .56275 .50213 .55508 Mtetra
.521 .627 .897 r
.50213 .55508 .50761 .56275 .51758 .5622 .51212 .55533 Mtetra
.544 .664 .916 r
.51212 .55533 .51758 .5622 .52761 .56085 .52216 .55491 Mtetra
.575 .712 .935 r
.52216 .55491 .52761 .56085 .53767 .55872 .53225 .55364 Mtetra
.613 .76 .949 r
.53225 .55364 .53767 .55872 .54778 .55584 .54238 .55143 Mtetra
.635 .796 .959 r
.54238 .55143 .54778 .55584 .55792 .55255 .55256 .5486 Mtetra
.649 .821 .966 r
.55256 .5486 .55792 .55255 .56809 .54905 .56276 .54538 Mtetra
.65 .834 .971 r
.56276 .54538 .56809 .54905 .5783 .54558 .573 .54205 Mtetra
.643 .839 .976 r
.573 .54205 .5783 .54558 .58854 .54226 .58328 .53878 Mtetra
.632 .839 .98 r
.58328 .53878 .58854 .54226 .59883 .53916 .5936 .53566 Mtetra
.622 .836 .982 r
.5936 .53566 .59883 .53916 .60916 .53629 .60397 .53269 Mtetra
.619 .832 .982 r
.60397 .53269 .60916 .53629 .61954 .53357 .61437 .52979 Mtetra
.629 .827 .977 r
.61437 .52979 .61954 .53357 .62996 .53087 .62481 .52678 Mtetra
.654 .822 .964 r
.62481 .52678 .62996 .53087 .64041 .52797 .63528 .52337 Mtetra
.685 .81 .942 r
.63528 .52337 .64041 .52797 .65089 .52465 .64576 .51934 Mtetra
.72 .792 .909 r
.64576 .51934 .65089 .52465 .66138 .52057 .65624 .51435 Mtetra
.739 .766 .875 r
.65624 .51435 .66138 .52057 .67186 .5157 .66672 .5085 Mtetra
.746 .74 .846 r
.66672 .5085 .67186 .5157 .68234 .51 .67718 .50194 Mtetra
.741 .717 .829 r
.67718 .50194 .68234 .51 .69281 .50387 .68766 .49525 Mtetra
.72 .697 .828 r
.68766 .49525 .69281 .50387 .70332 .4979 .69819 .48933 Mtetra
.694 .689 .84 r
.69819 .48933 .70332 .4979 .71389 .49253 .70881 .48452 Mtetra
.652 .686 .869 r
.70881 .48452 .71389 .49253 .72455 .48838 .71956 .48134 Mtetra
.608 .697 .906 r
.71956 .48134 .72455 .48838 .73532 .48531 .73042 .47937 Mtetra
.573 .722 .943 r
.73042 .47937 .73532 .48531 .74619 .48306 .74137 .47795 Mtetra
.554 .748 .967 r
.74137 .47795 .74619 .48306 .75714 .48124 .75238 .47659 Mtetra
.578 .78 .975 r
.75238 .47659 .75714 .48124 .76812 .47923 .7634 .4746 Mtetra
.611 .794 .969 r
.7634 .4746 .76812 .47923 .77913 .47691 .77443 .47198 Mtetra
.645 .795 .955 r
.77443 .47198 .77913 .47691 .79015 .47409 .78545 .46872 Mtetra
.666 .786 .938 r
.78545 .46872 .79015 .47409 .80119 .47086 .79648 .46503 Mtetra
.674 .771 .924 r
.79648 .46503 .80119 .47086 .81224 .46736 .80753 .46115 Mtetra
.676 .76 .914 r
.80753 .46115 .81224 .46736 .82332 .46367 .81862 .4572 Mtetra
.672 .75 .909 r
.81862 .4572 .82332 .46367 .83444 .45996 .82976 .45334 Mtetra
.669 .744 .907 r
.82976 .45334 .83444 .45996 .8456 .45624 .84095 .44957 Mtetra
.664 .741 .907 r
.84095 .44957 .8456 .45624 .85681 .45259 .85219 .44592 Mtetra
.661 .741 .909 r
.85219 .44592 .85681 .45259 .86806 .44898 .86348 .44235 Mtetra
.658 .742 .912 r
.86348 .44235 .86806 .44898 .87937 .44543 .87483 .43884 Mtetra
.656 .744 .914 r
.87483 .43884 .87937 .44543 .89072 .4419 .88622 .43537 Mtetra
.655 .746 .917 r
.88622 .43537 .89072 .4419 .90212 .4384 .89766 .43192 Mtetra
.655 .749 .919 r
.89766 .43192 .90212 .4384 .91357 .43489 .90915 .42846 Mtetra
.66 .752 .918 r
.29453 .60833 .3005 .61354 .30977 .61069 .30382 .60539 Mtetra
.661 .75 .916 r
.30382 .60539 .30977 .61069 .31907 .60784 .31315 .60244 Mtetra
.66 .747 .914 r
.31315 .60244 .31907 .60784 .3284 .60501 .3225 .59949 Mtetra
.659 .743 .912 r
.3225 .59949 .3284 .60501 .33776 .60221 .33189 .59656 Mtetra
.657 .738 .91 r
.33189 .59656 .33776 .60221 .34715 .59948 .34131 .59367 Mtetra
.652 .732 .908 r
.34131 .59367 .34715 .59948 .35657 .59683 .35075 .59089 Mtetra
.646 .726 .907 r
.35075 .59089 .35657 .59683 .36602 .5943 .36022 .58825 Mtetra
.639 .721 .907 r
.36022 .58825 .36602 .5943 .3755 .59186 .36972 .58578 Mtetra
.628 .718 .911 r
.36972 .58578 .3755 .59186 .38501 .5895 .37924 .58355 Mtetra
.622 .721 .917 r
.37924 .58355 .38501 .5895 .39456 .58708 .3888 .58143 Mtetra
.617 .731 .927 r
.3888 .58143 .39456 .58708 .40415 .58449 .39839 .57938 Mtetra
.628 .755 .939 r
.39839 .57938 .40415 .58449 .41379 .58148 .40804 .57701 Mtetra
.651 .788 .948 r
.40804 .57701 .41379 .58148 .42349 .57785 .41774 .57406 Mtetra
.687 .825 .949 r
.41774 .57406 .42349 .57785 .43323 .57361 .4275 .57022 Mtetra
.732 .849 .936 r
.4275 .57022 .43323 .57361 .44302 .56875 .43731 .56524 Mtetra
.75 .847 .923 r
.43731 .56524 .44302 .56875 .45283 .56395 .44717 .55974 Mtetra
.751 .82 .906 r
.44717 .55974 .45283 .56395 .46265 .55968 .45705 .55413 Mtetra
.712 .765 .894 r
.45705 .55413 .46265 .55968 .47248 .55659 .46693 .54957 Mtetra
.646 .699 .884 r
.46693 .54957 .47248 .55659 .48233 .5551 .47681 .54681 Mtetra
.586 .639 .87 r
.47681 .54681 .48233 .5551 .49221 .5547 .48671 .54572 Mtetra
.525 .593 .865 r
.48671 .54572 .49221 .5547 .50213 .55508 .49664 .54618 Mtetra
.505 .586 .87 r
.49664 .54618 .50213 .55508 .51212 .55533 .50663 .54707 Mtetra
.51 .607 .885 r
.50663 .54707 .51212 .55533 .52216 .55491 .51668 .54766 Mtetra
.535 .65 .908 r
.51668 .54766 .52216 .55491 .53225 .55364 .52679 .54747 Mtetra
.576 .706 .93 r
.52679 .54747 .53225 .55364 .54238 .55143 .53695 .5462 Mtetra
.606 .754 .949 r
.53695 .5462 .54238 .55143 .55256 .5486 .54715 .54411 Mtetra
.63 .793 .961 r
.54715 .54411 .55256 .5486 .56276 .54538 .55739 .54137 Mtetra
.638 .817 .969 r
.55739 .54137 .56276 .54538 .573 .54205 .56766 .53833 Mtetra
.638 .831 .975 r
.56766 .53833 .573 .54205 .58328 .53878 .57798 .53518 Mtetra
.634 .835 .978 r
.57798 .53518 .58328 .53878 .5936 .53566 .58833 .53204 Mtetra
.632 .835 .978 r
.58833 .53204 .5936 .53566 .60397 .53269 .59872 .52892 Mtetra
.64 .831 .974 r
.59872 .52892 .60397 .53269 .61437 .52979 .60915 .52569 Mtetra
.66 .823 .962 r
.60915 .52569 .61437 .52979 .62481 .52678 .61961 .52215 Mtetra
.692 .811 .939 r
.61961 .52215 .62481 .52678 .63528 .52337 .63008 .51795 Mtetra
.72 .789 .906 r
.63008 .51795 .63528 .52337 .64576 .51934 .64056 .51293 Mtetra
.744 .762 .868 r
.64056 .51293 .64576 .51934 .65624 .51435 .65103 .50681 Mtetra
.751 .732 .835 r
.65103 .50681 .65624 .51435 .66672 .5085 .66149 .49987 Mtetra
.746 .706 .814 r
.66149 .49987 .66672 .5085 .67718 .50194 .67194 .49263 Mtetra
.732 .687 .807 r
.67194 .49263 .67718 .50194 .68766 .49525 .68244 .4858 Mtetra
.699 .671 .82 r
.68244 .4858 .68766 .49525 .69819 .48933 .69303 .48054 Mtetra
.661 .67 .849 r
.69303 .48054 .69819 .48933 .70881 .48452 .70374 .47697 Mtetra
.6 .678 .896 r
.70374 .47697 .70881 .48452 .71956 .48134 .71459 .47525 Mtetra
.534 .699 .945 r
.71459 .47525 .71956 .48134 .73042 .47937 .72556 .47461 Mtetra
.504 .742 .98 r
.72556 .47461 .73042 .47937 .74137 .47795 .73659 .47387 Mtetra
.515 .779 .992 r
.73659 .47387 .74137 .47795 .75238 .47659 .74764 .47259 Mtetra
.586 .814 .986 r
.74764 .47259 .75238 .47659 .7634 .4746 .75866 .47014 Mtetra
.644 .816 .966 r
.75866 .47014 .7634 .4746 .77443 .47198 .76967 .46679 Mtetra
.676 .797 .939 r
.76967 .46679 .77443 .47198 .78545 .46872 .78067 .46282 Mtetra
.688 .775 .917 r
.78067 .46282 .78545 .46872 .79648 .46503 .79168 .45853 Mtetra
.685 .754 .903 r
.79168 .45853 .79648 .46503 .80753 .46115 .80274 .45429 Mtetra
.68 .741 .896 r
.80274 .45429 .80753 .46115 .81862 .4572 .81385 .45017 Mtetra
.672 .732 .896 r
.81385 .45017 .81862 .4572 .82976 .45334 .82501 .44629 Mtetra
.665 .73 .898 r
.82501 .44629 .82976 .45334 .84095 .44957 .83624 .44259 Mtetra
.66 .731 .902 r
.83624 .44259 .84095 .44957 .85219 .44592 .84752 .43903 Mtetra
.656 .733 .906 r
.84752 .43903 .85219 .44592 .86348 .44235 .85886 .43558 Mtetra
.654 .737 .911 r
.85886 .43558 .86348 .44235 .87483 .43884 .87024 .43217 Mtetra
.653 .741 .914 r
.87024 .43217 .87483 .43884 .88622 .43537 .88168 .42878 Mtetra
.652 .744 .917 r
.88168 .42878 .88622 .43537 .89766 .43192 .89317 .42539 Mtetra
.652 .747 .919 r
.89317 .42539 .89766 .43192 .90915 .42846 .90469 .42197 Mtetra
.661 .753 .918 r
.28853 .60308 .29453 .60833 .30382 .60539 .29784 .6001 Mtetra
.663 .752 .916 r
.29784 .6001 .30382 .60539 .31315 .60244 .30719 .59707 Mtetra
.663 .75 .915 r
.30719 .59707 .31315 .60244 .3225 .59949 .31657 .59403 Mtetra
.663 .747 .913 r
.31657 .59403 .3225 .59949 .33189 .59656 .32598 .59097 Mtetra
.663 .743 .91 r
.32598 .59097 .33189 .59656 .34131 .59367 .33542 .58791 Mtetra
.66 .737 .907 r
.33542 .58791 .34131 .59367 .35075 .59089 .3449 .58491 Mtetra
.655 .729 .904 r
.3449 .58491 .35075 .59089 .36022 .58825 .3544 .58203 Mtetra
.646 .719 .901 r
.3544 .58203 .36022 .58825 .36972 .58578 .36392 .57936 Mtetra
.633 .709 .901 r
.36392 .57936 .36972 .58578 .37924 .58355 .37347 .57701 Mtetra
.62 .701 .902 r
.37347 .57701 .37924 .58355 .3888 .58143 .38304 .57496 Mtetra
.604 .698 .91 r
.38304 .57496 .3888 .58143 .39839 .57938 .39263 .57328 Mtetra
.602 .711 .921 r
.39263 .57328 .39839 .57938 .40804 .57701 .40227 .57157 Mtetra
.609 .739 .937 r
.40227 .57157 .40804 .57701 .41774 .57406 .41196 .56959 Mtetra
.646 .789 .951 r
.41196 .56959 .41774 .57406 .4275 .57022 .42171 .5667 Mtetra
.705 .842 .948 r
.42171 .5667 .4275 .57022 .43731 .56524 .43155 .56238 Mtetra
.751 .875 .936 r
.43155 .56238 .43731 .56524 .44717 .55974 .44144 .55683 Mtetra
.786 .874 .912 r
.44144 .55683 .44717 .55974 .45705 .55413 .45137 .55021 Mtetra
.767 .834 .904 r
.45137 .55021 .45705 .55413 .46693 .54957 .46131 .54406 Mtetra
.715 .769 .895 r
.46131 .54406 .46693 .54957 .47681 .54681 .47124 .53938 Mtetra
.641 .687 .877 r
.47124 .53938 .47681 .54681 .48671 .54572 .48118 .53673 Mtetra
.557 .61 .861 r
.48118 .53673 .48671 .54572 .49664 .54618 .49113 .53642 Mtetra
.515 .571 .85 r
.49113 .53642 .49664 .54618 .50663 .54707 .50112 .53728 Mtetra
.495 .561 .852 r
.50112 .53728 .50663 .54707 .51668 .54766 .51117 .53858 Mtetra
.508 .585 .867 r
.51117 .53858 .51668 .54766 .52679 .54747 .52129 .53942 Mtetra
.542 .63 .888 r
.52129 .53942 .52679 .54747 .53695 .5462 .53146 .53925 Mtetra
.574 .68 .912 r
.53146 .53925 .53695 .5462 .54715 .54411 .54169 .53814 Mtetra
.608 .728 .93 r
.54169 .53814 .54715 .54411 .55739 .54137 .55196 .53612 Mtetra
.627 .763 .944 r
.55196 .53612 .55739 .54137 .56766 .53833 .56227 .53355 Mtetra
.64 .787 .953 r
.56227 .53355 .56766 .53833 .57798 .53518 .57262 .53061 Mtetra
.647 .799 .956 r
.57262 .53061 .57798 .53518 .58833 .53204 .583 .52745 Mtetra
.657 .802 .952 r
.583 .52745 .58833 .53204 .59872 .52892 .59341 .52408 Mtetra
.675 .797 .94 r
.59341 .52408 .59872 .52892 .60915 .52569 .60386 .52033 Mtetra
.696 .784 .919 r
.60386 .52033 .60915 .52569 .61961 .52215 .61433 .51602 Mtetra
.722 .765 .887 r
.61433 .51602 .61961 .52215 .63008 .51795 .6248 .5108 Mtetra
.738 .739 .852 r
.6248 .5108 .63008 .51795 .64056 .51293 .63527 .50462 Mtetra
.749 .713 .819 r
.63527 .50462 .64056 .51293 .65103 .50681 .64572 .4974 Mtetra
.746 .69 .798 r
.64572 .4974 .65103 .50681 .66149 .49987 .65617 .4897 Mtetra
.732 .671 .791 r
.65617 .4897 .66149 .49987 .67194 .49263 .66664 .48243 Mtetra
.71 .662 .801 r
.66664 .48243 .67194 .49263 .68244 .4858 .67719 .47634 Mtetra
.662 .656 .834 r
.67719 .47634 .68244 .4858 .69303 .48054 .68788 .47263 Mtetra
.598 .667 .888 r
.68788 .47263 .69303 .48054 .70374 .47697 .69871 .47097 Mtetra
.503 .689 .951 r
.69871 .47097 .70374 .47697 .71459 .47525 .70968 .47083 Mtetra
.407 .71 .985 r
.70968 .47083 .71459 .47525 .72556 .47461 .72075 .47119 Mtetra
.44 .773 .997 r
.72075 .47119 .72556 .47461 .73659 .47387 .73181 .47044 Mtetra
.535 .819 .998 r
.73181 .47044 .73659 .47387 .74764 .47259 .74285 .46845 Mtetra
.643 .83 .972 r
.74285 .46845 .74764 .47259 .75866 .47014 .75384 .465 Mtetra
.692 .805 .935 r
.75384 .465 .75866 .47014 .76967 .46679 .7648 .46059 Mtetra
.701 .769 .905 r
.7648 .46059 .76967 .46679 .78067 .46282 .77578 .45589 Mtetra
.699 .745 .887 r
.77578 .45589 .78067 .46282 .79168 .45853 .78679 .45117 Mtetra
.686 .728 .882 r
.78679 .45117 .79168 .45853 .80274 .45429 .79787 .44681 Mtetra
.675 .721 .883 r
.79787 .44681 .80274 .45429 .81385 .45017 .80901 .44277 Mtetra
.665 .719 .889 r
.80901 .44277 .81385 .45017 .82501 .44629 .82022 .43905 Mtetra
.658 .722 .897 r
.82022 .43905 .82501 .44629 .83624 .44259 .8315 .43556 Mtetra
.653 .728 .904 r
.8315 .43556 .83624 .44259 .84752 .43903 .84283 .43218 Mtetra
.65 .733 .91 r
.84283 .43218 .84752 .43903 .85886 .43558 .85421 .42887 Mtetra
.65 .739 .915 r
.85421 .42887 .85886 .43558 .87024 .43217 .86564 .42554 Mtetra
.65 .743 .918 r
.86564 .42554 .87024 .43217 .88168 .42878 .87712 .42221 Mtetra
.65 .746 .92 r
.87712 .42221 .88168 .42878 .89317 .42539 .88864 .41885 Mtetra
.651 .748 .921 r
.88864 .41885 .89317 .42539 .90469 .42197 .90021 .41544 Mtetra
.66 .752 .918 r
.28248 .59781 .28853 .60308 .29784 .6001 .29181 .59483 Mtetra
.662 .754 .918 r
.29181 .59483 .29784 .6001 .30719 .59707 .30118 .5918 Mtetra
.664 .755 .918 r
.30118 .5918 .30719 .59707 .31657 .59403 .31058 .58872 Mtetra
.666 .755 .917 r
.31058 .58872 .31657 .59403 .32598 .59097 .32002 .58557 Mtetra
.669 .753 .913 r
.32002 .58557 .32598 .59097 .33542 .58791 .32949 .58234 Mtetra
.669 .748 .909 r
.32949 .58234 .33542 .58791 .3449 .58491 .339 .5791 Mtetra
.668 .74 .903 r
.339 .5791 .3449 .58491 .3544 .58203 .34853 .57585 Mtetra
.661 .726 .897 r
.34853 .57585 .3544 .58203 .36392 .57936 .3581 .57277 Mtetra
.65 .71 .892 r
.3581 .57277 .36392 .57936 .37347 .57701 .36768 .56999 Mtetra
.632 .691 .887 r
.36768 .56999 .37347 .57701 .38304 .57496 .37727 .56767 Mtetra
.606 .674 .889 r
.37727 .56767 .38304 .57496 .39263 .57328 .38688 .566 Mtetra
.586 .667 .895 r
.38688 .566 .39263 .57328 .40227 .57157 .39652 .56476 Mtetra
.566 .675 .912 r
.39652 .56476 .40227 .57157 .41196 .56959 .40618 .56388 Mtetra
.584 .722 .938 r
.40618 .56388 .41196 .56959 .42171 .5667 .41591 .5624 Mtetra
.634 .796 .96 r
.41591 .5624 .42171 .5667 .43155 .56238 .42573 .55965 Mtetra
.709 .878 .96 r
.42573 .55965 .43155 .56238 .44144 .55683 .43563 .55505 Mtetra
.791 .92 .924 r
.43563 .55505 .44144 .55683 .45137 .55021 .4456 .54819 Mtetra
.811 .909 .908 r
.4456 .54819 .45137 .55021 .46131 .54406 .45561 .5407 Mtetra
.794 .859 .898 r
.45561 .5407 .46131 .54406 .47124 .53938 .46562 .53364 Mtetra
.725 .765 .885 r
.46562 .53364 .47124 .53938 .48118 .53673 .47561 .52855 Mtetra
.624 .661 .866 r
.47561 .52855 .48118 .53673 .49113 .53642 .48559 .52636 Mtetra
.555 .586 .839 r
.48559 .52636 .49113 .53642 .50112 .53728 .4956 .5262 Mtetra
.505 .539 .826 r
.4956 .5262 .50112 .53728 .51117 .53858 .50565 .52757 Mtetra
.497 .537 .828 r
.50565 .52757 .51117 .53858 .52129 .53942 .51577 .5291 Mtetra
.516 .562 .841 r
.51577 .5291 .52129 .53942 .53146 .53925 .52595 .53001 Mtetra
.544 .601 .862 r
.52595 .53001 .53146 .53925 .54169 .53814 .53619 .53001 Mtetra
.581 .649 .882 r
.53619 .53001 .54169 .53814 .55196 .53612 .54648 .5289 Mtetra
.609 .688 .899 r
.54648 .5289 .55196 .53612 .56227 .53355 .55682 .52697 Mtetra
.635 .72 .908 r
.55682 .52697 .56227 .53355 .57262 .53061 .56719 .52434 Mtetra
.655 .738 .91 r
.56719 .52434 .57262 .53061 .583 .52745 .5776 .52116 Mtetra
.675 .744 .903 r
.5776 .52116 .583 .52745 .59341 .52408 .58803 .51743 Mtetra
.696 .74 .885 r
.58803 .51743 .59341 .52408 .60386 .52033 .59849 .51299 Mtetra
.715 .727 .859 r
.59849 .51299 .60386 .52033 .61433 .51602 .60896 .50773 Mtetra
.732 .708 .828 r
.60896 .50773 .61433 .51602 .6248 .5108 .61942 .50134 Mtetra
.739 .686 .8 r
.61942 .50134 .6248 .5108 .63527 .50462 .62987 .49401 Mtetra
.739 .667 .779 r
.62987 .49401 .63527 .50462 .64572 .4974 .64031 .48604 Mtetra
.73 .652 .771 r
.64031 .48604 .64572 .4974 .65617 .4897 .65078 .47822 Mtetra
.704 .639 .781 r
.65078 .47822 .65617 .4897 .66664 .48243 .66131 .47193 Mtetra
.669 .639 .811 r
.66131 .47193 .66664 .48243 .67719 .47634 .67196 .46771 Mtetra
.587 .643 .873 r
.67196 .46771 .67719 .47634 .68788 .47263 .68278 .46642 Mtetra
.453 .657 .948 r
.68278 .46642 .68788 .47263 .69871 .47097 .69377 .46716 Mtetra
.29 .673 .973 r
.69377 .46716 .69871 .47097 .70968 .47083 .70484 .46834 Mtetra
.233 .695 .948 r
.70484 .46834 .70968 .47083 .72075 .47119 .71596 .4689 Mtetra
.446 .827 .989 r
.71596 .4689 .72075 .47119 .73181 .47044 .727 .46716 Mtetra
.635 .865 .985 r
.727 .46716 .73181 .47044 .74285 .46845 .73797 .46351 Mtetra
.712 .819 .932 r
.73797 .46351 .74285 .46845 .75384 .465 .74889 .45855 Mtetra
.726 .769 .887 r
.74889 .45855 .75384 .465 .7648 .46059 .7598 .45297 Mtetra
.709 .729 .866 r
.7598 .45297 .7648 .46059 .77578 .45589 .77077 .44774 Mtetra
.693 .709 .86 r
.77077 .44774 .77578 .45589 .78679 .45117 .7818 .44295 Mtetra
.674 .7 .866 r
.7818 .44295 .78679 .45117 .79787 .44681 .79293 .43884 Mtetra
.661 .702 .877 r
.79293 .43884 .79787 .44681 .80901 .44277 .80413 .4352 Mtetra
.652 .71 .89 r
.80413 .4352 .80901 .44277 .82022 .43905 .81541 .43186 Mtetra
.645 .72 .903 r
.81541 .43186 .82022 .43905 .8315 .43556 .82674 .42869 Mtetra
.644 .731 .912 r
.82674 .42869 .8315 .43556 .84283 .43218 .83813 .42553 Mtetra
.644 .739 .918 r
.83813 .42553 .84283 .43218 .85421 .42887 .84956 .42234 Mtetra
.647 .746 .922 r
.84956 .42234 .85421 .42887 .86564 .42554 .86103 .41907 Mtetra
.648 .749 .923 r
.86103 .41907 .86564 .42554 .87712 .42221 .87254 .41572 Mtetra
.65 .75 .923 r
.87254 .41572 .87712 .42221 .88864 .41885 .88409 .41232 Mtetra
.652 .751 .922 r
.88409 .41232 .88864 .41885 .90021 .41544 .89569 .40886 Mtetra
.656 .752 .92 r
.27639 .59249 .28248 .59781 .29181 .59483 .28574 .58959 Mtetra
.658 .755 .922 r
.28574 .58959 .29181 .59483 .30118 .5918 .29512 .58663 Mtetra
.66 .759 .923 r
.29512 .58663 .30118 .5918 .31058 .58872 .30454 .58361 Mtetra
.664 .763 .924 r
.30454 .58361 .31058 .58872 .32002 .58557 .31399 .58048 Mtetra
.67 .766 .922 r
.31399 .58048 .32002 .58557 .32949 .58234 .32349 .57721 Mtetra
.674 .766 .92 r
.32349 .57721 .32949 .58234 .339 .5791 .33303 .57381 Mtetra
.68 .762 .914 r
.33303 .57381 .339 .5791 .34853 .57585 .3426 .57027 Mtetra
.678 .752 .907 r
.3426 .57027 .34853 .57585 .3581 .57277 .35221 .56674 Mtetra
.673 .736 .897 r
.35221 .56674 .3581 .57277 .36768 .56999 .36184 .56331 Mtetra
.656 .711 .888 r
.36184 .56331 .36768 .56999 .37727 .56767 .37148 .56032 Mtetra
.629 .682 .881 r
.37148 .56032 .37727 .56767 .38688 .566 .38113 .55805 Mtetra
.597 .653 .876 r
.38113 .55805 .38688 .566 .39652 .56476 .39078 .55661 Mtetra
.555 .63 .881 r
.39078 .55661 .39652 .56476 .40618 .56388 .40044 .55618 Mtetra
.542 .638 .895 r
.40044 .55618 .40618 .56388 .41591 .5624 .41014 .55591 Mtetra
.549 .682 .926 r
.41014 .55591 .41591 .5624 .42573 .55965 .41991 .55522 Mtetra
.625 .789 .961 r
.41991 .55522 .42573 .55965 .43563 .55505 .42978 .55264 Mtetra
.742 .896 .948 r
.42978 .55264 .43563 .55505 .4456 .54819 .43976 .54718 Mtetra
.803 .948 .917 r
.43976 .54718 .4456 .54819 .45561 .5407 .44981 .53975 Mtetra
.842 .944 .888 r
.44981 .53975 .45561 .5407 .46562 .53364 .4599 .53098 Mtetra
.813 .887 .898 r
.4599 .53098 .46562 .53364 .47561 .52855 .46997 .5233 Mtetra
.728 .785 .898 r
.46997 .5233 .47561 .52855 .48559 .52636 .48001 .51816 Mtetra
.635 .667 .863 r
.48001 .51816 .48559 .52636 .4956 .5262 .49005 .51561 Mtetra
.549 .573 .831 r
.49005 .51561 .4956 .5262 .50565 .52757 .50012 .51565 Mtetra
.519 .533 .81 r
.50012 .51565 .50565 .52757 .51577 .5291 .51023 .51676 Mtetra
.515 .524 .804 r
.51023 .51676 .51577 .5291 .52595 .53001 .52041 .51807 Mtetra
.532 .541 .81 r
.52041 .51807 .52595 .53001 .53619 .53001 .53066 .5188 Mtetra
.563 .571 .82 r
.53066 .5188 .53619 .53001 .54648 .5289 .54096 .51849 Mtetra
.592 .601 .83 r
.54096 .51849 .54648 .5289 .55682 .52697 .55131 .51719 Mtetra
.623 .63 .836 r
.55131 .51719 .55682 .52697 .56719 .52434 .5617 .51488 Mtetra
.649 .649 .836 r
.5617 .51488 .56719 .52434 .5776 .52116 .57212 .51168 Mtetra
.672 .658 .828 r
.57212 .51168 .5776 .52116 .58803 .51743 .58256 .50758 Mtetra
.693 .66 .813 r
.58256 .50758 .58803 .51743 .59849 .51299 .59302 .50245 Mtetra
.708 .654 .794 r
.59302 .50245 .59849 .51299 .60896 .50773 .60348 .49633 Mtetra
.72 .646 .775 r
.60348 .49633 .60896 .50773 .61942 .50134 .61394 .48914 Mtetra
.722 .637 .762 r
.61394 .48914 .61942 .50134 .62987 .49401 .62439 .48136 Mtetra
.716 .628 .758 r
.62439 .48136 .62987 .49401 .64031 .48604 .63486 .47376 Mtetra
.702 .627 .77 r
.63486 .47376 .64031 .48604 .65078 .47822 .64538 .46723 Mtetra
.659 .626 .806 r
.64538 .46723 .65078 .47822 .66131 .47193 .65603 .46332 Mtetra
.586 .644 .875 r
.65603 .46332 .66131 .47193 .67196 .46771 .66683 .46204 Mtetra
.39 .647 .959 r
.66683 .46204 .67196 .46771 .68278 .46642 .6778 .46335 Mtetra
.081 .569 .899 r
.6778 .46335 .68278 .46642 .69377 .46716 .6889 .4658 Mtetra
.038 .593 .822 r
.6889 .4658 .69377 .46716 .70484 .46834 .70001 .46689 Mtetra
.283 .762 .927 r
.70001 .46689 .70484 .46834 .71596 .4689 .71109 .46598 Mtetra
.636 .882 .986 r
.71109 .46598 .71596 .4689 .727 .46716 .72204 .46212 Mtetra
.74 .823 .916 r
.72204 .46212 .727 .46716 .73797 .46351 .73291 .45631 Mtetra
.738 .75 .862 r
.73291 .45631 .73797 .46351 .74889 .45855 .74378 .45005 Mtetra
.723 .711 .839 r
.74378 .45005 .74889 .45855 .7598 .45297 .75468 .44395 Mtetra
.695 .689 .84 r
.75468 .44395 .7598 .45297 .77077 .44774 .76568 .43888 Mtetra
.674 .684 .852 r
.76568 .43888 .77077 .44774 .7818 .44295 .77679 .43468 Mtetra
.655 .691 .872 r
.77679 .43468 .7818 .44295 .79293 .43884 .78799 .4312 Mtetra
.641 .704 .893 r
.78799 .4312 .79293 .43884 .80413 .4352 .79927 .42818 Mtetra
.635 .722 .91 r
.79927 .42818 .80413 .4352 .81541 .43186 .81062 .42527 Mtetra
.633 .737 .923 r
.81062 .42527 .81541 .43186 .82674 .42869 .82201 .42237 Mtetra
.637 .749 .929 r
.82201 .42237 .82674 .42869 .83813 .42553 .83344 .41932 Mtetra
.641 .756 .932 r
.83344 .41932 .83813 .42553 .84956 .42234 .84491 .41614 Mtetra
.647 .759 .931 r
.84491 .41614 .84956 .42234 .86103 .41907 .8564 .4128 Mtetra
.651 .759 .929 r
.8564 .4128 .86103 .41907 .87254 .41572 .86794 .40935 Mtetra
.653 .757 .926 r
.86794 .40935 .87254 .41572 .88409 .41232 .87952 .40582 Mtetra
.655 .754 .923 r
.87952 .40582 .88409 .41232 .89569 .40886 .89113 .40224 Mtetra
.65 .75 .923 r
.27027 .58715 .27639 .59249 .28574 .58959 .27962 .58436 Mtetra
.65 .755 .926 r
.27962 .58436 .28574 .58959 .29512 .58663 .28901 .58157 Mtetra
.652 .762 .93 r
.28901 .58157 .29512 .58663 .30454 .58361 .29844 .5787 Mtetra
.656 .77 .933 r
.29844 .5787 .30454 .58361 .31399 .58048 .30791 .57572 Mtetra
.662 .778 .935 r
.30791 .57572 .31399 .58048 .32349 .57721 .31742 .57257 Mtetra
.671 .785 .935 r
.31742 .57257 .32349 .57721 .33303 .57381 .32697 .5692 Mtetra
.684 .79 .93 r
.32697 .5692 .33303 .57381 .3426 .57027 .33658 .56553 Mtetra
.692 .787 .923 r
.33658 .56553 .3426 .57027 .35221 .56674 .34623 .56163 Mtetra
.7 .776 .911 r
.34623 .56163 .35221 .56674 .36184 .56331 .35592 .55751 Mtetra
.691 .75 .896 r
.35592 .55751 .36184 .56331 .37148 .56032 .36562 .55355 Mtetra
.673 .715 .88 r
.36562 .55355 .37148 .56032 .38113 .55805 .37534 .55003 Mtetra
.636 .668 .864 r
.37534 .55003 .38113 .55805 .39078 .55661 .38505 .54752 Mtetra
.582 .619 .854 r
.38505 .54752 .39078 .55661 .40044 .55618 .39474 .54651 Mtetra
.536 .585 .85 r
.39474 .54651 .40044 .55618 .41014 .55591 .40443 .54674 Mtetra
.48 .569 .868 r
.40443 .54674 .41014 .55591 .41991 .55522 .41414 .54804 Mtetra
.505 .641 .916 r
.41414 .54804 .41991 .55522 .42978 .55264 .42394 .54829 Mtetra
.603 .788 .969 r
.42394 .54829 .42978 .55264 .43976 .54718 .43387 .54602 Mtetra
.717 .942 .957 r
.43387 .54602 .43976 .54718 .44981 .53975 .44391 .54057 Mtetra
.821 .992 .868 r
.44391 .54057 .44981 .53975 .4599 .53098 .45405 .53158 Mtetra
.848 .985 .861 r
.45405 .53158 .4599 .53098 .46997 .5233 .46421 .5219 Mtetra
.839 .933 .89 r
.46421 .5219 .46997 .5233 .48001 .51816 .47435 .51322 Mtetra
.759 .803 .888 r
.47435 .51322 .48001 .51816 .49005 .51561 .48446 .50704 Mtetra
.643 .662 .854 r
.48446 .50704 .49005 .51561 .50012 .51565 .49456 .50418 Mtetra
.577 .572 .811 r
.49456 .50418 .50012 .51565 .51023 .51676 .50469 .5034 Mtetra
.541 .524 .786 r
.50469 .5034 .51023 .51676 .52041 .51807 .51486 .50399 Mtetra
.54 .514 .776 r
.51486 .50399 .52041 .51807 .53066 .5188 .5251 .5047 Mtetra
.557 .524 .774 r
.5251 .5047 .53066 .5188 .54096 .51849 .5354 .50477 Mtetra
.581 .543 .777 r
.5354 .50477 .54096 .51849 .55131 .51719 .54575 .50389 Mtetra
.61 .564 .779 r
.54575 .50389 .55131 .51719 .5617 .51488 .55614 .50183 Mtetra
.636 .582 .777 r
.55614 .50183 .5617 .51488 .57212 .51168 .56657 .4986 Mtetra
.659 .594 .771 r
.56657 .4986 .57212 .51168 .58256 .50758 .57701 .49419 Mtetra
.679 .601 .761 r
.57701 .49419 .58256 .50758 .59302 .50245 .58747 .48858 Mtetra
.692 .602 .751 r
.58747 .48858 .59302 .50245 .60348 .49633 .59793 .48202 Mtetra
.699 .601 .743 r
.59793 .48202 .60348 .49633 .61394 .48914 .60839 .47479 Mtetra
.697 .599 .744 r
.60839 .47479 .61394 .48914 .62439 .48136 .61887 .46768 Mtetra
.679 .598 .758 r
.61887 .46768 .62439 .48136 .63486 .47376 .62941 .46193 Mtetra
.649 .608 .795 r
.62941 .46193 .63486 .47376 .64538 .46723 .64004 .45829 Mtetra
.548 .618 .874 r
.64004 .45829 .64538 .46723 .65603 .46332 .65085 .45801 Mtetra
.289 .607 .954 r
.65085 .45801 .65603 .46332 .66683 .46204 .66182 .46029 Mtetra
0 .408 .711 r
.66182 .46029 .66683 .46204 .6778 .46335 .67292 .46361 Mtetra
.301 0 0 r
.67292 .46361 .6778 .46335 .6889 .4658 .68408 .46624 Mtetra
0 0 0 r
.68408 .46624 .6889 .4658 .70001 .46689 .69513 .46527 Mtetra
.603 .92 .974 r
.69513 .46527 .70001 .46689 .71109 .46598 .70606 .46105 Mtetra
.77 .834 .901 r
.70606 .46105 .71109 .46598 .72204 .46212 .71688 .45424 Mtetra
.766 .741 .83 r
.71688 .45424 .72204 .46212 .73291 .45631 .72765 .44634 Mtetra
.725 .681 .807 r
.72765 .44634 .73291 .45631 .74378 .45005 .7385 .43952 Mtetra
.695 .658 .809 r
.7385 .43952 .74378 .45005 .75468 .44395 .74946 .43396 Mtetra
.663 .654 .831 r
.74946 .43396 .75468 .44395 .76568 .43888 .76056 .42995 Mtetra
.638 .667 .862 r
.76056 .42995 .76568 .43888 .77679 .43468 .77178 .42698 Mtetra
.622 .695 .896 r
.77178 .42698 .77679 .43468 .78799 .4312 .78309 .42447 Mtetra
.611 .722 .924 r
.78309 .42447 .78799 .4312 .79927 .42818 .79446 .42213 Mtetra
.616 .75 .941 r
.79446 .42213 .79927 .42818 .81062 .42527 .80587 .41955 Mtetra
.622 .767 .949 r
.80587 .41955 .81062 .42527 .82201 .42237 .81731 .41674 Mtetra
.634 .776 .948 r
.81731 .41674 .82201 .42237 .83344 .41932 .82877 .41361 Mtetra
.644 .778 .945 r
.82877 .41361 .83344 .41932 .84491 .41614 .84025 .41025 Mtetra
.652 .775 .939 r
.84025 .41025 .84491 .41614 .8564 .4128 .85177 .40672 Mtetra
.657 .771 .933 r
.85177 .40672 .8564 .4128 .86794 .40935 .86332 .40306 Mtetra
.66 .765 .928 r
.86332 .40306 .86794 .40935 .87952 .40582 .87491 .39932 Mtetra
.66 .759 .923 r
.87491 .39932 .87952 .40582 .89113 .40224 .88655 .39556 Mtetra
.645 .749 .925 r
.2641 .58177 .27027 .58715 .27962 .58436 .27346 .57908 Mtetra
.643 .753 .929 r
.27346 .57908 .27962 .58436 .28901 .58157 .28286 .57642 Mtetra
.643 .759 .933 r
.28286 .57642 .28901 .58157 .29844 .5787 .2923 .57373 Mtetra
.645 .767 .937 r
.2923 .57373 .29844 .5787 .30791 .57572 .30177 .57097 Mtetra
.649 .777 .942 r
.30177 .57097 .30791 .57572 .31742 .57257 .31129 .56809 Mtetra
.658 .79 .945 r
.31129 .56809 .31742 .57257 .32697 .5692 .32085 .56498 Mtetra
.672 .804 .946 r
.32085 .56498 .32697 .5692 .33658 .56553 .33047 .56153 Mtetra
.688 .817 .944 r
.33047 .56153 .33658 .56553 .34623 .56163 .34014 .55767 Mtetra
.71 .823 .935 r
.34014 .55767 .34623 .56163 .35592 .55751 .34987 .55327 Mtetra
.72 .814 .924 r
.34987 .55327 .35592 .55751 .36562 .55355 .35964 .54861 Mtetra
.722 .789 .905 r
.35964 .54861 .36562 .55355 .37534 .55003 .36944 .54381 Mtetra
.694 .74 .886 r
.36944 .54381 .37534 .55003 .38505 .54752 .37924 .53968 Mtetra
.646 .678 .866 r
.37924 .53968 .38505 .54752 .39474 .54651 .38901 .53684 Mtetra
.581 .607 .843 r
.38901 .53684 .39474 .54651 .40443 .54674 .39875 .53588 Mtetra
.494 .539 .831 r
.39875 .53588 .40443 .54674 .41414 .54804 .40846 .5373 Mtetra
.466 .527 .836 r
.40846 .5373 .41414 .54804 .42394 .54829 .4182 .53933 Mtetra
.469 .572 .876 r
.4182 .53933 .42394 .54829 .43387 .54602 .42803 .54075 Mtetra
.579 .744 .955 r
.42803 .54075 .43387 .54602 .44391 .54057 .43801 .53913 Mtetra
.755 .937 .945 r
.43801 .53913 .44391 .54057 .45405 .53158 .44813 .53299 Mtetra
.792 .998 .851 r
.44813 .53299 .45405 .53158 .46421 .5219 .45833 .52409 Mtetra
.824 1 .803 r
.45833 .52409 .46421 .5219 .47435 .51322 .46855 .51357 Mtetra
.84 .983 .869 r
.46855 .51357 .47435 .51322 .48446 .50704 .47876 .50418 Mtetra
.784 .887 .92 r
.47876 .50418 .48446 .50704 .49456 .50418 .48893 .49747 Mtetra
.692 .733 .882 r
.48893 .49747 .49456 .50418 .50469 .5034 .49911 .49323 Mtetra
.61 .614 .831 r
.49911 .49323 .50469 .5034 .51486 .50399 .5093 .49134 Mtetra
.58 .557 .793 r
.5093 .49134 .51486 .50399 .5251 .5047 .51953 .49045 Mtetra
.576 .533 .77 r
.51953 .49045 .5251 .5047 .5354 .50477 .52982 .48974 Mtetra
.588 .531 .759 r
.52982 .48974 .5354 .50477 .54575 .50389 .54017 .48852 Mtetra
.607 .539 .752 r
.54017 .48852 .54575 .50389 .55614 .50183 .55055 .48635 Mtetra
.628 .55 .748 r
.55055 .48635 .55614 .50183 .56657 .4986 .56097 .48308 Mtetra
.647 .561 .743 r
.56097 .48308 .56657 .4986 .57701 .49419 .57142 .47872 Mtetra
.663 .57 .74 r
.57142 .47872 .57701 .49419 .58747 .48858 .58188 .4734 Mtetra
.673 .578 .741 r
.58188 .4734 .58747 .48858 .59793 .48202 .59235 .46756 Mtetra
.674 .586 .75 r
.59235 .46756 .59793 .48202 .60839 .47479 .60286 .46189 Mtetra
.665 .6 .773 r
.60286 .46189 .60839 .47479 .61887 .46768 .61342 .45722 Mtetra
.619 .618 .828 r
.61342 .45722 .61887 .46768 .62941 .46193 .62408 .45492 Mtetra
.499 .653 .928 r
.62408 .45492 .62941 .46193 .64004 .45829 .63487 .45513 Mtetra
.021 .524 .871 r
.63487 .45513 .64004 .45829 .65085 .45801 .64583 .45807 Mtetra
.413 0 0 r
.64583 .45807 .65085 .45801 .66182 .46029 .65692 .46219 Mtetra
.398 0 0 r
.65692 .46219 .66182 .46029 .67292 .46361 .66803 .46467 Mtetra
.086 0 0 r
.66803 .46467 .67292 .46361 .68408 .46624 .67909 .46437 Mtetra
.662 .93 .971 r
.67909 .46437 .68408 .46624 .69513 .46527 .68998 .45944 Mtetra
.791 .806 .864 r
.68998 .45944 .69513 .46527 .70606 .46105 .70074 .4514 Mtetra
.761 .701 .795 r
.70074 .4514 .70606 .46105 .71688 .45424 .71148 .44272 Mtetra
.733 .658 .775 r
.71148 .44272 .71688 .45424 .72765 .44634 .72226 .43463 Mtetra
.689 .635 .791 r
.72226 .43463 .72765 .44634 .7385 .43952 .7332 .42898 Mtetra
.653 .639 .824 r
.7332 .42898 .7385 .43952 .74946 .43396 .74431 .42526 Mtetra
.619 .665 .873 r
.74431 .42526 .74946 .43396 .76056 .42995 .75555 .42288 Mtetra
.587 .7 .921 r
.75555 .42288 .76056 .42995 .77178 .42698 .7669 .42119 Mtetra
.578 .743 .955 r
.7669 .42119 .77178 .42698 .78309 .42447 .77829 .41936 Mtetra
.579 .773 .971 r
.77829 .41936 .78309 .42447 .79446 .42213 .78972 .41725 Mtetra
.603 .794 .973 r
.78972 .41725 .79446 .42213 .80587 .41955 .80116 .4146 Mtetra
.624 .8 .967 r
.80116 .4146 .80587 .41955 .81731 .41674 .81261 .41151 Mtetra
.643 .797 .957 r
.81261 .41151 .81731 .41674 .82877 .41361 .82408 .40807 Mtetra
.656 .79 .946 r
.82408 .40807 .82877 .41361 .84025 .41025 .83557 .40438 Mtetra
.661 .781 .937 r
.83557 .40438 .84025 .41025 .85177 .40672 .8471 .40057 Mtetra
.665 .773 .93 r
.8471 .40057 .85177 .40672 .86332 .40306 .85867 .39668 Mtetra
.666 .766 .925 r
.85867 .39668 .86332 .40306 .87491 .39932 .87027 .39275 Mtetra
.665 .76 .921 r
.87027 .39275 .87491 .39932 .88655 .39556 .88193 .38884 Mtetra
.643 .748 .926 r
.25789 .57635 .2641 .58177 .27346 .57908 .26727 .57369 Mtetra
.639 .749 .928 r
.26727 .57369 .27346 .57908 .28286 .57642 .27668 .5711 Mtetra
.637 .751 .931 r
.27668 .5711 .28286 .57642 .2923 .57373 .28613 .56854 Mtetra
.635 .756 .936 r
.28613 .56854 .2923 .57373 .30177 .57097 .29561 .56599 Mtetra
.632 .765 .943 r
.29561 .56599 .30177 .57097 .31129 .56809 .30512 .56346 Mtetra
.635 .78 .951 r
.30512 .56346 .31129 .56809 .32085 .56498 .31468 .56081 Mtetra
.641 .801 .96 r
.31468 .56081 .32085 .56498 .33047 .56153 .32429 .55794 Mtetra
.658 .83 .966 r
.32429 .55794 .33047 .56153 .34014 .55767 .33396 .55461 Mtetra
.687 .858 .964 r
.33396 .55461 .34014 .55767 .34987 .55327 .3437 .55059 Mtetra
.718 .878 .956 r
.3437 .55059 .34987 .55327 .35964 .54861 .3535 .54582 Mtetra
.754 .876 .935 r
.3535 .54582 .35964 .54861 .36944 .54381 .36338 .54015 Mtetra
.76 .843 .914 r
.36338 .54015 .36944 .54381 .37924 .53968 .37328 .53429 Mtetra
.741 .778 .883 r
.37328 .53429 .37924 .53968 .38901 .53684 .38319 .52869 Mtetra
.675 .682 .849 r
.38319 .52869 .38901 .53684 .39875 .53588 .39306 .52486 Mtetra
.581 .581 .817 r
.39306 .52486 .39875 .53588 .40846 .5373 .40285 .52393 Mtetra
.5 .5 .788 r
.40285 .52393 .40846 .5373 .4182 .53933 .41259 .52569 Mtetra
.407 .442 .784 r
.41259 .52569 .4182 .53933 .42803 .54075 .42233 .52995 Mtetra
.412 .498 .837 r
.42233 .52995 .42803 .54075 .43801 .53913 .43218 .53304 Mtetra
.518 .691 .946 r
.43218 .53304 .43801 .53913 .44813 .53299 .44219 .53264 Mtetra
.623 .945 .947 r
.44219 .53264 .44813 .53299 .45833 .52409 .45234 .5279 Mtetra
.656 .944 .696 r
.45234 .5279 .45833 .52409 .46855 .51357 .46262 .51845 Mtetra
.655 .921 .624 r
.46262 .51845 .46855 .51357 .47876 .50418 .47291 .50755 Mtetra
.747 .979 .733 r
.47291 .50755 .47876 .50418 .48893 .49747 .48319 .49709 Mtetra
.823 .972 .894 r
.48319 .49709 .48893 .49747 .49911 .49323 .49345 .48854 Mtetra
.749 .817 .905 r
.49345 .48854 .49911 .49323 .5093 .49134 .50369 .48272 Mtetra
.675 .678 .845 r
.50369 .48272 .5093 .49134 .51953 .49045 .51395 .47869 Mtetra
.629 .597 .798 r
.51395 .47869 .51953 .49045 .52982 .48974 .52424 .47593 Mtetra
.616 .562 .77 r
.52424 .47593 .52982 .48974 .54017 .48852 .53458 .47346 Mtetra
.618 .549 .754 r
.53458 .47346 .54017 .48852 .55055 .48635 .54496 .47073 Mtetra
.628 .549 .746 r
.54496 .47073 .55055 .48635 .56097 .48308 .55537 .46743 Mtetra
.638 .554 .744 r
.55537 .46743 .56097 .48308 .57142 .47872 .56582 .46357 Mtetra
.644 .563 .749 r
.56582 .46357 .57142 .47872 .58188 .4734 .5763 .45944 Mtetra
.643 .576 .764 r
.5763 .45944 .58188 .4734 .59235 .46756 .58682 .4556 Mtetra
.622 .593 .8 r
.58682 .4556 .59235 .46756 .60286 .46189 .59741 .45304 Mtetra
.564 .629 .874 r
.59741 .45304 .60286 .46189 .61342 .45722 .60809 .45229 Mtetra
.277 .62 .959 r
.60809 .45229 .61342 .45722 .62408 .45492 .6189 .45431 Mtetra
.36 0 0 r
.6189 .45431 .62408 .45492 .63487 .45513 .62986 .45829 Mtetra
.547 .015 0 r
.62986 .45829 .63487 .45513 .64583 .45807 .64092 .46273 Mtetra
.509 .003 0 r
.64092 .46273 .64583 .45807 .65692 .46219 .65202 .46573 Mtetra
.163 0 0 r
.65202 .46573 .65692 .46219 .66803 .46467 .663 .46395 Mtetra
.687 .967 .931 r
.663 .46395 .66803 .46467 .67909 .46437 .67384 .45775 Mtetra
.814 .785 .826 r
.67384 .45775 .67909 .46437 .68998 .45944 .68453 .44796 Mtetra
.774 .675 .755 r
.68453 .44796 .68998 .45944 .70074 .4514 .69515 .43694 Mtetra
.715 .612 .742 r
.69515 .43694 .70074 .4514 .71148 .44272 .70591 .42848 Mtetra
.675 .594 .758 r
.70591 .42848 .71148 .44272 .72226 .43463 .71684 .42275 Mtetra
.625 .601 .807 r
.71684 .42275 .72226 .43463 .7332 .42898 .72798 .42 Mtetra
.568 .634 .877 r
.72798 .42 .7332 .42898 .74431 .42526 .73929 .41908 Mtetra
.522 .703 .953 r
.73929 .41908 .74431 .42526 .75555 .42288 .75069 .41844 Mtetra
.481 .757 .991 r
.75069 .41844 .75555 .42288 .7669 .42119 .76214 .41761 Mtetra
.508 .809 .999 r
.76214 .41761 .7669 .42119 .77829 .41936 .77358 .41584 Mtetra
.557 .835 .997 r
.77358 .41584 .77829 .41936 .78972 .41725 .78501 .41331 Mtetra
.613 .84 .986 r
.78501 .41331 .78972 .41725 .80116 .4146 .79644 .41006 Mtetra
.648 .829 .97 r
.79644 .41006 .80116 .4146 .81261 .41151 .80788 .40632 Mtetra
.664 .809 .953 r
.80788 .40632 .81261 .41151 .82408 .40807 .81934 .40236 Mtetra
.672 .792 .939 r
.81934 .40236 .82408 .40807 .83557 .40438 .83084 .39825 Mtetra
.671 .777 .929 r
.83084 .39825 .83557 .40438 .8471 .40057 .84237 .39417 Mtetra
.671 .768 .923 r
.84237 .39417 .8471 .40057 .85867 .39668 .85396 .3901 Mtetra
.669 .762 .92 r
.85396 .3901 .85867 .39668 .87027 .39275 .86559 .38605 Mtetra
.667 .758 .918 r
.86559 .38605 .87027 .39275 .88193 .38884 .87727 .38207 Mtetra
.647 .749 .924 r
.25164 .57089 .25789 .57635 .26727 .57369 .26105 .56812 Mtetra
.644 .745 .923 r
.26105 .56812 .26727 .57369 .27668 .5711 .27049 .56542 Mtetra
.64 .741 .922 r
.27049 .56542 .27668 .5711 .28613 .56854 .27995 .5628 Mtetra
.634 .738 .923 r
.27995 .5628 .28613 .56854 .29561 .56599 .28945 .5603 Mtetra
.626 .738 .927 r
.28945 .5603 .29561 .56599 .30512 .56346 .29897 .55796 Mtetra
.621 .744 .934 r
.29897 .55796 .30512 .56346 .31468 .56081 .30852 .55568 Mtetra
.616 .757 .946 r
.30852 .55568 .31468 .56081 .32429 .55794 .31811 .55345 Mtetra
.623 .785 .959 r
.31811 .55345 .32429 .55794 .33396 .55461 .32776 .55094 Mtetra
.639 .824 .972 r
.32776 .55094 .33396 .55461 .3437 .55059 .33747 .54793 Mtetra
.672 .874 .975 r
.33747 .54793 .3437 .55059 .3535 .54582 .34726 .54403 Mtetra
.723 .915 .96 r
.34726 .54403 .3535 .54582 .36338 .54015 .35715 .53887 Mtetra
.764 .936 .94 r
.35715 .53887 .36338 .54015 .37328 .53429 .36711 .53262 Mtetra
.804 .92 .915 r
.36711 .53262 .37328 .53429 .38319 .52869 .37713 .52533 Mtetra
.784 .857 .905 r
.37713 .52533 .38319 .52869 .39306 .52486 .38714 .5186 Mtetra
.718 .749 .877 r
.38714 .5186 .39306 .52486 .40285 .52393 .39711 .51359 Mtetra
.604 .607 .827 r
.39711 .51359 .40285 .52393 .41259 .52569 .40698 .51187 Mtetra
.471 .477 .783 r
.40698 .51187 .41259 .52569 .42233 .52995 .41675 .5145 Mtetra
.425 .429 .76 r
.41675 .5145 .42233 .52995 .43218 .53304 .42654 .51885 Mtetra
.409 .437 .778 r
.42654 .51885 .43218 .53304 .44219 .53264 .43642 .52322 Mtetra
.488 .573 .868 r
.43642 .52322 .44219 .53264 .45234 .5279 .44646 .52433 Mtetra
.681 .848 .963 r
.44646 .52433 .45234 .5279 .46262 .51845 .45666 .52029 Mtetra
.681 .978 .829 r
.45666 .52029 .46262 .51845 .47291 .50755 .46696 .51269 Mtetra
.57 .874 .578 r
.46696 .51269 .47291 .50755 .48319 .49709 .4773 .50253 Mtetra
.531 .845 .54 r
.4773 .50253 .48319 .49709 .49345 .48854 .48765 .49237 Mtetra
.576 .904 .659 r
.48765 .49237 .49345 .48854 .50369 .48272 .49797 .48362 Mtetra
.701 .983 .875 r
.49797 .48362 .50369 .48272 .51395 .47869 .5083 .4765 Mtetra
.72 .916 .961 r
.5083 .4765 .51395 .47869 .52424 .47593 .51863 .47114 Mtetra
.696 .808 .934 r
.51863 .47114 .52424 .47593 .53458 .47346 .52899 .4668 Mtetra
.67 .734 .898 r
.52899 .4668 .53458 .47346 .54496 .47073 .53939 .46314 Mtetra
.656 .702 .88 r
.53939 .46314 .54496 .47073 .55537 .46743 .54983 .45982 Mtetra
.644 .697 .884 r
.54983 .45982 .55537 .46743 .56582 .46357 .56031 .45684 Mtetra
.616 .715 .916 r
.56031 .45684 .56582 .46357 .5763 .45944 .57084 .45454 Mtetra
.537 .754 .976 r
.57084 .45454 .5763 .45944 .58682 .4556 .58144 .45327 Mtetra
.207 .687 .933 r
.58144 .45327 .58682 .4556 .59741 .45304 .59212 .45379 Mtetra
.31 0 0 r
.59212 .45379 .59741 .45304 .60809 .45229 .60292 .45597 Mtetra
.521 0 0 r
.60292 .45597 .60809 .45229 .6189 .45431 .61383 .45958 Mtetra
.543 .054 .047 r
.61383 .45958 .6189 .45431 .62986 .45829 .62483 .46323 Mtetra
.421 0 0 r
.62483 .46323 .62986 .45829 .64092 .46273 .63583 .46429 Mtetra
0 0 0 r
.63583 .46429 .64092 .46273 .65202 .46573 .64677 .46176 Mtetra
.8 .872 .9 r
.64677 .46176 .65202 .46573 .663 .46395 .65755 .45398 Mtetra
.792 .705 .769 r
.65755 .45398 .663 .46395 .67384 .45775 .66819 .44285 Mtetra
.745 .623 .724 r
.66819 .44285 .67384 .45775 .68453 .44796 .67883 .43171 Mtetra
.714 .595 .722 r
.67883 .43171 .68453 .44796 .69515 .43694 .68954 .42231 Mtetra
.659 .582 .757 r
.68954 .42231 .69515 .43694 .70591 .42848 .7005 .41735 Mtetra
.594 .6 .827 r
.7005 .41735 .70591 .42848 .71684 .42275 .71168 .41576 Mtetra
.493 .659 .934 r
.71168 .41576 .71684 .42275 .72798 .42 .72303 .41595 Mtetra
.33 .693 .981 r
.72303 .41595 .72798 .42 .73929 .41908 .73449 .41673 Mtetra
.293 .743 .959 r
.73449 .41673 .73929 .41908 .75069 .41844 .74596 .41645 Mtetra
.369 .801 .966 r
.74596 .41645 .75069 .41844 .76214 .41761 .75741 .41505 Mtetra
.522 .86 .994 r
.75741 .41505 .76214 .41761 .77358 .41584 .76882 .41235 Mtetra
.622 .863 .988 r
.76882 .41235 .77358 .41584 .78501 .41331 .78022 .40871 Mtetra
.667 .834 .963 r
.78022 .40871 .78501 .41331 .79644 .41006 .79161 .40456 Mtetra
.684 .804 .939 r
.79161 .40456 .79644 .41006 .80788 .40632 .80303 .40012 Mtetra
.683 .779 .923 r
.80303 .40012 .80788 .40632 .81934 .40236 .81449 .39572 Mtetra
.68 .763 .914 r
.81449 .39572 .81934 .40236 .83084 .39825 .82599 .39137 Mtetra
.674 .753 .91 r
.82599 .39137 .83084 .39825 .84237 .39417 .83756 .3872 Mtetra
.67 .749 .91 r
.83756 .3872 .84237 .39417 .85396 .3901 .84918 .38313 Mtetra
.666 .749 .912 r
.84918 .38313 .85396 .3901 .86559 .38605 .86086 .37916 Mtetra
.663 .751 .915 r
.86086 .37916 .86559 .38605 .87727 .38207 .87259 .37524 Mtetra
.657 .752 .92 r
.24535 .5654 .25164 .57089 .26105 .56812 .2548 .56238 Mtetra
.656 .743 .914 r
.2548 .56238 .26105 .56812 .27049 .56542 .26428 .55938 Mtetra
.651 .732 .909 r
.26428 .55938 .27049 .56542 .27995 .5628 .27378 .5565 Mtetra
.643 .722 .905 r
.27378 .5565 .27995 .5628 .28945 .5603 .2833 .5538 Mtetra
.632 .713 .905 r
.2833 .5538 .28945 .5603 .29897 .55796 .29285 .55136 Mtetra
.62 .706 .907 r
.29285 .55136 .29897 .55796 .30852 .55568 .30241 .5492 Mtetra
.602 .705 .916 r
.30241 .5492 .30852 .55568 .31811 .55345 .31199 .54741 Mtetra
.591 .718 .931 r
.31199 .54741 .31811 .55345 .32776 .55094 .3216 .54576 Mtetra
.578 .746 .957 r
.3216 .54576 .32776 .55094 .33747 .54793 .33125 .54414 Mtetra
.586 .807 .984 r
.33125 .54414 .33747 .54793 .34726 .54403 .34098 .54195 Mtetra
.607 .883 .991 r
.34098 .54195 .34726 .54403 .35715 .53887 .3508 .53873 Mtetra
.639 .95 .946 r
.3508 .53873 .35715 .53887 .36711 .53262 .36073 .53389 Mtetra
.715 .986 .881 r
.36073 .53389 .36711 .53262 .37713 .52533 .37079 .52686 Mtetra
.783 .997 .861 r
.37079 .52686 .37713 .52533 .38714 .5186 .38093 .51835 Mtetra
.856 .957 .874 r
.38093 .51835 .38714 .5186 .39711 .51359 .39112 .50884 Mtetra
.792 .809 .866 r
.39112 .50884 .39711 .51359 .40698 .51187 .40123 .50129 Mtetra
.655 .626 .809 r
.40123 .50129 .40698 .51187 .41675 .5145 .41121 .49769 Mtetra
.534 .48 .743 r
.41121 .49769 .41675 .5145 .42654 .51885 .42109 .49868 Mtetra
.422 .382 .709 r
.42109 .49868 .42654 .51885 .43642 .52322 .43089 .50453 Mtetra
.394 .377 .722 r
.43089 .50453 .43642 .52322 .44646 .52433 .44077 .51087 Mtetra
.407 .448 .791 r
.44077 .51087 .44646 .52433 .45666 .52029 .45079 .51501 Mtetra
.458 .702 .972 r
.45079 .51501 .45666 .52029 .46696 .51269 .46098 .51504 Mtetra
.387 .832 .715 r
.46098 .51504 .46696 .51269 .4773 .50253 .47131 .50994 Mtetra
0 0 0 r
.47131 .50994 .4773 .50253 .48765 .49237 .4817 .50209 Mtetra
.4817 .50209 .48765 .49237 .49797 .48362 .49211 .49282 Mtetra
.49211 .49282 .49797 .48362 .5083 .4765 .50253 .48388 Mtetra
.50253 .48388 .5083 .4765 .51863 .47114 .51294 .47627 Mtetra
.51294 .47627 .51863 .47114 .52899 .4668 .52336 .47005 Mtetra
.52336 .47005 .52899 .4668 .53939 .46314 .53382 .46536 Mtetra
.53382 .46536 .53939 .46314 .54983 .45982 .5443 .46203 Mtetra
.003 0 0 r
.5443 .46203 .54983 .45982 .56031 .45684 .55485 .46004 Mtetra
.247 0 0 r
.55485 .46004 .56031 .45684 .57084 .45454 .56546 .4596 Mtetra
.422 0 0 r
.56546 .4596 .57084 .45454 .58144 .45327 .57615 .46057 Mtetra
.515 .063 .116 r
.57615 .46057 .58144 .45327 .59212 .45379 .58694 .4629 Mtetra
.536 .113 .184 r
.58694 .4629 .59212 .45379 .60292 .45597 .59781 .46558 Mtetra
.497 .079 .177 r
.59781 .46558 .60292 .45597 .61383 .45958 .60873 .46685 Mtetra
.349 0 .017 r
.60873 .46685 .61383 .45958 .62483 .46323 .61965 .46534 Mtetra
.499 .892 .732 r
.61965 .46534 .62483 .46323 .63583 .46429 .63045 .45863 Mtetra
.841 .813 .823 r
.63045 .45863 .63583 .46429 .64677 .46176 .64112 .44772 Mtetra
.773 .645 .72 r
.64112 .44772 .64677 .46176 .65755 .45398 .6517 .43455 Mtetra
.729 .581 .689 r
.6517 .43455 .65755 .45398 .66819 .44285 .66227 .42184 Mtetra
.669 .537 .695 r
.66227 .42184 .66819 .44285 .67883 .43171 .67305 .41408 Mtetra
.615 .529 .733 r
.67305 .41408 .67883 .43171 .68954 .42231 .68408 .41098 Mtetra
.513 .553 .834 r
.68408 .41098 .68954 .42231 .7005 .41735 .69536 .41195 Mtetra
.226 .571 .94 r
.69536 .41195 .7005 .41735 .71168 .41576 .70684 .41495 Mtetra
.122 0 0 r
.70684 .41495 .71168 .41576 .72303 .41595 .71834 .41693 Mtetra
.151 0 0 r
.71834 .41693 .72303 .41595 .73449 .41673 .72984 .41741 Mtetra
.114 .663 .705 r
.72984 .41741 .73449 .41673 .74596 .41645 .74126 .41564 Mtetra
.452 .877 .925 r
.74126 .41564 .74596 .41645 .75741 .41505 .75262 .41219 Mtetra
.653 .901 .982 r
.75262 .41219 .75741 .41505 .76882 .41235 .76394 .40766 Mtetra
.708 .844 .947 r
.76394 .40766 .76882 .41235 .78022 .40871 .77526 .40255 Mtetra
.707 .788 .914 r
.77526 .40255 .78022 .40871 .79161 .40456 .78662 .39746 Mtetra
.699 .754 .895 r
.78662 .39746 .79161 .40456 .80303 .40012 .79802 .39251 Mtetra
.685 .734 .888 r
.79802 .39251 .80303 .40012 .81449 .39572 .8095 .38792 Mtetra
.675 .726 .888 r
.8095 .38792 .81449 .39572 .82599 .39137 .82104 .38363 Mtetra
.667 .724 .892 r
.82104 .38363 .82599 .39137 .83756 .3872 .83266 .37961 Mtetra
.66 .728 .899 r
.83266 .37961 .83756 .3872 .84918 .38313 .84434 .37578 Mtetra
.656 .734 .907 r
.84434 .37578 .84918 .38313 .86086 .37916 .85607 .37206 Mtetra
.655 .742 .914 r
.85607 .37206 .86086 .37916 .87259 .37524 .86786 .36837 Mtetra
.669 .754 .915 r
.23902 .55988 .24535 .5654 .2548 .56238 .24851 .55656 Mtetra
.669 .745 .907 r
.24851 .55656 .2548 .56238 .26428 .55938 .25803 .55322 Mtetra
.666 .733 .9 r
.25803 .55322 .26428 .55938 .27378 .5565 .26758 .54994 Mtetra
.659 .719 .893 r
.26758 .54994 .27378 .5565 .2833 .5538 .27715 .54681 Mtetra
.649 .704 .887 r
.27715 .54681 .2833 .5538 .29285 .55136 .28674 .54392 Mtetra
.635 .687 .881 r
.28674 .54392 .29285 .55136 .30241 .5492 .29634 .54139 Mtetra
.615 .67 .879 r
.29634 .54139 .30241 .5492 .31199 .54741 .30594 .53939 Mtetra
.594 .657 .881 r
.30594 .53939 .31199 .54741 .3216 .54576 .31556 .53789 Mtetra
.567 .651 .892 r
.31556 .53789 .3216 .54576 .33125 .54414 .32518 .53698 Mtetra
.556 .668 .913 r
.32518 .53698 .33125 .54414 .34098 .54195 .33484 .53618 Mtetra
.548 .715 .95 r
.33484 .53618 .34098 .54195 .3508 .53873 .34457 .53517 Mtetra
.578 .817 .989 r
.34457 .53517 .3508 .53873 .36073 .53389 .3544 .53295 Mtetra
.63 .929 .971 r
.3544 .53295 .36073 .53389 .37079 .52686 .36437 .52871 Mtetra
.651 .969 .845 r
.36437 .52871 .37079 .52686 .38093 .51835 .37448 .52195 Mtetra
.729 .978 .75 r
.37448 .52195 .38093 .51835 .39112 .50884 .38474 .51221 Mtetra
.78 .992 .765 r
.38474 .51221 .39112 .50884 .40123 .50129 .39502 .50174 Mtetra
.849 .978 .867 r
.39502 .50174 .40123 .50129 .41121 .49769 .40527 .4921 Mtetra
.742 .78 .884 r
.40527 .4921 .41121 .49769 .42109 .49868 .41538 .48633 Mtetra
.551 .547 .803 r
.41538 .48633 .42109 .49868 .43089 .50453 .42535 .4863 Mtetra
.467 .428 .73 r
.42535 .4863 .43089 .50453 .44077 .51087 .43527 .48997 Mtetra
.421 .377 .704 r
.43527 .48997 .44077 .51087 .45079 .51501 .44521 .49605 Mtetra
.441 .406 .724 r
.44521 .49605 .45079 .51501 .46098 .51504 .45527 .50088 Mtetra
.509 .5 .782 r
.45527 .50088 .46098 .51504 .47131 .50994 .46549 .50237 Mtetra
.595 .68 .9 r
.46549 .50237 .47131 .50994 .4817 .50209 .47581 .50066 Mtetra
.664 .932 .97 r
.47581 .50066 .4817 .50209 .49211 .49282 .48623 .49588 Mtetra
.397 .823 .657 r
.48623 .49588 .49211 .49282 .50253 .48388 .49668 .48981 Mtetra
0 0 0 r
.49668 .48981 .50253 .48388 .51294 .47627 .50716 .4835 Mtetra
.056 0 0 r
.50716 .4835 .51294 .47627 .52336 .47005 .51766 .47779 Mtetra
.171 0 0 r
.51766 .47779 .52336 .47005 .53382 .46536 .52818 .47319 Mtetra
.257 0 0 r
.52818 .47319 .53382 .46536 .5443 .46203 .53874 .46985 Mtetra
.329 0 .027 r
.53874 .46985 .5443 .46203 .55485 .46004 .54935 .46775 Mtetra
.384 0 .053 r
.54935 .46775 .55485 .46004 .56546 .4596 .56002 .46678 Mtetra
.401 0 .041 r
.56002 .46678 .56546 .4596 .57615 .46057 .57076 .46642 Mtetra
.353 0 0 r
.57076 .46642 .57615 .46057 .58694 .4629 .58156 .46582 Mtetra
.088 0 0 r
.58156 .46582 .58694 .4629 .59781 .46558 .59238 .46394 Mtetra
.662 .934 .969 r
.59238 .46394 .59781 .46558 .60873 .46685 .60319 .45895 Mtetra
.771 .741 .825 r
.60319 .45895 .60873 .46685 .61965 .46534 .61394 .45072 Mtetra
.752 .629 .724 r
.61394 .45072 .61965 .46534 .63045 .45863 .6246 .43906 Mtetra
.73 .581 .688 r
.6246 .43906 .63045 .45863 .64112 .44772 .6352 .42612 Mtetra
.695 .55 .685 r
.6352 .42612 .64112 .44772 .6517 .43455 .64587 .4156 Mtetra
.665 .548 .711 r
.64587 .4156 .6517 .43455 .66227 .42184 .65669 .40882 Mtetra
.575 .558 .798 r
.65669 .40882 .66227 .42184 .67305 .41408 .66779 .4079 Mtetra
.264 .564 .935 r
.66779 .4079 .67305 .41408 .68408 .41098 .67914 .41095 Mtetra
.372 0 0 r
.67914 .41095 .68408 .41098 .69536 .41195 .69062 .41487 Mtetra
.464 0 0 r
.69062 .41487 .69536 .41195 .70684 .41495 .70216 .41807 Mtetra
.283 0 0 r
.70216 .41807 .70684 .41495 .71834 .41693 .71362 .41823 Mtetra
0 0 0 r
.71362 .41823 .71834 .41693 .72984 .41741 .72499 .4158 Mtetra
.601 .925 .968 r
.72499 .4158 .72984 .41741 .74126 .41564 .73627 .41127 Mtetra
.732 .861 .942 r
.73627 .41127 .74126 .41564 .75262 .41219 .74751 .40549 Mtetra
.732 .777 .889 r
.74751 .40549 .75262 .41219 .76394 .40766 .75877 .39949 Mtetra
.718 .73 .86 r
.75877 .39949 .76394 .40766 .77526 .40255 .77006 .39358 Mtetra
.698 .703 .851 r
.77006 .39358 .77526 .40255 .78662 .39746 .78142 .38828 Mtetra
.683 .692 .852 r
.78142 .38828 .78662 .39746 .79802 .39251 .79287 .38349 Mtetra
.669 .691 .861 r
.79287 .38349 .79802 .39251 .8095 .38792 .80441 .37924 Mtetra
.659 .695 .873 r
.80441 .37924 .8095 .38792 .82104 .38363 .81602 .37538 Mtetra
.652 .705 .885 r
.81602 .37538 .82104 .38363 .83266 .37961 .8277 .37175 Mtetra
.647 .715 .897 r
.8277 .37175 .83266 .37961 .84434 .37578 .83945 .36828 Mtetra
.645 .726 .908 r
.83945 .36828 .84434 .37578 .85607 .37206 .85125 .36487 Mtetra
.645 .737 .916 r
.85125 .36487 .85607 .37206 .86786 .36837 .8631 .36144 Mtetra
.677 .756 .911 r
.23264 .55431 .23902 .55988 .24851 .55656 .24217 .55076 Mtetra
.679 .75 .904 r
.24217 .55076 .24851 .55656 .25803 .55322 .25174 .54712 Mtetra
.679 .74 .897 r
.25174 .54712 .25803 .55322 .26758 .54994 .26134 .54344 Mtetra
.677 .728 .888 r
.26134 .54344 .26758 .54994 .27715 .54681 .27097 .53979 Mtetra
.673 .711 .877 r
.27097 .53979 .27715 .54681 .28674 .54392 .28062 .5362 Mtetra
.661 .689 .865 r
.28062 .5362 .28674 .54392 .29634 .54139 .29029 .53287 Mtetra
.644 .663 .853 r
.29029 .53287 .29634 .54139 .30594 .53939 .29996 .52998 Mtetra
.62 .633 .842 r
.29996 .52998 .30594 .53939 .31556 .53789 .30963 .52777 Mtetra
.588 .604 .836 r
.30963 .52777 .31556 .53789 .32518 .53698 .31927 .52651 Mtetra
.556 .582 .836 r
.31927 .52651 .32518 .53698 .33484 .53618 .32891 .52613 Mtetra
.514 .571 .851 r
.32891 .52613 .33484 .53618 .34457 .53517 .33855 .52672 Mtetra
.489 .601 .892 r
.33855 .52672 .34457 .53517 .3544 .53295 .34824 .52741 Mtetra
.452 .687 .966 r
.34824 .52741 .3544 .53295 .36437 .52871 .35802 .52761 Mtetra
.391 .828 .951 r
.35802 .52761 .36437 .52871 .37448 .52195 .36795 .52578 Mtetra
0 0 0 r
.36795 .52578 .37448 .52195 .38474 .51221 .37806 .52068 Mtetra
.37806 .52068 .38474 .51221 .39502 .50174 .38835 .51182 Mtetra
.38835 .51182 .39502 .50174 .40527 .4921 .3988 .49897 Mtetra
.673 .898 .55 r
.3988 .49897 .40527 .4921 .41538 .48633 .40925 .48576 Mtetra
.886 .94 .845 r
.40925 .48576 .41538 .48633 .42535 .4863 .4196 .47459 Mtetra
.701 .631 .776 r
.4196 .47459 .42535 .4863 .43527 .48997 .4298 .4684 Mtetra
.549 .455 .701 r
.4298 .4684 .43527 .48997 .44521 .49605 .43985 .46879 Mtetra
.49 .389 .667 r
.43985 .46879 .44521 .49605 .45527 .50088 .44987 .473 Mtetra
.454 .363 .662 r
.44987 .473 .45527 .50088 .46549 .50237 .45993 .47934 Mtetra
.45 .384 .692 r
.45993 .47934 .46549 .50237 .47581 .50066 .47011 .48479 Mtetra
.475 .46 .761 r
.47011 .48479 .47581 .50066 .48623 .49588 .48042 .48766 Mtetra
.495 .618 .902 r
.48042 .48766 .48623 .49588 .49668 .48981 .49083 .48815 Mtetra
.409 .827 .969 r
.49083 .48815 .49668 .48981 .50716 .4835 .50132 .48637 Mtetra
0 0 0 r
.50132 .48637 .50716 .4835 .51766 .47779 .51187 .48352 Mtetra
.15 0 0 r
.51187 .48352 .51766 .47779 .52818 .47319 .52245 .48018 Mtetra
.217 0 0 r
.52245 .48018 .52818 .47319 .53874 .46985 .53308 .47682 Mtetra
.216 0 0 r
.53308 .47682 .53874 .46985 .54935 .46775 .54376 .47344 Mtetra
.11 0 0 r
.54376 .47344 .54935 .46775 .56002 .46678 .55446 .46957 Mtetra
0 0 0 r
.55446 .46957 .56002 .46678 .57076 .46642 .5652 .46462 Mtetra
.779 .946 .931 r
.5652 .46462 .57076 .46642 .58156 .46582 .57593 .45737 Mtetra
.788 .732 .8 r
.57593 .45737 .58156 .46582 .59238 .46394 .58663 .44771 Mtetra
.746 .612 .709 r
.58663 .44771 .59238 .46394 .60319 .45895 .59727 .43541 Mtetra
.711 .55 .669 r
.59727 .43541 .60319 .45895 .61394 .45072 .60787 .42218 Mtetra
.672 .508 .655 r
.60787 .42218 .61394 .45072 .6246 .43906 .61852 .41109 Mtetra
.639 .488 .662 r
.61852 .41109 .6246 .43906 .6352 .42612 .62927 .40384 Mtetra
.565 .466 .701 r
.62927 .40384 .6352 .42612 .64587 .4156 .64029 .40328 Mtetra
.381 .459 .816 r
.64029 .40328 .64587 .4156 .65669 .40882 .65156 .40781 Mtetra
.502 0 0 r
.65156 .40781 .65669 .40882 .66779 .4079 .66303 .41446 Mtetra
.617 .153 .129 r
.66303 .41446 .66779 .4079 .67914 .41095 .6746 .42078 Mtetra
.519 .097 .179 r
.6746 .42078 .67914 .41095 .69062 .41487 .68607 .42303 Mtetra
.364 0 .054 r
.68607 .42303 .69062 .41487 .70216 .41807 .69743 .42144 Mtetra
0 0 0 r
.69743 .42144 .70216 .41807 .71362 .41823 .70866 .41649 Mtetra
.75 .961 .937 r
.70866 .41649 .71362 .41823 .72499 .4158 .7198 .40943 Mtetra
.774 .799 .873 r
.7198 .40943 .72499 .4158 .73627 .41127 .73093 .40184 Mtetra
.742 .709 .82 r
.73093 .40184 .73627 .41127 .74751 .40549 .74208 .39436 Mtetra
.708 .662 .802 r
.74208 .39436 .74751 .40549 .75877 .39949 .75331 .38786 Mtetra
.686 .644 .802 r
.75331 .38786 .75877 .39949 .77006 .39358 .76465 .38226 Mtetra
.667 .64 .814 r
.76465 .38226 .77006 .39358 .78142 .38828 .77609 .37764 Mtetra
.653 .647 .832 r
.77609 .37764 .78142 .38828 .79287 .38349 .78763 .37372 Mtetra
.644 .662 .853 r
.78763 .37372 .79287 .38349 .80441 .37924 .79926 .37026 Mtetra
.637 .679 .873 r
.79926 .37026 .80441 .37924 .81602 .37538 .81096 .36707 Mtetra
.635 .697 .89 r
.81096 .36707 .81602 .37538 .8277 .37175 .82272 .36394 Mtetra
.634 .712 .903 r
.82272 .36394 .8277 .37175 .83945 .36828 .83453 .36084 Mtetra
.634 .725 .913 r
.83453 .36084 .83945 .36828 .85125 .36487 .8464 .3577 Mtetra
.636 .736 .92 r
.8464 .3577 .85125 .36487 .8631 .36144 .85831 .35446 Mtetra
.675 .756 .912 r
.22623 .54871 .23264 .55431 .24217 .55076 .23577 .54519 Mtetra
.68 .758 .911 r
.23577 .54519 .24217 .55076 .25174 .54712 .24536 .54153 Mtetra
.684 .76 .909 r
.24536 .54153 .25174 .54712 .26134 .54344 .25499 .53774 Mtetra
.688 .757 .904 r
.25499 .53774 .26134 .54344 .27097 .53979 .26466 .53381 Mtetra
.693 .75 .895 r
.26466 .53381 .27097 .53979 .28062 .5362 .27437 .52971 Mtetra
.691 .734 .884 r
.27437 .52971 .28062 .5362 .29029 .53287 .28411 .52561 Mtetra
.684 .71 .868 r
.28411 .52561 .29029 .53287 .29996 .52998 .29388 .5216 Mtetra
.664 .675 .851 r
.29388 .5216 .29996 .52998 .30963 .52777 .30364 .51806 Mtetra
.636 .635 .832 r
.30364 .51806 .30963 .52777 .31927 .52651 .31339 .51529 Mtetra
.599 .59 .813 r
.31339 .51529 .31927 .52651 .32891 .52613 .32311 .51365 Mtetra
.552 .545 .8 r
.32311 .51365 .32891 .52613 .33855 .52672 .33278 .5135 Mtetra
.513 .513 .793 r
.33278 .5135 .33855 .52672 .34824 .52741 .34244 .51459 Mtetra
.467 .494 .803 r
.34244 .51459 .34824 .52741 .35802 .52761 .35211 .51683 Mtetra
.456 .528 .843 r
.35211 .51683 .35802 .52761 .36795 .52578 .36185 .51877 Mtetra
.469 .642 .932 r
.36185 .51877 .36795 .52578 .37806 .52068 .37173 .51928 Mtetra
.531 .886 .981 r
.37173 .51928 .37806 .52068 .38835 .51182 .38182 .51634 Mtetra
.476 .848 .614 r
.38182 .51634 .38835 .51182 .3988 .49897 .39214 .50851 Mtetra
0 0 0 r
.39214 .50851 .3988 .49897 .40925 .48576 .40261 .49712 Mtetra
.40261 .49712 .40925 .48576 .4196 .47459 .41314 .48318 Mtetra
.41314 .48318 .4196 .47459 .4298 .4684 .42361 .47085 Mtetra
.691 .977 .798 r
.42361 .47085 .4298 .4684 .43985 .46879 .43394 .46256 Mtetra
.681 .751 .905 r
.43394 .46256 .43985 .46879 .44987 .473 .44417 .45862 Mtetra
.536 .513 .776 r
.44417 .45862 .44987 .473 .45993 .47934 .45434 .45914 Mtetra
.506 .438 .715 r
.45434 .45914 .45993 .47934 .47011 .48479 .46454 .46151 Mtetra
.507 .42 .692 r
.46454 .46151 .47011 .48479 .48042 .48766 .47481 .46423 Mtetra
.523 .43 .692 r
.47481 .46423 .48042 .48766 .49083 .48815 .48517 .4661 Mtetra
.551 .456 .701 r
.48517 .4661 .49083 .48815 .50132 .48637 .49561 .46636 Mtetra
.575 .485 .715 r
.49561 .46636 .50132 .48637 .51187 .48352 .50613 .46529 Mtetra
.601 .514 .728 r
.50613 .46529 .51187 .48352 .52245 .48018 .5167 .46292 Mtetra
.621 .534 .735 r
.5167 .46292 .52245 .48018 .53308 .47682 .52732 .45952 Mtetra
.638 .544 .731 r
.52732 .45952 .53308 .47682 .54376 .47344 .53798 .4551 Mtetra
.654 .545 .719 r
.53798 .4551 .54376 .47344 .55446 .46957 .54867 .44937 Mtetra
.664 .539 .702 r
.54867 .44937 .55446 .46957 .5652 .46462 .55936 .4423 Mtetra
.673 .533 .685 r
.55936 .4423 .5652 .46462 .57593 .45737 .57005 .43359 Mtetra
.676 .528 .676 r
.57005 .43359 .57593 .45737 .58663 .44771 .58074 .424 Mtetra
.673 .526 .677 r
.58074 .424 .58663 .44771 .59727 .43541 .59143 .41474 Mtetra
.665 .537 .698 r
.59143 .41474 .59727 .43541 .60787 .42218 .60217 .40734 Mtetra
.618 .558 .764 r
.60217 .40734 .60787 .42218 .61852 .41109 .61304 .40444 Mtetra
.392 .622 .944 r
.61304 .40444 .61852 .41109 .62927 .40384 .62411 .40597 Mtetra
.568 .017 0 r
.62411 .40597 .62927 .40384 .64029 .40328 .63539 .41164 Mtetra
.638 .204 .2 r
.63539 .41164 .64029 .40328 .65156 .40781 .64684 .41898 Mtetra
.582 .176 .237 r
.64684 .41898 .65156 .40781 .66303 .41446 .6583 .42375 Mtetra
.481 .051 .144 r
.6583 .42375 .66303 .41446 .6746 .42078 .66971 .4249 Mtetra
.021 0 0 r
.66971 .4249 .6746 .42078 .68607 .42303 .68096 .42105 Mtetra
.771 .955 .932 r
.68096 .42105 .68607 .42303 .69743 .42144 .69206 .41365 Mtetra
.785 .76 .83 r
.69206 .41365 .69743 .42144 .70866 .41649 .7031 .40476 Mtetra
.749 .669 .773 r
.7031 .40476 .70866 .41649 .7198 .40943 .71413 .39554 Mtetra
.713 .624 .756 r
.71413 .39554 .7198 .40943 .73093 .40184 .72524 .38749 Mtetra
.69 .607 .758 r
.72524 .38749 .73093 .40184 .74208 .39436 .73645 .3807 Mtetra
.667 .604 .775 r
.73645 .3807 .74208 .39436 .75331 .38786 .74779 .37545 Mtetra
.65 .614 .8 r
.74779 .37545 .75331 .38786 .76465 .38226 .75925 .37136 Mtetra
.636 .634 .832 r
.75925 .37136 .76465 .38226 .77609 .37764 .77082 .36806 Mtetra
.625 .658 .863 r
.77082 .36806 .77609 .37764 .78763 .37372 .78247 .36526 Mtetra
.621 .686 .89 r
.78247 .36526 .78763 .37372 .79926 .37026 .79419 .36255 Mtetra
.619 .709 .909 r
.79419 .36255 .79926 .37026 .81096 .36707 .80597 .35985 Mtetra
.624 .727 .921 r
.80597 .35985 .81096 .36707 .82272 .36394 .81778 .35696 Mtetra
.628 .738 .927 r
.81778 .35696 .82272 .36394 .83453 .36084 .82964 .35392 Mtetra
.632 .743 .928 r
.82964 .35392 .83453 .36084 .8464 .3577 .84154 .35075 Mtetra
.637 .745 .926 r
.84154 .35075 .8464 .3577 .85831 .35446 .85348 .34743 Mtetra
.662 .753 .917 r
.21976 .54307 .22623 .54871 .23577 .54519 .2293 .53984 Mtetra
.667 .765 .924 r
.2293 .53984 .23577 .54519 .24536 .54153 .23889 .53649 Mtetra
.674 .779 .929 r
.23889 .53649 .24536 .54153 .25499 .53774 .24852 .53294 Mtetra
.685 .79 .93 r
.24852 .53294 .25499 .53774 .26466 .53381 .2582 .52912 Mtetra
.7 .797 .926 r
.2582 .52912 .26466 .53381 .27437 .52971 .26795 .52491 Mtetra
.712 .796 .917 r
.26795 .52491 .27437 .52971 .28411 .52561 .27775 .52035 Mtetra
.722 .782 .9 r
.27775 .52035 .28411 .52561 .29388 .5216 .2876 .5154 Mtetra
.719 .752 .878 r
.2876 .5154 .29388 .5216 .30364 .51806 .29749 .51037 Mtetra
.705 .707 .85 r
.29749 .51037 .30364 .51806 .31339 .51529 .30739 .50546 Mtetra
.673 .649 .818 r
.30739 .50546 .31339 .51529 .32311 .51365 .31727 .50126 Mtetra
.631 .588 .787 r
.31727 .50126 .32311 .51365 .33278 .5135 .32711 .49827 Mtetra
.584 .527 .757 r
.32711 .49827 .33278 .5135 .34244 .51459 .3369 .49699 Mtetra
.531 .472 .735 r
.3369 .49699 .34244 .51459 .35211 .51683 .34661 .49793 Mtetra
.486 .434 .724 r
.34661 .49793 .35211 .51683 .36185 .51877 .35628 .50076 Mtetra
.43 .407 .732 r
.35628 .50076 .36185 .51877 .37173 .51928 .36595 .5053 Mtetra
.38 .426 .784 r
.36595 .5053 .37173 .51928 .38182 .51634 .3757 .50988 Mtetra
.21 .527 .92 r
.3757 .50988 .38182 .51634 .39214 .50851 .38559 .51312 Mtetra
.275 0 0 r
.38559 .51312 .39214 .50851 .40261 .49712 .39571 .51226 Mtetra
.266 0 .169 r
.39571 .51226 .40261 .49712 .41314 .48318 .4061 .50549 Mtetra
.23 0 .241 r
.4061 .50549 .41314 .48318 .42361 .47085 .41667 .49376 Mtetra
.111 0 .196 r
.41667 .49376 .42361 .47085 .43394 .46256 .42735 .47798 Mtetra
0 0 0 r
.42735 .47798 .43394 .46256 .44417 .45862 .43798 .46246 Mtetra
.827 .988 .722 r
.43798 .46246 .44417 .45862 .45434 .45914 .44851 .44966 Mtetra
.766 .697 .785 r
.44851 .44966 .45434 .45914 .46454 .46151 .45894 .4406 Mtetra
.633 .513 .699 r
.45894 .4406 .46454 .46151 .47481 .46423 .46931 .43573 Mtetra
.586 .45 .662 r
.46931 .43573 .47481 .46423 .48517 .4661 .47967 .43321 Mtetra
.567 .424 .647 r
.47967 .43321 .48517 .4661 .49561 .46636 .49007 .43196 Mtetra
.567 .421 .642 r
.49007 .43196 .49561 .46636 .50613 .46529 .50052 .43062 Mtetra
.576 .427 .641 r
.50052 .43062 .50613 .46529 .5167 .46292 .51102 .4284 Mtetra
.589 .436 .642 r
.51102 .4284 .5167 .46292 .52732 .45952 .52158 .42495 Mtetra
.6 .444 .641 r
.52158 .42495 .52732 .45952 .53798 .4551 .53217 .42029 Mtetra
.608 .448 .64 r
.53217 .42029 .53798 .4551 .54867 .44937 .5428 .41473 Mtetra
.609 .45 .641 r
.5428 .41473 .54867 .44937 .55936 .4423 .55345 .40908 Mtetra
.599 .446 .646 r
.55345 .40908 .55936 .4423 .57005 .43359 .56414 .40469 Mtetra
.579 .445 .663 r
.56414 .40469 .57005 .43359 .58074 .424 .5749 .40268 Mtetra
.512 .438 .709 r
.5749 .40268 .58074 .424 .59143 .41474 .5858 .40491 Mtetra
.212 .414 .843 r
.5858 .40491 .59143 .41474 .60217 .40734 .59686 .41094 Mtetra
.681 .186 .063 r
.59686 .41094 .60217 .40734 .61304 .40444 .6081 .41978 Mtetra
.644 .274 .328 r
.6081 .41978 .61304 .40444 .62411 .40597 .61948 .42891 Mtetra
.577 .247 .372 r
.61948 .42891 .62411 .40597 .63539 .41164 .63086 .43397 Mtetra
.507 .181 .349 r
.63086 .43397 .63539 .41164 .64684 .41898 .64216 .434 Mtetra
.323 0 .205 r
.64216 .434 .64684 .41898 .6583 .42375 .65329 .42799 Mtetra
.523 .849 .559 r
.65329 .42799 .6583 .42375 .66971 .4249 .66427 .41777 Mtetra
.835 .785 .804 r
.66427 .41777 .66971 .4249 .68096 .42105 .67518 .40615 Mtetra
.751 .631 .727 r
.67518 .40615 .68096 .42105 .69206 .41365 .68609 .39454 Mtetra
.702 .571 .704 r
.68609 .39454 .69206 .41365 .7031 .40476 .69707 .38467 Mtetra
.674 .548 .704 r
.69707 .38467 .7031 .40476 .71413 .39554 .70817 .37672 Mtetra
.649 .543 .72 r
.70817 .37672 .71413 .39554 .72524 .38749 .71942 .37105 Mtetra
.63 .552 .749 r
.71942 .37105 .72524 .38749 .73645 .3807 .73082 .36713 Mtetra
.613 .578 .79 r
.73082 .36713 .73645 .3807 .74779 .37545 .74234 .36447 Mtetra
.597 .614 .839 r
.74234 .36447 .74779 .37545 .75925 .37136 .75398 .36255 Mtetra
.59 .662 .888 r
.75398 .36255 .75925 .37136 .77082 .36806 .76569 .36075 Mtetra
.584 .705 .926 r
.76569 .36075 .77082 .36806 .78247 .36526 .77745 .35887 Mtetra
.592 .743 .948 r
.77745 .35887 .78247 .36526 .79419 .36255 .78924 .35659 Mtetra
.603 .765 .957 r
.78924 .35659 .79419 .36255 .80597 .35985 .80106 .35395 Mtetra
.62 .775 .955 r
.80106 .35395 .80597 .35985 .81778 .35696 .8129 .35091 Mtetra
.633 .776 .949 r
.8129 .35091 .81778 .35696 .82964 .35392 .82477 .34757 Mtetra
.643 .77 .94 r
.82477 .34757 .82964 .35392 .84154 .35075 .83667 .34402 Mtetra
.649 .76 .93 r
.83667 .34402 .84154 .35075 .85348 .34743 .84861 .34035 Mtetra
.642 .748 .926 r
.21326 .53739 .21976 .54307 .2293 .53984 .22278 .53462 Mtetra
.642 .765 .938 r
.22278 .53462 .2293 .53984 .23889 .53649 .23233 .5318 Mtetra
.646 .787 .949 r
.23233 .5318 .23889 .53649 .24852 .53294 .24194 .52881 Mtetra
.655 .812 .959 r
.24194 .52881 .24852 .53294 .2582 .52912 .2516 .52554 Mtetra
.67 .838 .964 r
.2516 .52554 .2582 .52912 .26795 .52491 .26134 .52187 Mtetra
.69 .863 .964 r
.26134 .52187 .26795 .52491 .27775 .52035 .27114 .51767 Mtetra
.718 .881 .957 r
.27114 .51767 .27775 .52035 .2876 .5154 .28102 .51281 Mtetra
.741 .886 .946 r
.28102 .51281 .2876 .5154 .29749 .51037 .29097 .50738 Mtetra
.763 .872 .927 r
.29097 .50738 .29749 .51037 .30739 .50546 .30098 .50135 Mtetra
.762 .83 .905 r
.30098 .50135 .30739 .50546 .31727 .50126 .31101 .49523 Mtetra
.741 .764 .872 r
.31101 .49523 .31727 .50126 .32711 .49827 .32105 .48936 Mtetra
.692 .677 .831 r
.32105 .48936 .32711 .49827 .3369 .49699 .33104 .48458 Mtetra
.631 .588 .788 r
.33104 .48458 .3369 .49699 .34661 .49793 .34097 .48158 Mtetra
.567 .506 .747 r
.34097 .48158 .34661 .49793 .35628 .50076 .35081 .48094 Mtetra
.502 .437 .716 r
.35081 .48094 .35628 .50076 .36595 .5053 .36055 .48324 Mtetra
.455 .391 .697 r
.36055 .48324 .36595 .5053 .3757 .50988 .37026 .48784 Mtetra
.408 .361 .694 r
.37026 .48784 .3757 .50988 .38559 .51312 .37997 .49425 Mtetra
.416 .392 .724 r
.37997 .49425 .38559 .51312 .39571 .51226 .38983 .49948 Mtetra
.475 .505 .809 r
.38983 .49948 .39571 .51226 .4061 .50549 .3999 .50143 Mtetra
.615 .819 .979 r
.3999 .50143 .4061 .50549 .41667 .49376 .41021 .49857 Mtetra
.484 .845 .593 r
.41021 .49857 .41667 .49376 .42735 .47798 .42073 .49011 Mtetra
0 0 0 r
.42073 .49011 .42735 .47798 .43798 .46246 .43135 .47883 Mtetra
.055 0 .09 r
.43135 .47883 .43798 .46246 .44851 .44966 .44198 .46646 Mtetra
.126 0 .132 r
.44198 .46646 .44851 .44966 .45894 .4406 .45257 .45525 Mtetra
.172 0 .119 r
.45257 .45525 .45894 .4406 .46931 .43573 .46311 .44643 Mtetra
.142 0 .012 r
.46311 .44643 .46931 .43573 .47967 .43321 .47361 .43966 Mtetra
.047 0 0 r
.47361 .43966 .47967 .43321 .49007 .43196 .48412 .43473 Mtetra
0 0 0 r
.48412 .43473 .49007 .43196 .50052 .43062 .49464 .43072 Mtetra
.437 .874 .889 r
.49464 .43072 .50052 .43062 .51102 .4284 .5052 .42716 Mtetra
.536 .899 .969 r
.5052 .42716 .51102 .4284 .52158 .42495 .5158 .4237 Mtetra
.525 .895 .968 r
.5158 .4237 .52158 .42495 .53217 .42029 .52644 .42033 Mtetra
.359 .831 .868 r
.52644 .42033 .53217 .42029 .5428 .41473 .53713 .41742 Mtetra
.043 0 0 r
.53713 .41742 .5428 .41473 .55345 .40908 .54786 .41543 Mtetra
.383 0 0 r
.54786 .41543 .55345 .40908 .56414 .40469 .55867 .4153 Mtetra
.514 .102 .197 r
.55867 .4153 .56414 .40469 .5749 .40268 .56957 .41725 Mtetra
.574 .2 .294 r
.56957 .41725 .5749 .40268 .5858 .40491 .58059 .42165 Mtetra
.591 .23 .325 r
.58059 .42165 .5858 .40491 .59686 .41094 .59174 .42725 Mtetra
.574 .21 .313 r
.59174 .42725 .59686 .41094 .6081 .41978 .60296 .43176 Mtetra
.51 .111 .22 r
.60296 .43176 .6081 .41978 .61948 .42891 .61421 .43344 Mtetra
.022 0 0 r
.61421 .43344 .61948 .42891 .63086 .43397 .62536 .42943 Mtetra
.819 .861 .879 r
.62536 .42943 .63086 .43397 .64216 .434 .63639 .42051 Mtetra
.771 .655 .734 r
.63639 .42051 .64216 .434 .65329 .42799 .64729 .40821 Mtetra
.735 .585 .688 r
.64729 .40821 .65329 .42799 .66427 .41777 .65813 .39468 Mtetra
.699 .547 .677 r
.65813 .39468 .66427 .41777 .67518 .40615 .66903 .38296 Mtetra
.675 .532 .682 r
.66903 .38296 .67518 .40615 .68609 .39454 .68003 .37358 Mtetra
.65 .529 .702 r
.68003 .37358 .68609 .39454 .69707 .38467 .69119 .3672 Mtetra
.627 .541 .738 r
.69119 .3672 .69707 .38467 .70817 .37672 .70251 .36325 Mtetra
.6 .572 .794 r
.70251 .36325 .70817 .37672 .71942 .37105 .71398 .36113 Mtetra
.565 .621 .866 r
.71398 .36113 .71942 .37105 .73082 .36713 .72558 .36014 Mtetra
.527 .688 .941 r
.72558 .36014 .73082 .36713 .74234 .36447 .73727 .35941 Mtetra
.484 .744 .986 r
.73727 .35941 .74234 .36447 .75398 .36255 .74902 .3586 Mtetra
.48 .79 .999 r
.74902 .3586 .75398 .36255 .76569 .36075 .7608 .35718 Mtetra
.503 .819 1 r
.7608 .35718 .76569 .36075 .77745 .35887 .7726 .35517 Mtetra
.555 .838 .998 r
.7726 .35517 .77745 .35887 .78924 .35659 .7844 .35246 Mtetra
.599 .84 .99 r
.7844 .35246 .78924 .35659 .80106 .35395 .79621 .34922 Mtetra
.633 .829 .976 r
.79621 .34922 .80106 .35395 .8129 .35091 .80804 .34554 Mtetra
.653 .813 .96 r
.80804 .34554 .8129 .35091 .82477 .34757 .81989 .34157 Mtetra
.664 .793 .944 r
.81989 .34157 .82477 .34757 .83667 .34402 .83178 .33742 Mtetra
.667 .773 .929 r
.83178 .33742 .83667 .34402 .84861 .34035 .8437 .33321 Mtetra
.619 .742 .934 r
.20671 .53168 .21326 .53739 .22278 .53462 .2162 .52937 Mtetra
.612 .757 .948 r
.2162 .52937 .22278 .53462 .23233 .5318 .22573 .52711 Mtetra
.607 .779 .963 r
.22573 .52711 .23233 .5318 .24194 .52881 .2353 .5248 Mtetra
.605 .806 .977 r
.2353 .5248 .24194 .52881 .2516 .52554 .24492 .52235 Mtetra
.6 .839 .989 r
.24492 .52235 .2516 .52554 .26134 .52187 .2546 .51968 Mtetra
.601 .878 .992 r
.2546 .51968 .26134 .52187 .27114 .51767 .26435 .51655 Mtetra
.606 .915 .978 r
.26435 .51655 .27114 .51767 .28102 .51281 .27418 .51279 Mtetra
.615 .943 .945 r
.27418 .51279 .28102 .51281 .29097 .50738 .28411 .50818 Mtetra
.653 .966 .912 r
.28411 .50818 .29097 .50738 .30098 .50135 .29414 .50249 Mtetra
.702 .981 .895 r
.29414 .50249 .30098 .50135 .31101 .49523 .30426 .49582 Mtetra
.779 .984 .903 r
.30426 .49582 .31101 .49523 .32105 .48936 .31446 .48816 Mtetra
.818 .935 .907 r
.31446 .48816 .32105 .48936 .33104 .48458 .32469 .48016 Mtetra
.8 .823 .87 r
.32469 .48016 .33104 .48458 .34097 .48158 .33492 .4723 Mtetra
.73 .684 .806 r
.33492 .4723 .34097 .48158 .35081 .48094 .3451 .46556 Mtetra
.654 .566 .743 r
.3451 .46556 .35081 .48094 .36055 .48324 .35519 .46076 Mtetra
.591 .477 .692 r
.35519 .46076 .36055 .48324 .37026 .48784 .36519 .45847 Mtetra
.54 .414 .657 r
.36519 .45847 .37026 .48784 .37997 .49425 .37509 .45928 Mtetra
.498 .369 .635 r
.37509 .45928 .37997 .49425 .38983 .49948 .38491 .46342 Mtetra
.454 .335 .628 r
.38491 .46342 .38983 .49948 .3999 .50143 .39469 .4709 Mtetra
.406 .319 .644 r
.39469 .4709 .3999 .50143 .41021 .49857 .40452 .47983 Mtetra
.286 .311 .712 r
.40452 .47983 .41021 .49857 .42073 .49011 .41446 .48866 Mtetra
.499 0 0 r
.41446 .48866 .42073 .49011 .43135 .47883 .42462 .49439 Mtetra
.507 .143 .283 r
.42462 .49439 .43135 .47883 .44198 .46646 .435 .49529 Mtetra
.465 .165 .371 r
.435 .49529 .44198 .46646 .45257 .45525 .44555 .49183 Mtetra
.435 .157 .391 r
.44555 .49183 .45257 .45525 .46311 .44643 .45623 .48454 Mtetra
.422 .149 .392 r
.45623 .48454 .46311 .44643 .47361 .43966 .46694 .4758 Mtetra
.415 .139 .384 r
.46694 .4758 .47361 .43966 .48412 .43473 .47767 .4671 Mtetra
.418 .133 .371 r
.47767 .4671 .48412 .43473 .49464 .43072 .48838 .45959 Mtetra
.434 .138 .361 r
.48838 .45959 .49464 .43072 .5052 .42716 .4991 .45402 Mtetra
.46 .155 .36 r
.4991 .45402 .5052 .42716 .5158 .4237 .50983 .45056 Mtetra
.492 .183 .37 r
.50983 .45056 .5158 .4237 .52644 .42033 .52061 .44922 Mtetra
.521 .215 .388 r
.52061 .44922 .52644 .42033 .53713 .41742 .53144 .44983 Mtetra
.537 .237 .406 r
.53144 .44983 .53713 .41742 .54786 .41543 .54235 .45167 Mtetra
.538 .245 .418 r
.54235 .45167 .54786 .41543 .55867 .4153 .55334 .45355 Mtetra
.525 .237 .42 r
.55334 .45355 .55867 .4153 .56957 .41725 .5644 .45399 Mtetra
.484 .2 .406 r
.5644 .45399 .56957 .41725 .58059 .42165 .57546 .45057 Mtetra
.401 .11 .352 r
.57546 .45057 .58059 .42165 .59174 .42725 .58649 .44273 Mtetra
.063 0 .098 r
.58649 .44273 .59174 .42725 .60296 .43176 .59742 .42996 Mtetra
.933 .912 .774 r
.59742 .42996 .60296 .43176 .61421 .43344 .60825 .41401 Mtetra
.759 .6 .681 r
.60825 .41401 .61421 .43344 .62536 .42943 .61904 .39792 Mtetra
.688 .511 .642 r
.61904 .39792 .62536 .42943 .63639 .42051 .62983 .38326 Mtetra
.647 .47 .631 r
.62983 .38326 .63639 .42051 .64729 .40821 .64071 .37198 Mtetra
.623 .456 .636 r
.64071 .37198 .64729 .40821 .65813 .39468 .65171 .36408 Mtetra
.605 .458 .656 r
.65171 .36408 .65813 .39468 .66903 .38296 .66287 .35934 Mtetra
.585 .473 .693 r
.66287 .35934 .66903 .38296 .68003 .37358 .67419 .35717 Mtetra
.553 .508 .76 r
.67419 .35717 .68003 .37358 .69119 .3672 .68566 .35701 Mtetra
.49 .574 .868 r
.68566 .35701 .69119 .3672 .70251 .36325 .69727 .35801 Mtetra
.349 .663 .973 r
.69727 .35801 .70251 .36325 .71398 .36113 .70897 .35916 Mtetra
.122 .644 .883 r
.70897 .35916 .71398 .36113 .72558 .36014 .72073 .35998 Mtetra
.037 .607 .737 r
.72073 .35998 .72558 .36014 .73727 .35941 .73251 .35979 Mtetra
.083 .642 .718 r
.73251 .35979 .73727 .35941 .74902 .3586 .74429 .35859 Mtetra
.24 .756 .811 r
.74429 .35859 .74902 .3586 .7608 .35718 .75606 .35627 Mtetra
.415 .857 .917 r
.75606 .35627 .7608 .35718 .7726 .35517 .76783 .35308 Mtetra
.556 .899 .978 r
.76783 .35308 .7726 .35517 .7844 .35246 .77959 .34921 Mtetra
.634 .89 .986 r
.77959 .34921 .7844 .35246 .79621 .34922 .79136 .34487 Mtetra
.668 .86 .973 r
.79136 .34487 .79621 .34922 .80804 .34554 .80316 .34029 Mtetra
.683 .83 .954 r
.80316 .34029 .80804 .34554 .81989 .34157 .81498 .33555 Mtetra
.687 .803 .937 r
.81498 .33555 .81989 .34157 .83178 .33742 .82685 .33076 Mtetra
.685 .781 .923 r
.82685 .33076 .83178 .33742 .8437 .33321 .83876 .32602 Mtetra
.612 .74 .936 r
.20012 .52592 .20671 .53168 .2162 .52937 .20961 .52373 Mtetra
.604 .742 .942 r
.20961 .52373 .2162 .52937 .22573 .52711 .21914 .52165 Mtetra
.596 .748 .949 r
.21914 .52165 .22573 .52711 .2353 .5248 .2287 .51967 Mtetra
.588 .758 .96 r
.2287 .51967 .2353 .5248 .24492 .52235 .23829 .51775 Mtetra
.574 .775 .974 r
.23829 .51775 .24492 .52235 .2546 .51968 .24793 .5159 Mtetra
.563 .806 .99 r
.24793 .5159 .2546 .51968 .26435 .51655 .25761 .5139 Mtetra
.545 .846 .998 r
.25761 .5139 .26435 .51655 .27418 .51279 .26736 .51162 Mtetra
.523 .886 .977 r
.26736 .51162 .27418 .51279 .28411 .50818 .2772 .50871 Mtetra
.488 .9 .9 r
.2772 .50871 .28411 .50818 .29414 .50249 .28715 .50489 Mtetra
.439 .869 .766 r
.28715 .50489 .29414 .50249 .30426 .49582 .2972 .49989 Mtetra
.428 .836 .648 r
.2972 .49989 .30426 .49582 .31446 .48816 .30738 .49341 Mtetra
.436 .817 .575 r
.30738 .49341 .31446 .48816 .32469 .48016 .31766 .48565 Mtetra
.528 .865 .598 r
.31766 .48565 .32469 .48016 .33492 .4723 .32802 .47666 Mtetra
.664 .95 .708 r
.32802 .47666 .33492 .4723 .3451 .46556 .33841 .46718 Mtetra
.811 .997 .853 r
.33841 .46718 .3451 .46556 .35519 .46076 .3488 .45781 Mtetra
.818 .879 .889 r
.3488 .45781 .35519 .46076 .36519 .45847 .35913 .44963 Mtetra
.72 .693 .823 r
.35913 .44963 .36519 .45847 .37509 .45928 .36937 .44358 Mtetra
.609 .539 .751 r
.36937 .44358 .37509 .45928 .38491 .46342 .37947 .44102 Mtetra
.516 .43 .697 r
.37947 .44102 .38491 .46342 .39469 .4709 .38943 .44284 Mtetra
.466 .369 .661 r
.38943 .44284 .39469 .4709 .40452 .47983 .39933 .44798 Mtetra
.436 .335 .642 r
.39933 .44798 .40452 .47983 .41446 .48866 .40924 .45557 Mtetra
.451 .342 .64 r
.40924 .45557 .41446 .48866 .42462 .49439 .41928 .46258 Mtetra
.486 .371 .648 r
.41928 .46258 .42462 .49439 .435 .49529 .42949 .46714 Mtetra
.528 .413 .666 r
.42949 .46714 .435 .49529 .44555 .49183 .43987 .46869 Mtetra
.58 .47 .693 r
.43987 .46869 .44555 .49183 .45623 .48454 .4504 .46693 Mtetra
.622 .534 .733 r
.4504 .46693 .45623 .48454 .46694 .4758 .46102 .4633 Mtetra
.664 .613 .788 r
.46102 .4633 .46694 .4758 .47767 .4671 .47169 .45863 Mtetra
.689 .702 .857 r
.47169 .45863 .47767 .4671 .48838 .45959 .4824 .45391 Mtetra
.682 .786 .928 r
.4824 .45391 .48838 .45959 .4991 .45402 .49313 .44969 Mtetra
.641 .826 .972 r
.49313 .44969 .4991 .45402 .50983 .45056 .5039 .44621 Mtetra
.599 .813 .982 r
.5039 .44621 .50983 .45056 .52061 .44922 .51471 .44346 Mtetra
.592 .756 .956 r
.51471 .44346 .52061 .44922 .53144 .44983 .52557 .44123 Mtetra
.61 .672 .884 r
.52557 .44123 .53144 .44983 .54235 .45167 .53648 .43894 Mtetra
.632 .598 .797 r
.53648 .43894 .54235 .45167 .55334 .45355 .54743 .43562 Mtetra
.646 .547 .728 r
.54743 .43562 .55334 .45355 .5644 .45399 .55841 .4304 Mtetra
.666 .524 .682 r
.55841 .4304 .5644 .45399 .57546 .45057 .56937 .42183 Mtetra
.675 .51 .655 r
.56937 .42183 .57546 .45057 .58649 .44273 .58029 .41018 Mtetra
.681 .504 .64 r
.58029 .41018 .58649 .44273 .59742 .42996 .59115 .39603 Mtetra
.681 .5 .635 r
.59115 .39603 .59742 .42996 .60825 .41401 .60197 .38125 Mtetra
.667 .493 .641 r
.60197 .38125 .60825 .41401 .61904 .39792 .61282 .36892 Mtetra
.65 .492 .657 r
.61282 .36892 .61904 .39792 .62983 .38326 .62376 .35996 Mtetra
.617 .495 .691 r
.62376 .35996 .62983 .38326 .64071 .37198 .63486 .35544 Mtetra
.57 .516 .756 r
.63486 .35544 .64071 .37198 .65171 .36408 .64613 .35449 Mtetra
.469 .578 .882 r
.64613 .35449 .65171 .36408 .66287 .35934 .65756 .35574 Mtetra
.1 .574 .91 r
.65756 .35574 .66287 .35934 .67419 .35717 .66913 .35822 Mtetra
.33 0 0 r
.66913 .35822 .67419 .35717 .68566 .35701 .6808 .36083 Mtetra
.419 0 0 r
.6808 .36083 .68566 .35701 .69727 .35801 .69253 .36297 Mtetra
.385 0 0 r
.69253 .36297 .69727 .35801 .70897 .35916 .70429 .36385 Mtetra
.302 0 0 r
.70429 .36385 .70897 .35916 .72073 .35998 .71604 .36341 Mtetra
.126 0 0 r
.71604 .36341 .72073 .35998 .73251 .35979 .72778 .36146 Mtetra
0 0 0 r
.72778 .36146 .73251 .35979 .74429 .35859 .73949 .35829 Mtetra
.442 .878 .883 r
.73949 .35829 .74429 .35859 .75606 .35627 .75119 .35416 Mtetra
.618 .923 .973 r
.75119 .35416 .75606 .35627 .76783 .35308 .76288 .34938 Mtetra
.682 .889 .974 r
.76288 .34938 .76783 .35308 .77959 .34921 .7746 .34429 Mtetra
.702 .848 .953 r
.7746 .34429 .77959 .34921 .79136 .34487 .78634 .33904 Mtetra
.701 .815 .935 r
.78634 .33904 .79136 .34487 .80316 .34029 .79813 .33386 Mtetra
.699 .793 .923 r
.79813 .33386 .80316 .34029 .81498 .33555 .80996 .32873 Mtetra
.695 .779 .916 r
.80996 .32873 .81498 .33555 .82685 .33076 .82184 .32369 Mtetra
.689 .77 .913 r
.82184 .32369 .82685 .33076 .83876 .32602 .83378 .31877 Mtetra
.626 .744 .932 r
.19348 .52013 .20012 .52592 .20961 .52373 .20302 .51764 Mtetra
.619 .732 .927 r
.20302 .51764 .20961 .52373 .21914 .52165 .21259 .5153 Mtetra
.61 .721 .924 r
.21259 .5153 .21914 .52165 .2287 .51967 .22217 .51316 Mtetra
.598 .712 .924 r
.22217 .51316 .2287 .51967 .23829 .51775 .23178 .51129 Mtetra
.578 .708 .931 r
.23178 .51129 .23829 .51775 .24793 .5159 .2414 .50977 Mtetra
.558 .713 .944 r
.2414 .50977 .24793 .5159 .25761 .5139 .25104 .50852 Mtetra
.527 .731 .967 r
.25104 .50852 .25761 .5139 .26736 .51162 .26071 .50753 Mtetra
.489 .769 .994 r
.26071 .50753 .26736 .51162 .2772 .50871 .27043 .50652 Mtetra
.404 .805 .984 r
.27043 .50652 .2772 .50871 .28715 .50489 .28021 .50528 Mtetra
.245 .759 .819 r
.28021 .50528 .28715 .50489 .2972 .49989 .2901 .50336 Mtetra
0 0 0 r
.2901 .50336 .2972 .49989 .30738 .49341 .30009 .50038 Mtetra
.07 0 0 r
.30009 .50038 .30738 .49341 .31766 .48565 .31023 .49595 Mtetra
.105 0 0 r
.31023 .49595 .31766 .48565 .32802 .47666 .3205 .48966 Mtetra
.108 0 .027 r
.3205 .48966 .32802 .47666 .33841 .46718 .33091 .48159 Mtetra
.061 0 .034 r
.33091 .48159 .33841 .46718 .3488 .45781 .34142 .47171 Mtetra
0 0 0 r
.34142 .47171 .3488 .45781 .35913 .44963 .35198 .46089 Mtetra
.35198 .46089 .35913 .44963 .36937 .44358 .36255 .44971 Mtetra
.614 .893 .584 r
.36255 .44971 .36937 .44358 .37947 .44102 .37311 .43855 Mtetra
.866 .888 .849 r
.37311 .43855 .37947 .44102 .38943 .44284 .38364 .42789 Mtetra
.727 .61 .727 r
.38364 .42789 .38943 .44284 .39933 .44798 .39412 .41815 Mtetra
.642 .483 .652 r
.39412 .41815 .39933 .44798 .40924 .45557 .40455 .4099 Mtetra
.59 .415 .613 r
.40455 .4099 .40924 .45557 .41928 .46258 .41489 .40456 Mtetra
.557 .378 .595 r
.41489 .40456 .41928 .46258 .42949 .46714 .42514 .40281 Mtetra
.536 .358 .587 r
.42514 .40281 .42949 .46714 .43987 .46869 .43536 .40415 Mtetra
.519 .346 .585 r
.43536 .40415 .43987 .46869 .4504 .46693 .44559 .40796 Mtetra
.514 .346 .591 r
.44559 .40796 .4504 .46693 .46102 .4633 .45589 .41227 Mtetra
.517 .356 .602 r
.45589 .41227 .46102 .4633 .47169 .45863 .4663 .41581 Mtetra
.531 .378 .619 r
.4663 .41581 .47169 .45863 .4824 .45391 .47682 .4175 Mtetra
.557 .409 .636 r
.47682 .4175 .4824 .45391 .49313 .44969 .48745 .41666 Mtetra
.588 .439 .646 r
.48745 .41666 .49313 .44969 .5039 .44621 .49816 .41313 Mtetra
.615 .457 .645 r
.49816 .41313 .5039 .44621 .51471 .44346 .50892 .4069 Mtetra
.63 .459 .633 r
.50892 .4069 .51471 .44346 .52557 .44123 .51971 .39812 Mtetra
.63 .449 .618 r
.51971 .39812 .52557 .44123 .53648 .43894 .53051 .38747 Mtetra
.622 .433 .605 r
.53051 .38747 .53648 .43894 .54743 .43562 .5413 .376 Mtetra
.609 .416 .595 r
.5413 .376 .54743 .43562 .55841 .4304 .55208 .36502 Mtetra
.591 .399 .589 r
.55208 .36502 .55841 .4304 .56937 .42183 .56288 .35652 Mtetra
.575 .387 .589 r
.56288 .35652 .56937 .42183 .58029 .41018 .57374 .35112 Mtetra
.556 .378 .595 r
.57374 .35112 .58029 .41018 .59115 .39603 .5847 .34936 Mtetra
.536 .377 .613 r
.5847 .34936 .59115 .39603 .60197 .38125 .59578 .35056 Mtetra
.513 .396 .657 r
.59578 .35056 .60197 .38125 .61282 .36892 .60698 .35329 Mtetra
.441 .45 .773 r
.60698 .35329 .61282 .36892 .62376 .35996 .6183 .35698 Mtetra
0 .4 .762 r
.6183 .35698 .62376 .35996 .63486 .35544 .62974 .3612 Mtetra
.546 .053 .037 r
.62974 .3612 .63486 .35544 .64613 .35449 .64127 .36548 Mtetra
.555 .138 .205 r
.64127 .36548 .64613 .35449 .65756 .35574 .6529 .36941 Mtetra
.538 .147 .248 r
.6529 .36941 .65756 .35574 .66913 .35822 .66459 .3724 Mtetra
.499 .114 .242 r
.66459 .3724 .66913 .35822 .6808 .36083 .67628 .37356 Mtetra
.444 .049 .194 r
.67628 .37356 .6808 .36083 .69253 .36297 .68797 .37289 Mtetra
.344 0 .083 r
.68797 .37289 .69253 .36297 .70429 .36385 .69962 .37031 Mtetra
.154 0 0 r
.69962 .37031 .70429 .36385 .71604 .36341 .71125 .36623 Mtetra
0 0 0 r
.71125 .36623 .71604 .36341 .72778 .36146 .72285 .36104 Mtetra
.596 .948 .904 r
.72285 .36104 .72778 .36146 .73949 .35829 .73444 .35514 Mtetra
.721 .919 .96 r
.73444 .35514 .73949 .35829 .75119 .35416 .74605 .349 Mtetra
.736 .848 .933 r
.74605 .349 .75119 .35416 .76288 .34938 .75769 .34282 Mtetra
.724 .796 .908 r
.75769 .34282 .76288 .34938 .7746 .34429 .76938 .3369 Mtetra
.712 .766 .895 r
.76938 .3369 .7746 .34429 .78634 .33904 .78113 .33125 Mtetra
.699 .75 .891 r
.78113 .33125 .78634 .33904 .79813 .33386 .79294 .32596 Mtetra
.69 .744 .893 r
.79294 .32596 .79813 .33386 .80996 .32873 .80482 .32094 Mtetra
.684 .746 .898 r
.80482 .32094 .80996 .32873 .82184 .32369 .81676 .31613 Mtetra
.679 .752 .906 r
.81676 .31613 .82184 .32369 .83378 .31877 .82876 .31146 Mtetra
.656 .751 .92 r
.18679 .51429 .19348 .52013 .20302 .51764 .19642 .51112 Mtetra
.651 .728 .905 r
.19642 .51112 .20302 .51764 .21259 .5153 .20607 .50805 Mtetra
.642 .704 .891 r
.20607 .50805 .21259 .5153 .22217 .51316 .21574 .50519 Mtetra
.629 .679 .879 r
.21574 .50519 .22217 .51316 .23178 .51129 .22541 .50265 Mtetra
.611 .656 .869 r
.22541 .50265 .23178 .51129 .2414 .50977 .23509 .50056 Mtetra
.592 .634 .862 r
.23509 .50056 .2414 .50977 .25104 .50852 .24477 .49898 Mtetra
.568 .616 .861 r
.24477 .49898 .25104 .50852 .26071 .50753 .25444 .498 Mtetra
.547 .608 .866 r
.25444 .498 .26071 .50753 .27043 .50652 .26412 .49751 Mtetra
.521 .61 .882 r
.26412 .49751 .27043 .50652 .28021 .50528 .27383 .49746 Mtetra
.502 .637 .914 r
.27383 .49746 .28021 .50528 .2901 .50336 .28358 .4975 Mtetra
.473 .694 .964 r
.28358 .4975 .2901 .50336 .30009 .50038 .2934 .49735 Mtetra
.416 .783 .994 r
.2934 .49735 .30009 .50038 .31023 .49595 .30333 .49646 Mtetra
.252 .765 .813 r
.30333 .49646 .31023 .49595 .3205 .48966 .31339 .49434 Mtetra
0 0 0 r
.31339 .49434 .3205 .48966 .33091 .48159 .32359 .49062 Mtetra
.085 0 0 r
.32359 .49062 .33091 .48159 .34142 .47171 .33394 .4849 Mtetra
.146 0 .049 r
.33394 .4849 .34142 .47171 .35198 .46089 .34442 .47736 Mtetra
.159 0 .119 r
.34442 .47736 .35198 .46089 .36255 .44971 .35501 .46799 Mtetra
.129 0 .132 r
.35501 .46799 .36255 .44971 .37311 .43855 .36568 .45676 Mtetra
.054 0 .097 r
.36568 .45676 .37311 .43855 .38364 .42789 .37643 .44385 Mtetra
0 0 .013 r
.37643 .44385 .38364 .42789 .39412 .41815 .38717 .43053 Mtetra
0 0 0 r
.38717 .43053 .39412 .41815 .40455 .4099 .39786 .41787 Mtetra
.39786 .41787 .40455 .4099 .41489 .40456 .40844 .40788 Mtetra
.425 .841 .672 r
.40844 .40788 .41489 .40456 .42514 .40281 .41889 .4016 Mtetra
.512 .888 .969 r
.41889 .4016 .42514 .40281 .43536 .40415 .42928 .39847 Mtetra
.49 .712 .969 r
.42928 .39847 .43536 .40415 .44559 .40796 .43963 .39797 Mtetra
.509 .584 .865 r
.43963 .39797 .44559 .40796 .45589 .41227 .45003 .39835 Mtetra
.536 .525 .79 r
.45003 .39835 .45589 .41227 .4663 .41581 .46049 .39857 Mtetra
.563 .502 .745 r
.46049 .39857 .4663 .41581 .47682 .4175 .47103 .39788 Mtetra
.588 .497 .719 r
.47103 .39788 .47682 .4175 .48745 .41666 .48165 .39578 Mtetra
.61 .502 .706 r
.48165 .39578 .48745 .41666 .49816 .41313 .49234 .39221 Mtetra
.632 .516 .703 r
.49234 .39221 .49816 .41313 .50892 .4069 .50308 .38717 Mtetra
.656 .538 .708 r
.50308 .38717 .50892 .4069 .51971 .39812 .51386 .38071 Mtetra
.68 .569 .723 r
.51386 .38071 .51971 .39812 .53051 .38747 .52466 .37332 Mtetra
.704 .613 .753 r
.52466 .37332 .53051 .38747 .5413 .376 .53548 .36576 Mtetra
.719 .679 .81 r
.53548 .36576 .5413 .376 .55208 .36502 .54632 .35907 Mtetra
.672 .779 .93 r
.54632 .35907 .55208 .36502 .56288 .35652 .55721 .35503 Mtetra
.26 .75 .916 r
.55721 .35503 .56288 .35652 .57374 .35112 .56818 .35417 Mtetra
.45 0 0 r
.56818 .35417 .57374 .35112 .5847 .34936 .57928 .3571 Mtetra
.596 .143 .147 r
.57928 .3571 .5847 .34936 .59578 .35056 .59053 .36275 Mtetra
.605 .203 .254 r
.59053 .36275 .59578 .35056 .60698 .35329 .6019 .36911 Mtetra
.592 .217 .3 r
.6019 .36911 .60698 .35329 .6183 .35698 .61338 .37509 Mtetra
.563 .202 .315 r
.61338 .37509 .6183 .35698 .62974 .3612 .62492 .37938 Mtetra
.531 .173 .304 r
.62492 .37938 .62974 .3612 .64127 .36548 .6365 .38179 Mtetra
.492 .124 .268 r
.6365 .38179 .64127 .36548 .6529 .36941 .6481 .38236 Mtetra
.426 .033 .188 r
.6481 .38236 .6529 .36941 .66459 .3724 .6597 .38106 Mtetra
.274 0 .004 r
.6597 .38106 .66459 .3724 .67628 .37356 .67128 .37771 Mtetra
0 0 0 r
.67128 .37771 .67628 .37356 .68797 .37289 .68282 .37271 Mtetra
.614 .956 .896 r
.68282 .37271 .68797 .37289 .69962 .37031 .69433 .36643 Mtetra
.765 .898 .936 r
.69433 .36643 .69962 .37031 .71125 .36623 .70583 .35937 Mtetra
.759 .793 .881 r
.70583 .35937 .71125 .36623 .72285 .36104 .71734 .3521 Mtetra
.739 .731 .844 r
.71734 .3521 .72285 .36104 .73444 .35514 .72888 .3449 Mtetra
.718 .694 .826 r
.72888 .3449 .73444 .35514 .74605 .349 .74048 .33816 Mtetra
.703 .676 .821 r
.74048 .33816 .74605 .349 .75769 .34282 .75214 .33191 Mtetra
.689 .669 .826 r
.75214 .33191 .75769 .34282 .76938 .3369 .76388 .32628 Mtetra
.678 .671 .836 r
.76388 .32628 .76938 .3369 .78113 .33125 .77569 .32117 Mtetra
.669 .679 .85 r
.77569 .32117 .78113 .33125 .79294 .32596 .78759 .31652 Mtetra
.663 .692 .867 r
.78759 .31652 .79294 .32596 .80482 .32094 .79956 .3122 Mtetra
.658 .709 .885 r
.79956 .3122 .80482 .32094 .81676 .31613 .8116 .3081 Mtetra
.656 .73 .904 r
.8116 .3081 .81676 .31613 .82876 .31146 .82371 .3041 Mtetra
.688 .758 .905 r
.18006 .50842 .18679 .51429 .19642 .51112 .18979 .5044 Mtetra
.684 .731 .886 r
.18979 .5044 .19642 .51112 .20607 .50805 .19955 .50038 Mtetra
.675 .703 .868 r
.19955 .50038 .20607 .50805 .21574 .50519 .20933 .49648 Mtetra
.663 .674 .85 r
.20933 .49648 .21574 .50519 .22541 .50265 .21912 .49282 Mtetra
.648 .643 .832 r
.21912 .49282 .22541 .50265 .23509 .50056 .22891 .48951 Mtetra
.628 .612 .815 r
.22891 .48951 .23509 .50056 .24477 .49898 .2387 .4867 Mtetra
.606 .581 .799 r
.2387 .4867 .24477 .49898 .25444 .498 .24846 .48456 Mtetra
.583 .553 .786 r
.24846 .48456 .25444 .498 .26412 .49751 .25821 .48318 Mtetra
.558 .527 .777 r
.25821 .48318 .26412 .49751 .27383 .49746 .26794 .48267 Mtetra
.535 .509 .774 r
.26794 .48267 .27383 .49746 .28358 .4975 .27766 .48294 Mtetra
.51 .498 .779 r
.27766 .48294 .28358 .4975 .2934 .49735 .28739 .48396 Mtetra
.488 .504 .8 r
.28739 .48396 .2934 .49735 .30333 .49646 .29715 .48542 Mtetra
.458 .533 .846 r
.29715 .48542 .30333 .49646 .31339 .49434 .30697 .48705 Mtetra
.396 .609 .934 r
.30697 .48705 .31339 .49434 .32359 .49062 .31687 .48841 Mtetra
.139 .652 .896 r
.31687 .48841 .32359 .49062 .33394 .4849 .32688 .48908 Mtetra
.254 0 0 r
.32688 .48908 .33394 .4849 .34442 .47736 .33703 .48844 Mtetra
.35 0 .108 r
.33703 .48844 .34442 .47736 .35501 .46799 .34733 .48599 Mtetra
.38 .032 .244 r
.34733 .48599 .35501 .46799 .36568 .45676 .35777 .48186 Mtetra
.396 .084 .314 r
.35777 .48186 .36568 .45676 .37643 .44385 .36831 .47615 Mtetra
.424 .132 .362 r
.36831 .47615 .37643 .44385 .38717 .43053 .3789 .47 Mtetra
.448 .167 .394 r
.3789 .47 .38717 .43053 .39786 .41787 .38951 .46391 Mtetra
.455 .184 .412 r
.38951 .46391 .39786 .41787 .40844 .40788 .40016 .4572 Mtetra
.452 .185 .417 r
.40016 .4572 .40844 .40788 .41889 .4016 .41087 .44954 Mtetra
.434 .168 .41 r
.41087 .44954 .41889 .4016 .42928 .39847 .42164 .44031 Mtetra
.398 .129 .385 r
.42164 .44031 .42928 .39847 .43963 .39797 .43247 .42955 Mtetra
.34 .058 .331 r
.43247 .42955 .43963 .39797 .45003 .39835 .44329 .4185 Mtetra
.221 0 .204 r
.44329 .4185 .45003 .39835 .46049 .39857 .45409 .40804 Mtetra
0 0 0 r
.45409 .40804 .46049 .39857 .47103 .39788 .46486 .39934 Mtetra
.575 .94 .832 r
.46486 .39934 .47103 .39788 .48165 .39578 .47559 .39304 Mtetra
.609 .881 .991 r
.47559 .39304 .48165 .39578 .49234 .39221 .48632 .38945 Mtetra
.375 .779 .984 r
.48632 .38945 .49234 .39221 .50308 .38717 .49707 .38857 Mtetra
.286 0 0 r
.49707 .38857 .50308 .38717 .51386 .38071 .50786 .39012 Mtetra
.54 .107 .168 r
.50786 .39012 .51386 .38071 .52466 .37332 .51873 .39345 Mtetra
.558 .211 .336 r
.51873 .39345 .52466 .37332 .53548 .36576 .52969 .3974 Mtetra
.55 .242 .398 r
.52969 .3974 .53548 .36576 .54632 .35907 .54075 .40108 Mtetra
.535 .247 .424 r
.54075 .40108 .54632 .35907 .55721 .35503 .55189 .40324 Mtetra
.523 .245 .433 r
.55189 .40324 .55721 .35503 .56818 .35417 .56309 .40383 Mtetra
.517 .24 .434 r
.56309 .40383 .56818 .35417 .57928 .3571 .57436 .40348 Mtetra
.51 .231 .427 r
.57436 .40348 .57928 .3571 .59053 .36275 .58568 .4025 Mtetra
.506 .218 .411 r
.58568 .4025 .59053 .36275 .6019 .36911 .59707 .40159 Mtetra
.494 .193 .384 r
.59707 .40159 .6019 .36911 .61338 .37509 .60851 .40024 Mtetra
.456 .137 .336 r
.60851 .40024 .61338 .37509 .62492 .37938 .61997 .39728 Mtetra
.379 .032 .246 r
.61997 .39728 .62492 .37938 .6365 .38179 .63143 .3926 Mtetra
.181 0 .03 r
.63143 .3926 .6365 .38179 .6481 .38236 .64286 .38606 Mtetra
0 0 0 r
.64286 .38606 .6481 .38236 .6597 .38106 .65426 .37816 Mtetra
.811 .933 .912 r
.65426 .37816 .6597 .38106 .67128 .37771 .66565 .36953 Mtetra
.781 .76 .834 r
.66565 .36953 .67128 .37771 .68282 .37271 .67703 .3606 Mtetra
.739 .668 .781 r
.67703 .3606 .68282 .37271 .69433 .36643 .68844 .35183 Mtetra
.712 .622 .755 r
.68844 .35183 .69433 .36643 .70583 .35937 .69988 .34349 Mtetra
.691 .597 .746 r
.69988 .34349 .70583 .35937 .71734 .3521 .71138 .33592 Mtetra
.677 .587 .747 r
.71138 .33592 .71734 .3521 .72888 .3449 .72295 .32914 Mtetra
.664 .585 .756 r
.72295 .32914 .72888 .3449 .74048 .33816 .73461 .32326 Mtetra
.654 .59 .77 r
.73461 .32326 .74048 .33816 .75214 .33191 .74636 .31815 Mtetra
.646 .601 .789 r
.74636 .31815 .75214 .33191 .76388 .32628 .75821 .31373 Mtetra
.639 .617 .811 r
.75821 .31373 .76388 .32628 .77569 .32117 .77014 .30983 Mtetra
.635 .637 .836 r
.77014 .30983 .77569 .32117 .78759 .31652 .78215 .30629 Mtetra
.63 .659 .86 r
.78215 .30629 .78759 .31652 .79956 .3122 .79424 .30301 Mtetra
.627 .684 .884 r
.79424 .30301 .79956 .3122 .8116 .3081 .80639 .29985 Mtetra
.626 .711 .907 r
.80639 .29985 .8116 .3081 .82371 .3041 .81861 .29669 Mtetra
.706 .762 .895 r
.17328 .5025 .18006 .50842 .18979 .5044 .18309 .4979 Mtetra
.706 .744 .882 r
.18309 .4979 .18979 .5044 .19955 .50038 .19294 .49321 Mtetra
.702 .725 .868 r
.19294 .49321 .19955 .50038 .20933 .49648 .20282 .4885 Mtetra
.695 .702 .853 r
.20282 .4885 .20933 .49648 .21912 .49282 .21271 .48385 Mtetra
.685 .677 .836 r
.21271 .48385 .21912 .49282 .22891 .48951 .22263 .4793 Mtetra
.67 .646 .817 r
.22263 .4793 .22891 .48951 .2387 .4867 .23255 .47503 Mtetra
.652 .613 .798 r
.23255 .47503 .2387 .4867 .24846 .48456 .24246 .47118 Mtetra
.63 .578 .777 r
.24246 .47118 .24846 .48456 .25821 .48318 .25236 .46795 Mtetra
.605 .543 .758 r
.25236 .46795 .25821 .48318 .26794 .48267 .26223 .46552 Mtetra
.58 .509 .74 r
.26223 .46552 .26794 .48267 .27766 .48294 .27207 .46402 Mtetra
.555 .479 .724 r
.27207 .46402 .27766 .48294 .28739 .48396 .28188 .46358 Mtetra
.533 .455 .713 r
.28188 .46358 .28739 .48396 .29715 .48542 .29168 .46413 Mtetra
.513 .436 .706 r
.29168 .46413 .29715 .48542 .30697 .48705 .30147 .46567 Mtetra
.498 .426 .706 r
.30147 .46567 .30697 .48705 .31687 .48841 .31128 .46787 Mtetra
.485 .424 .714 r
.31128 .46787 .31687 .48841 .32688 .48908 .32114 .47048 Mtetra
.485 .441 .733 r
.32114 .47048 .32688 .48908 .33703 .48844 .33109 .47284 Mtetra
.493 .479 .77 r
.33109 .47284 .33703 .48844 .34733 .48599 .34116 .47448 Mtetra
.488 .543 .839 r
.34116 .47448 .34733 .48599 .35777 .48186 .35133 .47554 Mtetra
.434 .667 .96 r
.35133 .47554 .35777 .48186 .36831 .47615 .36159 .47597 Mtetra
.041 .61 .744 r
.36159 .47597 .36831 .47615 .3789 .47 .37195 .47581 Mtetra
.295 0 0 r
.37195 .47581 .3789 .47 .38951 .46391 .38241 .47484 Mtetra
.312 0 .079 r
.38241 .47484 .38951 .46391 .40016 .4572 .39301 .47167 Mtetra
.264 0 .132 r
.39301 .47167 .40016 .4572 .41087 .44954 .40376 .4657 Mtetra
.2 0 .132 r
.40376 .4657 .41087 .44954 .42164 .44031 .41461 .45728 Mtetra
.142 0 .119 r
.41461 .45728 .42164 .44031 .43247 .42955 .42554 .44695 Mtetra
.15 0 .13 r
.42554 .44695 .43247 .42955 .44329 .4185 .43646 .43645 Mtetra
.202 0 .163 r
.43646 .43645 .44329 .4185 .45409 .40804 .44736 .42685 Mtetra
.278 0 .209 r
.44736 .42685 .45409 .40804 .46486 .39934 .45823 .41892 Mtetra
.354 .018 .25 r
.45823 .41892 .46486 .39934 .47559 .39304 .46908 .41313 Mtetra
.414 .076 .28 r
.46908 .41313 .47559 .39304 .48632 .38945 .47992 .40954 Mtetra
.462 .12 .299 r
.47992 .40954 .48632 .38945 .49707 .38857 .49079 .40814 Mtetra
.503 .155 .309 r
.49079 .40814 .49707 .38857 .50786 .39012 .5017 .40891 Mtetra
.532 .177 .311 r
.5017 .40891 .50786 .39012 .51873 .39345 .51267 .41136 Mtetra
.547 .187 .307 r
.51267 .41136 .51873 .39345 .52969 .3974 .52373 .41475 Mtetra
.544 .18 .299 r
.52373 .41475 .52969 .3974 .54075 .40108 .53488 .418 Mtetra
.507 .14 .278 r
.53488 .418 .54075 .40108 .55189 .40324 .54612 .41933 Mtetra
.448 .079 .244 r
.54612 .41933 .55189 .40324 .56309 .40383 .5574 .4182 Mtetra
.352 0 .177 r
.5574 .4182 .56309 .40383 .57436 .40348 .56872 .41422 Mtetra
.18 0 .017 r
.56872 .41422 .57436 .40348 .58568 .4025 .58004 .40801 Mtetra
0 0 0 r
.58004 .40801 .58568 .4025 .59707 .40159 .59137 .40097 Mtetra
.737 .981 .913 r
.59137 .40097 .59707 .40159 .60851 .40024 .60271 .39331 Mtetra
.782 .79 .86 r
.60271 .39331 .60851 .40024 .61997 .39728 .61406 .38499 Mtetra
.739 .664 .776 r
.61406 .38499 .61997 .39728 .63143 .3926 .62539 .37606 Mtetra
.716 .603 .729 r
.62539 .37606 .63143 .3926 .64286 .38606 .63671 .36636 Mtetra
.699 .569 .705 r
.63671 .36636 .64286 .38606 .65426 .37816 .64803 .3564 Mtetra
.683 .547 .693 r
.64803 .3564 .65426 .37816 .66565 .36953 .65937 .34683 Mtetra
.671 .534 .689 r
.65937 .34683 .66565 .36953 .67703 .3606 .67074 .33792 Mtetra
.66 .528 .692 r
.67074 .33792 .67703 .3606 .68844 .35183 .68217 .33001 Mtetra
.651 .527 .7 r
.68217 .33001 .68844 .35183 .69988 .34349 .69367 .3231 Mtetra
.641 .531 .713 r
.69367 .3231 .69988 .34349 .71138 .33592 .70527 .31729 Mtetra
.634 .54 .731 r
.70527 .31729 .71138 .33592 .72295 .32914 .71696 .31243 Mtetra
.626 .554 .754 r
.71696 .31243 .72295 .32914 .73461 .32326 .72874 .3084 Mtetra
.62 .572 .779 r
.72874 .3084 .73461 .32326 .74636 .31815 .74062 .305 Mtetra
.615 .595 .807 r
.74062 .305 .74636 .31815 .75821 .31373 .75258 .30204 Mtetra
.61 .618 .835 r
.75258 .30204 .75821 .31373 .77014 .30983 .76462 .29938 Mtetra
.607 .644 .861 r
.76462 .29938 .77014 .30983 .78215 .30629 .77674 .29683 Mtetra
.605 .667 .883 r
.77674 .29683 .78215 .30629 .79424 .30301 .78892 .29433 Mtetra
.603 .689 .903 r
.78892 .29433 .79424 .30301 .80639 .29985 .80117 .29182 Mtetra
.604 .709 .919 r
.80117 .29182 .80639 .29985 .81861 .29669 .81347 .28921 Mtetra
.71 .762 .893 r
.16646 .49655 .17328 .5025 .18309 .4979 .1763 .4918 Mtetra
.714 .759 .888 r
.1763 .4918 .18309 .4979 .19294 .49321 .1862 .48689 Mtetra
.717 .754 .882 r
.1862 .48689 .19294 .49321 .20282 .4885 .19613 .48182 Mtetra
.718 .744 .872 r
.19613 .48182 .20282 .4885 .21271 .48385 .2061 .47659 Mtetra
.719 .729 .859 r
.2061 .47659 .21271 .48385 .22263 .4793 .21612 .47117 Mtetra
.714 .707 .842 r
.21612 .47117 .22263 .4793 .23255 .47503 .22617 .46569 Mtetra
.704 .677 .821 r
.22617 .46569 .23255 .47503 .24246 .47118 .23624 .4602 Mtetra
.688 .641 .798 r
.23624 .4602 .24246 .47118 .25236 .46795 .24631 .45492 Mtetra
.667 .602 .773 r
.24631 .45492 .25236 .46795 .26223 .46552 .25638 .45 Mtetra
.643 .561 .747 r
.25638 .45 .26223 .46552 .27207 .46402 .26644 .44569 Mtetra
.617 .521 .723 r
.26644 .44569 .27207 .46402 .28188 .46358 .27646 .44218 Mtetra
.593 .485 .701 r
.27646 .44218 .28188 .46358 .29168 .46413 .28645 .43959 Mtetra
.57 .454 .681 r
.28645 .43959 .29168 .46413 .30147 .46567 .29641 .43809 Mtetra
.552 .429 .665 r
.29641 .43809 .30147 .46567 .31128 .46787 .30635 .43755 Mtetra
.538 .409 .653 r
.30635 .43755 .31128 .46787 .32114 .47048 .31629 .43796 Mtetra
.527 .395 .644 r
.31629 .43796 .32114 .47048 .33109 .47284 .32624 .43918 Mtetra
.518 .386 .64 r
.32624 .43918 .33109 .47284 .34116 .47448 .33622 .4411 Mtetra
.508 .38 .641 r
.33622 .4411 .34116 .47448 .35133 .47554 .34623 .44368 Mtetra
.5 .38 .647 r
.34623 .44368 .35133 .47554 .36159 .47597 .3563 .44671 Mtetra
.51 .396 .66 r
.3563 .44671 .36159 .47597 .37195 .47581 .36649 .44894 Mtetra
.533 .422 .673 r
.36649 .44894 .37195 .47581 .38241 .47484 .37683 .44963 Mtetra
.561 .448 .682 r
.37683 .44963 .38241 .47484 .39301 .47167 .3873 .44865 Mtetra
.588 .477 .695 r
.3873 .44865 .39301 .47167 .40376 .4657 .39789 .44609 Mtetra
.594 .503 .721 r
.39789 .44609 .40376 .4657 .41461 .45728 .40853 .44355 Mtetra
.588 .562 .792 r
.40853 .44355 .41461 .45728 .42554 .44695 .41919 .44178 Mtetra
.494 .744 .984 r
.41919 .44178 .42554 .44695 .43646 .43645 .42989 .44085 Mtetra
.287 0 0 r
.42989 .44085 .43646 .43645 .44736 .42685 .44062 .44057 Mtetra
.439 .05 .202 r
.44062 .44057 .44736 .42685 .45823 .41892 .45143 .43977 Mtetra
.452 .112 .297 r
.45143 .43977 .45823 .41892 .46908 .41313 .46233 .43786 Mtetra
.436 .115 .321 r
.46233 .43786 .46908 .41313 .47992 .40954 .4733 .43427 Mtetra
.404 .086 .31 r
.4733 .43427 .47992 .40954 .49079 .40814 .48435 .42899 Mtetra
.349 .019 .258 r
.48435 .42899 .49079 .40814 .5017 .40891 .49543 .42258 Mtetra
.216 0 .098 r
.49543 .42258 .5017 .40891 .51267 .41136 .50655 .41565 Mtetra
0 0 0 r
.50655 .41565 .51267 .41136 .52373 .41475 .51768 .40936 Mtetra
.718 .819 .928 r
.51768 .40936 .52373 .41475 .53488 .418 .52884 .4039 Mtetra
.652 .595 .778 r
.52884 .4039 .53488 .418 .54612 .41933 .54004 .39921 Mtetra
.627 .523 .716 r
.54004 .39921 .54612 .41933 .5574 .4182 .55128 .39455 Mtetra
.637 .508 .689 r
.55128 .39455 .5574 .4182 .56872 .41422 .56254 .38828 Mtetra
.649 .504 .673 r
.56254 .38828 .56872 .41422 .58004 .40801 .5738 .38029 Mtetra
.658 .504 .663 r
.5738 .38029 .58004 .40801 .59137 .40097 .58505 .37072 Mtetra
.657 .495 .652 r
.58505 .37072 .59137 .40097 .60271 .39331 .59629 .36031 Mtetra
.645 .479 .643 r
.59629 .36031 .60271 .39331 .61406 .38499 .60753 .35034 Mtetra
.635 .468 .639 r
.60753 .35034 .61406 .38499 .62539 .37606 .6188 .34103 Mtetra
.628 .462 .638 r
.6188 .34103 .62539 .37606 .63671 .36636 .6301 .33241 Mtetra
.623 .461 .642 r
.6301 .33241 .63671 .36636 .64803 .3564 .64144 .32461 Mtetra
.619 .465 .65 r
.64144 .32461 .64803 .3564 .65937 .34683 .65284 .31775 Mtetra
.615 .471 .662 r
.65284 .31775 .65937 .34683 .67074 .33792 .6643 .31189 Mtetra
.61 .48 .679 r
.6643 .31189 .67074 .33792 .68217 .33001 .67586 .30714 Mtetra
.604 .493 .699 r
.67586 .30714 .68217 .33001 .69367 .3231 .68751 .30333 Mtetra
.598 .51 .726 r
.68751 .30333 .69367 .3231 .70527 .31729 .69925 .30036 Mtetra
.593 .533 .757 r
.69925 .30036 .70527 .31729 .71696 .31243 .71108 .298 Mtetra
.588 .561 .791 r
.71108 .298 .71696 .31243 .72874 .3084 .72301 .29603 Mtetra
.583 .592 .827 r
.72301 .29603 .72874 .3084 .74062 .305 .73501 .29428 Mtetra
.582 .625 .859 r
.73501 .29428 .74062 .305 .75258 .30204 .74708 .29253 Mtetra
.581 .654 .887 r
.74708 .29253 .75258 .30204 .76462 .29938 .75922 .29072 Mtetra
.584 .68 .906 r
.75922 .29072 .76462 .29938 .77674 .29683 .77141 .2887 Mtetra
.587 .698 .919 r
.77141 .2887 .77674 .29683 .78892 .29433 .78365 .28653 Mtetra
.591 .711 .927 r
.78365 .28653 .78892 .29433 .80117 .29182 .79595 .28419 Mtetra
.596 .72 .931 r
.79595 .28419 .80117 .29182 .81347 .28921 .8083 .28168 Mtetra
.693 .759 .903 r
.15958 .49055 .16646 .49655 .1763 .4918 .1694 .48629 Mtetra
.7 .778 .912 r
.1694 .48629 .1763 .4918 .1862 .48689 .17926 .48187 Mtetra
.709 .797 .919 r
.17926 .48187 .1862 .48689 .19613 .48182 .18918 .47722 Mtetra
.72 .813 .923 r
.18918 .47722 .19613 .48182 .2061 .47659 .19915 .47228 Mtetra
.733 .826 .922 r
.19915 .47228 .2061 .47659 .21612 .47117 .20919 .46696 Mtetra
.744 .831 .918 r
.20919 .46696 .21612 .47117 .22617 .46569 .21928 .46131 Mtetra
.753 .826 .909 r
.21928 .46131 .22617 .46569 .23624 .4602 .22943 .45531 Mtetra
.756 .81 .895 r
.22943 .45531 .23624 .4602 .24631 .45492 .23961 .4491 Mtetra
.752 .78 .876 r
.23961 .4491 .24631 .45492 .25638 .45 .24983 .44278 Mtetra
.737 .739 .852 r
.24983 .44278 .25638 .45 .26644 .44569 .26006 .43655 Mtetra
.715 .688 .823 r
.26006 .43655 .26644 .44569 .27646 .44218 .27028 .4306 Mtetra
.687 .634 .791 r
.27028 .4306 .27646 .44218 .28645 .43959 .28049 .42514 Mtetra
.656 .58 .758 r
.28049 .42514 .28645 .43959 .29641 .43809 .29068 .42035 Mtetra
.627 .533 .728 r
.29068 .42035 .29641 .43809 .30635 .43755 .30085 .41633 Mtetra
.601 .492 .702 r
.30085 .41633 .30635 .43755 .31629 .43796 .31099 .41319 Mtetra
.578 .458 .68 r
.31099 .41319 .31629 .43796 .32624 .43918 .3211 .4111 Mtetra
.557 .431 .663 r
.3211 .4111 .32624 .43918 .33622 .4411 .3312 .41014 Mtetra
.544 .412 .651 r
.3312 .41014 .33622 .4411 .34623 .44368 .3413 .41004 Mtetra
.535 .398 .641 r
.3413 .41004 .34623 .44368 .3563 .44671 .35143 .41055 Mtetra
.54 .395 .633 r
.35143 .41055 .3563 .44671 .36649 .44894 .36164 .41066 Mtetra
.549 .398 .628 r
.36164 .41066 .36649 .44894 .37683 .44963 .37196 .4099 Mtetra
.55 .395 .624 r
.37196 .4099 .37683 .44963 .3873 .44865 .38234 .40906 Mtetra
.546 .393 .625 r
.38234 .40906 .3873 .44865 .39789 .44609 .39276 .40859 Mtetra
.532 .388 .63 r
.39276 .40859 .39789 .44609 .40853 .44355 .4032 .40941 Mtetra
.512 .382 .64 r
.4032 .40941 .40853 .44355 .41919 .44178 .41366 .4117 Mtetra
.502 .389 .657 r
.41366 .4117 .41919 .44178 .42989 .44085 .42418 .41444 Mtetra
.502 .404 .677 r
.42418 .41444 .42989 .44085 .44062 .44057 .43479 .41685 Mtetra
.526 .435 .695 r
.43479 .41685 .44062 .44057 .45143 .43977 .44553 .41779 Mtetra
.565 .471 .706 r
.44553 .41779 .45143 .43977 .46233 .43786 .45638 .4166 Mtetra
.607 .502 .708 r
.45638 .4166 .46233 .43786 .4733 .43427 .46734 .41297 Mtetra
.643 .524 .703 r
.46734 .41297 .4733 .43427 .48435 .42899 .47837 .40689 Mtetra
.667 .533 .692 r
.47837 .40689 .48435 .42899 .49543 .42258 .48946 .39866 Mtetra
.675 .529 .679 r
.48946 .39866 .49543 .42258 .50655 .41565 .50057 .38893 Mtetra
.667 .512 .665 r
.50057 .38893 .50655 .41565 .51768 .40936 .51169 .37885 Mtetra
.65 .488 .651 r
.51169 .37885 .51768 .40936 .52884 .4039 .5228 .36919 Mtetra
.626 .46 .639 r
.5228 .36919 .52884 .4039 .54004 .39921 .53393 .36101 Mtetra
.607 .44 .63 r
.53393 .36101 .54004 .39921 .55128 .39455 .54507 .35412 Mtetra
.6 .431 .625 r
.54507 .35412 .55128 .39455 .56254 .38828 .55625 .34759 Mtetra
.601 .431 .624 r
.55625 .34759 .56254 .38828 .5738 .38029 .56745 .34097 Mtetra
.61 .44 .627 r
.56745 .34097 .5738 .38029 .58505 .37072 .57866 .33345 Mtetra
.617 .449 .632 r
.57866 .33345 .58505 .37072 .59629 .36031 .58988 .32551 Mtetra
.617 .454 .639 r
.58988 .32551 .59629 .36031 .60753 .35034 .60113 .31818 Mtetra
.614 .46 .649 r
.60113 .31818 .60753 .35034 .6188 .34103 .61242 .31172 Mtetra
.608 .465 .661 r
.61242 .31172 .6188 .34103 .6301 .33241 .62379 .30641 Mtetra
.603 .475 .678 r
.62379 .30641 .6301 .33241 .64144 .32461 .63522 .30215 Mtetra
.598 .49 .702 r
.63522 .30215 .64144 .32461 .65284 .31775 .64674 .29881 Mtetra
.592 .512 .733 r
.64674 .29881 .65284 .31775 .6643 .31189 .65834 .29626 Mtetra
.583 .541 .773 r
.65834 .29626 .6643 .31189 .67586 .30714 .67003 .2944 Mtetra
.572 .578 .82 r
.67003 .2944 .67586 .30714 .68751 .30333 .68182 .29305 Mtetra
.557 .62 .871 r
.68182 .29305 .68751 .30333 .69925 .30036 .69368 .29199 Mtetra
.539 .664 .918 r
.69368 .29199 .69925 .30036 .71108 .298 .70563 .29104 Mtetra
.526 .705 .953 r
.70563 .29104 .71108 .298 .72301 .29603 .71765 .28998 Mtetra
.518 .736 .973 r
.71765 .28998 .72301 .29603 .73501 .29428 .72972 .28871 Mtetra
.527 .76 .982 r
.72972 .28871 .73501 .29428 .74708 .29253 .74184 .28708 Mtetra
.542 .773 .983 r
.74184 .28708 .74708 .29253 .75922 .29072 .75401 .28511 Mtetra
.566 .779 .979 r
.75401 .28511 .75922 .29072 .77141 .2887 .76621 .28274 Mtetra
.586 .775 .97 r
.76621 .28274 .77141 .2887 .78365 .28653 .77846 .28008 Mtetra
.603 .765 .957 r
.77846 .28008 .78365 .28653 .79595 .28419 .79074 .27717 Mtetra
.614 .751 .943 r
.79074 .27717 .79595 .28419 .8083 .28168 .80308 .27409 Mtetra
.657 .752 .92 r
.15266 .48451 .15958 .49055 .1694 .48629 .1624 .48119 Mtetra
.66 .786 .941 r
.1624 .48119 .1694 .48629 .17926 .48187 .17218 .47775 Mtetra
.665 .824 .96 r
.17218 .47775 .17926 .48187 .18918 .47722 .18202 .47409 Mtetra
.67 .863 .973 r
.18202 .47409 .18918 .47722 .19915 .47228 .19193 .4701 Mtetra
.677 .899 .976 r
.19193 .4701 .19915 .47228 .20919 .46696 .20191 .46569 Mtetra
.683 .929 .969 r
.20191 .46569 .20919 .46696 .21928 .46131 .21197 .46081 Mtetra
.692 .952 .954 r
.21197 .46081 .21928 .46131 .22943 .45531 .22211 .45538 Mtetra
.702 .965 .938 r
.22211 .45538 .22943 .45531 .23961 .4491 .23231 .44943 Mtetra
.722 .973 .927 r
.23231 .44943 .23961 .4491 .24983 .44278 .24259 .44295 Mtetra
.747 .974 .925 r
.24259 .44295 .24983 .44278 .26006 .43655 .25292 .43608 Mtetra
.776 .962 .927 r
.25292 .43608 .26006 .43655 .27028 .4306 .26329 .4289 Mtetra
.793 .926 .924 r
.26329 .4289 .27028 .4306 .28049 .42514 .27368 .4216 Mtetra
.79 .863 .904 r
.27368 .4216 .28049 .42514 .29068 .42035 .28408 .41434 Mtetra
.765 .782 .867 r
.28408 .41434 .29068 .42035 .30085 .41633 .29448 .40734 Mtetra
.728 .699 .822 r
.29448 .40734 .30085 .41633 .31099 .41319 .30487 .40079 Mtetra
.689 .625 .779 r
.30487 .40079 .31099 .41319 .3211 .4111 .31524 .39489 Mtetra
.652 .562 .74 r
.31524 .39489 .3211 .4111 .3312 .41014 .32558 .38978 Mtetra
.629 .515 .706 r
.32558 .38978 .3312 .41014 .3413 .41004 .33592 .38503 Mtetra
.612 .48 .677 r
.33592 .38503 .3413 .41004 .35143 .41055 .34629 .38045 Mtetra
.597 .451 .654 r
.34629 .38045 .35143 .41055 .36164 .41066 .35668 .3762 Mtetra
.584 .43 .638 r
.35668 .3762 .36164 .41066 .37196 .4099 .36707 .37247 Mtetra
.564 .409 .629 r
.36707 .37247 .37196 .4099 .38234 .40906 .37743 .37032 Mtetra
.542 .391 .625 r
.37743 .37032 .38234 .40906 .39276 .40859 .38776 .37012 Mtetra
.529 .383 .626 r
.38776 .37012 .39276 .40859 .4032 .40941 .3981 .37104 Mtetra
.524 .379 .626 r
.3981 .37104 .4032 .40941 .41366 .4117 .4085 .37245 Mtetra
.533 .384 .625 r
.4085 .37245 .41366 .4117 .42418 .41444 .419 .37308 Mtetra
.547 .39 .62 r
.419 .37308 .42418 .41444 .43479 .41685 .42961 .37231 Mtetra
.557 .392 .614 r
.42961 .37231 .43479 .41685 .44553 .41779 .44031 .37037 Mtetra
.564 .393 .608 r
.44031 .37037 .44553 .41779 .45638 .4166 .45109 .36735 Mtetra
.568 .394 .605 r
.45109 .36735 .45638 .4166 .46734 .41297 .46193 .36365 Mtetra
.573 .398 .606 r
.46193 .36365 .46734 .41297 .47837 .40689 .47283 .35928 Mtetra
.583 .407 .609 r
.47283 .35928 .47837 .40689 .48946 .39866 .48377 .35381 Mtetra
.595 .419 .614 r
.48377 .35381 .48946 .39866 .50057 .38893 .49477 .34716 Mtetra
.61 .435 .62 r
.49477 .34716 .50057 .38893 .51169 .37885 .50579 .3391 Mtetra
.62 .445 .624 r
.50579 .3391 .51169 .37885 .5228 .36919 .51683 .33023 Mtetra
.618 .445 .626 r
.51683 .33023 .5228 .36919 .53393 .36101 .52788 .32184 Mtetra
.608 .438 .626 r
.52788 .32184 .53393 .36101 .54507 .35412 .53895 .31457 Mtetra
.59 .425 .626 r
.53895 .31457 .54507 .35412 .55625 .34759 .55005 .30926 Mtetra
.577 .418 .63 r
.55005 .30926 .55625 .34759 .56745 .34097 .56121 .30556 Mtetra
.575 .424 .639 r
.56121 .30556 .56745 .34097 .57866 .33345 .57242 .30238 Mtetra
.577 .437 .655 r
.57242 .30238 .57866 .33345 .58988 .32551 .58369 .29953 Mtetra
.581 .46 .679 r
.58369 .29953 .58988 .32551 .60113 .31818 .59501 .29686 Mtetra
.583 .487 .712 r
.59501 .29686 .60113 .31818 .61242 .31172 .6064 .29457 Mtetra
.573 .517 .754 r
.6064 .29457 .61242 .31172 .62379 .30641 .61788 .29308 Mtetra
.557 .558 .811 r
.61788 .29308 .62379 .30641 .63522 .30215 .62944 .29226 Mtetra
.527 .613 .882 r
.62944 .29226 .63522 .30215 .64674 .29881 .64109 .29192 Mtetra
.47 .677 .955 r
.64109 .29192 .64674 .29881 .65834 .29626 .65282 .29185 Mtetra
.372 .724 .989 r
.65282 .29185 .65834 .29626 .67003 .2944 .66464 .29184 Mtetra
.255 .722 .946 r
.66464 .29184 .67003 .2944 .68182 .29305 .67653 .29171 Mtetra
.175 .699 .87 r
.67653 .29171 .68182 .29305 .69368 .29199 .68849 .29128 Mtetra
.155 .693 .827 r
.68849 .29128 .69368 .29199 .70563 .29104 .7005 .29044 Mtetra
.197 .724 .836 r
.7005 .29044 .70563 .29104 .71765 .28998 .71255 .28906 Mtetra
.278 .776 .881 r
.71255 .28906 .71765 .28998 .72972 .28871 .72464 .28716 Mtetra
.385 .83 .939 r
.72464 .28716 .72972 .28871 .74184 .28708 .73676 .28468 Mtetra
.484 .862 .981 r
.73676 .28468 .74184 .28708 .75401 .28511 .74891 .28171 Mtetra
.563 .866 .996 r
.74891 .28171 .75401 .28511 .76621 .28274 .76108 .2783 Mtetra
.612 .848 .988 r
.76108 .2783 .76621 .28274 .77846 .28008 .77329 .27455 Mtetra
.64 .818 .968 r
.77329 .27455 .77846 .28008 .79074 .27717 .78554 .27056 Mtetra
.653 .784 .944 r
.78554 .27056 .79074 .27717 .80308 .27409 .79782 .26643 Mtetra
.607 .738 .938 r
.14569 .47843 .15266 .48451 .1624 .48119 .15533 .47616 Mtetra
.599 .775 .964 r
.15533 .47616 .1624 .48119 .17218 .47775 .16501 .47384 Mtetra
.589 .816 .986 r
.16501 .47384 .17218 .47775 .18202 .47409 .17475 .47137 Mtetra
.572 .856 .996 r
.17475 .47137 .18202 .47409 .19193 .4701 .18456 .46867 Mtetra
.542 .888 .984 r
.18456 .46867 .19193 .4701 .20191 .46569 .19444 .46564 Mtetra
.494 .896 .933 r
.19444 .46564 .20191 .46569 .21197 .46081 .2044 .46219 Mtetra
.431 .873 .841 r
.2044 .46219 .21197 .46081 .22211 .45538 .21444 .45821 Mtetra
.356 .817 .719 r
.21444 .45821 .22211 .45538 .23231 .44943 .22458 .45365 Mtetra
0 0 0 r
.22458 .45365 .23231 .44943 .24259 .44295 .2348 .44845 Mtetra
.2348 .44845 .24259 .44295 .25292 .43608 .2451 .44263 Mtetra
.2451 .44263 .25292 .43608 .26329 .4289 .25547 .43619 Mtetra
.25547 .43619 .26329 .4289 .27368 .4216 .26591 .42926 Mtetra
.26591 .42926 .27368 .4216 .28408 .41434 .27639 .42195 Mtetra
.27639 .42195 .28408 .41434 .29448 .40734 .2869 .41446 Mtetra
.2869 .41446 .29448 .40734 .30487 .40079 .29742 .40694 Mtetra
.29742 .40694 .30487 .40079 .31524 .39489 .30796 .39954 Mtetra
.43 .828 .618 r
.30796 .39954 .31524 .39489 .32558 .38978 .31849 .39236 Mtetra
.609 .95 .801 r
.31849 .39236 .32558 .38978 .33592 .38503 .32904 .3852 Mtetra
.743 .98 .916 r
.32904 .3852 .33592 .38503 .34629 .38045 .3396 .37804 Mtetra
.761 .914 .942 r
.3396 .37804 .34629 .38045 .35668 .3762 .35015 .37158 Mtetra
.725 .832 .931 r
.35015 .37158 .35668 .3762 .36707 .37247 .36065 .36623 Mtetra
.67 .765 .921 r
.36065 .36623 .36707 .37247 .37743 .37032 .37112 .36232 Mtetra
.615 .692 .898 r
.37112 .36232 .37743 .37032 .38776 .37012 .38157 .3598 Mtetra
.614 .634 .847 r
.38157 .3598 .38776 .37012 .3981 .37104 .39206 .35726 Mtetra
.624 .579 .783 r
.39206 .35726 .3981 .37104 .4085 .37245 .40263 .35398 Mtetra
.628 .531 .726 r
.40263 .35398 .4085 .37245 .419 .37308 .41328 .34962 Mtetra
.626 .498 .687 r
.41328 .34962 .419 .37308 .42961 .37231 .424 .3442 Mtetra
.613 .469 .663 r
.424 .3442 .42961 .37231 .44031 .37037 .43475 .33878 Mtetra
.599 .449 .649 r
.43475 .33878 .44031 .37037 .45109 .36735 .44552 .33391 Mtetra
.584 .433 .643 r
.44552 .33391 .45109 .36735 .46193 .36365 .4563 .33016 Mtetra
.571 .424 .643 r
.4563 .33016 .46193 .36365 .47283 .35928 .4671 .32755 Mtetra
.566 .426 .65 r
.4671 .32755 .47283 .35928 .48377 .35381 .47795 .32548 Mtetra
.569 .441 .665 r
.47795 .32548 .48377 .35381 .49477 .34716 .48885 .32342 Mtetra
.592 .476 .691 r
.48885 .32342 .49477 .34716 .50579 .3391 .49981 .3203 Mtetra
.622 .528 .727 r
.49981 .3203 .50579 .3391 .51683 .33023 .51083 .31609 Mtetra
.656 .595 .775 r
.51083 .31609 .51683 .33023 .52788 .32184 .52189 .31113 Mtetra
.677 .661 .827 r
.52189 .31113 .52788 .32184 .53895 .31457 .53298 .30614 Mtetra
.647 .703 .888 r
.53298 .30614 .53895 .31457 .55005 .30926 .54412 .30256 Mtetra
.581 .732 .946 r
.54412 .30256 .55005 .30926 .56121 .30556 .55533 .30045 Mtetra
.482 .749 .988 r
.55533 .30045 .56121 .30556 .57242 .30238 .5666 .29946 Mtetra
.3 .738 .967 r
.5666 .29946 .57242 .30238 .58369 .29953 .57796 .2992 Mtetra
.06 .624 .761 r
.57796 .2992 .58369 .29953 .59501 .29686 .58939 .29895 Mtetra
.153 0 0 r
.58939 .29895 .59501 .29686 .6064 .29457 .60089 .29872 Mtetra
.287 0 0 r
.60089 .29872 .6064 .29457 .61788 .29308 .61248 .29873 Mtetra
.347 0 0 r
.61248 .29873 .61788 .29308 .62944 .29226 .62415 .29888 Mtetra
.371 0 0 r
.62415 .29888 .62944 .29226 .64109 .29192 .63589 .29902 Mtetra
.372 0 0 r
.63589 .29902 .64109 .29192 .65282 .29185 .64771 .29897 Mtetra
.355 0 0 r
.64771 .29897 .65282 .29185 .66464 .29184 .65959 .29854 Mtetra
.32 0 0 r
.65959 .29854 .66464 .29184 .67653 .29171 .67153 .29762 Mtetra
.259 0 0 r
.67153 .29762 .67653 .29171 .68849 .29128 .68351 .29606 Mtetra
.169 0 0 r
.68351 .29606 .68849 .29128 .7005 .29044 .69552 .29387 Mtetra
.034 0 0 r
.69552 .29387 .7005 .29044 .71255 .28906 .70756 .29101 Mtetra
0 0 0 r
.70756 .29101 .71255 .28906 .72464 .28716 .71962 .28755 Mtetra
.346 .824 .809 r
.71962 .28755 .72464 .28716 .73676 .28468 .73171 .28354 Mtetra
.512 .905 .933 r
.73171 .28354 .73676 .28468 .74891 .28171 .74381 .27909 Mtetra
.616 .915 .979 r
.74381 .27909 .74891 .28171 .76108 .2783 .75594 .27428 Mtetra
.668 .886 .978 r
.75594 .27428 .76108 .2783 .77329 .27455 .7681 .26922 Mtetra
.689 .845 .958 r
.7681 .26922 .77329 .27455 .78554 .27056 .78029 .264 Mtetra
.694 .804 .933 r
.78029 .264 .78554 .27056 .79782 .26643 .79252 .25872 Mtetra
.556 .722 .951 r
.13868 .4723 .14569 .47843 .15533 .47616 .14823 .4709 Mtetra
.538 .749 .973 r
.14823 .4709 .15533 .47616 .16501 .47384 .15782 .46953 Mtetra
.515 .778 .992 r
.15782 .46953 .16501 .47384 .17475 .47137 .16747 .46814 Mtetra
.48 .806 1 r
.16747 .46814 .17475 .47137 .18456 .46867 .17717 .46665 Mtetra
.424 .822 .982 r
.17717 .46665 .18456 .46867 .19444 .46564 .18694 .46503 Mtetra
.34 .81 .914 r
.18694 .46503 .19444 .46564 .2044 .46219 .19678 .46317 Mtetra
.228 .748 .778 r
.19678 .46317 .2044 .46219 .21444 .45821 .20669 .46097 Mtetra
0 0 0 r
.20669 .46097 .21444 .45821 .22458 .45365 .21669 .45834 Mtetra
.21669 .45834 .22458 .45365 .2348 .44845 .22679 .45517 Mtetra
.079 0 0 r
.22679 .45517 .2348 .44845 .2451 .44263 .23697 .45143 Mtetra
.134 0 0 r
.23697 .45143 .2451 .44263 .25547 .43619 .24725 .44704 Mtetra
.175 0 0 r
.24725 .44704 .25547 .43619 .26591 .42926 .2576 .44205 Mtetra
.203 0 .044 r
.2576 .44205 .26591 .42926 .27639 .42195 .26804 .43647 Mtetra
.225 0 .092 r
.26804 .43647 .27639 .42195 .2869 .41446 .27853 .4304 Mtetra
.24 0 .126 r
.27853 .4304 .2869 .41446 .29742 .40694 .28908 .42393 Mtetra
.246 0 .146 r
.28908 .42393 .29742 .40694 .30796 .39954 .29968 .41707 Mtetra
.245 0 .154 r
.29968 .41707 .30796 .39954 .31849 .39236 .31032 .40989 Mtetra
.24 0 .152 r
.31032 .40989 .31849 .39236 .32904 .3852 .32099 .40255 Mtetra
.239 0 .15 r
.32099 .40255 .32904 .3852 .3396 .37804 .33167 .39521 Mtetra
.265 0 .162 r
.33167 .39521 .3396 .37804 .35015 .37158 .34233 .38859 Mtetra
.3 0 .177 r
.34233 .38859 .35015 .37158 .36065 .36623 .35296 .38293 Mtetra
.303 0 .175 r
.35296 .38293 .36065 .36623 .37112 .36232 .3636 .37745 Mtetra
.264 0 .131 r
.3636 .37745 .37112 .36232 .38157 .3598 .3743 .37162 Mtetra
.104 0 0 r
.3743 .37162 .38157 .3598 .39206 .35726 .38508 .36444 Mtetra
0 0 0 r
.38508 .36444 .39206 .35726 .40263 .35398 .39594 .35566 Mtetra
.772 .997 .84 r
.39594 .35566 .40263 .35398 .41328 .34962 .40683 .34629 Mtetra
.833 .888 .882 r
.40683 .34629 .41328 .34962 .424 .3442 .41772 .33705 Mtetra
.773 .768 .848 r
.41772 .33705 .424 .3442 .43475 .33878 .42858 .32912 Mtetra
.709 .691 .83 r
.42858 .32912 .43475 .33878 .44552 .33391 .4394 .32312 Mtetra
.647 .643 .832 r
.4394 .32312 .44552 .33391 .4563 .33016 .45019 .31935 Mtetra
.578 .611 .849 r
.45019 .31935 .4563 .33016 .4671 .32755 .46099 .31779 Mtetra
.492 .594 .884 r
.46099 .31779 .4671 .32755 .47795 .32548 .4718 .31819 Mtetra
.357 .6 .939 r
.4718 .31819 .47795 .32548 .48885 .32342 .48267 .31991 Mtetra
.109 .594 .909 r
.48267 .31991 .48885 .32342 .49981 .3203 .49363 .32179 Mtetra
.255 0 0 r
.49363 .32179 .49981 .3203 .51083 .31609 .50467 .32309 Mtetra
.358 0 0 r
.50467 .32309 .51083 .31609 .52189 .31113 .51579 .32279 Mtetra
.38 0 .12 r
.51579 .32279 .52189 .31113 .53298 .30614 .52699 .32113 Mtetra
.405 .023 .197 r
.52699 .32113 .53298 .30614 .54412 .30256 .53825 .31912 Mtetra
.423 .052 .227 r
.53825 .31912 .54412 .30256 .55533 .30045 .54957 .3173 Mtetra
.449 .078 .241 r
.54957 .3173 .55533 .30045 .5666 .29946 .56096 .31647 Mtetra
.466 .094 .249 r
.56096 .31647 .5666 .29946 .57796 .2992 .57243 .31636 Mtetra
.467 .096 .25 r
.57243 .31636 .57796 .2992 .58939 .29895 .58398 .31629 Mtetra
.464 .094 .251 r
.58398 .31629 .58939 .29895 .60089 .29872 .5956 .31605 Mtetra
.457 .087 .248 r
.5956 .31605 .60089 .29872 .61248 .29873 .60728 .3155 Mtetra
.445 .072 .236 r
.60728 .3155 .61248 .29873 .62415 .29888 .61903 .31456 Mtetra
.429 .048 .213 r
.61903 .31456 .62415 .29888 .63589 .29902 .63084 .31321 Mtetra
.404 .012 .179 r
.63084 .31321 .63589 .29902 .64771 .29897 .6427 .31136 Mtetra
.365 0 .126 r
.6427 .31136 .64771 .29897 .65959 .29854 .65461 .30891 Mtetra
.308 0 .05 r
.65461 .30891 .65959 .29854 .67153 .29762 .66654 .30584 Mtetra
.22 0 0 r
.66654 .30584 .67153 .29762 .68351 .29606 .67851 .30211 Mtetra
.09 0 0 r
.67851 .30211 .68351 .29606 .69552 .29387 .69049 .29777 Mtetra
0 0 0 r
.69049 .29777 .69552 .29387 .70756 .29101 .7025 .29288 Mtetra
.325 .794 .689 r
.7025 .29288 .70756 .29101 .71962 .28755 .71452 .28752 Mtetra
.525 .92 .87 r
.71452 .28752 .71962 .28755 .73171 .28354 .72656 .28181 Mtetra
.647 .949 .951 r
.72656 .28181 .73171 .28354 .74381 .27909 .73862 .27583 Mtetra
.702 .924 .966 r
.73862 .27583 .74381 .27909 .75594 .27428 .75071 .2697 Mtetra
.723 .884 .955 r
.75071 .2697 .75594 .27428 .7681 .26922 .76283 .26347 Mtetra
.727 .844 .936 r
.76283 .26347 .7681 .26922 .78029 .264 .77499 .2572 Mtetra
.724 .808 .917 r
.77499 .2572 .78029 .264 .79252 .25872 .78718 .25095 Mtetra
.538 .715 .954 r
.13161 .46613 .13868 .4723 .14823 .4709 .14114 .465 Mtetra
.527 .721 .962 r
.14114 .465 .14823 .4709 .15782 .46953 .15072 .46395 Mtetra
.514 .729 .971 r
.15072 .46395 .15782 .46953 .16747 .46814 .16033 .46297 Mtetra
.498 .74 .981 r
.16033 .46297 .16747 .46814 .17717 .46665 .16999 .46205 Mtetra
.474 .753 .991 r
.16999 .46205 .17717 .46665 .18694 .46503 .1797 .46119 Mtetra
.444 .77 .997 r
.1797 .46119 .18694 .46503 .19678 .46317 .18946 .4603 Mtetra
.399 .785 .99 r
.18946 .4603 .19678 .46317 .20669 .46097 .19928 .45932 Mtetra
.33 .786 .949 r
.19928 .45932 .20669 .46097 .21669 .45834 .20918 .45815 Mtetra
.232 .749 .848 r
.20918 .45815 .21669 .45834 .22679 .45517 .21915 .45671 Mtetra
0 0 0 r
.21915 .45671 .22679 .45517 .23697 .45143 .2292 .45489 Mtetra
.008 0 0 r
.2292 .45489 .23697 .45143 .24725 .44704 .23935 .45262 Mtetra
.106 0 0 r
.23935 .45262 .24725 .44704 .2576 .44205 .24958 .44986 Mtetra
.173 0 0 r
.24958 .44986 .2576 .44205 .26804 .43647 .2599 .44655 Mtetra
.222 0 0 r
.2599 .44655 .26804 .43647 .27853 .4304 .2703 .44271 Mtetra
.254 0 .058 r
.2703 .44271 .27853 .4304 .28908 .42393 .28078 .43834 Mtetra
.276 0 .114 r
.28078 .43834 .28908 .42393 .29968 .41707 .29133 .43344 Mtetra
.291 0 .155 r
.29133 .43344 .29968 .41707 .31032 .40989 .30195 .42804 Mtetra
.311 0 .191 r
.30195 .42804 .31032 .40989 .32099 .40255 .31262 .42245 Mtetra
.335 0 .223 r
.31262 .42245 .32099 .40255 .33167 .39521 .3233 .4169 Mtetra
.362 .025 .253 r
.3233 .4169 .33167 .39521 .34233 .38859 .334 .41166 Mtetra
.382 .05 .274 r
.334 .41166 .34233 .38859 .35296 .38293 .34471 .40676 Mtetra
.37 .044 .275 r
.34471 .40676 .35296 .38293 .3636 .37745 .35549 .40113 Mtetra
.34 .016 .262 r
.35549 .40113 .3636 .37745 .3743 .37162 .36637 .39429 Mtetra
.297 0 .235 r
.36637 .39429 .3743 .37162 .38508 .36444 .37732 .38621 Mtetra
.258 0 .211 r
.37732 .38621 .38508 .36444 .39594 .35566 .38832 .37713 Mtetra
.265 0 .212 r
.38832 .37713 .39594 .35566 .40683 .34629 .39932 .36837 Mtetra
.303 0 .235 r
.39932 .36837 .40683 .34629 .41772 .33705 .4103 .3606 Mtetra
.352 .028 .269 r
.4103 .3606 .41772 .33705 .42858 .32912 .42124 .35413 Mtetra
.396 .073 .297 r
.42124 .35413 .42858 .32912 .4394 .32312 .43217 .34912 Mtetra
.425 .104 .314 r
.43217 .34912 .4394 .32312 .45019 .31935 .44311 .34534 Mtetra
.448 .124 .322 r
.44311 .34534 .45019 .31935 .46099 .31779 .45405 .3428 Mtetra
.47 .14 .324 r
.45405 .3428 .46099 .31779 .4718 .31819 .46503 .34173 Mtetra
.489 .151 .32 r
.46503 .34173 .4718 .31819 .48267 .31991 .47605 .34197 Mtetra
.504 .158 .313 r
.47605 .34197 .48267 .31991 .49363 .32179 .48713 .34322 Mtetra
.509 .159 .309 r
.48713 .34322 .49363 .32179 .50467 .32309 .49828 .34481 Mtetra
.492 .144 .305 r
.49828 .34481 .50467 .32309 .51579 .32279 .50953 .34542 Mtetra
.472 .13 .305 r
.50953 .34542 .51579 .32279 .52699 .32113 .52086 .34478 Mtetra
.453 .117 .306 r
.52086 .34478 .52699 .32113 .53825 .31912 .53225 .34291 Mtetra
.44 .106 .302 r
.53225 .34291 .53825 .31912 .54957 .3173 .54371 .34032 Mtetra
.444 .106 .297 r
.54371 .34032 .54957 .3173 .56096 .31647 .55522 .33807 Mtetra
.444 .099 .285 r
.55522 .33807 .56096 .31647 .57243 .31636 .5668 .33615 Mtetra
.437 .083 .265 r
.5668 .33615 .57243 .31636 .58398 .31629 .57844 .33427 Mtetra
.423 .059 .239 r
.57844 .33427 .58398 .31629 .5956 .31605 .59014 .3322 Mtetra
.397 .021 .204 r
.59014 .3322 .5956 .31605 .60728 .3155 .60189 .32962 Mtetra
.361 0 .156 r
.60189 .32962 .60728 .3155 .61903 .31456 .61369 .3265 Mtetra
.31 0 .088 r
.61369 .3265 .61903 .31456 .63084 .31321 .62553 .32284 Mtetra
.233 0 0 r
.62553 .32284 .63084 .31321 .6427 .31136 .6374 .31862 Mtetra
.113 0 0 r
.6374 .31862 .6427 .31136 .65461 .30891 .6493 .31385 Mtetra
0 0 0 r
.6493 .31385 .65461 .30891 .66654 .30584 .66122 .30855 Mtetra
.66122 .30855 .66654 .30584 .67851 .30211 .67316 .30278 Mtetra
.514 .913 .828 r
.67316 .30278 .67851 .30211 .69049 .29777 .68513 .29661 Mtetra
.654 .96 .931 r
.68513 .29661 .69049 .29777 .7025 .29288 .69711 .29014 Mtetra
.718 .942 .957 r
.69711 .29014 .7025 .29288 .71452 .28752 .70911 .28346 Mtetra
.741 .904 .951 r
.70911 .28346 .71452 .28752 .72656 .28181 .72114 .27668 Mtetra
.746 .869 .937 r
.72114 .27668 .72656 .28181 .73862 .27583 .73319 .26986 Mtetra
.743 .84 .924 r
.73319 .26986 .73862 .27583 .75071 .2697 .74529 .26309 Mtetra
.739 .818 .913 r
.74529 .26309 .75071 .2697 .76283 .26347 .75742 .25636 Mtetra
.735 .802 .905 r
.75742 .25636 .76283 .26347 .77499 .2572 .76959 .2497 Mtetra
.73 .789 .9 r
.76959 .2497 .77499 .2572 .78718 .25095 .7818 .24311 Mtetra
.558 .722 .95 r
.12449 .45992 .13161 .46613 .14114 .465 .13408 .45845 Mtetra
.554 .71 .944 r
.13408 .45845 .14114 .465 .15072 .46395 .1437 .45709 Mtetra
.549 .698 .938 r
.1437 .45709 .15072 .46395 .16033 .46297 .15335 .45588 Mtetra
.541 .688 .935 r
.15335 .45588 .16033 .46297 .16999 .46205 .16304 .45483 Mtetra
.529 .68 .934 r
.16304 .45483 .16999 .46205 .1797 .46119 .17275 .454 Mtetra
.518 .677 .937 r
.17275 .454 .1797 .46119 .18946 .4603 .1825 .45333 Mtetra
.504 .68 .945 r
.1825 .45333 .18946 .4603 .19928 .45932 .19229 .45282 Mtetra
.489 .69 .957 r
.19229 .45282 .19928 .45932 .20918 .45815 .20212 .45238 Mtetra
.468 .71 .974 r
.20212 .45238 .20918 .45815 .21915 .45671 .21202 .45196 Mtetra
.439 .737 .99 r
.21202 .45196 .21915 .45671 .2292 .45489 .22197 .45147 Mtetra
.389 .764 .992 r
.22197 .45147 .2292 .45489 .23935 .45262 .232 .4508 Mtetra
.303 .768 .944 r
.232 .4508 .23935 .45262 .24958 .44986 .24211 .44989 Mtetra
.176 .711 .807 r
.24211 .44989 .24958 .44986 .2599 .44655 .2523 .44863 Mtetra
0 0 0 r
.2523 .44863 .2599 .44655 .2703 .44271 .26257 .44699 Mtetra
.095 0 0 r
.26257 .44699 .2703 .44271 .28078 .43834 .27293 .44492 Mtetra
.185 0 0 r
.27293 .44492 .28078 .43834 .29133 .43344 .28338 .44244 Mtetra
.248 0 0 r
.28338 .44244 .29133 .43344 .30195 .42804 .29389 .43957 Mtetra
.306 0 .065 r
.29389 .43957 .30195 .42804 .31262 .42245 .30446 .43659 Mtetra
.35 0 .145 r
.30446 .43659 .31262 .42245 .3233 .4169 .31508 .43363 Mtetra
.373 .001 .198 r
.31508 .43363 .3233 .4169 .334 .41166 .32575 .43044 Mtetra
.379 .021 .226 r
.32575 .43044 .334 .41166 .34471 .40676 .3365 .42682 Mtetra
.359 .011 .232 r
.3365 .42682 .34471 .40676 .35549 .40113 .34735 .42209 Mtetra
.333 0 .229 r
.34735 .42209 .35549 .40113 .36637 .39429 .3583 .41612 Mtetra
.337 .002 .24 r
.3583 .41612 .36637 .39429 .37732 .38621 .36929 .40995 Mtetra
.365 .036 .268 r
.36929 .40995 .37732 .38621 .38832 .37713 .38028 .40418 Mtetra
.411 .091 .31 r
.38028 .40418 .38832 .37713 .39932 .36837 .39126 .39961 Mtetra
.449 .138 .346 r
.39126 .39961 .39932 .36837 .4103 .3606 .40222 .3964 Mtetra
.464 .163 .369 r
.40222 .3964 .4103 .3606 .42124 .35413 .41322 .3936 Mtetra
.469 .174 .382 r
.41322 .3936 .42124 .35413 .43217 .34912 .42427 .39069 Mtetra
.463 .172 .386 r
.42427 .39069 .43217 .34912 .44311 .34534 .4354 .38692 Mtetra
.453 .164 .383 r
.4354 .38692 .44311 .34534 .45405 .3428 .44659 .3823 Mtetra
.448 .156 .375 r
.44659 .3823 .45405 .3428 .46503 .34173 .45783 .37757 Mtetra
.445 .146 .363 r
.45783 .37757 .46503 .34173 .47605 .34197 .46909 .37324 Mtetra
.453 .142 .347 r
.46909 .37324 .47605 .34197 .48713 .34322 .48039 .37028 Mtetra
.462 .136 .328 r
.48039 .37028 .48713 .34322 .49828 .34481 .49172 .36853 Mtetra
.46 .121 .305 r
.49172 .36853 .49828 .34481 .50953 .34542 .50311 .3672 Mtetra
.449 .103 .285 r
.50311 .3672 .50953 .34542 .52086 .34478 .51457 .36568 Mtetra
.42 .071 .266 r
.51457 .36568 .52086 .34478 .53225 .34291 .52609 .36289 Mtetra
.389 .039 .245 r
.52609 .36289 .53225 .34291 .54371 .34032 .53766 .35899 Mtetra
.368 .012 .222 r
.53766 .35899 .54371 .34032 .55522 .33807 .54928 .35464 Mtetra
.34 0 .183 r
.54928 .35464 .55522 .33807 .5668 .33615 .56095 .35005 Mtetra
.304 0 .122 r
.56095 .35005 .5668 .33615 .57844 .33427 .57266 .34549 Mtetra
.245 0 .034 r
.57266 .34549 .57844 .33427 .59014 .3322 .58441 .34081 Mtetra
.141 0 0 r
.58441 .34081 .59014 .3322 .60189 .32962 .5962 .33572 Mtetra
0 0 0 r
.5962 .33572 .60189 .32962 .61369 .3265 .60802 .3302 Mtetra
.60802 .3302 .61369 .3265 .62553 .32284 .61986 .32423 Mtetra
.486 .895 .784 r
.61986 .32423 .62553 .32284 .6374 .31862 .63173 .31786 Mtetra
.66 .965 .92 r
.63173 .31786 .6374 .31862 .6493 .31385 .64362 .31112 Mtetra
.737 .942 .951 r
.64362 .31112 .6493 .31385 .66122 .30855 .65552 .30412 Mtetra
.759 .891 .937 r
.65552 .30412 .66122 .30855 .67316 .30278 .66745 .29692 Mtetra
.76 .843 .914 r
.66745 .29692 .67316 .30278 .68513 .29661 .67941 .28964 Mtetra
.754 .807 .895 r
.67941 .28964 .68513 .29661 .69711 .29014 .69139 .28235 Mtetra
.746 .781 .881 r
.69139 .28235 .69711 .29014 .70911 .28346 .7034 .27513 Mtetra
.738 .764 .874 r
.7034 .27513 .70911 .28346 .72114 .27668 .71545 .26806 Mtetra
.732 .755 .871 r
.71545 .26806 .72114 .27668 .73319 .26986 .72754 .26115 Mtetra
.726 .752 .873 r
.72754 .26115 .73319 .26986 .74529 .26309 .73968 .25445 Mtetra
.722 .753 .877 r
.73968 .25445 .74529 .26309 .75742 .25636 .75186 .24791 Mtetra
.719 .758 .883 r
.75186 .24791 .75742 .25636 .76959 .2497 .76409 .24151 Mtetra
.717 .766 .891 r
.76409 .24151 .76959 .2497 .7818 .24311 .77637 .23521 Mtetra
.611 .739 .937 r
.11732 .45366 .12449 .45992 .13408 .45845 .12704 .45124 Mtetra
.609 .708 .915 r
.12704 .45124 .13408 .45845 .1437 .45709 .13679 .44891 Mtetra
.604 .678 .894 r
.13679 .44891 .1437 .45709 .15335 .45588 .14656 .44674 Mtetra
.596 .65 .875 r
.14656 .44674 .15335 .45588 .16304 .45483 .15635 .44478 Mtetra
.585 .625 .858 r
.15635 .44478 .16304 .45483 .17275 .454 .16616 .44309 Mtetra
.575 .602 .843 r
.16616 .44309 .17275 .454 .1825 .45333 .17599 .44167 Mtetra
.564 .583 .83 r
.17599 .44167 .1825 .45333 .19229 .45282 .18584 .44055 Mtetra
.556 .568 .821 r
.18584 .44055 .19229 .45282 .20212 .45238 .19572 .43967 Mtetra
.548 .557 .815 r
.19572 .43967 .20212 .45238 .21202 .45196 .20563 .43901 Mtetra
.544 .551 .812 r
.20563 .43901 .21202 .45196 .22197 .45147 .21558 .43849 Mtetra
.541 .549 .813 r
.21558 .43849 .22197 .45147 .232 .4508 .22558 .43805 Mtetra
.541 .554 .817 r
.22558 .43805 .232 .4508 .24211 .44989 .23564 .4376 Mtetra
.543 .564 .826 r
.23564 .4376 .24211 .44989 .2523 .44863 .24577 .43704 Mtetra
.547 .58 .839 r
.24577 .43704 .2523 .44863 .26257 .44699 .25597 .43631 Mtetra
.553 .603 .858 r
.25597 .43631 .26257 .44699 .27293 .44492 .26625 .43536 Mtetra
.558 .633 .882 r
.26625 .43536 .27293 .44492 .28338 .44244 .27661 .4342 Mtetra
.56 .671 .912 r
.27661 .4342 .28338 .44244 .29389 .43957 .28703 .43282 Mtetra
.55 .716 .949 r
.28703 .43282 .29389 .43957 .30446 .43659 .29752 .43135 Mtetra
.526 .762 .983 r
.29752 .43135 .30446 .43659 .31508 .43363 .30807 .42983 Mtetra
.52 .814 .999 r
.30807 .42983 .31508 .43363 .32575 .43044 .3187 .4278 Mtetra
.53 .859 .996 r
.3187 .4278 .32575 .43044 .3365 .42682 .32943 .42507 Mtetra
.55 .893 .982 r
.32943 .42507 .3365 .42682 .34735 .42209 .34025 .42158 Mtetra
.525 .908 .942 r
.34025 .42158 .34735 .42209 .3583 .41612 .35115 .41753 Mtetra
.283 .782 .764 r
.35115 .41753 .3583 .41612 .36929 .40995 .36205 .4142 Mtetra
.102 0 0 r
.36205 .4142 .36929 .40995 .38028 .40418 .37295 .41212 Mtetra
.339 0 0 r
.37295 .41212 .38028 .40418 .39126 .39961 .38384 .41127 Mtetra
.43 .007 .132 r
.38384 .41127 .39126 .39961 .40222 .3964 .39476 .4113 Mtetra
.438 .046 .197 r
.39476 .4113 .40222 .3964 .41322 .3936 .40577 .41082 Mtetra
.417 .044 .22 r
.40577 .41082 .41322 .3936 .42427 .39069 .41689 .40904 Mtetra
.371 .009 .214 r
.41689 .40904 .42427 .39069 .4354 .38692 .42813 .40527 Mtetra
.313 0 .189 r
.42813 .40527 .4354 .38692 .44659 .3823 .43948 .3995 Mtetra
.253 0 .147 r
.43948 .3995 .44659 .3823 .45783 .37757 .45088 .39242 Mtetra
.185 0 .078 r
.45088 .39242 .45783 .37757 .46909 .37324 .46232 .38481 Mtetra
.132 0 0 r
.46232 .38481 .46909 .37324 .48039 .37028 .47376 .37808 Mtetra
.048 0 0 r
.47376 .37808 .48039 .37028 .49172 .36853 .48522 .37257 Mtetra
0 0 0 r
.48522 .37257 .49172 .36853 .50311 .3672 .49671 .36834 Mtetra
.285 .783 .767 r
.49671 .36834 .50311 .3672 .51457 .36568 .50823 .36482 Mtetra
.505 .9 .939 r
.50823 .36482 .51457 .36568 .52609 .36289 .51981 .36073 Mtetra
.627 .92 .977 r
.51981 .36073 .52609 .36289 .53766 .35899 .53143 .35587 Mtetra
.692 .91 .971 r
.53143 .35587 .53766 .35899 .54928 .35464 .54309 .35029 Mtetra
.726 .876 .951 r
.54309 .35029 .54928 .35464 .56095 .35005 .55479 .34419 Mtetra
.73 .826 .925 r
.55479 .34419 .56095 .35005 .57266 .34549 .56651 .33802 Mtetra
.725 .775 .893 r
.56651 .33802 .57266 .34549 .58441 .34081 .57827 .33175 Mtetra
.72 .732 .86 r
.57827 .33175 .58441 .34081 .5962 .33572 .59006 .32525 Mtetra
.714 .698 .833 r
.59006 .32525 .5962 .33572 .60802 .3302 .60188 .31851 Mtetra
.709 .673 .813 r
.60188 .31851 .60802 .3302 .61986 .32423 .61372 .31154 Mtetra
.705 .655 .797 r
.61372 .31154 .61986 .32423 .63173 .31786 .62558 .30438 Mtetra
.701 .641 .786 r
.62558 .30438 .63173 .31786 .64362 .31112 .63746 .2971 Mtetra
.698 .632 .78 r
.63746 .2971 .64362 .31112 .65552 .30412 .64937 .28979 Mtetra
.694 .627 .777 r
.64937 .28979 .65552 .30412 .66745 .29692 .66132 .28255 Mtetra
.692 .625 .777 r
.66132 .28255 .66745 .29692 .67941 .28964 .67329 .27544 Mtetra
.689 .627 .781 r
.67329 .27544 .67941 .28964 .69139 .28235 .68531 .26855 Mtetra
.687 .632 .789 r
.68531 .26855 .69139 .28235 .7034 .27513 .69737 .2619 Mtetra
.685 .64 .799 r
.69737 .2619 .7034 .27513 .71545 .26806 .70949 .25554 Mtetra
.684 .652 .812 r
.70949 .25554 .71545 .26806 .72754 .26115 .72166 .24945 Mtetra
.683 .667 .828 r
.72166 .24945 .72754 .26115 .73968 .25445 .73388 .24365 Mtetra
.683 .686 .847 r
.73388 .24365 .73968 .25445 .75186 .24791 .74617 .23805 Mtetra
.685 .709 .867 r
.74617 .23805 .75186 .24791 .76409 .24151 .75851 .2326 Mtetra
.686 .736 .888 r
.75851 .2326 .76409 .24151 .77637 .23521 .7709 .22725 Mtetra
.667 .754 .915 r
.1101 .44736 .11732 .45366 .12704 .45124 .12 .44364 Mtetra
.661 .714 .888 r
.12 .44364 .12704 .45124 .13679 .44891 .12992 .43999 Mtetra
.652 .677 .862 r
.12992 .43999 .13679 .44891 .14656 .44674 .13986 .43647 Mtetra
.64 .643 .838 r
.13986 .43647 .14656 .44674 .15635 .44478 .14981 .43314 Mtetra
.627 .612 .816 r
.14981 .43314 .15635 .44478 .16616 .44309 .15978 .43008 Mtetra
.614 .583 .796 r
.15978 .43008 .16616 .44309 .17599 .44167 .16975 .4273 Mtetra
.6 .558 .778 r
.16975 .4273 .17599 .44167 .18584 .44055 .17973 .42486 Mtetra
.589 .536 .763 r
.17973 .42486 .18584 .44055 .19572 .43967 .18972 .42275 Mtetra
.578 .516 .749 r
.18972 .42275 .19572 .43967 .20563 .43901 .19972 .42096 Mtetra
.57 .501 .738 r
.19972 .42096 .20563 .43901 .21558 .43849 .20975 .41946 Mtetra
.563 .488 .729 r
.20975 .41946 .21558 .43849 .22558 .43805 .2198 .4182 Mtetra
.558 .479 .722 r
.2198 .4182 .22558 .43805 .23564 .4376 .2299 .4171 Mtetra
.555 .473 .717 r
.2299 .4171 .23564 .4376 .24577 .43704 .24004 .41611 Mtetra
.554 .469 .713 r
.24004 .41611 .24577 .43704 .25597 .43631 .25023 .41517 Mtetra
.553 .467 .712 r
.25023 .41517 .25597 .43631 .26625 .43536 .26048 .41423 Mtetra
.554 .468 .713 r
.26048 .41423 .26625 .43536 .27661 .4342 .27078 .41328 Mtetra
.555 .471 .715 r
.27078 .41328 .27661 .4342 .28703 .43282 .28115 .41228 Mtetra
.557 .475 .719 r
.28115 .41228 .28703 .43282 .29752 .43135 .29159 .41119 Mtetra
.561 .481 .722 r
.29159 .41119 .29752 .43135 .30807 .42983 .30209 .40993 Mtetra
.572 .49 .724 r
.30209 .40993 .30807 .42983 .3187 .4278 .31269 .40815 Mtetra
.584 .5 .726 r
.31269 .40815 .3187 .4278 .32943 .42507 .32338 .40576 Mtetra
.586 .505 .73 r
.32338 .40576 .32943 .42507 .34025 .42158 .33413 .40332 Mtetra
.581 .511 .742 r
.33413 .40332 .34025 .42158 .35115 .41753 .3449 .40123 Mtetra
.553 .516 .769 r
.3449 .40123 .35115 .41753 .36205 .4142 .35567 .40039 Mtetra
.501 .523 .811 r
.35567 .40039 .36205 .4142 .37295 .41212 .36642 .40104 Mtetra
.452 .551 .866 r
.36642 .40104 .37295 .41212 .38384 .41127 .37723 .40233 Mtetra
.416 .59 .914 r
.37723 .40233 .38384 .41127 .39476 .4113 .38811 .40361 Mtetra
.463 .654 .943 r
.38811 .40361 .39476 .4113 .40577 .41082 .39911 .40372 Mtetra
.557 .717 .947 r
.39911 .40372 .40577 .41082 .41689 .40904 .41025 .40202 Mtetra
.651 .756 .926 r
.41025 .40202 .41689 .40904 .42813 .40527 .42153 .39822 Mtetra
.72 .776 .896 r
.42153 .39822 .42813 .40527 .43948 .3995 .4329 .39232 Mtetra
.764 .782 .868 r
.4329 .39232 .43948 .3995 .45088 .39242 .44436 .38458 Mtetra
.782 .769 .841 r
.44436 .38458 .45088 .39242 .46232 .38481 .45586 .37566 Mtetra
.769 .736 .822 r
.45586 .37566 .46232 .38481 .47376 .37808 .46738 .3667 Mtetra
.737 .683 .799 r
.46738 .3667 .47376 .37808 .48522 .37257 .4789 .35838 Mtetra
.689 .62 .774 r
.4789 .35838 .48522 .37257 .49671 .36834 .49041 .35155 Mtetra
.652 .571 .751 r
.49041 .35155 .49671 .36834 .50823 .36482 .50195 .34597 Mtetra
.636 .543 .733 r
.50195 .34597 .50823 .36482 .51981 .36073 .51352 .34074 Mtetra
.632 .532 .723 r
.51352 .34074 .51981 .36073 .53143 .35587 .52513 .33545 Mtetra
.64 .533 .718 r
.52513 .33545 .53143 .35587 .54309 .35029 .53678 .32953 Mtetra
.646 .535 .714 r
.53678 .32953 .54309 .35029 .55479 .34419 .54846 .32307 Mtetra
.647 .533 .711 r
.54846 .32307 .55479 .34419 .56651 .33802 .56016 .31644 Mtetra
.646 .53 .707 r
.56016 .31644 .56651 .33802 .57827 .33175 .5719 .3097 Mtetra
.645 .526 .704 r
.5719 .3097 .57827 .33175 .59006 .32525 .58367 .3029 Mtetra
.644 .524 .702 r
.58367 .3029 .59006 .32525 .60188 .31851 .59546 .29608 Mtetra
.644 .523 .701 r
.59546 .29608 .60188 .31851 .61372 .31154 .60729 .28924 Mtetra
.644 .524 .703 r
.60729 .28924 .61372 .31154 .62558 .30438 .61915 .28244 Mtetra
.644 .527 .706 r
.61915 .28244 .62558 .30438 .63746 .2971 .63104 .27574 Mtetra
.644 .531 .711 r
.63104 .27574 .63746 .2971 .64937 .28979 .64297 .2692 Mtetra
.643 .536 .718 r
.64297 .2692 .64937 .28979 .66132 .28255 .65494 .2629 Mtetra
.643 .544 .727 r
.65494 .2629 .66132 .28255 .67329 .27544 .66696 .25688 Mtetra
.643 .553 .738 r
.66696 .25688 .67329 .27544 .68531 .26855 .67904 .2512 Mtetra
.642 .565 .753 r
.67904 .2512 .68531 .26855 .69737 .2619 .69117 .24584 Mtetra
.642 .58 .769 r
.69117 .24584 .69737 .2619 .70949 .25554 .70338 .24082 Mtetra
.642 .597 .789 r
.70338 .24082 .70949 .25554 .72166 .24945 .71564 .2361 Mtetra
.642 .619 .811 r
.71564 .2361 .72166 .24945 .73388 .24365 .72798 .23166 Mtetra
.643 .644 .836 r
.72798 .23166 .73388 .24365 .74617 .23805 .74038 .2274 Mtetra
.644 .674 .864 r
.74038 .2274 .74617 .23805 .75851 .2326 .75285 .22328 Mtetra
.644 .708 .893 r
.75285 .22328 .75851 .2326 .7709 .22725 .76539 .21923 Mtetra
.71 .762 .893 r
.10283 .44102 .1101 .44736 .12 .44364 .1129 .43602 Mtetra
.702 .725 .868 r
.1129 .43602 .12 .44364 .12992 .43999 .123 .43104 Mtetra
.691 .69 .845 r
.123 .43104 .12992 .43999 .13986 .43647 .13312 .42615 Mtetra
.678 .658 .823 r
.13312 .42615 .13986 .43647 .14981 .43314 .14325 .42139 Mtetra
.664 .627 .802 r
.14325 .42139 .14981 .43314 .15978 .43008 .15339 .41682 Mtetra
.65 .598 .783 r
.15339 .41682 .15978 .43008 .16975 .4273 .16353 .4125 Mtetra
.636 .571 .765 r
.16353 .4125 .16975 .4273 .17973 .42486 .17368 .40848 Mtetra
.622 .547 .748 r
.17368 .40848 .17973 .42486 .18972 .42275 .18382 .40475 Mtetra
.61 .524 .733 r
.18382 .40475 .18972 .42275 .19972 .42096 .19397 .40137 Mtetra
.599 .505 .719 r
.19397 .40137 .19972 .42096 .20975 .41946 .20413 .39829 Mtetra
.589 .488 .707 r
.20413 .39829 .20975 .41946 .2198 .4182 .2143 .39552 Mtetra
.581 .473 .696 r
.2143 .39552 .2198 .4182 .2299 .4171 .2245 .39299 Mtetra
.575 .461 .687 r
.2245 .39299 .2299 .4171 .24004 .41611 .23472 .39068 Mtetra
.57 .451 .679 r
.23472 .39068 .24004 .41611 .25023 .41517 .24497 .38853 Mtetra
.566 .444 .672 r
.24497 .38853 .25023 .41517 .26048 .41423 .25527 .38651 Mtetra
.563 .437 .667 r
.25527 .38651 .26048 .41423 .27078 .41328 .2656 .38456 Mtetra
.562 .433 .662 r
.2656 .38456 .27078 .41328 .28115 .41228 .27599 .38264 Mtetra
.562 .429 .658 r
.27599 .38264 .28115 .41228 .29159 .41119 .28644 .38062 Mtetra
.563 .427 .654 r
.28644 .38062 .29159 .41119 .30209 .40993 .29696 .37841 Mtetra
.567 .427 .65 r
.29696 .37841 .30209 .40993 .31269 .40815 .30754 .37587 Mtetra
.57 .427 .647 r
.30754 .37587 .31269 .40815 .32338 .40576 .3182 .37301 Mtetra
.564 .422 .646 r
.3182 .37301 .32338 .40576 .33413 .40332 .32889 .37051 Mtetra
.555 .415 .646 r
.32889 .37051 .33413 .40332 .3449 .40123 .33958 .36876 Mtetra
.542 .407 .647 r
.33958 .36876 .3449 .40123 .35567 .40039 .35028 .36799 Mtetra
.529 .399 .648 r
.35028 .36799 .35567 .40039 .36642 .40104 .36099 .36814 Mtetra
.531 .399 .646 r
.36099 .36814 .36642 .40104 .37723 .40233 .37178 .36818 Mtetra
.539 .401 .642 r
.37178 .36818 .37723 .40233 .38811 .40361 .38267 .36754 Mtetra
.551 .404 .635 r
.38267 .36754 .38811 .40361 .39911 .40372 .39367 .36588 Mtetra
.563 .409 .63 r
.39367 .36588 .39911 .40372 .41025 .40202 .40477 .36301 Mtetra
.572 .412 .627 r
.40477 .36301 .41025 .40202 .42153 .39822 .41596 .35915 Mtetra
.581 .419 .627 r
.41596 .35915 .42153 .39822 .4329 .39232 .42723 .3543 Mtetra
.595 .431 .63 r
.42723 .3543 .4329 .39232 .44436 .38458 .43857 .34824 Mtetra
.607 .444 .634 r
.43857 .34824 .44436 .38458 .45586 .37566 .44997 .34113 Mtetra
.618 .455 .64 r
.44997 .34113 .45586 .37566 .46738 .3667 .4614 .33334 Mtetra
.622 .461 .644 r
.4614 .33334 .46738 .3667 .4789 .35838 .47286 .32541 Mtetra
.614 .457 .646 r
.47286 .32541 .4789 .35838 .49041 .35155 .48432 .3184 Mtetra
.603 .449 .646 r
.48432 .3184 .49041 .35155 .50195 .34597 .4958 .31238 Mtetra
.594 .442 .645 r
.4958 .31238 .50195 .34597 .51352 .34074 .50731 .3071 Mtetra
.59 .439 .645 r
.50731 .3071 .51352 .34074 .52513 .33545 .51886 .30219 Mtetra
.594 .443 .646 r
.51886 .30219 .52513 .33545 .53678 .32953 .53044 .29695 Mtetra
.599 .448 .649 r
.53044 .29695 .53678 .32953 .54846 .32307 .54207 .29136 Mtetra
.603 .454 .652 r
.54207 .29136 .54846 .32307 .56016 .31644 .55374 .28557 Mtetra
.606 .459 .656 r
.55374 .28557 .56016 .31644 .5719 .3097 .56543 .27968 Mtetra
.607 .463 .66 r
.56543 .27968 .5719 .3097 .58367 .3029 .57717 .27381 Mtetra
.609 .467 .664 r
.57717 .27381 .58367 .3029 .59546 .29608 .58894 .268 Mtetra
.61 .472 .669 r
.58894 .268 .59546 .29608 .60729 .28924 .60076 .26231 Mtetra
.611 .478 .676 r
.60076 .26231 .60729 .28924 .61915 .28244 .61262 .25678 Mtetra
.611 .485 .684 r
.61262 .25678 .61915 .28244 .63104 .27574 .62452 .25147 Mtetra
.612 .493 .693 r
.62452 .25147 .63104 .27574 .64297 .2692 .63648 .2464 Mtetra
.612 .502 .704 r
.63648 .2464 .64297 .2692 .65494 .2629 .64849 .24165 Mtetra
.611 .512 .717 r
.64849 .24165 .65494 .2629 .66696 .25688 .66057 .23721 Mtetra
.61 .525 .733 r
.66057 .23721 .66696 .25688 .67904 .2512 .67272 .23311 Mtetra
.61 .539 .75 r
.67272 .23311 .67904 .2512 .69117 .24584 .68494 .22933 Mtetra
.608 .556 .771 r
.68494 .22933 .69117 .24584 .70338 .24082 .69723 .22585 Mtetra
.607 .576 .793 r
.69723 .22585 .70338 .24082 .71564 .2361 .7096 .22262 Mtetra
.606 .599 .818 r
.7096 .22262 .71564 .2361 .72798 .23166 .72204 .21959 Mtetra
.604 .625 .845 r
.72204 .21959 .72798 .23166 .74038 .2274 .73456 .21671 Mtetra
.602 .654 .874 r
.73456 .21671 .74038 .2274 .75285 .22328 .74716 .21391 Mtetra
.6 .687 .904 r
.74716 .21391 .75285 .22328 .76539 .21923 .75983 .21113 Mtetra
.738 .766 .876 r
.09551 .43462 .10283 .44102 .1129 .43602 .10574 .4286 Mtetra
.73 .738 .857 r
.10574 .4286 .1129 .43602 .123 .43104 .11599 .42255 Mtetra
.721 .71 .84 r
.11599 .42255 .123 .43104 .13312 .42615 .12626 .41652 Mtetra
.71 .683 .822 r
.12626 .41652 .13312 .42615 .14325 .42139 .13655 .41056 Mtetra
.699 .657 .805 r
.13655 .41056 .14325 .42139 .15339 .41682 .14685 .40469 Mtetra
.686 .631 .789 r
.14685 .40469 .15339 .41682 .16353 .4125 .15716 .39898 Mtetra
.673 .606 .772 r
.15716 .39898 .16353 .4125 .17368 .40848 .16746 .39347 Mtetra
.659 .582 .757 r
.16746 .39347 .17368 .40848 .18382 .40475 .17777 .38819 Mtetra
.646 .558 .742 r
.17777 .38819 .18382 .40475 .19397 .40137 .18808 .38318 Mtetra
.634 .537 .727 r
.18808 .38318 .19397 .40137 .20413 .39829 .1984 .37844 Mtetra
.622 .517 .714 r
.1984 .37844 .20413 .39829 .2143 .39552 .20871 .37399 Mtetra
.612 .5 .702 r
.20871 .37399 .2143 .39552 .2245 .39299 .21904 .3698 Mtetra
.602 .484 .691 r
.21904 .3698 .2245 .39299 .23472 .39068 .22938 .36586 Mtetra
.595 .471 .681 r
.22938 .36586 .23472 .39068 .24497 .38853 .23973 .36213 Mtetra
.589 .459 .672 r
.23973 .36213 .24497 .38853 .25527 .38651 .25012 .35857 Mtetra
.584 .45 .664 r
.25012 .35857 .25527 .38651 .2656 .38456 .26053 .3551 Mtetra
.581 .442 .657 r
.26053 .3551 .2656 .38456 .27599 .38264 .27099 .35168 Mtetra
.579 .436 .651 r
.27099 .35168 .27599 .38264 .28644 .38062 .28149 .34819 Mtetra
.578 .431 .645 r
.28149 .34819 .28644 .38062 .29696 .37841 .29204 .34458 Mtetra
.576 .426 .64 r
.29204 .34458 .29696 .37841 .30754 .37587 .30265 .3409 Mtetra
.574 .421 .636 r
.30265 .3409 .30754 .37587 .3182 .37301 .31329 .33726 Mtetra
.567 .414 .633 r
.31329 .33726 .3182 .37301 .32889 .37051 .32394 .33416 Mtetra
.558 .406 .632 r
.32394 .33416 .32889 .37051 .33958 .36876 .33459 .33178 Mtetra
.553 .402 .63 r
.33459 .33178 .33958 .36876 .35028 .36799 .34528 .32973 Mtetra
.552 .398 .626 r
.34528 .32973 .35028 .36799 .36099 .36814 .35602 .32769 Mtetra
.559 .399 .62 r
.35602 .32769 .36099 .36814 .37178 .36818 .36686 .32483 Mtetra
.566 .398 .613 r
.36686 .32483 .37178 .36818 .38267 .36754 .3778 .32094 Mtetra
.567 .394 .606 r
.3778 .32094 .38267 .36754 .39367 .36588 .3888 .31659 Mtetra
.566 .389 .601 r
.3888 .31659 .39367 .36588 .40477 .36301 .39985 .31212 Mtetra
.56 .383 .598 r
.39985 .31212 .40477 .36301 .41596 .35915 .41091 .3082 Mtetra
.555 .379 .598 r
.41091 .3082 .41596 .35915 .42723 .3543 .42201 .30482 Mtetra
.557 .383 .601 r
.42201 .30482 .42723 .3543 .43857 .34824 .43316 .30132 Mtetra
.563 .391 .606 r
.43316 .30132 .43857 .34824 .44997 .34113 .44437 .29736 Mtetra
.575 .405 .613 r
.44437 .29736 .44997 .34113 .4614 .33334 .45565 .29236 Mtetra
.586 .418 .62 r
.45565 .29236 .4614 .33334 .47286 .32541 .46698 .28654 Mtetra
.589 .424 .626 r
.46698 .28654 .47286 .32541 .48432 .3184 .47835 .28072 Mtetra
.588 .426 .63 r
.47835 .28072 .48432 .3184 .4958 .31238 .48975 .27522 Mtetra
.581 .423 .632 r
.48975 .27522 .4958 .31238 .50731 .3071 .50118 .27044 Mtetra
.576 .421 .633 r
.50118 .27044 .50731 .3071 .51886 .30219 .51265 .26622 Mtetra
.577 .423 .636 r
.51265 .26622 .51886 .30219 .53044 .29695 .52417 .26203 Mtetra
.579 .427 .64 r
.52417 .26203 .53044 .29695 .54207 .29136 .53573 .25777 Mtetra
.583 .434 .645 r
.53573 .25777 .54207 .29136 .55374 .28557 .54734 .25338 Mtetra
.586 .44 .65 r
.54734 .25338 .55374 .28557 .56543 .27968 .559 .24892 Mtetra
.588 .447 .657 r
.559 .24892 .56543 .27968 .57717 .27381 .5707 .2445 Mtetra
.589 .453 .664 r
.5707 .2445 .57717 .27381 .58894 .268 .58246 .24017 Mtetra
.59 .46 .672 r
.58246 .24017 .58894 .268 .60076 .26231 .59427 .23602 Mtetra
.59 .468 .681 r
.59427 .23602 .60076 .26231 .61262 .25678 .60613 .23208 Mtetra
.59 .476 .692 r
.60613 .23208 .61262 .25678 .62452 .25147 .61806 .2284 Mtetra
.589 .486 .704 r
.61806 .2284 .62452 .25147 .63648 .2464 .63005 .22498 Mtetra
.588 .497 .718 r
.63005 .22498 .63648 .2464 .64849 .24165 .64211 .22185 Mtetra
.587 .509 .735 r
.64211 .22185 .64849 .24165 .66057 .23721 .65425 .21901 Mtetra
.584 .523 .753 r
.65425 .21901 .66057 .23721 .67272 .23311 .66646 .21645 Mtetra
.582 .539 .773 r
.66646 .21645 .67272 .23311 .68494 .22933 .67875 .21413 Mtetra
.579 .557 .794 r
.67875 .21413 .68494 .22933 .69723 .22585 .69113 .21203 Mtetra
.575 .577 .817 r
.69113 .21203 .69723 .22585 .7096 .22262 .70358 .21008 Mtetra
.572 .599 .841 r
.70358 .21008 .7096 .22262 .72204 .21959 .71612 .20825 Mtetra
.568 .622 .866 r
.71612 .20825 .72204 .21959 .73456 .21671 .72874 .20648 Mtetra
.564 .647 .891 r
.72874 .20648 .73456 .21671 .74716 .21391 .74144 .20474 Mtetra
.558 .674 .916 r
.74144 .20474 .74716 .21391 .75983 .21113 .75422 .20298 Mtetra
.747 .767 .869 r
.08813 .42819 .09551 .43462 .10574 .4286 .09844 .42173 Mtetra
.745 .756 .861 r
.09844 .42173 .10574 .4286 .11599 .42255 .10878 .41522 Mtetra
.742 .744 .853 r
.10878 .41522 .11599 .42255 .12626 .41652 .11914 .40867 Mtetra
.737 .731 .845 r
.11914 .40867 .12626 .41652 .13655 .41056 .12952 .40212 Mtetra
.732 .717 .836 r
.12952 .40212 .13655 .41056 .14685 .40469 .13992 .39558 Mtetra
.725 .701 .827 r
.13992 .39558 .14685 .40469 .15716 .39898 .15033 .3891 Mtetra
.716 .683 .817 r
.15033 .3891 .15716 .39898 .16746 .39347 .16075 .38272 Mtetra
.707 .664 .806 r
.16075 .38272 .16746 .39347 .17777 .38819 .17118 .37648 Mtetra
.695 .644 .794 r
.17118 .37648 .17777 .38819 .18808 .38318 .18161 .37042 Mtetra
.684 .623 .782 r
.18161 .37042 .18808 .38318 .1984 .37844 .19204 .36457 Mtetra
.672 .603 .77 r
.19204 .36457 .1984 .37844 .20871 .37399 .20248 .35894 Mtetra
.661 .583 .758 r
.20248 .35894 .20871 .37399 .21904 .3698 .21292 .35353 Mtetra
.65 .565 .746 r
.21292 .35353 .21904 .3698 .22938 .36586 .22337 .34835 Mtetra
.64 .548 .734 r
.22337 .34835 .22938 .36586 .23973 .36213 .23383 .34337 Mtetra
.631 .532 .724 r
.23383 .34337 .23973 .36213 .25012 .35857 .24431 .33855 Mtetra
.624 .518 .714 r
.24431 .33855 .25012 .35857 .26053 .3551 .25481 .33386 Mtetra
.618 .506 .704 r
.25481 .33386 .26053 .3551 .27099 .35168 .26534 .32925 Mtetra
.613 .496 .696 r
.26534 .32925 .27099 .35168 .28149 .34819 .2759 .3247 Mtetra
.609 .487 .689 r
.2759 .3247 .28149 .34819 .29204 .34458 .28649 .32019 Mtetra
.603 .479 .684 r
.28649 .32019 .29204 .34458 .30265 .3409 .2971 .31588 Mtetra
.597 .472 .681 r
.2971 .31588 .30265 .3409 .31329 .33726 .30773 .31186 Mtetra
.588 .465 .679 r
.30773 .31186 .31329 .33726 .32394 .33416 .31837 .30836 Mtetra
.58 .458 .678 r
.31837 .30836 .32394 .33416 .33459 .33178 .32902 .30533 Mtetra
.583 .457 .674 r
.32902 .30533 .33459 .33178 .34528 .32973 .33974 .30201 Mtetra
.59 .456 .667 r
.33974 .30201 .34528 .32973 .35602 .32769 .35055 .29799 Mtetra
.601 .456 .656 r
.35055 .29799 .35602 .32769 .36686 .32483 .36145 .29281 Mtetra
.607 .453 .646 r
.36145 .29281 .36686 .32483 .3778 .32094 .37245 .28657 Mtetra
.601 .442 .638 r
.37245 .28657 .3778 .32094 .3888 .31659 .38347 .28037 Mtetra
.591 .43 .632 r
.38347 .28037 .3888 .31659 .39985 .31212 .39449 .27487 Mtetra
.573 .415 .629 r
.39449 .27487 .39985 .31212 .41091 .3082 .40548 .2709 Mtetra
.556 .403 .629 r
.40548 .2709 .41091 .3082 .42201 .30482 .41646 .26844 Mtetra
.549 .4 .632 r
.41646 .26844 .42201 .30482 .43316 .30132 .42748 .26669 Mtetra
.549 .406 .639 r
.42748 .26669 .43316 .30132 .44437 .29736 .43856 .26499 Mtetra
.565 .424 .648 r
.43856 .26499 .44437 .29736 .45565 .29236 .44973 .26224 Mtetra
.583 .444 .657 r
.44973 .26224 .45565 .29236 .46698 .28654 .46097 .25831 Mtetra
.596 .46 .666 r
.46097 .25831 .46698 .28654 .47835 .28072 .47228 .25368 Mtetra
.602 .469 .672 r
.47228 .25368 .47835 .28072 .48975 .27522 .48363 .24875 Mtetra
.597 .469 .676 r
.48363 .24875 .48975 .27522 .50118 .27044 .49502 .2443 Mtetra
.591 .466 .679 r
.49502 .2443 .50118 .27044 .51265 .26622 .50645 .24036 Mtetra
.587 .466 .681 r
.50645 .24036 .51265 .26622 .52417 .26203 .51793 .23672 Mtetra
.585 .467 .685 r
.51793 .23672 .52417 .26203 .53573 .25777 .52946 .23328 Mtetra
.586 .473 .691 r
.52946 .23328 .53573 .25777 .54734 .25338 .54104 .2299 Mtetra
.587 .48 .699 r
.54104 .2299 .54734 .25338 .559 .24892 .55268 .22656 Mtetra
.588 .488 .708 r
.55268 .22656 .559 .24892 .5707 .2445 .56438 .22331 Mtetra
.589 .497 .718 r
.56438 .22331 .5707 .2445 .58246 .24017 .57614 .22019 Mtetra
.588 .507 .73 r
.57614 .22019 .58246 .24017 .59427 .23602 .58796 .21724 Mtetra
.587 .517 .743 r
.58796 .21724 .59427 .23602 .60613 .23208 .59984 .2145 Mtetra
.584 .528 .758 r
.59984 .2145 .60613 .23208 .61806 .2284 .6118 .21199 Mtetra
.581 .54 .774 r
.6118 .21199 .61806 .2284 .63005 .22498 .62383 .2097 Mtetra
.577 .553 .792 r
.62383 .2097 .63005 .22498 .64211 .22185 .63593 .20766 Mtetra
.572 .568 .81 r
.63593 .20766 .64211 .22185 .65425 .21901 .64812 .20584 Mtetra
.566 .582 .829 r
.64812 .20584 .65425 .21901 .66646 .21645 .66039 .2042 Mtetra
.56 .597 .847 r
.66039 .2042 .66646 .21645 .67875 .21413 .67274 .20272 Mtetra
.555 .613 .865 r
.67274 .20272 .67875 .21413 .69113 .21203 .68517 .20134 Mtetra
.549 .628 .882 r
.68517 .20134 .69113 .21203 .70358 .21008 .69769 .20003 Mtetra
.545 .642 .897 r
.69769 .20003 .70358 .21008 .71612 .20825 .71029 .19874 Mtetra
.541 .656 .91 r
.71029 .19874 .71612 .20825 .72874 .20648 .72297 .19745 Mtetra
.538 .669 .922 r
.72297 .19745 .72874 .20648 .74144 .20474 .73573 .19613 Mtetra
.535 .681 .932 r
.73573 .19613 .74144 .20474 .75422 .20298 .74857 .19475 Mtetra
.744 .767 .872 r
.0807 .4217 .08813 .42819 .09844 .42173 .09102 .41538 Mtetra
.746 .772 .874 r
.09102 .41538 .09844 .42173 .10878 .41522 .10136 .40898 Mtetra
.749 .776 .875 r
.10136 .40898 .10878 .41522 .11914 .40867 .11174 .40252 Mtetra
.751 .779 .876 r
.11174 .40252 .11914 .40867 .12952 .40212 .12215 .39598 Mtetra
.753 .781 .876 r
.12215 .39598 .12952 .40212 .13992 .39558 .13258 .38938 Mtetra
.753 .78 .875 r
.13258 .38938 .13992 .39558 .15033 .3891 .14304 .38275 Mtetra
.751 .776 .873 r
.14304 .38275 .15033 .3891 .16075 .38272 .15352 .37611 Mtetra
.748 .77 .87 r
.15352 .37611 .16075 .38272 .17118 .37648 .16401 .36952 Mtetra
.743 .76 .866 r
.16401 .36952 .17118 .37648 .18161 .37042 .17452 .36301 Mtetra
.737 .748 .861 r
.17452 .36301 .18161 .37042 .19204 .36457 .18504 .35662 Mtetra
.729 .733 .854 r
.18504 .35662 .19204 .36457 .20248 .35894 .19556 .35037 Mtetra
.72 .717 .846 r
.19556 .35037 .20248 .35894 .21292 .35353 .20609 .34427 Mtetra
.711 .699 .837 r
.20609 .34427 .21292 .35353 .22337 .34835 .21663 .33834 Mtetra
.702 .681 .827 r
.21663 .33834 .22337 .34835 .23383 .34337 .22718 .33256 Mtetra
.692 .662 .816 r
.22718 .33256 .23383 .34337 .24431 .33855 .23774 .32692 Mtetra
.683 .645 .805 r
.23774 .32692 .24431 .33855 .25481 .33386 .24832 .32142 Mtetra
.675 .628 .795 r
.24832 .32142 .25481 .33386 .26534 .32925 .25892 .31604 Mtetra
.666 .613 .786 r
.25892 .31604 .26534 .32925 .2759 .3247 .26954 .31084 Mtetra
.658 .6 .779 r
.26954 .31084 .2759 .3247 .28649 .32019 .28017 .30584 Mtetra
.647 .589 .775 r
.28017 .30584 .28649 .32019 .2971 .31588 .29081 .30121 Mtetra
.636 .579 .774 r
.29081 .30121 .2971 .31588 .30773 .31186 .30146 .29699 Mtetra
.629 .573 .773 r
.30146 .29699 .30773 .31186 .31837 .30836 .31212 .29307 Mtetra
.625 .566 .768 r
.31212 .29307 .31837 .30836 .32902 .30533 .32282 .28921 Mtetra
.638 .564 .755 r
.32282 .28921 .32902 .30533 .33974 .30201 .33362 .28457 Mtetra
.653 .559 .737 r
.33362 .28457 .33974 .30201 .35055 .29799 .34451 .27877 Mtetra
.662 .549 .717 r
.34451 .27877 .35055 .29799 .36145 .29281 .35551 .27179 Mtetra
.664 .538 .701 r
.35551 .27179 .36145 .29281 .37245 .28657 .36656 .26399 Mtetra
.65 .52 .692 r
.36656 .26399 .37245 .28657 .38347 .28037 .37762 .25668 Mtetra
.629 .5 .687 r
.37762 .25668 .38347 .28037 .39449 .27487 .38863 .25063 Mtetra
.597 .477 .687 r
.38863 .25063 .39449 .27487 .40548 .2709 .39959 .2466 Mtetra
.563 .456 .69 r
.39959 .2466 .40548 .2709 .41646 .26844 .41053 .24462 Mtetra
.541 .445 .695 r
.41053 .24462 .41646 .26844 .42748 .26669 .42147 .2439 Mtetra
.532 .446 .704 r
.42147 .2439 .42748 .26669 .43856 .26499 .43247 .24369 Mtetra
.549 .468 .716 r
.43247 .24369 .43856 .26499 .44973 .26224 .44357 .24266 Mtetra
.575 .498 .731 r
.44357 .24266 .44973 .26224 .46097 .25831 .45476 .24046 Mtetra
.603 .531 .746 r
.45476 .24046 .46097 .25831 .47228 .25368 .46604 .23708 Mtetra
.624 .556 .758 r
.46604 .23708 .47228 .25368 .48363 .24875 .47737 .23291 Mtetra
.625 .566 .768 r
.47737 .23291 .48363 .24875 .49502 .2443 .48876 .22881 Mtetra
.62 .568 .775 r
.48876 .22881 .49502 .2443 .50645 .24036 .50019 .225 Mtetra
.611 .566 .779 r
.50019 .225 .50645 .24036 .51793 .23672 .51167 .22162 Mtetra
.602 .565 .785 r
.51167 .22162 .51793 .23672 .52946 .23328 .5232 .21861 Mtetra
.598 .569 .793 r
.5232 .21861 .52946 .23328 .54104 .2299 .53479 .21581 Mtetra
.595 .577 .803 r
.53479 .21581 .54104 .2299 .55268 .22656 .54644 .21319 Mtetra
.592 .588 .817 r
.54644 .21319 .55268 .22656 .56438 .22331 .55816 .2107 Mtetra
.589 .6 .831 r
.55816 .2107 .56438 .22331 .57614 .22019 .56994 .20835 Mtetra
.584 .614 .848 r
.56994 .20835 .57614 .22019 .58796 .21724 .58179 .20615 Mtetra
.579 .628 .865 r
.58179 .20615 .58796 .21724 .59984 .2145 .59371 .20411 Mtetra
.571 .641 .881 r
.59371 .20411 .59984 .2145 .6118 .21199 .6057 .20224 Mtetra
.562 .654 .898 r
.6057 .20224 .6118 .21199 .62383 .2097 .61778 .20054 Mtetra
.552 .666 .913 r
.61778 .20054 .62383 .2097 .63593 .20766 .62993 .19899 Mtetra
.542 .677 .926 r
.62993 .19899 .63593 .20766 .64812 .20584 .64216 .19756 Mtetra
.533 .686 .936 r
.64216 .19756 .64812 .20584 .66039 .2042 .65447 .19623 Mtetra
.526 .693 .944 r
.65447 .19623 .66039 .2042 .67274 .20272 .66686 .19494 Mtetra
.523 .699 .95 r
.66686 .19494 .67274 .20272 .68517 .20134 .67933 .19366 Mtetra
.522 .702 .952 r
.67933 .19366 .68517 .20134 .69769 .20003 .69188 .19236 Mtetra
.524 .705 .953 r
.69188 .19236 .69769 .20003 .71029 .19874 .70452 .19098 Mtetra
.528 .705 .952 r
.70452 .19098 .71029 .19874 .72297 .19745 .71722 .18955 Mtetra
.532 .703 .949 r
.71722 .18955 .72297 .19745 .73573 .19613 .73001 .18804 Mtetra
.537 .701 .945 r
.73001 .18804 .73573 .19613 .74857 .19475 .74288 .18646 Mtetra
.723 .764 .886 r
.07322 .41517 .0807 .4217 .09102 .41538 .08345 .40964 Mtetra
.729 .79 .9 r
.08345 .40964 .09102 .41538 .10136 .40898 .09372 .40402 Mtetra
.736 .816 .914 r
.09372 .40402 .10136 .40898 .11174 .40252 .10403 .39831 Mtetra
.741 .843 .927 r
.10403 .39831 .11174 .40252 .12215 .39598 .11438 .3925 Mtetra
.746 .868 .937 r
.11438 .3925 .12215 .39598 .13258 .38938 .12477 .38656 Mtetra
.747 .891 .944 r
.12477 .38656 .13258 .38938 .14304 .38275 .13519 .38053 Mtetra
.746 .912 .949 r
.13519 .38053 .14304 .38275 .15352 .37611 .14565 .37442 Mtetra
.741 .928 .952 r
.14565 .37442 .15352 .37611 .16401 .36952 .15613 .36826 Mtetra
.734 .941 .952 r
.15613 .36826 .16401 .36952 .17452 .36301 .16665 .36209 Mtetra
.724 .95 .951 r
.16665 .36209 .17452 .36301 .18504 .35662 .17718 .35595 Mtetra
.713 .955 .95 r
.17718 .35595 .18504 .35662 .19556 .35037 .18773 .34986 Mtetra
.702 .958 .948 r
.18773 .34986 .19556 .35037 .20609 .34427 .1983 .34385 Mtetra
.692 .958 .947 r
.1983 .34385 .20609 .34427 .21663 .33834 .20888 .33794 Mtetra
.682 .957 .947 r
.20888 .33794 .21663 .33834 .22718 .33256 .21948 .33213 Mtetra
.674 .956 .948 r
.21948 .33213 .22718 .33256 .23774 .32692 .2301 .32644 Mtetra
.665 .953 .95 r
.2301 .32644 .23774 .32692 .24832 .32142 .24073 .32087 Mtetra
.655 .95 .952 r
.24073 .32087 .24832 .32142 .25892 .31604 .25138 .31545 Mtetra
.642 .947 .953 r
.25138 .31545 .25892 .31604 .26954 .31084 .26205 .31021 Mtetra
.627 .942 .954 r
.26205 .31021 .26954 .31084 .28017 .30584 .27273 .30516 Mtetra
.611 .937 .955 r
.27273 .30516 .28017 .30584 .29081 .30121 .28343 .30033 Mtetra
.605 .932 .96 r
.28343 .30033 .29081 .30121 .30146 .29699 .29416 .29565 Mtetra
.636 .932 .969 r
.29416 .29565 .30146 .29699 .31212 .29307 .30493 .29079 Mtetra
.691 .92 .97 r
.30493 .29079 .31212 .29307 .32282 .28921 .31578 .28544 Mtetra
.753 .881 .937 r
.31578 .28544 .32282 .28921 .33362 .28457 .32672 .27897 Mtetra
.782 .823 .885 r
.32672 .27897 .33362 .28457 .34451 .27877 .33778 .2712 Mtetra
.78 .768 .842 r
.33778 .2712 .34451 .27877 .35551 .27179 .34889 .2626 Mtetra
.769 .729 .815 r
.34889 .2626 .35551 .27179 .36656 .26399 .36004 .25373 Mtetra
.742 .7 .811 r
.36004 .25373 .36656 .26399 .37762 .25668 .37114 .24582 Mtetra
.703 .675 .82 r
.37114 .24582 .37762 .25668 .38863 .25063 .38219 .23957 Mtetra
.647 .649 .837 r
.38219 .23957 .38863 .25063 .39959 .2466 .39316 .23552 Mtetra
.577 .616 .855 r
.39316 .23552 .39959 .2466 .41053 .24462 .4041 .23366 Mtetra
.51 .586 .867 r
.4041 .23366 .41053 .24462 .42147 .2439 .41504 .23348 Mtetra
.458 .574 .883 r
.41504 .23348 .42147 .2439 .43247 .24369 .42601 .23428 Mtetra
.458 .602 .906 r
.42601 .23428 .43247 .24369 .44357 .24266 .43708 .23482 Mtetra
.479 .662 .942 r
.43708 .23482 .44357 .24266 .45476 .24046 .44825 .23453 Mtetra
.522 .75 .979 r
.44825 .23453 .45476 .24046 .46604 .23708 .45952 .23294 Mtetra
.551 .83 .997 r
.45952 .23294 .46604 .23708 .47737 .23291 .47087 .23023 Mtetra
.531 .871 .991 r
.47087 .23023 .47737 .23291 .48876 .22881 .48229 .22702 Mtetra
.498 .881 .969 r
.48229 .22702 .48876 .22881 .50019 .225 .49377 .22363 Mtetra
.456 .869 .95 r
.49377 .22363 .50019 .225 .51167 .22162 .5053 .2204 Mtetra
.422 .855 .937 r
.5053 .2204 .51167 .22162 .5232 .21861 .51689 .21739 Mtetra
.4 .843 .932 r
.51689 .21739 .5232 .21861 .53479 .21581 .52853 .21457 Mtetra
.38 .832 .927 r
.52853 .21457 .53479 .21581 .54644 .21319 .54024 .21195 Mtetra
.363 .823 .923 r
.54024 .21195 .54644 .21319 .55816 .2107 .55201 .20947 Mtetra
.347 .814 .917 r
.55201 .20947 .55816 .2107 .56994 .20835 .56385 .20713 Mtetra
.332 .805 .912 r
.56385 .20713 .56994 .20835 .58179 .20615 .57575 .20491 Mtetra
.32 .798 .909 r
.57575 .20491 .58179 .20615 .59371 .20411 .58773 .20279 Mtetra
.313 .793 .91 r
.58773 .20279 .59371 .20411 .6057 .20224 .59978 .20079 Mtetra
.314 .791 .916 r
.59978 .20079 .6057 .20224 .61778 .20054 .6119 .19886 Mtetra
.322 .793 .927 r
.6119 .19886 .61778 .20054 .62993 .19899 .62409 .197 Mtetra
.341 .798 .943 r
.62409 .197 .62993 .19899 .64216 .19756 .63636 .19516 Mtetra
.368 .804 .961 r
.63636 .19516 .64216 .19756 .65447 .19623 .64871 .19332 Mtetra
.401 .81 .979 r
.64871 .19332 .65447 .19623 .66686 .19494 .66113 .19144 Mtetra
.438 .812 .993 r
.66113 .19144 .66686 .19494 .67933 .19366 .67362 .18948 Mtetra
.474 .808 .999 r
.67362 .18948 .67933 .19366 .69188 .19236 .68618 .18743 Mtetra
.508 .799 .998 r
.68618 .18743 .69188 .19236 .70452 .19098 .69882 .18525 Mtetra
.534 .782 .989 r
.69882 .18525 .70452 .19098 .71722 .18955 .71152 .18296 Mtetra
.555 .762 .974 r
.71152 .18296 .71722 .18955 .73001 .18804 .72429 .18057 Mtetra
.569 .739 .956 r
.72429 .18057 .73001 .18804 .74288 .18646 .73713 .1781 Mtetra
.684 .758 .907 r
.06568 .40859 .07322 .41517 .08345 .40964 .07577 .40425 Mtetra
.69 .798 .932 r
.07577 .40425 .08345 .40964 .09372 .40402 .0859 .39983 Mtetra
.691 .839 .954 r
.0859 .39983 .09372 .40402 .10403 .39831 .09609 .3953 Mtetra
.687 .88 .97 r
.09609 .3953 .10403 .39831 .11438 .3925 .10632 .39065 Mtetra
.675 .916 .975 r
.10632 .39065 .11438 .3925 .12477 .38656 .1166 .38585 Mtetra
.65 .939 .964 r
.1166 .38585 .12477 .38656 .13519 .38053 .12693 .3809 Mtetra
.61 .947 .933 r
.12693 .3809 .13519 .38053 .14565 .37442 .13731 .37582 Mtetra
.555 .933 .882 r
.13731 .37582 .14565 .37442 .15613 .36826 .14774 .37062 Mtetra
.489 .9 .814 r
.14774 .37062 .15613 .36826 .16665 .36209 .1582 .36534 Mtetra
.417 .853 .737 r
.1582 .36534 .16665 .36209 .17718 .35595 .1687 .36 Mtetra
.346 .797 .658 r
.1687 .36 .17718 .35595 .18773 .34986 .17924 .35464 Mtetra
0 0 0 r
.17924 .35464 .18773 .34986 .1983 .34385 .1898 .34927 Mtetra
.1898 .34927 .1983 .34385 .20888 .33794 .20039 .34393 Mtetra
.20039 .34393 .20888 .33794 .21948 .33213 .21101 .33863 Mtetra
.21101 .33863 .21948 .33213 .2301 .32644 .22165 .33341 Mtetra
.22165 .33341 .2301 .32644 .24073 .32087 .23232 .32828 Mtetra
.23232 .32828 .24073 .32087 .25138 .31545 .243 .32327 Mtetra
.012 0 0 r
.243 .32327 .25138 .31545 .26205 .31021 .25372 .31837 Mtetra
.042 0 0 r
.25372 .31837 .26205 .31021 .27273 .30516 .26445 .31357 Mtetra
.054 0 0 r
.26445 .31357 .27273 .30516 .28343 .30033 .27523 .30872 Mtetra
.041 0 0 r
.27523 .30872 .28343 .30033 .29416 .29565 .28606 .3037 Mtetra
0 0 0 r
.28606 .3037 .29416 .29565 .30493 .29079 .29697 .29808 Mtetra
.29697 .29808 .30493 .29079 .31578 .28544 .30797 .29162 Mtetra
.30797 .29162 .31578 .28544 .32672 .27897 .31906 .28406 Mtetra
.5 .865 .632 r
.31906 .28406 .32672 .27897 .33778 .2712 .33024 .27546 Mtetra
.579 .917 .699 r
.33024 .27546 .33778 .2712 .34889 .2626 .34145 .26661 Mtetra
.566 .913 .705 r
.34145 .26661 .34889 .2626 .36004 .25373 .35265 .25811 Mtetra
.433 .836 .637 r
.35265 .25811 .36004 .25373 .37114 .24582 .3638 .25075 Mtetra
0 0 0 r
.3638 .25075 .37114 .24582 .38219 .23957 .3749 .24497 Mtetra
.3749 .24497 .38219 .23957 .39316 .23552 .38595 .24089 Mtetra
.127 0 0 r
.38595 .24089 .39316 .23552 .4041 .23366 .39698 .23853 Mtetra
.23 0 0 r
.39698 .23853 .4041 .23366 .41504 .23348 .408 .23775 Mtetra
.291 0 0 r
.408 .23775 .41504 .23348 .42601 .23428 .41905 .23814 Mtetra
.301 0 0 r
.41905 .23814 .42601 .23428 .43708 .23482 .43017 .23888 Mtetra
.29 0 0 r
.43017 .23888 .43708 .23482 .44825 .23453 .44138 .23938 Mtetra
.247 0 0 r
.44138 .23938 .44825 .23453 .45952 .23294 .45269 .23886 Mtetra
.211 0 0 r
.45269 .23886 .45952 .23294 .47087 .23023 .4641 .23723 Mtetra
.196 0 0 r
.4641 .23723 .47087 .23023 .48229 .22702 .4756 .23474 Mtetra
.187 0 0 r
.4756 .23474 .48229 .22702 .49377 .22363 .48716 .23167 Mtetra
.188 0 0 r
.48716 .23167 .49377 .22363 .5053 .2204 .49878 .22841 Mtetra
.186 0 0 r
.49878 .22841 .5053 .2204 .51689 .21739 .51045 .22511 Mtetra
.183 0 0 r
.51045 .22511 .51689 .21739 .52853 .21457 .52219 .22191 Mtetra
.177 0 0 r
.52219 .22191 .52853 .21457 .54024 .21195 .53398 .21882 Mtetra
.168 0 0 r
.53398 .21882 .54024 .21195 .55201 .20947 .54584 .21586 Mtetra
.155 0 0 r
.54584 .21586 .55201 .20947 .56385 .20713 .55776 .21299 Mtetra
.138 0 0 r
.55776 .21299 .56385 .20713 .57575 .20491 .56974 .2102 Mtetra
.115 0 0 r
.56974 .2102 .57575 .20491 .58773 .20279 .58178 .20746 Mtetra
.085 0 0 r
.58178 .20746 .58773 .20279 .59978 .20079 .5939 .20475 Mtetra
.045 0 0 r
.5939 .20475 .59978 .20079 .6119 .19886 .60608 .20204 Mtetra
0 0 0 r
.60608 .20204 .6119 .19886 .62409 .197 .61832 .1993 Mtetra
.61832 .1993 .62409 .197 .63636 .19516 .63064 .1965 Mtetra
.63064 .1965 .63636 .19516 .64871 .19332 .64301 .19362 Mtetra
.257 .768 .795 r
.64301 .19362 .64871 .19332 .66113 .19144 .65545 .19062 Mtetra
.36 .828 .891 r
.65545 .19062 .66113 .19144 .67362 .18948 .66795 .18748 Mtetra
.452 .862 .958 r
.66795 .18748 .67362 .18948 .68618 .18743 .68051 .18419 Mtetra
.526 .867 .992 r
.68051 .18419 .68618 .18743 .69882 .18525 .69313 .18074 Mtetra
.576 .848 .996 r
.69313 .18074 .69882 .18525 .71152 .18296 .70581 .17715 Mtetra
.606 .816 .98 r
.70581 .17715 .71152 .18296 .72429 .18057 .71855 .17346 Mtetra
.622 .778 .956 r
.71855 .17346 .72429 .18057 .73713 .1781 .73134 .16968 Mtetra
.627 .744 .931 r
.05808 .40196 .06568 .40859 .07577 .40425 .068 .39901 Mtetra
.623 .79 .962 r
.068 .39901 .07577 .40425 .0859 .39983 .07796 .39598 Mtetra
.61 .837 .986 r
.07796 .39598 .0859 .39983 .09609 .3953 .08798 .39286 Mtetra
.583 .877 .993 r
.08798 .39286 .09609 .3953 .10632 .39065 .09806 .38961 Mtetra
.536 .897 .971 r
.09806 .38961 .10632 .39065 .1166 .38585 .10821 .38619 Mtetra
.464 .886 .91 r
.10821 .38619 .1166 .38585 .12693 .3809 .11841 .38261 Mtetra
.372 .838 .81 r
.11841 .38261 .12693 .3809 .13731 .37582 .12867 .37887 Mtetra
.269 .761 .685 r
.12867 .37887 .13731 .37582 .14774 .37062 .139 .37497 Mtetra
0 0 0 r
.139 .37497 .14774 .37062 .1582 .36534 .14937 .37094 Mtetra
.14937 .37094 .1582 .36534 .1687 .36 .1598 .36681 Mtetra
.1598 .36681 .1687 .36 .17924 .35464 .17027 .36258 Mtetra
.052 0 0 r
.17027 .36258 .17924 .35464 .1898 .34927 .18079 .3583 Mtetra
.101 0 0 r
.18079 .3583 .1898 .34927 .20039 .34393 .19135 .35398 Mtetra
.142 0 0 r
.19135 .35398 .20039 .34393 .21101 .33863 .20195 .34963 Mtetra
.175 0 0 r
.20195 .34963 .21101 .33863 .22165 .33341 .21259 .34527 Mtetra
.201 0 0 r
.21259 .34527 .22165 .33341 .23232 .32828 .22327 .34091 Mtetra
.222 0 .011 r
.22327 .34091 .23232 .32828 .243 .32327 .23399 .33655 Mtetra
.237 0 .035 r
.23399 .33655 .243 .32327 .25372 .31837 .24475 .33218 Mtetra
.247 0 .052 r
.24475 .33218 .25372 .31837 .26445 .31357 .25555 .32776 Mtetra
.251 0 .062 r
.25555 .32776 .26445 .31357 .27523 .30872 .2664 .32322 Mtetra
.249 0 .067 r
.2664 .32322 .27523 .30872 .28606 .3037 .2773 .31849 Mtetra
.242 0 .07 r
.2773 .31849 .28606 .3037 .29697 .29808 .28827 .31345 Mtetra
.239 0 .079 r
.28827 .31345 .29697 .29808 .30797 .29162 .2993 .30807 Mtetra
.253 0 .105 r
.2993 .30807 .30797 .29162 .31906 .28406 .31037 .30251 Mtetra
.285 0 .15 r
.31037 .30251 .31906 .28406 .33024 .27546 .32148 .29697 Mtetra
.336 0 .209 r
.32148 .29697 .33024 .27546 .34145 .26661 .33258 .29198 Mtetra
.381 .043 .261 r
.33258 .29198 .34145 .26661 .35265 .25811 .34369 .28768 Mtetra
.408 .083 .299 r
.34369 .28768 .35265 .25811 .3638 .25075 .35481 .28378 Mtetra
.423 .106 .321 r
.35481 .28378 .3638 .25075 .3749 .24497 .36598 .28007 Mtetra
.423 .111 .329 r
.36598 .28007 .3749 .24497 .38595 .24089 .37721 .27599 Mtetra
.418 .106 .328 r
.37721 .27599 .38595 .24089 .39698 .23853 .3885 .27156 Mtetra
.415 .099 .318 r
.3885 .27156 .39698 .23853 .408 .23775 .39983 .2673 Mtetra
.411 .085 .299 r
.39983 .2673 .408 .23775 .41905 .23814 .41119 .26346 Mtetra
.407 .066 .272 r
.41119 .26346 .41905 .23814 .43017 .23888 .42258 .26031 Mtetra
.401 .042 .236 r
.42258 .26031 .43017 .23888 .44138 .23938 .434 .25771 Mtetra
.382 .006 .194 r
.434 .25771 .44138 .23938 .45269 .23886 .44549 .25514 Mtetra
.36 0 .156 r
.44549 .25514 .45269 .23886 .4641 .23723 .45704 .25239 Mtetra
.338 0 .127 r
.45704 .25239 .4641 .23723 .4756 .23474 .46865 .24929 Mtetra
.32 0 .108 r
.46865 .24929 .4756 .23474 .48716 .23167 .48033 .24589 Mtetra
.309 0 .097 r
.48033 .24589 .48716 .23167 .49878 .22841 .49207 .24229 Mtetra
.3 0 .087 r
.49207 .24229 .49878 .22841 .51045 .22511 .50387 .23857 Mtetra
.293 0 .075 r
.50387 .23857 .51045 .22511 .52219 .22191 .51572 .23481 Mtetra
.283 0 .058 r
.51572 .23481 .52219 .22191 .53398 .21882 .52762 .23103 Mtetra
.271 0 .037 r
.52762 .23103 .53398 .21882 .54584 .21586 .53958 .22724 Mtetra
.255 0 .009 r
.53958 .22724 .54584 .21586 .55776 .21299 .5516 .22346 Mtetra
.234 0 0 r
.5516 .22346 .55776 .21299 .56974 .2102 .56367 .21966 Mtetra
.207 0 0 r
.56367 .21966 .56974 .2102 .58178 .20746 .5758 .21584 Mtetra
.172 0 0 r
.5758 .21584 .58178 .20746 .5939 .20475 .58799 .21197 Mtetra
.126 0 0 r
.58799 .21197 .5939 .20475 .60608 .20204 .60024 .20804 Mtetra
.064 0 0 r
.60024 .20804 .60608 .20204 .61832 .1993 .61254 .20402 Mtetra
0 0 0 r
.61254 .20402 .61832 .1993 .63064 .1965 .62489 .19988 Mtetra
.62489 .19988 .63064 .1965 .64301 .19362 .6373 .19561 Mtetra
.241 .741 .671 r
.6373 .19561 .64301 .19362 .65545 .19062 .64976 .19117 Mtetra
.375 .84 .809 r
.64976 .19117 .65545 .19062 .66795 .18748 .66227 .18655 Mtetra
.495 .901 .915 r
.66227 .18655 .66795 .18748 .68051 .18419 .67482 .18176 Mtetra
.587 .917 .971 r
.67482 .18176 .68051 .18419 .69313 .18074 .68742 .1768 Mtetra
.642 .896 .984 r
.68742 .1768 .69313 .18074 .70581 .17715 .70007 .1717 Mtetra
.67 .855 .97 r
.70007 .1717 .70581 .17715 .71855 .17346 .71276 .16648 Mtetra
.68 .808 .944 r
.71276 .16648 .71855 .17346 .73134 .16968 .7255 .16118 Mtetra
.553 .721 .951 r
.05043 .39529 .05808 .40196 .068 .39901 .06017 .39368 Mtetra
.536 .763 .981 r
.06017 .39368 .068 .39901 .07796 .39598 .06996 .392 Mtetra
.507 .801 .999 r
.06996 .392 .07796 .39598 .08798 .39286 .07982 .39024 Mtetra
.46 .828 .993 r
.07982 .39024 .08798 .39286 .09806 .38961 .08975 .38836 Mtetra
.394 .83 .951 r
.08975 .38836 .09806 .38961 .10821 .38619 .09974 .38631 Mtetra
.307 .798 .866 r
.09974 .38631 .10821 .38619 .11841 .38261 .10981 .38411 Mtetra
.209 .733 .746 r
.10981 .38411 .11841 .38261 .12867 .37887 .11995 .38173 Mtetra
0 0 0 r
.11995 .38173 .12867 .37887 .139 .37497 .13015 .37918 Mtetra
.13015 .37918 .139 .37497 .14937 .37094 .14042 .37648 Mtetra
.048 0 0 r
.14042 .37648 .14937 .37094 .1598 .36681 .15076 .37363 Mtetra
.107 0 0 r
.15076 .37363 .1598 .36681 .17027 .36258 .16115 .37067 Mtetra
.155 0 0 r
.16115 .37067 .17027 .36258 .18079 .3583 .17161 .3676 Mtetra
.192 0 0 r
.17161 .3676 .18079 .3583 .19135 .35398 .18212 .36443 Mtetra
.222 0 0 r
.18212 .36443 .19135 .35398 .20195 .34963 .19269 .36118 Mtetra
.245 0 0 r
.19269 .36118 .20195 .34963 .21259 .34527 .20331 .35783 Mtetra
.262 0 .027 r
.20331 .35783 .21259 .34527 .22327 .34091 .21399 .35436 Mtetra
.273 0 .053 r
.21399 .35436 .22327 .34091 .23399 .33655 .22472 .35077 Mtetra
.28 0 .073 r
.22472 .35077 .23399 .33655 .24475 .33218 .23552 .34702 Mtetra
.284 0 .086 r
.23552 .34702 .24475 .33218 .25555 .32776 .24637 .3431 Mtetra
.287 0 .097 r
.24637 .3431 .25555 .32776 .2664 .32322 .25728 .33904 Mtetra
.293 0 .108 r
.25728 .33904 .2664 .32322 .2773 .31849 .26824 .33492 Mtetra
.308 0 .126 r
.26824 .33492 .2773 .31849 .28827 .31345 .27923 .33097 Mtetra
.337 0 .157 r
.27923 .33097 .28827 .31345 .2993 .30807 .29023 .32744 Mtetra
.382 .01 .202 r
.29023 .32744 .2993 .30807 .31037 .30251 .30122 .32485 Mtetra
.427 .069 .252 r
.30122 .32485 .31037 .30251 .32148 .29697 .31218 .32344 Mtetra
.464 .12 .298 r
.31218 .32344 .32148 .29697 .33258 .29198 .32312 .32331 Mtetra
.484 .154 .331 r
.32312 .32331 .33258 .29198 .34369 .28768 .33408 .32407 Mtetra
.48 .162 .35 r
.33408 .32407 .34369 .28768 .35481 .28378 .34515 .32426 Mtetra
.465 .157 .357 r
.34515 .32426 .35481 .28378 .36598 .28007 .35639 .32291 Mtetra
.436 .135 .354 r
.35639 .32291 .36598 .28007 .37721 .27599 .36782 .31885 Mtetra
.403 .106 .343 r
.36782 .31885 .37721 .27599 .3885 .27156 .37943 .31205 Mtetra
.375 .078 .327 r
.37943 .31205 .3885 .27156 .39983 .2673 .39114 .30372 Mtetra
.349 .047 .304 r
.39114 .30372 .39983 .2673 .41119 .26346 .40289 .29479 Mtetra
.339 .025 .278 r
.40289 .29479 .41119 .26346 .42258 .26031 .41462 .28674 Mtetra
.334 .003 .246 r
.41462 .28674 .42258 .26031 .434 .25771 .42633 .27996 Mtetra
.33 0 .21 r
.42633 .27996 .434 .25771 .44549 .25514 .43804 .27438 Mtetra
.329 0 .177 r
.43804 .27438 .44549 .25514 .45704 .25239 .44977 .26973 Mtetra
.322 0 .149 r
.44977 .26973 .45704 .25239 .46865 .24929 .46153 .26551 Mtetra
.315 0 .129 r
.46153 .26551 .46865 .24929 .48033 .24589 .47334 .26146 Mtetra
.305 0 .114 r
.47334 .26146 .48033 .24589 .49207 .24229 .4852 .25735 Mtetra
.294 0 .101 r
.4852 .25735 .49207 .24229 .50387 .23857 .49712 .2531 Mtetra
.28 0 .085 r
.49712 .2531 .50387 .23857 .51572 .23481 .5091 .24867 Mtetra
.264 0 .065 r
.5091 .24867 .51572 .23481 .52762 .23103 .52112 .24407 Mtetra
.244 0 .039 r
.52112 .24407 .52762 .23103 .53958 .22724 .53319 .23934 Mtetra
.22 0 .005 r
.53319 .23934 .53958 .22724 .5516 .22346 .54532 .23449 Mtetra
.19 0 0 r
.54532 .23449 .5516 .22346 .56367 .21966 .55749 .22954 Mtetra
.153 0 0 r
.55749 .22954 .56367 .21966 .5758 .21584 .56971 .22449 Mtetra
.105 0 0 r
.56971 .22449 .5758 .21584 .58799 .21197 .58198 .21934 Mtetra
.044 0 0 r
.58198 .21934 .58799 .21197 .60024 .20804 .59429 .21406 Mtetra
0 0 0 r
.59429 .21406 .60024 .20804 .61254 .20402 .60665 .20866 Mtetra
.60665 .20866 .61254 .20402 .62489 .19988 .61905 .20311 Mtetra
.61905 .20311 .62489 .19988 .6373 .19561 .63149 .19739 Mtetra
.382 .833 .729 r
.63149 .19739 .6373 .19561 .64976 .19117 .64398 .19148 Mtetra
.508 .912 .847 r
.64398 .19148 .64976 .19117 .66227 .18655 .65649 .18539 Mtetra
.608 .948 .926 r
.65649 .18539 .66227 .18655 .67482 .18176 .66905 .17911 Mtetra
.676 .944 .961 r
.66905 .17911 .67482 .18176 .68742 .1768 .68164 .17266 Mtetra
.712 .913 .964 r
.68164 .17266 .68742 .1768 .70007 .1717 .69426 .16607 Mtetra
.726 .869 .948 r
.69426 .16607 .70007 .1717 .71276 .16648 .70692 .15938 Mtetra
.728 .823 .924 r
.70692 .15938 .71276 .16648 .7255 .16118 .71961 .15261 Mtetra
.482 .694 .961 r
.04273 .38856 .05043 .39529 .06017 .39368 .05233 .38795 Mtetra
.462 .722 .981 r
.05233 .38795 .06017 .39368 .06996 .392 .06199 .38728 Mtetra
.435 .748 .993 r
.06199 .38728 .06996 .392 .07982 .39024 .07173 .38653 Mtetra
.401 .768 .993 r
.07173 .38653 .07982 .39024 .08975 .38836 .08153 .38567 Mtetra
.359 .779 .976 r
.08153 .38567 .08975 .38836 .09974 .38631 .09142 .38466 Mtetra
.306 .775 .936 r
.09142 .38466 .09974 .38631 .10981 .38411 .10138 .38349 Mtetra
.246 .754 .874 r
.10138 .38349 .10981 .38411 .11995 .38173 .11142 .38215 Mtetra
.18 .715 .79 r
.11142 .38215 .11995 .38173 .13015 .37918 .12153 .38063 Mtetra
0 0 0 r
.12153 .38063 .13015 .37918 .14042 .37648 .13172 .37895 Mtetra
.13172 .37895 .14042 .37648 .15076 .37363 .14198 .37712 Mtetra
.01 0 0 r
.14198 .37712 .15076 .37363 .16115 .37067 .15232 .37513 Mtetra
.06 0 0 r
.15232 .37513 .16115 .37067 .17161 .3676 .16272 .37302 Mtetra
.102 0 0 r
.16272 .37302 .17161 .3676 .18212 .36443 .17319 .37077 Mtetra
.136 0 0 r
.17319 .37077 .18212 .36443 .19269 .36118 .18373 .36839 Mtetra
.164 0 0 r
.18373 .36839 .19269 .36118 .20331 .35783 .19433 .36588 Mtetra
.183 0 0 r
.19433 .36588 .20331 .35783 .21399 .35436 .205 .3632 Mtetra
.197 0 0 r
.205 .3632 .21399 .35436 .22472 .35077 .21574 .36032 Mtetra
.205 0 0 r
.21574 .36032 .22472 .35077 .23552 .34702 .22655 .35722 Mtetra
.211 0 0 r
.22655 .35722 .23552 .34702 .24637 .3431 .23744 .35389 Mtetra
.219 0 0 r
.23744 .35389 .24637 .3431 .25728 .33904 .24838 .35041 Mtetra
.234 0 0 r
.24838 .35041 .25728 .33904 .26824 .33492 .25938 .34691 Mtetra
.267 0 .012 r
.25938 .34691 .26824 .33492 .27923 .33097 .27039 .34377 Mtetra
.315 0 .058 r
.27039 .34377 .27923 .33097 .29023 .32744 .2814 .34133 Mtetra
.382 0 .117 r
.2814 .34133 .29023 .32744 .30122 .32485 .29237 .34024 Mtetra
.443 .038 .175 r
.29237 .34024 .30122 .32485 .31218 .32344 .3033 .34073 Mtetra
.486 .094 .222 r
.3033 .34073 .31218 .32344 .32312 .32331 .3142 .34268 Mtetra
.506 .126 .254 r
.3142 .34268 .32312 .32331 .33408 .32407 .32515 .34548 Mtetra
.488 .118 .264 r
.32515 .34548 .33408 .32407 .34515 .32426 .33624 .34725 Mtetra
.446 .086 .259 r
.33624 .34725 .34515 .32426 .35639 .32291 .34756 .34679 Mtetra
.371 .02 .234 r
.34756 .34679 .35639 .32291 .36782 .31885 .35914 .34272 Mtetra
.28 0 .196 r
.35914 .34272 .36782 .31885 .37943 .31205 .37094 .33503 Mtetra
.205 0 .156 r
.37094 .33503 .37943 .31205 .39114 .30372 .38287 .32509 Mtetra
.146 0 .114 r
.38287 .32509 .39114 .30372 .40289 .29479 .39485 .31409 Mtetra
.136 0 .086 r
.39485 .31409 .40289 .29479 .41462 .28674 .4068 .30392 Mtetra
.149 0 .062 r
.4068 .30392 .41462 .28674 .42633 .27996 .41871 .29521 Mtetra
.174 0 .041 r
.41871 .29521 .42633 .27996 .43804 .27438 .43058 .28808 Mtetra
.199 0 .022 r
.43058 .28808 .43804 .27438 .44977 .26973 .44245 .2823 Mtetra
.206 0 0 r
.44245 .2823 .44977 .26973 .46153 .26551 .45434 .27723 Mtetra
.204 0 0 r
.45434 .27723 .46153 .26551 .47334 .26146 .46627 .27252 Mtetra
.186 0 0 r
.46627 .27252 .47334 .26146 .4852 .25735 .47825 .26778 Mtetra
.162 0 0 r
.47825 .26778 .4852 .25735 .49712 .2531 .49028 .26289 Mtetra
.13 0 0 r
.49028 .26289 .49712 .2531 .5091 .24867 .50236 .25776 Mtetra
.093 0 0 r
.50236 .25776 .5091 .24867 .52112 .24407 .51449 .25239 Mtetra
.051 0 0 r
.51449 .25239 .52112 .24407 .53319 .23934 .52666 .24682 Mtetra
.001 0 0 r
.52666 .24682 .53319 .23934 .54532 .23449 .53888 .24107 Mtetra
0 0 0 r
.53888 .24107 .54532 .23449 .55749 .22954 .55114 .23518 Mtetra
.55114 .23518 .55749 .22954 .56971 .22449 .56344 .22914 Mtetra
.56344 .22914 .56971 .22449 .58198 .21934 .57578 .22295 Mtetra
.57578 .22295 .58198 .21934 .59429 .21406 .58816 .21662 Mtetra
.38 .822 .685 r
.58816 .21662 .59429 .21406 .60665 .20866 .60058 .21013 Mtetra
.475 .889 .777 r
.60058 .21013 .60665 .20866 .61905 .20311 .61303 .20347 Mtetra
.564 .937 .854 r
.61303 .20347 .61905 .20311 .63149 .19739 .62551 .19662 Mtetra
.637 .962 .909 r
.62551 .19662 .63149 .19739 .64398 .19148 .63803 .18959 Mtetra
.692 .964 .94 r
.63803 .18959 .64398 .19148 .65649 .18539 .65057 .18235 Mtetra
.728 .948 .951 r
.65057 .18235 .65649 .18539 .66905 .17911 .66314 .17495 Mtetra
.749 .921 .948 r
.66314 .17495 .66905 .17911 .68164 .17266 .67573 .16737 Mtetra
.759 .889 .936 r
.67573 .16737 .68164 .17266 .69426 .16607 .68835 .15966 Mtetra
.76 .854 .92 r
.68835 .15966 .69426 .16607 .70692 .15938 .701 .15185 Mtetra
.757 .82 .902 r
.701 .15185 .70692 .15938 .71961 .15261 .71368 .14397 Mtetra
.433 .673 .963 r
.03496 .38178 .04273 .38856 .05233 .38795 .04449 .38176 Mtetra
.42 .689 .974 r
.04449 .38176 .05233 .38795 .06199 .38728 .05408 .38167 Mtetra
.408 .705 .983 r
.05408 .38167 .06199 .38728 .07173 .38653 .06374 .38151 Mtetra
.395 .721 .989 r
.06374 .38151 .07173 .38653 .08153 .38567 .07348 .38124 Mtetra
.382 .736 .991 r
.07348 .38124 .08153 .38567 .09142 .38466 .0833 .38083 Mtetra
.367 .75 .989 r
.0833 .38083 .09142 .38466 .10138 .38349 .0932 .38027 Mtetra
.351 .761 .981 r
.0932 .38027 .10138 .38349 .11142 .38215 .10318 .37955 Mtetra
.33 .768 .966 r
.10318 .37955 .11142 .38215 .12153 .38063 .11324 .37867 Mtetra
.306 .77 .944 r
.11324 .37867 .12153 .38063 .13172 .37895 .12338 .37762 Mtetra
.277 .765 .914 r
.12338 .37762 .13172 .37895 .14198 .37712 .1336 .37641 Mtetra
.246 .754 .876 r
.1336 .37641 .14198 .37712 .15232 .37513 .1439 .37506 Mtetra
.213 .736 .831 r
.1439 .37506 .15232 .37513 .16272 .37302 .15427 .37355 Mtetra
.178 .714 .782 r
.15427 .37355 .16272 .37302 .17319 .37077 .16471 .3719 Mtetra
.146 .689 .731 r
.16471 .3719 .17319 .37077 .18373 .36839 .17523 .3701 Mtetra
0 0 0 r
.17523 .3701 .18373 .36839 .19433 .36588 .18582 .36815 Mtetra
.18582 .36815 .19433 .36588 .205 .3632 .19649 .366 Mtetra
.19649 .366 .205 .3632 .21574 .36032 .20723 .36365 Mtetra
.20723 .36365 .21574 .36032 .22655 .35722 .21805 .36106 Mtetra
.21805 .36106 .22655 .35722 .23744 .35389 .22895 .35824 Mtetra
.22895 .35824 .23744 .35389 .24838 .35041 .23991 .35526 Mtetra
.005 0 0 r
.23991 .35526 .24838 .35041 .25938 .34691 .25093 .35226 Mtetra
.071 0 0 r
.25093 .35226 .25938 .34691 .27039 .34377 .26197 .34962 Mtetra
.157 0 0 r
.26197 .34962 .27039 .34377 .2814 .34133 .273 .34768 Mtetra
.269 0 0 r
.273 .34768 .2814 .34133 .29237 .34024 .28401 .34699 Mtetra
.367 0 0 r
.28401 .34699 .29237 .34024 .3033 .34073 .29498 .34776 Mtetra
.432 0 0 r
.29498 .34776 .3033 .34073 .3142 .34268 .30595 .34976 Mtetra
.459 0 0 r
.30595 .34976 .3142 .34268 .32515 .34548 .31696 .35237 Mtetra
.405 0 0 r
.31696 .35237 .32515 .34548 .33624 .34725 .32814 .35388 Mtetra
.276 0 0 r
.32814 .35388 .33624 .34725 .34756 .34679 .33954 .3532 Mtetra
.019 0 0 r
.33954 .3532 .34756 .34679 .35914 .34272 .3512 .34911 Mtetra
0 0 0 r
.3512 .34911 .35914 .34272 .37094 .33503 .36308 .3416 Mtetra
.36308 .3416 .37094 .33503 .38287 .32509 .3751 .33187 Mtetra
.487 .827 .541 r
.3751 .33187 .38287 .32509 .39485 .31409 .38717 .32103 Mtetra
0 0 0 r
.38717 .32103 .39485 .31409 .4068 .30392 .39922 .31077 Mtetra
.39922 .31077 .4068 .30392 .41871 .29521 .41124 .30174 Mtetra
.41124 .30174 .41871 .29521 .43058 .28808 .42322 .29415 Mtetra
.42322 .29415 .43058 .28808 .44245 .2823 .43519 .28783 Mtetra
.43519 .28783 .44245 .2823 .45434 .27723 .44718 .28221 Mtetra
.44718 .28221 .45434 .27723 .46627 .27252 .45921 .27694 Mtetra
.45921 .27694 .46627 .27252 .47825 .26778 .47128 .27165 Mtetra
.47128 .27165 .47825 .26778 .49028 .26289 .4834 .2662 Mtetra
.4834 .2662 .49028 .26289 .50236 .25776 .49556 .26049 Mtetra
.357 .811 .689 r
.49556 .26049 .50236 .25776 .51449 .25239 .50777 .25454 Mtetra
.417 .854 .742 r
.50777 .25454 .51449 .25239 .52666 .24682 .52003 .24837 Mtetra
.476 .891 .791 r
.52003 .24837 .52666 .24682 .53888 .24107 .53232 .242 Mtetra
.529 .921 .835 r
.53232 .242 .53888 .24107 .55114 .23518 .54465 .23545 Mtetra
.579 .943 .872 r
.54465 .23545 .55114 .23518 .56344 .22914 .55702 .22874 Mtetra
.623 .958 .903 r
.55702 .22874 .56344 .22914 .57578 .22295 .56942 .22188 Mtetra
.662 .964 .926 r
.56942 .22188 .57578 .22295 .58816 .21662 .58186 .21485 Mtetra
.694 .963 .941 r
.58186 .21485 .58816 .21662 .60058 .21013 .59433 .20765 Mtetra
.72 .956 .948 r
.59433 .20765 .60058 .21013 .61303 .20347 .60683 .20027 Mtetra
.74 .943 .949 r
.60683 .20027 .61303 .20347 .62551 .19662 .61935 .19271 Mtetra
.754 .927 .946 r
.61935 .19271 .62551 .19662 .63803 .18959 .63191 .18496 Mtetra
.764 .908 .938 r
.63191 .18496 .63803 .18959 .65057 .18235 .64448 .17704 Mtetra
.77 .889 .929 r
.64448 .17704 .65057 .18235 .66314 .17495 .65708 .16894 Mtetra
.774 .869 .919 r
.65708 .16894 .66314 .17495 .67573 .16737 .6697 .16068 Mtetra
.774 .849 .908 r
.6697 .16068 .67573 .16737 .68835 .15966 .68234 .1523 Mtetra
.773 .83 .897 r
.68234 .1523 .68835 .15966 .701 .15185 .69501 .14381 Mtetra
.77 .811 .886 r
.69501 .14381 .701 .15185 .71368 .14397 .70769 .13525 Mtetra
.426 .67 .963 r
.02714 .37496 .03496 .38178 .04449 .38176 .03666 .37499 Mtetra
.43 .674 .965 r
.03666 .37499 .04449 .38176 .05408 .38167 .04626 .37495 Mtetra
.436 .679 .966 r
.04626 .37495 .05408 .38167 .06374 .38151 .05592 .37482 Mtetra
.444 .684 .967 r
.05592 .37482 .06374 .38151 .07348 .38124 .06567 .37458 Mtetra
.453 .69 .968 r
.06567 .37458 .07348 .38124 .0833 .38083 .07549 .37421 Mtetra
.462 .696 .969 r
.07549 .37421 .0833 .38083 .0932 .38027 .0854 .37371 Mtetra
.471 .703 .97 r
.0854 .37371 .0932 .38027 .10318 .37955 .09538 .37307 Mtetra
.48 .71 .971 r
.09538 .37307 .10318 .37955 .11324 .37867 .10544 .37228 Mtetra
.488 .718 .973 r
.10544 .37228 .11324 .37867 .12338 .37762 .11559 .37134 Mtetra
.495 .725 .974 r
.11559 .37134 .12338 .37762 .1336 .37641 .12581 .37025 Mtetra
.503 .733 .976 r
.12581 .37025 .1336 .37641 .1439 .37506 .1361 .36902 Mtetra
.509 .741 .978 r
.1361 .36902 .1439 .37506 .15427 .37355 .14648 .36765 Mtetra
.516 .749 .98 r
.14648 .36765 .15427 .37355 .16471 .3719 .15692 .36614 Mtetra
.522 .757 .982 r
.15692 .36614 .16471 .3719 .17523 .3701 .16745 .36448 Mtetra
.529 .765 .984 r
.16745 .36448 .17523 .3701 .18582 .36815 .17805 .36266 Mtetra
.537 .774 .985 r
.17805 .36266 .18582 .36815 .19649 .366 .18872 .36068 Mtetra
.545 .783 .987 r
.18872 .36068 .19649 .366 .20723 .36365 .19947 .35851 Mtetra
.554 .794 .988 r
.19947 .35851 .20723 .36365 .21805 .36106 .2103 .35613 Mtetra
.562 .805 .99 r
.2103 .35613 .21805 .36106 .22895 .35824 .2212 .35356 Mtetra
.565 .815 .992 r
.2212 .35356 .22895 .35824 .23991 .35526 .23217 .35084 Mtetra
.561 .824 .995 r
.23217 .35084 .23991 .35526 .25093 .35226 .2432 .34806 Mtetra
.54 .824 .998 r
.2432 .34806 .25093 .35226 .26197 .34962 .25426 .34548 Mtetra
.506 .813 1 r
.25426 .34548 .26197 .34962 .273 .34768 .26535 .34331 Mtetra
.452 .783 .998 r
.26535 .34331 .273 .34768 .28401 .34699 .27645 .34188 Mtetra
.405 .736 .992 r
.27645 .34188 .28401 .34699 .29498 .34776 .28754 .34131 Mtetra
.396 .685 .977 r
.28754 .34131 .29498 .34776 .30595 .34976 .29866 .3414 Mtetra
.427 .637 .944 r
.29866 .3414 .30595 .34976 .31696 .35237 .30983 .34176 Mtetra
.503 .611 .893 r
.30983 .34176 .31696 .35237 .32814 .35388 .32114 .34131 Mtetra
.568 .601 .846 r
.32114 .34131 .32814 .35388 .33954 .3532 .33262 .33939 Mtetra
.63 .61 .811 r
.33262 .33939 .33954 .3532 .3512 .34911 .34429 .33526 Mtetra
.679 .633 .796 r
.34429 .33526 .3512 .34911 .36308 .3416 .35612 .32892 Mtetra
.717 .668 .801 r
.35612 .32892 .36308 .3416 .3751 .33187 .36807 .32109 Mtetra
.748 .713 .819 r
.36807 .32109 .3751 .33187 .38717 .32103 .38008 .31243 Mtetra
.763 .766 .855 r
.38008 .31243 .38717 .32103 .39922 .31077 .39209 .30403 Mtetra
.763 .817 .895 r
.39209 .30403 .39922 .31077 .41124 .30174 .4041 .29628 Mtetra
.744 .854 .931 r
.4041 .29628 .41124 .30174 .42322 .29415 .41611 .28938 Mtetra
.717 .872 .954 r
.41611 .28938 .42322 .29415 .43519 .28783 .42812 .28323 Mtetra
.699 .875 .964 r
.42812 .28323 .43519 .28783 .44718 .28221 .44017 .27749 Mtetra
.69 .87 .966 r
.44017 .27749 .44718 .28221 .45921 .27694 .45225 .27193 Mtetra
.694 .863 .963 r
.45225 .27193 .45921 .27694 .47128 .27165 .46437 .26632 Mtetra
.701 .856 .956 r
.46437 .26632 .47128 .27165 .4834 .2662 .47654 .26055 Mtetra
.709 .848 .949 r
.47654 .26055 .4834 .2662 .49556 .26049 .48876 .25456 Mtetra
.716 .842 .942 r
.48876 .25456 .49556 .26049 .50777 .25454 .50102 .24836 Mtetra
.722 .837 .936 r
.50102 .24836 .50777 .25454 .52003 .24837 .51332 .24196 Mtetra
.727 .833 .93 r
.51332 .24196 .52003 .24837 .53232 .242 .52566 .23538 Mtetra
.732 .828 .925 r
.52566 .23538 .53232 .242 .54465 .23545 .53804 .22863 Mtetra
.735 .824 .92 r
.53804 .22863 .54465 .23545 .55702 .22874 .55045 .22172 Mtetra
.739 .82 .915 r
.55045 .22172 .55702 .22874 .56942 .22188 .5629 .21465 Mtetra
.742 .816 .91 r
.5629 .21465 .56942 .22188 .58186 .21485 .57538 .20742 Mtetra
.745 .812 .905 r
.57538 .20742 .58186 .21485 .59433 .20765 .58789 .20003 Mtetra
.748 .809 .901 r
.58789 .20003 .59433 .20765 .60683 .20027 .60044 .19247 Mtetra
.751 .806 .896 r
.60044 .19247 .60683 .20027 .61935 .19271 .61301 .18475 Mtetra
.754 .803 .892 r
.61301 .18475 .61935 .19271 .63191 .18496 .6256 .17686 Mtetra
.757 .801 .888 r
.6256 .17686 .63191 .18496 .64448 .17704 .63822 .1688 Mtetra
.76 .8 .885 r
.63822 .1688 .64448 .17704 .65708 .16894 .65087 .16059 Mtetra
.762 .798 .882 r
.65087 .16059 .65708 .16894 .6697 .16068 .66353 .15224 Mtetra
.765 .797 .88 r
.66353 .15224 .6697 .16068 .68234 .1523 .67622 .14375 Mtetra
.766 .796 .877 r
.67622 .14375 .68234 .1523 .69501 .14381 .68893 .13516 Mtetra
.768 .795 .875 r
.68893 .13516 .69501 .14381 .70769 .13525 .70165 .12647 Mtetra
.472 .69 .962 r
.01926 .36808 .02714 .37496 .03666 .37499 .02888 .36753 Mtetra
.491 .678 .949 r
.02888 .36753 .03666 .37499 .04626 .37495 .03858 .36687 Mtetra
.507 .666 .934 r
.03858 .36687 .04626 .37495 .05592 .37482 .04834 .36609 Mtetra
.52 .652 .918 r
.04834 .36609 .05592 .37482 .06567 .37458 .05819 .36519 Mtetra
.531 .639 .902 r
.05819 .36519 .06567 .37458 .07549 .37421 .06811 .36418 Mtetra
.54 .627 .887 r
.06811 .36418 .07549 .37421 .0854 .37371 .0781 .36305 Mtetra
.547 .616 .873 r
.0781 .36305 .0854 .37371 .09538 .37307 .08817 .3618 Mtetra
.553 .605 .859 r
.08817 .3618 .09538 .37307 .10544 .37228 .0983 .36044 Mtetra
.558 .596 .848 r
.0983 .36044 .10544 .37228 .11559 .37134 .10852 .35895 Mtetra
.563 .588 .837 r
.10852 .35895 .11559 .37134 .12581 .37025 .1188 .35734 Mtetra
.567 .581 .827 r
.1188 .35734 .12581 .37025 .1361 .36902 .12915 .35561 Mtetra
.57 .574 .818 r
.12915 .35561 .1361 .36902 .14648 .36765 .13958 .35375 Mtetra
.573 .569 .81 r
.13958 .35375 .14648 .36765 .15692 .36614 .15008 .35177 Mtetra
.576 .563 .802 r
.15008 .35177 .15692 .36614 .16745 .36448 .16065 .34967 Mtetra
.579 .559 .796 r
.16065 .34967 .16745 .36448 .17805 .36266 .17128 .34744 Mtetra
.581 .555 .789 r
.17128 .34744 .17805 .36266 .18872 .36068 .18199 .34509 Mtetra
.584 .551 .784 r
.18199 .34509 .18872 .36068 .19947 .35851 .19276 .34261 Mtetra
.586 .549 .78 r
.19276 .34261 .19947 .35851 .2103 .35613 .2036 .34 Mtetra
.589 .548 .777 r
.2036 .34 .2103 .35613 .2212 .35356 .21451 .33726 Mtetra
.591 .548 .775 r
.21451 .33726 .2212 .35356 .23217 .35084 .22549 .3344 Mtetra
.594 .548 .773 r
.22549 .3344 .23217 .35084 .2432 .34806 .23653 .3314 Mtetra
.596 .547 .77 r
.23653 .3314 .2432 .34806 .25426 .34548 .24763 .32827 Mtetra
.597 .542 .763 r
.24763 .32827 .25426 .34548 .26535 .34331 .2588 .32502 Mtetra
.596 .53 .751 r
.2588 .32502 .26535 .34331 .27645 .34188 .27003 .32163 Mtetra
.593 .51 .73 r
.27003 .32163 .27645 .34188 .28754 .34131 .28133 .31811 Mtetra
.587 .484 .705 r
.28133 .31811 .28754 .34131 .29866 .3414 .29268 .31446 Mtetra
.579 .458 .679 r
.29268 .31446 .29866 .3414 .30983 .34176 .3041 .31067 Mtetra
.573 .435 .656 r
.3041 .31067 .30983 .34176 .32114 .34131 .31558 .30675 Mtetra
.568 .42 .641 r
.31558 .30675 .32114 .34131 .33262 .33939 .32712 .3027 Mtetra
.566 .413 .633 r
.32712 .3027 .33262 .33939 .34429 .33526 .33871 .29851 Mtetra
.567 .414 .633 r
.33871 .29851 .34429 .33526 .35612 .32892 .35036 .29419 Mtetra
.572 .423 .641 r
.35036 .29419 .35612 .32892 .36807 .32109 .36207 .28973 Mtetra
.58 .441 .656 r
.36207 .28973 .36807 .32109 .38008 .31243 .37384 .28513 Mtetra
.592 .466 .678 r
.37384 .28513 .38008 .31243 .39209 .30403 .38565 .28041 Mtetra
.604 .495 .703 r
.38565 .28041 .39209 .30403 .4041 .29628 .39753 .27554 Mtetra
.617 .524 .727 r
.39753 .27554 .4041 .29628 .41611 .28938 .40945 .27054 Mtetra
.627 .548 .745 r
.40945 .27054 .41611 .28938 .42812 .28323 .42143 .2654 Mtetra
.634 .562 .756 r
.42143 .2654 .42812 .28323 .44017 .27749 .43345 .26012 Mtetra
.639 .57 .762 r
.43345 .26012 .44017 .27749 .45225 .27193 .44553 .25471 Mtetra
.642 .574 .763 r
.44553 .25471 .45225 .27193 .46437 .26632 .45765 .24916 Mtetra
.645 .577 .764 r
.45765 .24916 .46437 .26632 .47654 .26055 .46982 .24347 Mtetra
.648 .58 .765 r
.46982 .24347 .47654 .26055 .48876 .25456 .48204 .23764 Mtetra
.651 .584 .766 r
.48204 .23764 .48876 .25456 .50102 .24836 .4943 .23168 Mtetra
.655 .589 .769 r
.4943 .23168 .50102 .24836 .51332 .24196 .50661 .22558 Mtetra
.659 .595 .772 r
.50661 .22558 .51332 .24196 .52566 .23538 .51896 .21934 Mtetra
.663 .602 .776 r
.51896 .21934 .52566 .23538 .53804 .22863 .53134 .21296 Mtetra
.668 .61 .781 r
.53134 .21296 .53804 .22863 .55045 .22172 .54377 .20645 Mtetra
.673 .618 .786 r
.54377 .20645 .55045 .22172 .5629 .21465 .55624 .1998 Mtetra
.678 .628 .791 r
.55624 .1998 .5629 .21465 .57538 .20742 .56875 .19301 Mtetra
.684 .637 .797 r
.56875 .19301 .57538 .20742 .58789 .20003 .58129 .18608 Mtetra
.69 .648 .803 r
.58129 .18608 .58789 .20003 .60044 .19247 .59386 .17902 Mtetra
.696 .659 .81 r
.59386 .17902 .60044 .19247 .61301 .18475 .60647 .17182 Mtetra
.703 .672 .817 r
.60647 .17182 .61301 .18475 .6256 .17686 .61911 .16448 Mtetra
.71 .686 .825 r
.61911 .16448 .6256 .17686 .63822 .1688 .63179 .15701 Mtetra
.717 .701 .834 r
.63179 .15701 .63822 .1688 .65087 .16059 .64449 .1494 Mtetra
.725 .718 .843 r
.64449 .1494 .65087 .16059 .66353 .15224 .65722 .14165 Mtetra
.733 .735 .853 r
.65722 .14165 .66353 .15224 .67622 .14375 .66998 .13377 Mtetra
.741 .753 .862 r
.66998 .13377 .67622 .14375 .68893 .13516 .68276 .12576 Mtetra
.749 .771 .872 r
.68276 .12576 .68893 .13516 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Sooooo`03oko5gol0003ooooo01Gooooo00?o
0000ooooooooool0DOooool0063ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`0Mooooo`?o00000_ooool00ol0003oooooooooo`1Oooooo`?o_lGO00?o
0000oko5goooool05Oooool00ol0003oooooooooo`1@ooooo`00H?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol0000Looooo`;o0000IOooool00onm`=co_lGOoko5g`02oko5g`03o`000?o4
bmoooooo01Cooooo00?o0000ooooool00000DOooool0063ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0001[ooooo0ol0001Vooooo`?o_L3L0onoaMl00ol0003oa<_O
olC;g`0Fooooo`03o`000?oooooooooo04oooooo001Pooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool0000Hooooo`;o0000J?ooool5okg0g003oko5goo4bmoo000000?o
a<_O5_ooool00ol0003oooooooooo`1>ooooo`00H?ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l000005Oooool3o`0000;ooooo00?o0000ooooooooool0Hoooool00onk_=[o
_L3Lokg0g003okg0g004olC;h?o4bmooa<_Oo`0000;oa<_O00?oaLoRooooooooool05?ooool00ol0
003oooooooooo`1>ooooo`00H?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4
A?l000004oooool2o`0006Wooooo1?nk_=X3okg0g0?oa<_P00?oa<_Oo`000?o4bml00oo5cn8Foooo
o`03o`000?oooooooooo04gooooo001Pooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omg
MgOo0000ooooo`0?ooooo`?o0000JOooool00oni]mOo^kcJok^lfP04ok^lfP03okg0g?o4bn3oa<_P
00?oa<_P00?o0000olG?h_o5cn800oo5cn8Fooooo`03o`000?oooooooooo04cooooo0022ooooo`;o
0000Joooool3okVge`Co^kcJ00?o`lcQolC;h?o4bn000oo4bn000oo5e>Go0000olG?hP03olG?hP03
ol7Ai_oooooooooo01Cooooo00?o0000ooooooooool0C?ooool007oooooo0ol00002ooooo`03o`00
0?oooooooooo06Oooooo1?ni]mL3ok^lfP?o`lcQ0oo4bn02olGDi@03o`000?o5e>GoaLoR00Co`M7V
5?ooool3o`0004gooooo001looooo`?o0000KOooool00ong/mGo^KOGokVge`04okVge`03ok^lf_o3
c>7o`lcQ00?o`lcQ00Koa<_PolGDiOo5e>GoaMCUo`000?o2f^/5ol7AiQOooooo00?o0000oooooooo
ool0B_ooool007[ooooo0_l0001^ooooo`Co]k?E1?ni]mL6ol?<h@;oa]WX0oo5e>D00oo2f^_o0000
ol;Jj`03ol7AiP;o^];/5_ooool00ol0003oooooooooo`1:ooooo`00Moooool3o`0006kooooo00?o
]JoCokNceOng/mD01?ng/mD00oni]mOo`lcQol?<h@04ol?<h@Goa]WX00KoaMCUol;Jjoo2f^_o0000
ol;Jjoo1dNH5ok[Bk1Kooooo00?o0000ooooooooool0BOooool007Gooooo0_l00002ooooo`03o`00
0?oooooooooo06[ooooo1?ne[m<4okNce@03ol;<h_o3c>7o`lcQ00?o`lcQ0_o6g^/4olKIj005ol;S
koo2f^_o`][[ol;Jjol000000_nig_84ok[Bk003ojk>lOoooooooooo01Gooooo00?o0000oooooooo
ool0B?ooool007;ooooo0ol00005ooooo`03o`000?oooooooooo06Oooooo00?o/jcAokF_done[m<0
0one[m<3okNce@?o`/cR0oo3c>44olKNj`03olKIj?o2hnoo`^?_00;o`^?_00?o`][[okWNl_l00000
0onig_800onjd^co[/kaojk>l@02ojk>lAKooooo00?o0000ooooooooool0B?ooool0073ooooo0_l0
001aooooo`?o/jcA1One[m<00ong/mGo`/cRol;<hP03ol;<hP03ol?<hOo6g^_oa]k[00;oa]k[00?o
_n_bol;Skoo2hnl00_o2hnl2okKYmP04okWNl_l0003o^MkbokWNlP;oZm[h1On^c_4Fooooo`03o`00
0?oooooooooo04Oooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000Pooooo`?o0000L_ooool4ok>/d@Co]JoC0_o1cN<4ol;<hP;oaN?]0oo6g^/3oko[lP03ol;S
konfjOKo]^Wf00?o]^Wf00?o0000oj_Jn?n[f_P00on[f_P2ojk>l@;oWlOd5Oooool3o`0004Sooooo
000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A00Nooooo`;o00000oooool00ol0003oooooooooo`1]ooooo`03ok:Xconc[=7o/jcA00Co
/jcA00?o]JoCol7=hoo1cN<00oo1cN<00oo2c>;oaN?]olGSk@03olGSk@04olKNjonojo;o_n_boko[
lP?o[O7f0_nfjOH2ojCUn`04o`000?nTiO_oZm[hoj_Jn0;oVm3j1OnOao@Fooooo`03o`000?oooooo
oooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo02Wooooo000hooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP0Looooo`?o0000Loooool4ok:Xc`Co/jcA00?o`LgTol7=hoo1cN<00oo1cN<2ol?Xl0CoaN?]0_nj
l_<00onojo;o[O7fojgamP02ojgamP;oU^[h0onTiO/00ol0003oTmWnoi?IoP04oi_@nPGoWlOd5_oo
ool00ol0003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo
00?o0000ooooooooool0:_ooool003Sooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^01Sooooo0ol0001dooooo`03ok2UcOnbZ<oo/ZS?00?o/ZS?0onc[=43ol7=i0?o`LgS
1?o3j?001?o5hngo^_;cok[blonjl_<3oi_bk@03ojgam_nFj_SoU^[h00?oU^[h00?oY>Gkoi?Io_l0
00000onCfOh4oi_@nP;oWlOd0onA_O@Fooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000:oooool003Sooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Gooooo0ol0001dooooo`Co/:G=1OnbZ<l00onc[=7o`LgTol7=i003ol7=
i003ol7=hoo3j?3o`nS`00;o`nS`0_nam_001?njl_?oVo;]oi_bkOnKl^d4ogkVjP;oU^[h1?n6gOd0
0ol0003oTmWnohS8o@02ohS8o@CoS/?i1OnA_O@Eooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002cooooo000hooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`0Aooooo`?o00000oooool00ol0003ooooo
ooooo`1_ooooo`03ojnSc?n`YLgo/:G=00?o/:G=1?nbZ<l2ol3>i@Co`LgT0oo1kO801?o3j?3o/OK`
ok7fl?nam_02oh;Yf0?oGmO?0_mni^X4og?Lm@;oQ]gm0_n2c?l00ol0003oR<SmohS8o@03ohS8o@Co
S/?i0_nA_O@2ohVclAKooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOoooooo0000;?ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooooiRHV?l@41004Oooool2o`0007Oooooo0on_Xl`5ok2Uc@03ok:Xcoo0
c^Go`<kU00?o`<kU00?o`LgTol7]l_o1kO800_o1kO82oj?fj003ok7fl?n2jMSoP^WH00?oGmO?0_mL
dn@3og3?oPGoNLko0_n2c?l01?l0003oP/coohS8oOn8b?d2ohNdl`GoR;?b1?n9/o4Fooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000002co
oooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00kooooo0ol0001hooooo`Co[j?<1?n`YLd00onocnKo`<kUol3>i@03ol3>i@;o_O7b0oo1kO82oj?f
j003of7E^_lm_J_o?Kf[00;o@LC;1?mVcoX4og3?oP;oNLko0_n5/o<2ohJdl`03o`000?n6]??oQ[Cc
00CoQkCc1On8/o84ohVclACooooo0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0oo^k^koA4A4o`00000/ooooo`00FOooool3o`0007Sooooo00?o[J3:ojnSc?n_Xl`00on_Xl`3ok2U
c@?o_loV0oo0c^D4okgalP03ol7]l_nSm^SoXoKX00;oElca1?mNcOH2ofK?nP;oQ[7a1On5/_<4ohFc
l`03ohJdlol0003oQ[Cc00;oQ[Cc1?n7]?<2ohRclP;oRJ_/1?n8[^hCooooo`04o`000?oooooooooo
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02_ooooo001F
ooooo`?o00000oooool00ol0003oooooooooo`1cooooo`Co[J3:1On_Xl`00on`YLgo_loVoko?iP03
oko?iP03ol3>iOnmlO;o_O7b00;o_O7b0_n@kmX4ohZ]k@GoR:o_1?n6/O45ohFbl`CoQK?c00Co0000
ohJdlon;Y>GoRjCU1?n:YnP5ohV[k0CoR:k^5_ooool00ol0003oooooooooo`10ooooo`00E?ooool2
o`0007[ooooo00?o[9k9ojfPb_n]X<X00on]X<X4ojnSc0;o_/oW1?nocnH3okSdlP03okgal_n@km[o
T>oJ00?oSJ[Y1?n:[Nd5ohR_k`CoQ[7a0_n5/_<2ohjLg@CoS:3Q00?o0000oh^TiOn;Y>D00_n;Y>D4
ohZWj0CoRJ_/1?n8[^hFooooo`03o`000?oooooooooo043ooooo001Aooooo`?o0000N_ooool4ojbN
b@Go[J3:00?o[j?<okk?ionncnL00onncnL00onocnKo^?CbokSdlP02okSdlP03ogWSa_n?YnGoSjOU
00GoSJ[Y1?n:[Nd2ohR_k`;oT9CD1?n?V=P4ohjLg@CoS:3Q00?o0000oh^TiOn;Y>D00_n;Y>D4ohZW
j0;oRJ_/0_n@YN@5ohj/jQKooooo00?o0000ooooooooool0?oooool004kooooo1Ol0001iooooo`03
oj^Laon/W/Wo[9k900?o[9k91?n]X<X2okg@j0Co_/oW0onam_000onhm?;oTZCQohnWi@04ohnWi@;o
SJ[Y0_nCSLX4oi:Ac`GoT9CD1?n?V=P4ohjLg@?oS:3Q00?o0000oh^TiOn;Y>D00_nBVML4oi6Og@Go
T:GT1On>[>XFooooo`03o`000?oooooooooo03kooooo001<ooooo`;o00001Oooool00ol0003ooooo
ooooo`1dooooo`CoZic71On/W/T00on]X<[o_M3Xokg@j003okg@j003okk?ionam_3o/OK`00;o/OK`
1?nBY>42ohnWi@;oU8[61OnCSLX4oi:Ac`CoT9CD1On?V=P3ohjLg@;oS:3Q00?oTi?Ao`000?nBVML0
1?nBVML4oi6Og@GoT:GT0_n>[>X2oiV_iaKooooo00?o0000ooooooooool0?_ooool004Wooooo0ol0
001jooooo`;o;P0000?oZI[6oj^Laon[W<L00on[W<L4ojbNb@03okgAj_nmd>So_M3X00?o_M3X0onY
m^d00onam_3oU:3MoiJ4_P04oiF7`PGoU8[61?nCSLX4oi:Ac`GoT9CD0_n?V=P2oiB9a@?oU8k;1?nC
Tm400ol0003oTYWGoi:Ie`02oi:Ie`GoTIoM0_n@YN@2oiZWg`GoVJoW5?ooool3o`0003oooooo000R
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08?ooool2o`0007[ooooo00?o;`00obh00?l^00001?nY
V/H4oj^La`?o[9k90onmdNX3okg@j0?oZOK]00?oUX6joiJ4__nFQ;h00_nFQ;h4oiF7`PCoU8[61?nC
SLX5oi:Ac`;oT9CD0_nEQL04oiB9a@CoU8k;0onCTm400ol0003oTYWGoi:Ie`03oi:Ie`;oTIoM0_nJ
WmP5oiZWg`GoVJoW5Oooool00ol0003oooooooooo`0mooooo`008_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg01gooooo0ol00002ooooo`03o`000?oooooooooo07?ooooo0_l`0003obl00003ojRHaOnY
V/KoZI[600?oZI[61On[W<L00on/W/Wo_M7ZokgAjP03okgAjP03okg@j?nYm^goZOK]00CoUX6j0onF
Q;h4oiF7`PCoU8[61OnCSLX2oi:Ac`;oUX:l1OnEQL04oiB9a@?oU8k;0onCTm401?l0003oTi?Aoi:I
eonBVML2oi^Id@GoVYoH1OnJYml2oiV_i`?oY;GT5Oooool00ol0003oooooooooo`0looooo`008_oo
ool01Ol@413ooooooooooooooooo410@01_ooooo0_l0001gooooo`;o;`000ol`0002obl000CoZ9S5
1?nYV/H4oj^La`;o_=;[1?nmdNX2oioei`;oUWng1?nFPKX3oiJ4_PCoUHO21OnDR/H2oi>=bP;oUWng
1OnFP[`4oiF5`0CoU8W51?nDS//2oi>Cd@03o`000?nKTl_oViWA00CoViWA1OnJWmP2oiZWg`;oY:cM
1_nT]N@Eooooo`03o`000?oooooooooo03_ooooo000Rooooo`05o`000?ooooooooooooooool00000
6?ooool3o`0007Kooooo00?o<P00obl00?l_00000_l_0002oc000003obl00?nWU/CoZ9S500CoZ9S5
1OnYV/H00on[W<Oo_=;[okcBj`03okcBj`03okgAj_nOmNOoWoGW00CoUWng1?nFPKX4oiJ4_PCoUHO2
0_nDR/H2oiIl]0GoUWng1?nFP[`4oiF5`0CoU8W50_nDS//2oi^>a@;oVi?;00?o0000oi^CbonKTl/0
1?nKVM44oiZOf003ojBTe_nT[=goY:cM00?oY:cM1?nT]N@00on__>?oooooooooo`0Cooooo`03o`00
0?oooooooooo03_ooooo000Rooooo`05o`000?ooooooooooooooool000005_ooool3o`0007Cooooo
0_lf0003oc8000?o;`0000?o<000odl06?nWU/@00onWU/@4ojRHa@CoZI[60_nkdn`4okcBj`;oU?7O
0_nFO;D4oiIo]`GoUX6j0onFQ;h2oiF7`P;oUgVa1OnFO;@4oiIo]`CoUX:l1OnEQL02oiB9a@03oib9
_onKS/GoVhk500?oVhk500CoVi?;o`000?nKTl_oVi?;1OnKVM400onJWmSoY:CFojBTeP02ojBTePGo
Y:cM00?oY;GTojnlhon__><00_n__><Eooooo`03o`000?oooooooooo03[ooooo000Rooooo`05oa0@
4?ooooooooooooooool@41004oooool3o`0000;ooooo00?o0000ooooooooool0GOooool00olP003o
>P00ocX00002ocX000?oBP002Oooool2ocl000?o=P000olb00001Ol_003oD@0Koe406om?01SoYYG4
00GoYiK41OnXV<D00onYV/Ko^m?/ok_Ck003ok_Ck004okcBjonDlMooU?7OoiIj/P?oUWbe1OnFOkL4
oiJ1^P;oUXBn00?oUgN^oiMi/OnGNK400_nGNK45oiIl]0CoUWng1OnFP[`3oiF5`003oib6^onLRKoo
W8Vo00;oW8Vo1?nKS/D00onKTl_o0000oi^Cb`02oi^Cb`;oViWA0_nTW/l5ojBTePCoY:cM00?o[kGM
ojnlhon__><00on__><Fooooo`03o`000?oooooooooo03Wooooo000Rooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL04?ooool3o`00067ooooo0_l00002ob0000Co>P000om:0004odd000?oBP001?lo0003
ocH00003oc800?mF023oEP0P00?oD@0K1?nVUL@4ojNFa0CoZ9S50_njeNh4ok_Ck0;oQn_E0onFN[83
oiIl]@GoUWng0_nFPKX2oiMe[0CoUgN^1?nGNK44oiIl]0GoUWng1?nFP[`00onEQL3oW8Jkoib6^`02
oib6^`?oW8Vo1?nKS/D01OnKTl_o0000oi^CbonKTl_oY9S900GoY9k?1OnTY=H00onT[=go[kGMojne
g@02ojneg@?o[kcS0_nga>@Dooooo`;o0000>oooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0>ooooo`;o0000HOooool4o`000003ob000?m[6e?oJQUA00?oJQUA0omY5D`4ofP@A@?oIPXl1?mQ
0C43oe`09`CoEP0P00?oD@0KojFD`onVUL@01?nVUL@5ojNFa003ojRHaOnjeNko^]G^00?o^]G^00Co
^m?/ohO[eOn7jmGoUWV`1?nFN[84oiIl]@?oUWng00?oUW>YoiMe[?nGMJ`00_nGMJ`4oiMg[PCoUgVa
1OnFO;@4oiIo]`;oUX:l0_nLPkL5oib6^`?oW8Vo1OnKS/D00ol0003oY9S9ojBHb@02ojBHb@CoY9k?
1?nTY=H00on^[mSo[kGMojneg@04ojneg@03ojnlhonga>Co]lCT00;o]lCT5Oooool00ol0003ooooo
ooooo`0hooooo`00<_ooool5o`00063ooooo0_l00002of`LE0?oJa]C1?mZ6E43ofTEC0CoJ1150omV
2S`4of41<@?oG00W0omF0204ojFD``CoYYG41?nWU/@2okSFk`Co^]G^0_mii<X3oiIi/0GoUWZb0onF
O;D01?nFOkOoUW>YoiIcZOnFLjT5oiMe[0?oUgN^1?nGNK45oiIl]0;oUWng0_nLP;@5oib3]`CoW8Jk
1?nLRKl2oi^>a@03ojBDa?l0003o000000CoY9S91OnTW/l00onTY=Ko[ZoHojj_f002ojj_f0Co[kGM
00?o^<;RokO4i?nga>@00_nga>@00onjbNKoooooooooo`0Dooooo`03o`000?oooooooooo03Oooooo
000`ooooo`;o0000Hoooool00om^eZ?oK1]Bof`LE003of`LE0?oJa]C0omZ6E44ofTEC0?oJ1150omV
2S`4of41<@?oG00W00?oEP0PojFC`onUTl<01OnUU<<5ojJEa003ojNFa?nhe^oo^=K_00?o^=K_00Co
^]G^ogWTb_mii<[oUGN_1?nFNK05oiIj/P;oUWbe00?oUW:XoiIcZOnFLjT00onFLjT4oiMe[0CoUgN^
1?nGNK43oiIl]003oian/OnLP;CoW82d00;oW82d1OnLPkL5oib6^`;oW8Vo00KoY930o`000?l0003o
0000ojBDa?l00005ojBHb@;oY9k?0_n^Z]<6ojj_f003ojnegOnh`^;o^<;R00;o^<;R00?o]lCTok[9
i_njbNH00_njbNHEooooo`03o`000?oooooooooo03Oooooo000]ooooo`?o0000I?ooool00om^eZ?o
K1]Bof`KDP04of`LE0;oJa]C1?mZ6E43ofTEC0CoJ1150omV2S`4of41<@03oe`09onTT/?oYI?300Co
YI?31?nUU<<4ojJEa0;o]mOa1?nhe^l00omZf[goUWN^oiEg[`02oiEg[`GoUWV`0onFN[801?nFL:Ko
UW:XoiIbZ?nFLZP5oiIcZ@CoUgF/1?nGMjh4oiMi/@04oiIl]?nLO[7oW7jaoian/@GoW82d1?nLPkL5
oib6^`?o000000?oY930ojBDa?nTU<@00_nTU<@01Ol0003oY9S9ojBHbOnTV<Wo[jK?00Go[Z[C1?n^
[mP00onh`>3o^<;RokS2hP02okS2hP03okc=ionjbNKo^/WV00Co^/WV5Oooool00ol0003ooooooooo
o`0fooooo`00;?ooool2o`0006Gooooo00CoJ1E<of`KD_m/6e;oK1]B0om/75@3of/KD`CoJQUA0omY
5D`3ofP@A@CoIPXl1?mQ0C43ojBB``CoYI?31OnUU<<00onVULCo]mOaokOGl@03okOGl@03okSFkonF
MjkoUWN^00;oUWN^1?nEMjl4oiIi/004oiIj/_nFL:KoUW2VoiI`YPCoUW:X1?nFLjT4oiMe[0CoUgN^
0onGNK400onLO:ooW7jaoian/@03oian/@CoW82d1OnLPkL01?nLQ[_o0000o`000?l00004ojB@`0Go
Y9C400?o0000ojnVcon_Y/l00_n_Y/l5ojjZd`03ojj_f?nh`>3o^<3P00;o^<3P0_nh`^83okc=i`Co
^/WV0_nic^XEooooo`03o`000?oooooooooo03Gooooo000/ooooo`?o0000H_ooool3ofPEC0;oK1]B
1?m/75@3of/KD`?oJQUA1?mY5D`3ofP@A@?oIPXl0_mQ0C400omD03GoXi73ojBB``03ojBB``CoYI?3
1?nUU<<2okGIlPCo]mOa00?oFln`oiMg[OnFMjh00onFMjh4oiEg[`;oUWV`0_nEKjD5oiI`YP?oUW:X
1?nFLjT5oiMe[0CoUgN^00?oUgVaoial[onLO:l01OnLO[44oib0]0?oW8>g0ol00004ojB=_0?oY930
1?nTU<@00on_Xlco[jK?o`000003ojnVc`Co[Z[C00?o^L3OokS0h?nh`>000onh`>000onh`^;o_<gW
okc=i`03okc=i`03ok[9i_nic^[o^LkZ00?o^LkZ5?ooool00ol0003oooooooooo`0eooooo`00;?oo
ool01?l0003oooooo`000?l0001Pooooo`CoJ1E<0_m/6e84of`LE0;oJa]C1?mZ6E44ofTEC0?oJ115
00CoIPXloeD0?_mE03koE00e1?nSTL<4ojBB``CoYI?300?oYIC3okGIl_nefO800onefO800ongeo7o
Fln`oiMg[@02oiMg[@CoUWN^0_nEMjl2oiA]X`CoUFnU1OnFL:H3oiIbZ0CoUW>Y1OnGMJ`2oiMg[P;o
W7Z]1?nLO:l4oian/@CoW82d0ol000000onLPkOoY8^jojB=_004ojB=_0CoY93000?oY9C4ojnSc?n_
Xl`00_n_Xl`00ol0003o[jK?ojnVc`02ojnVc`03ojjZdoni`=oo^L3O00;o^L3O0onh`>02okgAj@Co
_<gW0_njf>l4okW>jP03ok7=k_oooooooooo017ooooo00?o0000ooooool000002?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`06Oooool0
02cooooo0_l00002ooooo`03o`000?oooooooooo05cooooo00CoH@]2ofPEC?mX5DcoJ1E<0om/6e83
of`LE0?oJa]C1?mZ6E43ofTEC0;oJ11500?oEPI7oeD0?_mE03h00_nRSl45oj>A``CoY9;30onUTl<3
ok?Km0?o]MWb00?o0000oiQh[OnGMjd01?nGMjd2oiIg[P03oi=/X_nDKJ?oU6fS00;oU6fS1OnEKjD4
oiI`YP?oUW:X1OnFLjT3oiMe[003oiahZonLNZgoW7Z]00;oW7Z]1?nLO:l4oian/@06oib0]?l0003o
0000o`000?nLP;CoW8>g1?nTRkX4ojB=_0?oY93000?o[j79ojnSc?n_Xl`00on_Xl`01On_Y/oo0000
ojnVcon_Y/oo^l7N00Ko^L3O00?o^<3PokgAjOnmdNT00_nmdNT00onlcNOo^]S_ok[Hk`03ok[Hk`03
okW>j_nacNko/Lg^00;o/Lg^5Oooool00ol0003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0Iooooo`00:oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo05[ooooo0_mQ2d83ofPEC0;oK1]B1?m/75@3of/K
D`?oJQUA0_mY5D`2oeT<C@;oEPI700?oX8bnoj:?`OnRSl400onRSl44oj>A``GoY9;300?oYI?3ok?K
m?ncfo@00oncfo@00onefO;oV7R]oiQh[@02oiQh[@CoUgN]00?oUWN^oi=/X_nCK:801?nDKJ<5oiE_
Y@CoUW2V0onFLZP5oiIcZ@04oiMe[?nLN:_oW7R[oiahZ`GoW7Z]0onLO:l3oian/@;o00000onLP;@0
0onTRKOoY8^jojB;^P03ojB;^PGoY8fl00CoY930ojnQbOn_XLWo[j791On_Xl`00on_Y/oo0000ok_1
gP02ok_1gPCo^L3O00?o_]O/okgAjOnmdNT00_nmdNT2okWRm0Co^]S_00?o/=Seok7=k_nacNh00ona
cNhEooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`00
0?ooooooooooooooool000006Oooool002_ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1Gooooo`03oeH0=OmQ2d;oH@]200CoJ1E<0_m/6e84of`LE0;oJa]C0_mZ6E42oelCD`CoF@a=
1?nPS;h4oj:?`@GoXi730onTT/<3ok7LmP;o/m_d0onJN:`4oiQh[@;oUgN]0_nCJj83oi=/XPGoU6fS
1?nEKjD4oiI`YPCoUW:X0onFLjT00onKMjWoW7R[oiahZ`03oiahZ`CoW7Z]0onLO:l3o`0000;oW7ja
00?oW82dojB9]onTRKL00_nTRKL4ojB;^PCoY8fl00?o/:37ojnQbOn_XLT00_n_XLT4ojnSc003okc3
gonk`Mko000000Co^l7N00?o^L3OokkGk?nnen`00_nnen`00onmdNWo^N;dokWRm003okWRm003ok[H
kon`f?Go/=Se00;o/=Se0_nacNh3ojO8lAGooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Iooooo`00:oooool3o`0000Go
oooo00?o0000ooooooooool0EOooool2oeH0=@;oH@]20omX5D`3of`KDPCoK1aD00?oJa]CofLKEomO
4e<00omO4e<2oeT<C@03oif6^_nPS;koX8bn00?oX8bn1?nRSl45oj>A``03ojBB`onag?Ko/Mcf00;o
/Mcf0_nHMJX5oiYh[0;oV7R]00?oU6bQoi=[X_nCJj800_nCJj84oi=/XPCoU6fS1?nEKjD5oiI`YP?o
UW:X00CoUW>Yoi]gZOnKMjWoVgNY1OnLN:/4oiaj[@?o000000GoW7b_oian/OnLO[7oW7jaojB7]P05
ojB9]`GoY8^j0_nTSK`3ok2Pa`?o[j790on_Xl`3okc3g`05ok_1g_l0003o^l7Nok_1g_nng^l01?nn
en`3ok?/m`;o^N;d0on[h_X2ok3Hm@?oXm7g1OnWb?4Eooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`06Oooool002_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Cooooo`;oEP0e0omQ2d83ofPEC0?oK1]B
0om/75@00om[6e?oIa]GofLKE`04oelCD`CoWHJj1?nPS;h5oj:?`@;oXi731?n`g_L00onag?KoV7FZ
oiQeZP03oiQeZPCoVWR/00?oV7R]oiA/XOnDK:401?nCJj84oi=/XPCoU6fS1?nEKjD5oiI`YP;oUW:X
00?oVgJXoi]gZOnKMjT00onKMjT4oiahZ`04oiaj[Ol0003o0000o`0000CoW7b_00?oW7jaojB7]_nT
QkH00_nTQkH4ojB9]`GoY8^j00?oY8flok2Paon`X<L00_n`X<L4ojnQb@03ojnSc?nl`moo_<?O00?o
_<?O00?o^l7No`000?nng^l00_nng^l00onnenco/ncgok?/m`02ok?/m`;oWN[j0on[h_X2oicIo0Go
Xm7g0_nWb?42oig0lAGooooo00?o0000ooooooooool00oooool01Ol@413ooooooooooooooooo410@
00_ooooo00?oEEEEohN7Qoooool06oooool002_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1@ooooo`04odP09_mF03GoEP0eoeH0=@;oH@]21?mX5D`2of`KDP;oK1aD0_m_8UX3ofLK
E`;oGa=C00?oVWjcoif6^_nMQ[X00onMQ[X5oj2<_P?oXXo10_nbgoH4ok3Nm`;oUG6X1OnHMJX2oiYh
[0;oUVfQ0onDK:45oi=[XP?oTfbR1?nDKJ<5oiE_Y@CoUW2V00?oUW:Xoi]fZ?nKMZP01OnKMjT2oiah
Z`?o00001?nLNZd2oial[`03ojB6]?nTQkKoY8Nf00?oY8Nf1OnTRKL3ojB;^P03ok6Oa_n`X<Oo/:37
00?o/:370on_XLT2okk7h@Co_<?O0_nmio<00onng^oo0000okkNk`03ojGbl`03ok?/monMj_[oWN[j
00?oWN[j00?oZn;joicIo?nLfO`00_nLfO`2oj?Am`?oV/?d1?nM`?4Cooooo`?o00001?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P06oooool0013ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`1=ooooo`?oB00V0omF03D2of4;@P?oJ1E<0_m/6e80
0omg:5_oKb9JoflRFP02oflRFP;oIa]G00?oUgN]oiYn/onJO[<00_nJO[<4oif6^PGoX8bn00?oXXo1
ok;Om_nbgoH00onbgoH00on`g_OoT6bUoiEaZ003oiEaZ0?oV7FZ00?oUVbPoiI]XOnFKJ400_nFKJ44
oiA/X@CoTf^R0onCK:84oiA]X`GoUFnU0onFL:H00onKMJOoVgJXoi]fZ002oi]fZ0?oVgNY0ol00002
oiahZ`GoW7Z]00?oW7b_ojB6]?nTQ[@01OnTQkH5ojB9]`03ojB;^_naWlKo/Io600;o/Io61On`X<L0
0on_XLWo_/OQokk7h@02okk7h@03okc3gonmio?o_NOc00?o_NOc00?o0000ojGblonUl_<01?n3inh2
oigZnP?oT=gn0_nLfO`3oiK6n0GoV/?d1?nM`?4Eooooo`09o`000?ooooooooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@6Oooool0013ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`?o00002_ooool00ol0
003oooooooooo`1;ooooo`?oB00V0omF03D3of4;@P;oJ1E<00CoNRUIogLXFomg:5_oMbQK1?m_8UX3
oiMg[@CoVWjc1OnMQ[X3oj2<_P;o]mod1?nbgoH4oi1/Y@?oUG6X00CoV7FZoiI/X?nFK:3oUVbP1?nF
KJ44oiA/X@CoTf^R0onCK:85oiA]X`CoUFnU00CoUW2Voi]eYonKMJOoVgFW1?nKMZP3o`000003oi]g
ZOnLN:_oW7R[00?oW7R[0onLNZd00onTQ[?oY8JdojB6]002ojB6]0GoY8Nf0onTRKL00onaX<Ko/Io6
ok6OaP03ok6OaPCo/:3700?o`LkUokk7hOnnan400_nnan43okOam0;o_NOc00GoQ^_NoeSBcomHd/oo
0000oeSBc`02oh?WkP?oNmck0_n@gOh3oi37nPGoU/Kh0_nJ`o@2oiNfk@CoV;S^5Oooool00ol0003o
ooooooooo`0_ooooo`002?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04Sooooo00?o0000od006_m8
02H00_m802H3oeH0=@;oH@]200CoJ1E<ogXYFOmj:EWoNRUI0omg:5/00om_8U[oU72WoiA`Y`05oiMg
[@?oVWjc1OnMQ[X00onPS;ko]modokOOm003okOOm003ok;Om_n<Ij?oT6bU00CoT6bU0_nELJP00onF
JikoUVbPoiI/X002oiI/X0CoUVfQ1?nDK:44oi=[XPCoTfbR1?nDKJ<3oiE_Y@03oiYdY_nKMJOoVgFW
00?oVgFW00?oVgJXo`000?l000001?nKMjT5oiahZ`04oiaj[OnTQ[?oY8JcojB6/`CoY8Jd1OnTQkH0
0onTRKOo/J36ok6PaP02ok6PaPGo/Io600?o/:37ol7>iOo1c^D00_o1c^D00onnan7o]o7dokOam002
okOam003oe?;/?l0003oAlKQ00?oAlKQ00CoH]C`o`000?n6`__oQ/;k1On:aO/4oi37nP;oU/Kh0_nF
/^/5oiNfk@CoV;S^5Oooool00ol0003oooooooooo`0^ooooo`004?ooool01Ol0003ooooooooooooo
oooo000000_ooooo00CoA4A4omgMgOoooooo00001_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo04Kooooo00?o0000od006_m802H00_m802H4oeH0=@03of4;@_mk9eCoNRUI00?oNRUI
00?oMbQKoi9/Y?nDL:L00onDL:L5oiMg[@CoVWjc0onMQ[X2okkJkPCo]mod1?n<Ij<4oi1/Y@03oiEa
Z?nFJikoUV^N00GoUVbP0onFKJ44oiA/X@CoTf^R1?nCK:84oiA]X`04oiE_YOnJM:KoVWBVoiYdYP?o
VgFW0ol00002oi]fZ0GoVgNY0onLN:/00onTQK?oY8JcojB6/`03ojB6/`?oY8Jd1?nTQkH00onbXLOo
/J36ok6PaP03ok6PaPCo/Io60_o2enT3ol7>i@?oYoG^00?o]o7doe?;/?mCbk000on6]?<3ohBln@03
ohK2nol0003oQ/;k00;oQ/;k0_n:aO/2oiBWh`GoUJkW1?nF/^/4oiNfk@;oV;S^0onJ]N/Eooooo`03
o`000?oooooooooo02gooooo000@ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgo
EEEEooooool00006ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0@oooool01?l0
003o?@0Dod006_m001X3odP09P03oeH0=Omf7TcoMQi<00?oNbMD0omj:ET3oi9/Y0GoU72W1?nGMjd4
oiYn/`03oif6^_nnf^ko_][^00?o_][^00Co]modohaVXOn<IZ7oS6JQ0on<Ij<3oi1/Y@04oi=WW?nF
JikoUV^NoiI[WPGoUVbP1?nFKJ43oiA/X@GoTf^R0onCK:82oiA]X`;oVG:V1?nJM:H3o`0000;oVgFW
0onKMZP5oi]gZ@04oiahZonTQK?oY8FcojB5/`GoY8Jc1?nTQ[@2ojB7]P?o/Z771OnaX<H00onaWlKo
`]OYol;Gj@03ol;Gj@04ol7>iOnWmNkoYoG^ojOekP?oRJW[1On6]?<3ohBln@04ohK2nol0003oU9oK
oiBOf`GoU:OS1OnE[^L3oiJbj`;oUkK]0onJ/>L5oiZejaCooooo00?o0000ooooooooool0;Oooool0
013ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo0_l0000?
ooooo`;o0000@?ooool00ol:003o0000ocd05002ocd050;o@00J00?oB00VofdA@?mf7T`00omf7T`3
og/WE003ogXYFOnAJJ;oTVbT00CoTVbT1?nDL:L4oiMg[@CoVWjc0_o3dND3okkJkP03ohiWXOn<IZ7o
S6JQ00;oS6JQ0on<Ij<01?n@K:GoTfNLoi=WW?nCIi`4oiI[WPCoUVbP1?nFKJ43oiA/X@GoTf^R0_nC
K:800onHLJGoVG:VoiUbYP02oiUbYP05oiYdY_l0003o0000o`000?nJM:H01?nKMJL4oi]fZ0?oVgNY
00?oY8JcojB5/onTQK<00onTQK<4ojB6/`CoY8Jd00?oY8Nfok:QaonbXLL00_nbXLL4ok6PaP;o`^C_
1?o2enT2oh?Yd`03ojOek_n>W]koRJW[00CoRJW[0_n6]?<2oiJ?bP?oUIOC0_nDWm/00ol0003oU9oK
oiBOf`05oiBWh`;oUJkW0_nKY=`4oiZZhPGoV[3W0_nJ]N/2oj2fj1Gooooo00?o0000ooooooooool0
;?ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0kooooo`;o2P0000Co?@0Aocd05?lm01Co
?@0D0_m001X00om802KoKA50ofdA@004ogHNC0;oT6VR0onAJJ85oi9/Y0CoU72W1OnGMjd2oiYn/`Co
`m7U00?o_][^ohiWXOn>Ij401?n<IZ42ohaWX`03oi1TVonCIicoTfNL00;oTfNL1?nFJih4oiI/X0Co
UVfQ1?nDK:44oi=[XP03oi=/X_nHLJGoV76U00;oVG:V0ol00004oiYdYPCoVgFW1?nKMZP01?nKMjWo
Y8JcojB6/onTQ[<5ojB5/`GoY8Jc0_nTQ[@00oncY<Wo/Z77ok:Qa`03ok:Qa`?o/J361?o2i>l01?o2
enWoPnWCoh?YdonBTm44ohjNgP;oRJW[0_nGR<44oiJ?bPCoUIOC0_nDWm/00ol0003oU9oKoiBOf`02
oiBWh`;oW9kE1OnKY=`4oiZZhP;oV[3W0_nP[n85oj2fj1?ooooo0_l0000^ooooo`004?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo03Sooooo00?o3@00o`X00?l:00000_lm0142ocd050;o@00J00?oH@8c
ofdA@?m]4D000_mf7T`00onAJjCoT6VRoi1YXP02oi1YXP?oTFVR1OnBK:@4oiA`Y`GoUgN]00?oVWjc
ol?AiOo3dND00_o3dND01?nBJZ7oSVNQohiWXOn>Ij42ohaVX@;oSV:I0on@I9/5oi=WW0?oUV^N1?nF
K:04oiI]X@CoU6bQ0onCJj800onGL:GoV76UoiQaY@03o`0000?oVG:V1?nJM:H5oi]eY`?oVgJX1OnT
Q[<4ojB5/`GoY8Jc00CoY8Jdok>TbOncY<Wo/jC91OnbXLL00onaX<Ko`^C_ol;Tk`02ol;Tk`05o`00
0?nBTm7oTY?Aoi:CdOnJO[801?nIP[T5oiN8`@CoUXo:1?nEUm<01?nDWm_o0000oifHc_nMV<h4oibN
e@GoVjCL0_nJZ^82oj6Xg0GoX:oR1?nP]^PEooooo`03o`000?oooooooooo02_ooooo000Yooooo`;o
00005?ooool00ol0003oooooooooo`0dooooo`05o`X00?l=003o3@00o`X00?lo01400_lm0143ocd0
50?oH@8c0_m]4D03oi5[Y0CoT6VR1?nAJJ84oi9/Y0GoU72W0onGMjd2ol?4fP?o`m7U0_nBJZ42ohiW
X@03ohiQVOn>HYWoSV:I00;oSV:I0on@I9/5oi=WW0?oUV^N1?nFK:04oiI]X@CoU6bQ00?oTf^RoiM`
YOnGL:D00ol00002oiQaY@CoVG:V1?nJM:H5oi]eY`;oVgJX00?oYHJdojB6/onTQ[<00onTQ[<5ojB5
/`?oY8Jc00?o]:O<ok>TbOncY<T00_ncY<T4ok:Qa`?o_?7c00?o`^C_oiF:aOnER/D00_nER/D00onB
Tm7oVWjboiYn/P05oiV2^@CoUhS11?nFSlX2oiFGd`;oWY;70_nMV<h00ol0003oWIS>oifHcP04oibN
e@?oVjCL00?oXZ?Foj6Xg?nQZ=`00onQZ=`5oj2_hP;oX;KX0_nW^^LEooooo`03o`000?oooooooooo
02[ooooo000Yooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0<Oooool2o`X00003
o`d00?m000oo?`0A00;o?`0A0_lm01400olm01CoEP0Xof42<`02of42<`03ofdA@?nBKjOoTF^T00?o
TF^T1?n@JJ84oi5YXPCoTVbT1OnDL:L00onGMjgo`lCJol?4fP03ol?4fP04ol?AiOnBJZ7oSf:IohmR
V@?oSV6I1?n>HYT4oi1TV`CoTfNL0onFJih5oiI/X0?oUVfQ0_nDK:42oiQaY@04oiM`YOl0003o0000
oiM`Y@CoV76U1?nILZH5oiYdYPCoVgFW00CoVgJXojF6]?nUQ[CoYHJd1?nTQ[<5ojB5/`03ojB6/ond
Ylco]:O<00;o]:O<1?ncY<T00onbXLOo_?7cokcal`02okcal`;oUh>k0_nER/D2oiaj[@CoVWjb1?nI
P[T5oiN8`@;oUXo:00?oX8g1oijBaonNT/L00onNT/L2oifHcP03o`000?nMV<koW9kE00?oW9kE00?o
VjCLoj:Se_nRXmH00_nRXmH5oj6Xg0;oX:oR0_nX]N85ojNjiaCooooo00?o0000ooooooooool0:_oo
ool002Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0^ooooo`03o`<00?l:003o
2P0000?o@00?0_lo0143ocd04@;oEP0X0_nDMJd3oi9_Y`GoTF^T0on@JJ84oi5YXPGoTVbT0onDL:L0
0ono]]7o`lCJol?4fP03ol?4fP03oi1SVOn?HYWoSf:I00;oSf:I0on>HIT4ohiRV@CoT6BK1?nCIi`3
oiI[WPGoUVbP0_nFKJ400onJLZGoV76UoiQaY@03o`0000CoUg2U0onHLJD4oiUbYPGoVWBV0onKMJL0
0onUQkCoYHJdojF6]002ojF6]0GoY8Jc0onTQK<00one[=3o]:O<okBWc003okBWc0?o/jC90onXmn/0
1OnllO?oUh>koiN3^onGPk_oWGRY00CoW7Z]1?nJO[84oiV2^@CoUhS100?oXXZkoj2=`OnPSL400_nP
SL44oijBa`?oWIS>00Go0000oifHc_nLW]GoW9kEoj>Mc`05oj:SePCoXJSL00?oZK7MojReh_nX]N80
0onX]N83ojNji`;o[L3W5?ooool00ol0003oooooooooo`0Yooooo`00:Oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo02[ooooo00Go0000o`<00?l3003o2P00ocl03@03od003`;o?`0A
00Co?@0Aodh08?nFNkCoUW^d1?nDMJd3oi9_Y`GoTF^T0on@JJ84oi5YXPGoTVbT0_nDL:L3oknfd@?o
`lCJ0_n@HiT4ohmRV@?oSV6I1?n>HYT4oi1TV`CoTfNL1?nFJih4oiI/X003oiI]XOnJLZGo000000;o
00000onHLJD4oiM`Y@?oV76U1OnILZH4oiYdYP04oi]eYonUQkCoYHNdojF7]0CoYHJd1OnTQ[<00onT
QK?o]Jc@okF/d002okF/d0Go]:O<00?o/jC9ojSgjonXmn/00onIOK<01?nGPk_oWGRYoiehZOnMN:T5
oiaj[@?oVWjb1OnIP[T00onGR<7oXXZkoj::^`02oj::^`?oX8g11OnNT/L2oifHcP03o`000?nUVLWo
Xig?00?oXig?1OnRXmH00onQZ=coZK7MojVag@02ojVag@CoZ;GR00?oYk[Wojg0ion]`>L00on]`>LD
ooooo`03o`000?oooooooooo02Sooooo000Yooooo`?o00005oooool00ol0003oooooooooo`0Xoooo
o`03o`000?l3003o?00800?o?`0=0_m000l00olo017oB`0KoiN2^P04oiIk]0GoU7F]0onBKjL4oi5[
Y0CoT6VR0onAJJ85oi9/Y003oiA`Yono]]7o_kKA00?o_kKA00Co`lCJoi1SVOn@HiWoT6>I1?n?HYT4
ohiQV@?oSV:I1?n@I9/4oi=WW0CoUV^N0onFK:03o`000003oiYbYOnHLJGoV76U00?oV76U1?nGL:D3
oiQaY@GoVG:V0onJM:H00onUR;KoYHNdojF7]003ojF7]0CoYHJd0onTQ[<00onf/]Go]Jc@okF/d003
okF/d0Co]:O<00CoO>G8oiYi[OnJNJgoVWV]0_nIOK<00onNMjKoWGRYoiehZ@03oiehZ@CoW7Z]1?nJ
O[83oiV2^@03ojB7]_nRR[_oXXZk00?oXXZk0onPSL44oijBa`06ojNGaOnUVLWoYIW9ojFIbOl0003o
YIW91?nSWLl2oj:SeP;oZjgI1OnY/Md2ojRehP?o[kkU1?n]`>L00on`aNWoooooooooo`0Aooooo`;o
0000:_ooool002Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Uooooo`;o0000
0oll00P2ocl03@03od003onHQl3oV8O000?oUh:j1OnFNk@4oiAe[@?oTVnW1?nAJj@4oi1YXPCoTFVR
0onBK:@00ongZlgo_kKAoknfd@04oknfd@04oi5TVon@HiWoT6>Ioi1SV@CoSf:I1?n>HIT3ohiRV@Co
T6BK1?nCIi`4oiI[WP?o000000?oWGBUoiYbYOnJLZD00_nJLZD4oiQaY@CoUg2U1?nHLJD4oiUbYP03
oiYdY_nUR;KoYHRf00;oYHRf1?nUQk@4ojF6]003ojB6/onf/]Go][;E00;o][;E1One[=000ondYlco
O>G8ogcUb004oiYi[@03oiUm/onNMjKoWWNV00GoWGRY1?nLNZd4oiYn/P03oiV2^OnTQkKoY8Nf00;o
Y8Nf1?nRR[/4oj2=`@03oijBaonWUlGoYiO500;oYiO50onUVLT01Ol0003oXig?oj>MconSWLoo[J_F
00GoZjgI0onY/Md00on`_^Co[kkUojnni@04ojnni@03ojg0ion`aNWo/<GY00;o/<GY5?ooool00ol0
003oooooooooo`0Wooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02;ooooo0_l000001_lh
00;o?008oc`02?ll00So?`0=oiR:``CoV8O01?nGP[X4oiIk]0CoU7F]0onBKjL4oi5[Y0CoT6VR1?nA
JJ82oi9/Y0?o]j_=1?no]]42oi5TV`CoT6>I0on?HYT4ohiQV@CoSV:I0on@I9/5oi=WW0?o00001?nM
M:D4oiYbY@CoV76U1?nGL:D4oiQaY@?oVG:V1_nUR;H4ojF7]0CoYHJd1Onf/]D4okF/d003o`000?nK
MjWoVgNY00CoVWV]00?oWgJToiigY_nNMjH00_nNMjH4oiehZ@GoW7Z]0_nJO[800onVQ[?oY8NfojB7
]P03ojB7]PGoXXZk0_nPSL400onYUL7oYiO5ojNGa@03ojNGa@?oYIW900?o0000ojFIbOnSWLl00on]
ZmH5oj^]f@04ojVagOn`_^Co/;kTok2ni0Co[kkU00?o/LOZok35jOn`aNT00on`aNTEooooo`03o`00
0?oooooooooo02Kooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool07oooool00ol0003o<`00ocP00P02ocP00P;oV8c51?nHR/<4oiR7`0?oUh:j1?nFNk@4oiAe[@?o
TVnW1?nAJj@4oi1YXPCoTFVR00?oTVbTokN[cOngZld00_ngZld3oknfd@?oTFBK1?n@HiT3ohmRV@Co
SV6I1?n>HYT3oi1TV`;oTfNL0ol00002oiI[WP03oimfY?nMM:GoWGBU00?oWGBU0onJLZD4oiQaY@Go
Ug2U0onHLJD00onILZKoYHRfojF8]P06ojF8]PGoYHNd0_nUQ[@2okRkg0Go][;E00?o]Jc@oieeY_nK
MjT01?nKMjT2oiYi[@;oWgJT1?nNMjH4oiehZ@GoW7Z]00CoVWjbojJ6/onVQ[?oYXJc1?nTQkH5oj::
^`04oj2=`OnYUL7oZIG1ojVE`@CoYiO51?nUVLT00ol0003o[J_Fojf[eP03ojf[eP;oZjgI0_nb_n@5
ok2ni003ojnniOnaan[o/LOZ00;o/LOZ0_n`aNT3ojo7k1Cooooo00?o0000ooooooooool09_ooool0
00Kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP06
ooooo`;o00007Oooool00ol0003oooooooooo`0Mooooo`03o`000?lc003o<`0000KoV8c50onHR/<4
oiR7`0?oUh:j1?nFNk@4oiAe[@?oTVnW1OnAJj@3oi1YXP?oTFVR00?o[J;;okN[cOngZld01?ngZld0
0ono]]7oTFBKoi5TV`02oi5TV`CoT6>I0on?HYT4ohiQV@CoSV:I0on@I9/2o`0000?oTfNL00?oUV^N
oimfY?nOMZ@01OnMM:D3oiYbY@GoV76U1?nGL:D2oiQaY@03oj>8]onUR;KoYHRf00SoYHRf1?nUQk@0
1?nUQ[Co^;_LokRkg?nh^m`4okJbe@?oWGFV1OnKMjT00onJNJgoWgJToimfY002oimfY0?oWWNV1OnM
N:T3oiaj[@03ojR7/OnVQ[?oYXJc00;oYXJc1OnTQkH3oj::^`03ojfF_onYUL7oZIG100;oZIG11OnW
UlD01OnUVLWo/:_Cok2[don`Zm?o000000?o[J_F00?o]/CUok:oi?nb_n@00onb_n@2ok2ni0?o//_/
0onaanX2ojo=k`Go[lO/5?ooool00ol0003oooooooooo`0Uooooo`003_ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo01[ooooo00?o0000oiN<a_nGS<H02?nHS<D3oiR:``CoV8O00onGP[X4oiIk]0GoU7F]
0onBKjL4oi5[Y0?oT6VR00?oTFVRojfRbon]X//00_n]X//4okN[c@03o`000?n@IIcoT6FL00?oTFBK
1?n@HiT4ohmRV@?oSV6I1?n>HYT3o`000005oi1TVonCIicoTfNLoi=WW?nNM:<01?nOMZ@4oiedY@?o
VW:U1OnHLJD4oiM`Y@04oiQaYOnSR;OoXhRgoj>8]`WoYHRf0_nUQk@3okW6i0Co^;_L00?o][;Eoied
XonMM:<01?nMMJH3oi]gZ@03oj1fXonOMZCoWgJT00?oWgJT0onNMjH5oiehZ@04oiaj[OnXQk7oZ8Na
ojR7/@CoYXJc1OnTQkH01?nRR[_o[IJoojfF_on]U[l4ojVE`@CoYiO500?o/jgBok2[don`Zm<00on`
Zm<00ol0003o]/CUokK4i@02okK4i@?o/[oT0_ncd>l5ok;;k003ok77j_n_cNoo[lg_00;o[lg_0_n_
an`2oj[5kAGooooo00?o0000ooooooooool09?ooool000kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool07_ooool2o`0001Oooooo00?o
0000oiJ<a_nGS<H01?nGS<H7oiR<a@CoV8[31?nHQl03oiN2^PCoUW^d1?nDMJd3oi9_Y`CoTF^T0_n@
JJ800onQW<oo[J;;ojfRb`03ojfRb`?o]j_=1?n@II`3oi5TV`CoT6>I1?n?HYT3ohiQV@04ohiRVOl0
003o0000o`0000CoT6BK00CoTfNLoiidXonNM:?oWWBS1?nOMZ@4oiedY@CoVW:U1?nHLJD2oiM`Y@;o
XHRi1?nSR;L8ojF8]P03ok[Ck?nia^Co^LKT00Co^LKT0_nh^m`4oiedX`CoWGFV00CoVgNYoj1fXonP
MZ?oX7JS1OnOMZ@3oiigYPCoWGRY00?oZhR`ojR7/OnXQk400onXQk44ojJ6/`?oY8Nf00?o/9RnojfF
_on]U[l00on]U[l4ojVE`@03ojNGaOnc[M;o/jgB00;o/jgB0on`Zm<00onibnSo0000okK4i@04okK4
i@03ok:oi?ncd>oo/m3_00;o/m3_0_nbbn`2ojkDm0Co[lg_0_nYbo44oj[5kA?ooooo0_l00008oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<
c009ooooo`003_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00ooo
ool2o`00027ooooo00?o0000ooooooooool04Oooool2oiJ<a`CoUXc61?nGS<H8oiR<a@?oV8[31?nH
Ql03oiN2^PCoUW^d1?nDMJd3oi9_Y`;oTF^T0_nAVMP4oj6Lc`Go[J;;00?o]j_=ohmVW_n@II`00on@
II`4oi5TV`?oT6>I1?n?HYT01?n>HIWo0000o`000?l00003ohiRV@?oT6BK00?oVg6RoiidXonNM:<0
0_nNM:<4oimfY0CoWGBU1?nJLZD3oiQaY@03oj:;^onQR;WoXHRi00?oXHRi0onSR;L6ojF8]PCo^]?/
1?nia^@3oiebX@GoWGBS0onMMJH5oj1fX`CoWgJT1?nNMjH2oiehZ@;oZhR`1OnXQk44ojJ6/`03ojB7
]_n`V;ko/9Rn00;o/9Rn1?n]U[l3ojVE`@03okNadonc[M;o/jgB00Co/jgB00Go/:_CokW;j?nibnSo
^L_Xo`000002okK4i@;o/mWc1?ncd>l2oj_Ln@Co[]Cd00?o[lg_ojW;lOnYbo400onYbo42oj[5k@;o
Y/;^5?ooool00ol0003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@09ooooo`003_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`;o00008oooool00ol0003ooooooooo
o`0=ooooo`03oiF=b?nFS<OoUXc700?oUXc70onFS<H4oiN<aPSoV8c50_nHR/<3oh7@o`CoLlSo0omW
_?d3ofF_nP?oKJ?a0on0W>@5oi6If0CoXIc?0on]X//3ohmVWPCoT6FL1?nAI9/3oi1SV@;oSf:I0ol0
0003ohiQV@?oSV:I0_n@I9/2oi]aXPCoWWBS1?nOMZ@5oiedY@?oVW:U00CoV76Uoj:;^onRRk_oXX^k
1OnQR;T4oj>8]`?oYHRf0_nih?<5ok[Ck003okW6i?nLL:3oW72P00?oWG:Q1OnMM:<2oieeYP03oj9g
XonPMZ?oX7JS00?oX7JS1?nOMZ@4oiigYP03oiehZOn[R;3oZhR`00;oZhR`1?nXQk44ojJ6/`Go/9Rn
1?n]U[l00onYUL7o]k7CokNad`02okNad`Co/jgB00?o_=W^okW;j?nibnP00_nibnP00on^hoWo0000
ok?Il`03ok?Il`03ok?@kon[g?WoZmci00?oZmci0_n^e?@2ojO@m@CoZL_a00?oY<G`ojK2k_nV`^h0
0onV`^hDooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05
o`000?ooooooooooooooool000002Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00Gooooo0_nDSl/3oiB>b@CoUHg81?nFS<L3oiJ<aPGoUhc61OnHS<D4oh[Bo`CoPM3o0_mcb?l0
1OnLO[;oVgb`oi]l/?nCKZGoIkcm00?oIJoj0om]Xo43oh2Li0CoTIWH1OnQW<l00on]X/_oSFFPohmV
WP03ohmVWP?oT6FL1?nAI9/2oi1SV@?o00000_n?HYT4ohiQV@?oSV:I00CoT6BKoi]aX_nKLJ;oVg6R
1?nNM:<4oimfY0GoWGBU0_nJLZD00onVT/3oXX^koj:;^`03oj:;^`CoXHRi1?nSR;L00onUR;Ko^N3c
okWPl`03okWPl`;o^]?/1OnLL:03oiebX@GoWGBS00CoWGFVoj9gXonRMj?oXWNS1?nPMZ<5oimfY0?o
WWNV1On[R;05ojR7/@;oYXJc0_nfWl44ok2H_P?o[IJo00?o_K_HokNadong/M<01?ng/M<00onc[M;o
_=W^okcIkP02okcIkP03okW;j?n^hoWo[^?i00;o[^?i00?o0000ok?IlonRho`00onRho`2oj_Ln@;o
X]Ci1OnWd?D00onYbo7oY<G`ojC5l002ojC5l0?oY/;^00?oXkk]ooooooooool04_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b00Wooooo000Wooooo`03o`000?oooooooooo02Cooooo00Go0000oooooooooooooooooi>@c@05
oiB?b`?oU8k91?nESLP3oiJ<a`CoUXc61?nGS<H2oiR<a@CoSm;n0_n:d_l01?nOQ;KoWX6doij1]?nN
PK@2oian/P;oU6nV0onCKZD4oi=]X`?oTV^R00?oKJ?aoh2Li?n0W>@01OnAVMP2oj6Lc`04oheVXOn=
IJ3oSFFPoheUX0CoSfJN0on@II`3oi5TV`?o00000_n@HiT3ohmRV@CoSV6I0_n>HYT00onHKZ7oVg6R
oi]aXP03oi]aXPCoWWBS1?nOMZ@4oiedY@04oiYbYOnVT/3oYY;0ojJB`0CoXX^k1OnQR;T2oj>8]`;o
/NSh1?nih?<4oiU^W`CoW72P0onMLZ45oiedX`CoXWNS1?nPMZ<5oimfY0;oWWNV00?o[Xbaoj^8/?n[
R;000on[R;05ojR7/@04ojJ6/onfWl7o]Yo1okJO`@Go/9Rn00Co[IJookfkf?nm^mSo_K_H1?ng/M<0
0onhjoGo_=W^okcIkP02okcIkP?oW^ci0_n^hoT00on>i_[o0000ohkVnP02oj;So0;oVMOm1OnRe?T2
ojO@m@;oX/Kb1OnTaO000onV`^koXkk]oj>nk@02oj>nkACooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c009ooooo`009ooo
ool2o`0002;ooooo0_nAT]43oi:Ac`CoTi3=1?nDSl/3oiB>b@CoUHg81?nFS<L2oiJ<aP?oSlkm1?n@
d?d2ohoBoP;oXHRi0onOQ;H2oij1]003oiAaZ?nDKjKoU6nV00;oU6nV0onCKZD4oi=]X`?oTV^R1?nA
JJ82oi6If003ohiWXOn=IZ7oSFJQ00;oSFJQ0on=IJ04ohmVWP?oT6FL00CoTFBKo`000?l0003oTFBK
1?n@HiT3ohmRV@CoSV6I00?oSV:IoiQ^XOnHKZ401OnKLJ84oiidX`CoWgJT0onMM:D00on`W/KoYY;0
ojJB`002ojJB`0CoXX^k1OnQR;T00onSR;Oo/NShok7Xn002ok7Xn003okWPlonIKYooVFjO00CoVFjO
1?nLL:04oiebX@?oWGBS00?oYGZToj9gXonRMj<00_nRMj<4oj1fX`GoWgJT00CoWWNVojj</On^S;7o
[Xba1?n[R;04ojR7/@03okf[aonfWl7o]Yo100;o]Yo11?n`V;h00oo2bn7o_K_Hokfkf003okfkf003
okNadonhjoGo^>_e00;o^>_e00Co_=W^oik/nOnNk?WoW^ci0omZfnX2ohkVnP04ohkFool0003oS]Ko
ohkFo`?oVMOm0_nRe?T4oik6m0?oX/Kb0_nTaO03oj6nk@CoXkk]5Oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Wooooo
000Wooooo`03o`000?oooooooooo01kooooo00?oTICCoi6BdOnAT]400onAT]43oi:Ac`?oTi3=1?nD
Sl/3oiB>b@GoUHg80_nFS<L2ohg;o0GoSlkm0_n@d?d00onSS;_oXHRioj68^@02oj68^@;oWhBf00Co
UG>YoiAaZ?nDLJSoU76X1?nDKjH3oi=^Y@CoTffS1?nBJj83oi5YXP?oSVNQ1?n=IZ43oheUX0CoSfJN
00CoT6FLo`000?l0003o00000onAI9/4oi1SV@?oSf:I0_n>HIT2oiA[X0?oV6jQ1OnKLJ84oiidX`Co
WgJT00?oWGBUok2Na_n`W/H00_n`W/H3ojJB`0GoXX^k0onQR;T3oj3[nP;o/NSh2?nIKYl4oia`X0Co
WG:Q0_nMM:<2ojEjY0CoXWNS1OnPMZ<3oimfY003ok:A]?n^S;7o[Xba00;o[Xba1On[R;02ojR7/@;o
_J_71OnfWl400on`V;ko`/_Qol;;h@02ol;;h@?o_K_H0onHl^L2okS[m@03og7Ph_lm`Loo?L7?00;o
?L7?0_mZfnX3oh3Ao`;oS]Ko00?o0000oiNnl_nJ`o@01?nJ`o@2oik6m0;oWk[[1?nP_>d5oj6nk@;o
Xkk]0_nR_>/Booooo`?o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`000009ooooo`009oooool00ol0003oooooooooo`0Gooooo`;oSYSI0on@U]H4oi6D
d`CoTI;A0onBTLl3oi>@c@GoU8o;0onDS/T2oiF=b0?oRlSl1?n=bo`2oho>o@03ojJ@__nSS;_oXhbk
00;oXhbk0_nQR;T2oiIe[0?oUG>Y1?nDLJP3oiA_YP?oTfjU1?nCKJ<4oi9[XP?oTFVR1?n>Ij43oheV
X@CoSFFP00CoSfJNo`000?l0003o00000on@II`3oi5TV`CoT6>I0_n?HYT00onBJJ3oU6^PoiA[X002
oiA[X0CoV6jQ1?nKLJ84oiidX`?oWgJT00?o_:k<ok2Na_n`W/H00on`W/H4ojJB`0CoXX^k00KoXHRi
oj3[n_nPjo[oX>_joiiaX?nKL:02oi]`X@SoVFjO1?nLL:04oiebX@03oiedXonUNZCoYGZT00;oYGZT
1?nRMj<4oj1fX`;oWgJT0_nbTK@4ojj</@GoZhR`00?oZ8Naokf[aonmZlL00_nmZlL3okJO`@;o`nG_
1?o2bn401?nm^mSoV?;WoiSbionHl^L2ohJ`l0CoNkkl1?mjb_l2oh3Ao`;oUKC]0_nG__800ol0003o
UkkboiNnlP02oi[3m0;oW[GX1OnO^^/4oj2lk@;oXKk]0_nR^NT5oj:ljaCooooo00Wo0000oooooooo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Wooooo
000Vooooo`?o00003oooool01?n:X>?oS9gOohbMgon<WMl4ohfJf`CoSYSI0on@U]H3oi6Dd`CoTI;A
1?nBTLl3oi>@c@;oU8o;0on7`o/5ohW6o0?oRlSl0_n=bo`00onYUL;oYY2nojJ@_P02ojJ@_P;oXhbk
00?oV7R^oiIe[?nFMJ`00_nFMJ`3oiEcZ@CoU76X0onDKjH4oi=^Y@?oTffS1?nBJj84oi5YXP?oSVNQ
0on=IZ42oheUX0?o00000_n?IYh4oi1UW0?oTFBK0_n@HiT2oi1XX@?oTVVP1?nDJj04oiQ^X@CoVg6R
1?nNM:<2oimfY0?o_:k<1?n`W/H4ojJB`0;oXX^k0_n1i_001OnNLIooWW6PoiiaX?nNLJ3oX7FS00?o
Vg2Q2?nIKYl5oia`X0?oWG:Q1OnUNZ@4oj9gX`CoX7JS00?oWgJTok:A]?nbTK@00_nbTK@4ojj</@?o
ZhR`00?oal;Eokf[aonmZlL00onmZlL2okJO`@Co`nG_0_o2bn400ol0003oT9kMoi2Ng@05ohJ`l0;o
Nkkl00?oV9gFoiNYhonGZN<00onGZN<4oiFdk@;oUkkb00?o0000oij_honN]NP01?nN]NP4oinjj`;o
X;c]0_nR]^L5oj:ij@;oX[c[0_nU_>XEooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`00
0?oooooooooo00Gooooo0_n1Z^l3ohFVj`?oQj?V1?n:X><3ohbMg`CoSI[K0on>V=T3oi2FePCoTICC
1?nAT]42oi:Ac`;oQ;oj1?n5`O/4ohO3n`;oRLKl1?n/V/D5ojVE`P;oYY2n00CoVW^`oiQh[_nHN:ko
V7R^1?nFMJ`3oiEcZ@CoU76X1?nDKjH3oi=^Y@CoTffS0onBJj84oi5YXP?oSVNQ0_n=IZ43o`0000;o
SFFP0on?IYh4oi1UW0;oTFBK00?oSFNRoi1XXOn@J:400_n@J:43oi9YX0GoU6^P0onHKZ45oi]aXP?o
WWBS00?oWgJTokb^c?nl[/`00_nl[/`5ok2NaP;oYY;00_m8b<@4oiiaW`04oiiaX?nPMJ?oX7FSoj1e
X`CoVg2Q1onIKYl5oia`X0;oWG:Q00?oZ7jVojEjY?nUNZ@00onUNZ@4oj9gX`CoX7JS1OnbTK@4ojj<
/@03oj^8/?o7`]Goal;E00;oal;E1?nmZlL00onfWl7o`nG_ol?Uk`02ol?Uk`?oVI;;1?n@W]d2ohJ`
l0;oW9?:1?nHWMH5oiNYh`;oUKC]00KoWjSLoij_honN[n?oWZoSo`000?nN[n<4oijej0;oWk[[0onR
/^<4oj:fi`;oX[WY0onU^NP4ojFljQCooooo00?o0000ooooooooool07_ooool001_ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?ooooooN;3f00;oN;3f0omm[O83oh6Zk`?oQJK[0on7
XnH3ohZPh`CoS9gO1?n=V]/3ohjHf@?oT9KF0_nAU=<3oh2kn@?oP[gj1?n4_oX4ohG1n`;oQl?k00Co
_;oLojnOb?n_WlSo[io80on/V/D5ojVE`P03ojJ@__nJNk3oVW^`00CoV7R^0onFMJ`4oiEcZ@?oU76X
1?nDKjH3oi=^Y@CoTffS0onBJj84oi5YXP;oSVNQ0ol000000on:J:GoQfJUohMVY@05ohMVY@CoRFJT
0on=Ij84oi1XX@CoTVVP1?nDJj03oiQ^X@GoVg6R0_nNM:<2olBldPGo_:k<0_n`W/H2oiQ[W@GoW6nN
0onNLIl4oj1eX`CoVg2Q1onIKYl5oia`X004oiebXOnXOZKoZ7jVojQnYPCoYGZT1?nRMj<4oj1fX`Go
/Y6d1?n^S;46olO2e@;o_J_70onMm>D00oo3iNooX8ZloiVBb`03oiVBb`;oT9kM0_nQSKl5oibCbPCo
V9gF0_nGZN<2oj:Re0CoWjSL0onN[n<01?l0003oWZoSoijej?nN]NP2oj>]g`GoX[;S0_nR]^L2ojFg
i@GoYKWX0_nU_>X2ojNmjACooooo00?o0000ooooooooool07Oooool001_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`06ooooo`03o`000?oooooooooo00?oN;3f0omm[O83oh6Zk`?oQJK[0on7XnH3ohZP
h`CoS9gO0_n=V]/2ogZen0?oO;Oi1?mn^OT4oh2kn@?oP[gj0_n4_oX3obffb0?o_/;M00?o/JC;ojnO
b?n_WlP00_n_WlP4ojbJa@;oZIG20_nLOk<4oiYk/0?oV7R^1?nFMJ`3oiEcZ@?oU76X1?nDKjH3oi=^
Y@CoTffS0onBJj82oi5YXP05oi1/YOl0003o0000o`000?n>JZD00on:J:D7ohMVY@CoRFJT0on=Ij84
oi1XX@CoTVVP1?nDJj03oiQ^X@GoVg6R00?oWWBSolBld_o4_=800_o4_=83okb^c003oiEXVonHJigo
V6^M00;oV6^M1OnLKih2oiiaW`03ojIlY_nPMJ?oX7FS00?oX7FS0onKL:48oiU^W`?oW72P00?oZ86Y
ojQnY_nXOZH00_nXOZH4ojEjY0GoXWNS0_nPMZ<2okNJ^PGo/Y6d0_n^S;42olo^j@Coal;E0_l00002
oigdi@CoX8Zl0onIT//00onVRkSoXHfooj6=_`03oj6=_`CoW9?:0_nHWMH2ojJMc0GoXZ;D1?nOZ=`2
oij_h`03o`000?nTZM[oXjgO00CoXjgO0_nR/^<2ojJdhPGoYKOU0_nU^NP2ojNkj0GoYkgY4oooool2
o`0001kooooo000Kooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0000;ooooo0om]ZoH3
ofj/m`?oKjgg1?ma[oL3og>`m`?oM[;h0omh/oP4ogZen0?oO;Oi1?mn^OT2oh2kn@;o?/7P0_nnjO80
0onmkO?o_lGNoko5gP03oko5gP04okk2gOnaY<_o/JC;ok6Tb`Co[io80_n/V/D00onOQ;KoW7ncoiao
/`02oiao/`CoVW^`0onHN:h4oiIe[0?oUG>Y1?nDLJP3oiA_YP?oTfjU0_nCKJ<2oi5]YP?oTFfU0ol0
00001?n@K:GoSVZUohiZYOn>JZD4ohYXY@KoQfJU1?n9IZ@4oheWXP?oT6RQ1?nBJJ04oiA[X0CoV6jQ
0onKLJ800oo8a=Ooa;cBolBldP04olBldP04okb^c?nEJ9_oUFRKoiEXV`?oV6^M1OnLKih00onNLIoo
YWbVojIlYP05oj1eX`?oVg2Q2?nIKYl2oia`X0;oZ86Y1?nXOZH5ojEjY0CoXWNS00CoX7JSokNJ^_ng
V[[o]iZj1OnbTK@00on^S;7ocnkYolo^j@02olo^j@03olO2eOnENK7o[8R^00CoYXNc1OnPR[`01?nI
T/_oYX^hojJ;^?nVRkP4oj6=_`?oW9?:00?oZY[6ojJMc?nVWL`00onVWL`4oj:Re0;oWjSL0_nWYM@3
ojBYfP03o`000?nTZM[oXjgO00;oXjgO00?oZ;7OojJdh_nV]>800onV]>83ojFgi@03ojRji_nW^nSo
Yk_X00?oYk_X0onW_NT00onY`>[oooooooooo`0@ooooo`03o`000?oooooo000001kooooo000Koooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`?oKJ_f0om^[?L3
ofn]m`CoLJog0omc/?L3ogJbn0?oN;?h0_mj]OP4oeC4m`;oC/Ga0ol00004okkYlP;o`<KO1?noaMh0
0ondZLko/JC;ok6Tb`02ok6Tb`?o[io800CoXXVjoin4]_nOQ;KoWhBf1?nLOk<4oiYk/0?oV7R^1?nF
MJ`3oiEcZ@CoU76X0onDKjH2oi=^Y@03oi1]YonAKJKoTFfV00;oTFfV00?oTFfUo`000?l000001?n@
K:D4ohiZY@?oRVRU1on7IZD3ohUVY0CoSFNR0on@J:44oi9YX0CoU6^P1?nHKZ42oi]aXP?ob<CG1?o4
_=800onBII_oUFRKoiEXV`02oiEXV`CoV6^M1?nLKih4ojIlYPCoX7FS0onKL:48oiU^W`03oia`X?nX
PJWoZ86Y00;oZ86Y0onXOZH5ojEjY0?oXWNS00?o_JW6okNJ^_ngV[X00_ngV[X4ok:A]0;o00000_o?
k^T00onJMJOoUGVaoiEi/@03ojb8[P?oYXNc1?nPR[`00on/S;CoYX^hojJ;^002ojJ;^0GoXHfo00Co
W9?:ojZJa_nZV/KoZY[61?nVWL`3oj:Re003ojZSd?nWYMCoYjGD00?oYjGD0onTZMX00ol0003oXjgO
ojRag`03ojRag`CoY[CR00?oYKOUojRji_nX^^H00_nX^^H4ojNkj003ojNmjOnY`>[oZL3Z00;oZL3Z
5?ooool00ol0003oooooooooo`0Kooooo`006oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00oooool4ofj/mP?oJk3i0omX]?/3ofFho@CoHKcm0omM_od2oeW2n`?o?/7O
0_le^kh00omOe/ooY_3fojK`mP04okoTl@03okkYl_o0a]oo`<KO00;o`<KO00?o_lGNokBYc_ndZLh0
0_ndZLh4ok6Tb`03ojnOb?nRRK[oXXVj00CoWhBf1?nLOk<3oiYk/0?oV7R^1?nFMJ`3oiEcZ@CoU76X
0_nDKjH01?n?KJSoT6fWoi1]Yon@KJL2oi5]YP?o00000onAKJD3oi1/Y@CoSVZU0on:J:D7ohMVY@?o
RFJT1?n=Ij84oi1XX@?oTVVP1?nDJj04oiQ^X@03oi]aX_o8a=Oob<CG00?ob<CG00Coa;cBoi9UVonB
II_oTVFK1?nEJ9/4oiQ[W@?oW6nN00?oZX>ZojIlY_nVO:H00_nVO:H4oj1eX`?oVg2Q1onIKYl00onV
PJcoZ86YojR1Z@03ojR1Z@?oZ7jV1OnUNZ@00onRMj?o_JW6okfYaP02okfYaPCo]iZj0_nbTK@2o`00
00CoVWFW00?oUGVaojb8[_n/R:h00_n/R:h4ojJ7/`03oj2:_?n/S;Co[8bd00;o[8bd0onVRkP4oj6=
_`03ok2K`_nZV/KoZY[600;oZY[61OnVWL`01?nRX]CoZZ?@ojZSd?nZXm05ojNUe0;oY:WJ00?o0000
oj^`g?nX/Ml01?nX/Ml2ojJdhP;oZ[WT1OnX^^H2ojNkj0;oZ[oY0onY`>X00onZ`^_oooooooooo`0C
ooooo`03o`000?oooooooooo01[ooooo000Kooooo`05oa0@4?ooooooooooooooool@41001Oooool0
0ol0003oooooooooo`05ooooo`CoKZcf0om[/?T3ofRdn`?oIKSm0_mQ_?d4oe_7n@;oC/K_0om>c=d0
1?mfh^SoY_3fojK`m_nVl?H4okoTl@;o`<OO0oo0a]l00ong[]7o]:W>okBYcP04okBYcP;o/JC;00?o
YHjmoj:9^_nRRKX00_nRRKX3oin4]PCoW7nc1?nJNk03oiQh[P?oUWF/0_nELjT00on@Kj[oSfjYohm^
Z@02ohm^Z@?oSffX0_n@KJL3o`0000;oTFfV1?nAKJD3oi1/Y@CoSVZU0on:J:D7ohMVY@CoRFJT0on=
Ij84oi1XX@?oTVVP1OnDJj03oiQ^X@Gob<CG00?oTFBJoi9UVonBII/00_nBII/4oiEXV`CoV6^M0_nL
Kih2ojZ3ZPCoYWbV1?nPMJ<4oi]`X@GoVFjO0_nVPJ`5ojR1Z@CoZ7jV0onUNZ@00oo8b]co_JW6okfY
aP03okfYaPCo]iZj00Co/Y6doimdX_nOM:;oWgBR1?nJMJL5ojb8[PCoYXNc1On/S;@4ojJ;^003oj6=
_on`Vl;o/9_200;o/9_21?nZV/H2ojJMc0;o[jC=1OnZXm02ojNUe0;o[[7J0on[/=`01?l0003oZk3L
ojRagonX/Ml2ojbih`GoZ[WT0_nX^^H2oj^oj0GoZ[oY00CoZL3Zoj[2jonZ`^_oZ/;[5?ooool00ol0
003oooooooooo`0Jooooo`006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00007oooo
o`;oKZcf0_mk/OH3ogJhn`GoKkon0_mVa?h3ogGCoP;oI=Cc0on9iOP3ojcZn@?o_]k_00?o_nCaol37
goo0aml00oo0aml01?o0a]oo]jkAokN^dOng[]44okBYcP03ojRD`OnUS[goYHjm00;oYHjm0onRRKX3
oin4]PCoW7nc1?nJNk03oiQh[P;oUWF/00CoT76/oi1_Z_n@Kj[oT6nZ1?n?KZT2ohm]Z0?o00000_n@
KJL3oi5]YPCoTFfU1?n@K:D3ohiZY@?oRVRU1on7IZD4ohUVY0?oSFNR1?n@J:43oi9YX0GoU6^P0_nH
KZ42ol?8gP?ob<CG0onAI9X3oi9UV`CoUFRK1?nHJid01?nLKikoZX>ZojZ3Z_nZPjX4ojIlYPCoX7FS
1?nKL:43oiU^W`03oj>2/?nVPJcoYX6/00;oYX6/1?nXPJT4ojQnYP;oYGZT0oo8b]`4okfYaP?o]iZj
00?oYGRQoimdX_nOM:800onOM:82oiYeY`03ok:<[On/R:ko[8R^00Co[8R^0_nVQk<00oncT[Co[8bd
ojb<]003ojb<]0CoYX^h1On`Vl83ojZJaP03okFYcOn_Y<go[jC=00?o[jC=0onZXm000onb/mWo[[7J
ojjafP03ojjafP?oZk3L00?o0000ojbihon/^N<00on/^N<2ojZii0;o[<3X1On[_nP2ojZoj@;oZl?[
1OnZ`^/Dooooo`03o`000?oooooooooo01Wooooo000Kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool00ol0003oooooooooo`07ooooo`CoNk7f0omf^?/2ofnooPCoPLgo0_medoh3oiGPoPCo[n7h
00Co[>[iokkNkonng^oo_]k_0oo0an03ol37g`03okVcdong[]7o]jkA00?o]jkA00?o]:W>ojRD`OnX
U<400_nXU<43ojF>_@?oXXVj1?nOQ;H3oiao/`;oVW^`0_nCMZl3oi5c[@?oT76/1?n@KjX2ohm^Z@?o
00000_n?KJP3oi1]Y`CoTFfV0onAKJD4oi1/Y@?oSVZU1?n:J:D6ohMVY@CoRFJT0on=Ij84oi1XX@Co
TVVP1?nDJj000onHKZ7o`lSNol?8gP02ol?8gP03olS4eonAI9[oTFBJ00;oTFBJ0onBII/4oiEXV`?o
V6^M00?o[8N]ojZ3Z_nZPjX00_nZPjX4ojIlYPGoX7FS0onKL:401?nIKYooXh:`oj>2/?nSP[04ojJ1
[0CoZ86Y1?nXOZH00onUNZCob<[LolS:g002olS:g0Go_JW600Co]iZjojEhXOnUN:7oYGRQ1?nOM:80
1?nJMJOo/Xb]ok:<[OnbS:d5ojb8[P04ojJ7/oncT[Co/i:dok>B]0Go[8bd0_nVRkP2okJO`@Go/9_2
00CoZY[6okFYcOneZLgo]JW=1?n_Y<d00onZXm3o/[?Iok:cf@02ok:cf@Co[[7J00GoZk3Lojnkhon_
^n?o[k_So`000003ojbih`03ojk3jOn/`>So[<3X00?o[<3X0_n[_nP3oj_4k0CoZl?[1?nZ`^/Doooo
o`03o`000?oooooooooo01Wooooo000Uooooo`03o`000?oooooooooo00Sooooo0_mk/OH3ohfhl`Co
RL?k0_n1cOl4oicFo003oiGPo_n_hOSo[n7h00;o[n7h0onmend00onng^oo`<OPol37h003ol37h004
ol37goni/m?o^K?CokVcd`?o]jkA00?o[9_5ojRD`OnXU<400onXU<43ojF>_@CoXXVj0onOQ;H2oiao
/`03oiAi/_nCMZooTgJ_00;oTgJ_0onALjd4oi1a[0;oT6nZ0ol000000on?KZWoSffXohm]Z002ohm]
Z0?oT6fW1?nAKJH3oi5]Y@CoT6bU1?n>JZD3ohYXY@OoQfJU0on9IZ@4oheWXP?oT6RQ1?nBJJ03oiA[
X0;o^<KU0oo3b=h2oi1TV`CoTFBJ1?nBII/3oiEXV`;oV6^M0_n/Qjd5ojZ3ZPCoYWbV1?nPMJ<2oi]`
X@03oj25]onSP[3oXh:`00?oXh:`0onVPJ`5ojR1Z@;oZ7jV0_nlnnT5olS:g0;o_JW60_n`PZ@4ojEh
X@CoWgBR1?nbS:d5ojb8[PCo/i:d1On/S;@01?nVRkSo]Yo1okJO`OnfWl44ok2K`P03okfedOneZLgo
]JW=00;o]JW=0on_Y<d00ong^]co/[?Iok:cf@04ok:cf@;o[[7J0_nb`ND3ojnkh`03o`000?n_^n?o
[;WS00?o[/?Y0on/`>P2oj_6k@GoZlC/0_n[`n/2oj[4k0CoZ/;[4_ooool00ol0003oooooo`00000J
ooooo`009Oooool00ol0003oooooooooo`0:ooooo`CoSKSc0_n9`o/4oio:mP;oW=Kl0on`e_@00on_
hOSo_MO]okgGk@02okgGk@Ko`<OP00?o^kOFokVcdoni/m<00oni/m<01?ng[]7o[9_5ojbKaOn/VlD4
ojRD`@CoYHjm0onRRKX2oin4]P04oiIl]?nDNK;oU7VboiAi/PCoTgJ_1?nALjd2oi1a[0?o000000?o
T6nZohm^ZOn?KZT00_n?KZT3ohm]Z0?oT6fW1?nAKJH4oi5]Y@?oT6bU1?n>JZD3ohYXY@OoQfJU0on9
IZ@4oheWXP?oT6RQ1?nBJJ000onDJj3o^<KUokS6i@03okS6i@04ol?8g_n@I9_oT6BKoi1TV`CoTFBJ
1?nBII/3oiEXV`03oiQ[WOn/Qjgo[8N]00;o[8N]1?nZPjX4ojIlYPCoX7FS00?oVg2Qoj25]onPQKL0
1OnSP[03ojJ1[0GoZ86Y00?oZ7jVokckjOnlnnT00_nlnnT2olS:g0;oZWjT1?n`PZ@4ojEhX@CoWgBR
1?nbS:d4ojb8[P;o`:6j0oncT[@4ojb<]003okn[aOnfWl7o]Yo100;o]Yo10on`Vl82okfed@Go]JW=
00Co[jC=okNjg?ng^]co]k[L1?nb/mT00ondbNWo//7Uok;1i@03ok;1i@;o[k_S00?o[/O/o`000?n^
`nT01?n^`nT00on/`>SoZlK]oj_6k@02oj_6k@;oZlC/0_nZaNh5oj[4k0;oZ/;[0_nX`^`Dooooo`03
o`000?oooooooooo01Oooooo000Uooooo`;o00003?ooool2ohfhl`?oX;k^0_nOb_H4ok3<kP;o/=Kd
1?nld>T00onmengo`<OPol37h003ol37h0Co^kOF0oni/m<00on_XLWo[9_5ojbKa@02ojbKa@GoZ9C1
0onUS[d2oj:9^P04oiV1^?nFO;CoUWbdoiIl]0CoU7Vb0onCMZl4oi5c[@;o000000CoT76/oi1_Z_n@
Kj[oT6nZ1?n?KZT3ohm]Z0CoT6fW0onAKJH4oi5]Y@?oT6bU1?n>JZD2ohYXY@04ohf4a?n0QLooP8G?
oh25c`?oLhgM00CoQfJUohUVY?n9IZCoRFJT1?n=Ij83oi1XX@;oTVVP0onV`Nd4okS6i@;oSVBM0on@
I9/4oi5TVPCoTVFK0_nEJ9/00onZR;7o[8N]ojb7[@03ojb7[@CoZX>Z1?nVO:H2oj1eX`;oYYS71?nP
QKL4oj>2/0?oYX6/1?nXPJT3o`0000;o_?_Y1OnZOZ@4ok22Y0CoYGRQ0onOM:82okbE/0Co/Xb]0_n/
R:h3ol2Q^PCo/i:d0_n/S;@3okn[a@Co]Yo100?o/9_2okfedOnm]M400_nm]M43okFYc@03ok_6hong
^]co]k[L00?o]k[L00?o/[?IokC9jOndbNT00_ndbNT3ok;1i@03ojo=l?n^anco[/O/00;o[/O/00?o
0000ojk3jOn^`nT00_n/b_04oj_6k@03ojW7konZaNkoZ/G^00?oZ/G^0_nZa>`2ojS3k@GoZ<;/4ooo
ool00ol0003oooooooooo`0Gooooo`009?ooool00ol0003oooooooooo`0=ooooo`?oX;k^0on_`^P3
ok3<kP;o^/[V1?nld>T2oko6g`?o`<OP0onl^mP4ok^geP04okVcdon_XLWo[j79ojnQb@?o[9_51OnX
U<42ojF>_@03oib6^onIPKSoVH6h00;oVH6h0onFO;@3oiAi/PCoTgJ_0ol00003oi1a[0?oT6nZ1?n?
KZT4ohm]Z0?oT6fW0onAKJH4oi5]Y@;oT6bU00?oUX6joiB2_OnDP[d00_nDP[d4ohf4a0?oP8G?0omc
SMd3ofZGj@CoMZOa1?n>]o85ojK1k@03okS6iOn<HikoSVBM00;oSVBM1?n@I9/3oi5TVPCoTVFK00?o
UFRKojZ8/OnZR;401On/Qjd4ojZ3ZP?oYWbV00?o]m7]ojJHaonVV<L00_nVV<L4oj25]`CoXh:`1?nV
PJ`2ojR1Z@;o[X6S1?n^Oj84ojYnY0;o`YV^0on`PZ@5ojEhX@04oimdX_nlUK3o_9F`okbE/0Co/Xb]
00?o[8R^ol2Q^_o0XKX00_o0XKX4ok>B]003ojb<]?noZlGo_j_500;o_j_50onfWl400oo6c=oo_KGA
okfed@03okfed@03okFYcOnka^?o^lKS00;o^lKS0ong^]`2okGHlPCo]<WY00?o//7Uojo=l?n_cO00
0_n_cO02ojk7k0;oZLoc00?o0000ojc:l?n/b_000_n/b_000on[a^goZLO_ojW7k`02ojW7k`;oZ/G^
0onXaNh4ojS3k@;oZ<;/0_nW`N`Dooooo`03o`000?oooooooooo01Kooooo000Tooooo`03o`000?oo
oooooooo00kooooo00?oX;k^ojo2j?n_`^P00on_`^P00on`c>ko^/[Vok[:iP02ok[:iP03okc@jOno
a]oo_lKO00?o_lKO00?o`<OPokbkf?nl^mP00onl^mP2ok^geP03ok:Xc_n_XLWo[j7900;o[j791?n/
VlD2ojRD`@;oWhbo1?nLQ[/3oiV1^0?oUWbd0onDNK801?nCMZoo0000o`000?l00003oi5c[@?oT76/
1?n@KjX3ohm^Z@CoSffX0on@KJL3oi5]YP;oTFfU0_nEOkT4oiJ1^PCoU8:m0on=Q<@4oh25c`?oLhgM
0omZUnT4ogJWl@CoS[Ob0_nV`Nd01?n8HYooS6>NohaSW_n<Hih4ohiTW@?oT6BK0onAI9X3oi9UV`03
ojB6/onZR;7oZXRa00;oZXRa1?n/Qjd4ojZ3ZP03ojIlY_ngdNgo]m7]00;o]m7]0onVV<L4oj25]`Co
Xh:`1?nVPJ`00onXPJWo[X6Sojj1X`02ojj1X`Co[WnR0_nZOZ@3ol:I[P?o/8:T1OnUN:401?nOM:;o
_9F`okbE/?nlUK04ok:<[@Ko`:6j0_ncT[@00oo8`]Co_j_5okn[a@04okn[a@04okJO`Oo6c=ooa/cO
olK<g`?o_KGA0_nkg?45ok_6h`03okNjg?nef?;o]MSb00;o]MSb0_ndbNT3oj[EmP;o[lg`0_nUe?P3
ojW?l`04o`000?nYco?o[<[`ojc:l0?oYl[b0_nYanl2ojK6l0GoZ<G^0_nX`nd2ojO1k@CoYl7/5?oo
ool00ol0003oooooooooo`0Eooooo`009?ooool3o`0000oooooo1?n_`^P2okW3hP?o^/[V0onnaMl3
oko6g`;o_KkJ1?nl^mP00one[];o/ZS>ok:XcP02ok:XcPCo[j790_n/VlD00onRT/?oWhbooin<_`02
oin<_`CoW8Jk0onIPKP3oiIl]004oiAi/_l0003o0000o`0000?oTgJ_1?nALjd3oi1a[0?oT6nZ0on?
KZT4ohm]Z0;oT6fW00CoSg^hoi9m^OnBOKWoTWfi1OnEOkT3oiJ1^PCoU8:m0on=Q<@5oh25c`?oLhgM
0omZUnT4ogJWl@;oS[Ob1?n8HYl3ohaSWPCoSVBM0on@I9/3oi5TVP04oi9UVonTQ[?oY8JcojB6/`Co
ZXRa1On/Qjd2ojZ3ZP;o00001?ngdNd4ojJHa`?oX8Fg1OnSP[02ojJ1[003oi=SU_n^PJ?o[X6S00?o
[X6S1?n^Oj82ojYnY0?o`YV^0on`PZ@5ojEhX@Co_9F`1?nbS:d00ooEb<go`:6jol2Q^P03ol2Q^P04
ok>B]?o8`]Cob<;DolS2e0Co_j_500?o_oK_olK<goo6c=l00oo6c=l00onm]M7o^mcaok_Ll@02ok_L
l@;o^lKS0onWi_/2okGHlP?oWmcl0_nZeOH2oicGo0GoYMCh0_nYco<00onTc?Co0000ojC<m002ojO:
lP;oY<Oa1OnVa_02ojS5kP;oY/;]1OnW`Nd2ojO1k0;oY/3/4_ooool2o`0000Wooooo1?l000000ol@
413oooooooooo`07ooooo`009?ooool00ol0003oooooooooo`0@ooooo`03ojo2j?ni`n;o^L?R00?o
^L?R00?o^/[Vokk5gonnaMl00onnaMl00onoa]oo_KkJokfnfP02okfnfP03okbkf?ne[];o]JkB00;o
]JkB1?nbZ<h2ojnQb@03ojJIb?nRT/?oXY;300;oXY;31?nOS;l3oib6^`CoVH6h0ol00003oiAi/P?o
TgJ_1?nALjd3oi1a[0;oT6nZ00CoSGNfohih]on>N;OoSWRg1?n>NKP3ohmk^0CoTWfi1?nEOkT3oiJ1
^PCoU8:m1?n=Q<@2oh25c`03ohaUX?n<IIooS6FO00;oS6FO0on;I9l3ohQSX@?oPf6S0on0HjP01?n8
HYooS6>NohaSW_n<Hih4ohiTW@?oT6BK0_nAI9X00onKP;GoY8JcojB6/`03ojB6/`?oZXRa1On/Qjd0
0onZPj[oXGFRoj5eXP02oj5eXP?o]m7]1?nVV<L4oj25]`CoXh:`00?oYX6/oi=SU_nCHiH01On^PJ<4
ojioXP03ojYnY?o2VJko`YV^00;o`YV^1?n`PZ@3ojEhX@03olFW^onlUK3o_9F`00?o_9F`0_nbS:d2
omG8c@Co`:6j00?oaOC^olS2e?o8`]@00oo8`]@00onoZlGo_oK_okofk`02okofk`;oa/cO0onIk?L2
ok_Ll@?oLn3/0_nWi_/4ohGLoP;oWmcl0_n>eOl4oicGo0;oYMCh0onOc?L2ojC<m003oj;6l_l0003o
X/Kb00CoY<Oa0_nVa_02ojG2kPGoY/;]0_nW`Nd2ojJok0GoY/3/4oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo01;ooooo0oni`n82okk4g`Co_/GO0_nn`M`3
okfnfP03okReeone[];o]JkB00?o]JkB0onbZ<h00onYX<goYYW8ojJIb002ojJIb0?oXY;31?nOS;l4
oib6^`?o00000onFO;@3oiAi/P;oTgJ_00?oSWVgoheh]_n=N;H00_n=N;H6oheg]P?oSWRg1On>NKP3
ohmk^0?oTWfi1?nEOkT4oiJ1^PCoU8:m0_n=Q<@01?n:IJ;oS6FPohaUX?n<IJ04ohaUW`?oRfBO0on8
Hj43oh=QX`CoP6>X0on0Ijd3ohI_/@04ohiTWOn@I9_oT6BKoi1h]0?oVh2e1OnTQ[<4ojZ8/@?o[8N]
0_nMM:D4oj5eXP?oXG:N00Co]m7]ojJHaonVV<OoYYS71?nPQKL2oj>2/0;oUfJF0_nCHiH00on/PZOo
[X6Sojj1X`03ojj1X`Co[WnR1Oo2VJh4ok22Y0;oYGRQ0_o5Yk/5okbE/004ok:<[OoEb<goeLS=omG8
c@?o`:6j0oo5m>h3olS2e0?o00000_nom^l3o`0000;oVNcg00CoE;7kod^nmOm;__GoBkke1?mNcOL2
ohGLoP?oP/oo1?n>eOl2oicGo0?oV/_i0_nOc?L2oio4lP;oX/Kb00?o0000oj;6l_nRa_800_nTao42
ojC1kPCoYL;^0_nV`^d2ojFok0GoY[o/0_nV`>`2ojJojaCooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`09ooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0Cooooo`03okW3h_nn
a=oo_/CO00;o_/CO00?o_/GOokk1g?nn`M`00onn`M`01?nm_][o^;GGokReeonh]ML5okF^dP04ok:X
c_nYX<goZJ3=ojVPc@?oYYW80onRT/<4oin<_`04oib6^ol0003o0000o`0000;oVH6h00CoTH2loi1l
^_n@O;[oT7bj0on>N[P3ohii]`CoSGRf1on=MkH3ohih]`CoSWVh0on?NkP3oi9m^@GoUGni0onFPKX2
oiB2_@03ohKXlOn8IJCoRVFR00;oRVFR1?n<IJ03ohaUW`?oRfBO1?n8Hj43oh=QX`?oP6>X0on0Ijd4
ohI_/@?oT7Rd1?nKP;D4ojB6/`CoZXRa00?o[8N]oiedYOnMM:D00_nMM:D4oj5eXPCoXG:N1?nOKYX3
oi]ZV0CoUfJF00CoTf>Fojb2Yon/PZOo[8:W1?n^PJ<4ojioXP03onkYa_o2VJko`YV^00?o`YV^0on`
PZ@00onUN:7oaJNkolFW^`02olFW^`?o_9F`0_n5fHl4omG8c@03ol2Q^_o5m>koaOC^00;oaOC^00?o
b<;DoiRIdonHVM<01?nHVM<2ogjXk`03oinIc_nAX^3oTJ;P00;oTJ;P1On5/o<3og_1o@;oP/oo0onC
__@4oiC5n0;oV/_i0_nM_o05oio4lP;oX/Kb00?o0000oj>okOnT`Nh01?nT`Nh2ojG2kP;oYKk/1?nU
_n`2ojJok0?oY[k[1?nV_n/Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Ooo
ool000Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o
0000ooooooooool05Oooool3okk4g`?o_lCN0onn`M`00onj_=_o^;GGokRee`03okRee`;o]JkB0_n]
Z=84ojVPc@?oYYW81?nRT/<2oin<_`;o00000onCQ;l4oi60_0?oT7bj0on>N[P3ohii]`?oSGRf1on=
MkH3ohih]`CoSWVh0on?NkP4oi9m^@CoUGni0_nFPKX2ohcTn`?oR6FT0on:IJ84ohaUX0?oS6FO0on;
I9l4ohQSX@?oPf6S1?n0HjP3oh1W[@?oQVna1?n@N;@3oi^0]@GoY8Jc0_nZR;43oiI`Y@?oWGBU1?nQ
MJ84oj5bWPCoWfjJ0onKJYP3oiMVUP03ojZ6[_n/PZOo[8:W00;o[8:W1On^PJ<2ojioXP;ok^W61Oo2
VJh2ok22Y003om7LhOo5Yk_oaJNk00?oaJNk0_nlUK04ohGIS`;oeLS=1?nMQk/4ojRD`@CoV9WC00?o
[9S2oinIc_nOVLh00_nOVLh4oi6Rh0;oQK?c0_nNZ]l4oiJcj`GoTkkd0_nDaOP2oibhk0CoWKo`0_nO
a?82oj:lk0?oXko]00Co0000oj>okOnT`NkoY<7^0_nT_N/5ojFnk0;oYKo/1onV_^/4ojJoja?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`002Oooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`0001Kooooo00?o_/COoko4g_noa=h0
0onoa=h01?nn`Mco^[cKokZlfonj_=/3okRee`03ok2`f?n]Z=;o[JSB00?o[JSB0onYX<d4ojJIb0;o
XY;30ol00002oiJ9``?oThBo1?nAP;`3oi1l^P?oSWZh0on>NKL4oheh]PKoSGNf0on>N;L5ohii^0?o
Sg^h0onBOKT2oiEo^@CoQm_n00?oS>Ckoh]YY_n8IJ@00_n8IJ@3ohYUXPCoS6FP0on<IIl3oh]TW`Co
R6>Q0on3HJ<4oh1SZ0?oP6N]0on6Kk44oi1h]0?oVh2e1OnTQ[<00onZR;7oSVRRoiI`Y@02oiI`Y@Co
WGBU0onQMJ84oj5bWPCoWfjJ0onKJYP2oiMVUP;oZXJ^1?n/PZL5ojj1X`04ojioX_o^jLKok^W6onkY
aPGo`YV^00Co/8:Tom7LhOoAg>7odMcQ1?o5Yk/00onlUK3oZXbfojZ<]P05oj^9/@?oWHNk0_nfV;P4
ojRD`@04oiRIdon/V<;o[9S2ojbH`PGoWiW>0_nAX^000onWXm;oWZ[OoijZg`03oijZg`CoU[?[0_nC
__@2oinai@GoW;S/0_nM_o02oj:hj0CoX[c/0_nS_nd00onT^nWo0000ojBkj@04ojBmj`;oYKk/0_nV
_NX7ojJnj`;oY[kZ1OnV_n/Aooooo`?o00001oooool00ol0003oooooooooo`09ooooo`002Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01?ooool00ol0003ooooooooo
o`0Hooooo`?o_lCN00?o_<CPokZlfonj_=/00onj_=/01?nh]MOo/;3Hok2`f?n`/=P4ojfXdPCoZJ3=
0_nVVLP3o`0000;oVHk70onFRL<3oi>4_`CoTH2l0on@O;X3ohij^0?oSWVg1?n=N;H7oheg]P?oSWRg
1?n>NKP3ohmk^0;oTWfi1?n5d?l2ohOKoP?oRfVV1?n8IJ@2ohYUXPCoS6FP1?n<IIl3oh]TW`?oR6>Q
0on3HJ<4oh1SZ0?oP6N]1?n6Kk43oi1h]0CoVh2e0onTQ[<3ohiXXP?oUW2U1?nMM:D3oj5eXPCoXG:N
1?nOKYX3oi]ZV003oiMVU_nZQZkoZXJ^00;oZXJ^0on/PZL5ojj1X`03ojioX_o^jLKok^W600;ok^W6
0oo2VJh00onSO:WodMcQom7Lh@02om7Lh@?oaJNk00?o/Hb_ojZ<]_nZS;H00_njU;05oj^9/@04oif7
^onfV;So]YRhokJH^0CoZ9C11On/V<83oinIcP03ok2Rb_nWXm;oYj?B00;oYj?B1?nNZ]l2oiJcj`?o
Xj[L1?nO/ND2oibhk0;oY;CT1OnR^>P2oj:lk0;oYKSW0_nT^nT00ol0003oY;_YojBkj@02ojBmj`;o
Y[_X1?nV_NX2ojJnj`;oYkgY1OnV_^X2ojJoj`;oYko[3_ooool4o`000003ooooool0003ooooo00Ko
oooo00?o0000ooooooooool02Oooool000Wooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool06Oooool01?noa=ko_<CPokc4h?nla>03okZl
f`03ok>ig_n`/=So/;3H00?o/;3H1?n]Z=82ojVPc@?o00000_nMUL/3oiV>a`?oUXW31?nCQ;l4oi60
_0?oT7bj0on>N[P3ohii]`?oSGRf1on=MkH3ohih]`;oSWVh0on<]o84ohK3n`;oQM3o00?oTgF^ohi^
ZOn>KZT00_n>KZT2oh]YYPCoR6FT0on:IJ83ohaUX0CoS6FO0on;I9l3ohQSX@?oPf6S1?n0HjP3oh1W
[@CoQVna1?n@N;@3oi^0]@03ojB6/on7H9koSVRR00?oSVRR0onFL:D4oiedY@CoXGFR0onQLYh4oim^
VP;oVfZH00?oYHbjojZ6[_nZQZh00onZQZh3ojb2Y`Go[X6S00OoZXVbokJ<ZonfS:_o]Xb[onkYa_o2
VJko[8:W00?oXgbY1?oAg>401?o5Yk_o/Hb_ok6<[onZS;H3okZD/0GoZhVa1?nfV;P3ojRD`@;o]ibm
1?n/V<801?nOVLko/:;:ok2Rb_n`X/X5ojNSdP;oWZ[O0_nYYm@5oj>Zg0;oWk7U0_nW/=l4ojBdi0;o
X[SX0_nV]N<5ojFhi`;oY;_Y00?o0000ojNjionV^nP01?nV^nP2ojJmjP;oYkcY1?nW_NT2ojJnjP;o
YkkZ1OnW_n/:ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`03oeEEEOmVIVKo000000_o
oooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Gooooo0_l0000Kooooo`Co_<CP00Co^[cKok>ig_nc^Mko/kWN1On`/=P2ojfXdP?o00000_nPW=03
oifEb`?oVHk71?nFRL<3oi>4_`CoTH2l0on@O;X3ohij^0?oSWVg0on=N;H2oheg]P;oSI[K0on>X^44
ohn[j@GoS;Ob0_n6`o/2oiUm/`?oTgF^0on>KZT3oh]YYP?oR6FT0on:IJ83ohaUX0CoS6FO0on;I9l4
ohQSX@?oPf6S1?n0HjP3oh1W[@?oQVna1?n@N;@2oi^0]@?oQf2N1?n>J:83oiI`Y@CoWGBU1?nQMJ83
oj5bWP;oWfjJ0_nQVL`3ojF<^PGoZXJ^1?n/PZL3ojj1X`03ojb6[OnfS:_o]Xb[00;o]Xb[1?n/PZL2
oj=lZ@?o^YB`1?naS:l4okZD/0CoZhVa00?o_YniokJH^?nfV;P00onfV;P01?nXU<7o]ibmokNL_Ong
W;d4ojbH`PGo/:;:0onWXm800onaZ<ooZJODojVWe003ojVWe0;oXj[L0_n/[mX5ojN`g`;oY;CT00?o
ZK?PojJehonV]N<00onV]N<3ojFhi`06ojRhiOnW^^OoYk[WojNjiol0003oYk[W0onV^nP00onW^nOo
YkcYojNlj@03ojNlj@;oYkgY0_nW_^T4ojNnjP;oYko[0_nX_n/6ooooo`Co00002?ooool00ol0003o
ooooooooo`0Aooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo01_ooooo0_nla>02okG3i0Co/kWN0_n`/=P01?nV
[Mco0000o`000?l00002oj>TeP?oX9c@1?nMUL/3oiV>a`?oUXW30onCQ;l2oi60_0;oRhg?0on:S=03
ohZ=d@?oRi3C1?n<U=H4ohfJf`?oSZ;Q1?n?ZnT2ohbglP;oSFfZ1?n9J:L3ohIUY0?oSVjY0on;JJH3
ohQUY0?oRVFR0on<IJ04ohaUW`?oRfBO1?n8Hj43oh=QX`CoP6>X0on0Ijd3ohI_/@;oT7Rd00CoPeRG
ohAKV_n4Fi[oQ5^J0on7H9h4ohiXXPCoUW2U0onMM:D4oj5eXP;oXG:N00?oW:cRoj6Ic?nQVL`00onQ
VL`3ojF<^PCoZXJ^1?n/PZL2ojj1X`03ojb6[OnnW;Go]Xb[00?o]Xb[1?n/PZL00onSO:Wo^YB`okZD
/002okZD/0Co/Hb_00?oaJFhokZD/?njU;000_njU;02oj^9/@?o_Yni0onfV;P00oo6[<7o]ibmokNL
_@02okNL_@?o[9S20_nkZ<H4ok2RbP03ojNSd_naZ<oo/JS?00;o/JS?0onYYm@00ona/=Oo[:oJojb_
fP03ojb_fP?oYk3O00?o[;?MojVch?nY/n000_nY/n04ojJeh`03ojFhionX^>GoZ;SU00;oZ;SU0_nW
^^L00ol0003oYk[WojJkj004ojNki`?oYkcY00?oZ;gYojNnjOnW_^T00onW_^T2ojNnjP;oZ;oZ1?nX
_n/2ooooo`?o00003?ooool00ol0003oooooooooo`0Aooooo`008_ooool00ol0003oooooooooo`0M
ooooo`Co]L?T0_nc^Mh01?nY]^?o0000o`000?l00002ojJ]g0CoXjCF0onPW=02oifEb`04oi>Jeon@
UMCoT9GDoi2Ee0?oSY7B0on<S]05oh^=c`?oRXc@0on:SM43oh^@d`CoS9CF1?n=V]/3ohjRh@;oSj_Y
0_nAM:h3ohe]ZPCoRFRW0on6IJ@3ohARX`?oPV6T0on8IJ@3ohYUXPCoS6FP0on<IIl3oh]TW`CoR6>Q
0_n3HJ<2oiJ?bP?oO[kk0_n9FiH4ohAHU@?oPeRG0on4FiX3ohMPWPGoSVRR0onFL:D3oiedY@;oXGFR
0_nG`O@4oib/hPCoXIW<0onUS;X4ojZ6[PCo[8:W00?o[X6Sojb6[OnnW;D00_nnW;D3okJ<Z`Co[8:W
1_njU;02ok6<[`;oaJFh1?njU;000on[RK7o_YniokjO^@02okjO^@;o]YRh0_o6[<45okNL_@04ojbH
`_nkZ<Ko^jS6ok^XaP?o/:;:00?o^Jk>ok6XconaZ<l01?naZ<l01?nYYmCo/K3Gok6`eona/=L4ojb_
fP03ojN`gon//mgo[;?M00;o[;?M1?nY/n02ojJeh`;oZ[SS1?nX^>D2ojNji`03ojRki_l0003oZ;_V
00CoYk_W00?oYkcYojRmjOnX_NT00_nX_NT3ojNnj@KoZ;oZ0_nX_n/2ojS0j`03o`000?oooooooooo
00kooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool07_ooool2okG3i0;o
Z/7Z0_l00002ojVfh`CoYZgL0_nSY=H01?nHY]ooUIoKoiFOfonEWm/4oi>Je`?oT9GD0on>TM83ohb>
d0CoRhg?0on:S=03ohZ=d@?oRi3C1On<U=H2ohfJf`03okN`d_nMQKWoUgbc00;oUgbc1?nAM:h3ohe]
ZP?oRFRW0on6IJ@3ohARX`?oPV6T0omoHJD3ohYUXPCoS6FP0on<IIl3oh]TW`;oR6>Q0_nHP;P5oiJ?
bP04ogjnnon9FiKoRE^FohUKUPCoQ5RE0on3F9L3ohAKVPCoQf2N1?n>J:83oiI`Y@;oWGBU0_nId?/4
oiO1m0?oW:cR1?nQVL`3ojF<^PGoZXJ^0_n/PZL00on]Qjgo[8J]okjL]@03okjL]@Co]Xb[0_n/PZL2
ol2Q^@Go^YB`00Co/Hb_olFU^?o5YKSoaJFh1?njU;05okjO^@03okJH^?o6[<7oaZc100;oaZc10ong
W;d00oo2/l_o^jS6ok^XaP03ok^XaP04ok2Rb_ni[/ko^Jk>okV^cPCo/JS?00?o^KKFok6`eona/=L0
0ona/=L2ojb_fP;o/KGL1?n//md2ojVch0;o[;SR1OnZ^><2ojRhi@;oZ[[U0onX^nH01?l0003oZ;_V
ojNkionW^nL2ojVmj0CoZ;gY00?oYkkYojRoj_nX_nX01?nX_nX7ojS0ja3ooooo00?o0000oooooooo
ool04?ooool002;ooooo0_l0000Pooooo`?o00000_nZ`NX3ojVfh`;oYZgL00?oVZgToiRVgonHY]l0
0_nHY]l3oiFOf`?oTi[G0on@UM@3ohjAdP?oS8k@1On;SLl3ohZ<d0?oRXgA0on;T=<2ohbDeP;o_;gJ
00?oY8nooif5^OnMQKT00_nMQKT3oiMl/`?oTGB^0on=KJX3ohUXY`?oQVFT0on4HZ<3oh9QY0?oOf6U
0on2IJP4ohaUX0?oS6FO0_n;I9l00onFN[7oV82hoiR0^003oiR0^0CoUXo:00CoSV2HohUKU_n9FiKo
RE^F1?n4F9D3oh=HU`CoQ5^J0on7H9h4ohiXXP;oUW2U0onTdoP3oiW@n`CoUl7d0_nL[>85oj6Ic0?o
YHbj1?nZQZh00on/PZOo[HN]ojf7[@05okjL]@Co]Xb[00Co[8:Wol2Q^Oo0XKWo`:6i1OnjU;05olFU
^0;o^YB`0_o:]<@4okjO^@GoaZc100?o]ibmol:cboo2/l/00_o2/l/3ok^XaP03olBme?ni[/ko^Jk>
00?o^Jk>00?o/JS?okVfe_ni]]H00_ni]]H3ok6`e`03okFjgOna]Mco/KGL00?o/KGL0_n//md2ojnj
h@Co[;SR0_nZ^><2ojbki@GoZ[[U0_nX^nH00onY_NSo0000ojVmj004ojVmj0;oZ;gY0_nY_nT3ojRo
jP;oZL3[2?nX`>/@ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo01co
oooo0ol000000oooooooZ/7Zoj[1jP02oibmk`CoVkGZ0onJ[N@3oiRVg`CoUIoK0onCV]L3oi2Ee0?o
SY7B0on<S]02oh^=c`?oL;cm1?mS`od2odg4l@?o`<OP00?oZY[5ojB?_onTSkl00_nTSkl3oif5^@?o
Ugbc0onAM:h3ohe]ZP?oRFRW0on6IJ@3ohARX`CoPV6T0_moHJD3oh9UZ0CoR6b/0on?LZh4oiIj/@Co
V82h0onFSlX2ohiPV0?oRE^F1?n4F9D3oh=HU`CoQ5^J0on7H9h2ohiXXPCo[/W]0_nTdoP2oi=]Y0Co
UVnT1?nILJ@00onKLZ?oXIW<oj6Ic002oj6Ic0?oYHbj0_nZQZh2ojb8[`;o[HN]0_o9^l`4okjL]@Co
]Xb[1?o0XKT4okZD/003omO@d_o5YKSoaJFh00?oaJFh00Co^YB`olZda?o:]<Cob[C40onnWkT2om38
d`CoaZc11_o2/l/01?nkZ<Koa;gDolBme?o4_M@3okV^cP03okbog?ni]]Ko^KKF00?o^KKF00?o/K3G
okFjgOne^]d00_ne^]d3ok6eg003ok:nhon_^^7o[k[Q00?o[k[Q0_n/^>82ojjmi@Co[;_U0_nZ^^D2
oj^nj0?oZKgX00Co0000ojVmj?nY_NSoZKgX1onY_nT00onX_n[oZL3[ojW0j`02ojW0j`;oZ<3[0_nX
`N/4ojS0j`oooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool06Oooool3
o`0000Kooooo0onL_Nl4oi^ejP?oVZgT0onHY]l2oiFOf`03ohN^kon4[NooQ:g_00;oQ:g_0on1[_44
ogf`m0CoMkGi0om`_?d2of?3o@?o`LoU00Co`<OPojZJaOnZV/GoZY[51?nTSkl3oif5^@?oUgbc0onA
M:h3ohe]ZPCoRFRW0_n6IJ@3ohARX`CoPV6T0omoHJD2oh9UZ0CoR6b/0on?LZh4oiIj/@GoV82h00Co
UXo:ohiPV?n>H9SoSV2H1?n9FiH3ohAHU@?oPeRG1?n4FiX2ohMPWP;o/;?K1?n^bNd2oi5[Y0CoTffT
0onFKj@4oiUaY004oi]bXonWRkSoYh^hojN;^0CoZHVc1?n/R:l01?n]QjgobK_<olVkc?o9^l`5okjL
]@;o]Xb[0_o5_M<4ol2Q^@;o^YB`0ooGd=83olFU^003olcOi_o:]<Cob[C400?ob[C400Co_Yniom38
doo@b=?od<SC0oo6[<42ol[>g@Co`[?;00?oaMGVolBme?o4_M@00oo4_M@01?ni[/ko_;oLokbog?nl
_m`3okVfeP;o^LCS1?ne^]d00ona]Mco/[kSok:nh`02ok:nh`?o[k[Q00?o[l7WojjmiOn^_ND00on^
_ND2ojbki@;o[;oX1?n[_^P2ojVmj003oj[0jOl0003oZKoY00KoZKoY1_nY`>/6ojS1j`;oZ<3[00?o
Z<7[ooooooooool03Oooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0F
ooooo`?o00002_ooool3oibmk`;oVkGZ0_n=]O43ohbbl0?oR[3_0on7[^l4ohB]k`?oPJka1?mm/?@2
ogNen@;o>koI00Co/O?dol3Cj?o0dnSo`=?X0_o1cnD00on`Y<coZY[5ojZJa@03ojZJa@?oY8no1?nM
QKT3oiMl/`;oTGB^0on=KJX4ohUXY`?oQVFT0on4HZ<3oh9QY0?oOf6U0on2IJP4ohQ/[0?oSg:^0onF
N[44oiR0^003og=GXonGJYcoSV2H00;oSV2H1?n9FiH3ohAHU@?oPeRG1?n4FiX00on7H9ko/;?Kok2c
f`02ok2cf`03ojk9kOnAK:GoTF^T00?oTF^T0onCKJ@3oiI_Y0;oVG6T0_nSRk/4ojN;^0CoZHVc1?n/
R:l4olVkc0Go_Ybe00Co]Xb[olFmdoo5_M?oaKgC1?o0XKT00onjU;3oem3BomO@dP02omO@dP;oaJFh
0oo<gnH3olZda003ojogk_o@b=?od<SC00?od<SC00CoaZc1ol[>gOo:c]gob/kM0oo2/l/3olGEiP?o
a;gD00?o_M;Zokbog?nl_m`00onl_m`00oni]]Ko^LCSokW4h`02okW4h`;o]K[M0_nca>L4ok:nh`03
ojnjhOn_`NOo[l7W00;o[l7W0on^_ND00on]`^Wo[;oXojboj003ojboj0;oZkkX0_n[`NX3oj[0j@03
o`000?nY_nWoZKoY00;oZL7[1_nY`>/<ojS1j`kooooo00?o0000ooooooooool04?ooool002;ooooo
0_l0000Dooooo`?o00003_ooool3ohjhl`CoSKGa0on</_03ohZ`k`?oQjk_0_n4[Nl4og75o`;oI/Sm
0_lj_lL3ojk]n005ok7cm?o0dnSo`=?Xol3Cj?nd[M801?n`Y<`4ojZJa@CoY8no0onMQKT3oiMl/`?o
TGB^0on=KJX3ohUXY`?oQVFT0on4HZ<3oh9QY0?oOf6U0on2IJP4ohQ/[0?oSg:^1?nFN[42oiR0^0?o
LeNS0on>H9P4ohUKUP?oQ5RE0on3F9L2ohAKVP?oZIc90on`/m/3oi5/Y@CoTF^T0onCKJ@2oiI_Y003
oij8_?nSRk_oXh^k00?oXh^k0onWRkP5ojV9/`;o[8R_0_o7l^h4olVkc0;o_Ybe0_nYkoP4olFmd`?o
`:6i0_moi;/4omO@dP03olFU^?o<gnKoc=oV00?oc=oV00Cob[C4ojogk_n_mnko[oO^0oo@b=<2ojW^
n0Cob/kM00?o`[?;olGEi_o5eNH00_o5eNH00oo4_MCo_M;ZokgBjP02okgBjP;o_;oL0_nfdNh4okW4
h`03ok7>konca>Oo/lCW00?o/lCW0_nb_^<2ok36jPCo[l7W00?o[[gUojg2jOn]`^T00_n]`^T2ojbo
j0;oZl?[1On[`NX2oj[0j@03ojW2jol0003oZL7[00?oZL7[0_nY`>/2ojW1j`CoZ<7[00?oZ<7/ojS1
jonX`N/01onX`N/=ooooo`03o`000?oooooooooo013ooooo000Qooooo`;o00004_ooool3o`0001;o
oooo0on>^?<2ohfel@;oQ[Sf0on3^_P4ognmn`CoNL3m0_maaOl2oeO?j@03ogkUk_n^kOSo[^gh00;o
[^gh0onne>/01?o0dnSo]:gBokB]d_nd[M83ok2Tc0CoZY[50_nTSkl2oiB2_@?oSWZi0on8M;H3oh=_
]0?oSFfZ0on9J:L3ohIUY0?oQ6:S0on2HJ@3ogmQY@?oPVFX1?n8K:`3ohmb[PCoUWZa00?oV82hofmE
Y?m_EJ@00_mcEj<3ogaNY@CoRE^F0on4F9D2oh=HU`03oin8^onYW<WoZIc900CoZIc900?o/;?KoiIc
ZOnAK:D00_nAK:D4oi5[Y0;oTffT00?oVH>joij8_?nNR;`00_nNR;`4oj>;^`CoYh^h1?nYRK<00on/
R:ooao;^olObkP02olObkP;obK_<0_nOUl`01?lF003oZNohojW_n?nYkoP4olFmd`05ol2Q^OnNW]?o
[IW2ojJKbomoi;/00_oGd=800onVVl_oS9kOohbNg`02olcOiP?oUZCO1?n_mnh00oo@b=?oZNkhojW^
n002ojW^n0;ob/kM0onJjoT2olGEiP?oX^7l0_nmd^X2oj;Mo0Co]]7^00?o^LCSok7>konac^l00_na
c^l2ok?4i`;o[Lc`1On`a^X2ojo1i`;o[<G/0on]`^T2oj[5k@CoZl?[0_n[`NX2ojW3k0?oZL;[00Co
0000ojW2jonY`N_oZL7[0_nY`^`4ojW1j`03ojS1jonX`NcoZ<7/00;oZ<7/2OnX`N/<ooooo`03o`00
0?oooooooooo013ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo
0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00oooooo0_l0000Fooooo`?oRKOd
1?n6^?H3oh>jn0;oOkgk1?mjc_l2ofcBn`;oR^?k0on]i_T2ok_Ck0?o_]C[00?o][CGokB]d_nd[M80
0_nd[M84ok2Tc0;oZY[500?oVX_2oiB2_OnDP[d00_nDP[d3ohij^@?oR7Bf0on3Kk@3ogm]]0?oRFRW
0on6IJ@3ohARX`CoPV6T0_moHJD3oh9UZ0CoR6b/1?n?LZh2oiIj/@04ogMNZOm_EJCoKeFTofmEY0;o
LeNS0omlGZD3ohMYZP04ohUKU_n4F9GoQ5REoiAh/@CoWhRk1?nYW<T3ohE^/@?oSGBc1?nCO;L4oiV3
^P?oWXRl1?nSRk/4ojN;^0;oZHVc0_nSSKh4ojB@_`CoY9?300CoWiO<ojbF_on/U[oo[9Jo1OnZVLD0
1?nNW]?o[IW2ojfI`_n]VL84ojJKb`CoZ:3>1?nFY=l2of>Um@;oUZCO1?mcZ?82odZ/n@04o`VGd_m8
`ngoB<?]odS3k@;oX^7l0ombdod4oj;Mo0;o]]7^0onTe?P2ok7>k`;oY=3g1?n]c?02ok36jP;oZ/W`
1On/aN`00on]`^WoZ/G]oj[5k@02oj[5k@;oZl?[0_nYa>d4ojW3k0;oZL;[00?oZ<?]o`000?nY`^`0
1?nY`^`2ojW1j`?oZ<;/1?nX`N`6ojS1j`;oZ<3[3Oooool00ol0003oooooooooo`0?ooooo`001ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool03?ooool3o`0001Wooooo0on9]o@2ohJhmP?oRKoi1?n3aod2og[>o`;oT]_n
0on[g?T00on]i_Wo^m?/ok_Ck003ok_Ck004okkDjonf]=Oo][CGokJde`Co]:gB0_n`Y<`00onQTlKo
VX_2oiZ;`P02oiZ;`P?oU8:m0on>N[T3ohQd]P?oPfnd0omoKK@3oga/]P?oO72k0on4HZ<4oh9QY0?o
Of6U0on2IJP4ohQ/[0?oSg:^00CoUWZaogMNZOmgGZWoMejY0_m_EJ@3og=GX`;oO5jU1?n7JJX4oiAh
/@?oWhRk0onYW<T01?n1Jk7oQFjaohE^/On5K[43ohed/`GoTgbg0onIPkX3oij8_0GoXh^k0_nWRkP0
0onPS;koXhfnoj>=_P03oj>=_PCoY92o0_nTTl<00on/Tkgo[9JoojbF_`02ojbF_`CoZYW500?o/YVn
ojfI`_n]VL800_n]VL83ojJKb`;o/j351?nXX<h2oiJTg`;oZj??1?nFY=l4og>XlP?oBZci1?lk/O82
og;Co@;oL<Go1?n8dOl2ojCDn0;oU]3l1OnTd?L2ojg<l0;oYL_d1?nZbO02ojc5k0?oZ<O`0_nZaNd2
ojO5k`GoZLC]0_nY`n`5ojS3k@03o`000?nY`^coZL;/00OoZ<;/1OnX`N`4ojS1j`CoZ<3[3?ooool0
0ol0003oooooooooo`0?ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00005
ooooo`;o00002_ooool3o`0001gooooo1On>^?<3ohVon@;oPlOm0onFd?`01?nBfokoZmcioj_LnOn[
g?T4okS@k0;o^m?/0_nh^]/4okJde`;o]:gB00?oYYc<oj6Ca_nQTlH00_nQTlH3oiZ;`PCoU8:m0on>
N[T3ohQd]P?oPfnd0omoKK@3oga/]P;oO72k0omnN/D4oh9QY0?oOf6U0on2IJP4ohQ/[0;oSg:^00?o
M5FPofMAY?mWDJ@00_mgGZT2ofmEY0?oLeNS0omlGZD3ohMYZPCoU7Ra1?nOR;/01?nYW<WoPF^aoh5[
/On1Jk43ohE^/@?oSGBc1?nCO;L3oiV3^PCoWXRl0onSRk/00onNS<7oX8bnoj2<_P02oj2<_PCoXhfn
0onTT;l00onYTKgo[9>mojbC_@02ojbC_@Co[9Jo00CoZYW5ok:I__nbVKko/YVn1On]VL801?nVVl_o
/j35ok>PaOncX<D3ojRPcP03okBSaon[XlooZj??00?oZj??0_nFY=l00onYYmGoVJ[SoiVZh`02oiVZ
h`GoP;3c0omX]O`4og35o`;oR=7o0on3aod3oiK@o0;oY=3g0_nLboP5ojG;m0;oZ/W`0onUbO82ojS7
l0;oYLK`1?nWaNl2ojW4k@;oYlC^1onX`nd00ol0003oZ<;]ojS2k008ojS2k0CoZ<7/1OnX`N/2ojS0
j`;oYl3[2oooool00ol0003oooooooooo`0?ooooo`001oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CoA4A4omgMgOoooooo00001_ooool00ol0003oooooooooo`06ooooo`?o00008Oooool2
ohjhl`?oVkc`1?nIa_H2oiK@o0?oZ];e00?oZmciokS@k?nhd>`00_nhd>`00ong_]oo^;[KokRjf`03
okRjf`;o][CG00?oZjGAojJLc?nVW<`00_nVW<`3oj6CaP?oVX_21?nDP[d3ohij^@?oR7Bf0on3Kk@3
ogm]]0?oO6bf0omlL;/2ogija@GoO8_F0om_Z_D01?nGN[7oRVVXohYYZ?n:JJP3ogmNXP;oM5FP1?mW
DJ@2ofmEY0?oLeNS0omlGZD4ohMYZP?oU7Ra1?nOR;/01?n1L;OoPF^aoh5[/On1Jk43ohE^/@?oSGBc
1?nCO;L4oiV3^P?oWXRl00?oXh^koif?aOnNS<400_nNS<43oj2<_PCoXhfn00?oY92oojVA_OnYTKd0
0_nYTKd3ojbC_@?o[9Jo1_nbVKh3ojfI`P03okNP`_ncX<Go/j3500?o/j3500CoZ:3>okBSaondXlOo
]:?70on[Xll00oneZLgoZJOEojVWe@02ojVWe@CoVJ[S0_n0/?<2oiV]i@GoR;;a0on1_OX2oh?7o@;o
SKog1OnCaoT3oic;n0;oYL_d0onPb?D2ojG9lP;oX/Kb1OnUa_02ojO5k`;oY/C_1?nWa>h2ojS3k@;o
Yl?]0onX`^d01?l0003oZ<;]ojS2k?nX`^`3ojO2k0;oZ<;/0_nW`N`4ojS1k0;oZ<7[1onW`>/:oooo
o`03o`000?oooooooooo00oooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01?oM
gMgoEEEEooooool00006ooooo`03o`000?oooooooooo00?ooooo0ol0000Vooooo`CoVkc`0_nIa_H3
ojS9l0;oZ];e0onec>/00onhd>co]kkOokNng`02okNng`?o^;[K00?o[jgFoj^UdOn[YM400_n[YM43
ojJLc0?oXI?61?nJRl83oiB2_@?oSWZi0on8M;H3oh=_]0?oOffd0omlK;H3oga`^`?oOW[51OmlRmH0
0om_Z_GoUgZaoiMj/@03ohYYZ0?oOejR0omdEJ03ofMAY003odU?]_m_EJCoKeFT00;oLeNS0omlGZD4
ohMYZPCoU7Ra0_nOR;/00omcH[7oPG2goh5[/@02oh5[/@?oQFja0on=M;<5oi=l]`?oVH>j0_nNR;`3
oif?a@?oWXc11?nPS;h2oj>=_P03ojF?__nYTKgoZI6m00?oZI6m1?n/Tkd00on/U[oo/YVnok:I_P05
ok:I_P03ojfI`_ngX<;o]j3200;o]j320oncX<D00onjY/Go]:?7okBSa`03okBSa`04oj^SconeZLgo
]JW=okFYc@CoZJOE0_nIZ^<2ojV[f@CoVJgU0_n8/_42oi^bi`GoT[Sa0on=_oL2oi?7n@;oUl7d1OnJ
aOH2oj38m@;oWlCb1?nRa_82ojG6l0;oY<C`1OnVa>l2ojO4kP;oY/?^1?nW`nd2ojS2k@03ojO2kOl0
003oYl;/00?oYl;/1_nW`N`2ojS1k003ojO0k?nW`>_oYl3[00OoYl3[2_ooool00ol0003ooooooooo
o`0?ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001Ooo
ool01?l0003oooooooooooooool3o`0002[ooooo0_nK_?02ojS0j`?oZ<W`0_ncanT3okG<j`?o]l7Q
1?ng_]l01?nh^]_o[jgFojn]e_n_[MH3oj^Ud@CoYYc<0onQTlH2oiZ;`P04ohj6a_n8P/KoR8;6ohR2
aP?oPWo70on8M;H4oh=_]0?oOffd0omlK;H2oga`^`CoOW[50_mlRmH3oh1_]`?oUgZa0_n:JJP3ogmN
XP?oM5FP0omWDJ@2odU?]P03ofmEY?mcEj?oLeNS00?oO5jU1?n7JJX4oiAh/@04oin8^omcH[7oLf:a
og=R/@CoPF^a0on5K[43ohed/`CoTgbg0_nIPkX3oj6Hc0?oWHo50onNS<43oj2<_P03oj2<_onUSkko
YHnn00;oYHnn1?nYTKd3ojbC_@03ok6J`?nbVKko/YVn00Go/YVn00?o^:?3okNP`_ngX<800ongX<80
1?ncX<Go^ZK5okZVaOnjY/D4okBSa`03ok^[b_neZLgo]JW=00?o]JW=0_nYYmD2ok:[d@CoZJ_I0_nI
[ND2ojJ_gPCoVk;W0_nB^?42oijej@CoV;[`1?nG`O@2oi[5mP;oWL3a1OnOa?82oj;6lP;oX/?`1?nT
a?02ojK4k`;oYL;^1OnV`nh2ojO3k@;oY/;]0onW`^d00ol0003oYl;/ojO1k007ojO1k0CoYl3/2OnW
`>/9ooooo`03o`000?oooooooooo00oooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00oo^k^koA4A4o`000005ooooo`Co0000;_ooool4ojS0j`03ojS9l?ncanWo/lOY00;o/lOY00?o
]Lc[okO1hOng`N400ong`N42okNng`03ok6cf_n_[MKo[jgF00;o[jgF1?n[YM42ojJLc004oi^Dc?nE
SLWoUHg9oiF=b@CoSXK60on8P/H2oh9oa`?oO87<0omeR=P01?n3KkCoOffdogm]]?moKK@3oga/]P?o
O72k0_mnN/D3oi61_`?oP6ng0omdI;83ohYYZ0;oOejR0omdEJ03ofMAY0?oBDnf0omcEj<2ogaNY@Go
QfVZ0_nDN;43ogALZ@;oLf:a0omiML801?n1Jk7oQFjaohE^/On5K[43ohed/`;oTgbg0on/[MP4oj6H
c0CoWHo50onNS<401?nPS;koX8booj2<_onPS;l3ojF?_PGoZI6m00Co[9>mok6J`?naV/3o/I[01Onb
VKh3okRS``Co]j321OnjY/D2okBSa`;o^j_:1?neZLd00onk[lko/Z_Aok:[d@03ok:[d@;oZJ_I0_na
/=L4ojJ_gP;oVk;W0_nV/^44oijej@CoV;[`0_nG`O@2oiflkPCoWL3a0_nOa?82oj71k`GoX/?`0_nT
a?02ojC2kPCoYL;^0_nV`nh7ojK2k@;oYl;]00Co0000ojO1k?nW`NcoYl7/0_nW`>`5ojO1k0;oYl3/
2_nW`>/9ooooo`03o`000?oooooooooo00oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3Oooool00omgMgOo0000ooooo`04ooooo`;o0000<Oooool2ojS0j`?o/L;W0_ncanT2okK2h`Co]l7Q
00?o/kWNok6cf_na/mX00_na/mX4ojn]eP;oZjGA00?oX9c@oi^Dc?nKU<`00_nKU<`3oiF=b@?oSXK6
0on8P/H3oh9oa`?oO87<1?meR=P4ofFKk`03ob>ViOna[MCo/JgD00?oXIK90onAPKl3oh1_]`?oM6Bb
0_mXG;400on:JJSoOejRogmNXP03ogAEX0CoIe6T1?m9CkH01?mcEj?oO5jUogaNYOmlGZD4ohMYZP03
oiAh/OmmHj[oM5bY00;oM5bY0omcH[43ogUe`PGoOYkV00CoJ=?hokoAionodNOo_m7W0on/[MP3oj6H
c0;oWHo50_nFQl83oi^9`0CoX8bo0onUSkh4ojVA_@03ojfI`_naV/3o/I[000;o/I[01?nbVKh4okRS
``?o]j320_nmZ/L4okZVa@03okBSaonkZl[o^j_:00;o^j_:0_neZLd3ok^_cP?o/Z_A00?o^;;Cok6`
eona/=L00ona/=L2ojJ_gP03ojjbfonV/^7oY[;Q00?oY[;Q0_nN]NT2ojJfi0CoX;SY1?nM_>h2oig0
l@;oXKg]1?nQ`Nl2oj;3l0;oXl3^1OnT`^h2ojG2kP;oYL7]1_nV`^d3ojK1k0;oYl7/00?o0000ojO0
k?nW`>`00onW`>`2ojO1k0ooYl3[2?ooool00ol0003oooooooooo`0?ooooo`008_ooool00ol0003o
ooooooooo`0_ooooo`?o/L;W0_ne`n@4okK2h`03okO1hOnc^Mko/kWN00;o/kWN1?na/mX2ojn]eP03
ojFTe?nPW=3oX9c@00;oX9c@0onKU<`3oiF=b@?oSXK60on8P/H3oh9oa`?oO87<1OmeR=P2ofFKk`04
okg3gona[MCo/JgDok6]e0?oXIK91?nAPKl2oh1_]`?oM6Bb0omXG;43ogmNXP;oM5FP1?mWDJ@3odU?
]P;oSHc=0omlGZD2ohMYZP04ohad/ommHj[oOF>ZogeSZP?oM5bY0omcH[44ogUe`P?oOYkV0_oBn>@2
okoAi`04oibMe?nDS/_oU8k;oiB>b`?oThS51?nFQl84oi^9`0?oX8bo1?nUSkh01?nYTKgo[IW2ojfI
`_n]VL84ok6J`0?o/YVn0_nhYLH4okRS``04okNP`_nmZ/Oo_J[7okfZa`?o^ZK500?o_[3<ok^[b_nk
ZlX00onkZlX00oneZLgo^jo>ok^_cP02ok^_cP03ok:[dOnh/]?o^;;C00;o^;;C0ona/=L00onf]=Oo
[[;Kojjbf`02ojjbf`?oY[;Q00?o[;GOojJfi?nV]^@00onV]^@2oj2hj@03ojJhi_nS^^[oXk[Z00;o
Xk[Z1OnQ_Nd2oj71k`;oXkk/1?nS`>h2ojC2kP;oYL3/1OnU`Nd2ojK2k@;oY/3/0_nV`N`5ojO0k004
o`000?nW`>coYl3/ojO0k1;oYl3[2Oooool00ol0003oooooooooo`0>ooooo`008oooool00ol0003o
ooooooooo`0_ooooo`03ok72ione`nCo]L?T00;o]L?T0_nf`^<3okBnh@Co/kWN0_na/mX00onY[=Wo
YJCDojFTe002ojFTe0?oX9c@1?nKU<`3oiF=b@?oSXK60on8P/H3oh9oa`?oO87<0_meR=P2od33d0Co
_L?O0ona[M@3oj6Fb@?oTH6o0on0KkL2ogAT/P?oJ5ba0_mZI;T01?moGZ;oM5FPogAEX?mdEJ03ofMA
Y004odU?]_nMdO[o_LORokg7hP;oSHc=0omgKKX2of]P]0CoOF>Z0_mdG:T3og=R/@CoNGG200?oOYkV
ojW^n?oBn>@00_na^n44oibMe0?oU8k;0onCR<D4oiJ7`P?oVhW01?nPS;l2ojF?_P03ojRHaOn]VL;o
[IW200?o[IW21?naV/001?nbVKko^:G6okRUa_nhYLH3okRS``03okf_c?nmZ/Oo_J[700?o_J[700Co
^ZK5okj`c?nn/<co_[3<0onkZlX2okjdd0?o^jo>00?o_KODokRbdonh/]<00onh/]<00ona/=Oo][CG
okJde`02okJde`Co[[;K00CoY[;Qojbegon/]Moo[;GO0onV]^@00on[]n;oY[SVojJhiP02ojJhiPCo
Xk[Z0_nQ_Nd2ojBljPGoXkk/0_nS`>h3ojFnj`?oYL3/0_nU`Nd3ojJok0;oY/3/0_nW_n/6ojO0k003
o`000?nW_n_oYl3[00KoYl3[0_nW_n/<ojO0j`Sooooo00?o0000ooooooooool03_ooool002Cooooo
00?o0000ooooooooool0;oooool3okG3i0;o]<?U1Ond_^42ok>igP03ojbcg_nY[=WoZJcI00;oZJcI
1?nUY=@3oj2Ld0;oViC<00CoTIgLohbKgOn<VmgoS9_M0on5W>44oh2Sj@CoNK7f0_mZb?h4ol?Di`;o
_L?O00CoXIK9oiF6`OnEQ/7oUHK10on7N;`3oga_^@?oP6ng0omdI;83ofQL/@;oJVBi0omdEJ02ofMA
Y0?oWM7j0_n8N[h2ofaQ]@?oMffj0_m[H;@3og1W^@04ogeSZ_mdG:WoM5bYogALZ@?oLf:a0_miML82
ojW^n003olSSjona^n7o/K_Q00;o/K_Q0onLWM@3oiB>b`?oThS51?nFQl84oi^9`0;oX8bo00?oXYC6
ojRHaOnXV<D00_nXV<D4ojfI`P?o/I[000?o]JO;okRUa_nhYLH00onhYLH01?nhXl?o_Jo<okf_c?nm
[l`3okfZa`03oknfdOnn/<co_[3<00?o_[3<00?o^j_:okjdd?nn]=000_nn]=001?nk[lko_KODokfg
e?nm]m@3okRbd`03okZheonf]=Oo][CG00?o][CG0_n^/]/2ok:fg0Go[;GO00CoY[KToj^gh_n[]n;o
ZkOR1?nV^>H2oj>jjP;oY[[W1?nT_>X2oj>nk0?oY[cZ0_nU_^/2ojJmjPGoY[k[0_nV_n`00onW_^_o
Yko[ojNoj`03ojNoj`;oYl3/1?nW_n/01?l0003oYko[ojO0jonW`>/7ojNoj`;oYl3[00?oYko[ojO0
jonW`>/01onW`>/7ooooo`03o`000?oooooooooo00kooooo000Uooooo`;o0000<?ooool00one`nCo
]<?UokC3i@02okC3i@;o];kQ0on_^n83ojbcgPCoZJcI0_nUY=@01?nLYmkoUj;LoiNRg?nGX]`4oi6M
g0?oS9_M0on5W>44oh2Sj@;oNK7f00?oL=k4ol?OkOo3gnd00oo3e>L00on/Y]7oXIK9oj6Fb@02oj6F
b@?oUHK10on7N;`2oga_^@;oKVRk00CoP6ngogAT/_mdI;;oM6Bb0omXG;42ofYT^@CoNH7?0onMdOX3
ohQj_P?oK66e0_mgKKX3of]P]0?oL6Ni0on2OlP2og=R/@?oV:kV00CoZNkholSSjoo8hn_ob>?[0ona
^n44oibMe0?oU8k;0onCR<D3oiJ7`P;oVhW00_nLT<L4oj:DaP?oZ9S51?n]VL800onaV/3o]JO;okFW
b`02okFWb`?o^:G600?o^kGCokf_c?nm[l`00onm[l`01?nmZ/Oo_kKAoknfdOno]]43okj`c003ol2k
eOnn]=3o_[C@00?o_[C@1Onm]m@01?nh/]?o^[SGokZheonj^=L3okJde`;o]k[K1?nb]]`2ojbeg`;o
/;SO1On[]n82ojJhiP03ojZii?nV^^OoY[[W00?oY[[W0_nT_>X3ojNkj0;oY[cZ0_nW_>P4ojJmjP;o
Y[k[0_nW_^X4ojNnj`;oYko[0_nW_nX7ojNoj`03o`000?nW_n_oYko[00_oYko[2OnW`>/6ooooo`03
o`000?oooooooooo00kooooo000Wooooo`03o`000?oooooooooo02kooooo0ond`nD3ok32i`Co[k_R
0on//mh2ojV/f@;oXJgQ0onLYmh3oiNRg0CoTIgL0on<Vmd3ohFLh@;oP:?Y00?oO>KVojOgjOnWmnT0
1?o3gnd01?o3e>Oo[:KAojbVdOn/Y]43oj6Fb@?oUHK10on7N;`3oga_^@;oKVRk0omdI;83ofQL/@?o
JVBi1?miPLl00onMdO[oYj3?ojNPc`03ohQj_P;oK66e0_mTH;P00omgKK[oJf2dof]P]003og1W^@Co
PWo80onH[^H2omOkgP;ob>?[00CoY:WJoi>BconCT/ooTi;?1?n:Q/T3ohZ3aP?oSXK60onDRlH4oib@
a`CoXYC61?nXV<D2ojfI`P03ok6Xd?neYl_o]JO;00?o]JO;00?o^:G6ok^edonk]M<00_nk]M<3okf_
c003okbmf_no]]7o_kKA00?o_kKA00Co_[3<ol2keOo0^mGo`;_E0onn]=02okjmf0?o_KOD00?o_KkK
okZheonj^=L00onj^=L00onf]=Oo]k[KokNjf`02okNjf`;o/[KL0_nd^]h4ok2hg`;oZkOR0_n]^N84
ojZii0;oY[[W0_nY^^H4ojNkj003ojVlionW_>SoYkcX00?oYkcX0_nV_NX2ojRmj@CoYkkZ0_nW_^/2
ojNnjPCoYkoZ0_nW_n/2ojNojP?oYko[00?o0000ojNojonW_n/02onW_n/8ojO0j`Kooooo00?o0000
ooooooooool03_ooool002Sooooo00?o0000ooooooooool0;_ooool00ond`nGo/<;Wok32i`03ok32
i`;o[k_R00?oY[[WojBdi?nT]>@00_nT]>@4oj6]h@?oW:ON0onGX]`2oi6Mg0;oQ[_g1?mma?h01?mW
c__oWO7aoigalOnMlO43okgRlP;o`mo]00?o];CIojbVdOn/Y]400_n/Y]43oj6Fb@?oUHK10on7N;`3
oga_^@;oKVRk0omQKLP4ofQL/@;oJVBi0omiPLl01?o:cmgoYj3?ojNPconWX<l3ohQj_P?oK66e0_mT
H;P2of]P]0CoL6Ni1?n2OlP01?nH[^Koeo_NomOkg_o2cN<4ojBYfP?oTi;?0on:Q/T4ohZ3aP?oSXK6
0onDRlH4oib@a`?oXYC60onXV<D00on/Z=?o/JS@ok6Xd002ok6Xd0?o]JO;00?o]k[Kok^edonk]M<0
0onk]M<00onm[lco_;gJokbmfP02okbmfP?o_kKA00?o_/?Nol2keOo0^mD00oo0^mD00onn]=3o_[gH
okjmf002okjmf004okfge?nm_]_o_KkKokfnf`?o^[SG0_nj_]d3okNjf`03okNngond^]ko];[N00?o
];[N0_n`^=l2ok6kh@Co[KWR0_nZ^N@2ojbji0CoZK[V00?oYk_XojVlionY_>L00_nY_>L2ojNlj0;o
ZKgX1OnX_NT2ojNnjP03ojRnjOnW_^[oYkkZ00?oYkkZ0_nW_nX2ojRnjPCoYkoZ0_nW_n/00ol0003o
Z;o[ojNoj`0<ojNoj`SoYl3[1Oooool00ol0003oooooooooo`0>ooooo`00:Oooool00ol0003ooooo
ooooo`0_ooooo`;o/<;W0onW`>/3ojJji`CoY;CT0_nQ[N42oiVfk0?oTkG^1?n>]_43ohJkm`;oOLCn
00?oQN;joigalOnMlO401?nmh_800onh`>3o];CIokBdf@02okBdf@Co[:KA0onQU/T3oiF6`@?oQgRl
0_mlKkT3ofiX^`?oHFg80_leQ^/01OmXG;7oJVBiofYT^OmZI;WoNH7?00;ob/oM0onWX<l3ohQj_P?o
K66e0_mTH;P2ofQbbP04of]P]?m`IkWoL6Niog1W^@?oPWo800?o[_[DomOkg_oGnmh00oo2cN<3ojBY
fP?oTi;?1?n:Q/T3ohZ3aP?oSXK60onDRlH4oib@a`CoXYC600CoZ9S5ojbXdon/Z=?o[:SC1?naZ=00
1?neYl_o]k[KokNjfong^]/3ok^ed`03okS3honl_M[o_;gJ00?o_;gJ00?o_kKAokk3g_nn`mh00_nn
`mh2ol2ke@;o_LCO1?nn_MP00onla>7o_KkKokfnf`03okfnf`03okZheonj_]go^[kM00;o^[kM00Co
]k[KokNngong_]oo]kkO0ond^]h00ond_N7o/K_Qok6kh@03ok6kh@;o[KWR0_n_^n<4ojbji0;oZK[V
0_n[_>H3ojVli`;oZ[cW1?nY_NP2ojRmj@;oZKgX1?nX_^T2ojNnjP;oZ;kY1OnX_^X2ojNojP06ojRo
j_nX_n_oZ;o[ojRojol0003oZ;o[0_nW_n/2ojRoj`KoYko[2onW`>/4ooooo`03o`000?oooooooooo
00kooooo000Zooooo`;o0000<Oooool4ojO0j`?oY[[W0_nT]>@2oibhk0CoVKK/0onC]Nh2ohjfl@?o
T<km0_n;f?l2oi_ZnP?o]n7d00?o_N;bokS0h?nh`>000_nh`>04okBdf@;o[:KA00CoVIO@ohf;c?n=
RlcoSH_<0on3Pl/3ogMnc@?oO6ni0_m^J;/4of5]b005ocF6jonjn[oofoCOom_dgong_n000onJVm<3
ogQjb0;oK6g20_n8N[h2ofaQ]@?oI62h0_mXL/X3og1W^@05oh9ob?n^n]Co[_[Dom;ocOoFk^<01Oo2
cN<3ojBYfP?oTi;?0on:Q/T3ohZ3aP?oSXK61?nDRlH3oib@a`;oXYC60_nVY]H5ojbXd`;o/JS@0_nb
_N84okNjf`04ok^edonh`n?o^<?SokS3h`?o_;gJ0_nhbNL3okk3gP;o^<[X1?nma=l00onn_MSo_<CQ
okc4h@02okc4h@;o_KkK0_nj`n44okZng@03okS2h_ng_]oo]kkO00;o]kkO00?o];[NokBmhOnd_N40
0_nd_N42ok6kh@;o/KkS1On_^n<2ojbji003ojfliOn[_>KoZkcV00?oZkcV00?oZKcWojZlionZ_>L0
0_nZ_>L2ojVmj0;oZ[gX1?nY_NP2ojRnj@;oZKkY1?nX_^T2ojRnjPKoZ;oZ0onX_n/00ol0003oZ;o[
ojRoj`03ojRoj`;oYko[0_nX_n/=ojO0j`?ooooo00?o0000ooooooooool03_ooool002cooooo00?o
0000ooooooooool0;oooool2ojO0j`;oX;k^0onN^nd4oibhk0;oVKK/0_nF`_D4oi;6n@;oT<km0_nI
h?d3ok3LmP;o]n7d0_nhb>H5okS0h0;o];CI00?oXZ;DoiVGd?nIUm000_nIUm03ohf;c0?oPh?;0_mg
O/d3ogB7e`?oKVRk0_mQKLP01?n7h__o^_Zoom_dgooKm=l3okNoh0?oVY_C0omhN/P3ofa]`P?oK66e
0_mTH;P4ofQbbP04ogFcn?n^n]Co[_[Dom;oc@?oe^kS0_o2cN<2oj:Zg0?oS9;D0on4R<l3oh>6c@Co
RX?60on>Q/H2oiB;aP04oiNIe?nOXMKoWj7FoinQePGoYZKF0on/Z=<00on/_^Oo/[gRok:mhP03ok:m
hP;o]k[K0_nbb>/4okS3h`03okbmf_nhbNOo^<WW00;o^<WW00?o_/?NokS:j?nhb^P00_nhb^P2okg4
g`;o]l[Y0onla>42okO8j0Co^/?Q00?o^[kMokS2h_nh`^800_nh`^82okNng`;o]L7S0ond_N42ok;1
i0Co/KkS0_n_^n<2ojnni@Co[KcU0_n[_>H2ojbmiPCoZ[cW00?oZkkWojZmj?nZ_NP00onZ_NP2ojVm
j0KoZKkY0_nX_^T2ojRoj@SoZ;oZ0onX_n/00ol0003oZ;o[ojRoj`07ojRoj`;oYl3[0_nX`>/9ojO0
j`?ooooo00?o0000ooooooooool03Oooool002gooooo00?o0000ooooooooool0;oooool4oj2nkP?o
W[_]0_nL^>`2oiRolPCoU/;e0_nBa_T3oiWFo@04oiWPoOn`g?Ko/=cfok3LmP;o]/_Z1?nhb>H2okS0
h0;oZJcI1?nRX]@3oiVGd0?oSH_<0on3Pl/3ogMnc@?oM8OG0omhY>h00ol0003ob?oLolSog002olSK
i`Co]koP0_nJVm<3ogQjb0?oK6g20omXKlL2ofAP^0?oJ7;:0on^fOH01?oBolgoe^kSomK^hooFk^<2
ok[8i@CoXZ[L0on<T]@3ohB8c`;oPhK=1?n8R/l3oi2Bd@CoUiWD0onOXMH4ojJVeP03ojbXdon/_^Oo
[;kW00;o[;kW0_nb_N82ojc<l0Go//S[0_nh`n<3ok7?l0;o^<WW0_n_co43okS:j0;o/<o`1?ngb^T0
0onla>7o]lSXokO8j002okO8j0;o^/?Q0_neanL3okS2hP;o]<GW1?ne`N<00ond_N7o//7Tok;1i002
ok;1i0;o/KkS0_n``>H4ojnni@;o[KcU0_n]_^H4ojbmiP03ojZlion[_^OoZkkW00;oZkkW0_nZ_NP2
ojZnj0KoZKkY0_nY_nT5ojRoj@SoZ;oZ0_nX_n/00ol0003oZ;o[ojRoj`05ojRoj`OoZ<3[2?nW`>/3
ooooo`03o`000?oooooooooo00gooooo000^ooooo`03o`000?oooooooooo02oooooo0_nP_^h2oibm
k`CoV[ga0onH_o82oiK2m@?oV/kj0_nIe_d3oj_FmP03ok3Lm_nfbn[o]/_Z00;o]/_Z0_nhb>H2ojne
gPCoZJcI1?nRX]@3oiVGd0?oSH_<0_n3Pl/3ogMnc@CoM8OG00CoN:C^ojKhf?o8omcob?oL1?o8fnL2
okNoh004oiBDdOmoOlWoOgo9ogmob@;oN7[80om/KL83ofQ_a`?oO9;N00GoJ7;:ojkIm_n^fOKo[]Wf
ol[of@02omWlg003om3SiOnjb>Go^/SU00;o^/SU0onRZ]`3ohbBe0?oQ8S?0on3Q/d4ohR:c`?oT9;A
1?nGVM@3oinQeP;oYZKF0_nW_>P3ojbni`;oZ<gc1?n/c?02ok;8j`?oZ=;f0_naco02ojOBmPGo[loa
00?o^<[Xok3?l?n`co000_n`co02okO:j@?o/<c_0_ngb>P00onabngo]LOWokG7i`03okG7i`03okS2
h_ndaNOo]<GW00;o]<GW0_ne`N<00onba>Oo//7Tok;1i002ok;1i003ok32ion``>Ko/<3V00?o/<3V
0_n__^D2ojk0i`Co[KkV0_n/_NH2ojbni`?oZkkW0_n[_nP4ojZnj0;oZKkY1_nY_nT2ojRoj@;oZKoZ
1_nX_nX2ojS0j`?oZ;o[00Co0000ojRojonX_n_oZ;o[2onX`>/8ojO0j`;ooooo00?o0000oooooooo
ool03Oooool002oooooo00?o0000ooooooooool0;oooool4oibmk`;oV[ga0_nL`O84oi_7mP;oV/kj
0onWcoD2oj_FmP?o/lc]0_nfbnX2ok2khPCo[kGN0onY[=T2oj:Re0;oUY[F0on>U=H3oh>Bf@?oOIWT
0omgO/d2ogB7e`03ofCClonQkOSo]ocQ00?ocN_Z0_o8fnL00on/[]WoU9CAoiBDd@02oiBDd@;oOgo9
0omXLLP3ofa]`P?oJ6o71?mlT]h01?n^fOKob_oIomWlg?oIo=`3om3Si@;o^/SU00CoWjWMohjFe_n>
U]KoSYKF0on1RM<01?n<T]CoQ8S?ohB8con4R<l3oh>6c@?oR8[?1?n@T]42oiNIe0;oVk3V0onR^>P4
ojNlj003ojbnionXcO?oZ<gc00;oZ<gc0_n/c?03oj?Dn@;oZ=;f0_nQdoX4ojOBmP;o[loa0onVdOH2
ok3?l0;oZ<kd1?n`c>l00onYc?;o/L_]ok7;k@02ok7;k@;o]LOW0on`b>`2okC5i`;o/<K[1?nba>L0
0onb`NCo/<;Wok32i`02ok32i`;o/<3V0_n_`^P5ojk0i`;o[KkV00?o[L3Xojbnion/_^L00on/_^L0
0on[_^OoZkoXoj^oj002oj^oj0;oZ[kX00?oZ[oYojVojOnY_nT01OnY_nT6ojVojP;oZ;oZ1_nX`>/2
ojRoj`03ojS0jol0003oZ<3[00coZ<3[2?nW`>/2ooooo`03o`000?oooooooooo00gooooo000`oooo
o`;o0000<?ooool2oibmk`;oW[g_1?nL`O82oi_7mP?oYLWb0_nWcoD2ojo:kP?o/lc]0_na_nD4ok2k
hP;o[kGN00CoY:WJoijReonNX]OoWZ;G1?nFV]H4ohjDeP?oPi;I1?mmVN@2og>_m`;oXNgh00Go]ocQ
olg[j_o=jn[ocN_Zokg7hP04ojb^f@?oU9CA0omoOlT2ofQab0?oJGoF0omXKlL2ogbBgP03oioal_o:
omWob_oI00;ofOcL0oo@hnD00oni`n;oWjWMoinYg@02oinYg@?oSYKF0on1RM<3ogn9d`?oQ8oG0on;
VM`4oiBVh@GoVk3V0onR^>P2ojNlj0?oYLcd0_nXcO<3oj7EnP;oXmCi0_nNe?/4oj7CnP;oYm;f0onO
d_T2ojKAmP;oXLoh1?nXc_@00on`c>ooZLcbojW<lP02ojW<lP;o/L_]0_n[b_03ok38k0;o[<S^1?n`
a^/2ok;4i`;o[lGZ0on``^L2ojk4jPCo[l;X0_n^`>L2ojg1j0Co[L3X0_n/_^L3ojc0j0;oZkoX0_n[
`>T4ojZoj@;oZKoY0_nY`>X7ojVojP03ojW0j_nX`>_oZ<3[00WoZ<3[00?o0000ojS0jonX`>/03?nX
`>/8ojO0j`03ooooool0003ooooo00kooooo000booooo`03o`000?oooooooooo02kooooo1?nN_Nl2
oic1lP?oY<?`0_nUbO82ojc7k@Co[l[^00?o/lc]ok6oiOna_nD00_na_nD2ok2khP03ojV`gOnTZM[o
Y:WJ00;oY:WJ0onNX]L4oiJJeP?oSYCF1?n3T]T2ogfIi0?oTm7m00GoXNghol?_l?o3ko3o`no`olg[
jP03okg7hPCo[:kI0_nDU=43ogmob@?oJ7780omYOmH3ohB`lP?o`Noa00God_gNomOahooGlN?oeo7S
om3Si@03okW3hPCoWjWM0_n>U]H4oh69d`?oOhWC0on4SmL3oh^Ig0CoU:KQ0_nK/>H2oj33l@GoXlWc
0_nUc?@3oj;EnP;oXMGj0_nOe_/4oikDn`;oXM?j0onLd_/2oioBn@?oWLoi0onQcoP2ojS>m0?oXlgf
0_nYc?82ojG;l`CoZl[`00?o/<S/ojc8k_n/b>h00_n/b>h2ok36j`;o[LO]1?n_aNX00on``^Oo[/CZ
ojk4jP02ojk4jP;o[l;X0_n]`nX4ojg1j0;o[L3X0_n/`NT3ojc0j0;oZl7Z1?n[`>T2ojZoj@;oZ/3Z
1?nY`>X2ojVojPKoZL3Z2?nX`>/01?nX`N_oZ<3[ojS0jol0000;ojS0j`[oYl3[00?oooooo`000?oo
ool03_ooool003?ooooo00?o0000ooooooooool0;_ooool2oijmk`?oY;o]0_nT`o02oj[3k0Co[<O]
0_n_b^h3ok31i`;o/KoU00?o[;KPojV`gOnY/=d00_nY/=d4ojBYfP?oWZ;G0onFV]H2ohjDeP;oSZ_Y
1On<]o<2oi?Ao@04oj?cl_o3ko3o`no`ol?_l0?o`]OY0onman82ojb^f@04oiBKeomnRMCoOXWDogj9
e0?oOgo90_mXLLP4ofUoeP05ohB`l_o1ko7o`Noaol7_lOoBoMh00ooGlN<3ol_Ki@?o^L?R0_nOZMd0
1?n>W=coPi;Ioh>BfOn3T]T3oh69d`CoOhWC0on4SmL3oh^Ig0;oU:KQ0_nK^^h4oj33l@;oXlWc0onS
e?T2oj;EnP?oXMKj0_nOe_/2oioCnPKoW=;k0onLcoT2oig?n@;oW<ch1?nNc?L2oj?=mP;oXL[e1OnU
bo<2oj_:l0?oYlWa0_n/b>h00onYao3o[LO]ojg7k@03ojg7k@;o[lGZ0on/aN`2ojk4jP03ojc4k?n]
`n[o[L?Z00?o[L?Z0_n]`NP00on/`^[o[<7Yojc1j@03ojc1j@03ojc0j?n[`N[oZl7Z00;oZl7Z0_n[
`>T00onZ`N[oZ/3Zoj[0jP03oj[0jP;oZL3Z0_nY`N/6ojW0jP;oZL7[1OnX`>/4ojS1j`;oZ<3[00?o
0000ojS1jonX`>/01onX`>/<ojO0j`03o`000?oooooooooo00gooooo000dooooo`03o`000?oooooo
oooo02kooooo0onT_nd2ojW0jPCoZ/?/0_n/and2ojo2j0?o/<7W00?o[K[Sojbfh?n/]^000_n/]^04
ojV`g@;oY:WJ00?oWJ_QoiRXhOnHZ>400_nHZ>43oi6Vi0CoSZ_Y0_n<]o<3oi_Ro@;o^N[e00?o`no`
ol;GjOo2enT00_o2enT01?na_N;oYJgMojF]gOnU[Md4oiBKe`;oOXWD0omgQ]H3ogRBh0;oJGoF0onD
__@01Oo1ko7o]o7dolgbj_o=l^[oeo7S00?obm_U00?o]lCUojB_h?nT[n000_nT[n03ohjLg0;oPi;I
0omnSmX4oh:Eg@?oRZ7S1?nB[^T4oi^jkP;oX<?a0onSdOP2oj?Dn@?oY=Ki0_nQe_X3oj;Dn@?oWm?j
0_nLd_/3oig?n@;oW<oi0_nMc?P4oic<n0;oW/cg0onNbOH3oj7:m@;oYL_c0onSbO<2ojO9l@;oYLSb
1?nYao02ojg7k@?oZ/K^0_n/aN`2oj[5k@Co[<C/0_n]`nX2oj_3j`Co[<;Z0_n/`NT3oj_2jP;oZl7Z
0_nZ`^/4oj[1jP;oZ/3Z1onY`N/2ojW0jPKoZL7[0_nX`>/9ojS1j`05o`000?nX`N_oZ<3[ojS0jonX
`N/01OnX`>/:ojO0j`03ooooool0003ooooo00kooooo000eooooo`;o0000;oooool00onT_ngoZL3Z
ojW0jP02ojW0jP;oZ/?/0_n^`^T4ojo2j004ok31ion]^^?o[K[Sojfjh`Co[;KP0_nY/=d2oj:_h@?o
WJ_Q1?nHZ>43oi6Vi0;oSZ_Y0onFc_/01?nKh_go^N[eokWZmOnij_D3ol7Pk`03ol;GjOna_N;o/KgR
00;o/KgR0onU[Md3oiBKe`?oOXWD0omgQ]H4ogRBh0;oU;kd0_nglO@2olgbjP?ocnSX00Cobm_UokO4
iOnga>Go]lCU1?nT[n02ohjLg0?oPi;I0omnSmX4oh:Eg@?oRZ7S1?nB[^T2oi^jkP?oXL_f0_nSdOP3
ojKEn0;oY=Ki0onUeOP2oj;Dn@03ojCAmonPd?SoX=3h00?oX=3h0_nMcoT3oio<m`?oWLch0_nLc?P3
oig9mP;oW/Wf0_nNao@4oj38m0;oXlWc0_nRao<4ojG8lP;oZLO`0onVao02oj[6kP;oZ<K_1?nZaNd2
ojc4k0;oZ/C]1?n[`n/2ojc2jP?oZl?[0_n[`^X6oj[2j`;oZ/7Z0_nY`^/>ojW1j`GoZ<7[0_nX`N`6
ojS1j`03o`000?nX`NcoZ<7[00?oZ<7[0_nX`>/8ojO0j`Kooooo00?o0000ooooooooool03?ooool0
03Oooooo00?o0000ooooooooool0;_ooool2ojW0jP;o[<7Y1?n^`^T2ojo2j0;o[KgU1?n]^^<2ojbf
h0;oY[CS1?nR[n43oif[h@;oV:SQ0_nG]nh4oi>nm0;oU/kk0_n/goT3okOPm0;o`N3_0_nhbNL4ok6m
hP?oYJgM1?nDVmL3ogj9e0?oMhKF0_mhT^03oi[9n003okOam?o=l^[ocO;Z00?ocnSX00?oa=GWokO4
iOnga>D00_nga>D2ojB_h0;oUZ?N0on6Umd3oh>Bf@?oOXoJ0on2UMd4ohZQh`;oTZkY0_nK`O82oj7;
mP?oY];g0_nVeOP3ojSFm`;oYMGh0_nWd_H4ojCAm`;oX=3h0onRc?H2oio<m`;oXLWd1?nOb?D2oig9
mP;oWlKd1OnNao@2oj38m003oj36lonRao?oX/Oc00?oX/Oc0_nUb?83ojC6l@;oY/O`00?oYLG`ojS6
konXa^l00onXa^l2oj[5k@03ojS5k_nZa>goZ/C]00?oZ/C]0_n[`n/3oj[3k0;oZl?[00?oZL?/oj[2
jonZ`^/01OnZ`^/00onY`^coZL;[ojW2j`03ojW2j`;oZL7[0_nY`^/6ojW1j`?oZ<7/0_nX`N/6ojS1
k0;oZ<7[1?nX`N`01?l0003oZ<7/ojS1jonX`N/2ojO1k0KoYl3[2Oooool00ol0003oooooooooo`0<
ooooo`00>?ooool00ol0003oooooooooo`0^ooooo`Co[<7Y0_n^`^T2ojfoi`Co[KgU0_n]^^<2ojRh
i0CoY[CS0_nR[n400onN]>SoV[CZoiZdjP02oiZdjPCoUkO^0_nC__@3oj?Bn004ojcOnOngh?Co]n3d
okOPm0;o^=3/1?nhbNL2ok6mhP04oj:[gOnDW][oU9kJoiBNfPCoRIGI0omjTMh4oh6TjP?oV/Wh0_nm
iO82ol[[k003oloXj?o4eNOoa=GW00;oa=GW0_nga>D2ojFbhPCoUZ?N0on6Umd3oh6FgP?oPY_R0on8
Y^P4oi>dkP;oVl7b0_nRboD3ojKBm`;oZMCg0onXe_L2ojWCmPCoYm;f0_nTdOL3ojG=m@;oX/cf0_nS
bO<4oj79m0;oWlSe0onPa_<3oio6m0;oW/Od0onPaO<3oj36l`;oX/Oc0onRaO82ojC6l@;oXlGa1?nU
aO02ojS6k`;oY/G_1?nXaNh2oj[4k@?oZ<C]0_nZ`n`2ojW4k@CoZL?/0_nZ`^/2ojW3k0CoZL;/0_nY
`^/2ojW2k0GoZL;[0_nY`N/2ojW2k0;oZ<7/0_nX`^`>ojS1k003ojO1k?l0003oYl7/00CoYl7/0_nW
`>/<ooooo`03o`000?oooooooooo00cooooo000iooooo`03o`000?oooooooooo02kooooo0_n/`NT2
ojg1j@Co[KoW0_n]_ND2ojZkiPCoZ;ST0_nV]><2oj6fi`?oW[CX1?nJ]>X2oiNgkP?oWlSe0_nSd_P3
ojoKmP03okOPm?nhd>co^=3/00;o^=3/0_nhbNL2ojbgh@?oXZ_M0onDW]X4ohVEf@?oNY7N1?n1Y>X0
0onJbOSo_NGbol[[k002ol[[k0?obMoY0_o4eNL2okK3i0CoYK;R0onFXmh4ohJGg@?oPIKN0on2Vn83
ohRVj0;oTkC^0_nL`_84oj;;m@03ojKBmonYe?OoZMCg00;oZMCg00?oZ=KgojWCm_nYdoH00_nYdoH2
ojOBmP?oZ<kd0_nUcOD2ojK:l`CoXlWc0_nQbO@3oj;6lP;oX<Kc0_nRa?44oj35lP;oX<Gc0_nQa?44
oj75lP;oX/Gb0_nRa?44oj?5l@;oYLG`0_nUa?04ojK5k`;oZ<G^0onWa>h2ojS4k@;oZ<C^1?nYa>d2
ojW3k0;oZ<?]1?nY`n`2ojW2k0;oZL?/1?nY`^`2ojW2j`GoZL;/1_nX`^`2ojS1k0;oZ<;/1_nX`N`5
ojO1k003o`000?nW`NcoYl7/013ooooo00?o0000ooooooooool03?ooool003[ooooo0_l0000_oooo
o`Co[L7Y0_n]_nL2oj^nj0CoZ[_V0_nX^>@2ojBhi`CoXKKW0onN]>P2oiZdjP?oWL7b0_nOb?D3ojSD
m`;o[m_f0oned^l2okS@k0;o/;oU1?n/]n43oj:[g@?oU9kJ0on9UMT2ogZAgP;oS:k]0onObOH3okGP
m@04ol[[k?o9gnWobMoYolWOj@;o`=7W1?nf`n@2ojFbhP04oiVZh_n>XN7oSZ7QohjQh@CoQIcR0on5
X>D4oh^YjPCoTkK_0onL`_82oj;;m@?oYm7f0_nYe?L3oj_Cm@;oZM?f0onZd?<2ojS>m0;oZ<_b1?nV
b_<2oj?9l`?oY<Oa0_nRa_800onSa?7oX/Caoj;4l@03oj;4l@;oX<Gb00?oX/?aoj74lOnQa?400onQ
a?42oj75lP03oj;3lOnRa?7oX/Ca00?oX/Ca0_nSaO42oj?4l0CoYLC`0_nVaNl3ojK4k`;oYlC^00?o
Y/C^ojS4k_nXa>h00onXa>h2ojW4k@KoZ<?]0_nY`n`00onX`ngoZL?/ojW3k003ojW3k0;oZL;/0onX
`n`2ojW2k0koZ<;/0_nX`N`8ojO1k003o`000?oooooooooo013ooooo00?o0000ooooooooool03?oo
ool003cooooo00?o0000ooooooooool0;Oooool2ojg1j@;oZl7Z1?n[_^P2ojZkiP;oY[_X1?nT^>L2
oj6fi`;oX;c]1?nN_^l2oig1lP?oY<ge0_nXe?L3ok3Al@;o]M;_0_nca^T4ok2oi@;o[;OQ00?oXJkQ
oiRWh?nHYn000_nHYn03ohjQh@?oRZ?U1?n<[^d01?nObOKo]N3eokGPmOneh?D3ol3Ok`03olWOjOo0
dNOo`=7W00;o`=7W0_nf`n@2ojRgi0?oVJ[R0on>XN44ohFLhP?oQJ3U1?n;ZNX2oi>fk`03oic2lonS
boCoXl_d00?oXl_d0_nWdOH3oj_Am0;oZm?e0_n/d?<2oj[@l`?oZlca0_nXbo82ojS8l0CoY/Oa0_nT
ao42ojG5l0CoXlCa0_nRa?42oj?3l0CoX/?a0_nQa?42oj;3l0CoX/?a0_nRa?43oj?3l0CoXlC`0_nU
a?02ojG4k`;oY/C_0_nU`nl4ojK4kP;oZ<C^0_nW`nh<ojS3k@;oZL?/0onX`nd2ojS3k0;oZ<?]1_nX
`^`2ojS2k@KoZ<;/0_nW`^`6ojO1k0Gooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0<ooooo`00?Oooool00ol0003oooooooooo`0]ooooo`CoZl7Z0_n[_^P2ojNnj@CoY[_X0_nT^>L2
oj:lk0CoX;c]0_nN_^l3oj;7l`;oY<ge0_n/cO83ok3Al@;o/LW/1?nca^T2ok2oi@;oYkKS0onQ[^44
oiRWh0?oSZ7Q0on:XnD2ohb^k@?oX/_e00Co]N3eol3Okoo0gnoo`=o_0onof>`2ol3Ai`;o]<CV1?nX
]n@3oiVZhP?oSZ7Q0on5W>83ohFPi@;oRjWZ0_nD]nl4oic2l`;oXl_d0onXc_@2oj_Am0Go[=3c0_n/
cO43oj_<l@;oZ/W`1?nXb?02ojK7l@;oYlG_1?nUaO02oj?4l@?oY<?_0onS`o02oj;3l@?oXl;_0onR
`o02oj;3l@GoXl?`0_nS`nl4ojC3k`;oYLC_1_nU`nl2ojK4kP;oY/?^1?nW`nh2ojS3k@?oYl?^4?nX
`nd2ojS2k0;oZ<?]1?nX`^d2ojS2k0?oYl;]0onW`^`2ojO1k0Wooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0<ooooo`00?_ooool00ol0003oooooooooo`0]ooooo`;oZl7Z0onX`>/3
ojNnj@;oY[_X0_nS_N`4oj:lk0;oX;c]0onQ`o42oj;7l`;oZ<[a1?n/cO800on`dO7o/LW/ok79k002
ok79k0;o/lKY0_n/_>D4ojNfh`?oXJkQ0_nHYn000onFZ^GoT:cYoi2/j@02oi2/j@CoUKS`0_nRboD3
okCGlP04ol3Okonof>co_mS/okoHk0;o^LgY1?nda>H2ojRgi003oin`honCYn?oTjOS00;oTjOS0on<
Xn@3ohVUi`CoS:c[0onD]nl2oic2l`?oXlSc0_nXc_@3oj_?l`;o[=3c0_n]c_44ojc=l@03oj_<lOnZ
bO3oZ/W`00;oZ/W`0_nXb?02ojS6k`CoYlG_0_nUaO03ojK3k`;oY<?_00?oYL;^ojC2konT`^l00onT
`^l2oj?2k`03ojC2k_nS`^ooXl;_00?oXl;_0_nS`o02ojC2k`CoXl?_0_nT`nl2ojC2k`KoYL?_0_nU
`nh4ojK3kPSoYl?^1OnW`nd2ojS3k@03ojO3kOnX`ngoZ<?]00_oZ<?]0_nX`^d4ojO2kA3ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`00?oooool2o`0002oooooo0_nX`>/2
ojFok0CoY;k/0onS_N`2oj:lk0?oX/7_0_nQ`o42ojK6l@CoZ<[a0_n/cO83ojo:kP;o/LW/0_n]`>P4
ojbli@;oYkKS00?oXK3Soi^/honK[><00_nK[><3oiJZi@CoT:cY0_nE^?03ojG9l`;o]=Ob0onkfNl0
0onof>co^LgYokW=j@02okW=j@;o]<CV00?oZK[Uoin`honO/><00_nO/><4oi>Wh`?oS:?T0on9YNL2
ohb/j`;oU;O_1?nL`?42oj?8l`;oYlcc0on[co<2ojc>l@Co[Lka0_n/cO43ojc;l0;oZ/W`00?oZ/O_
ojS6konXa^l00onXa^l2ojO5k`;oYlC^0_nV`nl2ojK2kPCoYL;^0_nT`^l2ojG2kPCoY<;^0_nS`^l2
ojC2kPGoY<;_0_nS`nl00onT`^koY<;_ojC2k`03ojC2k`;oYL?_00?oYL;^ojG3k_nU`nh00onU`nh4
ojK3kPSoYl?^0_nW`nd2ojO3kPCoYl?]0_nX`nd2ojO3k@KoZ<?]0onW`nd2ojO2kACooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`00@Oooool00ol0003oooooooooo`0]oooo
o`CoYKo/0_nT_^`2oj>ok@CoXl3^0_nR`Nl2ojG4k`CoY/Ka0_nXb_43oj_8k`;o[l[^0_n^`nT4ojg0
j0;o[;cU0_nV]N@3oj6`h`CoVjcS0onFZ^D2oi2/j@?oVkg_0_nUbO<3ojoClP;o^mW_0onjd^`2okW=
j@03ok73ionY^^GoZK[U00;oZK[U1?nO/><2oi>Wh`03oi6Yi_n?Z^SoSj[X00;oSj[X0on?[^/4oiBg
k`;oW<3a0_nRa_84ojO<l`03oj_?lon/c_7o[<ka00;o[<ka0_n]c_43ojg<l0;o[<_`00?oZlS_oj[7
konZanl00_nZanl2ojS6k`?oZ<C^0_nWa>h2ojO3k@CoY/;^0_nU`^h2ojG2k@CoYL;^0_nT`^h2ojG1
kPCoY<;^0_nT`^l6ojC2kP;oY<;_1_nU`^h2ojG3kPOoY/?^3?nW`nh8ojO3k@;oZ<?]1OnW`ndHoooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool004;ooooo00?o0000oooooooo
ool0;Oooool2ojFok0;oY;o]1?nS_nd2oj?0kP;oY<;^1?nUa>l2ojK6l@?oZLO_0_n[b>l2ojc4j`Co
[/?Y0_n]`>P2ojVii@CoY[GT0onQ/><2oi^/h`;oV[;X1?nJ]^/2oi^mk`;oY/Wb0on_do82okCAk`;o
^];/0_neb^T4ok73i`;oZK[U0_nR]>H3oiZ^i@CoTJWV1?n?Z^P3ohn^j`;oU;O_0_nK_o44oj;6lP;o
Ylcc0onZc?82ojc>l@Co[Lc`0_n/bNl4oj_8k`;oZ/O_0onYaNh2ojS4kP;oZ<?]1?nW`nd2ojK2kP;o
Y/;]1?nU`^d2ojG2kP;oYL7]1?nU`Nh2ojC2kP?oYL7^1OnT`^h;ojG2kP;oY/?^00?oY/;^ojK3k_nV
`nh00onV`nh<ojO3kP[oYl?]7Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_o
oooo0013ooooo`03o`000?oooooooooo02gooooo1?nT_nd2oj>ok@;oY<3]1?nT`^h2ojG4k`?oYlG^
0_nYanl2oj_4k0Co[<C[0_n^`nT2oj^mi`CoZKWU0_nV]N@2oj:eiP?oW[?V1?nJ/^P2oiZfj`03oj31
l?nVbO;oY/Wb00?oY/Wb00?o[m?bokCAkonddNl00_ndcNd4okG:j@;o/L?W0_nZ_>H4oj:diP?oVZkU
0_nAZNH2oi>^j@?oTk7[1?nF]nh4oi^ol@;oX/Kb0_nVbO42oj[<lP?oZl_`0_n]c?02ojc:k`Co[<W_
0_n[b>l3oj_6kP;oZLG^0_nYa>d4ojS3k@;oYl?]0_nW`^d4ojK2k@;oYL;]0onV`Nd3ojG1k@;oYL7^
0onU`Nd2ojG1kPGoYL7]0_nU`^h2ojG1k@KoYL;^1_nV`^h2ojK3kP;oY/;^4OnW`nh2ojO3kB3ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`00A?ooool00ol0003ooooooooo
o`0]ooooo`;oY;o]0_nU_n`4ojC0k@;oY<;^0onV`nh2ojO5kP;oZL?/1?n[a>`2ojc4j`;oZkoX1?n[
_NL2ojVii@;oYKSV1?nR]NH3oijciP;oV[;X00?oWK_]oj31l?nP`O000_nP`O02ojK9lP?o[/g`00?o
]=7_okC=kOndcNd00_ndcNd2okG:j@;o[l;X1?nZ_>H2oj:diP;oWK;V0onH[nL4oi>^j@?oTk7[0_nF
]nh2oibmk`CoXL?a0_nVbO43ojW9l@;oZl_`1_n/b^l2ojc9k`?o[<O^0_n[a^h2oj[5k@CoZLC]0_nX
`nd2ojS2k@CoYl;]0_nV`^d2ojO1k@;oY/7]0_nV`N`4ojK1k@;oYL7]0_nV`Nd<ojG1k@;oYL;^0_nV
`^d6ojK2kP;oY/;]1?nV`^h?ojO3kRCooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0;ooooo`00AOooool2o`0002oooooo0onU_n`2ojC0k@?oY/7]0_nV`nh2ojS2k0CoZL?/0_n[a>`2
oj_0j@CoZkoX0_n[_NL00onW^^OoYKSVojFhiP03ojFhiP;oX[GV00?oX;OYoinhj_nO^>X00_nO^>X3
oifkk@;oX<7`0onWb?02ojk=l0?o/Lg^0_ndcNd2ok77jPCo[l;X0_nZ_>H2ojBgiPCoWK;V0onH[nL2
oi>^j@;oUk?[0onH^>h4oibmk`;oXL?a0onUa_42ojW9l@;oZ/W`1_n/b^l3ojc8kP;o[<O^00?oZlK]
oj[5kOnZaNd00onZaNd2ojW4k@;oZL?/0_nX`^d2ojS2k0CoYl7/0_nW`Nd2ojO1k0CoY/7/0_nV`Nd2
ojK1k0CoY/7]0_nU`Nd2ojK1k@KoYL7]0_nV`Nd4ojK2k@;oY/;^1_nV`^d2ojK2kP?oY/;]0_nW`nh0
0onW`ngoYl?^ojO3kP04ojO3kRWooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;
ooooo`00Aoooool00ol0003oooooooooo`0]ooooo`CoY[o/0_nV`Nd2ojS1k0CoZ<;/0_nY`n`2oj[1
jPCoZl3Y0_n[_nP00onX_>SoYk[WojNji`02ojNji`;oYKSV0_nS^>P4oj2gj@;oWkSZ0_nR_^d4oj?2
k`;oYlS`0on/bo02ok7=kP;o/<W/1?naanX2ojo2j0;oZKgW1?nT]nH2oifbiP;oW;?X0onH/^T4oiNc
j`?oV;S^0_nL_Nl3oj72l0;oYLKa0_nWao04oj[9l0;o[<[_0_n/b>l2ojc8kPKoZlK]0_nZaNd3ojW4
k@;oZL?/1_nX`^`8ojO1k0SoY/7/0_nV`Nd2ojK1k0CoY/7]0_nU`Nd6ojK1k@;oY/;]0_nV`Nd:ojK2
k@;oYl;]1?nW`nd2ojO3kRcooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;oooo
o`00B?ooool00ol0003oooooooooo`0]ooooo`;oY[o/0_nW`>/4ojS1k0;oZ<;/0_nY`N/4oj[1jP;o
Zl3Y00?oZKkXojRlj?nX_>P00_nX_>P2ojNji`;oYKWX1?nS^>P2oj2gj@;oX[c/1?nR_^d2oj?2k`;o
Z<O`0on/bo02ojk9kPCo/<W/0_naanX3ojg1j@?oZKgW0_nT]nH2oj6fi`CoW;?X0onH/^T2oiNcj`;o
V[S]1?nM_Nl2oj72l003ojC4l?nWao3oYlO`00?oYlO`0_nZbO02oj_8k`;o[<S_0_n[anh6oj_6k@?o
Z/C]0_nYa>d2ojW3k0KoZ<;/0_nX`N`7ojO1k0OoY/7/0_nV`>`4ojK1k0;oY/7]0_nV`N`2ojK1k@;o
Y/7/2?nV`Nd6ojK2k@KoYl;]0_nW`nd`ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02oooool004Wooooo00?o0000ooooooooool0;Oooool4ojO0j`;oZ<7/1_nY`N/2oj[1jP?oZKoY
0_nY_^P2ojRlj0;oY[_X1?nU^NP2oj>hj0;oXk_[1?nR_>`2oj:nk@;oYL?_1?nXao000on/bo3o[/W^
ojk9kP02ojk9kP;o/<W/0on^aN/2ojg1j@03ojVmj?nU^^SoYK[X00;oYK[X1?nQ]^L2oibcj004oibe
jOnJ]^_oV[K[oiZfj`GoV[S]0_nM_Nl00onQ`>ooY<C`ojC4l002ojC4l0;oYlO`0onYanl2oj_8k`Ko
ZlO^0_n[a^d3oj_5k@;oZ/C]0_nZ`n`4ojW3k0?oZ<;/1OnX`N`7ojO1k0;oY/7/0onW`>`2ojK0k0;o
Yl3/1?nV`>`8ojK1k0;oY/7]0_nW`N`4ojK1k@;oY/;]2?nW`^ddooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool004[ooooo0_l0000^ooooo`;oYl3[0_nX`>/6ojW1j`?oZKoZ
0_nY_nT00onX_^WoZ;cXojRlj002ojRlj0?oY[_X0_nU^NP2ojBkjPCoXk_[0_nR_>`3ojC1kP?oYL?_
0_nXao03oj_7kP;o[/W^0on]a^`2ojk5j`03oj_1jOnY_NSoZKgX00;oZKgX1?nU^^P2oj6fi`03oinf
j?nL]NWoW;GY00;oW;GY0onJ]^/2oiZhk@;oW[c^1?nQ`>l2ojC4l0?oYlG_0_nYanl2oj[7k`KoZlO^
0on[a^d2oj_5k@03oj[4kOnZ`ncoZ/?/00?oZ/?/0_nY`n`00onY`^coZ<;/ojS2k002ojS2k0GoZ<7/
1OnW`N`;ojO0k0;oY/3/00?oYl3/ojK1k?nV`N`01OnV`N`6ojO1k0;oY/7]00?oYl7]ojO2kOnW`^d0
1?nW`^diooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool004cooooo00?o
0000ooooooooool0;?ooool4ojS0j`;oZL7[0onY`>X2ojVojP03ojRojOnX_^WoZ;kY00;oZ;kY0_nX
_>P2ojJmj@CoYKcY0onT^nX2oj>kj`?oY;o]0_nT`Nh2ojK3kPCoZ<G^0_n[anh3ojc6k@;o[LK/00?o
[<?[oj_1jOn[`NT00_n[`NT2ojVmj0;oY[_X0onS^>P4oinfj0;oW;GY0_nM^>/4oifik0?oW[c^0_nQ
`>l3ojC3k`;oYlG_0_nXa^l4oj[7k`;oZlO^0on[a^h2oj_6k@03oj[5kOnZa>goZ/C]00;oZ/C]0_nZ
`n`2ojW3k0CoZL;/0_nX`^`7ojS1k0CoYl7/3onW`>`2ojK1k0_oYl7/0onW`Nd2ojO2kCcooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00COooool00ol0003oooooooooo`0/
ooooo`;oZ<3[0onY`>/2ojW0jP03ojVoj_nX_nWoZ;oY00;oZ;oY0_nX_^T2ojNnjPCoY[gY0_nU_>T2
ojFnj`CoY;k/0_nT_nd2ojG2k@CoY/?^0_nXaNh3oj[6kP;o[<K]00?o[<C/ojc3jon/`n/00_n/`n/2
oj_1j@;oZ;gY1?nV^nP3oj>hj0;oWkKX0_nO^>X4oifhj`;oWKW/0_nP_Nd4oj6okP;oY<?_0_nVa>l4
ojS6k`;oZ/O_0_nZa^h2oj_6kPKoZ/G]0_nZa>d6ojW3k0;oZL;/0onX`^`8ojS1k0;oYl7/4OnW`>`;
ojO1k4?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`00C_ooool00ol0
003oooooooooo`0]ooooo`;oZL3[00?oZ<3[ojVoj_nY_nX00_nY_nX2ojRoj@KoYkkZ0_nV_NT6ojFn
j`;oY;k/0_nU`>d4ojG2k@;oY/?^0onXa>h2oj[6kP03oj[4k?n/a>co[<C/00;o[<C/0_n/`n/2ojW0
jPCoZ;gY0_nV^nP2ojBjj@CoXKSY0onO^>X2oifhj`;oWk_/1?nP_Nd2oj6okP;oY<7^1?nVa>l2ojS6
k`;oZLG^0_nZa^h8oj[5k@?oZ/C/1OnY`n`3ojW2k0;oZ<;/2?nX`N`00onW`NcoYl3/ojO0k00BojO0
k0OoYl7/Aoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo001?ooooo`;o
0000;_ooool3ojS0j`;oZKoZ0_nX_n/6ojNnjP;oY[k[1_nU_^/2ojFok0CoYL3]0_nU`^d3ojO3kP;o
Z<C^00?oZLC]oj[4k?nZa>`00_nZa>`2ojc4k0;oZ/7[1?nY`>X2ojRmj@;oY[cY1?nT^^T2oj6hj@;o
XKWZ1?nP^^/3oinkk0;oX;g]0_nR_nh4ojC1kP;oY/C_0_nWa>h4ojW5kPKoZ/G]0onZa>d2oj[4k0Ko
ZL?/0_nY`^`00onX`^coZ<7/ojS1k006ojS1k0CoYl7/0_nW`>`3ojO0j`ooYl3/0_nW`Na<ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool0057ooooo00?o0000ooooooooool0
;?ooool3ojS0j`CoZ;o[0_nW_^X2ojNoj`CoY[k[0_nU_^/6ojFok0;oYL3]0onV`^d2ojO3kP03ojS3
kOnYa>goZLC]00;oZLC]0_nZa>`2oj[2j`CoZ/7[0_nY`>X2ojRnj@CoY[cY0_nT^^T2oj>jj@CoXKWZ
0_nP^^/00onQ_>coXKg]oj6mk@02oj6mk@CoX[o^0_nT`Nh2ojG3kP;oYlC^0_nXa>h4ojW5kPGoZ/G]
0_nZa>d00onYa>goZL?/ojW3k004ojW3k0;oZL;/1?nX`^`8ojS1k0;oYl7/2_nW`>/:ojO0k4oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`00D_ooool00ol0003ooooooooo
o`0[ooooo`CoZ<3[0_nX_n/6ojNoj`;oY[k[0onV_n`5ojFok0?oY/7]0_nV`^d00onW`^goZ<?]ojS3
k@02ojS3k@;oZLC]0_nY`n`4oj[2j`;oZ/7[0onY_nX3ojRnj@;oY[cY0_nU^nT4oj>jj@;oXKWZ00?o
X[_[oj6lk?nQ_>`00_nQ_>`2oj6mk@;oXko]1?nT`Nh2ojG3kP;oYl?^1?nXa>h2ojW5kP?oZLG]0_nZ
aNd5ojW4k@;oZL?/1_nY`^`2ojS2k0SoZ<7/0onX`N/;ojO0j`KoYl3/Doooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00[ooooo001Cooooo`03o`000?oooooooooo02_ooooo0_nX`>/3
ojO0j`;oYko[2?nV_n`6ojK0k0;oY/7]1OnW`^d2ojS3k@KoZL?/0_nZ`^/3ojW0j`;oZKoZ0_nW_^X4
ojJlj@?oYK_Y0_nS^^T00onS^n[oX[_[oj:kj`02oj:kj`;oXKc/0_nR_^d4oj>ok@;oY<7^0_nU`^h4
ojO3kPGoZ<C^0_nYaNd7ojW4k@;oZL?/1_nY`^`3ojS2k0OoZ<7/0_nX`N/>ojO0j`;oYl3/Eoooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo001Dooooo`;o0000;Oooool2ojO0
j`SoY[o/2?nV`>`00onV`NgoYl;]ojO2k@04ojO2k@?oZ<;/1OnY`n`3ojW1j`;oZL3[0_nX_nX4ojNn
jP;oY[cY00?oYKcZojBlj_nT_>X00_nT_>X3oj>kjP;oX[_[0_nR_N`4oj:nk@;oXko]0onT`Nd3ojG2
kP;oYl?^0_nWa>h2ojS4kP;oZ<C]1_nYa>d2ojW3k@CoZL?/0_nY`^`5ojS2k0WoZ<7/3_nW`>]Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool005Kooooo00?o0000oooooooo
ool0:oooool8ojJok0KoY/3/0_nV`N`3ojK1k@;oYl;]0onW`^`2ojS2k0;oZ<7/1_nY`N/2ojS0j`Co
Z;oZ0_nW_^X00onV_N[oYKcZojFljP02ojFljP;oY;cZ0_nT_>/4oj>lj`?oX[g/0_nR_^d3ojBok@;o
Y<7]00?oYL;^ojK3k_nV`nh00_nV`nh2ojO4kP;oZ<C^1?nXa>d5ojW4k@?oZL?]0_nY`n`3ojW2k0?o
Z<;/3?nX`N`2ojO0j`?oYl3/1OnW`>]Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02Oooool005Oooooo00?o0000ooooooooool0:oooool8ojJok0GoY/3/0onV`N`01?nV`NgoYl7/
ojO1k?nW`N`2ojO2k0KoZ<7/0_nY`N/6ojS0j`;oZ;oZ00?oYkkZojJmj_nV_NX00_nV_NX2ojFljP;o
YKgZ1?nT_>/2oj>lj`;oY;k/1?nS_^`2ojBok@03ojG1kOnU`^koYL;^00;oYL;^0_nV`nh2ojO3kPCo
Z<C^1OnXa>d2ojW4k@03ojS3kOnY`ngoZL?]00;oZL?]0_nY`^`6ojS2k0[oZ<7/0_nW`N`2ojO0k6Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`00F?ooool00ol0003ooooo
ooooo`0/ooooo`GoY[o/1OnV`>`00onW`>coYl7/ojO1k006ojO1k0KoZ<7/0_nX`N/6ojS0j`03ojNo
j_nW_^[oYkkZ00;oYkkZ1?nV_NX4ojFmjP;oY;c[0_nT_N/4ojBnk0;oXkk/00?oY<3]ojG1kOnU`Nd0
0_nU`Nd2ojG2kP;oY/;^1?nW`nh2ojS4kPGoZ<C]1OnX`nd2ojW3k@SoZ<;/2?nX`N`4ojO1k6[ooooo
00Go0000ooooooooooooooooo`00000;ooooo`00FOooool00ol0003oooooooooo`0/ooooo`CoY[o/
0onV`>`4ojO0k0SoYl7/0_nX`N`6ojS1j`;oZ<3[0_nX_n/3ojNojP;oYkkZ0onV_^X3ojJmjP;oYKgZ
0onU_N/3ojBmj`;oY;k/0_nT_n`3ojC0k@;oYL7]0onU`^d3ojK2kPGoYl?^0_nXa>d:ojS3k@SoZ<;/
0_nX`N`7ojO1k6gooooo00Go0000ooooooooooooooooo`00000;ooooo`00F_ooool2o`0002gooooo
0_nV_n`2ojO0k0?oY/3/1?nW`>`6ojO1k0?oZ<7/1OnX`N/2ojS0j`;oZ;o[0_nW_n/4ojNnjP;oY[kZ
0_nV_^/6ojFmj`03ojFnk?nT_^coY;k/00;oY;k/0_nT_n`2ojG0k@CoYL7]0_nU`^d2ojK2kPKoYl?^
00?oYl?]ojS3kOnX`nd02onX`nd6ojS2k003ojO2k?nW`NcoYl7/00CoYl7/LOooool01?l0003ooooo
ooooool0000;ooooo`00G?ooool00ol0003oooooooooo`0[ooooo`CoYl3/00?oY/3/ojO0k?nW`>`0
1?nW`>`5ojO1k0;oZ<7/1onX`>/6ojNoj`;oYkkZ1_nV_^/2ojFmj`03ojFnjonU_^coYKk/00;oYKk/
0_nT_^`2ojFok0CoYL3]0_nU`Nd2ojK2k@CoY/;^0onW`nh4ojO3k@goZ<?]0_nX`^`00onW`^goYl;/
ojO2k002ojO2k0;oYl7/MOooool00ol0003oooooo`00000;ooooo`00GOooool00ol0003ooooooooo
o`0[ooooo`;oYl3/0_nW`>/2ojO0k0KoYl3[0_nW`N`8ojS0j`03ojRojonW_n_oYko[00KoYko[1onV
_^/4ojFnj`;oYKk/1_nU_n`2ojG0k@;oYL7]1?nV`^d2ojK2kP;oY/?^0onW`nh5ojO3k@[oZ<?]1OnW
`^d2ojO2k7Sooooo00Co0000oooooooooooo00002_ooool005kooooo00?o0000ooooooooool0:ooo
ool<ojO0j`OoZ<3[1?nX_n/8ojNoj`OoY[k[0_nU_^/8ojFok0KoYL7]1?nV`^d2ojK3kPKoYl?^0onW
`nd6ojS3k@?oYl?]1OnW`^elooooo`03o`000?oooooo000000[ooooo001Oooooo`;o0000;?ooool<
ojO0j`OoZ<3[0_nX_n/7ojNoj`CoY[o[00?oY[k[ojJojonV_n/01?nV_n`2ojFok0KoYL3/0_nU`Nd0
0onV`NgoY/;]ojK2k@04ojK2k@;oY/?^2?nW`nh3ojO3k@;oZ<?]1OnW`nf3ooooo`;o00002_ooool0
067ooooo00?o0000ooooooooool0:_ooool:ojO0j`CoZ<3[0_nW`>/<ojNoj`OoY[o[1?nV_n`6ojG0
k0GoY/7]1?nV`^d4ojK3kPSoYl?^1_nW`nf5ooooo`?o00002_ooool006;ooooo00?o0000oooooooo
ool0:oooool8ojO0j`03ojS0jonW`>_oYl3[00CoYl3[2onW_n/6ojJoj`KoY[o/0_nU`>`7ojK1k@Ko
Y/;]0_nV`nh:ojO3kP;oYl?]Q?ooool4o`0000gooooo001Sooooo`03o`000?oooooooooo02_ooooo
3OnW`>/=ojNoj`;oY[o[2?nV_n`2ojK0k0SoY/7]1?nV`^d4ojO2k@WoYl?^Poooool4o`00017ooooo
001Tooooo`;o0000;?ooool<ojO0j`_oYko[1?nV_n/2ojJok0OoY/3/0_nV`N`6ojK1k@KoY/;]0_nW
`^d2ojO3k@GoYl?^Poooool3o`0001Gooooo001Vooooo`03o`000?oooooooooo02_ooooo2onW`>/;
ojNoj`;oY[o[2?nV`>`5ojK1k0GoY/7]1OnV`^d2ojO2k@;oYl?]QOooool4o`0001Sooooo001Woooo
o`03o`000?oooooooooo02[ooooo3?nW`>/2ojNoj`03ojO0jonW_n_oYko[00CoYko[0_nW`>`8ojK0
k0GoY/7/1OnV`Nd7ojO2kHCooooo1?l0000Looooo`00J?ooool00ol0003oooooooooo`0Zooooo`oo
Yl3[0_nW_n/3ojO0j`?oYl3/0_nV`>`2ojO0k0;oY/3/1_nW`N`2ojK1k@03ojO1kOnW`^goYl;]00Co
Yl;]Poooool4o`00023ooooo001Yooooo`;o0000;?oooolCojO0j`OoYl3/1onW`N`4ojO1k@;oYl;]
P_ooool4o`0002Cooooo001[ooooo`03o`000?oooooooooo02[ooooo4onW`>/7ojO0k0OoYl7/0_nW
`Nf2ooooo`?o0000:?ooool006cooooo00?o0000ooooooooool0:_oooolAojO0j`OoYl3/1OnW`Nb3
ooooo`Co0000:oooool006gooooo00?o0000ooooooooool0:oooool>ojO0j`SoYl3/0_nW`Nb2oooo
o`Co0000;oooool006kooooo00?o0000ooooooooool0:_ooool?ojO0j`KoYl3/POooool4o`0003?o
oooo001_ooooo`;o0000:oooool?ojO0j`;oYl3/P?ooool4o`0003Oooooo001aooooo`03o`000?oo
oooooooo02[ooooo2OnW`>^2ooooo`Co0000>oooool007;ooooo00?o0000ooooooooool0:_ooool5
ojO0jh;ooooo0ol0000oooooo`00Loooool00ol0003oooooooooo`0Zooooo`03ojO0jooooooooooo
07oooooo1?l00012ooooo`00M?ooool2o`0002[ooooo00?o0000ooooooooool0Noooool4o`0004Ko
oooo001fooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0N?ooool4o`0004[ooooo
001gooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0M?ooool4o`0004kooooo001h
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0LOooool3o`0005;ooooo001ioooo
o`;o00009?ooool00ol0003oooooooooo`1]ooooo`Co0000EOooool007_ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`1Yooooo`Co0000FOooool007cooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`1Uooooo`Co0000GOooool007gooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`1Qooooo`Co0000HOooool007kooooo0_l0000Oooooo`03o`000?oooooo
oooo05gooooo1?l0001Uooooo`00P?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
05[ooooo0ol0001Yooooo`00POooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Ko
oooo1?l0001/ooooo`00P_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05;ooooo
1?l0001`ooooo`00Poooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04kooooo1?l0
001dooooo`00Q?ooool2o`0001Wooooo00?o0000ooooooooool0B_ooool4o`0007Sooooo0026oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0A_ooool4o`0007cooooo0027ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0@oooool3o`00083ooooo0028ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0?oooool4o`0008?ooooo0029ooooo`;o00005?oo
ool00ol0003oooooooooo`0kooooo`Co0000Qoooool008_ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0gooooo`Co0000Roooool008cooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0cooooo`Co0000Soooool008gooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0`ooooo`?o0000Toooool008kooooo0_l0000?ooooo`03o`000?oooooooooo02cooooo
1?l0002Fooooo`00T?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Sooooo1?l0
002Jooooo`00TOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Cooooo1?l0002N
ooooo`00T_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo1?l0002Roooo
o`00Toooool2o`0000Wooooo00?o0000ooooooooool07Oooool4o`000:Kooooo002Eooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool06_ooool3o`000:[ooooo002Fooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool05_ooool4o`000:gooooo002Gooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool04_ooool4o`000;7ooooo002Hooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool03_ooool4o`000;Gooooo002Iooooo`;o00000oooool00ol0003o
ooooooooo`0:ooooo`Co0000^Oooool009_ooooo00Co0000oooooooooooo00002Oooool3o`000;go
oooo002Looooo`03o`000?oooooo000000Gooooo1?l00030ooooo`00WOooool2o`000003ooooool0
003o000000;o0000a?ooool009kooooo0_l00038ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
Z_ooool01OnHV9So0000o`000?m4A4Co^[Zj00[ooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?l@413oc<c<1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c02Cooooo`00Z_oo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo1_l00004ooooo`03o`000?oooooooooo00;ooooo
00GoEEEEogMgMoooooooV9RHob4Q8@05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q
09?ooooo002Zooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`00002Cooooo`00Z_ooool00ol0
003oooooooooo`04ooooo`Ko00001?ooool00ol0003oooooooooo`02ooooo`05o`000?nHV9Sooooo
oiRHV?lQ8B402oooool01Olb<S;oV9RHoooooonHV9So<S8b09?ooooo002Zooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool00_ooool01Ol0003oEEEEo`000?l@413oc<c<00_ooooo00Go
c<c<o`000?l0003o0000olc<c02Cooooo`00Z?ooool00ol@413o0000o`000003o`0000gooooo00?o
0000ooooooooool00_ooool00omEEEGoQhN7ooooo`0=ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
Toooool00:[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03omgMgOl@
413oV9RH00gooooo00Go0000okZj^_oooooo^[Zjo`00002Cooooo`00Z_ooool00ol0003ooooooooo
o`0<ooooo`03oeEEEOmVIVKo000000Gooooo00Coc<c<odA4A?l0003o410@2oooool01OnYZJWo410@
o`000?l@413oZJVY09?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -20 0 ]
[.5 .82364 20 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(17.6) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .752 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69466 Mtetra
.656 .751 .92 r
.4053 .69466 .41061 .69934 .41957 .69681 .41428 .69211 Mtetra
.656 .751 .919 r
.41428 .69211 .41957 .69681 .42855 .69428 .42328 .68955 Mtetra
.656 .75 .919 r
.42328 .68955 .42855 .69428 .43756 .69174 .43231 .68698 Mtetra
.43231 .68698 .43756 .69174 .4466 .68919 .44137 .68441 Mtetra
.656 .749 .919 r
.44137 .68441 .4466 .68919 .45567 .68663 .45046 .68184 Mtetra
.45046 .68184 .45567 .68663 .46478 .68407 .45958 .67926 Mtetra
.45958 .67926 .46478 .68407 .47391 .68149 .46873 .67668 Mtetra
.655 .75 .919 r
.46873 .67668 .47391 .68149 .48307 .67891 .47792 .67409 Mtetra
.655 .75 .92 r
.47792 .67409 .48307 .67891 .49227 .67632 .48713 .67151 Mtetra
.654 .751 .921 r
.48713 .67151 .49227 .67632 .50149 .67371 .49638 .66893 Mtetra
.654 .753 .922 r
.49638 .66893 .50149 .67371 .51075 .6711 .50565 .66635 Mtetra
.653 .754 .924 r
.50565 .66635 .51075 .6711 .52004 .66849 .51496 .66377 Mtetra
.653 .756 .926 r
.51496 .66377 .52004 .66849 .52936 .66586 .5243 .66118 Mtetra
.652 .759 .927 r
.5243 .66118 .52936 .66586 .53871 .66322 .53367 .65859 Mtetra
.652 .761 .929 r
.53367 .65859 .53871 .66322 .54809 .66058 .54308 .65598 Mtetra
.652 .763 .931 r
.54308 .65598 .54809 .66058 .55751 .65792 .55252 .65336 Mtetra
.652 .766 .932 r
.55252 .65336 .55751 .65792 .56695 .65526 .56199 .65072 Mtetra
.653 .767 .933 r
.56199 .65072 .56695 .65526 .57643 .65259 .57149 .64805 Mtetra
.653 .768 .934 r
.57149 .64805 .57643 .65259 .58595 .6499 .58102 .64536 Mtetra
.654 .769 .933 r
.58102 .64536 .58595 .6499 .59549 .64721 .59059 .64263 Mtetra
.655 .768 .933 r
.59059 .64263 .59549 .64721 .60507 .64451 .60019 .63989 Mtetra
.655 .767 .932 r
.60019 .63989 .60507 .64451 .61468 .6418 .60983 .63713 Mtetra
.656 .766 .93 r
.60983 .63713 .61468 .6418 .62432 .63908 .61949 .63435 Mtetra
.656 .764 .929 r
.61949 .63435 .62432 .63908 .634 .63636 .62919 .63156 Mtetra
.656 .762 .928 r
.62919 .63156 .634 .63636 .64371 .63362 .63892 .62876 Mtetra
.656 .761 .927 r
.63892 .62876 .64371 .63362 .65345 .63087 .64869 .62597 Mtetra
.656 .759 .926 r
.64869 .62597 .65345 .63087 .66323 .62811 .65849 .62317 Mtetra
.656 .758 .925 r
.65849 .62317 .66323 .62811 .67304 .62535 .66833 .62037 Mtetra
.655 .758 .925 r
.66833 .62037 .67304 .62535 .68289 .62257 .6782 .61758 Mtetra
.655 .757 .925 r
.6782 .61758 .68289 .62257 .69277 .61979 .6881 .61479 Mtetra
.654 .758 .926 r
.6881 .61479 .69277 .61979 .70269 .61699 .69804 .612 Mtetra
.654 .758 .927 r
.69804 .612 .70269 .61699 .71264 .61418 .70802 .60921 Mtetra
.653 .76 .928 r
.70802 .60921 .71264 .61418 .72262 .61137 .71803 .60641 Mtetra
.653 .761 .929 r
.71803 .60641 .72262 .61137 .73264 .60854 .72808 .60361 Mtetra
.652 .763 .93 r
.72808 .60361 .73264 .60854 .7427 .60571 .73816 .6008 Mtetra
.652 .765 .932 r
.73816 .6008 .7427 .60571 .75279 .60286 .74828 .59798 Mtetra
.653 .767 .933 r
.74828 .59798 .75279 .60286 .76291 .60001 .75844 .59513 Mtetra
.653 .768 .933 r
.75844 .59513 .76291 .60001 .77308 .59714 .76863 .59226 Mtetra
.654 .769 .934 r
.76863 .59226 .77308 .59714 .78328 .59427 .77885 .58936 Mtetra
.654 .769 .933 r
.77885 .58936 .78328 .59427 .79351 .59138 .78911 .58644 Mtetra
.655 .768 .932 r
.78911 .58644 .79351 .59138 .80378 .58849 .79941 .58349 Mtetra
.656 .767 .931 r
.79941 .58349 .80378 .58849 .81409 .58558 .80974 .58051 Mtetra
.657 .765 .929 r
.80974 .58051 .81409 .58558 .82443 .58267 .82011 .57752 Mtetra
.657 .763 .928 r
.82011 .57752 .82443 .58267 .83482 .57974 .83051 .57451 Mtetra
.657 .76 .926 r
.83051 .57451 .83482 .57974 .84523 .5768 .84095 .57149 Mtetra
.657 .758 .924 r
.84095 .57149 .84523 .5768 .85569 .57385 .85143 .56847 Mtetra
.657 .756 .922 r
.85143 .56847 .85569 .57385 .86618 .57089 .86195 .56545 Mtetra
.657 .754 .921 r
.86195 .56545 .86618 .57089 .87672 .56792 .8725 .56242 Mtetra
.657 .752 .92 r
.8725 .56242 .87672 .56792 .88729 .56494 .8831 .55939 Mtetra
.657 .751 .919 r
.8831 .55939 .88729 .56494 .89789 .56195 .89373 .55636 Mtetra
.656 .75 .919 r
.89373 .55636 .89789 .56195 .90854 .55895 .90441 .55333 Mtetra
.90441 .55333 .90854 .55895 .91923 .55594 .91512 .5503 Mtetra
.656 .749 .919 r
.91512 .5503 .91923 .55594 .92995 .55292 .92587 .54725 Mtetra
.92587 .54725 .92995 .55292 .94071 .54988 .93666 .5442 Mtetra
.656 .75 .919 r
.93666 .5442 .94071 .54988 .95152 .54684 .9475 .54115 Mtetra
.655 .75 .919 r
.9475 .54115 .95152 .54684 .96236 .54378 .95837 .53808 Mtetra
.655 .75 .92 r
.95837 .53808 .96236 .54378 .97324 .54071 .96928 .535 Mtetra
.655 .751 .92 r
.96928 .535 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.657 .752 .92 r
.391 .69252 .39636 .6972 .4053 .69466 .39996 .68995 Mtetra
.657 .751 .919 r
.39996 .68995 .4053 .69466 .41428 .69211 .40895 .68737 Mtetra
.40895 .68737 .41428 .69211 .42328 .68955 .41797 .68479 Mtetra
.657 .75 .919 r
.41797 .68479 .42328 .68955 .43231 .68698 .42702 .6822 Mtetra
.42702 .6822 .43231 .68698 .44137 .68441 .4361 .6796 Mtetra
.656 .75 .919 r
.4361 .6796 .44137 .68441 .45046 .68184 .44521 .67701 Mtetra
.656 .749 .919 r
.44521 .67701 .45046 .68184 .45958 .67926 .45435 .67441 Mtetra
.655 .749 .919 r
.45435 .67441 .45958 .67926 .46873 .67668 .46353 .67182 Mtetra
.46353 .67182 .46873 .67668 .47792 .67409 .47273 .66924 Mtetra
.654 .75 .92 r
.47273 .66924 .47792 .67409 .48713 .67151 .48196 .66666 Mtetra
.653 .75 .921 r
.48196 .66666 .48713 .67151 .49638 .66893 .49123 .6641 Mtetra
.652 .751 .923 r
.49123 .6641 .49638 .66893 .50565 .66635 .50052 .66154 Mtetra
.651 .753 .924 r
.50052 .66154 .50565 .66635 .51496 .66377 .50985 .659 Mtetra
.65 .755 .926 r
.50985 .659 .51496 .66377 .5243 .66118 .51922 .65645 Mtetra
.65 .757 .928 r
.51922 .65645 .5243 .66118 .53367 .65859 .52861 .65391 Mtetra
.649 .759 .93 r
.52861 .65391 .53367 .65859 .54308 .65598 .53804 .65135 Mtetra
.65 .762 .931 r
.53804 .65135 .54308 .65598 .55252 .65336 .5475 .64876 Mtetra
.65 .765 .933 r
.5475 .64876 .55252 .65336 .56199 .65072 .55699 .64614 Mtetra
.652 .767 .933 r
.55699 .64614 .56199 .65072 .57149 .64805 .56651 .64348 Mtetra
.653 .768 .934 r
.56651 .64348 .57149 .64805 .58102 .64536 .57607 .64078 Mtetra
.655 .769 .933 r
.57607 .64078 .58102 .64536 .59059 .64263 .58566 .63803 Mtetra
.656 .769 .933 r
.58566 .63803 .59059 .64263 .60019 .63989 .59529 .63525 Mtetra
.657 .768 .931 r
.59529 .63525 .60019 .63989 .60983 .63713 .60494 .63243 Mtetra
.658 .767 .93 r
.60494 .63243 .60983 .63713 .61949 .63435 .61463 .62959 Mtetra
.658 .765 .929 r
.61463 .62959 .61949 .63435 .62919 .63156 .62435 .62674 Mtetra
.658 .763 .927 r
.62435 .62674 .62919 .63156 .63892 .62876 .63411 .62388 Mtetra
.658 .761 .926 r
.63411 .62388 .63892 .62876 .64869 .62597 .6439 .62103 Mtetra
.657 .76 .926 r
.6439 .62103 .64869 .62597 .65849 .62317 .65372 .61819 Mtetra
.656 .759 .925 r
.65372 .61819 .65849 .62317 .66833 .62037 .66358 .61537 Mtetra
.655 .758 .925 r
.66358 .61537 .66833 .62037 .6782 .61758 .67347 .61256 Mtetra
.654 .757 .926 r
.67347 .61256 .6782 .61758 .6881 .61479 .6834 .60976 Mtetra
.653 .758 .926 r
.6834 .60976 .6881 .61479 .69804 .612 .69337 .60697 Mtetra
.652 .758 .927 r
.69337 .60697 .69804 .612 .70802 .60921 .70337 .6042 Mtetra
.651 .759 .929 r
.70337 .6042 .70802 .60921 .71803 .60641 .71341 .60143 Mtetra
.651 .761 .93 r
.71341 .60143 .71803 .60641 .72808 .60361 .72349 .59866 Mtetra
.651 .763 .931 r
.72349 .59866 .72808 .60361 .73816 .6008 .7336 .59587 Mtetra
.651 .765 .933 r
.7336 .59587 .73816 .6008 .74828 .59798 .74375 .59307 Mtetra
.651 .766 .933 r
.74375 .59307 .74828 .59798 .75844 .59513 .75393 .59023 Mtetra
.653 .768 .934 r
.75393 .59023 .75844 .59513 .76863 .59226 .76415 .58735 Mtetra
.654 .769 .934 r
.76415 .58735 .76863 .59226 .77885 .58936 .7744 .58443 Mtetra
.656 .769 .933 r
.7744 .58443 .77885 .58936 .78911 .58644 .78469 .58146 Mtetra
.657 .769 .932 r
.78469 .58146 .78911 .58644 .79941 .58349 .79501 .57844 Mtetra
.658 .767 .93 r
.79501 .57844 .79941 .58349 .80974 .58051 .80536 .57539 Mtetra
.659 .765 .928 r
.80536 .57539 .80974 .58051 .82011 .57752 .81575 .57232 Mtetra
.66 .763 .926 r
.81575 .57232 .82011 .57752 .83051 .57451 .82618 .56923 Mtetra
.66 .76 .924 r
.82618 .56923 .83051 .57451 .84095 .57149 .83664 .56613 Mtetra
.66 .758 .923 r
.83664 .56613 .84095 .57149 .85143 .56847 .84714 .56303 Mtetra
.659 .755 .921 r
.84714 .56303 .85143 .56847 .86195 .56545 .85768 .55994 Mtetra
.658 .753 .92 r
.85768 .55994 .86195 .56545 .8725 .56242 .86826 .55686 Mtetra
.658 .752 .919 r
.86826 .55686 .8725 .56242 .8831 .55939 .87888 .55379 Mtetra
.657 .751 .919 r
.87888 .55379 .8831 .55939 .89373 .55636 .88954 .55073 Mtetra
.657 .75 .919 r
.88954 .55073 .89373 .55636 .90441 .55333 .90024 .54767 Mtetra
.656 .749 .919 r
.90024 .54767 .90441 .55333 .91512 .5503 .91098 .54461 Mtetra
.91098 .54461 .91512 .5503 .92587 .54725 .92176 .54155 Mtetra
.655 .749 .919 r
.92176 .54155 .92587 .54725 .93666 .5442 .93259 .53849 Mtetra
.93259 .53849 .93666 .5442 .9475 .54115 .94345 .53542 Mtetra
.655 .75 .919 r
.94345 .53542 .9475 .54115 .95837 .53808 .95435 .53235 Mtetra
.655 .75 .92 r
.95435 .53235 .95837 .53808 .96928 .535 .9653 .52926 Mtetra
.655 .751 .92 r
.9653 .52926 .96928 .535 .98024 .53192 .97628 .52616 Mtetra
.657 .752 .92 r
.38561 .68781 .391 .69252 .39996 .68995 .39459 .68522 Mtetra
.657 .751 .919 r
.39459 .68522 .39996 .68995 .40895 .68737 .4036 .68262 Mtetra
.4036 .68262 .40895 .68737 .41797 .68479 .41264 .68001 Mtetra
.41264 .68001 .41797 .68479 .42702 .6822 .4217 .67739 Mtetra
.657 .75 .919 r
.4217 .67739 .42702 .6822 .4361 .6796 .4308 .67477 Mtetra
.656 .75 .919 r
.4308 .67477 .4361 .6796 .44521 .67701 .43993 .67216 Mtetra
.656 .749 .919 r
.43993 .67216 .44521 .67701 .45435 .67441 .44909 .66954 Mtetra
.655 .749 .919 r
.44909 .66954 .45435 .67441 .46353 .67182 .45829 .66694 Mtetra
.654 .749 .919 r
.45829 .66694 .46353 .67182 .47273 .66924 .46751 .66434 Mtetra
.653 .749 .92 r
.46751 .66434 .47273 .66924 .48196 .66666 .47676 .66177 Mtetra
.652 .749 .921 r
.47676 .66177 .48196 .66666 .49123 .6641 .48605 .65921 Mtetra
.65 .75 .922 r
.48605 .65921 .49123 .6641 .50052 .66154 .49536 .65668 Mtetra
.649 .751 .924 r
.49536 .65668 .50052 .66154 .50985 .659 .50471 .65416 Mtetra
.648 .753 .926 r
.50471 .65416 .50985 .659 .51922 .65645 .5141 .65166 Mtetra
.647 .755 .928 r
.5141 .65166 .51922 .65645 .52861 .65391 .52351 .64916 Mtetra
.647 .757 .93 r
.52351 .64916 .52861 .65391 .53804 .65135 .53296 .64664 Mtetra
.647 .76 .931 r
.53296 .64664 .53804 .65135 .5475 .64876 .54244 .6441 Mtetra
.648 .763 .933 r
.54244 .6441 .5475 .64876 .55699 .64614 .55196 .64152 Mtetra
.65 .765 .933 r
.55196 .64152 .55699 .64614 .56651 .64348 .56151 .63888 Mtetra
.652 .768 .934 r
.56151 .63888 .56651 .64348 .57607 .64078 .57109 .63617 Mtetra
.655 .769 .933 r
.57109 .63617 .57607 .64078 .58566 .63803 .5807 .63341 Mtetra
.657 .77 .932 r
.5807 .63341 .58566 .63803 .59529 .63525 .59035 .63058 Mtetra
.658 .769 .931 r
.59035 .63058 .59529 .63525 .60494 .63243 .60003 .62772 Mtetra
.66 .768 .93 r
.60003 .62772 .60494 .63243 .61463 .62959 .60974 .62482 Mtetra
.66 .766 .929 r
.60974 .62482 .61463 .62959 .62435 .62674 .61948 .6219 Mtetra
.66 .765 .927 r
.61948 .6219 .62435 .62674 .63411 .62388 .62926 .61899 Mtetra
.659 .763 .926 r
.62926 .61899 .63411 .62388 .6439 .62103 .63907 .61609 Mtetra
.658 .761 .926 r
.63907 .61609 .6439 .62103 .65372 .61819 .64892 .6132 Mtetra
.657 .759 .926 r
.64892 .6132 .65372 .61819 .66358 .61537 .6588 .61035 Mtetra
.655 .758 .926 r
.6588 .61035 .66358 .61537 .67347 .61256 .66872 .60752 Mtetra
.653 .758 .926 r
.66872 .60752 .67347 .61256 .6834 .60976 .67867 .60471 Mtetra
.652 .758 .927 r
.67867 .60471 .6834 .60976 .69337 .60697 .68867 .60194 Mtetra
.65 .758 .928 r
.68867 .60194 .69337 .60697 .70337 .6042 .6987 .59918 Mtetra
.649 .759 .93 r
.6987 .59918 .70337 .6042 .71341 .60143 .70876 .59643 Mtetra
.649 .761 .931 r
.70876 .59643 .71341 .60143 .72349 .59866 .71887 .59369 Mtetra
.649 .763 .933 r
.71887 .59369 .72349 .59866 .7336 .59587 .72901 .59093 Mtetra
.649 .765 .934 r
.72901 .59093 .7336 .59587 .74375 .59307 .73918 .58814 Mtetra
.651 .767 .934 r
.73918 .58814 .74375 .59307 .75393 .59023 .7494 .5853 Mtetra
.652 .768 .934 r
.7494 .5853 .75393 .59023 .76415 .58735 .75964 .58241 Mtetra
.655 .769 .933 r
.75964 .58241 .76415 .58735 .7744 .58443 .76992 .57944 Mtetra
.657 .769 .932 r
.76992 .57944 .7744 .58443 .78469 .58146 .78023 .57642 Mtetra
.659 .768 .93 r
.78023 .57642 .78469 .58146 .79501 .57844 .79057 .57333 Mtetra
.661 .767 .928 r
.79057 .57333 .79501 .57844 .80536 .57539 .80095 .5702 Mtetra
.662 .765 .926 r
.80095 .5702 .80536 .57539 .81575 .57232 .81136 .56704 Mtetra
.662 .762 .924 r
.81136 .56704 .81575 .57232 .82618 .56923 .82181 .56387 Mtetra
.662 .76 .922 r
.82181 .56387 .82618 .56923 .83664 .56613 .83229 .56069 Mtetra
.662 .757 .921 r
.83229 .56069 .83664 .56613 .84714 .56303 .84282 .55753 Mtetra
.661 .755 .92 r
.84282 .55753 .84714 .56303 .85768 .55994 .85338 .55438 Mtetra
.66 .753 .919 r
.85338 .55438 .85768 .55994 .86826 .55686 .86399 .55125 Mtetra
.658 .751 .919 r
.86399 .55125 .86826 .55686 .87888 .55379 .87463 .54814 Mtetra
.658 .75 .918 r
.87463 .54814 .87888 .55379 .88954 .55073 .88532 .54505 Mtetra
.657 .75 .918 r
.88532 .54505 .88954 .55073 .90024 .54767 .89605 .54197 Mtetra
.656 .749 .919 r
.89605 .54197 .90024 .54767 .91098 .54461 .90682 .53889 Mtetra
.90682 .53889 .91098 .54461 .92176 .54155 .91763 .53582 Mtetra
.655 .749 .919 r
.91763 .53582 .92176 .54155 .93259 .53849 .92848 .53274 Mtetra
.655 .75 .919 r
.92848 .53274 .93259 .53849 .94345 .53542 .93938 .52966 Mtetra
.655 .75 .92 r
.93938 .52966 .94345 .53542 .95435 .53235 .95031 .52658 Mtetra
.95031 .52658 .95435 .53235 .9653 .52926 .96129 .52348 Mtetra
.96129 .52348 .9653 .52926 .97628 .52616 .9723 .52037 Mtetra
.657 .752 .92 r
.38018 .68308 .38561 .68781 .39459 .68522 .38918 .68046 Mtetra
.657 .752 .919 r
.38918 .68046 .39459 .68522 .4036 .68262 .39821 .67784 Mtetra
.657 .751 .919 r
.39821 .67784 .4036 .68262 .41264 .68001 .40726 .6752 Mtetra
.40726 .6752 .41264 .68001 .4217 .67739 .41635 .67256 Mtetra
.41635 .67256 .4217 .67739 .4308 .67477 .42547 .66992 Mtetra
.657 .75 .919 r
.42547 .66992 .4308 .67477 .43993 .67216 .43462 .66728 Mtetra
.656 .75 .919 r
.43462 .66728 .43993 .67216 .44909 .66954 .4438 .66465 Mtetra
.655 .749 .919 r
.4438 .66465 .44909 .66954 .45829 .66694 .45301 .66202 Mtetra
.654 .749 .919 r
.45301 .66202 .45829 .66694 .46751 .66434 .46226 .65941 Mtetra
.653 .749 .92 r
.46226 .65941 .46751 .66434 .47676 .66177 .47153 .65682 Mtetra
.651 .748 .921 r
.47153 .65682 .47676 .66177 .48605 .65921 .48083 .65427 Mtetra
.649 .748 .922 r
.48083 .65427 .48605 .65921 .49536 .65668 .49017 .65174 Mtetra
.647 .749 .923 r
.49017 .65174 .49536 .65668 .50471 .65416 .49954 .64925 Mtetra
.646 .75 .925 r
.49954 .64925 .50471 .65416 .5141 .65166 .50894 .64678 Mtetra
.644 .752 .927 r
.50894 .64678 .5141 .65166 .52351 .64916 .51838 .64432 Mtetra
.644 .754 .929 r
.51838 .64432 .52351 .64916 .53296 .64664 .52785 .64185 Mtetra
.644 .757 .931 r
.52785 .64185 .53296 .64664 .54244 .6441 .53735 .63937 Mtetra
.646 .76 .932 r
.53735 .63937 .54244 .6441 .55196 .64152 .54689 .63683 Mtetra
.648 .763 .933 r
.54689 .63683 .55196 .64152 .56151 .63888 .55646 .63422 Mtetra
.651 .766 .934 r
.55646 .63422 .56151 .63888 .57109 .63617 .56607 .63153 Mtetra
.654 .769 .933 r
.56607 .63153 .57109 .63617 .5807 .63341 .57571 .62876 Mtetra
.657 .77 .933 r
.57571 .62876 .5807 .63341 .59035 .63058 .58538 .62591 Mtetra
.66 .77 .931 r
.58538 .62591 .59035 .63058 .60003 .62772 .59508 .623 Mtetra
.661 .77 .93 r
.59508 .623 .60003 .62772 .60974 .62482 .60481 .62005 Mtetra
.662 .768 .929 r
.60481 .62005 .60974 .62482 .61948 .6219 .61458 .61707 Mtetra
.661 .766 .928 r
.61458 .61707 .61948 .6219 .62926 .61899 .62438 .61409 Mtetra
.66 .764 .927 r
.62438 .61409 .62926 .61899 .63907 .61609 .63421 .61114 Mtetra
.659 .762 .926 r
.63421 .61114 .63907 .61609 .64892 .6132 .64408 .60821 Mtetra
.657 .761 .926 r
.64408 .60821 .64892 .6132 .6588 .61035 .65399 .60532 Mtetra
.655 .759 .927 r
.65399 .60532 .6588 .61035 .66872 .60752 .66393 .60247 Mtetra
.653 .759 .927 r
.66393 .60247 .66872 .60752 .67867 .60471 .67391 .59966 Mtetra
.651 .759 .928 r
.67391 .59966 .67867 .60471 .68867 .60194 .68393 .5969 Mtetra
.649 .759 .93 r
.68393 .5969 .68867 .60194 .6987 .59918 .69399 .59416 Mtetra
.647 .76 .931 r
.69399 .59416 .6987 .59918 .70876 .59643 .70408 .59144 Mtetra
.646 .762 .933 r
.70408 .59144 .70876 .59643 .71887 .59369 .71422 .58872 Mtetra
.647 .764 .934 r
.71422 .58872 .71887 .59369 .72901 .59093 .72439 .58598 Mtetra
.648 .766 .935 r
.72439 .58598 .72901 .59093 .73918 .58814 .73459 .5832 Mtetra
.65 .767 .935 r
.73459 .5832 .73918 .58814 .7494 .5853 .74483 .58035 Mtetra
.653 .769 .934 r
.74483 .58035 .7494 .5853 .75964 .58241 .7551 .57742 Mtetra
.656 .769 .933 r
.7551 .57742 .75964 .58241 .76992 .57944 .7654 .57441 Mtetra
.659 .769 .931 r
.7654 .57441 .76992 .57944 .78023 .57642 .77574 .57131 Mtetra
.662 .768 .928 r
.77574 .57131 .78023 .57642 .79057 .57333 .7861 .56814 Mtetra
.664 .766 .926 r
.7861 .56814 .79057 .57333 .80095 .5702 .7965 .56492 Mtetra
.665 .763 .923 r
.7965 .56492 .80095 .5702 .81136 .56704 .80693 .56167 Mtetra
.665 .761 .921 r
.80693 .56167 .81136 .56704 .82181 .56387 .8174 .55841 Mtetra
.664 .758 .92 r
.8174 .55841 .82181 .56387 .83229 .56069 .82791 .55517 Mtetra
.663 .756 .919 r
.82791 .55517 .83229 .56069 .84282 .55753 .83846 .55194 Mtetra
.662 .754 .918 r
.83846 .55194 .84282 .55753 .85338 .55438 .84905 .54875 Mtetra
.66 .752 .918 r
.84905 .54875 .85338 .55438 .86399 .55125 .85968 .54558 Mtetra
.659 .751 .918 r
.85968 .54558 .86399 .55125 .87463 .54814 .87035 .54245 Mtetra
.658 .75 .918 r
.87035 .54245 .87463 .54814 .88532 .54505 .88107 .53933 Mtetra
.657 .75 .919 r
.88107 .53933 .88532 .54505 .89605 .54197 .89183 .53624 Mtetra
.656 .749 .919 r
.89183 .53624 .89605 .54197 .90682 .53889 .90263 .53315 Mtetra
.655 .75 .919 r
.90263 .53315 .90682 .53889 .91763 .53582 .91347 .53006 Mtetra
.655 .75 .92 r
.91347 .53006 .91763 .53582 .92848 .53274 .92435 .52697 Mtetra
.92435 .52697 .92848 .53274 .93938 .52966 .93528 .52388 Mtetra
.654 .75 .92 r
.93528 .52388 .93938 .52966 .95031 .52658 .94624 .52077 Mtetra
.94624 .52077 .95031 .52658 .96129 .52348 .95725 .51766 Mtetra
.654 .751 .921 r
.95725 .51766 .96129 .52348 .9723 .52037 .96829 .51454 Mtetra
.657 .752 .92 r
.37472 .67831 .38018 .68308 .38918 .68046 .38374 .67568 Mtetra
.658 .752 .92 r
.38374 .67568 .38918 .68046 .39821 .67784 .39278 .67303 Mtetra
.658 .752 .919 r
.39278 .67303 .39821 .67784 .40726 .6752 .40186 .67038 Mtetra
.657 .752 .919 r
.40186 .67038 .40726 .6752 .41635 .67256 .41097 .66772 Mtetra
.657 .751 .919 r
.41097 .66772 .41635 .67256 .42547 .66992 .42011 .66506 Mtetra
.42011 .66506 .42547 .66992 .43462 .66728 .42928 .66239 Mtetra
.42928 .66239 .43462 .66728 .4438 .66465 .43848 .65973 Mtetra
.656 .75 .919 r
.43848 .65973 .4438 .66465 .45301 .66202 .44771 .65707 Mtetra
.655 .749 .919 r
.44771 .65707 .45301 .66202 .46226 .65941 .45697 .65444 Mtetra
.653 .748 .92 r
.45697 .65444 .46226 .65941 .47153 .65682 .46626 .65183 Mtetra
.651 .747 .92 r
.46626 .65183 .47153 .65682 .48083 .65427 .47559 .64925 Mtetra
.649 .747 .921 r
.47559 .64925 .48083 .65427 .49017 .65174 .48495 .64672 Mtetra
.647 .746 .922 r
.48495 .64672 .49017 .65174 .49954 .64925 .49434 .64423 Mtetra
.644 .747 .924 r
.49434 .64423 .49954 .64925 .50894 .64678 .50376 .64178 Mtetra
.642 .748 .926 r
.50376 .64178 .50894 .64678 .51838 .64432 .51322 .63937 Mtetra
.641 .75 .928 r
.51322 .63937 .51838 .64432 .52785 .64185 .52271 .63696 Mtetra
.641 .753 .93 r
.52271 .63696 .52785 .64185 .53735 .63937 .53223 .63453 Mtetra
.642 .756 .932 r
.53223 .63453 .53735 .63937 .54689 .63683 .54179 .63206 Mtetra
.645 .761 .933 r
.54179 .63206 .54689 .63683 .55646 .63422 .55139 .62951 Mtetra
.649 .765 .934 r
.55139 .62951 .55646 .63422 .56607 .63153 .56102 .62686 Mtetra
.653 .768 .934 r
.56102 .62686 .56607 .63153 .57571 .62876 .57068 .6241 Mtetra
.657 .77 .933 r
.57068 .6241 .57571 .62876 .58538 .62591 .58037 .62124 Mtetra
.66 .772 .932 r
.58037 .62124 .58538 .62591 .59508 .623 .5901 .61829 Mtetra
.662 .772 .931 r
.5901 .61829 .59508 .623 .60481 .62005 .59985 .61528 Mtetra
.663 .771 .929 r
.59985 .61528 .60481 .62005 .61458 .61707 .60964 .61225 Mtetra
.663 .769 .928 r
.60964 .61225 .61458 .61707 .62438 .61409 .61947 .60921 Mtetra
.662 .767 .927 r
.61947 .60921 .62438 .61409 .63421 .61114 .62933 .60619 Mtetra
.66 .764 .927 r
.62933 .60619 .63421 .61114 .64408 .60821 .63922 .60322 Mtetra
.657 .762 .927 r
.63922 .60322 .64408 .60821 .65399 .60532 .64915 .60029 Mtetra
.655 .761 .928 r
.64915 .60029 .65399 .60532 .66393 .60247 .65912 .59743 Mtetra
.652 .76 .929 r
.65912 .59743 .66393 .60247 .67391 .59966 .66913 .59462 Mtetra
.649 .76 .93 r
.66913 .59462 .67391 .59966 .68393 .5969 .67917 .59186 Mtetra
.647 .76 .932 r
.67917 .59186 .68393 .5969 .69399 .59416 .68925 .58914 Mtetra
.645 .761 .933 r
.68925 .58914 .69399 .59416 .70408 .59144 .69938 .58645 Mtetra
.644 .763 .935 r
.69938 .58645 .70408 .59144 .71422 .58872 .70954 .58376 Mtetra
.645 .765 .936 r
.70954 .58376 .71422 .58872 .72439 .58598 .71973 .58103 Mtetra
.647 .767 .936 r
.71973 .58103 .72439 .58598 .73459 .5832 .72997 .57825 Mtetra
.65 .769 .936 r
.72997 .57825 .73459 .5832 .74483 .58035 .74023 .57537 Mtetra
.654 .77 .934 r
.74023 .57537 .74483 .58035 .7551 .57742 .75053 .5724 Mtetra
.659 .77 .932 r
.75053 .5724 .7551 .57742 .7654 .57441 .76085 .56931 Mtetra
.663 .769 .929 r
.76085 .56931 .7654 .57441 .77574 .57131 .77121 .56612 Mtetra
.666 .767 .926 r
.77121 .56612 .77574 .57131 .7861 .56814 .7816 .56285 Mtetra
.668 .765 .923 r
.7816 .56285 .7861 .56814 .7965 .56492 .79202 .55952 Mtetra
.668 .761 .92 r
.79202 .55952 .7965 .56492 .80693 .56167 .80247 .55618 Mtetra
.668 .758 .918 r
.80247 .55618 .80693 .56167 .8174 .55841 .81296 .55284 Mtetra
.666 .756 .917 r
.81296 .55284 .8174 .55841 .82791 .55517 .8235 .54953 Mtetra
.664 .753 .916 r
.8235 .54953 .82791 .55517 .83846 .55194 .83407 .54626 Mtetra
.662 .752 .916 r
.83407 .54626 .83846 .55194 .84905 .54875 .84469 .54304 Mtetra
.66 .75 .917 r
.84469 .54304 .84905 .54875 .85968 .54558 .85535 .53985 Mtetra
.659 .75 .917 r
.85535 .53985 .85968 .54558 .87035 .54245 .86605 .53671 Mtetra
.657 .75 .918 r
.86605 .53671 .87035 .54245 .88107 .53933 .87679 .53358 Mtetra
.656 .75 .919 r
.87679 .53358 .88107 .53933 .89183 .53624 .88758 .53048 Mtetra
.655 .75 .919 r
.88758 .53048 .89183 .53624 .90263 .53315 .89841 .52738 Mtetra
.655 .75 .92 r
.89841 .52738 .90263 .53315 .91347 .53006 .90928 .52428 Mtetra
.654 .75 .92 r
.90928 .52428 .91347 .53006 .92435 .52697 .9202 .52118 Mtetra
.9202 .52118 .92435 .52697 .93528 .52388 .93115 .51806 Mtetra
.654 .751 .921 r
.93115 .51806 .93528 .52388 .94624 .52077 .94215 .51494 Mtetra
.94215 .51494 .94624 .52077 .95725 .51766 .95318 .51181 Mtetra
.95318 .51181 .95725 .51766 .96829 .51454 .96426 .50866 Mtetra
.657 .752 .92 r
.36922 .67351 .37472 .67831 .38374 .67568 .37826 .67087 Mtetra
.37826 .67087 .38374 .67568 .39278 .67303 .38732 .66822 Mtetra
.38732 .66822 .39278 .67303 .40186 .67038 .39642 .66555 Mtetra
.39642 .66555 .40186 .67038 .41097 .66772 .40555 .66288 Mtetra
.40555 .66288 .41097 .66772 .42011 .66506 .41471 .66019 Mtetra
.41471 .66019 .42011 .66506 .42928 .66239 .4239 .6575 Mtetra
.4239 .6575 .42928 .66239 .43848 .65973 .43312 .65481 Mtetra
.656 .751 .92 r
.43312 .65481 .43848 .65973 .44771 .65707 .44237 .65212 Mtetra
.656 .75 .92 r
.44237 .65212 .44771 .65707 .45697 .65444 .45165 .64944 Mtetra
.654 .749 .919 r
.45165 .64944 .45697 .65444 .46626 .65183 .46097 .64679 Mtetra
.652 .748 .92 r
.46097 .64679 .46626 .65183 .47559 .64925 .47031 .64418 Mtetra
.65 .746 .92 r
.47031 .64418 .47559 .64925 .48495 .64672 .47969 .64162 Mtetra
.647 .745 .921 r
.47969 .64162 .48495 .64672 .49434 .64423 .4891 .63912 Mtetra
.644 .744 .922 r
.4891 .63912 .49434 .64423 .50376 .64178 .49854 .63668 Mtetra
.641 .744 .924 r
.49854 .63668 .50376 .64178 .51322 .63937 .50802 .63429 Mtetra
.639 .745 .926 r
.50802 .63429 .51322 .63937 .52271 .63696 .51753 .63193 Mtetra
.638 .748 .928 r
.51753 .63193 .52271 .63696 .53223 .63453 .52708 .62958 Mtetra
.639 .752 .93 r
.52708 .62958 .53223 .63453 .54179 .63206 .53666 .62718 Mtetra
.641 .756 .932 r
.53666 .62718 .54179 .63206 .55139 .62951 .54628 .62471 Mtetra
.645 .762 .934 r
.54628 .62471 .55139 .62951 .56102 .62686 .55593 .62213 Mtetra
.65 .766 .934 r
.55593 .62213 .56102 .62686 .57068 .6241 .56561 .61941 Mtetra
.655 .77 .934 r
.56561 .61941 .57068 .6241 .58037 .62124 .57533 .61656 Mtetra
.66 .773 .933 r
.57533 .61656 .58037 .62124 .5901 .61829 .58508 .6136 Mtetra
.663 .774 .932 r
.58508 .6136 .5901 .61829 .59985 .61528 .59486 .61055 Mtetra
.665 .773 .93 r
.59486 .61055 .59985 .61528 .60964 .61225 .60468 .60746 Mtetra
.665 .772 .929 r
.60468 .60746 .60964 .61225 .61947 .60921 .61453 .60436 Mtetra
.663 .77 .929 r
.61453 .60436 .61947 .60921 .62933 .60619 .62441 .60128 Mtetra
.661 .767 .928 r
.62441 .60128 .62933 .60619 .63922 .60322 .63433 .59825 Mtetra
.658 .765 .929 r
.63433 .59825 .63922 .60322 .64915 .60029 .64428 .59529 Mtetra
.654 .763 .929 r
.64428 .59529 .64915 .60029 .65912 .59743 .65427 .59241 Mtetra
.651 .762 .931 r
.65427 .59241 .65912 .59743 .66913 .59462 .66431 .5896 Mtetra
.647 .762 .932 r
.66431 .5896 .66913 .59462 .67917 .59186 .67438 .58685 Mtetra
.644 .762 .934 r
.67438 .58685 .67917 .59186 .68925 .58914 .68449 .58416 Mtetra
.643 .763 .936 r
.68449 .58416 .68925 .58914 .69938 .58645 .69464 .58149 Mtetra
.642 .765 .937 r
.69464 .58149 .69938 .58645 .70954 .58376 .70483 .57882 Mtetra
.643 .767 .938 r
.70483 .57882 .70954 .58376 .71973 .58103 .71505 .5761 Mtetra
.646 .769 .938 r
.71505 .5761 .71973 .58103 .72997 .57825 .72531 .5733 Mtetra
.651 .77 .936 r
.72531 .5733 .72997 .57825 .74023 .57537 .7356 .57037 Mtetra
.657 .771 .933 r
.7356 .57037 .74023 .57537 .75053 .5724 .74592 .56732 Mtetra
.662 .77 .93 r
.74592 .56732 .75053 .5724 .76085 .56931 .75627 .56412 Mtetra
.667 .768 .926 r
.75627 .56412 .76085 .56931 .77121 .56612 .76665 .56081 Mtetra
.67 .766 .922 r
.76665 .56081 .77121 .56612 .7816 .56285 .77705 .55742 Mtetra
.671 .762 .919 r
.77705 .55742 .7816 .56285 .79202 .55952 .78749 .55399 Mtetra
.671 .759 .916 r
.78749 .55399 .79202 .55952 .80247 .55618 .79797 .55056 Mtetra
.669 .755 .915 r
.79797 .55056 .80247 .55618 .81296 .55284 .80849 .54715 Mtetra
.667 .753 .914 r
.80849 .54715 .81296 .55284 .8235 .54953 .81904 .5438 Mtetra
.665 .751 .915 r
.81904 .5438 .8235 .54953 .83407 .54626 .82965 .5405 Mtetra
.662 .75 .915 r
.82965 .5405 .83407 .54626 .84469 .54304 .84029 .53727 Mtetra
.66 .749 .916 r
.84029 .53727 .84469 .54304 .85535 .53985 .85098 .53408 Mtetra
.658 .749 .918 r
.85098 .53408 .85535 .53985 .86605 .53671 .86171 .53093 Mtetra
.656 .75 .919 r
.86171 .53093 .86605 .53671 .87679 .53358 .87249 .52781 Mtetra
.655 .75 .92 r
.87249 .52781 .87679 .53358 .88758 .53048 .88331 .5247 Mtetra
.88331 .5247 .88758 .53048 .89841 .52738 .89417 .5216 Mtetra
.654 .751 .921 r
.89417 .5216 .89841 .52738 .90928 .52428 .90507 .51848 Mtetra
.90507 .51848 .90928 .52428 .9202 .52118 .91601 .51536 Mtetra
.91601 .51536 .9202 .52118 .93115 .51806 .927 .51223 Mtetra
.927 .51223 .93115 .51806 .94215 .51494 .93802 .50908 Mtetra
.93802 .50908 .94215 .51494 .95318 .51181 .94909 .50592 Mtetra
.94909 .50592 .95318 .51181 .96426 .50866 .9602 .50275 Mtetra
.657 .752 .92 r
.36369 .66869 .36922 .67351 .37826 .67087 .37275 .66604 Mtetra
.37275 .66604 .37826 .67087 .38732 .66822 .38183 .66338 Mtetra
.657 .753 .921 r
.38183 .66338 .38732 .66822 .39642 .66555 .39095 .66071 Mtetra
.39095 .66071 .39642 .66555 .40555 .66288 .40009 .65803 Mtetra
.40009 .65803 .40555 .66288 .41471 .66019 .40927 .65533 Mtetra
.657 .754 .921 r
.40927 .65533 .41471 .66019 .4239 .6575 .41848 .65261 Mtetra
.658 .753 .921 r
.41848 .65261 .4239 .6575 .43312 .65481 .42772 .64989 Mtetra
.657 .753 .92 r
.42772 .64989 .43312 .65481 .44237 .65212 .437 .64716 Mtetra
.657 .752 .92 r
.437 .64716 .44237 .65212 .45165 .64944 .4463 .64444 Mtetra
.656 .75 .92 r
.4463 .64444 .45165 .64944 .46097 .64679 .45563 .64174 Mtetra
.654 .748 .919 r
.45563 .64174 .46097 .64679 .47031 .64418 .465 .63907 Mtetra
.651 .746 .919 r
.465 .63907 .47031 .64418 .47969 .64162 .4744 .63645 Mtetra
.648 .744 .919 r
.4744 .63645 .47969 .64162 .4891 .63912 .48383 .63391 Mtetra
.644 .742 .92 r
.48383 .63391 .4891 .63912 .49854 .63668 .49329 .63145 Mtetra
.64 .74 .921 r
.49329 .63145 .49854 .63668 .50802 .63429 .50279 .62907 Mtetra
.637 .74 .923 r
.50279 .62907 .50802 .63429 .51753 .63193 .51232 .62676 Mtetra
.634 .742 .926 r
.51232 .62676 .51753 .63193 .52708 .62958 .52189 .62448 Mtetra
.634 .746 .929 r
.52189 .62448 .52708 .62958 .53666 .62718 .53149 .62218 Mtetra
.636 .751 .931 r
.53149 .62218 .53666 .62718 .54628 .62471 .54113 .61982 Mtetra
.64 .757 .933 r
.54113 .61982 .54628 .62471 .55593 .62213 .55081 .61734 Mtetra
.646 .764 .935 r
.55081 .61734 .55593 .62213 .56561 .61941 .56052 .61469 Mtetra
.653 .77 .935 r
.56052 .61469 .56561 .61941 .57533 .61656 .57026 .61189 Mtetra
.659 .774 .934 r
.57026 .61189 .57533 .61656 .58508 .6136 .58004 .60893 Mtetra
.663 .776 .933 r
.58004 .60893 .58508 .6136 .59486 .61055 .58984 .60586 Mtetra
.666 .777 .932 r
.58984 .60586 .59486 .61055 .60468 .60746 .59968 .60271 Mtetra
.666 .775 .931 r
.59968 .60271 .60468 .60746 .61453 .60436 .60955 .59955 Mtetra
.665 .773 .93 r
.60955 .59955 .61453 .60436 .62441 .60128 .61946 .59641 Mtetra
.662 .771 .93 r
.61946 .59641 .62441 .60128 .63433 .59825 .6294 .59333 Mtetra
.658 .768 .931 r
.6294 .59333 .63433 .59825 .64428 .59529 .63938 .59034 Mtetra
.654 .766 .932 r
.63938 .59034 .64428 .59529 .65427 .59241 .6494 .58743 Mtetra
.65 .765 .933 r
.6494 .58743 .65427 .59241 .66431 .5896 .65946 .58462 Mtetra
.645 .764 .935 r
.65946 .58462 .66431 .5896 .67438 .58685 .66955 .58189 Mtetra
.642 .764 .937 r
.66955 .58189 .67438 .58685 .68449 .58416 .67969 .57922 Mtetra
.64 .765 .939 r
.67969 .57922 .68449 .58416 .69464 .58149 .68987 .57658 Mtetra
.64 .767 .94 r
.68987 .57658 .69464 .58149 .70483 .57882 .70009 .57392 Mtetra
.642 .769 .94 r
.70009 .57392 .70483 .57882 .71505 .5761 .71034 .57119 Mtetra
.647 .771 .939 r
.71034 .57119 .71505 .5761 .72531 .5733 .72063 .56835 Mtetra
.654 .773 .936 r
.72063 .56835 .72531 .5733 .7356 .57037 .73094 .56534 Mtetra
.661 .772 .932 r
.73094 .56534 .7356 .57037 .74592 .56732 .74128 .56217 Mtetra
.667 .771 .927 r
.74128 .56217 .74592 .56732 .75627 .56412 .75165 .55884 Mtetra
.672 .768 .922 r
.75165 .55884 .75627 .56412 .76665 .56081 .76204 .55538 Mtetra
.674 .763 .918 r
.76204 .55538 .76665 .56081 .77705 .55742 .77247 .55185 Mtetra
.675 .759 .914 r
.77247 .55185 .77705 .55742 .78749 .55399 .78293 .5483 Mtetra
.673 .755 .912 r
.78293 .5483 .78749 .55399 .79797 .55056 .79343 .54478 Mtetra
.671 .751 .911 r
.79343 .54478 .79797 .55056 .80849 .54715 .80397 .54132 Mtetra
.667 .749 .912 r
.80397 .54132 .80849 .54715 .81904 .5438 .81456 .53795 Mtetra
.664 .748 .913 r
.81456 .53795 .81904 .5438 .82965 .5405 .82519 .53466 Mtetra
.661 .748 .915 r
.82519 .53466 .82965 .5405 .84029 .53727 .83586 .53144 Mtetra
.658 .748 .916 r
.83586 .53144 .84029 .53727 .85098 .53408 .84659 .52828 Mtetra
.656 .749 .918 r
.84659 .52828 .85098 .53408 .86171 .53093 .85735 .52515 Mtetra
.655 .75 .92 r
.85735 .52515 .86171 .53093 .87249 .52781 .86816 .52204 Mtetra
.654 .751 .921 r
.86816 .52204 .87249 .52781 .88331 .5247 .87901 .51893 Mtetra
.654 .752 .922 r
.87901 .51893 .88331 .5247 .89417 .5216 .8899 .51581 Mtetra
.8899 .51581 .89417 .5216 .90507 .51848 .90083 .51269 Mtetra
.654 .753 .922 r
.90083 .51269 .90507 .51848 .91601 .51536 .91181 .50954 Mtetra
.91181 .50954 .91601 .51536 .927 .51223 .92282 .50638 Mtetra
.655 .752 .922 r
.92282 .50638 .927 .51223 .93802 .50908 .93387 .5032 Mtetra
.655 .752 .921 r
.93387 .5032 .93802 .50908 .94909 .50592 .94497 .50001 Mtetra
.94497 .50001 .94909 .50592 .9602 .50275 .9561 .4968 Mtetra
.656 .751 .92 r
.35813 .66383 .36369 .66869 .37275 .66604 .3672 .66119 Mtetra
.656 .752 .921 r
.3672 .66119 .37275 .66604 .38183 .66338 .3763 .65853 Mtetra
.656 .753 .921 r
.3763 .65853 .38183 .66338 .39095 .66071 .38544 .65586 Mtetra
.656 .754 .922 r
.38544 .65586 .39095 .66071 .40009 .65803 .3946 .65317 Mtetra
.657 .754 .922 r
.3946 .65317 .40009 .65803 .40927 .65533 .4038 .65047 Mtetra
.657 .755 .922 r
.4038 .65047 .40927 .65533 .41848 .65261 .41303 .64774 Mtetra
.658 .755 .922 r
.41303 .64774 .41848 .65261 .42772 .64989 .42229 .64499 Mtetra
.42229 .64499 .42772 .64989 .437 .64716 .43159 .64223 Mtetra
.658 .754 .921 r
.43159 .64223 .437 .64716 .4463 .64444 .44091 .63945 Mtetra
.657 .753 .92 r
.44091 .63945 .4463 .64444 .45563 .64174 .45027 .63669 Mtetra
.656 .751 .919 r
.45027 .63669 .45563 .64174 .465 .63907 .45966 .63394 Mtetra
.654 .748 .919 r
.45966 .63394 .465 .63907 .4744 .63645 .46908 .63125 Mtetra
.65 .744 .918 r
.46908 .63125 .4744 .63645 .48383 .63391 .47853 .62863 Mtetra
.646 .741 .918 r
.47853 .62863 .48383 .63391 .49329 .63145 .48801 .62611 Mtetra
.64 .738 .919 r
.48801 .62611 .49329 .63145 .50279 .62907 .49753 .62371 Mtetra
.636 .736 .921 r
.49753 .62371 .50279 .62907 .51232 .62676 .50708 .62142 Mtetra
.631 .736 .923 r
.50708 .62142 .51232 .62676 .52189 .62448 .51667 .61921 Mtetra
.629 .739 .926 r
.51667 .61921 .52189 .62448 .53149 .62218 .52629 .61702 Mtetra
.63 .744 .93 r
.52629 .61702 .53149 .62218 .54113 .61982 .53595 .6148 Mtetra
.634 .751 .933 r
.53595 .6148 .54113 .61982 .55081 .61734 .54565 .61245 Mtetra
.64 .76 .935 r
.54565 .61245 .55081 .61734 .56052 .61469 .55539 .60993 Mtetra
.648 .768 .936 r
.55539 .60993 .56052 .61469 .57026 .61189 .56516 .60721 Mtetra
.656 .774 .936 r
.56516 .60721 .57026 .61189 .58004 .60893 .57496 .60429 Mtetra
.662 .778 .935 r
.57496 .60429 .58004 .60893 .58984 .60586 .58479 .60121 Mtetra
.666 .78 .934 r
.58479 .60121 .58984 .60586 .59968 .60271 .59465 .59803 Mtetra
.667 .78 .933 r
.59465 .59803 .59968 .60271 .60955 .59955 .60455 .59481 Mtetra
.666 .778 .933 r
.60455 .59481 .60955 .59955 .61946 .59641 .61448 .59161 Mtetra
.663 .775 .933 r
.61448 .59161 .61946 .59641 .6294 .59333 .62445 .58848 Mtetra
.659 .773 .933 r
.62445 .58848 .6294 .59333 .63938 .59034 .63445 .58545 Mtetra
.653 .77 .935 r
.63445 .58545 .63938 .59034 .6494 .58743 .64449 .58252 Mtetra
.648 .768 .937 r
.64449 .58252 .6494 .58743 .65946 .58462 .65458 .57971 Mtetra
.643 .768 .939 r
.65458 .57971 .65946 .58462 .66955 .58189 .6647 .577 Mtetra
.639 .768 .941 r
.6647 .577 .66955 .58189 .67969 .57922 .67487 .57436 Mtetra
.637 .769 .943 r
.67487 .57436 .67969 .57922 .68987 .57658 .68508 .57173 Mtetra
.638 .771 .943 r
.68508 .57173 .68987 .57658 .70009 .57392 .69532 .56907 Mtetra
.643 .773 .943 r
.69532 .56907 .70009 .57392 .71034 .57119 .7056 .56631 Mtetra
.649 .775 .94 r
.7056 .56631 .71034 .57119 .72063 .56835 .71591 .56339 Mtetra
.658 .775 .936 r
.71591 .56339 .72063 .56835 .73094 .56534 .72625 .56026 Mtetra
.666 .774 .93 r
.72625 .56026 .73094 .56534 .74128 .56217 .73661 .55693 Mtetra
.674 .77 .923 r
.73661 .55693 .74128 .56217 .75165 .55884 .74699 .55341 Mtetra
.678 .766 .917 r
.74699 .55341 .75165 .55884 .76204 .55538 .7574 .54978 Mtetra
.679 .76 .912 r
.7574 .54978 .76204 .55538 .77247 .55185 .76785 .5461 Mtetra
.678 .755 .909 r
.76785 .5461 .77247 .55185 .78293 .5483 .77833 .54243 Mtetra
.675 .75 .908 r
.77833 .54243 .78293 .5483 .79343 .54478 .78885 .53886 Mtetra
.671 .748 .908 r
.78885 .53886 .79343 .54478 .80397 .54132 .79942 .53538 Mtetra
.666 .746 .91 r
.79942 .53538 .80397 .54132 .81456 .53795 .81004 .53203 Mtetra
.662 .746 .913 r
.81004 .53203 .81456 .53795 .82519 .53466 .8207 .52878 Mtetra
.658 .747 .915 r
.8207 .52878 .82519 .53466 .83586 .53144 .83141 .5256 Mtetra
.656 .748 .918 r
.83141 .5256 .83586 .53144 .84659 .52828 .84217 .52248 Mtetra
.654 .75 .92 r
.84217 .52248 .84659 .52828 .85735 .52515 .85296 .51938 Mtetra
.653 .751 .922 r
.85296 .51938 .85735 .52515 .86816 .52204 .86381 .51628 Mtetra
.653 .753 .923 r
.86381 .51628 .86816 .52204 .87901 .51893 .87469 .51317 Mtetra
.654 .754 .923 r
.87469 .51317 .87901 .51893 .8899 .51581 .88561 .51004 Mtetra
.88561 .51004 .8899 .51581 .90083 .51269 .89657 .50689 Mtetra
.89657 .50689 .90083 .51269 .91181 .50954 .90757 .50371 Mtetra
.655 .754 .923 r
.90757 .50371 .91181 .50954 .92282 .50638 .91861 .50051 Mtetra
.655 .753 .922 r
.91861 .50051 .92282 .50638 .93387 .5032 .9297 .49729 Mtetra
.656 .753 .921 r
.9297 .49729 .93387 .5032 .94497 .50001 .94082 .49405 Mtetra
.656 .752 .921 r
.94082 .49405 .94497 .50001 .9561 .4968 .95198 .4908 Mtetra
.655 .751 .921 r
.35253 .65894 .35813 .66383 .3672 .66119 .36162 .65631 Mtetra
.655 .752 .921 r
.36162 .65631 .3672 .66119 .3763 .65853 .37074 .65366 Mtetra
.655 .753 .922 r
.37074 .65366 .3763 .65853 .38544 .65586 .37989 .651 Mtetra
.655 .754 .923 r
.37989 .651 .38544 .65586 .3946 .65317 .38908 .64832 Mtetra
.656 .755 .923 r
.38908 .64832 .3946 .65317 .4038 .65047 .39829 .64562 Mtetra
.656 .756 .924 r
.39829 .64562 .4038 .65047 .41303 .64774 .40754 .64289 Mtetra
.657 .757 .924 r
.40754 .64289 .41303 .64774 .42229 .64499 .41683 .64013 Mtetra
.658 .758 .923 r
.41683 .64013 .42229 .64499 .43159 .64223 .42614 .63734 Mtetra
.659 .757 .923 r
.42614 .63734 .43159 .64223 .44091 .63945 .43549 .63451 Mtetra
.659 .756 .922 r
.43549 .63451 .44091 .63945 .45027 .63669 .44487 .63168 Mtetra
.659 .754 .92 r
.44487 .63168 .45027 .63669 .45966 .63394 .45428 .62884 Mtetra
.658 .751 .919 r
.45428 .62884 .45966 .63394 .46908 .63125 .46372 .62604 Mtetra
.654 .746 .917 r
.46372 .62604 .46908 .63125 .47853 .62863 .47319 .62331 Mtetra
.65 .741 .917 r
.47319 .62331 .47853 .62863 .48801 .62611 .4827 .62069 Mtetra
.643 .736 .917 r
.4827 .62069 .48801 .62611 .49753 .62371 .49223 .61822 Mtetra
.636 .732 .918 r
.49223 .61822 .49753 .62371 .50708 .62142 .50181 .6159 Mtetra
.629 .73 .92 r
.50181 .6159 .50708 .62142 .51667 .61921 .51141 .61375 Mtetra
.624 .731 .923 r
.51141 .61375 .51667 .61921 .52629 .61702 .52106 .61167 Mtetra
.622 .735 .928 r
.52106 .61167 .52629 .61702 .53595 .6148 .53074 .60961 Mtetra
.625 .743 .932 r
.53074 .60961 .53595 .6148 .54565 .61245 .54046 .60745 Mtetra
.632 .754 .935 r
.54046 .60745 .54565 .61245 .55539 .60993 .55022 .6051 Mtetra
.641 .764 .938 r
.55022 .6051 .55539 .60993 .56516 .60721 .56001 .60252 Mtetra
.651 .774 .938 r
.56001 .60252 .56516 .60721 .57496 .60429 .56984 .59968 Mtetra
.659 .781 .938 r
.56984 .59968 .57496 .60429 .58479 .60121 .5797 .59664 Mtetra
.666 .784 .937 r
.5797 .59664 .58479 .60121 .59465 .59803 .58959 .59344 Mtetra
.668 .785 .936 r
.58959 .59344 .59465 .59803 .60455 .59481 .59951 .59017 Mtetra
.667 .784 .936 r
.59951 .59017 .60455 .59481 .61448 .59161 .60947 .58692 Mtetra
.664 .781 .936 r
.60947 .58692 .61448 .59161 .62445 .58848 .61946 .58373 Mtetra
.659 .778 .937 r
.61946 .58373 .62445 .58848 .63445 .58545 .62949 .58066 Mtetra
.653 .775 .939 r
.62949 .58066 .63445 .58545 .64449 .58252 .63956 .57771 Mtetra
.646 .773 .941 r
.63956 .57771 .64449 .58252 .65458 .57971 .64967 .57491 Mtetra
.64 .772 .943 r
.64967 .57491 .65458 .57971 .6647 .577 .65982 .57221 Mtetra
.636 .772 .945 r
.65982 .57221 .6647 .577 .67487 .57436 .67002 .56959 Mtetra
.635 .774 .947 r
.67002 .56959 .67487 .57436 .68508 .57173 .68026 .56697 Mtetra
.637 .776 .947 r
.68026 .56697 .68508 .57173 .69532 .56907 .69053 .56429 Mtetra
.644 .778 .945 r
.69053 .56429 .69532 .56907 .7056 .56631 .70083 .56146 Mtetra
.653 .779 .941 r
.70083 .56146 .7056 .56631 .71591 .56339 .71116 .55841 Mtetra
.665 .778 .934 r
.71116 .55841 .71591 .56339 .72625 .56026 .72152 .55511 Mtetra
.674 .775 .926 r
.72152 .55511 .72625 .56026 .73661 .55693 .73189 .55156 Mtetra
.681 .77 .918 r
.73189 .55156 .73661 .55693 .74699 .55341 .74229 .54782 Mtetra
.685 .763 .911 r
.74229 .54782 .74699 .55341 .7574 .54978 .75272 .54397 Mtetra
.684 .756 .906 r
.75272 .54397 .7574 .54978 .76785 .5461 .76318 .54014 Mtetra
.68 .75 .904 r
.76318 .54014 .76785 .5461 .77833 .54243 .77368 .53639 Mtetra
.674 .745 .904 r
.77368 .53639 .77833 .54243 .78885 .53886 .78423 .53279 Mtetra
.669 .743 .906 r
.78423 .53279 .78885 .53886 .79942 .53538 .79483 .52935 Mtetra
.663 .743 .909 r
.79483 .52935 .79942 .53538 .81004 .53203 .80548 .52606 Mtetra
.658 .744 .913 r
.80548 .52606 .81004 .53203 .8207 .52878 .81618 .52288 Mtetra
.655 .746 .917 r
.81618 .52288 .8207 .52878 .83141 .5256 .82693 .51978 Mtetra
.652 .749 .92 r
.82693 .51978 .83141 .5256 .84217 .52248 .83772 .51671 Mtetra
.652 .752 .923 r
.83772 .51671 .84217 .52248 .85296 .51938 .84856 .51364 Mtetra
.652 .754 .924 r
.84856 .51364 .85296 .51938 .86381 .51628 .85943 .51055 Mtetra
.653 .755 .925 r
.85943 .51055 .86381 .51628 .87469 .51317 .87034 .50743 Mtetra
.653 .756 .925 r
.87034 .50743 .87469 .51317 .88561 .51004 .88129 .50428 Mtetra
.654 .756 .925 r
.88129 .50428 .88561 .51004 .89657 .50689 .89228 .50109 Mtetra
.655 .756 .924 r
.89228 .50109 .89657 .50689 .90757 .50371 .90331 .49787 Mtetra
.656 .755 .923 r
.90331 .49787 .90757 .50371 .91861 .50051 .91438 .49462 Mtetra
.656 .755 .922 r
.91438 .49462 .91861 .50051 .9297 .49729 .92549 .49135 Mtetra
.656 .754 .922 r
.92549 .49135 .9297 .49729 .94082 .49405 .93664 .48806 Mtetra
.657 .753 .921 r
.93664 .48806 .94082 .49405 .95198 .4908 .94784 .48476 Mtetra
.654 .751 .921 r
.34689 .65403 .35253 .65894 .36162 .65631 .356 .6514 Mtetra
.653 .752 .922 r
.356 .6514 .36162 .65631 .37074 .65366 .36514 .64876 Mtetra
.654 .753 .923 r
.36514 .64876 .37074 .65366 .37989 .651 .37431 .64611 Mtetra
.654 .754 .923 r
.37431 .64611 .37989 .651 .38908 .64832 .38352 .64345 Mtetra
.654 .755 .924 r
.38352 .64345 .38908 .64832 .39829 .64562 .39275 .64076 Mtetra
.655 .757 .925 r
.39275 .64076 .39829 .64562 .40754 .64289 .40202 .63804 Mtetra
.656 .758 .925 r
.40202 .63804 .40754 .64289 .41683 .64013 .41132 .63528 Mtetra
.658 .759 .925 r
.41132 .63528 .41683 .64013 .42614 .63734 .42066 .63248 Mtetra
.66 .76 .924 r
.42066 .63248 .42614 .63734 .43549 .63451 .43002 .62963 Mtetra
.661 .76 .923 r
.43002 .62963 .43549 .63451 .44487 .63168 .43943 .62673 Mtetra
.662 .759 .922 r
.43943 .62673 .44487 .63168 .45428 .62884 .44886 .6238 Mtetra
.662 .756 .92 r
.44886 .6238 .45428 .62884 .46372 .62604 .45832 .62088 Mtetra
.66 .751 .918 r
.45832 .62088 .46372 .62604 .47319 .62331 .46782 .618 Mtetra
.655 .745 .916 r
.46782 .618 .47319 .62331 .4827 .62069 .47735 .61523 Mtetra
.648 .738 .915 r
.47735 .61523 .4827 .62069 .49223 .61822 .48691 .61263 Mtetra
.639 .731 .915 r
.48691 .61263 .49223 .61822 .50181 .6159 .4965 .61024 Mtetra
.629 .725 .917 r
.4965 .61024 .50181 .6159 .51141 .61375 .50613 .60808 Mtetra
.621 .723 .92 r
.50613 .60808 .51141 .61375 .52106 .61167 .51579 .60609 Mtetra
.615 .725 .924 r
.51579 .60609 .52106 .61167 .53074 .60961 .52549 .6042 Mtetra
.615 .733 .93 r
.52549 .6042 .53074 .60961 .54046 .60745 .53524 .60226 Mtetra
.621 .744 .935 r
.53524 .60226 .54046 .60745 .55022 .6051 .54502 .60015 Mtetra
.631 .758 .938 r
.54502 .60015 .55022 .6051 .56001 .60252 .55484 .59778 Mtetra
.644 .771 .94 r
.55484 .59778 .56001 .60252 .56984 .59968 .56469 .59509 Mtetra
.655 .781 .941 r
.56469 .59509 .56984 .59968 .5797 .59664 .57458 .59213 Mtetra
.663 .788 .941 r
.57458 .59213 .5797 .59664 .58959 .59344 .58449 .58894 Mtetra
.667 .79 .94 r
.58449 .58894 .58959 .59344 .59951 .59017 .59444 .58566 Mtetra
.668 .79 .94 r
.59444 .58566 .59951 .59017 .60947 .58692 .60442 .58235 Mtetra
.664 .788 .94 r
.60442 .58235 .60947 .58692 .61946 .58373 .61444 .57911 Mtetra
.659 .785 .942 r
.61444 .57911 .61946 .58373 .62949 .58066 .6245 .576 Mtetra
.651 .782 .944 r
.6245 .576 .62949 .58066 .63956 .57771 .6346 .57304 Mtetra
.644 .78 .946 r
.6346 .57304 .63956 .57771 .64967 .57491 .64473 .57023 Mtetra
.637 .778 .949 r
.64473 .57023 .64967 .57491 .65982 .57221 .65492 .56755 Mtetra
.633 .778 .951 r
.65492 .56755 .65982 .57221 .67002 .56959 .66514 .56494 Mtetra
.633 .78 .951 r
.66514 .56494 .67002 .56959 .68026 .56697 .6754 .56231 Mtetra
.637 .781 .95 r
.6754 .56231 .68026 .56697 .69053 .56429 .6857 .55958 Mtetra
.648 .783 .946 r
.6857 .55958 .69053 .56429 .70083 .56146 .69603 .55662 Mtetra
.66 .783 .939 r
.69603 .55662 .70083 .56146 .71116 .55841 .70638 .55339 Mtetra
.674 .78 .93 r
.70638 .55339 .71116 .55841 .72152 .55511 .71675 .54983 Mtetra
.684 .775 .92 r
.71675 .54983 .72152 .55511 .73189 .55156 .72714 .546 Mtetra
.69 .766 .91 r
.72714 .546 .73189 .55156 .74229 .54782 .73755 .542 Mtetra
.691 .758 .903 r
.73755 .542 .74229 .54782 .75272 .54397 .74799 .53794 Mtetra
.687 .75 .899 r
.74799 .53794 .75272 .54397 .76318 .54014 .75847 .53398 Mtetra
.681 .744 .899 r
.75847 .53398 .76318 .54014 .77368 .53639 .769 .53018 Mtetra
.672 .74 .901 r
.769 .53018 .77368 .53639 .78423 .53279 .77958 .52663 Mtetra
.664 .739 .906 r
.77958 .52663 .78423 .53279 .79483 .52935 .79022 .52328 Mtetra
.658 .741 .911 r
.79022 .52328 .79483 .52935 .80548 .52606 .80091 .5201 Mtetra
.653 .744 .917 r
.80091 .5201 .80548 .52606 .81618 .52288 .81165 .51704 Mtetra
.65 .748 .921 r
.81165 .51704 .81618 .52288 .82693 .51978 .82243 .51402 Mtetra
.649 .752 .924 r
.82243 .51402 .82693 .51978 .83772 .51671 .83326 .51101 Mtetra
.65 .755 .926 r
.83326 .51101 .83772 .51671 .84856 .51364 .84412 .50796 Mtetra
.651 .757 .927 r
.84412 .50796 .84856 .51364 .85943 .51055 .85503 .50486 Mtetra
.653 .758 .927 r
.85503 .50486 .85943 .51055 .87034 .50743 .86597 .50171 Mtetra
.654 .758 .926 r
.86597 .50171 .87034 .50743 .88129 .50428 .87695 .49851 Mtetra
.655 .758 .925 r
.87695 .49851 .88129 .50428 .89228 .50109 .88797 .49527 Mtetra
.656 .757 .924 r
.88797 .49527 .89228 .50109 .90331 .49787 .89902 .49199 Mtetra
.657 .756 .923 r
.89902 .49199 .90331 .49787 .91438 .49462 .91012 .48869 Mtetra
.657 .755 .922 r
.91012 .48869 .91438 .49462 .92549 .49135 .92126 .48537 Mtetra
.658 .754 .921 r
.92126 .48537 .92549 .49135 .93664 .48806 .93244 .48203 Mtetra
.658 .753 .92 r
.93244 .48203 .93664 .48806 .94784 .48476 .94366 .47868 Mtetra
.653 .751 .922 r
.34122 .64908 .34689 .65403 .356 .6514 .35035 .64645 Mtetra
.652 .751 .922 r
.35035 .64645 .356 .6514 .36514 .64876 .35951 .64382 Mtetra
.652 .752 .923 r
.35951 .64382 .36514 .64876 .37431 .64611 .3687 .64119 Mtetra
.652 .753 .924 r
.3687 .64119 .37431 .64611 .38352 .64345 .37792 .63853 Mtetra
.653 .755 .925 r
.37792 .63853 .38352 .64345 .39275 .64076 .38717 .63587 Mtetra
.653 .757 .925 r
.38717 .63587 .39275 .64076 .40202 .63804 .39646 .63318 Mtetra
.654 .758 .926 r
.39646 .63318 .40202 .63804 .41132 .63528 .40578 .63044 Mtetra
.656 .761 .927 r
.40578 .63044 .41132 .63528 .42066 .63248 .41514 .62766 Mtetra
.658 .763 .927 r
.41514 .62766 .42066 .63248 .43002 .62963 .42452 .62481 Mtetra
.661 .764 .926 r
.42452 .62481 .43002 .62963 .43943 .62673 .43395 .62188 Mtetra
.664 .764 .925 r
.43395 .62188 .43943 .62673 .44886 .6238 .4434 .61888 Mtetra
.666 .762 .922 r
.4434 .61888 .44886 .6238 .45832 .62088 .45289 .61583 Mtetra
.666 .758 .919 r
.45289 .61583 .45832 .62088 .46782 .618 .46241 .61278 Mtetra
.662 .751 .916 r
.46241 .61278 .46782 .618 .47735 .61523 .47197 .60981 Mtetra
.656 .743 .914 r
.47197 .60981 .47735 .61523 .48691 .61263 .48155 .607 Mtetra
.645 .732 .912 r
.48155 .607 .48691 .61263 .4965 .61024 .49116 .60444 Mtetra
.632 .723 .913 r
.49116 .60444 .4965 .61024 .50613 .60808 .50081 .60221 Mtetra
.62 .716 .915 r
.50081 .60221 .50613 .60808 .51579 .60609 .51049 .60025 Mtetra
.608 .714 .92 r
.51049 .60025 .51579 .60609 .52549 .6042 .52021 .59853 Mtetra
.605 .72 .926 r
.52021 .59853 .52549 .6042 .53524 .60226 .52998 .59684 Mtetra
.607 .731 .933 r
.52998 .59684 .53524 .60226 .54502 .60015 .53978 .59504 Mtetra
.617 .748 .939 r
.53978 .59504 .54502 .60015 .55484 .59778 .54963 .59295 Mtetra
.632 .765 .943 r
.54963 .59295 .55484 .59778 .56469 .59509 .55951 .59049 Mtetra
.646 .78 .945 r
.55951 .59049 .56469 .59509 .57458 .59213 .56942 .58768 Mtetra
.659 .791 .945 r
.56942 .58768 .57458 .59213 .58449 .58894 .57936 .58457 Mtetra
.665 .796 .945 r
.57936 .58457 .58449 .58894 .59444 .58566 .58934 .58129 Mtetra
.667 .798 .945 r
.58934 .58129 .59444 .58566 .60442 .58235 .59935 .57795 Mtetra
.664 .797 .946 r
.59935 .57795 .60442 .58235 .61444 .57911 .6094 .57467 Mtetra
.658 .794 .947 r
.6094 .57467 .61444 .57911 .6245 .576 .61948 .57152 Mtetra
.65 .791 .95 r
.61948 .57152 .6245 .576 .6346 .57304 .6296 .56854 Mtetra
.641 .788 .952 r
.6296 .56854 .6346 .57304 .64473 .57023 .63977 .56573 Mtetra
.634 .786 .955 r
.63977 .56573 .64473 .57023 .65492 .56755 .64998 .56306 Mtetra
.63 .786 .957 r
.64998 .56306 .65492 .56755 .66514 .56494 .66023 .56044 Mtetra
.632 .787 .956 r
.66023 .56044 .66514 .56494 .6754 .56231 .67052 .55776 Mtetra
.64 .789 .953 r
.67052 .55776 .6754 .56231 .6857 .55958 .68085 .55492 Mtetra
.655 .79 .946 r
.68085 .55492 .6857 .55958 .69603 .55662 .69119 .55177 Mtetra
.671 .788 .936 r
.69119 .55177 .69603 .55662 .70638 .55339 .70156 .54827 Mtetra
.686 .782 .924 r
.70156 .54827 .70638 .55339 .71675 .54983 .71194 .54438 Mtetra
.696 .773 .911 r
.71194 .54438 .71675 .54983 .72714 .546 .72234 .5402 Mtetra
.699 .762 .901 r
.72234 .5402 .72714 .546 .73755 .542 .73276 .5359 Mtetra
.697 .751 .894 r
.73276 .5359 .73755 .542 .74799 .53794 .74322 .53163 Mtetra
.688 .742 .892 r
.74322 .53163 .74799 .53794 .75847 .53398 .75372 .52759 Mtetra
.678 .737 .895 r
.75372 .52759 .75847 .53398 .769 .53018 .76428 .52383 Mtetra
.667 .735 .9 r
.76428 .52383 .769 .53018 .77958 .52663 .7749 .5204 Mtetra
.657 .736 .908 r
.7749 .5204 .77958 .52663 .79022 .52328 .78558 .51723 Mtetra
.65 .74 .915 r
.78558 .51723 .79022 .52328 .80091 .5201 .79631 .51422 Mtetra
.646 .746 .922 r
.79631 .51422 .80091 .5201 .81165 .51704 .80709 .5113 Mtetra
.645 .752 .927 r
.80709 .5113 .81165 .51704 .82243 .51402 .81791 .50837 Mtetra
.646 .756 .929 r
.81791 .50837 .82243 .51402 .83326 .51101 .82877 .50539 Mtetra
.649 .76 .93 r
.82877 .50539 .83326 .51101 .84412 .50796 .83967 .50233 Mtetra
.651 .761 .93 r
.83967 .50233 .84412 .50796 .85503 .50486 .8506 .4992 Mtetra
.654 .761 .929 r
.8506 .4992 .85503 .50486 .86597 .50171 .86157 .49599 Mtetra
.656 .761 .927 r
.86157 .49599 .86597 .50171 .87695 .49851 .87258 .49272 Mtetra
.657 .759 .925 r
.87258 .49272 .87695 .49851 .88797 .49527 .88362 .48941 Mtetra
.658 .758 .924 r
.88362 .48941 .88797 .49527 .89902 .49199 .8947 .48607 Mtetra
.658 .757 .923 r
.8947 .48607 .89902 .49199 .91012 .48869 .90583 .48272 Mtetra
.658 .755 .922 r
.90583 .48272 .91012 .48869 .92126 .48537 .91699 .47934 Mtetra
.659 .754 .921 r
.91699 .47934 .92126 .48537 .93244 .48203 .9282 .47595 Mtetra
.658 .753 .92 r
.9282 .47595 .93244 .48203 .94366 .47868 .93945 .47256 Mtetra
.652 .751 .922 r
.33552 .6441 .34122 .64908 .35035 .64645 .34466 .64146 Mtetra
.34466 .64146 .35035 .64645 .35951 .64382 .35384 .63883 Mtetra
.652 .751 .923 r
.35384 .63883 .35951 .64382 .3687 .64119 .36305 .6362 Mtetra
.651 .752 .923 r
.36305 .6362 .3687 .64119 .37792 .63853 .37229 .63355 Mtetra
.651 .753 .924 r
.37229 .63355 .37792 .63853 .38717 .63587 .38156 .63091 Mtetra
.651 .754 .925 r
.38156 .63091 .38717 .63587 .39646 .63318 .39086 .62825 Mtetra
.652 .756 .926 r
.39086 .62825 .39646 .63318 .40578 .63044 .4002 .62556 Mtetra
.653 .759 .927 r
.4002 .62556 .40578 .63044 .41514 .62766 .40958 .62282 Mtetra
.656 .762 .928 r
.40958 .62282 .41514 .62766 .42452 .62481 .41899 .62001 Mtetra
.66 .766 .928 r
.41899 .62001 .42452 .62481 .43395 .62188 .42843 .6171 Mtetra
.664 .768 .927 r
.42843 .6171 .43395 .62188 .4434 .61888 .43791 .61406 Mtetra
.668 .769 .925 r
.43791 .61406 .4434 .61888 .45289 .61583 .44742 .61093 Mtetra
.672 .767 .922 r
.44742 .61093 .45289 .61583 .46241 .61278 .45697 .60771 Mtetra
.67 .761 .918 r
.45697 .60771 .46241 .61278 .47197 .60981 .46655 .60451 Mtetra
.666 .752 .914 r
.46655 .60451 .47197 .60981 .48155 .607 .47615 .60142 Mtetra
.655 .739 .911 r
.47615 .60142 .48155 .607 .49116 .60444 .48579 .59861 Mtetra
.639 .725 .91 r
.48579 .59861 .49116 .60444 .50081 .60221 .49546 .59618 Mtetra
.622 .713 .911 r
.49546 .59618 .50081 .60221 .51049 .60025 .50516 .59416 Mtetra
.604 .705 .915 r
.50516 .59416 .51049 .60025 .52021 .59853 .5149 .59254 Mtetra
.594 .706 .921 r
.5149 .59254 .52021 .59853 .52998 .59684 .52468 .5911 Mtetra
.592 .715 .929 r
.52468 .5911 .52998 .59684 .53978 .59504 .53451 .58965 Mtetra
.6 .732 .937 r
.53451 .58965 .53978 .59504 .54963 .59295 .54438 .58794 Mtetra
.617 .754 .943 r
.54438 .58794 .54963 .59295 .55951 .59049 .55428 .58581 Mtetra
.634 .774 .948 r
.55428 .58581 .55951 .59049 .56942 .58768 .56422 .58325 Mtetra
.651 .79 .949 r
.56422 .58325 .56942 .58768 .57936 .58457 .5742 .58028 Mtetra
.66 .8 .95 r
.5742 .58028 .57936 .58457 .58934 .58129 .5842 .57707 Mtetra
.665 .805 .95 r
.5842 .57707 .58934 .58129 .59935 .57795 .59424 .57374 Mtetra
.663 .805 .952 r
.59424 .57374 .59935 .57795 .6094 .57467 .60432 .57043 Mtetra
.656 .804 .954 r
.60432 .57043 .6094 .57467 .61948 .57152 .61443 .56726 Mtetra
.647 .801 .957 r
.61443 .56726 .61948 .57152 .6296 .56854 .62458 .56426 Mtetra
.637 .798 .959 r
.62458 .56426 .6296 .56854 .63977 .56573 .63478 .56144 Mtetra
.63 .796 .962 r
.63478 .56144 .63977 .56573 .64998 .56306 .64502 .55875 Mtetra
.628 .795 .962 r
.64502 .55875 .64998 .56306 .66023 .56044 .6553 .55609 Mtetra
.634 .796 .96 r
.6553 .55609 .66023 .56044 .67052 .55776 .66561 .55331 Mtetra
.647 .796 .954 r
.66561 .55331 .67052 .55776 .68085 .55492 .67596 .55028 Mtetra
.667 .795 .944 r
.67596 .55028 .68085 .55492 .69119 .55177 .68632 .54684 Mtetra
.685 .79 .929 r
.68632 .54684 .69119 .55177 .70156 .54827 .6967 .54296 Mtetra
.7 .78 .913 r
.6967 .54296 .70156 .54827 .71194 .54438 .70709 .53865 Mtetra
.708 .768 .899 r
.70709 .53865 .71194 .54438 .72234 .5402 .71749 .53407 Mtetra
.706 .754 .889 r
.71749 .53407 .72234 .5402 .73276 .5359 .72792 .52948 Mtetra
.699 .743 .885 r
.72792 .52948 .73276 .5359 .74322 .53163 .7384 .52506 Mtetra
.686 .734 .887 r
.7384 .52506 .74322 .53163 .75372 .52759 .74893 .52105 Mtetra
.672 .731 .894 r
.74893 .52105 .75372 .52759 .76428 .52383 .75953 .51744 Mtetra
.658 .731 .903 r
.75953 .51744 .76428 .52383 .7749 .5204 .77019 .51424 Mtetra
.647 .736 .914 r
.77019 .51424 .7749 .5204 .78558 .51723 .78092 .51131 Mtetra
.642 .743 .923 r
.78092 .51131 .78558 .51723 .79631 .51422 .79169 .5085 Mtetra
.639 .75 .929 r
.79169 .5085 .79631 .51422 .80709 .5113 .80251 .50571 Mtetra
.641 .757 .933 r
.80251 .50571 .80709 .5113 .81791 .50837 .81337 .50282 Mtetra
.645 .761 .934 r
.81337 .50282 .81791 .50837 .82877 .50539 .82427 .49984 Mtetra
.65 .764 .933 r
.82427 .49984 .82877 .50539 .83967 .50233 .83519 .49672 Mtetra
.653 .764 .931 r
.83519 .49672 .83967 .50233 .8506 .4992 .84615 .49351 Mtetra
.656 .763 .928 r
.84615 .49351 .8506 .4992 .86157 .49599 .85714 .49021 Mtetra
.658 .761 .926 r
.85714 .49021 .86157 .49599 .87258 .49272 .86817 .48686 Mtetra
.659 .759 .924 r
.86817 .48686 .87258 .49272 .88362 .48941 .87924 .48348 Mtetra
.659 .757 .922 r
.87924 .48348 .88362 .48941 .8947 .48607 .89035 .48007 Mtetra
.659 .756 .921 r
.89035 .48007 .8947 .48607 .90583 .48272 .9015 .47666 Mtetra
.659 .754 .92 r
.9015 .47666 .90583 .48272 .91699 .47934 .9127 .47324 Mtetra
.9127 .47324 .91699 .47934 .9282 .47595 .92393 .46982 Mtetra
.659 .753 .92 r
.92393 .46982 .9282 .47595 .93945 .47256 .93521 .46639 Mtetra
.653 .751 .922 r
.32977 .63908 .33552 .6441 .34466 .64146 .33894 .63643 Mtetra
.652 .75 .922 r
.33894 .63643 .34466 .64146 .35384 .63883 .34813 .63377 Mtetra
.34813 .63377 .35384 .63883 .36305 .6362 .35736 .63112 Mtetra
.651 .75 .922 r
.35736 .63112 .36305 .6362 .37229 .63355 .36662 .62847 Mtetra
.65 .75 .923 r
.36662 .62847 .37229 .63355 .38156 .63091 .37591 .62584 Mtetra
.649 .751 .924 r
.37591 .62584 .38156 .63091 .39086 .62825 .38524 .62321 Mtetra
.649 .753 .925 r
.38524 .62321 .39086 .62825 .4002 .62556 .39459 .62058 Mtetra
.65 .756 .927 r
.39459 .62058 .4002 .62556 .40958 .62282 .40398 .61791 Mtetra
.651 .76 .929 r
.40398 .61791 .40958 .62282 .41899 .62001 .41341 .61518 Mtetra
.655 .765 .93 r
.41341 .61518 .41899 .62001 .42843 .6171 .42287 .61235 Mtetra
.661 .77 .93 r
.42287 .61235 .42843 .6171 .43791 .61406 .43237 .60937 Mtetra
.668 .775 .93 r
.43237 .60937 .43791 .61406 .44742 .61093 .44191 .60621 Mtetra
.676 .776 .926 r
.44191 .60621 .44742 .61093 .45697 .60771 .45148 .60287 Mtetra
.679 .773 .922 r
.45148 .60287 .45697 .60771 .46655 .60451 .46109 .59944 Mtetra
.678 .765 .916 r
.46109 .59944 .46655 .60451 .47615 .60142 .47072 .59601 Mtetra
.669 .75 .911 r
.47072 .59601 .47615 .60142 .48579 .59861 .48038 .59282 Mtetra
.652 .732 .908 r
.48038 .59282 .48579 .59861 .49546 .59618 .49008 .59004 Mtetra
.631 .714 .906 r
.49008 .59004 .49546 .59618 .50516 .59416 .4998 .58781 Mtetra
.604 .697 .909 r
.4998 .58781 .50516 .59416 .5149 .59254 .50956 .5862 Mtetra
.587 .691 .914 r
.50956 .5862 .5149 .59254 .52468 .5911 .51935 .58495 Mtetra
.575 .695 .923 r
.51935 .58495 .52468 .5911 .53451 .58965 .5292 .5839 Mtetra
.58 .712 .933 r
.5292 .5839 .53451 .58965 .54438 .58794 .53909 .58265 Mtetra
.595 .737 .943 r
.53909 .58265 .54438 .58794 .55428 .58581 .54902 .58098 Mtetra
.615 .763 .95 r
.54902 .58098 .55428 .58581 .56422 .58325 .55899 .57879 Mtetra
.638 .787 .953 r
.55899 .57879 .56422 .58325 .5742 .58028 .569 .57607 Mtetra
.651 .802 .955 r
.569 .57607 .5742 .58028 .5842 .57707 .57903 .57301 Mtetra
.659 .812 .957 r
.57903 .57301 .5842 .57707 .59424 .57374 .5891 .56973 Mtetra
.659 .815 .958 r
.5891 .56973 .59424 .57374 .60432 .57043 .59921 .56643 Mtetra
.653 .815 .961 r
.59921 .56643 .60432 .57043 .61443 .56726 .60935 .56324 Mtetra
.643 .812 .964 r
.60935 .56324 .61443 .56726 .62458 .56426 .61953 .56023 Mtetra
.634 .809 .967 r
.61953 .56023 .62458 .56426 .63478 .56144 .62976 .55739 Mtetra
.627 .807 .969 r
.62976 .55739 .63478 .56144 .64502 .55875 .64002 .55465 Mtetra
.628 .806 .968 r
.64002 .55465 .64502 .55875 .6553 .55609 .65033 .55189 Mtetra
.64 .806 .963 r
.65033 .55189 .6553 .55609 .66561 .55331 .66067 .54893 Mtetra
.658 .805 .953 r
.66067 .54893 .66561 .55331 .67596 .55028 .67103 .54561 Mtetra
.683 .8 .937 r
.67103 .54561 .67596 .55028 .68632 .54684 .68141 .54175 Mtetra
.703 .79 .919 r
.68141 .54175 .68632 .54684 .6967 .54296 .69179 .53737 Mtetra
.716 .776 .9 r
.69179 .53737 .6967 .54296 .70709 .53865 .70218 .53255 Mtetra
.719 .759 .885 r
.70218 .53255 .70709 .53865 .71749 .53407 .71259 .52753 Mtetra
.711 .743 .877 r
.71259 .52753 .71749 .53407 .72792 .52948 .72303 .52269 Mtetra
.698 .732 .877 r
.72303 .52269 .72792 .52948 .7384 .52506 .73353 .51822 Mtetra
.679 .724 .884 r
.73353 .51822 .7384 .52506 .74893 .52105 .7441 .51438 Mtetra
.661 .724 .896 r
.7441 .51438 .74893 .52105 .75953 .51744 .75475 .51109 Mtetra
.645 .729 .91 r
.75475 .51109 .75953 .51744 .77019 .51424 .76547 .50824 Mtetra
.633 .738 .923 r
.76547 .50824 .77019 .51424 .78092 .51131 .77624 .50562 Mtetra
.631 .749 .933 r
.77624 .50562 .78092 .51131 .79169 .5085 .78707 .503 Mtetra
.633 .758 .938 r
.78707 .503 .79169 .5085 .80251 .50571 .79793 .5003 Mtetra
.64 .766 .939 r
.79793 .5003 .80251 .50571 .81337 .50282 .80882 .4974 Mtetra
.647 .768 .937 r
.80882 .4974 .81337 .50282 .82427 .49984 .81973 .49432 Mtetra
.653 .768 .934 r
.81973 .49432 .82427 .49984 .83519 .49672 .83068 .49109 Mtetra
.658 .766 .93 r
.83068 .49109 .83519 .49672 .84615 .49351 .84166 .48773 Mtetra
.66 .763 .926 r
.84166 .48773 .84615 .49351 .85714 .49021 .85267 .48432 Mtetra
.661 .76 .923 r
.85267 .48432 .85714 .49021 .86817 .48686 .86373 .48087 Mtetra
.661 .757 .921 r
.86373 .48087 .86817 .48686 .87924 .48348 .87482 .47741 Mtetra
.661 .755 .92 r
.87482 .47741 .87924 .48348 .89035 .48007 .88596 .47396 Mtetra
.66 .753 .919 r
.88596 .47396 .89035 .48007 .9015 .47666 .89714 .47051 Mtetra
.659 .752 .919 r
.89714 .47051 .9015 .47666 .9127 .47324 .90836 .46707 Mtetra
.90836 .46707 .9127 .47324 .92393 .46982 .91963 .46362 Mtetra
.91963 .46362 .92393 .46982 .93521 .46639 .93095 .46018 Mtetra
.654 .751 .921 r
.32399 .63404 .32977 .63908 .33894 .63643 .33318 .63134 Mtetra
.653 .75 .921 r
.33318 .63134 .33894 .63643 .34813 .63377 .3424 .62864 Mtetra
.653 .749 .92 r
.3424 .62864 .34813 .63377 .35736 .63112 .35164 .62595 Mtetra
.652 .748 .92 r
.35164 .62595 .35736 .63112 .36662 .62847 .36092 .62327 Mtetra
.65 .747 .92 r
.36092 .62327 .36662 .62847 .37591 .62584 .37023 .62063 Mtetra
.648 .746 .921 r
.37023 .62063 .37591 .62584 .38524 .62321 .37958 .61801 Mtetra
.647 .747 .923 r
.37958 .61801 .38524 .62321 .39459 .62058 .38895 .61542 Mtetra
.646 .749 .924 r
.38895 .61542 .39459 .62058 .40398 .61791 .39836 .61283 Mtetra
.646 .753 .927 r
.39836 .61283 .40398 .61791 .41341 .61518 .4078 .61022 Mtetra
.649 .759 .93 r
.4078 .61022 .41341 .61518 .42287 .61235 .41728 .60752 Mtetra
.655 .766 .931 r
.41728 .60752 .42287 .61235 .43237 .60937 .4268 .60467 Mtetra
.663 .775 .932 r
.4268 .60467 .43237 .60937 .44191 .60621 .43636 .6016 Mtetra
.675 .782 .93 r
.43636 .6016 .44191 .60621 .45148 .60287 .44595 .59824 Mtetra
.684 .784 .926 r
.44595 .59824 .45148 .60287 .46109 .59944 .45558 .59466 Mtetra
.69 .78 .92 r
.45558 .59466 .46109 .59944 .47072 .59601 .46525 .5909 Mtetra
.685 .767 .914 r
.46525 .5909 .47072 .59601 .48038 .59282 .47494 .58727 Mtetra
.671 .748 .908 r
.47494 .58727 .48038 .59282 .49008 .59004 .48466 .58398 Mtetra
.646 .723 .904 r
.48466 .58398 .49008 .59004 .4998 .58781 .4944 .58134 Mtetra
.613 .698 .904 r
.4944 .58134 .4998 .58781 .50956 .5862 .50418 .57953 Mtetra
.586 .681 .907 r
.50418 .57953 .50956 .5862 .51935 .58495 .514 .57835 Mtetra
.562 .674 .914 r
.514 .57835 .51935 .58495 .5292 .5839 .52386 .57764 Mtetra
.558 .686 .925 r
.52386 .57764 .5292 .5839 .53909 .58265 .53377 .5769 Mtetra
.57 .71 .937 r
.53377 .5769 .53909 .58265 .54902 .58098 .54372 .5758 Mtetra
.591 .742 .948 r
.54372 .5758 .54902 .58098 .55899 .57879 .55372 .57413 Mtetra
.619 .774 .955 r
.55372 .57413 .55899 .57879 .569 .57607 .56376 .57181 Mtetra
.637 .797 .959 r
.56376 .57181 .569 .57607 .57903 .57301 .57383 .56901 Mtetra
.65 .813 .962 r
.57383 .56901 .57903 .57301 .5891 .56973 .58393 .56587 Mtetra
.652 .821 .964 r
.58393 .56587 .5891 .56973 .59921 .56643 .59406 .56264 Mtetra
.648 .824 .968 r
.59406 .56264 .59921 .56643 .60935 .56324 .60423 .55946 Mtetra
.639 .823 .971 r
.60423 .55946 .60935 .56324 .61953 .56023 .61445 .55643 Mtetra
.631 .82 .973 r
.61445 .55643 .61953 .56023 .62976 .55739 .6247 .55354 Mtetra
.628 .818 .973 r
.6247 .55354 .62976 .55739 .64002 .55465 .635 .55069 Mtetra
.634 .816 .97 r
.635 .55069 .64002 .55465 .65033 .55189 .64533 .54776 Mtetra
.653 .814 .961 r
.64533 .54776 .65033 .55189 .66067 .54893 .65569 .54449 Mtetra
.677 .809 .946 r
.65569 .54449 .66067 .54893 .67103 .54561 .66606 .54074 Mtetra
.704 .799 .924 r
.66606 .54074 .67103 .54561 .68141 .54175 .67644 .53631 Mtetra
.722 .783 .901 r
.67644 .53631 .68141 .54175 .69179 .53737 .68683 .53131 Mtetra
.729 .764 .881 r
.68683 .53131 .69179 .53737 .70218 .53255 .69722 .52593 Mtetra
.726 .746 .868 r
.69722 .52593 .70218 .53255 .71259 .52753 .70763 .52051 Mtetra
.71 .73 .866 r
.70763 .52051 .71259 .52753 .72303 .52269 .7181 .51557 Mtetra
.692 .721 .872 r
.7181 .51557 .72303 .52269 .73353 .51822 .72863 .51126 Mtetra
.666 .717 .886 r
.72863 .51126 .73353 .51822 .7441 .51438 .73925 .50779 Mtetra
.643 .721 .905 r
.73925 .50779 .7441 .51438 .75475 .51109 .74996 .50499 Mtetra
.627 .732 .923 r
.74996 .50499 .75475 .51109 .76547 .50824 .76073 .50254 Mtetra
.617 .744 .937 r
.76073 .50254 .76547 .50824 .77624 .50562 .77156 .50022 Mtetra
.622 .759 .944 r
.77156 .50022 .77624 .50562 .78707 .503 .78243 .49772 Mtetra
.631 .768 .945 r
.78243 .49772 .78707 .503 .79793 .5003 .79332 .49499 Mtetra
.643 .773 .942 r
.79332 .49499 .79793 .5003 .80882 .4974 .80423 .49196 Mtetra
.653 .772 .936 r
.80423 .49196 .80882 .4974 .81973 .49432 .81516 .4887 Mtetra
.66 .768 .93 r
.81516 .4887 .81973 .49432 .83068 .49109 .82613 .48529 Mtetra
.663 .764 .925 r
.82613 .48529 .83068 .49109 .84166 .48773 .83712 .48178 Mtetra
.664 .759 .921 r
.83712 .48178 .84166 .48773 .85267 .48432 .84816 .47824 Mtetra
.664 .755 .918 r
.84816 .47824 .85267 .48432 .86373 .48087 .85923 .4747 Mtetra
.662 .752 .917 r
.85923 .4747 .86373 .48087 .87482 .47741 .87036 .47119 Mtetra
.661 .751 .916 r
.87036 .47119 .87482 .47741 .88596 .47396 .88152 .46771 Mtetra
.66 .75 .917 r
.88152 .46771 .88596 .47396 .89714 .47051 .89274 .46425 Mtetra
.659 .75 .917 r
.89274 .46425 .89714 .47051 .90836 .46707 .904 .46081 Mtetra
.658 .75 .918 r
.904 .46081 .90836 .46707 .91963 .46362 .9153 .45737 Mtetra
.658 .751 .919 r
.9153 .45737 .91963 .46362 .93095 .46018 .92665 .45393 Mtetra
.656 .751 .92 r
.31818 .62896 .32399 .63404 .33318 .63134 .32738 .6262 Mtetra
.656 .75 .919 r
.32738 .6262 .33318 .63134 .3424 .62864 .33662 .62343 Mtetra
.655 .748 .918 r
.33662 .62343 .3424 .62864 .35164 .62595 .34589 .62068 Mtetra
.654 .746 .917 r
.34589 .62068 .35164 .62595 .36092 .62327 .35519 .61794 Mtetra
.652 .743 .917 r
.35519 .61794 .36092 .62327 .37023 .62063 .36452 .61525 Mtetra
.649 .742 .917 r
.36452 .61525 .37023 .62063 .37958 .61801 .37389 .6126 Mtetra
.646 .74 .918 r
.37389 .6126 .37958 .61801 .38895 .61542 .38328 .61002 Mtetra
.643 .741 .92 r
.38328 .61002 .38895 .61542 .39836 .61283 .3927 .60748 Mtetra
.64 .743 .923 r
.3927 .60748 .39836 .61283 .4078 .61022 .40216 .605 Mtetra
.641 .748 .927 r
.40216 .605 .4078 .61022 .41728 .60752 .41166 .60248 Mtetra
.644 .757 .931 r
.41166 .60248 .41728 .60752 .4268 .60467 .42119 .59987 Mtetra
.653 .769 .935 r
.42119 .59987 .4268 .60467 .43636 .6016 .43076 .59702 Mtetra
.667 .783 .935 r
.43076 .59702 .43636 .6016 .44595 .59824 .44038 .59382 Mtetra
.683 .793 .933 r
.44038 .59382 .44595 .59824 .45558 .59466 .45003 .59023 Mtetra
.699 .797 .926 r
.45003 .59023 .45558 .59466 .46525 .5909 .45973 .58622 Mtetra
.702 .789 .918 r
.45973 .58622 .46525 .5909 .47494 .58727 .46945 .58211 Mtetra
.696 .77 .909 r
.46945 .58211 .47494 .58727 .48466 .58398 .4792 .57815 Mtetra
.67 .74 .902 r
.4792 .57815 .48466 .58398 .4944 .58134 .48898 .57485 Mtetra
.632 .705 .899 r
.48898 .57485 .4944 .58134 .50418 .57953 .49878 .57256 Mtetra
.594 .676 .898 r
.49878 .57256 .50418 .57953 .514 .57835 .50861 .57122 Mtetra
.554 .655 .902 r
.50861 .57122 .514 .57835 .52386 .57764 .51848 .57076 Mtetra
.539 .657 .912 r
.51848 .57076 .52386 .57764 .53377 .5769 .52841 .57053 Mtetra
.541 .676 .926 r
.52841 .57053 .53377 .5769 .54372 .5758 .53839 .57011 Mtetra
.56 .711 .942 r
.53839 .57011 .54372 .5758 .55372 .57413 .54841 .56913 Mtetra
.592 .751 .954 r
.54841 .56913 .55372 .57413 .56376 .57181 .55848 .56737 Mtetra
.616 .784 .962 r
.55848 .56737 .56376 .57181 .57383 .56901 .56858 .56499 Mtetra
.636 .81 .967 r
.56858 .56499 .57383 .56901 .58393 .56587 .57871 .56211 Mtetra
.642 .824 .97 r
.57871 .56211 .58393 .56587 .59406 .56264 .58888 .55902 Mtetra
.641 .831 .974 r
.58888 .55902 .59406 .56264 .60423 .55946 .59909 .55589 Mtetra
.635 .832 .976 r
.59909 .55589 .60423 .55946 .61445 .55643 .60933 .55284 Mtetra
.63 .831 .978 r
.60933 .55284 .61445 .55643 .6247 .55354 .61961 .54986 Mtetra
.633 .829 .976 r
.61961 .54986 .6247 .55354 .635 .55069 .62994 .54684 Mtetra
.646 .825 .969 r
.62994 .54684 .635 .55069 .64533 .54776 .64029 .54361 Mtetra
.674 .821 .954 r
.64029 .54361 .64533 .54776 .65569 .54449 .65066 .53987 Mtetra
.701 .81 .932 r
.65066 .53987 .65569 .54449 .66606 .54074 .66104 .53551 Mtetra
.727 .793 .904 r
.66104 .53551 .66606 .54074 .67644 .53631 .67142 .53035 Mtetra
.739 .771 .879 r
.67142 .53035 .67644 .53631 .68683 .53131 .6818 .52462 Mtetra
.738 .748 .86 r
.6818 .52462 .68683 .53131 .69722 .52593 .69219 .51868 Mtetra
.727 .729 .852 r
.69219 .51868 .69722 .52593 .70763 .52051 .70262 .51297 Mtetra
.703 .714 .857 r
.70262 .51297 .70763 .52051 .7181 .51557 .71312 .50814 Mtetra
.677 .708 .871 r
.71312 .50814 .7181 .51557 .72863 .51126 .7237 .50428 Mtetra
.644 .709 .894 r
.7237 .50428 .72863 .51126 .73925 .50779 .73439 .50144 Mtetra
.615 .719 .92 r
.73439 .50144 .73925 .50779 .74996 .50499 .74517 .49928 Mtetra
.602 .739 .941 r
.74517 .49928 .74996 .50499 .76073 .50254 .756 .49728 Mtetra
.601 .757 .953 r
.756 .49728 .76073 .50254 .77156 .50022 .76688 .49518 Mtetra
.618 .774 .955 r
.76688 .49518 .77156 .50022 .78243 .49772 .77777 .49265 Mtetra
.636 .781 .95 r
.77777 .49265 .78243 .49772 .79332 .49499 .78868 .48971 Mtetra
.653 .78 .941 r
.78868 .48971 .79332 .49499 .80423 .49196 .7996 .48642 Mtetra
.664 .774 .931 r
.7996 .48642 .80423 .49196 .81516 .4887 .81054 .48287 Mtetra
.668 .765 .923 r
.81054 .48287 .81516 .4887 .82613 .48529 .82152 .47923 Mtetra
.669 .758 .917 r
.82152 .47923 .82613 .48529 .83712 .48178 .83253 .47554 Mtetra
.667 .751 .913 r
.83253 .47554 .83712 .48178 .84816 .47824 .84359 .4719 Mtetra
.665 .748 .912 r
.84359 .4719 .84816 .47824 .85923 .4747 .85469 .46831 Mtetra
.662 .746 .912 r
.85469 .46831 .85923 .4747 .87036 .47119 .86585 .46479 Mtetra
.66 .745 .913 r
.86585 .46479 .87036 .47119 .88152 .46771 .87705 .46131 Mtetra
.658 .746 .914 r
.87705 .46131 .88152 .46771 .89274 .46425 .8883 .45788 Mtetra
.657 .747 .916 r
.8883 .45788 .89274 .46425 .904 .46081 .89959 .45446 Mtetra
.656 .748 .918 r
.89959 .45446 .904 .46081 .9153 .45737 .91093 .45104 Mtetra
.656 .75 .919 r
.91093 .45104 .9153 .45737 .92665 .45393 .92232 .44763 Mtetra
.658 .752 .919 r
.31232 .62385 .31818 .62896 .32738 .6262 .32155 .62103 Mtetra
.658 .75 .918 r
.32155 .62103 .32738 .6262 .33662 .62343 .33081 .61819 Mtetra
.657 .748 .917 r
.33081 .61819 .33662 .62343 .34589 .62068 .34011 .61536 Mtetra
.656 .746 .916 r
.34011 .61536 .34589 .62068 .35519 .61794 .34943 .61254 Mtetra
.655 .743 .914 r
.34943 .61254 .35519 .61794 .36452 .61525 .35878 .60975 Mtetra
.652 .739 .914 r
.35878 .60975 .36452 .61525 .37389 .6126 .36817 .60703 Mtetra
.648 .736 .914 r
.36817 .60703 .37389 .6126 .38328 .61002 .37758 .60439 Mtetra
.644 .734 .914 r
.37758 .60439 .38328 .61002 .3927 .60748 .38702 .60185 Mtetra
.638 .732 .917 r
.38702 .60185 .3927 .60748 .40216 .605 .3965 .59943 Mtetra
.634 .734 .92 r
.3965 .59943 .40216 .605 .41166 .60248 .40601 .59707 Mtetra
.632 .74 .926 r
.40601 .59707 .41166 .60248 .42119 .59987 .41555 .59473 Mtetra
.638 .753 .932 r
.41555 .59473 .42119 .59987 .43076 .59702 .42513 .59222 Mtetra
.651 .771 .936 r
.42513 .59222 .43076 .59702 .44038 .59382 .43476 .58937 Mtetra
.672 .791 .938 r
.43476 .58937 .44038 .59382 .45003 .59023 .44444 .58601 Mtetra
.699 .807 .932 r
.44444 .58601 .45003 .59023 .45973 .58622 .45416 .58198 Mtetra
.714 .81 .924 r
.45416 .58198 .45973 .58622 .46945 .58211 .46392 .57754 Mtetra
.721 .798 .912 r
.46392 .57754 .46945 .58211 .4792 .57815 .47371 .57287 Mtetra
.701 .768 .904 r
.47371 .57287 .4792 .57815 .48898 .57485 .48351 .56872 Mtetra
.663 .729 .899 r
.48351 .56872 .48898 .57485 .49878 .57256 .49334 .5656 Mtetra
.615 .686 .893 r
.49334 .5656 .49878 .57256 .50861 .57122 .50319 .56373 Mtetra
.559 .647 .893 r
.50319 .56373 .50861 .57122 .51848 .57076 .51308 .56322 Mtetra
.529 .632 .897 r
.51308 .56322 .51848 .57076 .52841 .57053 .52302 .56333 Mtetra
.516 .638 .908 r
.52302 .56333 .52841 .57053 .53839 .57011 .53301 .5636 Mtetra
.529 .668 .925 r
.53301 .5636 .53839 .57011 .54841 .56913 .54306 .56341 Mtetra
.561 .712 .942 r
.54306 .56341 .54841 .56913 .55848 .56737 .55315 .56239 Mtetra
.589 .754 .956 r
.55315 .56239 .55848 .56737 .56858 .56499 .56329 .56062 Mtetra
.617 .79 .965 r
.56329 .56062 .56858 .56499 .57871 .56211 .57345 .55816 Mtetra
.629 .813 .971 r
.57345 .55816 .57871 .56211 .58888 .55902 .58366 .55533 Mtetra
.635 .827 .974 r
.58366 .55533 .58888 .55902 .59909 .55589 .5939 .55231 Mtetra
.634 .833 .977 r
.5939 .55231 .59909 .55589 .60933 .55284 .60417 .54923 Mtetra
.637 .833 .976 r
.60417 .54923 .60933 .55284 .61961 .54986 .61449 .54611 Mtetra
.649 .831 .97 r
.61449 .54611 .61961 .54986 .62994 .54684 .62483 .54279 Mtetra
.67 .825 .958 r
.62483 .54279 .62994 .54684 .64029 .54361 .6352 .5391 Mtetra
.702 .815 .935 r
.6352 .5391 .64029 .54361 .65066 .53987 .64558 .53471 Mtetra
.727 .796 .906 r
.64558 .53471 .65066 .53987 .66104 .53551 .65596 .52956 Mtetra
.745 .773 .875 r
.65596 .52956 .66104 .53551 .67142 .53035 .66634 .52356 Mtetra
.749 .749 .852 r
.66634 .52356 .67142 .53035 .6818 .52462 .67671 .51709 Mtetra
.739 .726 .839 r
.67671 .51709 .6818 .52462 .69219 .51868 .68711 .51075 Mtetra
.721 .711 .839 r
.68711 .51075 .69219 .51868 .70262 .51297 .69756 .50504 Mtetra
.687 .699 .855 r
.69756 .50504 .70262 .51297 .71312 .50814 .70811 .50071 Mtetra
.651 .699 .881 r
.70811 .50071 .71312 .50814 .7237 .50428 .71877 .49765 Mtetra
.61 .708 .914 r
.71877 .49765 .7237 .50428 .73439 .50144 .72953 .49564 Mtetra
.577 .725 .944 r
.72953 .49564 .73439 .50144 .74517 .49928 .74038 .49417 Mtetra
.577 .754 .962 r
.74038 .49417 .74517 .49928 .756 .49728 .75127 .49247 Mtetra
.593 .775 .967 r
.75127 .49247 .756 .49728 .76688 .49518 .76217 .49034 Mtetra
.627 .788 .959 r
.76217 .49034 .76688 .49518 .77777 .49265 .77308 .48753 Mtetra
.653 .787 .945 r
.77308 .48753 .77777 .49265 .78868 .48971 .78399 .4842 Mtetra
.669 .777 .93 r
.78399 .4842 .78868 .48971 .7996 .48642 .79491 .48051 Mtetra
.676 .766 .918 r
.79491 .48051 .7996 .48642 .81054 .48287 .80586 .47664 Mtetra
.675 .754 .911 r
.80586 .47664 .81054 .48287 .82152 .47923 .81685 .47279 Mtetra
.673 .747 .907 r
.81685 .47279 .82152 .47923 .83253 .47554 .82788 .46899 Mtetra
.668 .742 .906 r
.82788 .46899 .83253 .47554 .84359 .4719 .83897 .46532 Mtetra
.664 .74 .907 r
.83897 .46532 .84359 .4719 .85469 .46831 .85011 .46174 Mtetra
.66 .74 .909 r
.85011 .46174 .85469 .46831 .86585 .46479 .8613 .45826 Mtetra
.658 .741 .911 r
.8613 .45826 .86585 .46479 .87705 .46131 .87254 .45483 Mtetra
.656 .743 .914 r
.87254 .45483 .87705 .46131 .8883 .45788 .88382 .45144 Mtetra
.655 .745 .916 r
.88382 .45144 .8883 .45788 .89959 .45446 .89516 .44806 Mtetra
.654 .747 .918 r
.89516 .44806 .89959 .45446 .91093 .45104 .90654 .44468 Mtetra
.654 .749 .919 r
.90654 .44468 .91093 .45104 .92232 .44763 .91796 .44128 Mtetra
.659 .752 .919 r
.30643 .61871 .31232 .62385 .32155 .62103 .31568 .61583 Mtetra
.66 .751 .918 r
.31568 .61583 .32155 .62103 .33081 .61819 .32496 .61293 Mtetra
.66 .749 .916 r
.32496 .61293 .33081 .61819 .34011 .61536 .33428 .61002 Mtetra
.66 .747 .915 r
.33428 .61002 .34011 .61536 .34943 .61254 .34363 .6071 Mtetra
.659 .744 .913 r
.34363 .6071 .34943 .61254 .35878 .60975 .35301 .60419 Mtetra
.657 .74 .911 r
.35301 .60419 .35878 .60975 .36817 .60703 .36242 .60133 Mtetra
.653 .735 .909 r
.36242 .60133 .36817 .60703 .37758 .60439 .37185 .59855 Mtetra
.648 .728 .908 r
.37185 .59855 .37758 .60439 .38702 .60185 .38132 .5959 Mtetra
.64 .723 .908 r
.38132 .5959 .38702 .60185 .3965 .59943 .39081 .59344 Mtetra
.632 .72 .911 r
.39081 .59344 .3965 .59943 .40601 .59707 .40034 .59116 Mtetra
.622 .72 .916 r
.40034 .59116 .40601 .59707 .41555 .59473 .40989 .58907 Mtetra
.622 .729 .924 r
.40989 .58907 .41555 .59473 .42513 .59222 .41948 .58696 Mtetra
.626 .747 .934 r
.41948 .58696 .42513 .59222 .43476 .58937 .42912 .58467 Mtetra
.648 .777 .942 r
.42912 .58467 .43476 .58937 .44444 .58601 .4388 .58184 Mtetra
.683 .807 .942 r
.4388 .58184 .44444 .58601 .45416 .58198 .44854 .57817 Mtetra
.715 .829 .935 r
.44854 .57817 .45416 .58198 .46392 .57754 .45833 .57367 Mtetra
.743 .831 .918 r
.45833 .57367 .46392 .57754 .47371 .57287 .46816 .56838 Mtetra
.736 .806 .907 r
.46816 .56838 .47371 .57287 .48351 .56872 .47801 .56323 Mtetra
.706 .764 .898 r
.47801 .56323 .48351 .56872 .49334 .5656 .48787 .55889 Mtetra
.652 .708 .889 r
.48787 .55889 .49334 .5656 .50319 .56373 .49774 .55601 Mtetra
.582 .651 .884 r
.49774 .55601 .50319 .56373 .51308 .56322 .50765 .555 Mtetra
.534 .616 .88 r
.50765 .555 .51308 .56322 .52302 .56333 .5176 .55516 Mtetra
.499 .601 .886 r
.5176 .55516 .52302 .56333 .53301 .5636 .5276 .55602 Mtetra
.5 .62 .901 r
.5276 .55602 .53301 .5636 .54306 .56341 .53767 .55667 Mtetra
.526 .661 .921 r
.53767 .55667 .54306 .56341 .55315 .56239 .54778 .55657 Mtetra
.557 .708 .942 r
.54778 .55657 .55315 .56239 .56329 .56062 .55795 .55561 Mtetra
.593 .756 .956 r
.55795 .55561 .56329 .56062 .57345 .55816 .56815 .55375 Mtetra
.614 .789 .966 r
.56815 .55375 .57345 .55816 .58366 .55533 .57839 .55132 Mtetra
.629 .812 .97 r
.57839 .55132 .58366 .55533 .5939 .55231 .58866 .54847 Mtetra
.639 .824 .972 r
.58866 .54847 .5939 .55231 .60417 .54923 .59897 .54538 Mtetra
.651 .828 .968 r
.59897 .54538 .60417 .54923 .61449 .54611 .60931 .54204 Mtetra
.673 .825 .957 r
.60931 .54204 .61449 .54611 .62483 .54279 .61967 .53829 Mtetra
.699 .814 .936 r
.61967 .53829 .62483 .54279 .6352 .5391 .63005 .53395 Mtetra
.73 .797 .905 r
.63005 .53395 .6352 .5391 .64558 .53471 .64044 .5287 Mtetra
.748 .772 .873 r
.64044 .5287 .64558 .53471 .65596 .52956 .65081 .52258 Mtetra
.756 .746 .843 r
.65081 .52258 .65596 .52956 .66634 .52356 .66118 .51568 Mtetra
.751 .722 .825 r
.66118 .51568 .66634 .52356 .67671 .51709 .67155 .50856 Mtetra
.731 .7 .821 r
.67155 .50856 .67671 .51709 .68711 .51075 .68196 .50214 Mtetra
.705 .689 .832 r
.68196 .50214 .68711 .51075 .69756 .50504 .69246 .49689 Mtetra
.658 .682 .861 r
.69246 .49689 .69756 .50504 .70811 .50071 .70309 .49353 Mtetra
.606 .689 .901 r
.70309 .49353 .70811 .50071 .71877 .49765 .71384 .49168 Mtetra
.557 .71 .943 r
.71384 .49168 .71877 .49765 .72953 .49564 .72469 .49065 Mtetra
.525 .737 .972 r
.72469 .49065 .72953 .49564 .74038 .49417 .73561 .48977 Mtetra
.557 .779 .982 r
.73561 .48977 .74038 .49417 .75127 .49247 .74653 .48809 Mtetra
.605 .8 .975 r
.74653 .48809 .75127 .49247 .76217 .49034 .75744 .48556 Mtetra
.653 .801 .954 r
.75744 .48556 .76217 .49034 .77308 .48753 .76834 .48217 Mtetra
.679 .787 .931 r
.76834 .48217 .77308 .48753 .78399 .4842 .77923 .4782 Mtetra
.685 .767 .913 r
.77923 .4782 .78399 .4842 .79491 .48051 .79015 .47406 Mtetra
.685 .751 .901 r
.79015 .47406 .79491 .48051 .80586 .47664 .80111 .46989 Mtetra
.678 .739 .897 r
.80111 .46989 .80586 .47664 .81685 .47279 .81211 .46591 Mtetra
.671 .733 .896 r
.81211 .46591 .81685 .47279 .82788 .46899 .82318 .46211 Mtetra
.664 .731 .899 r
.82318 .46211 .82788 .46899 .83897 .46532 .8343 .45851 Mtetra
.659 .732 .903 r
.8343 .45851 .83897 .46532 .85011 .46174 .84548 .45504 Mtetra
.656 .735 .908 r
.84548 .45504 .85011 .46174 .8613 .45826 .85671 .45165 Mtetra
.654 .738 .912 r
.85671 .45165 .8613 .45826 .87254 .45483 .86799 .44831 Mtetra
.653 .742 .915 r
.86799 .44831 .87254 .45483 .88382 .45144 .87932 .44497 Mtetra
.652 .745 .917 r
.87932 .44497 .88382 .45144 .89516 .44806 .89069 .44163 Mtetra
.652 .747 .919 r
.89069 .44163 .89516 .44806 .90654 .44468 .90211 .43828 Mtetra
.653 .749 .92 r
.90211 .43828 .90654 .44468 .91796 .44128 .91357 .43489 Mtetra
.659 .752 .919 r
.3005 .61354 .30643 .61871 .31568 .61583 .30977 .61064 Mtetra
.66 .752 .918 r
.30977 .61064 .31568 .61583 .32496 .61293 .31908 .60771 Mtetra
.661 .752 .918 r
.31908 .60771 .32496 .61293 .33428 .61002 .32841 .60474 Mtetra
.662 .751 .916 r
.32841 .60474 .33428 .61002 .34363 .6071 .33778 .60175 Mtetra
.663 .749 .914 r
.33778 .60175 .34363 .6071 .35301 .60419 .34719 .59873 Mtetra
.662 .746 .912 r
.34719 .59873 .35301 .60419 .36242 .60133 .35662 .59571 Mtetra
.661 .74 .909 r
.35662 .59571 .36242 .60133 .37185 .59855 .36609 .59273 Mtetra
.656 .732 .906 r
.36609 .59273 .37185 .59855 .38132 .5959 .37558 .58986 Mtetra
.647 .723 .904 r
.37558 .58986 .38132 .5959 .39081 .59344 .3851 .5872 Mtetra
.636 .714 .903 r
.3851 .5872 .39081 .59344 .40034 .59116 .39465 .58481 Mtetra
.621 .705 .906 r
.39465 .58481 .40034 .59116 .40989 .58907 .40421 .58278 Mtetra
.611 .705 .911 r
.40421 .58278 .40989 .58907 .41948 .58696 .41381 .58096 Mtetra
.602 .713 .922 r
.41381 .58096 .41948 .58696 .42912 .58467 .42345 .57926 Mtetra
.616 .74 .934 r
.42345 .57926 .42912 .58467 .4388 .58184 .43314 .57717 Mtetra
.648 .78 .944 r
.43314 .57717 .4388 .58184 .44854 .57817 .44288 .5743 Mtetra
.696 .824 .944 r
.44288 .5743 .44854 .57817 .45833 .57367 .45269 .57026 Mtetra
.749 .851 .926 r
.45269 .57026 .45833 .57367 .46816 .56838 .46255 .56481 Mtetra
.764 .846 .913 r
.46255 .56481 .46816 .56838 .47801 .56323 .47244 .55887 Mtetra
.755 .815 .9 r
.47244 .55887 .47801 .56323 .48787 .55889 .48235 .55309 Mtetra
.704 .755 .892 r
.48235 .55309 .48787 .55889 .49774 .55601 .49227 .54874 Mtetra
.625 .683 .885 r
.49227 .54874 .49774 .55601 .50765 .555 .50219 .54657 Mtetra
.56 .623 .872 r
.50219 .54657 .50765 .555 .5176 .55516 .51215 .54616 Mtetra
.501 .58 .867 r
.51215 .54616 .5176 .55516 .5276 .55602 .52216 .5472 Mtetra
.487 .578 .873 r
.52216 .5472 .5276 .55602 .53767 .55667 .53224 .54848 Mtetra
.5 .603 .888 r
.53224 .54848 .53767 .55667 .54778 .55657 .54237 .5493 Mtetra
.528 .646 .909 r
.54237 .5493 .54778 .55657 .55795 .55561 .55256 .54928 Mtetra
.57 .697 .927 r
.55256 .54928 .55795 .55561 .56815 .55375 .56279 .54818 Mtetra
.6 .738 .941 r
.56279 .54818 .56815 .55375 .57839 .55132 .57306 .54628 Mtetra
.628 .77 .948 r
.57306 .54628 .57839 .55132 .58866 .54847 .58337 .54368 Mtetra
.65 .788 .948 r
.58337 .54368 .58866 .54847 .59897 .54538 .5937 .54057 Mtetra
.672 .794 .94 r
.5937 .54057 .59897 .54538 .60931 .54204 .60407 .53694 Mtetra
.699 .791 .922 r
.60407 .53694 .60931 .54204 .61967 .53829 .61444 .53261 Mtetra
.724 .777 .895 r
.61444 .53261 .61967 .53829 .63005 .53395 .62483 .52746 Mtetra
.746 .757 .861 r
.62483 .52746 .63005 .53395 .64044 .5287 .63521 .52123 Mtetra
.755 .733 .832 r
.63521 .52123 .64044 .5287 .65081 .52258 .64557 .51413 Mtetra
.754 .71 .81 r
.64557 .51413 .65081 .52258 .66118 .51568 .65594 .50654 Mtetra
.743 .692 .803 r
.65594 .50654 .66118 .51568 .67155 .50856 .66632 .4992 Mtetra
.713 .677 .813 r
.66632 .4992 .67155 .50856 .68196 .50214 .67679 .4933 Mtetra
.676 .673 .84 r
.67679 .4933 .68196 .50214 .69246 .49689 .68736 .48918 Mtetra
.609 .675 .887 r
.68736 .48918 .69246 .49689 .70309 .49353 .69809 .48729 Mtetra
.529 .688 .94 r
.69809 .48729 .70309 .49353 .71384 .49168 .70894 .48685 Mtetra
.478 .723 .978 r
.70894 .48685 .71384 .49168 .72469 .49065 .71987 .48659 Mtetra
.48 .761 .992 r
.71987 .48659 .72469 .49065 .73561 .48977 .73083 .48584 Mtetra
.573 .808 .988 r
.73083 .48584 .73561 .48977 .74653 .48809 .74175 .48365 Mtetra
.648 .815 .963 r
.74175 .48365 .74653 .48809 .75744 .48556 .75264 .48025 Mtetra
.687 .793 .93 r
.75264 .48025 .75744 .48556 .76834 .48217 .76351 .47605 Mtetra
.7 .768 .904 r
.76351 .47605 .76834 .48217 .77923 .4782 .77439 .47144 Mtetra
.694 .744 .89 r
.77439 .47144 .77923 .4782 .79015 .47406 .78531 .46695 Mtetra
.686 .731 .885 r
.78531 .46695 .79015 .47406 .80111 .46989 .79628 .46267 Mtetra
.674 .724 .887 r
.79628 .46267 .80111 .46989 .81211 .46591 .80733 .45876 Mtetra
.665 .723 .893 r
.80733 .45876 .81211 .46591 .82318 .46211 .81844 .45513 Mtetra
.657 .726 .9 r
.81844 .45513 .82318 .46211 .8343 .45851 .82961 .4517 Mtetra
.653 .731 .907 r
.82961 .4517 .8343 .45851 .84548 .45504 .84083 .4484 Mtetra
.651 .737 .912 r
.84083 .4484 .84548 .45504 .85671 .45165 .85211 .44513 Mtetra
.65 .741 .916 r
.85211 .44513 .85671 .45165 .86799 .44831 .86343 .44187 Mtetra
.651 .745 .919 r
.86343 .44187 .86799 .44831 .87932 .44497 .8748 .43856 Mtetra
.651 .748 .92 r
.8748 .43856 .87932 .44497 .89069 .44163 .8862 .43523 Mtetra
.652 .749 .921 r
.8862 .43523 .89069 .44163 .90211 .43828 .89765 .43186 Mtetra
.653 .75 .921 r
.89765 .43186 .90211 .43828 .91357 .43489 .90915 .42846 Mtetra
.657 .752 .92 r
.29453 .60833 .3005 .61354 .30977 .61064 .30382 .60545 Mtetra
.658 .754 .92 r
.30382 .60545 .30977 .61064 .31908 .60771 .31314 .60254 Mtetra
.66 .756 .921 r
.31314 .60254 .31908 .60771 .32841 .60474 .3225 .59959 Mtetra
.662 .757 .921 r
.3225 .59959 .32841 .60474 .33778 .60175 .33189 .59657 Mtetra
.665 .757 .919 r
.33189 .59657 .33778 .60175 .34719 .59873 .34132 .59347 Mtetra
.667 .756 .917 r
.34132 .59347 .34719 .59873 .35662 .59571 .35078 .59031 Mtetra
.669 .752 .912 r
.35078 .59031 .35662 .59571 .36609 .59273 .36028 .58708 Mtetra
.667 .743 .907 r
.36028 .58708 .36609 .59273 .37558 .58986 .3698 .58391 Mtetra
.662 .732 .902 r
.3698 .58391 .37558 .58986 .3851 .5872 .37936 .58086 Mtetra
.65 .716 .896 r
.37936 .58086 .3851 .5872 .39465 .58481 .38893 .57811 Mtetra
.631 .699 .894 r
.38893 .57811 .39465 .58481 .40421 .58278 .39853 .57583 Mtetra
.611 .685 .895 r
.39853 .57583 .40421 .58278 .41381 .58096 .40814 .57405 Mtetra
.586 .677 .903 r
.40814 .57405 .41381 .58096 .42345 .57926 .41777 .57281 Mtetra
.582 .691 .917 r
.41777 .57281 .42345 .57926 .43314 .57717 .42746 .57158 Mtetra
.592 .727 .938 r
.42746 .57158 .43314 .57717 .44288 .5743 .43719 .56996 Mtetra
.646 .795 .954 r
.43719 .56996 .44288 .5743 .45269 .57026 .447 .56703 Mtetra
.726 .858 .943 r
.447 .56703 .45269 .57026 .46255 .56481 .45688 .56215 Mtetra
.775 .885 .925 r
.45688 .56215 .46255 .56481 .47244 .55887 .46682 .5559 Mtetra
.801 .872 .9 r
.46682 .5559 .47244 .55887 .48235 .55309 .47678 .54869 Mtetra
.766 .817 .893 r
.47678 .54869 .48235 .55309 .49227 .54874 .48674 .54247 Mtetra
.693 .738 .886 r
.48674 .54247 .49227 .54874 .50219 .54657 .49671 .53838 Mtetra
.611 .653 .867 r
.49671 .53838 .50219 .54657 .51215 .54616 .50669 .53659 Mtetra
.528 .581 .852 r
.50669 .53659 .51215 .54616 .52216 .5472 .5167 .53712 Mtetra
.493 .552 .845 r
.5167 .53712 .52216 .5472 .53224 .54848 .52678 .5386 Mtetra
.486 .554 .85 r
.52678 .5386 .53224 .54848 .54237 .5493 .53692 .54018 Mtetra
.507 .583 .866 r
.53692 .54018 .54237 .5493 .55256 .54928 .54713 .54109 Mtetra
.547 .629 .884 r
.54713 .54109 .55256 .54928 .56279 .54818 .55738 .54087 Mtetra
.584 .672 .9 r
.55738 .54087 .56279 .54818 .57306 .54628 .56768 .53962 Mtetra
.623 .709 .908 r
.56768 .53962 .57306 .54628 .58337 .54368 .57801 .53735 Mtetra
.655 .733 .906 r
.57801 .53735 .58337 .54368 .5937 .54057 .58837 .53421 Mtetra
.685 .743 .895 r
.58837 .53421 .5937 .54057 .60407 .53694 .59875 .53021 Mtetra
.714 .74 .872 r
.59875 .53021 .60407 .53694 .61444 .53261 .60914 .52518 Mtetra
.734 .727 .845 r
.60914 .52518 .61444 .53261 .62483 .52746 .61952 .51911 Mtetra
.748 .71 .816 r
.61952 .51911 .62483 .52746 .63521 .52123 .62989 .51189 Mtetra
.75 .691 .794 r
.62989 .51189 .63521 .52123 .64557 .51413 .64025 .50397 Mtetra
.741 .673 .784 r
.64025 .50397 .64557 .51413 .65594 .50654 .65063 .49614 Mtetra
.723 .662 .789 r
.65063 .49614 .65594 .50654 .66632 .4992 .66105 .48924 Mtetra
.68 .652 .815 r
.66105 .48924 .66632 .4992 .67679 .4933 .67159 .4847 Mtetra
.621 .656 .863 r
.67159 .4847 .67679 .4933 .68736 .48918 .68228 .4825 Mtetra
.515 .666 .93 r
.68228 .4825 .68736 .48918 .69809 .48729 .69312 .48246 Mtetra
.382 .676 .975 r
.69312 .48246 .69809 .48729 .70894 .48685 .70409 .48344 Mtetra
.375 .738 .99 r
.70409 .48344 .70894 .48685 .71987 .48659 .71506 .48346 Mtetra
.478 .804 1 r
.71506 .48346 .71987 .48659 .73083 .48584 .72602 .48208 Mtetra
.635 .841 .979 r
.72602 .48208 .73083 .48584 .74175 .48365 .7369 .47871 Mtetra
.706 .814 .932 r
.7369 .47871 .74175 .48365 .75264 .48025 .74774 .47399 Mtetra
.716 .768 .894 r
.74774 .47399 .75264 .48025 .76351 .47605 .75857 .46886 Mtetra
.71 .738 .873 r
.75857 .46886 .76351 .47605 .77439 .47144 .76944 .46373 Mtetra
.691 .716 .868 r
.76944 .46373 .77439 .47144 .78531 .46695 .78039 .45916 Mtetra
.676 .709 .872 r
.78039 .45916 .78531 .46695 .79628 .46267 .7914 .45509 Mtetra
.662 .71 .883 r
.7914 .45509 .79628 .46267 .80733 .45876 .8025 .4515 Mtetra
.652 .716 .895 r
.8025 .4515 .80733 .45876 .81844 .45513 .81367 .44823 Mtetra
.647 .726 .907 r
.81367 .44823 .81844 .45513 .82961 .4517 .8249 .44508 Mtetra
.644 .735 .915 r
.8249 .44508 .82961 .4517 .84083 .4484 .83618 .44198 Mtetra
.645 .744 .921 r
.83618 .44198 .84083 .4484 .85211 .44513 .8475 .43882 Mtetra
.647 .749 .924 r
.8475 .43882 .85211 .44513 .86343 .44187 .85886 .43559 Mtetra
.65 .753 .925 r
.85886 .43559 .86343 .44187 .8748 .43856 .87026 .43227 Mtetra
.652 .754 .924 r
.87026 .43227 .8748 .43856 .8862 .43523 .88169 .42889 Mtetra
.653 .754 .923 r
.88169 .42889 .8862 .43523 .89765 .43186 .89317 .42545 Mtetra
.654 .752 .922 r
.89317 .42545 .89765 .43186 .90915 .42846 .90469 .42197 Mtetra
.654 .751 .921 r
.28853 .60308 .29453 .60833 .30382 .60545 .29783 .60027 Mtetra
.654 .754 .923 r
.29783 .60027 .30382 .60545 .31314 .60254 .30716 .59743 Mtetra
.656 .758 .925 r
.30716 .59743 .31314 .60254 .3225 .59959 .31653 .59454 Mtetra
.659 .762 .926 r
.31653 .59454 .3225 .59959 .33189 .59657 .32594 .59157 Mtetra
.663 .765 .926 r
.32594 .59157 .33189 .59657 .34132 .59347 .33539 .58848 Mtetra
.668 .767 .924 r
.33539 .58848 .34132 .59347 .35078 .59031 .34488 .58527 Mtetra
.674 .768 .921 r
.34488 .58527 .35078 .59031 .36028 .58708 .35441 .58189 Mtetra
.677 .763 .916 r
.35441 .58189 .36028 .58708 .3698 .58391 .36397 .57844 Mtetra
.678 .754 .909 r
.36397 .57844 .3698 .58391 .37936 .58086 .37356 .57495 Mtetra
.669 .737 .901 r
.37356 .57495 .37936 .58086 .38893 .57811 .38318 .57167 Mtetra
.653 .716 .894 r
.38318 .57167 .38893 .57811 .39853 .57583 .39281 .56879 Mtetra
.628 .689 .888 r
.39281 .56879 .39853 .57583 .40814 .57405 .40245 .56657 Mtetra
.592 .663 .888 r
.40245 .56657 .40814 .57405 .41777 .57281 .4121 .56526 Mtetra
.566 .65 .892 r
.4121 .56526 .41777 .57281 .42746 .57158 .42178 .56453 Mtetra
.543 .657 .91 r
.42178 .56453 .42746 .57158 .43719 .56996 .4315 .56415 Mtetra
.58 .716 .936 r
.4315 .56415 .43719 .56996 .447 .56703 .44129 .56278 Mtetra
.661 .805 .952 r
.44129 .56278 .447 .56703 .45688 .56215 .45117 .55949 Mtetra
.747 .885 .942 r
.45117 .55949 .45688 .56215 .46682 .5559 .46112 .55397 Mtetra
.82 .913 .902 r
.46112 .55397 .46682 .5559 .47678 .54869 .47114 .54616 Mtetra
.819 .89 .894 r
.47114 .54616 .47678 .54869 .48674 .54247 .48116 .5383 Mtetra
.775 .828 .894 r
.48116 .5383 .48674 .54247 .49671 .53838 .49117 .53177 Mtetra
.689 .729 .88 r
.49117 .53177 .49671 .53838 .50669 .53659 .50119 .52771 Mtetra
.584 .626 .859 r
.50119 .52771 .50669 .53659 .5167 .53712 .51122 .52667 Mtetra
.526 .562 .835 r
.51122 .52667 .5167 .53712 .52678 .5386 .5213 .52738 Mtetra
.496 .531 .823 r
.5213 .52738 .52678 .5386 .53692 .54018 .53145 .52905 Mtetra
.504 .538 .825 r
.53145 .52905 .53692 .54018 .54713 .54109 .54165 .53049 Mtetra
.536 .566 .833 r
.54165 .53049 .54713 .54109 .55738 .54087 .55192 .53098 Mtetra
.572 .6 .842 r
.55192 .53098 .55738 .54087 .56768 .53962 .56223 .53033 Mtetra
.614 .634 .847 r
.56223 .53033 .56768 .53962 .57801 .53735 .57258 .52838 Mtetra
.651 .658 .844 r
.57258 .52838 .57801 .53735 .58837 .53421 .58296 .52522 Mtetra
.682 .671 .833 r
.58296 .52522 .58837 .53421 .59875 .53021 .59335 .52085 Mtetra
.709 .674 .814 r
.59335 .52085 .59875 .53021 .60914 .52518 .60374 .51516 Mtetra
.725 .669 .794 r
.60374 .51516 .60914 .52518 .61952 .51911 .61412 .50833 Mtetra
.735 .66 .776 r
.61412 .50833 .61952 .51911 .62989 .51189 .62449 .50052 Mtetra
.734 .651 .768 r
.62449 .50052 .62989 .51189 .64025 .50397 .63486 .49246 Mtetra
.717 .642 .773 r
.63486 .49246 .64025 .50397 .65063 .49614 .64528 .48535 Mtetra
.691 .642 .796 r
.64528 .48535 .65063 .49614 .66105 .48924 .65578 .48 Mtetra
.623 .642 .849 r
.65578 .48 .66105 .48924 .67159 .4847 .66644 .47771 Mtetra
.505 .652 .924 r
.66644 .47771 .67159 .4847 .68228 .4825 .67726 .47794 Mtetra
.31 .648 .969 r
.67726 .47794 .68228 .4825 .69312 .48246 .68822 .47953 Mtetra
.17 .635 .934 r
.68822 .47953 .69312 .48246 .70409 .48344 .69925 .4811 Mtetra
.363 .779 .979 r
.69925 .4811 .70409 .48344 .71506 .48346 .71022 .48032 Mtetra
.598 .856 .993 r
.71022 .48032 .71506 .48346 .72602 .48208 .72111 .47728 Mtetra
.716 .822 .931 r
.72111 .47728 .72602 .48208 .7369 .47871 .73192 .47226 Mtetra
.74 .77 .877 r
.73192 .47226 .7369 .47871 .74774 .47399 .7427 .46622 Mtetra
.72 .725 .854 r
.7427 .46622 .74774 .47399 .75857 .46886 .75353 .46053 Mtetra
.701 .704 .85 r
.75353 .46053 .75857 .46886 .76944 .46373 .76443 .45542 Mtetra
.677 .696 .86 r
.76443 .45542 .76944 .46373 .78039 .45916 .77543 .45125 Mtetra
.658 .699 .877 r
.77543 .45125 .78039 .45916 .7914 .45509 .78652 .44776 Mtetra
.645 .712 .896 r
.78652 .44776 .7914 .45509 .8025 .4515 .79769 .44468 Mtetra
.636 .725 .912 r
.79769 .44468 .8025 .4515 .81367 .44823 .80893 .44182 Mtetra
.635 .74 .924 r
.80893 .44182 .81367 .44823 .8249 .44508 .82021 .43891 Mtetra
.637 .75 .931 r
.82021 .43891 .8249 .44508 .83618 .44198 .83153 .43593 Mtetra
.642 .758 .933 r
.83153 .43593 .83618 .44198 .8475 .43882 .84289 .43278 Mtetra
.647 .761 .932 r
.84289 .43278 .8475 .43882 .85886 .43559 .85428 .42949 Mtetra
.651 .762 .93 r
.85428 .42949 .85886 .43559 .87026 .43227 .8657 .42608 Mtetra
.654 .76 .928 r
.8657 .42608 .87026 .43227 .88169 .42889 .87716 .42259 Mtetra
.656 .758 .925 r
.87716 .42259 .88169 .42889 .89317 .42545 .88866 .41903 Mtetra
.657 .755 .922 r
.88866 .41903 .89317 .42545 .90469 .42197 .90021 .41544 Mtetra
.649 .75 .923 r
.28248 .59781 .28853 .60308 .29783 .60027 .29179 .59508 Mtetra
.649 .754 .926 r
.29179 .59508 .29783 .60027 .30716 .59743 .30114 .59234 Mtetra
.65 .758 .929 r
.30114 .59234 .30716 .59743 .31653 .59454 .31052 .58957 Mtetra
.652 .764 .931 r
.31052 .58957 .31653 .59454 .32594 .59157 .31995 .58672 Mtetra
.656 .771 .934 r
.31995 .58672 .32594 .59157 .33539 .58848 .32941 .58377 Mtetra
.663 .778 .935 r
.32941 .58377 .33539 .58848 .34488 .58527 .33891 .58064 Mtetra
.672 .785 .934 r
.33891 .58064 .34488 .58527 .35441 .58189 .34846 .57728 Mtetra
.682 .788 .93 r
.34846 .57728 .35441 .58189 .36397 .57844 .35805 .57368 Mtetra
.692 .785 .922 r
.35805 .57368 .36397 .57844 .37356 .57495 .36769 .5698 Mtetra
.693 .771 .912 r
.36769 .5698 .37356 .57495 .38318 .57167 .37735 .56589 Mtetra
.687 .748 .898 r
.37735 .56589 .38318 .57167 .39281 .56879 .38704 .56209 Mtetra
.663 .712 .885 r
.38704 .56209 .39281 .56879 .40245 .56657 .39674 .55891 Mtetra
.624 .671 .875 r
.39674 .55891 .40245 .56657 .4121 .56526 .40643 .55678 Mtetra
.579 .631 .867 r
.40643 .55678 .4121 .56526 .42178 .56453 .41612 .55586 Mtetra
.519 .599 .874 r
.41612 .55586 .42178 .56453 .4315 .56415 .42582 .55632 Mtetra
.512 .62 .896 r
.42582 .55632 .4315 .56415 .44129 .56278 .43558 .5567 Mtetra
.546 .695 .937 r
.43558 .5567 .44129 .56278 .45117 .55949 .44542 .55598 Mtetra
.659 .838 .969 r
.44542 .55598 .45117 .55949 .46112 .55397 .45537 .55253 Mtetra
.795 .935 .923 r
.45537 .55253 .46112 .55397 .47114 .54616 .46541 .54545 Mtetra
.839 .954 .89 r
.46541 .54545 .47114 .54616 .48116 .5383 .47549 .53674 Mtetra
.849 .923 .88 r
.47549 .53674 .48116 .5383 .49117 .53177 .48558 .52766 Mtetra
.789 .833 .886 r
.48558 .52766 .49117 .53177 .50119 .52771 .49565 .52059 Mtetra
.679 .712 .873 r
.49565 .52059 .50119 .52771 .51122 .52667 .50571 .51677 Mtetra
.594 .608 .836 r
.50571 .51677 .51122 .52667 .5213 .52738 .51581 .51548 Mtetra
.532 .54 .808 r
.51581 .51548 .5213 .52738 .53145 .52905 .52595 .51624 Mtetra
.522 .52 .795 r
.52595 .51624 .53145 .52905 .54165 .53049 .53615 .51747 Mtetra
.537 .526 .791 r
.53615 .51747 .54165 .53049 .55192 .53098 .54641 .51825 Mtetra
.566 .547 .792 r
.54641 .51825 .55192 .53098 .56223 .53033 .55673 .51799 Mtetra
.604 .573 .792 r
.55673 .51799 .56223 .53033 .57258 .52838 .56709 .51628 Mtetra
.639 .595 .789 r
.56709 .51628 .57258 .52838 .58296 .52522 .57747 .51309 Mtetra
.67 .611 .78 r
.57747 .51309 .58296 .52522 .59335 .52085 .58786 .50842 Mtetra
.694 .619 .767 r
.58786 .50842 .59335 .52085 .60374 .51516 .59825 .50229 Mtetra
.708 .62 .756 r
.59825 .50229 .60374 .51516 .61412 .50833 .60864 .49511 Mtetra
.713 .618 .75 r
.60864 .49511 .61412 .50833 .62449 .50052 .61902 .48745 Mtetra
.707 .617 .755 r
.61902 .48745 .62449 .50052 .63486 .49246 .62944 .48025 Mtetra
.678 .615 .778 r
.62944 .48025 .63486 .49246 .64528 .48535 .63993 .47511 Mtetra
.629 .624 .827 r
.63993 .47511 .64528 .48535 .65578 .48 .65056 .47253 Mtetra
.486 .627 .914 r
.65056 .47253 .65578 .48 .66644 .47771 .66136 .47326 Mtetra
.185 .578 .939 r
.66136 .47326 .66644 .47771 .67726 .47794 .67233 .47603 Mtetra
0 .506 .797 r
.67233 .47603 .67726 .47794 .68822 .47953 .68336 .47846 Mtetra
.041 .6 .807 r
.68336 .47846 .68822 .47953 .69925 .4811 .69439 .47923 Mtetra
.524 .878 .985 r
.69439 .47923 .69925 .4811 .71022 .48032 .70528 .47631 Mtetra
.74 .86 .937 r
.70528 .47631 .71022 .48032 .72111 .47728 .71605 .4706 Mtetra
.757 .768 .862 r
.71605 .4706 .72111 .47728 .73192 .47226 .72679 .46374 Mtetra
.741 .715 .827 r
.72679 .46374 .73192 .47226 .7427 .46622 .73753 .45679 Mtetra
.704 .68 .825 r
.73753 .45679 .7427 .46622 .75353 .46053 .74839 .45124 Mtetra
.675 .672 .839 r
.74839 .45124 .75353 .46053 .76443 .45542 .75937 .44693 Mtetra
.648 .68 .866 r
.75937 .44693 .76443 .45542 .77543 .45125 .77047 .4437 Mtetra
.627 .698 .896 r
.77047 .4437 .77543 .45125 .78652 .44776 .78166 .44111 Mtetra
.619 .725 .922 r
.78166 .44111 .78652 .44776 .79769 .44468 .79291 .43864 Mtetra
.616 .747 .939 r
.79291 .43864 .79769 .44468 .80893 .44182 .80421 .43614 Mtetra
.625 .765 .947 r
.80421 .43614 .80893 .44182 .82021 .43891 .81554 .43334 Mtetra
.634 .774 .948 r
.81554 .43334 .82021 .43891 .83153 .43593 .82689 .4303 Mtetra
.644 .777 .944 r
.82689 .4303 .83153 .43593 .84289 .43278 .83827 .42702 Mtetra
.652 .775 .939 r
.83827 .42702 .84289 .43278 .85428 .42949 .84968 .42355 Mtetra
.656 .771 .934 r
.84968 .42355 .85428 .42949 .8657 .42608 .86112 .41996 Mtetra
.659 .767 .929 r
.86112 .41996 .8657 .42608 .87716 .42259 .8726 .4163 Mtetra
.661 .762 .925 r
.8726 .4163 .87716 .42259 .88866 .41903 .88412 .41258 Mtetra
.661 .757 .922 r
.88412 .41258 .88866 .41903 .90021 .41544 .89569 .40886 Mtetra
.647 .749 .924 r
.27639 .59249 .28248 .59781 .29179 .59508 .28572 .58981 Mtetra
.645 .751 .926 r
.28572 .58981 .29179 .59508 .30114 .59234 .29508 .58715 Mtetra
.644 .754 .929 r
.29508 .58715 .30114 .59234 .31052 .58957 .30448 .58449 Mtetra
.645 .759 .932 r
.30448 .58449 .31052 .58957 .31995 .58672 .31391 .58178 Mtetra
.646 .766 .936 r
.31391 .58178 .31995 .58672 .32941 .58377 .32338 .57903 Mtetra
.651 .776 .94 r
.32338 .57903 .32941 .58377 .33891 .58064 .3329 .57613 Mtetra
.66 .788 .942 r
.3329 .57613 .33891 .58064 .34846 .57728 .34245 .573 Mtetra
.674 .801 .943 r
.34245 .573 .34846 .57728 .35805 .57368 .35206 .56954 Mtetra
.692 .811 .938 r
.35206 .56954 .35805 .57368 .36769 .5698 .36173 .56562 Mtetra
.706 .812 .931 r
.36173 .56562 .36769 .5698 .37735 .56589 .37143 .56136 Mtetra
.718 .801 .916 r
.37143 .56136 .37735 .56589 .38704 .56209 .38118 .55676 Mtetra
.705 .77 .902 r
.38118 .55676 .38704 .56209 .39674 .55891 .39094 .55243 Mtetra
.677 .725 .886 r
.39094 .55243 .39674 .55891 .40643 .55678 .40071 .54881 Mtetra
.623 .664 .869 r
.40071 .54881 .40643 .55678 .41612 .55586 .41046 .54667 Mtetra
.546 .599 .858 r
.41046 .54667 .41612 .55586 .42582 .55632 .42018 .5466 Mtetra
.497 .563 .853 r
.42018 .5466 .42582 .55632 .43558 .5567 .42992 .54775 Mtetra
.457 .563 .874 r
.42992 .54775 .43558 .5567 .44542 .55598 .4397 .54947 Mtetra
.535 .677 .929 r
.4397 .54947 .44542 .55598 .45537 .55253 .4496 .54902 Mtetra
.699 .848 .954 r
.4496 .54902 .45537 .55253 .46541 .54545 .45963 .5447 Mtetra
.8 .959 .915 r
.45963 .5447 .46541 .54545 .47549 .53674 .46974 .53717 Mtetra
.863 .979 .853 r
.46974 .53717 .47549 .53674 .48558 .52766 .47989 .52699 Mtetra
.859 .952 .872 r
.47989 .52699 .48558 .52766 .49565 .52059 .49004 .51739 Mtetra
.799 .871 .901 r
.49004 .51739 .49565 .52059 .50571 .51677 .50016 .51014 Mtetra
.701 .735 .878 r
.50016 .51014 .50571 .51677 .51581 .51548 .51028 .50564 Mtetra
.603 .615 .837 r
.51028 .50564 .51581 .51548 .52595 .51624 .52043 .50403 Mtetra
.565 .554 .8 r
.52043 .50403 .52595 .51624 .53615 .51747 .53063 .50374 Mtetra
.557 .528 .778 r
.53063 .50374 .53615 .51747 .54641 .51825 .54089 .50382 Mtetra
.574 .529 .767 r
.54089 .50382 .54641 .51825 .55673 .51799 .5512 .50328 Mtetra
.601 .542 .76 r
.5512 .50328 .55673 .51799 .56709 .51628 .56155 .50151 Mtetra
.63 .558 .754 r
.56155 .50151 .56709 .51628 .57747 .51309 .57193 .49829 Mtetra
.656 .572 .748 r
.57193 .49829 .57747 .51309 .58786 .50842 .58232 .49362 Mtetra
.676 .583 .743 r
.58232 .49362 .58786 .50842 .59825 .50229 .59272 .48771 Mtetra
.687 .591 .742 r
.59272 .48771 .59825 .50229 .60864 .49511 .60312 .48117 Mtetra
.685 .597 .751 r
.60312 .48117 .60864 .49511 .61902 .48745 .61356 .47499 Mtetra
.671 .608 .776 r
.61356 .47499 .61902 .48745 .62944 .48025 .62405 .47013 Mtetra
.611 .619 .834 r
.62405 .47013 .62944 .48025 .63993 .47511 .63468 .46818 Mtetra
.465 .636 .929 r
.63468 .46818 .63993 .47511 .65056 .47253 .64545 .46903 Mtetra
.03 .515 .879 r
.64545 .46903 .65056 .47253 .66136 .47326 .65639 .47229 Mtetra
.312 0 0 r
.65639 .47229 .66136 .47326 .67233 .47603 .66744 .47615 Mtetra
.149 0 0 r
.66744 .47615 .67233 .47603 .68336 .47846 .67845 .47734 Mtetra
.379 .827 .938 r
.67845 .47734 .68336 .47846 .69439 .47923 .68937 .47526 Mtetra
.75 .864 .932 r
.68937 .47526 .69439 .47923 .70528 .47631 .70014 .46923 Mtetra
.782 .763 .836 r
.70014 .46923 .70528 .47631 .71605 .4706 .7108 .46096 Mtetra
.744 .692 .802 r
.7108 .46096 .71605 .4706 .72679 .46374 .72151 .45327 Mtetra
.714 .665 .8 r
.72151 .45327 .72679 .46374 .73753 .45679 .73231 .4468 Mtetra
.672 .656 .826 r
.73231 .4468 .73753 .45679 .74839 .45124 .74327 .44246 Mtetra
.635 .667 .864 r
.74327 .44246 .74839 .45124 .75937 .44693 .75437 .43964 Mtetra
.607 .698 .908 r
.75437 .43964 .75937 .44693 .77047 .4437 .76558 .43755 Mtetra
.585 .729 .943 r
.76558 .43755 .77047 .4437 .78166 .44111 .77687 .43575 Mtetra
.59 .763 .961 r
.77687 .43575 .78166 .44111 .79291 .43864 .78818 .4336 Mtetra
.602 .783 .967 r
.78818 .4336 .79291 .43864 .80421 .43614 .79952 .43109 Mtetra
.625 .793 .963 r
.79952 .43109 .80421 .43614 .81554 .43334 .81087 .42811 Mtetra
.642 .793 .955 r
.81087 .42811 .81554 .43334 .82689 .4303 .82223 .42478 Mtetra
.654 .786 .945 r
.82223 .42478 .82689 .4303 .83827 .42702 .83362 .42122 Mtetra
.661 .779 .937 r
.83362 .42122 .83827 .42702 .84968 .42355 .84504 .41749 Mtetra
.663 .772 .93 r
.84504 .41749 .84968 .42355 .86112 .41996 .8565 .41371 Mtetra
.665 .766 .925 r
.8565 .41371 .86112 .41996 .8726 .4163 .868 .40989 Mtetra
.665 .761 .922 r
.868 .40989 .8726 .4163 .88412 .41258 .87954 .40606 Mtetra
.664 .757 .92 r
.87954 .40606 .88412 .41258 .89569 .40886 .89113 .40224 Mtetra
.647 .749 .924 r
.27027 .58715 .27639 .59249 .28572 .58981 .27961 .58444 Mtetra
.644 .748 .925 r
.27961 .58444 .28572 .58981 .29508 .58715 .28899 .58178 Mtetra
.642 .748 .926 r
.28899 .58178 .29508 .58715 .30448 .58449 .29841 .57916 Mtetra
.64 .75 .929 r
.29841 .57916 .30448 .58449 .31391 .58178 .30785 .57657 Mtetra
.636 .754 .934 r
.30785 .57657 .31391 .58178 .32338 .57903 .31733 .57404 Mtetra
.636 .764 .94 r
.31733 .57404 .32338 .57903 .3329 .57613 .32684 .57145 Mtetra
.638 .777 .948 r
.32684 .57145 .3329 .57613 .34245 .573 .3364 .56877 Mtetra
.65 .799 .955 r
.3364 .56877 .34245 .573 .35206 .56954 .34601 .56578 Mtetra
.669 .824 .958 r
.34601 .56578 .35206 .56954 .36173 .56562 .35568 .5623 Mtetra
.696 .847 .955 r
.35568 .5623 .36173 .56562 .37143 .56136 .36541 .55817 Mtetra
.73 .858 .941 r
.36541 .55817 .37143 .56136 .38118 .55676 .3752 .55322 Mtetra
.745 .845 .926 r
.3752 .55322 .38118 .55676 .39094 .55243 .38504 .54786 Mtetra
.745 .806 .9 r
.38504 .54786 .39094 .55243 .40071 .54881 .3949 .54235 Mtetra
.7 .734 .877 r
.3949 .54235 .40071 .54881 .41046 .54667 .40474 .53798 Mtetra
.626 .649 .853 r
.40474 .53798 .41046 .54667 .42018 .5466 .41454 .53571 Mtetra
.54 .561 .825 r
.41454 .53571 .42018 .5466 .42992 .54775 .42431 .53601 Mtetra
.432 .486 .816 r
.42431 .53601 .42992 .54775 .4397 .54947 .43405 .53915 Mtetra
.426 .514 .845 r
.43405 .53915 .4397 .54947 .4496 .54902 .44388 .54191 Mtetra
.5 .643 .92 r
.44388 .54191 .4496 .54902 .45963 .5447 .45383 .54221 Mtetra
.659 .885 .981 r
.45383 .54221 .45963 .5447 .46974 .53717 .46391 .53831 Mtetra
.802 .997 .858 r
.46391 .53831 .46974 .53717 .47989 .52699 .4741 .52938 Mtetra
.819 .999 .79 r
.4741 .52938 .47989 .52699 .49004 .51739 .48432 .5187 Mtetra
.853 .995 .828 r
.48432 .5187 .49004 .51739 .50016 .51014 .49453 .50812 Mtetra
.832 .916 .893 r
.49453 .50812 .50016 .51014 .51028 .50564 .50471 .49969 Mtetra
.728 .766 .883 r
.50471 .49969 .51028 .50564 .52043 .50403 .51489 .49438 Mtetra
.65 .642 .829 r
.51489 .49438 .52043 .50403 .53063 .50374 .5251 .49114 Mtetra
.605 .57 .788 r
.5251 .49114 .53063 .50374 .54089 .50382 .53535 .48935 Mtetra
.599 .543 .763 r
.53535 .48935 .54089 .50382 .5512 .50328 .54565 .48769 Mtetra
.609 .537 .748 r
.54565 .48769 .5512 .50328 .56155 .50151 .55599 .48544 Mtetra
.626 .543 .74 r
.55599 .48544 .56155 .50151 .57193 .49829 .56636 .48219 Mtetra
.643 .552 .737 r
.56636 .48219 .57193 .49829 .58232 .49362 .57676 .47794 Mtetra
.655 .563 .739 r
.57676 .47794 .58232 .49362 .59272 .48771 .58717 .47309 Mtetra
.657 .575 .751 r
.58717 .47309 .59272 .48771 .60312 .48117 .59762 .46838 Mtetra
.637 .587 .781 r
.59762 .46838 .60312 .48117 .61356 .47499 .60814 .4651 Mtetra
.586 .612 .845 r
.60814 .4651 .61356 .47499 .62405 .47013 .61876 .46393 Mtetra
.359 .609 .944 r
.61876 .46393 .62405 .47013 .63468 .46818 .62953 .46593 Mtetra
0 .355 .696 r
.62953 .46593 .63468 .46818 .64545 .46903 .64046 .4701 Mtetra
.485 0 0 r
.64046 .4701 .64545 .46903 .65639 .47229 .65148 .47442 Mtetra
.418 0 0 r
.65148 .47442 .65639 .47229 .66744 .47615 .66252 .47699 Mtetra
.2 .726 .735 r
.66252 .47699 .66744 .47615 .67845 .47734 .67341 .47444 Mtetra
.775 .911 .933 r
.67341 .47444 .67845 .47734 .68937 .47526 .68414 .4676 Mtetra
.794 .751 .814 r
.68414 .4676 .68937 .47526 .70014 .46923 .69477 .45825 Mtetra
.763 .676 .767 r
.69477 .45825 .70014 .46923 .7108 .46096 .70537 .44847 Mtetra
.706 .63 .77 r
.70537 .44847 .7108 .46096 .72151 .45327 .71614 .44159 Mtetra
.661 .621 .798 r
.71614 .44159 .72151 .45327 .73231 .4468 .72709 .43733 Mtetra
.612 .64 .854 r
.72709 .43733 .73231 .4468 .74327 .44246 .73822 .43523 Mtetra
.557 .677 .919 r
.73822 .43523 .74327 .44246 .75437 .43964 .74948 .43431 Mtetra
.53 .738 .97 r
.74948 .43431 .75437 .43964 .76558 .43755 .7608 .43325 Mtetra
.524 .781 .991 r
.7608 .43325 .76558 .43755 .77687 .43575 .77215 .43178 Mtetra
.566 .815 .992 r
.77215 .43178 .77687 .43575 .78818 .4336 .78349 .42944 Mtetra
.609 .825 .983 r
.78349 .42944 .78818 .4336 .79952 .43109 .79482 .42644 Mtetra
.643 .818 .967 r
.79482 .42644 .79952 .43109 .81087 .42811 .80616 .42293 Mtetra
.662 .804 .951 r
.80616 .42293 .81087 .42811 .82223 .42478 .81752 .41909 Mtetra
.668 .787 .937 r
.81752 .41909 .82223 .42478 .83362 .42122 .82891 .41515 Mtetra
.671 .775 .928 r
.82891 .41515 .83362 .42122 .84504 .41749 .84034 .41115 Mtetra
.669 .765 .922 r
.84034 .41115 .84504 .41749 .8565 .41371 .85182 .4072 Mtetra
.667 .759 .919 r
.85182 .4072 .8565 .41371 .868 .40989 .86335 .40328 Mtetra
.666 .756 .918 r
.86335 .40328 .868 .40989 .87954 .40606 .87492 .3994 Mtetra
.664 .755 .918 r
.87492 .3994 .87954 .40606 .89113 .40224 .88655 .39556 Mtetra
.651 .75 .922 r
.2641 .58177 .27027 .58715 .27961 .58444 .27348 .57894 Mtetra
.649 .746 .92 r
.27348 .57894 .27961 .58444 .28899 .58178 .28288 .57615 Mtetra
.646 .741 .919 r
.28288 .57615 .28899 .58178 .29841 .57916 .29232 .57344 Mtetra
.641 .738 .919 r
.29232 .57344 .29841 .57916 .30785 .57657 .30178 .57082 Mtetra
.634 .735 .921 r
.30178 .57082 .30785 .57657 .31733 .57404 .31127 .56836 Mtetra
.629 .737 .925 r
.31127 .56836 .31733 .57404 .32684 .57145 .32079 .566 Mtetra
.622 .744 .934 r
.32079 .566 .32684 .57145 .3364 .56877 .33034 .56374 Mtetra
.625 .761 .944 r
.33034 .56374 .3364 .56877 .34601 .56578 .33994 .56135 Mtetra
.633 .789 .957 r
.33994 .56135 .34601 .56578 .35568 .5623 .34959 .55867 Mtetra
.659 .829 .965 r
.34959 .55867 .35568 .5623 .36541 .55817 .35931 .55532 Mtetra
.701 .869 .961 r
.35931 .55532 .36541 .55817 .3752 .55322 .36911 .55095 Mtetra
.741 .898 .949 r
.36911 .55095 .3752 .55322 .38504 .54786 .37898 .54556 Mtetra
.782 .897 .924 r
.37898 .54556 .38504 .54786 .3949 .54235 .38892 .53904 Mtetra
.777 .858 .91 r
.38892 .53904 .3949 .54235 .40474 .53798 .39887 .53262 Mtetra
.737 .779 .887 r
.39887 .53262 .40474 .53798 .41454 .53571 .40881 .52718 Mtetra
.636 .658 .854 r
.40881 .52718 .41454 .53571 .42431 .53601 .41867 .52458 Mtetra
.498 .53 .82 r
.41867 .52458 .42431 .53601 .43405 .53915 .42846 .52603 Mtetra
.434 .465 .793 r
.42846 .52603 .43405 .53915 .44388 .54191 .43826 .52953 Mtetra
.393 .454 .805 r
.43826 .52953 .44388 .54191 .45383 .54221 .44811 .53371 Mtetra
.484 .593 .887 r
.44811 .53371 .45383 .54221 .46391 .53831 .45812 .5347 Mtetra
.698 .847 .955 r
.45812 .5347 .46391 .53831 .4741 .52938 .46827 .53035 Mtetra
.771 .994 .872 r
.46827 .53035 .4741 .52938 .48432 .5187 .47851 .52217 Mtetra
.768 .982 .727 r
.47851 .52217 .48432 .5187 .49453 .50812 .48879 .51117 Mtetra
.776 .988 .75 r
.48879 .51117 .49453 .50812 .50471 .49969 .49905 .50047 Mtetra
.8 .995 .866 r
.49905 .50047 .50471 .49969 .51489 .49438 .5093 .49172 Mtetra
.781 .899 .926 r
.5093 .49172 .51489 .49438 .5251 .49114 .51954 .48504 Mtetra
.704 .758 .894 r
.51954 .48504 .5251 .49114 .53535 .48935 .52981 .48047 Mtetra
.662 .667 .844 r
.52981 .48047 .53535 .48935 .54565 .48769 .54011 .47687 Mtetra
.643 .619 .811 r
.54011 .47687 .54565 .48769 .55599 .48544 .55045 .47369 Mtetra
.641 .603 .795 r
.55045 .47369 .55599 .48544 .56636 .48219 .56083 .47041 Mtetra
.643 .604 .795 r
.56083 .47041 .56636 .48219 .57676 .47794 .57125 .46704 Mtetra
.636 .616 .813 r
.57125 .46704 .57676 .47794 .58717 .47309 .58172 .46409 Mtetra
.611 .644 .859 r
.58172 .46409 .58717 .47309 .59762 .46838 .59224 .46211 Mtetra
.486 .673 .947 r
.59224 .46211 .59762 .46838 .60814 .4651 .60287 .46227 Mtetra
.058 .564 .883 r
.60287 .46227 .60814 .4651 .61876 .46393 .61361 .46453 Mtetra
.463 0 0 r
.61361 .46453 .61876 .46393 .62953 .46593 .6245 .46878 Mtetra
.551 .015 0 r
.6245 .46878 .62953 .46593 .64046 .4701 .63548 .47337 Mtetra
.412 0 0 r
.63548 .47337 .64046 .4701 .65148 .47442 .64646 .47511 Mtetra
.173 .708 .737 r
.64646 .47511 .65148 .47442 .66252 .47699 .65735 .47298 Mtetra
.796 .868 .902 r
.65735 .47298 .66252 .47699 .67341 .47444 .66806 .46541 Mtetra
.798 .722 .78 r
.66806 .46541 .67341 .47444 .68414 .4676 .67863 .45457 Mtetra
.749 .643 .744 r
.67863 .45457 .68414 .4676 .69477 .45825 .68923 .44439 Mtetra
.714 .617 .748 r
.68923 .44439 .69477 .45825 .70537 .44847 .69993 .43629 Mtetra
.652 .609 .793 r
.69993 .43629 .70537 .44847 .71614 .44159 .71088 .43232 Mtetra
.576 .628 .867 r
.71088 .43232 .71614 .44159 .72709 .43733 .72205 .43127 Mtetra
.487 .688 .956 r
.72205 .43127 .72709 .43733 .73822 .43523 .73335 .43124 Mtetra
.392 .728 .99 r
.73335 .43124 .73822 .43523 .74948 .43431 .74472 .43133 Mtetra
.424 .791 .995 r
.74472 .43133 .74948 .43431 .7608 .43325 .75607 .43026 Mtetra
.509 .834 .999 r
.75607 .43026 .7608 .43325 .77215 .43178 .76741 .42814 Mtetra
.605 .847 .99 r
.76741 .42814 .77215 .43178 .78349 .42944 .77873 .42496 Mtetra
.657 .831 .967 r
.77873 .42496 .78349 .42944 .79482 .42644 .79003 .42108 Mtetra
.677 .802 .942 r
.79003 .42108 .79482 .42644 .80616 .42293 .80135 .4169 Mtetra
.683 .78 .924 r
.80135 .4169 .80616 .42293 .81752 .41909 .8127 .41257 Mtetra
.679 .762 .914 r
.8127 .41257 .81752 .41909 .82891 .41515 .82411 .40835 Mtetra
.675 .752 .909 r
.82411 .40835 .82891 .41515 .84034 .41115 .83556 .40423 Mtetra
.669 .747 .909 r
.83556 .40423 .84034 .41115 .85182 .4072 .84707 .40026 Mtetra
.665 .745 .91 r
.84707 .40026 .85182 .4072 .86335 .40328 .85864 .3964 Mtetra
.662 .746 .913 r
.85864 .3964 .86335 .40328 .87492 .3994 .87026 .3926 Mtetra
.66 .749 .916 r
.87026 .3926 .87492 .3994 .88655 .39556 .88193 .38884 Mtetra
.66 .752 .919 r
.25789 .57635 .2641 .58177 .27348 .57894 .2673 .57331 Mtetra
.659 .745 .914 r
.2673 .57331 .27348 .57894 .28288 .57615 .27674 .57028 Mtetra
.656 .737 .909 r
.27674 .57028 .28288 .57615 .29232 .57344 .28621 .56733 Mtetra
.65 .728 .906 r
.28621 .56733 .29232 .57344 .30178 .57082 .29571 .56451 Mtetra
.641 .719 .904 r
.29571 .56451 .30178 .57082 .31127 .56836 .30522 .56189 Mtetra
.631 .711 .904 r
.30522 .56189 .31127 .56836 .32079 .566 .31476 .55952 Mtetra
.616 .707 .91 r
.31476 .55952 .32079 .566 .33034 .56374 .32432 .55748 Mtetra
.605 .712 .92 r
.32432 .55748 .33034 .56374 .33994 .56135 .3339 .55564 Mtetra
.593 .728 .938 r
.3339 .55564 .33994 .56135 .34959 .55867 .34352 .55394 Mtetra
.6 .769 .961 r
.34352 .55394 .34959 .55867 .35931 .55532 .35319 .55189 Mtetra
.62 .83 .981 r
.35319 .55189 .35931 .55532 .36911 .55095 .36295 .5491 Mtetra
.666 .905 .979 r
.36295 .5491 .36911 .55095 .37898 .54556 .3728 .54496 Mtetra
.739 .957 .943 r
.3728 .54496 .37898 .54556 .38892 .53904 .38276 .53892 Mtetra
.793 .971 .912 r
.38276 .53892 .38892 .53904 .39887 .53262 .3928 .53143 Mtetra
.84 .932 .89 r
.3928 .53143 .39887 .53262 .40881 .52718 .40289 .52277 Mtetra
.784 .819 .88 r
.40289 .52277 .40881 .52718 .41867 .52458 .41293 .51574 Mtetra
.663 .663 .84 r
.41293 .51574 .41867 .52458 .42846 .52603 .42287 .5122 Mtetra
.533 .512 .779 r
.42287 .5122 .42846 .52603 .43826 .52953 .43273 .51301 Mtetra
.399 .4 .744 r
.43273 .51301 .43826 .52953 .44811 .53371 .44253 .51856 Mtetra
.38 .405 .761 r
.44253 .51856 .44811 .53371 .45812 .5347 .45243 .52409 Mtetra
.43 .514 .843 r
.45243 .52409 .45812 .5347 .46827 .53035 .46246 .52679 Mtetra
.557 .813 .993 r
.46246 .52679 .46827 .53035 .47851 .52217 .47264 .52479 Mtetra
.605 .942 .76 r
.47264 .52479 .47851 .52217 .48879 .51117 .48294 .51724 Mtetra
0 0 0 r
.48294 .51724 .48879 .51117 .49905 .50047 .49327 .50726 Mtetra
.49327 .50726 .49905 .50047 .5093 .49172 .5036 .49658 Mtetra
.53 .854 .565 r
.5036 .49658 .5093 .49172 .51954 .48504 .51392 .48697 Mtetra
.652 .966 .804 r
.51392 .48697 .51954 .48504 .52981 .48047 .52424 .4794 Mtetra
.722 .955 .948 r
.52424 .4794 .52981 .48047 .54011 .47687 .53458 .47345 Mtetra
.692 .863 .963 r
.53458 .47345 .54011 .47687 .55045 .47369 .54495 .46904 Mtetra
.651 .802 .956 r
.54495 .46904 .55045 .47369 .56083 .47041 .55536 .46574 Mtetra
.591 .782 .971 r
.55536 .46574 .56083 .47041 .57125 .46704 .56582 .46356 Mtetra
.431 .767 .997 r
.56582 .46356 .57125 .46704 .58172 .46409 .57636 .46293 Mtetra
.011 .577 .793 r
.57636 .46293 .58172 .46409 .59224 .46211 .58698 .46394 Mtetra
.445 0 0 r
.58698 .46394 .59224 .46211 .60287 .46227 .59772 .46701 Mtetra
.562 .068 .041 r
.59772 .46701 .60287 .46227 .61361 .46453 .60857 .4712 Mtetra
.551 .092 .116 r
.60857 .4712 .61361 .46453 .6245 .46878 .61949 .4747 Mtetra
.447 0 .019 r
.61949 .4747 .6245 .46878 .63548 .47337 .63041 .47576 Mtetra
0 0 0 r
.63041 .47576 .63548 .47337 .64646 .47511 .64122 .4712 Mtetra
.836 .871 .87 r
.64122 .4712 .64646 .47511 .65735 .47298 .65187 .46186 Mtetra
.792 .686 .747 r
.65187 .46186 .65735 .47298 .66806 .46541 .6624 .4496 Mtetra
.75 .616 .711 r
.6624 .4496 .66806 .46541 .67863 .45457 .67291 .4373 Mtetra
.684 .57 .72 r
.67291 .4373 .67863 .45457 .68923 .44439 .68364 .4298 Mtetra
.624 .562 .765 r
.68364 .4298 .68923 .44439 .69993 .43629 .69462 .42675 Mtetra
.517 .592 .869 r
.69462 .42675 .69993 .43629 .71088 .43232 .70584 .42729 Mtetra
.275 .614 .957 r
.70584 .42729 .71088 .43232 .72205 .43127 .71724 .42951 Mtetra
.092 .624 .866 r
.71724 .42951 .72205 .43127 .73335 .43124 .72864 .43054 Mtetra
.134 .677 .825 r
.72864 .43054 .73335 .43124 .74472 .43133 .74002 .4301 Mtetra
.401 .84 .942 r
.74002 .4301 .74472 .43133 .75607 .43026 .75133 .42769 Mtetra
.605 .892 .989 r
.75133 .42769 .75607 .43026 .76741 .42814 .7626 .42389 Mtetra
.685 .851 .962 r
.7626 .42389 .76741 .42814 .77873 .42496 .77384 .41932 Mtetra
.705 .802 .925 r
.77384 .41932 .77873 .42496 .79003 .42108 .7851 .41438 Mtetra
.697 .763 .902 r
.7851 .41438 .79003 .42108 .80135 .4169 .7964 .40958 Mtetra
.689 .741 .891 r
.7964 .40958 .80135 .4169 .8127 .41257 .80776 .40497 Mtetra
.677 .728 .889 r
.80776 .40497 .8127 .41257 .82411 .40835 .81919 .40071 Mtetra
.669 .724 .891 r
.81919 .40071 .82411 .40835 .83556 .40423 .83069 .3967 Mtetra
.662 .726 .897 r
.83069 .3967 .83556 .40423 .84707 .40026 .84225 .3929 Mtetra
.657 .73 .903 r
.84225 .3929 .84707 .40026 .85864 .3964 .85387 .38924 Mtetra
.654 .736 .91 r
.85387 .38924 .85864 .3964 .87026 .3926 .86555 .38565 Mtetra
.653 .743 .916 r
.86555 .38565 .87026 .3926 .88193 .38884 .87727 .38207 Mtetra
.667 .754 .915 r
.25164 .57089 .25789 .57635 .2673 .57331 .26109 .56765 Mtetra
.668 .748 .91 r
.26109 .56765 .2673 .57331 .27674 .57028 .27057 .56437 Mtetra
.666 .739 .904 r
.27057 .56437 .27674 .57028 .28621 .56733 .28008 .56111 Mtetra
.662 .729 .899 r
.28008 .56111 .28621 .56733 .29571 .56451 .28961 .55796 Mtetra
.656 .717 .893 r
.28961 .55796 .29571 .56451 .30522 .56189 .29917 .55495 Mtetra
.644 .702 .888 r
.29917 .55495 .30522 .56189 .31476 .55952 .30874 .55223 Mtetra
.628 .687 .886 r
.30874 .55223 .31476 .55952 .32432 .55748 .31833 .54994 Mtetra
.609 .673 .886 r
.31833 .54994 .32432 .55748 .3339 .55564 .32792 .54809 Mtetra
.584 .664 .893 r
.32792 .54809 .3339 .55564 .34352 .55394 .33753 .54683 Mtetra
.572 .673 .908 r
.33753 .54683 .34352 .55394 .35319 .55189 .34717 .54575 Mtetra
.561 .704 .936 r
.34717 .54575 .35319 .55189 .36295 .5491 .35686 .54467 Mtetra
.59 .781 .971 r
.35686 .54467 .36295 .5491 .3728 .54496 .36664 .54263 Mtetra
.65 .885 .983 r
.36664 .54263 .3728 .54496 .38276 .53892 .37653 .53889 Mtetra
.715 .969 .933 r
.37653 .53889 .38276 .53892 .3928 .53143 .38656 .53284 Mtetra
.802 .997 .859 r
.38656 .53284 .3928 .53143 .40289 .52277 .39671 .52398 Mtetra
.835 .993 .855 r
.39671 .52398 .40289 .52277 .41293 .51574 .40689 .5144 Mtetra
.843 .928 .886 r
.40689 .5144 .41293 .51574 .42287 .5122 .41704 .50553 Mtetra
.71 .737 .872 r
.41704 .50553 .42287 .5122 .43273 .51301 .42708 .50069 Mtetra
.515 .526 .805 r
.42708 .50069 .43273 .51301 .44253 .51856 .43699 .50181 Mtetra
.435 .421 .744 r
.43699 .50181 .44253 .51856 .45243 .52409 .44688 .50632 Mtetra
.389 .382 .731 r
.44688 .50632 .45243 .52409 .46246 .52679 .45682 .51258 Mtetra
.434 .453 .78 r
.45682 .51258 .46246 .52679 .47264 .52479 .46689 .51637 Mtetra
.571 .641 .881 r
.46689 .51637 .47264 .52479 .48294 .51724 .47712 .5154 Mtetra
.682 .92 .972 r
.47712 .5154 .48294 .51724 .49327 .50726 .48744 .51063 Mtetra
.551 .902 .686 r
.48744 .51063 .49327 .50726 .5036 .49658 .49782 .5027 Mtetra
0 0 0 r
.49782 .5027 .5036 .49658 .51392 .48697 .50821 .49403 Mtetra
.50821 .49403 .51392 .48697 .52424 .4794 .5186 .48599 Mtetra
.5186 .48599 .52424 .4794 .53458 .47345 .52901 .47923 Mtetra
.022 0 0 r
.52901 .47923 .53458 .47345 .54495 .46904 .53944 .47423 Mtetra
.131 0 0 r
.53944 .47423 .54495 .46904 .55536 .46574 .54991 .47092 Mtetra
.266 0 0 r
.54991 .47092 .55536 .46574 .56582 .46356 .56044 .4693 Mtetra
.398 0 0 r
.56044 .4693 .56582 .46356 .57636 .46293 .57105 .46946 Mtetra
.476 .009 .066 r
.57105 .46946 .57636 .46293 .58698 .46394 .58174 .47092 Mtetra
.506 .048 .101 r
.58174 .47092 .58698 .46394 .59772 .46701 .59252 .47302 Mtetra
.463 0 .032 r
.59252 .47302 .59772 .46701 .60857 .4712 .60336 .47441 Mtetra
.127 0 0 r
.60336 .47441 .60857 .4712 .61949 .4747 .61418 .47261 Mtetra
.715 .931 .961 r
.61418 .47261 .61949 .4747 .63041 .47576 .62494 .46695 Mtetra
.796 .726 .787 r
.62494 .46695 .63041 .47576 .64122 .4712 .63556 .45647 Mtetra
.765 .634 .715 r
.63556 .45647 .64122 .4712 .65187 .46186 .64609 .44344 Mtetra
.721 .582 .699 r
.64609 .44344 .65187 .46186 .6624 .4496 .65666 .43216 Mtetra
.687 .57 .718 r
.65666 .43216 .6624 .4496 .67291 .4373 .66738 .42431 Mtetra
.599 .57 .793 r
.66738 .42431 .67291 .4373 .68364 .4298 .67839 .42254 Mtetra
.373 .583 .924 r
.67839 .42254 .68364 .4298 .69462 .42675 .68967 .4249 Mtetra
0 .443 .745 r
.68967 .4249 .69462 .42675 .70584 .42729 .70107 .42801 Mtetra
.304 0 0 r
.70107 .42801 .70584 .42729 .71724 .42951 .71253 .43041 Mtetra
.048 0 0 r
.71253 .43041 .71724 .42951 .72864 .43054 .72389 .42992 Mtetra
.385 .842 .903 r
.72389 .42992 .72864 .43054 .74002 .4301 .73516 .42706 Mtetra
.668 .895 .978 r
.73516 .42706 .74002 .4301 .75133 .42769 .74637 .42245 Mtetra
.728 .823 .924 r
.74637 .42245 .75133 .42769 .7626 .42389 .75754 .41684 Mtetra
.72 .759 .883 r
.75754 .41684 .7626 .42389 .77384 .41932 .76874 .4112 Mtetra
.708 .724 .863 r
.76874 .4112 .77384 .41932 .7851 .41438 .77998 .40576 Mtetra
.689 .705 .859 r
.77998 .40576 .7851 .41438 .7964 .40958 .79131 .40091 Mtetra
.676 .698 .863 r
.79131 .40091 .7964 .40958 .80776 .40497 .80272 .39653 Mtetra
.664 .7 .873 r
.80272 .39653 .80776 .40497 .81919 .40071 .81421 .39258 Mtetra
.656 .706 .884 r
.81421 .39258 .81919 .40071 .83069 .3967 .82577 .38892 Mtetra
.651 .715 .895 r
.82577 .38892 .83069 .3967 .84225 .3929 .83739 .38543 Mtetra
.647 .723 .904 r
.83739 .38543 .84225 .3929 .85387 .38924 .84907 .38203 Mtetra
.645 .732 .912 r
.84907 .38203 .85387 .38924 .86555 .38565 .8608 .37866 Mtetra
.646 .74 .918 r
.8608 .37866 .86555 .38565 .87727 .38207 .87259 .37524 Mtetra
.672 .755 .913 r
.24535 .5654 .25164 .57089 .26109 .56765 .25483 .56203 Mtetra
.675 .752 .909 r
.25483 .56203 .26109 .56765 .27057 .56437 .26434 .55856 Mtetra
.676 .747 .904 r
.26434 .55856 .27057 .56437 .28008 .56111 .27389 .55504 Mtetra
.675 .738 .898 r
.27389 .55504 .28008 .56111 .28961 .55796 .28347 .55151 Mtetra
.674 .727 .889 r
.28347 .55151 .28961 .55796 .29917 .55495 .29308 .54797 Mtetra
.666 .709 .879 r
.29308 .54797 .29917 .55495 .30874 .55223 .30271 .5446 Mtetra
.654 .687 .869 r
.30271 .5446 .30874 .55223 .31833 .54994 .31236 .54154 Mtetra
.633 .66 .859 r
.31236 .54154 .31833 .54994 .32792 .54809 .322 .53904 Mtetra
.604 .633 .853 r
.322 .53904 .32792 .54809 .33753 .54683 .33164 .53736 Mtetra
.574 .61 .851 r
.33164 .53736 .33753 .54683 .34717 .54575 .34127 .5365 Mtetra
.533 .597 .864 r
.34127 .5365 .34717 .54575 .35686 .54467 .35091 .53659 Mtetra
.513 .621 .895 r
.35091 .53659 .35686 .54467 .36664 .54263 .36059 .53681 Mtetra
.495 .692 .956 r
.36059 .53681 .36664 .54263 .37653 .53889 .37034 .53662 Mtetra
.52 .85 .997 r
.37034 .53662 .37653 .53889 .38656 .53284 .38024 .53445 Mtetra
.539 .925 .835 r
.38024 .53445 .38656 .53284 .39671 .52398 .3903 .52908 Mtetra
.513 .854 .585 r
.3903 .52908 .39671 .52398 .40689 .5144 .40052 .52023 Mtetra
.707 .931 .611 r
.40052 .52023 .40689 .5144 .41704 .50553 .41086 .50785 Mtetra
.864 .996 .798 r
.41086 .50785 .41704 .50553 .42708 .50069 .42116 .49622 Mtetra
.807 .822 .862 r
.42116 .49622 .42708 .50069 .43699 .50181 .43135 .48803 Mtetra
.618 .562 .769 r
.43135 .48803 .43699 .50181 .44688 .50632 .44141 .4855 Mtetra
.471 .409 .707 r
.44141 .4855 .44688 .50632 .45682 .51258 .45135 .48968 Mtetra
.429 .369 .689 r
.45135 .48968 .45682 .51258 .46689 .51637 .46134 .49616 Mtetra
.414 .378 .71 r
.46134 .49616 .46689 .51637 .47712 .5154 .47143 .50242 Mtetra
.434 .473 .801 r
.47143 .50242 .47712 .5154 .48744 .51063 .48165 .50578 Mtetra
.512 .744 .979 r
.48165 .50578 .48744 .51063 .49782 .5027 .49199 .50488 Mtetra
0 0 0 r
.49199 .50488 .49782 .5027 .50821 .49403 .50241 .50129 Mtetra
.087 0 0 r
.50241 .50129 .50821 .49403 .5186 .48599 .51287 .49593 Mtetra
.215 0 .045 r
.51287 .49593 .5186 .48599 .52901 .47923 .52336 .4905 Mtetra
.299 0 .125 r
.52336 .4905 .52901 .47923 .53944 .47423 .53387 .48589 Mtetra
.362 0 .165 r
.53387 .48589 .53944 .47423 .54991 .47092 .54443 .48257 Mtetra
.41 .021 .188 r
.54443 .48257 .54991 .47092 .56044 .4693 .55503 .48054 Mtetra
.434 .039 .189 r
.55503 .48054 .56044 .4693 .57105 .46946 .5657 .47936 Mtetra
.413 .001 .144 r
.5657 .47936 .57105 .46946 .58174 .47092 .57642 .47809 Mtetra
.258 0 0 r
.57642 .47809 .58174 .47092 .59252 .47302 .58717 .47506 Mtetra
.432 .858 .728 r
.58717 .47506 .59252 .47302 .60336 .47441 .59789 .46931 Mtetra
.835 .827 .84 r
.59789 .46931 .60336 .47441 .61418 .47261 .60854 .45924 Mtetra
.777 .652 .724 r
.60854 .45924 .61418 .47261 .62494 .46695 .61909 .4462 Mtetra
.726 .572 .681 r
.61909 .4462 .62494 .46695 .63556 .45647 .62962 .43291 Mtetra
.691 .537 .674 r
.62962 .43291 .63556 .45647 .64609 .44344 .6402 .42192 Mtetra
.622 .505 .699 r
.6402 .42192 .64609 .44344 .65666 .43216 .65104 .41774 Mtetra
.512 .501 .782 r
.65104 .41774 .65666 .43216 .66738 .42431 .66217 .41933 Mtetra
0 .425 .855 r
.66217 .41933 .66738 .42431 .67839 .42254 .67353 .42446 Mtetra
.572 .016 0 r
.67353 .42446 .67839 .42254 .68967 .4249 .68503 .43039 Mtetra
.485 0 .007 r
.68503 .43039 .68967 .4249 .70107 .42801 .69646 .43272 Mtetra
.273 0 0 r
.69646 .43272 .70107 .42801 .71253 .43041 .70777 .4315 Mtetra
.362 .828 .763 r
.70777 .4315 .71253 .43041 .72389 .42992 .71895 .42699 Mtetra
.754 .919 .945 r
.71895 .42699 .72389 .42992 .73516 .42706 .73003 .42042 Mtetra
.759 .783 .873 r
.73003 .42042 .73516 .42706 .74637 .42245 .74111 .41342 Mtetra
.734 .712 .83 r
.74111 .41342 .74637 .42245 .75754 .41684 .75222 .40654 Mtetra
.703 .673 .818 r
.75222 .40654 .75754 .41684 .76874 .4112 .76342 .40064 Mtetra
.682 .659 .82 r
.76342 .40064 .76874 .4112 .77998 .40576 .77472 .39557 Mtetra
.664 .658 .834 r
.77472 .39557 .77998 .40576 .79131 .40091 .78612 .39135 Mtetra
.651 .667 .852 r
.78612 .39135 .79131 .40091 .80272 .39653 .79762 .38771 Mtetra
.644 .683 .872 r
.79762 .38771 .80272 .39653 .81421 .39258 .80919 .38438 Mtetra
.638 .698 .889 r
.80919 .38438 .81421 .39258 .82577 .38892 .82082 .38124 Mtetra
.638 .714 .902 r
.82082 .38124 .82577 .38892 .83739 .38543 .83251 .37809 Mtetra
.638 .725 .911 r
.83251 .37809 .83739 .38543 .84907 .38203 .84425 .37492 Mtetra
.639 .734 .918 r
.84425 .37492 .84907 .38203 .8608 .37866 .85603 .37169 Mtetra
.641 .741 .921 r
.85603 .37169 .8608 .37866 .87259 .37524 .86786 .36837 Mtetra
.668 .754 .915 r
.23902 .55988 .24535 .5654 .25483 .56203 .24851 .55657 Mtetra
.672 .758 .915 r
.24851 .55657 .25483 .56203 .26434 .55856 .25804 .55315 Mtetra
.677 .762 .915 r
.25804 .55315 .26434 .55856 .27389 .55504 .26761 .5496 Mtetra
.682 .762 .912 r
.26761 .5496 .27389 .55504 .28347 .55151 .27722 .54591 Mtetra
.688 .759 .906 r
.27722 .54591 .28347 .55151 .29308 .54797 .28688 .54203 Mtetra
.689 .748 .897 r
.28688 .54203 .29308 .54797 .30271 .5446 .29657 .53808 Mtetra
.686 .73 .884 r
.29657 .53808 .30271 .5446 .31236 .54154 .30629 .53414 Mtetra
.671 .701 .869 r
.30629 .53414 .31236 .54154 .322 .53904 .31601 .53054 Mtetra
.647 .664 .853 r
.31601 .53054 .322 .53904 .33164 .53736 .32574 .52757 Mtetra
.612 .621 .836 r
.32574 .52757 .33164 .53736 .34127 .5365 .33544 .52561 Mtetra
.565 .578 .825 r
.33544 .52561 .34127 .5365 .35091 .53659 .34511 .52505 Mtetra
.525 .546 .819 r
.34511 .52505 .35091 .53659 .36059 .53681 .35477 .52565 Mtetra
.477 .528 .831 r
.35477 .52565 .36059 .53681 .37034 .53662 .36443 .52735 Mtetra
.474 .57 .872 r
.36443 .52735 .37034 .53662 .38024 .53445 .37418 .5286 Mtetra
.505 .697 .955 r
.37418 .5286 .38024 .53445 .3903 .52908 .38407 .52824 Mtetra
.598 .924 .968 r
.38407 .52824 .3903 .52908 .40052 .52023 .39414 .52422 Mtetra
.634 .937 .699 r
.39414 .52422 .40052 .52023 .41086 .50785 .40443 .51519 Mtetra
.538 .818 .469 r
.40443 .51519 .41086 .50785 .42116 .49622 .41482 .50325 Mtetra
.655 .884 .528 r
.41482 .50325 .42116 .49622 .43135 .48803 .42524 .48993 Mtetra
.819 1 .824 r
.42524 .48993 .43135 .48803 .44141 .4855 .43554 .47989 Mtetra
.692 .772 .913 r
.43554 .47989 .44141 .4855 .45135 .48968 .4457 .47571 Mtetra
.537 .516 .78 r
.4457 .47571 .45135 .48968 .46134 .49616 .45579 .47626 Mtetra
.456 .407 .715 r
.45579 .47626 .46134 .49616 .47143 .50242 .46587 .48081 Mtetra
.457 .397 .702 r
.46587 .48081 .47143 .50242 .48165 .50578 .47604 .4857 Mtetra
.488 .428 .716 r
.47604 .4857 .48165 .50578 .49199 .50488 .48631 .48898 Mtetra
.527 .49 .758 r
.48631 .48898 .49199 .50488 .50241 .50129 .49668 .49011 Mtetra
.586 .59 .823 r
.49668 .49011 .50241 .50129 .51287 .49593 .50713 .48884 Mtetra
.624 .709 .906 r
.50713 .48884 .51287 .49593 .52336 .4905 .51764 .48634 Mtetra
.634 .822 .973 r
.51764 .48634 .52336 .4905 .53387 .48589 .52819 .48315 Mtetra
.607 .873 .992 r
.52819 .48315 .53387 .48589 .54443 .48257 .53878 .47981 Mtetra
.616 .876 .99 r
.53878 .47981 .54443 .48257 .55503 .48054 .54941 .47632 Mtetra
.68 .835 .958 r
.54941 .47632 .55503 .48054 .5657 .47936 .56008 .47214 Mtetra
.717 .74 .87 r
.56008 .47214 .5657 .47936 .57642 .47809 .57076 .46672 Mtetra
.73 .657 .777 r
.57076 .46672 .57642 .47809 .58717 .47506 .58144 .45886 Mtetra
.722 .599 .719 r
.58144 .45886 .58717 .47506 .59789 .46931 .59207 .44883 Mtetra
.713 .566 .687 r
.59207 .44883 .59789 .46931 .60854 .45924 .60267 .43713 Mtetra
.701 .55 .679 r
.60267 .43713 .60854 .45924 .61909 .4462 .61326 .42576 Mtetra
.666 .538 .699 r
.61326 .42576 .61909 .4462 .62962 .43291 .62397 .41842 Mtetra
.613 .558 .769 r
.62397 .41842 .62962 .43291 .6402 .42192 .63485 .41587 Mtetra
.221 .542 .927 r
.63485 .41587 .6402 .42192 .65104 .41774 .64601 .4193 Mtetra
.603 .05 0 r
.64601 .4193 .65104 .41774 .66217 .41933 .65739 .42609 Mtetra
.597 .136 .129 r
.65739 .42609 .66217 .41933 .67353 .42446 .66883 .43151 Mtetra
.508 .045 .088 r
.66883 .43151 .67353 .42446 .68503 .43039 .68024 .43398 Mtetra
.087 0 0 r
.68024 .43398 .68503 .43039 .69646 .43272 .69146 .43132 Mtetra
.713 .962 .943 r
.69146 .43132 .69646 .43272 .70777 .4315 .70254 .42491 Mtetra
.783 .79 .858 r
.70254 .42491 .70777 .4315 .71895 .42699 .71354 .41682 Mtetra
.754 .695 .796 r
.71354 .41682 .71895 .42699 .73003 .42042 .72452 .40826 Mtetra
.717 .647 .778 r
.72452 .40826 .73003 .42042 .74111 .41342 .73559 .40081 Mtetra
.693 .629 .781 r
.73559 .40081 .74111 .41342 .75222 .40654 .74676 .39455 Mtetra
.668 .627 .799 r
.74676 .39455 .75222 .40654 .76342 .40064 .75806 .38973 Mtetra
.65 .638 .825 r
.75806 .38973 .76342 .40064 .77472 .39557 .76947 .38595 Mtetra
.637 .659 .855 r
.76947 .38595 .77472 .39557 .78612 .39135 .78099 .38281 Mtetra
.626 .682 .883 r
.78099 .38281 .78612 .39135 .79762 .38771 .79258 .38004 Mtetra
.624 .708 .906 r
.79258 .38004 .79762 .38771 .80919 .38438 .80423 .37727 Mtetra
.624 .727 .92 r
.80423 .37727 .80919 .38438 .82082 .38124 .81593 .37444 Mtetra
.63 .741 .927 r
.81593 .37444 .82082 .38124 .83251 .37809 .82767 .3714 Mtetra
.635 .748 .93 r
.82767 .3714 .83251 .37809 .84425 .37492 .83944 .36821 Mtetra
.64 .75 .929 r
.83944 .36821 .84425 .37492 .85603 .37169 .85125 .36488 Mtetra
.644 .749 .926 r
.85125 .36488 .85603 .37169 .86786 .36837 .8631 .36144 Mtetra
.656 .752 .92 r
.23264 .55431 .23902 .55988 .24851 .55657 .24213 .55127 Mtetra
.659 .762 .926 r
.24213 .55127 .24851 .55657 .25804 .55315 .25166 .54814 Mtetra
.665 .775 .932 r
.25166 .54814 .25804 .55315 .26761 .5496 .26123 .54485 Mtetra
.674 .788 .934 r
.26123 .54485 .26761 .5496 .27722 .54591 .27085 .54132 Mtetra
.688 .797 .932 r
.27085 .54132 .27722 .54591 .28688 .54203 .28053 .53743 Mtetra
.701 .8 .926 r
.28053 .53743 .28688 .54203 .29657 .53808 .29027 .5332 Mtetra
.715 .792 .912 r
.29027 .5332 .29657 .53808 .30629 .53414 .30006 .52857 Mtetra
.716 .769 .894 r
.30006 .52857 .30629 .53414 .31601 .53054 .30988 .5238 Mtetra
.708 .731 .869 r
.30988 .5238 .31601 .53054 .32574 .52757 .31973 .51904 Mtetra
.679 .677 .841 r
.31973 .51904 .32574 .52757 .33544 .52561 .32957 .51492 Mtetra
.639 .617 .812 r
.32957 .51492 .33544 .52561 .34511 .52505 .33938 .51194 Mtetra
.588 .554 .784 r
.33938 .51194 .34511 .52505 .35477 .52565 .34913 .51065 Mtetra
.527 .496 .765 r
.34913 .51065 .35477 .52565 .36443 .52735 .35882 .5116 Mtetra
.477 .458 .758 r
.35882 .5116 .36443 .52735 .37418 .5286 .36848 .51428 Mtetra
.411 .437 .778 r
.36848 .51428 .37418 .5286 .38407 .52824 .37816 .51839 Mtetra
.374 .505 .861 r
.37816 .51839 .38407 .52824 .39414 .52422 .38796 .52154 Mtetra
.25 .703 .955 r
.38796 .52154 .39414 .52422 .40443 .51519 .39793 .52192 Mtetra
.056 0 0 r
.39793 .52192 .40443 .51519 .41482 .50325 .40815 .51704 Mtetra
0 0 .012 r
.40815 .51704 .41482 .50325 .42524 .48993 .41861 .50552 Mtetra
0 0 .009 r
.41861 .50552 .42524 .48993 .43554 .47989 .42915 .49089 Mtetra
0 0 0 r
.42915 .49089 .43554 .47989 .4457 .47571 .43967 .47551 Mtetra
.893 .951 .835 r
.43967 .47551 .4457 .47571 .45579 .47626 .45008 .46382 Mtetra
.687 .616 .772 r
.45008 .46382 .45579 .47626 .46587 .48081 .46035 .45811 Mtetra
.577 .467 .693 r
.46035 .45811 .46587 .48081 .47604 .4857 .47058 .45688 Mtetra
.524 .407 .662 r
.47058 .45688 .47604 .4857 .48631 .48898 .4808 .45921 Mtetra
.515 .398 .658 r
.4808 .45921 .48631 .48898 .49668 .49011 .4911 .46224 Mtetra
.525 .412 .667 r
.4911 .46224 .49668 .49011 .50713 .48884 .50148 .46439 Mtetra
.547 .441 .685 r
.50148 .46439 .50713 .48884 .51764 .48634 .51194 .465 Mtetra
.581 .48 .704 r
.51194 .465 .51764 .48634 .52819 .48315 .52247 .46354 Mtetra
.615 .512 .714 r
.52247 .46354 .52819 .48315 .53878 .47981 .53304 .46017 Mtetra
.643 .529 .709 r
.53304 .46017 .53878 .47981 .54941 .47632 .54365 .45487 Mtetra
.663 .53 .692 r
.54365 .45487 .54941 .47632 .56008 .47214 .55427 .44749 Mtetra
.667 .518 .673 r
.55427 .44749 .56008 .47214 .57076 .46672 .56488 .43854 Mtetra
.663 .503 .658 r
.56488 .43854 .57076 .46672 .58144 .45886 .57548 .42869 Mtetra
.651 .489 .652 r
.57548 .42869 .58144 .45886 .59207 .44883 .5861 .41953 Mtetra
.619 .471 .658 r
.5861 .41953 .59207 .44883 .60267 .43713 .59679 .41394 Mtetra
.573 .465 .693 r
.59679 .41394 .60267 .43713 .61326 .42576 .60764 .41288 Mtetra
.368 .44 .804 r
.60764 .41288 .61326 .42576 .62397 .41842 .61871 .4179 Mtetra
.637 .076 0 r
.61871 .4179 .62397 .41842 .63485 .41587 .63001 .42671 Mtetra
.646 .243 .265 r
.63001 .42671 .63485 .41587 .64601 .4193 .64141 .43479 Mtetra
.584 .218 .312 r
.64141 .43479 .64601 .4193 .65739 .42609 .65281 .43974 Mtetra
.435 .062 .23 r
.65281 .43974 .65739 .42609 .66883 .43151 .66403 .43794 Mtetra
0 0 0 r
.66403 .43794 .66883 .43151 .68024 .43398 .67506 .43074 Mtetra
.853 .908 .872 r
.67506 .43074 .68024 .43398 .69146 .43132 .68596 .42068 Mtetra
.785 .698 .768 r
.68596 .42068 .69146 .43132 .70254 .42491 .6968 .40961 Mtetra
.724 .612 .733 r
.6968 .40961 .70254 .42491 .71354 .41682 .70773 .39999 Mtetra
.69 .581 .728 r
.70773 .39999 .71354 .41682 .72452 .40826 .71876 .39214 Mtetra
.66 .571 .744 r
.71876 .39214 .72452 .40826 .73559 .40081 .72995 .38658 Mtetra
.637 .58 .773 r
.72995 .38658 .73559 .40081 .74676 .39455 .74129 .38276 Mtetra
.618 .606 .816 r
.74129 .38276 .74676 .39455 .75806 .38973 .75276 .38011 Mtetra
.601 .643 .864 r
.75276 .38011 .75806 .38973 .76947 .38595 .76434 .37813 Mtetra
.594 .69 .909 r
.76434 .37813 .76947 .38595 .78099 .38281 .77597 .37617 Mtetra
.591 .728 .939 r
.77597 .37617 .78099 .38281 .79258 .38004 .78766 .37407 Mtetra
.602 .759 .954 r
.78766 .37407 .79258 .38004 .80423 .37727 .79937 .37155 Mtetra
.615 .775 .958 r
.79937 .37155 .80423 .37727 .81593 .37444 .8111 .36867 Mtetra
.631 .781 .953 r
.8111 .36867 .81593 .37444 .82767 .3714 .82286 .36542 Mtetra
.643 .779 .946 r
.82286 .36542 .82767 .3714 .83944 .36821 .83464 .36192 Mtetra
.651 .772 .937 r
.83464 .36192 .83944 .36821 .85125 .36488 .84645 .35824 Mtetra
.655 .761 .928 r
.84645 .35824 .85125 .36488 .8631 .36144 .85831 .35446 Mtetra
.64 .747 .927 r
.22623 .54871 .23264 .55431 .24213 .55127 .2357 .54602 Mtetra
.639 .761 .936 r
.2357 .54602 .24213 .55127 .25166 .54814 .24521 .5433 Mtetra
.642 .778 .946 r
.24521 .5433 .25166 .54814 .26123 .54485 .25477 .54047 Mtetra
.649 .798 .954 r
.25477 .54047 .26123 .54485 .27085 .54132 .26438 .53741 Mtetra
.661 .82 .96 r
.26438 .53741 .27085 .54132 .28053 .53743 .27405 .53402 Mtetra
.679 .844 .962 r
.27405 .53402 .28053 .53743 .29027 .5332 .28378 .53016 Mtetra
.705 .864 .957 r
.28378 .53016 .29027 .5332 .30006 .52857 .2936 .52568 Mtetra
.729 .873 .948 r
.2936 .52568 .30006 .52857 .30988 .5238 .30347 .52063 Mtetra
.753 .863 .93 r
.30347 .52063 .30988 .5238 .31973 .51904 .31341 .51494 Mtetra
.753 .829 .91 r
.31341 .51494 .31973 .51904 .32957 .51492 .32338 .50915 Mtetra
.736 .769 .879 r
.32338 .50915 .32957 .51492 .33938 .51194 .33335 .50357 Mtetra
.688 .686 .843 r
.33335 .50357 .33938 .51194 .34913 .51065 .34329 .49914 Mtetra
.622 .597 .804 r
.34329 .49914 .34913 .51065 .35882 .5116 .35315 .49665 Mtetra
.552 .512 .764 r
.35315 .49665 .35882 .5116 .36848 .51428 .36293 .49665 Mtetra
.477 .439 .736 r
.36293 .49665 .36848 .51428 .37816 .51839 .37263 .49967 Mtetra
.432 .401 .724 r
.37263 .49967 .37816 .51839 .38796 .52154 .38233 .50446 Mtetra
.389 .391 .74 r
.38233 .50446 .38796 .52154 .39793 .52192 .39208 .51003 Mtetra
.437 .496 .822 r
.39208 .51003 .39793 .52192 .40815 .51704 .40203 .51274 Mtetra
.607 .803 .975 r
.40203 .51274 .40815 .51704 .41861 .50552 .41223 .51017 Mtetra
.453 .829 .587 r
.41223 .51017 .41861 .50552 .42915 .49089 .42264 .50223 Mtetra
0 0 0 r
.42264 .50223 .42915 .49089 .43967 .47551 .4332 .48916 Mtetra
.4332 .48916 .43967 .47551 .45008 .46382 .44376 .47547 Mtetra
.44376 .47547 .45008 .46382 .46035 .45811 .45424 .46369 Mtetra
.45424 .46369 .46035 .45811 .47058 .45688 .46466 .45523 Mtetra
.653 .922 .976 r
.46466 .45523 .47058 .45688 .4808 .45921 .47502 .45075 Mtetra
.618 .666 .874 r
.47502 .45075 .4808 .45921 .4911 .46224 .48538 .44844 Mtetra
.581 .546 .781 r
.48538 .44844 .4911 .46224 .50148 .46439 .49578 .44729 Mtetra
.582 .511 .74 r
.49578 .44729 .50148 .46439 .51194 .465 .50624 .44599 Mtetra
.596 .505 .721 r
.50624 .44599 .51194 .465 .52247 .46354 .51675 .44378 Mtetra
.615 .51 .712 r
.51675 .44378 .52247 .46354 .53304 .46017 .52731 .44037 Mtetra
.633 .521 .709 r
.52731 .44037 .53304 .46017 .54365 .45487 .53791 .43576 Mtetra
.648 .535 .712 r
.53791 .43576 .54365 .45487 .55427 .44749 .54853 .43022 Mtetra
.658 .555 .727 r
.54853 .43022 .55427 .44749 .56488 .43854 .55917 .42453 Mtetra
.654 .585 .766 r
.55917 .42453 .56488 .43854 .57548 .42869 .56986 .41999 Mtetra
.616 .664 .873 r
.56986 .41999 .57548 .42869 .5861 .41953 .58063 .41766 Mtetra
.006 .559 .823 r
.58063 .41766 .5861 .41953 .59679 .41394 .59152 .41934 Mtetra
.586 .102 .073 r
.59152 .41934 .59679 .41394 .60764 .41288 .60257 .42441 Mtetra
.627 .229 .27 r
.60257 .42441 .60764 .41288 .61871 .4179 .61378 .43145 Mtetra
.611 .23 .295 r
.61378 .43145 .61871 .4179 .63001 .42671 .62509 .43789 Mtetra
.499 .094 .203 r
.62509 .43789 .63001 .42671 .64141 .43479 .63633 .43914 Mtetra
0 0 0 r
.63633 .43914 .64141 .43479 .65281 .43974 .64744 .43492 Mtetra
.831 .85 .861 r
.64744 .43492 .65281 .43974 .66403 .43794 .65837 .4253 Mtetra
.782 .668 .738 r
.65837 .4253 .66403 .43794 .67506 .43074 .66917 .41273 Mtetra
.73 .593 .703 r
.66917 .41273 .67506 .43074 .68596 .42068 .67999 .40092 Mtetra
.7 .564 .699 r
.67999 .40092 .68596 .42068 .6968 .40961 .69089 .39091 Mtetra
.668 .553 .716 r
.69089 .39091 .6968 .40961 .70773 .39999 .70196 .38398 Mtetra
.641 .561 .75 r
.70196 .38398 .70773 .39999 .71876 .39214 .7132 .37961 Mtetra
.61 .59 .805 r
.7132 .37961 .71876 .39214 .72995 .38658 .7246 .37722 Mtetra
.572 .635 .875 r
.7246 .37722 .72995 .38658 .74129 .38276 .73614 .37604 Mtetra
.538 .7 .944 r
.73614 .37604 .74129 .38276 .75276 .38011 .74776 .37509 Mtetra
.504 .752 .984 r
.74776 .37509 .75276 .38011 .76434 .37813 .75945 .37402 Mtetra
.513 .796 .997 r
.75945 .37402 .76434 .37813 .77597 .37617 .77114 .37231 Mtetra
.541 .821 .998 r
.77114 .37231 .77597 .37617 .78766 .37407 .78285 .37001 Mtetra
.586 .833 .992 r
.78285 .37001 .78766 .37407 .79937 .37155 .79457 .36705 Mtetra
.622 .831 .98 r
.79457 .36705 .79937 .37155 .8111 .36867 .8063 .36361 Mtetra
.646 .818 .966 r
.8063 .36361 .8111 .36867 .82286 .36542 .81804 .35982 Mtetra
.661 .802 .951 r
.81804 .35982 .82286 .36542 .83464 .36192 .82982 .35578 Mtetra
.668 .786 .937 r
.82982 .35578 .83464 .36192 .84645 .35824 .84162 .35162 Mtetra
.669 .77 .926 r
.84162 .35162 .84645 .35824 .85831 .35446 .85348 .34743 Mtetra
.625 .743 .932 r
.21976 .54307 .22623 .54871 .2357 .54602 .22923 .54068 Mtetra
.619 .753 .942 r
.22923 .54068 .2357 .54602 .24521 .5433 .23873 .53835 Mtetra
.615 .768 .953 r
.23873 .53835 .24521 .5433 .25477 .54047 .24826 .53602 Mtetra
.613 .788 .965 r
.24826 .53602 .25477 .54047 .26438 .53741 .25785 .5336 Mtetra
.609 .814 .979 r
.25785 .5336 .26438 .53741 .27405 .53402 .26748 .53106 Mtetra
.614 .85 .988 r
.26748 .53106 .27405 .53402 .28378 .53016 .27717 .52814 Mtetra
.624 .889 .988 r
.27717 .52814 .28378 .53016 .2936 .52568 .28694 .52466 Mtetra
.643 .928 .973 r
.28694 .52466 .2936 .52568 .30347 .52063 .2968 .52039 Mtetra
.684 .957 .948 r
.2968 .52039 .30347 .52063 .31341 .51494 .30676 .51505 Mtetra
.73 .971 .93 r
.30676 .51505 .31341 .51494 .32338 .50915 .31681 .50873 Mtetra
.791 .961 .919 r
.31681 .50873 .32338 .50915 .33335 .50357 .32693 .50139 Mtetra
.809 .901 .906 r
.32693 .50139 .33335 .50357 .34329 .49914 .33708 .4938 Mtetra
.779 .79 .862 r
.33708 .4938 .34329 .49914 .35315 .49665 .34722 .48653 Mtetra
.704 .657 .801 r
.34722 .48653 .35315 .49665 .36293 .49665 .35729 .4808 Mtetra
.623 .543 .744 r
.35729 .4808 .36293 .49665 .37263 .49967 .36727 .47765 Mtetra
.552 .454 .697 r
.36727 .47765 .37263 .49967 .38233 .50446 .37713 .47779 Mtetra
.486 .388 .669 r
.37713 .47779 .38233 .50446 .39208 .51003 .38689 .48185 Mtetra
.436 .348 .658 r
.38689 .48185 .39208 .51003 .40203 .51274 .39662 .48885 Mtetra
.36 .318 .675 r
.39662 .48885 .40203 .51274 .41223 .51017 .40638 .49778 Mtetra
.227 .363 .793 r
.40638 .49778 .41223 .51017 .42264 .50223 .41632 .50454 Mtetra
.388 0 0 r
.41632 .50454 .42264 .50223 .4332 .48916 .42651 .50642 Mtetra
.391 .048 .259 r
.42651 .50642 .4332 .48916 .44376 .47547 .43693 .50224 Mtetra
.327 .04 .315 r
.43693 .50224 .44376 .47547 .45424 .46369 .44753 .49171 Mtetra
.282 .007 .306 r
.44753 .49171 .45424 .46369 .46466 .45523 .45818 .47855 Mtetra
.203 0 .244 r
.45818 .47855 .46466 .45523 .47502 .45075 .46881 .46495 Mtetra
.006 0 .036 r
.46881 .46495 .47502 .45075 .48538 .44844 .4794 .453 Mtetra
.534 .869 .602 r
.4794 .453 .48538 .44844 .49578 .44729 .48994 .4438 Mtetra
.784 .876 .915 r
.48994 .4438 .49578 .44729 .50624 .44599 .50047 .43679 Mtetra
.692 .68 .834 r
.50047 .43679 .50624 .44599 .51675 .44378 .51101 .43183 Mtetra
.641 .607 .8 r
.51101 .43183 .51675 .44378 .52731 .44037 .52158 .42839 Mtetra
.601 .587 .809 r
.52158 .42839 .52731 .44037 .53791 .43576 .53219 .42647 Mtetra
.521 .604 .877 r
.53219 .42647 .53791 .43576 .54853 .43022 .54286 .42662 Mtetra
.101 .573 .91 r
.54286 .42662 .54853 .43022 .55917 .42453 .55362 .42899 Mtetra
.585 .085 .033 r
.55362 .42899 .55917 .42453 .56986 .41999 .56449 .43414 Mtetra
.618 .242 .309 r
.56449 .43414 .56986 .41999 .58063 .41766 .57549 .441 Mtetra
.594 .265 .383 r
.57549 .441 .58063 .41766 .59152 .41934 .5866 .44744 Mtetra
.56 .249 .398 r
.5866 .44744 .59152 .41934 .60257 .42441 .59776 .45126 Mtetra
.478 .173 .369 r
.59776 .45126 .60257 .42441 .61378 .43145 .60884 .44865 Mtetra
.269 0 .216 r
.60884 .44865 .61378 .43145 .62509 .43789 .6198 .43988 Mtetra
.868 .992 .742 r
.6198 .43988 .62509 .43789 .63633 .43914 .6306 .42611 Mtetra
.81 .675 .714 r
.6306 .42611 .63633 .43914 .64744 .43492 .6413 .4101 Mtetra
.711 .546 .664 r
.6413 .4101 .64744 .43492 .65837 .4253 .65203 .39602 Mtetra
.669 .504 .653 r
.65203 .39602 .65837 .4253 .66917 .41273 .66286 .3849 Mtetra
.636 .488 .664 r
.66286 .3849 .66917 .41273 .67999 .40092 .67386 .37778 Mtetra
.609 .491 .693 r
.67386 .37778 .67999 .40092 .69089 .39091 .68506 .37404 Mtetra
.576 .516 .751 r
.68506 .37404 .69089 .39091 .70196 .38398 .69644 .37293 Mtetra
.52 .569 .845 r
.69644 .37293 .70196 .38398 .7132 .37961 .70798 .37343 Mtetra
.419 .66 .96 r
.70798 .37343 .7132 .37961 .7246 .37722 .71962 .37426 Mtetra
.246 .694 .956 r
.71962 .37426 .7246 .37722 .73614 .37604 .73132 .37486 Mtetra
.177 .702 .869 r
.73132 .37486 .73614 .37604 .74776 .37509 .74302 .37441 Mtetra
.228 .744 .856 r
.74302 .37441 .74776 .37509 .75945 .37402 .75473 .37295 Mtetra
.378 .833 .922 r
.75473 .37295 .75945 .37402 .77114 .37231 .76641 .37039 Mtetra
.517 .885 .975 r
.76641 .37039 .77114 .37231 .78285 .37001 .77809 .36699 Mtetra
.611 .888 .99 r
.77809 .36699 .78285 .37001 .79457 .36705 .78977 .36301 Mtetra
.658 .865 .978 r
.78977 .36301 .79457 .36705 .8063 .36361 .80147 .35865 Mtetra
.675 .834 .96 r
.80147 .35865 .8063 .36361 .81804 .35982 .81319 .35413 Mtetra
.683 .809 .943 r
.81319 .35413 .81804 .35982 .82982 .35578 .82495 .34952 Mtetra
.684 .789 .93 r
.82495 .34952 .82982 .35578 .84162 .35162 .83675 .3449 Mtetra
.681 .773 .921 r
.83675 .3449 .84162 .35162 .85348 .34743 .84861 .34035 Mtetra
.625 .743 .932 r
.21326 .53739 .21976 .54307 .22923 .54068 .22274 .53498 Mtetra
.618 .742 .935 r
.22274 .53498 .22923 .54068 .23873 .53835 .23225 .5327 Mtetra
.611 .742 .938 r
.23225 .5327 .23873 .53835 .24826 .53602 .24179 .53053 Mtetra
.604 .746 .945 r
.24179 .53053 .24826 .53602 .25785 .5336 .25137 .52846 Mtetra
.591 .756 .957 r
.25137 .52846 .25785 .5336 .26748 .53106 .26097 .52653 Mtetra
.585 .78 .972 r
.26097 .52653 .26748 .53106 .27717 .52814 .27062 .52453 Mtetra
.575 .815 .99 r
.27062 .52453 .27717 .52814 .28694 .52466 .28032 .52236 Mtetra
.573 .866 .996 r
.28032 .52236 .28694 .52466 .2968 .52039 .29011 .51962 Mtetra
.569 .913 .969 r
.29011 .51962 .2968 .52039 .30676 .51505 .29999 .516 Mtetra
.558 .934 .891 r
.29999 .516 .30676 .51505 .31681 .50873 .30998 .51119 Mtetra
.577 .938 .804 r
.30998 .51119 .31681 .50873 .32693 .50139 .3201 .50482 Mtetra
.606 .94 .748 r
.3201 .50482 .32693 .50139 .33708 .4938 .33031 .49713 Mtetra
.707 .978 .775 r
.33031 .49713 .33708 .4938 .34722 .48653 .3406 .48819 Mtetra
.802 .997 .854 r
.3406 .48819 .34722 .48653 .35729 .4808 .3509 .47909 Mtetra
.83 .918 .895 r
.3509 .47909 .35729 .4808 .36727 .47765 .36118 .47064 Mtetra
.74 .74 .852 r
.36118 .47064 .36727 .47765 .37713 .47779 .37135 .46445 Mtetra
.62 .571 .778 r
.37135 .46445 .37713 .47779 .38689 .48185 .38139 .46176 Mtetra
.519 .446 .714 r
.38139 .46176 .38689 .48185 .39662 .48885 .3913 .46335 Mtetra
.436 .36 .673 r
.3913 .46335 .39662 .48885 .40638 .49778 .4011 .4696 Mtetra
.418 .336 .657 r
.4011 .4696 .40638 .49778 .41632 .50454 .41094 .47741 Mtetra
.425 .346 .664 r
.41094 .47741 .41632 .50454 .42651 .50642 .42091 .48466 Mtetra
.478 .411 .703 r
.42091 .48466 .42651 .50642 .43693 .50224 .43108 .48832 Mtetra
.591 .553 .78 r
.43108 .48832 .43693 .50224 .44753 .49171 .44147 .48672 Mtetra
.726 .813 .918 r
.44147 .48672 .44753 .49171 .45818 .47855 .45199 .48141 Mtetra
.615 .944 .752 r
.45199 .48141 .45818 .47855 .46881 .46495 .4626 .47336 Mtetra
0 0 0 r
.4626 .47336 .46881 .46495 .4794 .453 .47322 .46482 Mtetra
.133 0 .038 r
.47322 .46482 .4794 .453 .48994 .4438 .48384 .45705 Mtetra
.243 0 .127 r
.48384 .45705 .48994 .4438 .50047 .43679 .49446 .45052 Mtetra
.321 0 .173 r
.49446 .45052 .50047 .43679 .51101 .43183 .50509 .44559 Mtetra
.375 .003 .199 r
.50509 .44559 .51101 .43183 .52158 .42839 .51575 .44214 Mtetra
.423 .048 .22 r
.51575 .44214 .52158 .42839 .53219 .42647 .52645 .44018 Mtetra
.469 .091 .239 r
.52645 .44018 .53219 .42647 .54286 .42662 .53721 .43984 Mtetra
.499 .115 .243 r
.53721 .43984 .54286 .42662 .55362 .42899 .54804 .44075 Mtetra
.512 .113 .221 r
.54804 .44075 .55362 .42899 .56449 .43414 .55895 .44245 Mtetra
.473 .028 .109 r
.55895 .44245 .56449 .43414 .57549 .441 .56994 .44368 Mtetra
.093 0 0 r
.56994 .44368 .57549 .441 .5866 .44744 .58095 .44215 Mtetra
.718 .814 .925 r
.58095 .44215 .5866 .44744 .59776 .45126 .59194 .43686 Mtetra
.743 .631 .735 r
.59194 .43686 .59776 .45126 .60884 .44865 .60283 .42623 Mtetra
.726 .565 .673 r
.60283 .42623 .60884 .44865 .6198 .43988 .61362 .41192 Mtetra
.704 .531 .651 r
.61362 .41192 .6198 .43988 .6306 .42611 .62436 .397 Mtetra
.687 .517 .65 r
.62436 .397 .6306 .42611 .6413 .4101 .63512 .38364 Mtetra
.656 .505 .667 r
.63512 .38364 .6413 .4101 .65203 .39602 .64604 .375 Mtetra
.621 .51 .706 r
.64604 .375 .65203 .39602 .66286 .3849 .65714 .37072 Mtetra
.565 .541 .786 r
.65714 .37072 .66286 .3849 .67386 .37778 .66845 .37004 Mtetra
.416 .602 .923 r
.66845 .37004 .67386 .37778 .68506 .37404 .67993 .37167 Mtetra
.001 .541 .839 r
.67993 .37167 .68506 .37404 .69644 .37293 .69154 .37401 Mtetra
.299 0 0 r
.69154 .37401 .69644 .37293 .70798 .37343 .70323 .37619 Mtetra
.304 0 0 r
.70323 .37619 .70798 .37343 .71962 .37426 .71493 .3771 Mtetra
.208 0 0 r
.71493 .3771 .71962 .37426 .73132 .37486 .72662 .37665 Mtetra
0 0 0 r
.72662 .37665 .73132 .37486 .74302 .37441 .73829 .37461 Mtetra
.319 .808 .821 r
.73829 .37461 .74302 .37441 .75473 .37295 .74992 .37132 Mtetra
.56 .912 .965 r
.74992 .37132 .75473 .37295 .76641 .37039 .76154 .36711 Mtetra
.664 .897 .98 r
.76154 .36711 .76641 .37039 .77809 .36699 .77315 .36232 Mtetra
.693 .851 .958 r
.77315 .36232 .77809 .36699 .78977 .36301 .7848 .35734 Mtetra
.7 .815 .937 r
.7848 .35734 .78977 .36301 .80147 .35865 .79647 .35227 Mtetra
.694 .789 .923 r
.79647 .35227 .80147 .35865 .81319 .35413 .8082 .34734 Mtetra
.69 .774 .916 r
.8082 .34734 .81319 .35413 .82495 .34952 .81998 .34251 Mtetra
.685 .766 .913 r
.81998 .34251 .82495 .34952 .83675 .3449 .83181 .3378 Mtetra
.68 .762 .913 r
.83181 .3378 .83675 .3449 .84861 .34035 .8437 .33321 Mtetra
.641 .748 .926 r
.20671 .53168 .21326 .53739 .22274 .53498 .21624 .52891 Mtetra
.635 .735 .92 r
.21624 .52891 .22274 .53498 .23225 .5327 .2258 .52627 Mtetra
.627 .721 .914 r
.2258 .52627 .23225 .5327 .24179 .53053 .23538 .52382 Mtetra
.615 .709 .912 r
.23538 .52382 .24179 .53053 .25137 .52846 .24498 .52165 Mtetra
.597 .7 .915 r
.24498 .52165 .25137 .52846 .26097 .52653 .25458 .51987 Mtetra
.579 .699 .924 r
.25458 .51987 .26097 .52653 .27062 .52453 .2642 .51842 Mtetra
.552 .709 .944 r
.2642 .51842 .27062 .52453 .28032 .52236 .27384 .51732 Mtetra
.527 .742 .974 r
.27384 .51732 .28032 .52236 .29011 .51962 .28353 .51627 Mtetra
.476 .792 .999 r
.28353 .51627 .29011 .51962 .29999 .516 .29327 .51508 Mtetra
.382 .827 .942 r
.29327 .51508 .29999 .516 .30998 .51119 .30311 .51319 Mtetra
.222 .734 .692 r
.30311 .51319 .30998 .51119 .3201 .50482 .31306 .51012 Mtetra
0 0 0 r
.31306 .51012 .3201 .50482 .33031 .49713 .32316 .50539 Mtetra
.32316 .50539 .33031 .49713 .3406 .48819 .33341 .49849 Mtetra
.33341 .49849 .3406 .48819 .3509 .47909 .34378 .48966 Mtetra
.34378 .48966 .3509 .47909 .36118 .47064 .35425 .47896 Mtetra
.35425 .47896 .36118 .47064 .37135 .46445 .36475 .46753 Mtetra
.828 .998 .782 r
.36475 .46753 .37135 .46445 .38139 .46176 .37523 .4562 Mtetra
.825 .792 .821 r
.37523 .4562 .38139 .46176 .3913 .46335 .38565 .44607 Mtetra
.689 .569 .715 r
.38565 .44607 .3913 .46335 .4011 .4696 .39598 .43821 Mtetra
.597 .447 .649 r
.39598 .43821 .4011 .4696 .41094 .47741 .40618 .4343 Mtetra
.539 .383 .617 r
.40618 .4343 .41094 .47741 .42091 .48466 .41624 .43534 Mtetra
.501 .347 .603 r
.41624 .43534 .42091 .48466 .43108 .48832 .42624 .44079 Mtetra
.462 .321 .603 r
.42624 .44079 .43108 .48832 .44147 .48672 .43623 .44989 Mtetra
.429 .317 .625 r
.43623 .44989 .44147 .48672 .45199 .48141 .44633 .45939 Mtetra
.37 .34 .694 r
.44633 .45939 .45199 .48141 .4626 .47336 .45659 .46729 Mtetra
0 .406 .852 r
.45659 .46729 .4626 .47336 .47322 .46482 .467 .47239 Mtetra
.487 .031 .095 r
.467 .47239 .47322 .46482 .48384 .45705 .47756 .47411 Mtetra
.478 .125 .287 r
.47756 .47411 .48384 .45705 .49446 .45052 .48823 .47355 Mtetra
.466 .145 .337 r
.48823 .47355 .49446 .45052 .50509 .44559 .49896 .4712 Mtetra
.456 .146 .351 r
.49896 .4712 .50509 .44559 .51575 .44214 .50975 .46776 Mtetra
.437 .13 .345 r
.50975 .46776 .51575 .44214 .52645 .44018 .52059 .46322 Mtetra
.388 .076 .31 r
.52059 .46322 .52645 .44018 .53721 .43984 .53146 .45688 Mtetra
.251 0 .195 r
.53146 .45688 .53721 .43984 .54804 .44075 .54233 .44823 Mtetra
0 0 0 r
.54233 .44823 .54804 .44075 .55895 .44245 .55319 .43615 Mtetra
.875 .794 .768 r
.55319 .43615 .55895 .44245 .56994 .44368 .564 .42122 Mtetra
.743 .575 .666 r
.564 .42122 .56994 .44368 .58095 .44215 .57475 .40464 Mtetra
.68 .492 .626 r
.57475 .40464 .58095 .44215 .59194 .43686 .58546 .38841 Mtetra
.634 .445 .609 r
.58546 .38841 .59194 .43686 .60283 .42623 .59621 .37584 Mtetra
.604 .421 .608 r
.59621 .37584 .60283 .42623 .61362 .41192 .60706 .36772 Mtetra
.574 .408 .619 r
.60706 .36772 .61362 .41192 .62436 .397 .61806 .36463 Mtetra
.54 .409 .651 r
.61806 .36463 .62436 .397 .63512 .38364 .62925 .36557 Mtetra
.475 .443 .743 r
.62925 .36557 .63512 .38364 .64604 .375 .64059 .36883 Mtetra
.121 .481 .898 r
.64059 .36883 .64604 .375 .65714 .37072 .65208 .37335 Mtetra
.519 0 0 r
.65208 .37335 .65714 .37072 .66845 .37004 .66368 .378 Mtetra
.549 .094 .125 r
.66368 .378 .66845 .37004 .67993 .37167 .67535 .38193 Mtetra
.507 .083 .17 r
.67535 .38193 .67993 .37167 .69154 .37401 .68702 .38396 Mtetra
.445 .019 .135 r
.68702 .38396 .69154 .37401 .70323 .37619 .69868 .38402 Mtetra
.318 0 .004 r
.69868 .38402 .70323 .37619 .71493 .3771 .71028 .38185 Mtetra
.07 0 0 r
.71028 .38185 .71493 .3771 .72662 .37665 .72184 .37796 Mtetra
.376 .832 .744 r
.72184 .37796 .72662 .37665 .73829 .37461 .73336 .37285 Mtetra
.673 .949 .956 r
.73336 .37285 .73829 .37461 .74992 .37132 .74487 .36699 Mtetra
.731 .874 .947 r
.74487 .36699 .74992 .37132 .76154 .36711 .75641 .36099 Mtetra
.729 .808 .913 r
.75641 .36099 .76154 .36711 .77315 .36232 .76797 .35502 Mtetra
.713 .764 .893 r
.76797 .35502 .77315 .36232 .7848 .35734 .7796 .34942 Mtetra
.7 .742 .884 r
.7796 .34942 .7848 .35734 .79647 .35227 .7913 .34414 Mtetra
.687 .732 .885 r
.7913 .34414 .79647 .35227 .8082 .34734 .80307 .33927 Mtetra
.678 .731 .89 r
.80307 .33927 .8082 .34734 .81998 .34251 .8149 .33467 Mtetra
.672 .736 .898 r
.8149 .33467 .81998 .34251 .83181 .3378 .8268 .33028 Mtetra
.668 .745 .908 r
.8268 .33028 .83181 .3378 .8437 .33321 .83876 .32602 Mtetra
.666 .754 .916 r
.20012 .52592 .20671 .53168 .21624 .52891 .20972 .52254 Mtetra
.663 .733 .902 r
.20972 .52254 .21624 .52891 .2258 .52627 .21936 .51922 Mtetra
.654 .711 .889 r
.21936 .51922 .2258 .52627 .23538 .52382 .22902 .51608 Mtetra
.642 .687 .877 r
.22902 .51608 .23538 .52382 .24498 .52165 .23868 .51323 Mtetra
.625 .664 .868 r
.23868 .51323 .24498 .52165 .25458 .51987 .24835 .51082 Mtetra
.605 .641 .859 r
.24835 .51082 .25458 .51987 .2642 .51842 .25801 .50892 Mtetra
.58 .62 .857 r
.25801 .50892 .2642 .51842 .27384 .51732 .26767 .50769 Mtetra
.558 .608 .859 r
.26767 .50769 .27384 .51732 .28353 .51627 .27733 .50703 Mtetra
.53 .605 .873 r
.27733 .50703 .28353 .51627 .29327 .51508 .287 .50693 Mtetra
.512 .628 .902 r
.287 .50693 .29327 .51508 .30311 .51319 .29672 .50696 Mtetra
.488 .683 .953 r
.29672 .50696 .30311 .51319 .31306 .51012 .3065 .5068 Mtetra
.457 .788 .999 r
.3065 .5068 .31306 .51012 .32316 .50539 .3164 .50573 Mtetra
.34 .82 .86 r
.3164 .50573 .32316 .50539 .33341 .49849 .32644 .50312 Mtetra
0 0 0 r
.32644 .50312 .33341 .49849 .34378 .48966 .33664 .49848 Mtetra
.33664 .49848 .34378 .48966 .35425 .47896 .347 .49131 Mtetra
.347 .49131 .35425 .47896 .36475 .46753 .3575 .48181 Mtetra
.3575 .48181 .36475 .46753 .37523 .4562 .3681 .47011 Mtetra
.3681 .47011 .37523 .4562 .38565 .44607 .37875 .45717 Mtetra
.37875 .45717 .38565 .44607 .39598 .43821 .38938 .44396 Mtetra
.604 .891 .589 r
.38938 .44396 .39598 .43821 .40618 .4343 .3999 .43318 Mtetra
.76 .953 .938 r
.3999 .43318 .40618 .4343 .41624 .43534 .41027 .42651 Mtetra
.61 .655 .869 r
.41027 .42651 .41624 .43534 .42624 .44079 .42051 .42436 Mtetra
.484 .46 .755 r
.42051 .42436 .42624 .44079 .43623 .44989 .43066 .42672 Mtetra
.47 .396 .692 r
.43066 .42672 .43623 .44989 .44633 .45939 .44085 .43087 Mtetra
.484 .381 .662 r
.44085 .43087 .44633 .45939 .45659 .46729 .45112 .43516 Mtetra
.51 .387 .648 r
.45112 .43516 .45659 .46729 .467 .47239 .4615 .43819 Mtetra
.538 .401 .642 r
.4615 .43819 .467 .47239 .47756 .47411 .47201 .43911 Mtetra
.558 .413 .64 r
.47201 .43911 .47756 .47411 .48823 .47355 .4826 .43837 Mtetra
.574 .424 .64 r
.4826 .43837 .48823 .47355 .49896 .4712 .49326 .43606 Mtetra
.586 .433 .64 r
.49326 .43606 .49896 .4712 .50975 .46776 .50399 .43257 Mtetra
.597 .44 .64 r
.50399 .43257 .50975 .46776 .52059 .46322 .51476 .42789 Mtetra
.611 .45 .639 r
.51476 .42789 .52059 .46322 .53146 .45688 .52556 .42163 Mtetra
.626 .46 .638 r
.52556 .42163 .53146 .45688 .54233 .44823 .53639 .41367 Mtetra
.645 .474 .638 r
.53639 .41367 .54233 .44823 .55319 .43615 .54721 .4036 Mtetra
.66 .489 .642 r
.54721 .4036 .55319 .43615 .564 .42122 .55801 .39221 Mtetra
.671 .506 .653 r
.55801 .39221 .564 .42122 .57475 .40464 .56881 .38095 Mtetra
.675 .528 .677 r
.56881 .38095 .57475 .40464 .58546 .38841 .57963 .37147 Mtetra
.646 .554 .737 r
.57963 .37147 .58546 .38841 .59621 .37584 .59055 .36655 Mtetra
.536 .618 .881 r
.59055 .36655 .59621 .37584 .60706 .36772 .60161 .36621 Mtetra
.263 0 0 r
.60161 .36621 .60706 .36772 .61806 .36463 .61285 .37007 Mtetra
.612 .126 .075 r
.61285 .37007 .61806 .36463 .62925 .36557 .62427 .37643 Mtetra
.604 .19 .23 r
.62427 .37643 .62925 .36557 .64059 .36883 .6358 .38255 Mtetra
.577 .189 .269 r
.6358 .38255 .64059 .36883 .65208 .37335 .64739 .38744 Mtetra
.533 .149 .257 r
.64739 .38744 .65208 .37335 .66368 .378 .659 .3901 Mtetra
.468 .067 .195 r
.659 .3901 .66368 .378 .67535 .38193 .67059 .39038 Mtetra
.324 0 .027 r
.67059 .39038 .67535 .38193 .68702 .38396 .68213 .38808 Mtetra
0 0 0 r
.68213 .38808 .68702 .38396 .69868 .38402 .69362 .38368 Mtetra
.609 .953 .905 r
.69362 .38368 .69868 .38402 .71028 .38185 .70507 .37769 Mtetra
.765 .885 .931 r
.70507 .37769 .71028 .38185 .72184 .37796 .71648 .37073 Mtetra
.754 .778 .872 r
.71648 .37073 .72184 .37796 .73336 .37285 .72791 .36358 Mtetra
.733 .718 .836 r
.72791 .36358 .73336 .37285 .74487 .36699 .73937 .35654 Mtetra
.711 .684 .822 r
.73937 .35654 .74487 .36699 .75641 .36099 .7509 .35008 Mtetra
.695 .669 .82 r
.7509 .35008 .75641 .36099 .76797 .35502 .7625 .34419 Mtetra
.68 .664 .827 r
.7625 .34419 .76797 .35502 .7796 .34942 .77418 .33898 Mtetra
.67 .668 .839 r
.77418 .33898 .7796 .34942 .7913 .34414 .78595 .33432 Mtetra
.66 .678 .856 r
.78595 .33432 .7913 .34414 .80307 .33927 .7978 .33009 Mtetra
.654 .691 .873 r
.7978 .33009 .80307 .33927 .8149 .33467 .80973 .32618 Mtetra
.649 .708 .891 r
.80973 .32618 .8149 .33467 .8268 .33028 .82173 .32244 Mtetra
.647 .728 .908 r
.82173 .32244 .8268 .33028 .83876 .32602 .83378 .31877 Mtetra
.69 .759 .904 r
.19348 .52013 .20012 .52592 .20972 .52254 .20317 .51608 Mtetra
.689 .738 .888 r
.20317 .51608 .20972 .52254 .21936 .51922 .2129 .51199 Mtetra
.683 .714 .873 r
.2129 .51199 .21936 .51922 .22902 .51608 .22265 .50795 Mtetra
.673 .689 .857 r
.22265 .50795 .22902 .51608 .23868 .51323 .23241 .5041 Mtetra
.66 .661 .84 r
.23241 .5041 .23868 .51323 .24835 .51082 .24219 .5005 Mtetra
.641 .629 .823 r
.24219 .5005 .24835 .51082 .25801 .50892 .25196 .49738 Mtetra
.619 .597 .807 r
.25196 .49738 .25801 .50892 .26767 .50769 .26171 .4949 Mtetra
.594 .566 .792 r
.26171 .4949 .26767 .50769 .27733 .50703 .27144 .49323 Mtetra
.564 .536 .782 r
.27144 .49323 .27733 .50703 .287 .50693 .28115 .49256 Mtetra
.537 .514 .777 r
.28115 .49256 .287 .50693 .29672 .50696 .29084 .49282 Mtetra
.505 .499 .784 r
.29084 .49282 .29672 .50696 .3065 .5068 .30052 .49403 Mtetra
.477 .506 .809 r
.30052 .49403 .3065 .5068 .3164 .50573 .31024 .49576 Mtetra
.432 .541 .867 r
.31024 .49576 .3164 .50573 .32644 .50312 .32001 .49766 Mtetra
.327 .64 .965 r
.32001 .49766 .32644 .50312 .33664 .49848 .32988 .49898 Mtetra
.063 0 0 r
.32988 .49898 .33664 .49848 .347 .49131 .33989 .49905 Mtetra
.306 0 0 r
.33989 .49905 .347 .49131 .3575 .48181 .35007 .49714 Mtetra
.341 0 .195 r
.35007 .49714 .3575 .48181 .3681 .47011 .36042 .49263 Mtetra
.361 .044 .286 r
.36042 .49263 .3681 .47011 .37875 .45717 .3709 .48602 Mtetra
.369 .076 .331 r
.3709 .48602 .37875 .45717 .38938 .44396 .38148 .47748 Mtetra
.364 .085 .35 r
.38148 .47748 .38938 .44396 .3999 .43318 .39215 .46702 Mtetra
.334 .061 .341 r
.39215 .46702 .3999 .43318 .41027 .42651 .40288 .45471 Mtetra
.238 0 .278 r
.40288 .45471 .41027 .42651 .42051 .42436 .41366 .44049 Mtetra
0 0 0 r
.41366 .44049 .42051 .42436 .43066 .42672 .42446 .42484 Mtetra
.918 .884 .784 r
.42446 .42484 .43066 .42672 .44085 .43087 .4352 .40975 Mtetra
.724 .568 .678 r
.4352 .40975 .44085 .43087 .45112 .43516 .44587 .39642 Mtetra
.64 .462 .626 r
.44587 .39642 .45112 .43516 .4615 .43819 .45645 .38576 Mtetra
.599 .414 .603 r
.45645 .38576 .4615 .43819 .47201 .43911 .46698 .37803 Mtetra
.58 .393 .593 r
.46698 .37803 .47201 .43911 .4826 .43837 .47749 .37224 Mtetra
.569 .382 .588 r
.47749 .37224 .4826 .43837 .49326 .43606 .48801 .36789 Mtetra
.564 .376 .586 r
.48801 .36789 .49326 .43606 .50399 .43257 .49856 .36432 Mtetra
.56 .373 .585 r
.49856 .36432 .50399 .43257 .51476 .42789 .50914 .36153 Mtetra
.552 .369 .587 r
.50914 .36153 .51476 .42789 .52556 .42163 .51977 .36019 Mtetra
.541 .364 .591 r
.51977 .36019 .52556 .42163 .53639 .41367 .53046 .3608 Mtetra
.518 .356 .6 r
.53046 .3608 .53639 .41367 .54721 .4036 .54124 .36438 Mtetra
.479 .349 .625 r
.54124 .36438 .54721 .4036 .55801 .39221 .55213 .37067 Mtetra
.366 .343 .701 r
.55213 .37067 .55801 .39221 .56881 .38095 .56315 .37878 Mtetra
.58 .01 0 r
.56315 .37878 .56881 .38095 .57963 .37147 .5743 .38751 Mtetra
.614 .244 .317 r
.5743 .38751 .57963 .37147 .59055 .36655 .58556 .39482 Mtetra
.572 .254 .392 r
.58556 .39482 .59055 .36655 .60161 .36621 .59689 .40023 Mtetra
.55 .248 .408 r
.59689 .40023 .60161 .36621 .61285 .37007 .60829 .4038 Mtetra
.531 .231 .402 r
.60829 .4038 .61285 .37007 .62427 .37643 .61973 .40542 Mtetra
.505 .197 .377 r
.61973 .40542 .62427 .37643 .6358 .38255 .63118 .40508 Mtetra
.459 .133 .324 r
.63118 .40508 .6358 .38255 .64739 .38744 .64263 .40261 Mtetra
.341 0 .2 r
.64263 .40261 .64739 .38744 .659 .3901 .65403 .39747 Mtetra
0 0 0 r
.65403 .39747 .659 .3901 .67059 .39038 .66537 .39029 Mtetra
.746 .991 .878 r
.66537 .39029 .67059 .39038 .68213 .38808 .67667 .3818 Mtetra
.805 .816 .859 r
.67667 .3818 .68213 .38808 .69362 .38368 .68796 .37269 Mtetra
.752 .689 .791 r
.68796 .37269 .69362 .38368 .70507 .37769 .69927 .36375 Mtetra
.718 .631 .76 r
.69927 .36375 .70507 .37769 .71648 .37073 .71061 .35531 Mtetra
.692 .601 .749 r
.71061 .35531 .71648 .37073 .72791 .36358 .72203 .34785 Mtetra
.675 .589 .751 r
.72203 .34785 .72791 .36358 .73937 .35654 .73353 .34134 Mtetra
.661 .588 .762 r
.73353 .34134 .73937 .35654 .7509 .35008 .74513 .33586 Mtetra
.65 .594 .779 r
.74513 .33586 .7509 .35008 .7625 .34419 .75683 .3312 Mtetra
.641 .608 .801 r
.75683 .3312 .7625 .34419 .77418 .33898 .76863 .32722 Mtetra
.634 .625 .824 r
.76863 .32722 .77418 .33898 .78595 .33432 .78052 .32373 Mtetra
.63 .647 .849 r
.78052 .32373 .78595 .33432 .7978 .33009 .79248 .32051 Mtetra
.626 .669 .872 r
.79248 .32051 .7978 .33009 .80973 .32618 .80451 .31747 Mtetra
.623 .692 .893 r
.80451 .31747 .80973 .32618 .82173 .32244 .81661 .31449 Mtetra
.623 .715 .912 r
.81661 .31449 .82173 .32244 .83378 .31877 .82876 .31146 Mtetra
.7 .761 .899 r
.18679 .51429 .19348 .52013 .20317 .51608 .19653 .50993 Mtetra
.702 .752 .89 r
.19653 .50993 .20317 .51608 .2129 .51199 .20632 .50543 Mtetra
.702 .74 .881 r
.20632 .50543 .2129 .51199 .22265 .50795 .21614 .50086 Mtetra
.7 .725 .869 r
.21614 .50086 .22265 .50795 .23241 .5041 .22599 .49625 Mtetra
.695 .704 .854 r
.22599 .49625 .23241 .5041 .24219 .5005 .23587 .49162 Mtetra
.684 .676 .837 r
.23587 .49162 .24219 .5005 .25196 .49738 .24576 .48717 Mtetra
.668 .644 .817 r
.24576 .48717 .25196 .49738 .26171 .4949 .25566 .48305 Mtetra
.644 .605 .795 r
.25566 .48305 .26171 .4949 .27144 .49323 .26554 .47952 Mtetra
.617 .566 .774 r
.26554 .47952 .27144 .49323 .28115 .49256 .27539 .47684 Mtetra
.587 .526 .754 r
.27539 .47684 .28115 .49256 .29084 .49282 .2852 .47521 Mtetra
.555 .489 .736 r
.2852 .47521 .29084 .49282 .30052 .49403 .29497 .47487 Mtetra
.527 .459 .723 r
.29497 .47487 .30052 .49403 .31024 .49576 .30471 .47575 Mtetra
.499 .435 .716 r
.30471 .47575 .31024 .49576 .32001 .49766 .31444 .47787 Mtetra
.481 .426 .719 r
.31444 .47787 .32001 .49766 .32988 .49898 .3242 .48069 Mtetra
.465 .43 .734 r
.3242 .48069 .32988 .49898 .33989 .49905 .33401 .4838 Mtetra
.461 .462 .773 r
.33401 .4838 .33989 .49905 .35007 .49714 .34393 .48643 Mtetra
.463 .544 .853 r
.34393 .48643 .35007 .49714 .36042 .49263 .35398 .48793 Mtetra
.401 .712 .986 r
.35398 .48793 .36042 .49263 .3709 .48602 .36416 .48806 Mtetra
0 0 0 r
.36416 .48806 .3709 .48602 .38148 .47748 .3745 .48633 Mtetra
.159 0 0 r
.3745 .48633 .38148 .47748 .39215 .46702 .38501 .48158 Mtetra
.159 0 .088 r
.38501 .48158 .39215 .46702 .40288 .45471 .39569 .47317 Mtetra
.129 0 .138 r
.39569 .47317 .40288 .45471 .41366 .44049 .40651 .46153 Mtetra
.101 0 .158 r
.40651 .46153 .41366 .44049 .42446 .42484 .41739 .44736 Mtetra
.147 0 .196 r
.41739 .44736 .42446 .42484 .4352 .40975 .42824 .43338 Mtetra
.225 0 .24 r
.42824 .43338 .4352 .40975 .44587 .39642 .43902 .4211 Mtetra
.307 .008 .283 r
.43902 .4211 .44587 .39642 .45645 .38576 .44973 .41123 Mtetra
.377 .072 .316 r
.44973 .41123 .45645 .38576 .46698 .37803 .46038 .40407 Mtetra
.414 .108 .333 r
.46038 .40407 .46698 .37803 .47749 .37224 .47102 .3986 Mtetra
.439 .13 .344 r
.47102 .3986 .47749 .37224 .48801 .36789 .48167 .39435 Mtetra
.451 .141 .349 r
.48167 .39435 .48801 .36789 .49856 .36432 .49236 .39078 Mtetra
.462 .151 .352 r
.49236 .39078 .49856 .36432 .50914 .36153 .50308 .38789 Mtetra
.481 .168 .358 r
.50308 .38789 .50914 .36153 .51977 .36019 .51384 .38623 Mtetra
.506 .189 .364 r
.51384 .38623 .51977 .36019 .53046 .3608 .52466 .38628 Mtetra
.543 .22 .371 r
.52466 .38628 .53046 .3608 .54124 .36438 .53556 .38906 Mtetra
.573 .245 .375 r
.53556 .38906 .54124 .36438 .55213 .37067 .54656 .39431 Mtetra
.595 .261 .373 r
.54656 .39431 .55213 .37067 .56315 .37878 .55768 .40131 Mtetra
.599 .259 .366 r
.55768 .40131 .56315 .37878 .5743 .38751 .56892 .40853 Mtetra
.568 .224 .345 r
.56892 .40853 .5743 .38751 .58556 .39482 .58024 .41322 Mtetra
.515 .16 .303 r
.58024 .41322 .58556 .39482 .59689 .40023 .59159 .41466 Mtetra
.411 .035 .21 r
.59159 .41466 .59689 .40023 .60829 .4038 .60294 .4124 Mtetra
.156 0 0 r
.60294 .4124 .60829 .4038 .61973 .40542 .61426 .40703 Mtetra
.568 .932 .786 r
.61426 .40703 .61973 .40542 .63118 .40508 .62556 .39978 Mtetra
.805 .843 .879 r
.62556 .39978 .63118 .40508 .64263 .40261 .63683 .39109 Mtetra
.761 .683 .776 r
.63683 .39109 .64263 .40261 .65403 .39747 .64806 .38123 Mtetra
.727 .61 .727 r
.64806 .38123 .65403 .39747 .66537 .39029 .65927 .37085 Mtetra
.702 .571 .705 r
.65927 .37085 .66537 .39029 .67667 .3818 .6705 .36075 Mtetra
.685 .551 .697 r
.6705 .36075 .67667 .3818 .68796 .37269 .68176 .35135 Mtetra
.669 .54 .699 r
.68176 .35135 .68796 .37269 .69927 .36375 .6931 .3432 Mtetra
.657 .538 .707 r
.6931 .3432 .69927 .36375 .71061 .35531 .70452 .3363 Mtetra
.644 .542 .724 r
.70452 .3363 .71061 .35531 .72203 .34785 .71605 .33072 Mtetra
.634 .553 .745 r
.71605 .33072 .72203 .34785 .73353 .34134 .72768 .32623 Mtetra
.625 .57 .772 r
.72768 .32623 .73353 .34134 .74513 .33586 .73942 .32261 Mtetra
.617 .592 .802 r
.73942 .32261 .74513 .33586 .75683 .3312 .75125 .31961 Mtetra
.612 .618 .833 r
.75125 .31961 .75683 .3312 .76863 .32722 .76317 .31695 Mtetra
.607 .644 .861 r
.76317 .31695 .76863 .32722 .78052 .32373 .77516 .31447 Mtetra
.607 .67 .884 r
.77516 .31447 .78052 .32373 .79248 .32051 .78721 .31198 Mtetra
.606 .69 .902 r
.78721 .31198 .79248 .32051 .80451 .31747 .79932 .30946 Mtetra
.607 .707 .915 r
.79932 .30946 .80451 .31747 .81661 .31449 .81149 .30685 Mtetra
.61 .721 .924 r
.81149 .30685 .81661 .31449 .82876 .31146 .82371 .3041 Mtetra
.695 .76 .902 r
.18006 .50842 .18679 .51429 .19653 .50993 .18981 .50418 Mtetra
.701 .766 .902 r
.18981 .50418 .19653 .50993 .20632 .50543 .19961 .49977 Mtetra
.708 .771 .901 r
.19961 .49977 .20632 .50543 .21614 .50086 .20946 .49515 Mtetra
.715 .771 .896 r
.20946 .49515 .21614 .50086 .22599 .49625 .21935 .49028 Mtetra
.723 .765 .886 r
.21935 .49028 .22599 .49625 .23587 .49162 .22931 .4851 Mtetra
.724 .749 .872 r
.22931 .4851 .23587 .49162 .24576 .48717 .2393 .4797 Mtetra
.721 .723 .851 r
.2393 .4797 .24576 .48717 .25566 .48305 .24934 .47413 Mtetra
.708 .686 .826 r
.24934 .47413 .25566 .48305 .26554 .47952 .25939 .46863 Mtetra
.688 .641 .798 r
.25939 .46863 .26554 .47952 .27539 .47684 .26944 .46339 Mtetra
.66 .592 .767 r
.26944 .46339 .27539 .47684 .2852 .47521 .27948 .45872 Mtetra
.63 .543 .738 r
.27948 .45872 .2852 .47521 .29497 .47487 .28948 .45493 Mtetra
.599 .498 .711 r
.28948 .45493 .29497 .47487 .30471 .47575 .29944 .45226 Mtetra
.57 .458 .687 r
.29944 .45226 .30471 .47575 .31444 .47787 .30935 .45096 Mtetra
.546 .427 .669 r
.30935 .45096 .31444 .47787 .3242 .48069 .31922 .45102 Mtetra
.525 .403 .656 r
.31922 .45102 .3242 .48069 .33401 .4838 .32907 .45248 Mtetra
.507 .385 .648 r
.32907 .45248 .33401 .4838 .34393 .48643 .33892 .4552 Mtetra
.49 .374 .648 r
.33892 .4552 .34393 .48643 .35398 .48793 .34878 .45902 Mtetra
.482 .377 .659 r
.34878 .45902 .35398 .48793 .36416 .48806 .35872 .46304 Mtetra
.48 .394 .681 r
.35872 .46304 .36416 .48806 .3745 .48633 .36876 .46662 Mtetra
.485 .432 .723 r
.36876 .46662 .3745 .48633 .38501 .48158 .37893 .46926 Mtetra
.48 .522 .824 r
.37893 .46926 .38501 .48158 .39569 .47317 .38922 .47074 Mtetra
.012 .555 .838 r
.38922 .47074 .39569 .47317 .40651 .46153 .39958 .47255 Mtetra
.532 .122 .208 r
.39958 .47255 .40651 .46153 .41739 .44736 .40997 .47526 Mtetra
.549 .233 .385 r
.40997 .47526 .41739 .44736 .42824 .43338 .42043 .47856 Mtetra
.547 .263 .435 r
.42043 .47856 .42824 .43338 .43902 .4211 .43097 .48205 Mtetra
.537 .268 .455 r
.43097 .48205 .43902 .4211 .44973 .41123 .44163 .48436 Mtetra
.527 .267 .464 r
.44163 .48436 .44973 .41123 .46038 .40407 .45241 .4849 Mtetra
.521 .265 .468 r
.45241 .4849 .46038 .40407 .47102 .3986 .46328 .48387 Mtetra
.515 .261 .469 r
.46328 .48387 .47102 .3986 .48167 .39435 .47424 .48135 Mtetra
.51 .259 .469 r
.47424 .48135 .48167 .39435 .49236 .39078 .48526 .47784 Mtetra
.506 .255 .468 r
.48526 .47784 .49236 .39078 .50308 .38789 .49633 .47333 Mtetra
.498 .248 .466 r
.49633 .47333 .50308 .38789 .51384 .38623 .50745 .46733 Mtetra
.488 .238 .461 r
.50745 .46733 .51384 .38623 .52466 .38628 .51861 .45973 Mtetra
.473 .222 .452 r
.51861 .45973 .52466 .38628 .53556 .38906 .52977 .45033 Mtetra
.451 .196 .435 r
.52977 .45033 .53556 .38906 .54656 .39431 .54094 .43971 Mtetra
.42 .154 .402 r
.54094 .43971 .54656 .39431 .55768 .40131 .5521 .42927 Mtetra
.346 .054 .319 r
.5521 .42927 .55768 .40131 .56892 .40853 .56328 .41939 Mtetra
.036 0 0 r
.56328 .41939 .56892 .40853 .58024 .41322 .57446 .41041 Mtetra
.816 .925 .907 r
.57446 .41041 .58024 .41322 .59159 .41466 .58566 .40174 Mtetra
.747 .655 .759 r
.58566 .40174 .59159 .41466 .60294 .4124 .59685 .39188 Mtetra
.704 .565 .695 r
.59685 .39188 .60294 .4124 .61426 .40703 .60801 .38102 Mtetra
.682 .525 .666 r
.60801 .38102 .61426 .40703 .62556 .39978 .61916 .3697 Mtetra
.665 .5 .651 r
.61916 .3697 .62556 .39978 .63683 .39109 .6303 .35855 Mtetra
.648 .481 .645 r
.6303 .35855 .63683 .39109 .64806 .38123 .64148 .3485 Mtetra
.636 .473 .645 r
.64148 .3485 .64806 .38123 .65927 .37085 .65271 .33973 Mtetra
.627 .472 .652 r
.65271 .33973 .65927 .37085 .6705 .36075 .66401 .33238 Mtetra
.619 .476 .665 r
.66401 .33238 .6705 .36075 .68176 .35135 .6754 .32642 Mtetra
.611 .485 .684 r
.6754 .32642 .68176 .35135 .6931 .3432 .68689 .32186 Mtetra
.604 .501 .71 r
.68689 .32186 .6931 .3432 .70452 .3363 .6985 .31845 Mtetra
.596 .524 .744 r
.6985 .31845 .70452 .3363 .71605 .33072 .7102 .31594 Mtetra
.588 .554 .783 r
.7102 .31594 .71605 .33072 .72768 .32623 .72201 .31404 Mtetra
.583 .591 .827 r
.72201 .31404 .72768 .32623 .73942 .32261 .73389 .31241 Mtetra
.577 .63 .868 r
.73389 .31241 .73942 .32261 .75125 .31961 .74585 .31086 Mtetra
.578 .669 .901 r
.74585 .31086 .75125 .31961 .76317 .31695 .75786 .30913 Mtetra
.58 .699 .924 r
.75786 .30913 .76317 .31695 .77516 .31447 .76993 .30718 Mtetra
.589 .722 .935 r
.76993 .30718 .77516 .31447 .78721 .31198 .78204 .30491 Mtetra
.598 .734 .94 r
.78204 .30491 .78721 .31198 .79932 .30946 .79418 .30238 Mtetra
.606 .739 .939 r
.79418 .30238 .79932 .30946 .81149 .30685 .80637 .29962 Mtetra
.614 .738 .934 r
.80637 .29962 .81149 .30685 .82371 .3041 .81861 .29669 Mtetra
.67 .755 .914 r
.17328 .5025 .18006 .50842 .18981 .50418 .18299 .49892 Mtetra
.676 .779 .928 r
.18299 .49892 .18981 .50418 .19961 .49977 .19274 .49519 Mtetra
.685 .806 .94 r
.19274 .49519 .19961 .49977 .20946 .49515 .20255 .49121 Mtetra
.697 .833 .948 r
.20255 .49121 .20946 .49515 .21935 .49028 .21243 .48688 Mtetra
.714 .856 .95 r
.21243 .48688 .21935 .49028 .22931 .4851 .22237 .48211 Mtetra
.731 .874 .947 r
.22237 .48211 .22931 .4851 .2393 .4797 .23239 .47687 Mtetra
.75 .881 .939 r
.23239 .47687 .2393 .4797 .24934 .47413 .24247 .4711 Mtetra
.763 .875 .928 r
.24247 .4711 .24934 .47413 .25939 .46863 .25261 .46495 Mtetra
.771 .851 .911 r
.25261 .46495 .25939 .46863 .26944 .46339 .26279 .45846 Mtetra
.765 .809 .888 r
.26279 .45846 .26944 .46339 .27948 .45872 .273 .45192 Mtetra
.745 .75 .856 r
.273 .45192 .27948 .45872 .28948 .45493 .28322 .44554 Mtetra
.712 .68 .818 r
.28322 .44554 .28948 .45493 .29944 .45226 .29341 .43966 Mtetra
.672 .611 .778 r
.29341 .43966 .29944 .45226 .30935 .45096 .30358 .4346 Mtetra
.632 .547 .74 r
.30358 .4346 .30935 .45096 .31922 .45102 .3137 .43063 Mtetra
.596 .494 .708 r
.3137 .43063 .31922 .45102 .32907 .45248 .32377 .42803 Mtetra
.564 .451 .682 r
.32377 .42803 .32907 .45248 .33892 .4552 .33379 .42694 Mtetra
.537 .416 .663 r
.33379 .42694 .33892 .4552 .34878 .45902 .34378 .42747 Mtetra
.525 .397 .648 r
.34378 .42747 .34878 .45902 .35872 .46304 .35378 .4289 Mtetra
.519 .386 .639 r
.35378 .4289 .35872 .46304 .36876 .46662 .36383 .43085 Mtetra
.51 .376 .634 r
.36383 .43085 .36876 .46662 .37893 .46926 .37391 .43357 Mtetra
.499 .368 .634 r
.37391 .43357 .37893 .46926 .38922 .47074 .38404 .43716 Mtetra
.475 .357 .64 r
.38404 .43716 .38922 .47074 .39958 .47255 .39419 .44221 Mtetra
.442 .346 .651 r
.39419 .44221 .39958 .47255 .40997 .47526 .40438 .44865 Mtetra
.434 .357 .671 r
.40438 .44865 .40997 .47526 .42043 .47856 .4147 .45471 Mtetra
.454 .386 .691 r
.4147 .45471 .42043 .47856 .43097 .48205 .42516 .45934 Mtetra
.502 .425 .702 r
.42516 .45934 .43097 .48205 .44163 .48436 .43578 .46158 Mtetra
.553 .458 .701 r
.43578 .46158 .44163 .48436 .45241 .4849 .44654 .46117 Mtetra
.579 .47 .693 r
.44654 .46117 .45241 .4849 .46328 .48387 .45741 .45913 Mtetra
.594 .474 .686 r
.45741 .45913 .46328 .48387 .47424 .48135 .46834 .45599 Mtetra
.598 .474 .682 r
.46834 .45599 .47424 .48135 .48526 .47784 .47933 .45243 Mtetra
.604 .478 .681 r
.47933 .45243 .48526 .47784 .49633 .47333 .49036 .44846 Mtetra
.619 .49 .683 r
.49036 .44846 .49633 .47333 .50745 .46733 .50145 .44338 Mtetra
.642 .509 .686 r
.50145 .44338 .50745 .46733 .51861 .45973 .51257 .43666 Mtetra
.676 .535 .685 r
.51257 .43666 .51861 .45973 .52977 .45033 .52373 .42724 Mtetra
.7 .549 .679 r
.52373 .42724 .52977 .45033 .54094 .43971 .53487 .4154 Mtetra
.708 .548 .669 r
.53487 .4154 .54094 .43971 .5521 .42927 .546 .40208 Mtetra
.698 .531 .657 r
.546 .40208 .5521 .42927 .56328 .41939 .5571 .38834 Mtetra
.672 .501 .646 r
.5571 .38834 .56328 .41939 .57446 .41041 .5682 .37597 Mtetra
.65 .478 .638 r
.5682 .37597 .57446 .41041 .58566 .40174 .57931 .36506 Mtetra
.637 .464 .633 r
.57931 .36506 .58566 .40174 .59685 .39188 .59042 .35501 Mtetra
.63 .459 .632 r
.59042 .35501 .59685 .39188 .60801 .38102 .60156 .34572 Mtetra
.63 .462 .637 r
.60156 .34572 .60801 .38102 .61916 .3697 .61272 .33695 Mtetra
.628 .467 .646 r
.61272 .33695 .61916 .3697 .6303 .35855 .62392 .32908 Mtetra
.619 .471 .659 r
.62392 .32908 .6303 .35855 .64148 .3485 .63519 .32285 Mtetra
.611 .481 .679 r
.63519 .32285 .64148 .3485 .65271 .33973 .64655 .31816 Mtetra
.601 .497 .708 r
.64655 .31816 .65271 .33973 .66401 .33238 .65801 .31487 Mtetra
.589 .522 .747 r
.65801 .31487 .66401 .33238 .6754 .32642 .66957 .31271 Mtetra
.574 .56 .801 r
.66957 .31271 .6754 .32642 .68689 .32186 .68124 .31139 Mtetra
.552 .609 .864 r
.68124 .31139 .68689 .32186 .6985 .31845 .693 .3106 Mtetra
.522 .668 .928 r
.693 .3106 .6985 .31845 .7102 .31594 .70485 .30998 Mtetra
.487 .719 .973 r
.70485 .30998 .7102 .31594 .72201 .31404 .71676 .30932 Mtetra
.467 .76 .994 r
.71676 .30932 .72201 .31404 .73389 .31241 .72873 .30832 Mtetra
.468 .787 .999 r
.72873 .30832 .73389 .31241 .74585 .31086 .74075 .30692 Mtetra
.498 .809 1 r
.74075 .30692 .74585 .31086 .75786 .30913 .75279 .30498 Mtetra
.537 .82 .998 r
.75279 .30498 .75786 .30913 .76993 .30718 .76487 .30256 Mtetra
.578 .82 .99 r
.76487 .30256 .76993 .30718 .78204 .30491 .77697 .29966 Mtetra
.608 .809 .977 r
.77697 .29966 .78204 .30491 .79418 .30238 .7891 .2964 Mtetra
.629 .791 .96 r
.7891 .2964 .79418 .30238 .80637 .29962 .80127 .29289 Mtetra
.64 .769 .941 r
.80127 .29289 .80637 .29962 .81861 .29669 .81347 .28921 Mtetra
.629 .744 .931 r
.16646 .49655 .17328 .5025 .18299 .49892 .17608 .4939 Mtetra
.626 .779 .954 r
.17608 .4939 .18299 .49892 .19274 .49519 .18576 .49118 Mtetra
.625 .818 .975 r
.18576 .49118 .19274 .49519 .20255 .49121 .19549 .48828 Mtetra
.622 .859 .988 r
.19549 .48828 .20255 .49121 .21243 .48688 .20528 .48506 Mtetra
.618 .898 .987 r
.20528 .48506 .21243 .48688 .22237 .48211 .21516 .48143 Mtetra
.609 .928 .967 r
.21516 .48143 .22237 .48211 .23239 .47687 .22511 .47728 Mtetra
.602 .945 .929 r
.22511 .47728 .23239 .47687 .24247 .4711 .23516 .47246 Mtetra
.595 .949 .883 r
.23516 .47246 .24247 .4711 .25261 .46495 .24529 .46698 Mtetra
.61 .955 .849 r
.24529 .46698 .25261 .46495 .26279 .45846 .2555 .46074 Mtetra
.642 .966 .839 r
.2555 .46074 .26279 .45846 .273 .45192 .26579 .45387 Mtetra
.703 .985 .86 r
.26579 .45387 .273 .45192 .28322 .44554 .27614 .44642 Mtetra
.767 .988 .897 r
.27614 .44642 .28322 .44554 .29341 .43966 .28652 .43867 Mtetra
.807 .946 .914 r
.28652 .43867 .29341 .43966 .30358 .4346 .29692 .43081 Mtetra
.798 .853 .891 r
.29692 .43081 .30358 .4346 .3137 .43063 .30731 .4232 Mtetra
.754 .739 .839 r
.30731 .4232 .3137 .43063 .32377 .42803 .31769 .41612 Mtetra
.702 .636 .779 r
.31769 .41612 .32377 .42803 .33379 .42694 .32804 .40968 Mtetra
.656 .554 .727 r
.32804 .40968 .33379 .42694 .34378 .42747 .33836 .40403 Mtetra
.621 .493 .685 r
.33836 .40403 .34378 .42747 .35378 .4289 .34867 .39917 Mtetra
.596 .451 .655 r
.34867 .39917 .35378 .4289 .36383 .43085 .35896 .39518 Mtetra
.571 .418 .635 r
.35896 .39518 .36383 .43085 .37391 .43357 .36921 .39271 Mtetra
.551 .393 .621 r
.36921 .39271 .37391 .43357 .38404 .43716 .37944 .39187 Mtetra
.546 .383 .611 r
.37944 .39187 .38404 .43716 .39419 .44221 .38971 .39133 Mtetra
.55 .378 .602 r
.38971 .39133 .39419 .44221 .40438 .44865 .40006 .39018 Mtetra
.561 .379 .592 r
.40006 .39018 .40438 .44865 .4147 .45471 .41054 .38712 Mtetra
.571 .38 .584 r
.41054 .38712 .4147 .45471 .42516 .45934 .42114 .3817 Mtetra
.571 .375 .576 r
.42114 .3817 .42516 .45934 .43578 .46158 .4318 .37514 Mtetra
.569 .37 .571 r
.4318 .37514 .43578 .46158 .44654 .46117 .44249 .36818 Mtetra
.564 .363 .567 r
.44249 .36818 .44654 .46117 .45741 .45913 .45319 .36189 Mtetra
.558 .357 .565 r
.45319 .36189 .45741 .45913 .46834 .45599 .46388 .35685 Mtetra
.552 .352 .564 r
.46388 .35685 .46834 .45599 .47933 .45243 .47459 .35319 Mtetra
.546 .348 .563 r
.47459 .35319 .47933 .45243 .49036 .44846 .48532 .3509 Mtetra
.541 .345 .563 r
.48532 .3509 .49036 .44846 .50145 .44338 .49609 .34988 Mtetra
.538 .344 .565 r
.49609 .34988 .50145 .44338 .51257 .43666 .50692 .34954 Mtetra
.541 .348 .569 r
.50692 .34954 .51257 .43666 .52373 .42724 .51782 .34881 Mtetra
.548 .357 .575 r
.51782 .34881 .52373 .42724 .53487 .4154 .52877 .34693 Mtetra
.563 .374 .583 r
.52877 .34693 .53487 .4154 .546 .40208 .53978 .34268 Mtetra
.579 .393 .593 r
.53978 .34268 .546 .40208 .5571 .38834 .55081 .33648 Mtetra
.589 .407 .603 r
.55081 .33648 .5571 .38834 .5682 .37597 .56186 .32966 Mtetra
.593 .417 .612 r
.56186 .32966 .5682 .37597 .57931 .36506 .57293 .32314 Mtetra
.585 .418 .621 r
.57293 .32314 .57931 .36506 .59042 .35501 .58407 .31826 Mtetra
.577 .422 .635 r
.58407 .31826 .59042 .35501 .60156 .34572 .59527 .31493 Mtetra
.574 .437 .656 r
.59527 .31493 .60156 .34572 .61272 .33695 .60655 .31249 Mtetra
.57 .46 .689 r
.60655 .31249 .61272 .33695 .62392 .32908 .61791 .31085 Mtetra
.561 .498 .742 r
.61791 .31085 .62392 .32908 .63519 .32285 .62935 .31003 Mtetra
.538 .554 .819 r
.62935 .31003 .63519 .32285 .64655 .31816 .64089 .30988 Mtetra
.478 .63 .92 r
.64089 .30988 .64655 .31816 .65801 .31487 .65253 .31028 Mtetra
.333 .691 .981 r
.65253 .31028 .65801 .31487 .66957 .31271 .66426 .31094 Mtetra
.115 .647 .867 r
.66426 .31094 .66957 .31271 .68124 .31139 .67607 .31151 Mtetra
.039 0 0 r
.67607 .31151 .68124 .31139 .693 .3106 .68795 .31179 Mtetra
.079 0 0 r
.68795 .31179 .693 .3106 .70485 .30998 .69987 .31147 Mtetra
.045 0 0 r
.69987 .31147 .70485 .30998 .71676 .30932 .71183 .31051 Mtetra
0 0 0 r
.71183 .31051 .71676 .30932 .72873 .30832 .72382 .30878 Mtetra
.195 .724 .758 r
.72382 .30878 .72873 .30832 .74075 .30692 .73582 .30634 Mtetra
.361 .831 .882 r
.73582 .30634 .74075 .30692 .75279 .30498 .74785 .30323 Mtetra
.501 .887 .962 r
.74785 .30323 .75279 .30498 .76487 .30256 .75988 .29956 Mtetra
.595 .892 .989 r
.75988 .29956 .76487 .30256 .77697 .29966 .77194 .29546 Mtetra
.646 .868 .982 r
.77194 .29546 .77697 .29966 .7891 .2964 .78403 .29103 Mtetra
.67 .832 .961 r
.78403 .29103 .7891 .2964 .80127 .29289 .79614 .2864 Mtetra
.677 .794 .937 r
.79614 .2864 .80127 .29289 .81347 .28921 .8083 .28168 Mtetra
.587 .732 .944 r
.15958 .49055 .16646 .49655 .17608 .4939 .16914 .4887 Mtetra
.575 .758 .965 r
.16914 .4887 .17608 .4939 .18576 .49118 .17874 .48687 Mtetra
.562 .789 .984 r
.17874 .48687 .18576 .49118 .19549 .48828 .18839 .48497 Mtetra
.543 .823 .998 r
.18839 .48497 .19549 .48828 .20528 .48506 .1981 .48291 Mtetra
.512 .854 .995 r
.1981 .48291 .20528 .48506 .21516 .48143 .20788 .48063 Mtetra
.464 .87 .957 r
.20788 .48063 .21516 .48143 .22511 .47728 .21773 .47796 Mtetra
.394 .852 .867 r
.21773 .47796 .22511 .47728 .23516 .47246 .22767 .4748 Mtetra
.305 .789 .724 r
.22767 .4748 .23516 .47246 .24529 .46698 .2377 .471 Mtetra
0 0 0 r
.2377 .471 .24529 .46698 .2555 .46074 .24784 .46644 Mtetra
.24784 .46644 .2555 .46074 .26579 .45387 .25806 .46108 Mtetra
.25806 .46108 .26579 .45387 .27614 .44642 .26838 .45485 Mtetra
.26838 .45485 .27614 .44642 .28652 .43867 .27878 .44788 Mtetra
.27878 .44788 .28652 .43867 .29692 .43081 .28925 .44022 Mtetra
.28925 .44022 .29692 .43081 .30731 .4232 .29975 .43213 Mtetra
.29975 .43213 .30731 .4232 .31769 .41612 .31029 .4238 Mtetra
.31029 .4238 .31769 .41612 .32804 .40968 .32084 .41533 Mtetra
.453 .821 .564 r
.32084 .41533 .32804 .40968 .33836 .40403 .33139 .40688 Mtetra
.654 .965 .792 r
.33139 .40688 .33836 .40403 .34867 .39917 .34193 .3989 Mtetra
.761 .973 .923 r
.34193 .3989 .34867 .39917 .35896 .39518 .35244 .39169 Mtetra
.755 .873 .933 r
.35244 .39169 .35896 .39518 .36921 .39271 .36291 .38553 Mtetra
.708 .742 .878 r
.36291 .38553 .36921 .39271 .37944 .39187 .37336 .38041 Mtetra
.689 .641 .796 r
.37336 .38041 .37944 .39187 .38971 .39133 .38385 .37479 Mtetra
.677 .574 .731 r
.38385 .37479 .38971 .39133 .40006 .39018 .39443 .36797 Mtetra
.663 .526 .687 r
.39443 .36797 .40006 .39018 .41054 .38712 .40506 .36009 Mtetra
.653 .499 .662 r
.40506 .36009 .41054 .38712 .42114 .3817 .41573 .35144 Mtetra
.636 .477 .651 r
.41573 .35144 .42114 .3817 .4318 .37514 .42639 .34344 Mtetra
.62 .462 .646 r
.42639 .34344 .4318 .37514 .44249 .36818 .43702 .33669 Mtetra
.608 .455 .648 r
.43702 .33669 .44249 .36818 .45319 .36189 .44765 .33113 Mtetra
.597 .449 .652 r
.44765 .33113 .45319 .36189 .46388 .35685 .45828 .32672 Mtetra
.59 .447 .655 r
.45828 .32672 .46388 .35685 .47459 .35319 .46894 .32301 Mtetra
.581 .441 .655 r
.46894 .32301 .47459 .35319 .48532 .3509 .47962 .32001 Mtetra
.566 .429 .653 r
.47962 .32001 .48532 .3509 .49609 .34988 .49034 .31816 Mtetra
.551 .416 .65 r
.49034 .31816 .49609 .34988 .50692 .34954 .50111 .31751 Mtetra
.534 .404 .649 r
.50111 .31751 .50692 .34954 .51782 .34881 .51194 .31813 Mtetra
.525 .402 .655 r
.51194 .31813 .51782 .34881 .52877 .34693 .52283 .31943 Mtetra
.535 .421 .671 r
.52283 .31943 .52877 .34693 .53978 .34268 .53381 .31995 Mtetra
.553 .457 .7 r
.53381 .31995 .53978 .34268 .55081 .33648 .54485 .31942 Mtetra
.581 .519 .751 r
.54485 .31942 .55081 .33648 .56186 .32966 .55595 .31768 Mtetra
.6 .6 .823 r
.55595 .31768 .56186 .32966 .57293 .32314 .5671 .31545 Mtetra
.549 .682 .926 r
.5671 .31545 .57293 .32314 .58407 .31826 .57833 .31426 Mtetra
.365 .732 .989 r
.57833 .31426 .58407 .31826 .59527 .31493 .58964 .31416 Mtetra
0 .572 .756 r
.58964 .31416 .59527 .31493 .60655 .31249 .60105 .31486 Mtetra
.292 0 0 r
.60105 .31486 .60655 .31249 .61791 .31085 .61255 .31605 Mtetra
.398 0 0 r
.61255 .31605 .61791 .31085 .62935 .31003 .62413 .31728 Mtetra
.431 0 .014 r
.62413 .31728 .62935 .31003 .64089 .30988 .63579 .31838 Mtetra
.439 0 .063 r
.63579 .31838 .64089 .30988 .65253 .31028 .64754 .31924 Mtetra
.429 0 .073 r
.64754 .31924 .65253 .31028 .66426 .31094 .65934 .31968 Mtetra
.399 0 .05 r
.65934 .31968 .66426 .31094 .67607 .31151 .6712 .31942 Mtetra
.351 0 0 r
.6712 .31942 .67607 .31151 .68795 .31179 .68309 .3184 Mtetra
.272 0 0 r
.68309 .3184 .68795 .31179 .69987 .31147 .69501 .31649 Mtetra
.152 0 0 r
.69501 .31649 .69987 .31147 .71183 .31051 .70695 .31376 Mtetra
0 0 0 r
.70695 .31376 .71183 .31051 .72382 .30878 .7189 .31023 Mtetra
.26 .758 .698 r
.7189 .31023 .72382 .30878 .73582 .30634 .73086 .30605 Mtetra
.474 .895 .883 r
.73086 .30605 .73582 .30634 .74785 .30323 .74283 .30133 Mtetra
.609 .931 .963 r
.74283 .30133 .74785 .30323 .75988 .29956 .75482 .29621 Mtetra
.674 .909 .976 r
.75482 .29621 .75988 .29956 .77194 .29546 .76684 .29085 Mtetra
.7 .872 .962 r
.76684 .29085 .77194 .29546 .78403 .29103 .77888 .28531 Mtetra
.708 .834 .942 r
.77888 .28531 .78403 .29103 .79614 .2864 .79096 .2797 Mtetra
.707 .8 .923 r
.79096 .2797 .79614 .2864 .8083 .28168 .80308 .27409 Mtetra
.56 .723 .95 r
.15266 .48451 .15958 .49055 .16914 .4887 .16219 .4831 Mtetra
.546 .735 .963 r
.16219 .4831 .16914 .4887 .17874 .48687 .17175 .48178 Mtetra
.529 .75 .976 r
.17175 .48178 .17874 .48687 .18839 .48497 .18135 .48054 Mtetra
.507 .768 .99 r
.18135 .48054 .18839 .48497 .1981 .48291 .191 .47933 Mtetra
.47 .787 .999 r
.191 .47933 .1981 .48291 .20788 .48063 .20069 .47816 Mtetra
.415 .804 .989 r
.20069 .47816 .20788 .48063 .21773 .47796 .21044 .47689 Mtetra
.325 .794 .929 r
.21044 .47689 .21773 .47796 .22767 .4748 .22025 .47546 Mtetra
.196 .726 .781 r
.22025 .47546 .22767 .4748 .2377 .471 .23014 .47369 Mtetra
0 0 0 r
.23014 .47369 .2377 .471 .24784 .46644 .24013 .47145 Mtetra
.069 0 0 r
.24013 .47145 .24784 .46644 .25806 .46108 .2502 .46861 Mtetra
.149 0 0 r
.2502 .46861 .25806 .46108 .26838 .45485 .26038 .46504 Mtetra
.202 0 0 r
.26038 .46504 .26838 .45485 .27878 .44788 .27065 .46068 Mtetra
.232 0 .067 r
.27065 .46068 .27878 .44788 .28925 .44022 .28102 .45546 Mtetra
.252 0 .127 r
.28102 .45546 .28925 .44022 .29975 .43213 .29148 .44944 Mtetra
.263 0 .165 r
.29148 .44944 .29975 .43213 .31029 .4238 .30201 .44267 Mtetra
.267 0 .188 r
.30201 .44267 .31029 .4238 .32084 .41533 .31261 .43526 Mtetra
.268 0 .201 r
.31261 .43526 .32084 .41533 .33139 .40688 .32324 .42735 Mtetra
.279 0 .213 r
.32324 .42735 .33139 .40688 .34193 .3989 .33389 .41949 Mtetra
.294 0 .222 r
.33389 .41949 .34193 .3989 .35244 .39169 .34453 .41198 Mtetra
.288 0 .217 r
.34453 .41198 .35244 .39169 .36291 .38553 .3552 .40436 Mtetra
.256 0 .187 r
.3552 .40436 .36291 .38553 .37336 .38041 .36589 .39644 Mtetra
.169 0 .106 r
.36589 .39644 .37336 .38041 .38385 .37479 .37662 .38781 Mtetra
.039 0 0 r
.37662 .38781 .38385 .37479 .39443 .36797 .38739 .3786 Mtetra
0 0 0 r
.38739 .3786 .39443 .36797 .40506 .36009 .39812 .3705 Mtetra
.12 0 0 r
.39812 .3705 .40506 .36009 .41573 .35144 .4088 .3643 Mtetra
.305 0 .118 r
.4088 .3643 .41573 .35144 .42639 .34344 .41942 .36023 Mtetra
.419 .055 .238 r
.41942 .36023 .42639 .34344 .43702 .33669 .43003 .35806 Mtetra
.451 .113 .3 r
.43003 .35806 .43702 .33669 .44765 .33113 .44068 .35621 Mtetra
.455 .132 .329 r
.44068 .35621 .44765 .33113 .45828 .32672 .4514 .35384 Mtetra
.439 .125 .335 r
.4514 .35384 .45828 .32672 .46894 .32301 .4622 .35013 Mtetra
.416 .105 .327 r
.4622 .35013 .46894 .32301 .47962 .32001 .47306 .34508 Mtetra
.395 .079 .307 r
.47306 .34508 .47962 .32001 .49034 .31816 .48396 .3395 Mtetra
.377 .046 .272 r
.48396 .3395 .49034 .31816 .50111 .31751 .49489 .33425 Mtetra
.388 .026 .224 r
.49489 .33425 .50111 .31751 .51194 .31813 .50584 .33089 Mtetra
.415 .015 .169 r
.50584 .33089 .51194 .31813 .52283 .31943 .51683 .32969 Mtetra
.455 .024 .13 r
.51683 .32969 .52283 .31943 .53381 .31995 .52789 .33042 Mtetra
.492 .063 .153 r
.52789 .33042 .53381 .31995 .54485 .31942 .53903 .33228 Mtetra
.487 .085 .202 r
.53903 .33228 .54485 .31942 .55595 .31768 .55025 .33357 Mtetra
.482 .105 .248 r
.55025 .33357 .55595 .31768 .5671 .31545 .56154 .33416 Mtetra
.485 .127 .283 r
.56154 .33416 .5671 .31545 .57833 .31426 .57291 .33445 Mtetra
.487 .137 .297 r
.57291 .33445 .57833 .31426 .58964 .31416 .58435 .33465 Mtetra
.494 .144 .302 r
.58435 .33465 .58964 .31416 .60105 .31486 .59587 .33522 Mtetra
.495 .144 .3 r
.59587 .33522 .60105 .31486 .61255 .31605 .60748 .33586 Mtetra
.484 .131 .291 r
.60748 .33586 .61255 .31605 .62413 .31728 .61916 .33599 Mtetra
.468 .11 .274 r
.61916 .33599 .62413 .31728 .63579 .31838 .63089 .33548 Mtetra
.444 .077 .246 r
.63089 .33548 .63579 .31838 .64754 .31924 .64267 .3342 Mtetra
.409 .028 .201 r
.64267 .3342 .64754 .31924 .65934 .31968 .65448 .33211 Mtetra
.354 0 .131 r
.65448 .33211 .65934 .31968 .6712 .31942 .66632 .32914 Mtetra
.269 0 .02 r
.66632 .32914 .6712 .31942 .68309 .3184 .67817 .32535 Mtetra
.129 0 0 r
.67817 .32535 .68309 .3184 .69501 .31649 .69004 .32079 Mtetra
0 0 0 r
.69004 .32079 .69501 .31649 .70695 .31376 .70192 .31561 Mtetra
.359 .814 .698 r
.70192 .31561 .70695 .31376 .7189 .31023 .71381 .30994 Mtetra
.576 .941 .891 r
.71381 .30994 .7189 .31023 .73086 .30605 .72572 .30391 Mtetra
.684 .949 .957 r
.72572 .30391 .73086 .30605 .74283 .30133 .73765 .29768 Mtetra
.722 .912 .96 r
.73765 .29768 .74283 .30133 .75482 .29621 .7496 .29135 Mtetra
.731 .871 .947 r
.7496 .29135 .75482 .29621 .76684 .29085 .7616 .28505 Mtetra
.73 .838 .931 r
.7616 .28505 .76684 .29085 .77888 .28531 .77363 .27877 Mtetra
.726 .813 .918 r
.77363 .27877 .77888 .28531 .79096 .2797 .7857 .27256 Mtetra
.721 .792 .908 r
.7857 .27256 .79096 .2797 .80308 .27409 .79782 .26643 Mtetra
.574 .728 .947 r
.14569 .47843 .15266 .48451 .16219 .4831 .15526 .47676 Mtetra
.568 .717 .943 r
.15526 .47676 .16219 .4831 .17175 .48178 .16486 .47522 Mtetra
.561 .708 .939 r
.16486 .47522 .17175 .48178 .18135 .48054 .17449 .47384 Mtetra
.551 .7 .939 r
.17449 .47384 .18135 .48054 .191 .47933 .18415 .47265 Mtetra
.535 .696 .942 r
.18415 .47265 .191 .47933 .20069 .47816 .19383 .47169 Mtetra
.521 .698 .95 r
.19383 .47169 .20069 .47816 .21044 .47689 .20355 .47091 Mtetra
.5 .708 .964 r
.20355 .47091 .21044 .47689 .22025 .47546 .2133 .47026 Mtetra
.476 .73 .981 r
.2133 .47026 .22025 .47546 .23014 .47369 .22311 .46964 Mtetra
.438 .759 .996 r
.22311 .46964 .23014 .47369 .24013 .47145 .23298 .46893 Mtetra
.371 .783 .98 r
.23298 .46893 .24013 .47145 .2502 .46861 .24292 .46799 Mtetra
.255 .759 .88 r
.24292 .46799 .2502 .46861 .26038 .46504 .25295 .46668 Mtetra
0 0 0 r
.25295 .46668 .26038 .46504 .27065 .46068 .26307 .46486 Mtetra
.051 0 0 r
.26307 .46486 .27065 .46068 .28102 .45546 .27329 .46239 Mtetra
.154 0 0 r
.27329 .46239 .28102 .45546 .29148 .44944 .28361 .45923 Mtetra
.216 0 0 r
.28361 .45923 .29148 .44944 .30201 .44267 .29402 .4553 Mtetra
.26 0 .076 r
.29402 .4553 .30201 .44267 .31261 .43526 .30451 .4507 Mtetra
.291 0 .147 r
.30451 .4507 .31261 .43526 .32324 .42735 .31508 .4455 Mtetra
.323 0 .203 r
.31508 .4455 .32324 .42735 .33389 .41949 .32569 .44004 Mtetra
.347 .009 .241 r
.32569 .44004 .33389 .41949 .34453 .41198 .33634 .43444 Mtetra
.347 .019 .259 r
.33634 .43444 .34453 .41198 .3552 .40436 .34705 .42812 Mtetra
.337 .017 .266 r
.34705 .42812 .3552 .40436 .36589 .39644 .35784 .42094 Mtetra
.34 .023 .273 r
.35784 .42094 .36589 .39644 .37662 .38781 .36865 .41355 Mtetra
.36 .046 .291 r
.36865 .41355 .37662 .38781 .38739 .3786 .37946 .40656 Mtetra
.413 .102 .326 r
.37946 .40656 .38739 .3786 .39812 .3705 .39021 .40147 Mtetra
.463 .156 .359 r
.39021 .40147 .39812 .3705 .4088 .3643 .4009 .39884 Mtetra
.491 .189 .382 r
.4009 .39884 .4088 .3643 .41942 .36023 .41158 .39778 Mtetra
.504 .207 .395 r
.41158 .39778 .41942 .36023 .43003 .35806 .4223 .39761 Mtetra
.499 .206 .399 r
.4223 .39761 .43003 .35806 .44068 .35621 .4331 .39689 Mtetra
.487 .197 .398 r
.4331 .39689 .44068 .35621 .4514 .35384 .44399 .39487 Mtetra
.469 .182 .394 r
.44399 .39487 .4514 .35384 .4622 .35013 .45497 .39118 Mtetra
.451 .166 .389 r
.45497 .39118 .4622 .35013 .47306 .34508 .46603 .3858 Mtetra
.435 .152 .383 r
.46603 .3858 .47306 .34508 .48396 .3395 .47715 .37911 Mtetra
.426 .142 .378 r
.47715 .37911 .48396 .3395 .49489 .33425 .48829 .37187 Mtetra
.432 .144 .373 r
.48829 .37187 .49489 .33425 .50584 .33089 .49945 .3655 Mtetra
.444 .148 .367 r
.49945 .3655 .50584 .33089 .51683 .32969 .51063 .36071 Mtetra
.469 .161 .36 r
.51063 .36071 .51683 .32969 .52789 .33042 .52184 .3584 Mtetra
.491 .171 .351 r
.52184 .3584 .52789 .33042 .53903 .33228 .53312 .35803 Mtetra
.493 .165 .339 r
.53312 .35803 .53903 .33228 .55025 .33357 .54446 .35806 Mtetra
.488 .155 .329 r
.54446 .35806 .55025 .33357 .56154 .33416 .55589 .3579 Mtetra
.472 .138 .318 r
.55589 .3579 .56154 .33416 .57291 .33445 .56737 .35687 Mtetra
.455 .117 .302 r
.56737 .35687 .57291 .33445 .58435 .33465 .57891 .35511 Mtetra
.445 .097 .281 r
.57891 .35511 .58435 .33465 .59587 .33522 .59051 .35323 Mtetra
.426 .065 .247 r
.59051 .35323 .59587 .33522 .60748 .33586 .60217 .35107 Mtetra
.389 .01 .194 r
.60217 .35107 .60748 .33586 .61916 .33599 .61387 .34831 Mtetra
.33 0 .113 r
.61387 .34831 .61916 .33599 .63089 .33548 .62561 .34486 Mtetra
.23 0 0 r
.62561 .34486 .63089 .33548 .64267 .3342 .63737 .34062 Mtetra
.062 0 0 r
.63737 .34062 .64267 .3342 .65448 .33211 .64916 .33566 Mtetra
0 0 0 r
.64916 .33566 .65448 .33211 .66632 .32914 .66095 .33002 Mtetra
.507 .909 .816 r
.66095 .33002 .66632 .32914 .67817 .32535 .67276 .32385 Mtetra
.685 .961 .942 r
.67276 .32385 .67817 .32535 .69004 .32079 .68459 .31728 Mtetra
.743 .918 .951 r
.68459 .31728 .69004 .32079 .70192 .31561 .69643 .31046 Mtetra
.753 .862 .929 r
.69643 .31046 .70192 .31561 .71381 .30994 .7083 .30354 Mtetra
.749 .82 .908 r
.7083 .30354 .71381 .30994 .72572 .30391 .72019 .29663 Mtetra
.74 .79 .893 r
.72019 .29663 .72572 .30391 .73765 .29768 .73213 .28986 Mtetra
.731 .772 .885 r
.73213 .28986 .73765 .29768 .7496 .29135 .74411 .28324 Mtetra
.723 .762 .884 r
.74411 .28324 .7496 .29135 .7616 .28505 .75614 .27687 Mtetra
.717 .759 .885 r
.75614 .27687 .7616 .28505 .77363 .27877 .76822 .27067 Mtetra
.713 .761 .89 r
.76822 .27067 .77363 .27877 .7857 .27256 .78035 .26463 Mtetra
.71 .766 .896 r
.78035 .26463 .7857 .27256 .79782 .26643 .79252 .25872 Mtetra
.617 .741 .935 r
.13868 .4723 .14569 .47843 .15526 .47676 .14835 .46982 Mtetra
.613 .714 .917 r
.14835 .46982 .15526 .47676 .16486 .47522 .15805 .46747 Mtetra
.606 .687 .9 r
.15805 .46747 .16486 .47522 .17449 .47384 .16778 .4653 Mtetra
.596 .662 .884 r
.16778 .4653 .17449 .47384 .18415 .47265 .17752 .4634 Mtetra
.583 .639 .872 r
.17752 .4634 .18415 .47265 .19383 .47169 .18727 .46184 Mtetra
.569 .619 .862 r
.18727 .46184 .19383 .47169 .20355 .47091 .19703 .46062 Mtetra
.554 .603 .856 r
.19703 .46062 .20355 .47091 .2133 .47026 .20681 .45979 Mtetra
.541 .593 .855 r
.20681 .45979 .2133 .47026 .22311 .46964 .21661 .45927 Mtetra
.528 .59 .86 r
.21661 .45927 .22311 .46964 .23298 .46893 .22643 .45904 Mtetra
.517 .597 .873 r
.22643 .45904 .23298 .46893 .24292 .46799 .23631 .45896 Mtetra
.505 .615 .895 r
.23631 .45896 .24292 .46799 .25295 .46668 .24623 .45895 Mtetra
.492 .649 .928 r
.24623 .45895 .25295 .46668 .26307 .46486 .25623 .45887 Mtetra
.469 .7 .969 r
.25623 .45887 .26307 .46486 .27329 .46239 .2663 .45856 Mtetra
.41 .758 .995 r
.2663 .45856 .27329 .46239 .28361 .45923 .27645 .45794 Mtetra
.271 .76 .914 r
.27645 .45794 .28361 .45923 .29402 .4553 .28669 .45691 Mtetra
0 0 0 r
.28669 .45691 .29402 .4553 .30451 .4507 .29701 .45551 Mtetra
.165 0 0 r
.29701 .45551 .30451 .4507 .31508 .4455 .30741 .45373 Mtetra
.274 0 0 r
.30741 .45373 .31508 .4455 .32569 .44004 .31789 .45152 Mtetra
.325 0 .082 r
.31789 .45152 .32569 .44004 .33634 .43444 .32845 .4488 Mtetra
.34 0 .15 r
.32845 .4488 .33634 .43444 .34705 .42812 .33911 .4453 Mtetra
.351 0 .2 r
.33911 .4453 .34705 .42812 .35784 .42094 .34984 .44108 Mtetra
.396 .049 .255 r
.34984 .44108 .35784 .42094 .36865 .41355 .36058 .43745 Mtetra
.444 .112 .308 r
.36058 .43745 .36865 .41355 .37946 .40656 .37131 .43507 Mtetra
.481 .163 .35 r
.37131 .43507 .37946 .40656 .39021 .40147 .38202 .43412 Mtetra
.504 .194 .375 r
.38202 .43412 .39021 .40147 .4009 .39884 .39274 .43443 Mtetra
.502 .199 .385 r
.39274 .43443 .4009 .39884 .41158 .39778 .40355 .43446 Mtetra
.492 .192 .385 r
.40355 .43446 .41158 .39778 .4223 .39761 .41445 .4335 Mtetra
.478 .178 .378 r
.41445 .4335 .4223 .39761 .4331 .39689 .42545 .43147 Mtetra
.462 .161 .368 r
.42545 .43147 .4331 .39689 .44399 .39487 .43654 .42835 Mtetra
.452 .15 .361 r
.43654 .42835 .44399 .39487 .45497 .39118 .44769 .42466 Mtetra
.445 .143 .358 r
.44769 .42466 .45497 .39118 .46603 .3858 .4589 .42041 Mtetra
.433 .135 .359 r
.4589 .42041 .46603 .3858 .47715 .37911 .47016 .41505 Mtetra
.422 .129 .36 r
.47016 .41505 .47715 .37911 .48829 .37187 .48148 .40862 Mtetra
.412 .122 .36 r
.48148 .40862 .48829 .37187 .49945 .3655 .49284 .40118 Mtetra
.404 .114 .355 r
.49284 .40118 .49945 .3655 .51063 .36071 .50422 .39343 Mtetra
.412 .113 .345 r
.50422 .39343 .51063 .36071 .52184 .3584 .51561 .38695 Mtetra
.418 .107 .327 r
.51561 .38695 .52184 .3584 .53312 .35803 .52703 .38191 Mtetra
.42 .09 .298 r
.52703 .38191 .53312 .35803 .54446 .35806 .5385 .37813 Mtetra
.412 .063 .261 r
.5385 .37813 .54446 .35806 .55589 .3579 .55002 .37495 Mtetra
.37 .006 .209 r
.55002 .37495 .55589 .3579 .56737 .35687 .56158 .37104 Mtetra
.309 0 .137 r
.56158 .37104 .56737 .35687 .57891 .35511 .57318 .36632 Mtetra
.226 0 .033 r
.57318 .36632 .57891 .35511 .59051 .35323 .58482 .3611 Mtetra
.076 0 0 r
.58482 .3611 .59051 .35323 .60217 .35107 .59648 .35541 Mtetra
0 0 0 r
.59648 .35541 .60217 .35107 .61387 .34831 .60817 .34933 Mtetra
.537 .923 .823 r
.60817 .34933 .61387 .34831 .62561 .34486 .61988 .34286 Mtetra
.725 .955 .947 r
.61988 .34286 .62561 .34486 .63737 .34062 .63161 .33595 Mtetra
.765 .876 .928 r
.63161 .33595 .63737 .34062 .64916 .33566 .64336 .3287 Mtetra
.76 .8 .885 r
.64336 .3287 .64916 .33566 .66095 .33002 .65512 .32122 Mtetra
.747 .747 .851 r
.65512 .32122 .66095 .33002 .67276 .32385 .6669 .31364 Mtetra
.733 .71 .829 r
.6669 .31364 .67276 .32385 .68459 .31728 .67871 .30612 Mtetra
.722 .687 .816 r
.67871 .30612 .68459 .31728 .69643 .31046 .69055 .29874 Mtetra
.712 .673 .81 r
.69055 .29874 .69643 .31046 .7083 .30354 .70243 .29165 Mtetra
.704 .667 .811 r
.70243 .29165 .7083 .30354 .72019 .29663 .71436 .28487 Mtetra
.697 .667 .817 r
.71436 .28487 .72019 .29663 .73213 .28986 .72634 .27847 Mtetra
.692 .672 .826 r
.72634 .27847 .73213 .28986 .74411 .28324 .73839 .27243 Mtetra
.687 .682 .84 r
.73839 .27243 .74411 .28324 .75614 .27687 .7505 .26674 Mtetra
.685 .697 .856 r
.7505 .26674 .75614 .27687 .76822 .27067 .76267 .2613 Mtetra
.684 .716 .873 r
.76267 .2613 .76822 .27067 .78035 .26463 .7749 .25607 Mtetra
.683 .738 .893 r
.7749 .25607 .78035 .26463 .79252 .25872 .78718 .25095 Mtetra
.668 .754 .915 r
.13161 .46613 .13868 .4723 .14835 .46982 .14144 .46248 Mtetra
.662 .717 .89 r
.14144 .46248 .14835 .46982 .15805 .46747 .15129 .4589 Mtetra
.652 .682 .865 r
.15129 .4589 .15805 .46747 .16778 .4653 .16116 .45548 Mtetra
.639 .649 .843 r
.16116 .45548 .16778 .4653 .17752 .4634 .17105 .45229 Mtetra
.625 .617 .823 r
.17105 .45229 .17752 .4634 .18727 .46184 .18093 .44943 Mtetra
.61 .588 .804 r
.18093 .44943 .18727 .46184 .19703 .46062 .19082 .44695 Mtetra
.594 .561 .787 r
.19082 .44695 .19703 .46062 .20681 .45979 .20071 .44491 Mtetra
.58 .538 .772 r
.20071 .44491 .20681 .45979 .21661 .45927 .2106 .4433 Mtetra
.567 .518 .76 r
.2106 .4433 .21661 .45927 .22643 .45904 .2205 .44215 Mtetra
.556 .502 .751 r
.2205 .44215 .22643 .45904 .23631 .45896 .23042 .44138 Mtetra
.547 .49 .744 r
.23042 .44138 .23631 .45896 .24623 .45895 .24036 .44096 Mtetra
.541 .483 .74 r
.24036 .44096 .24623 .45895 .25623 .45887 .25034 .44077 Mtetra
.538 .481 .74 r
.25034 .44077 .25623 .45887 .2663 .45856 .26037 .44072 Mtetra
.537 .483 .743 r
.26037 .44072 .2663 .45856 .27645 .45794 .27046 .4407 Mtetra
.538 .49 .751 r
.27046 .4407 .27645 .45794 .28669 .45691 .28061 .44062 Mtetra
.54 .502 .763 r
.28061 .44062 .28669 .45691 .29701 .45551 .29083 .44045 Mtetra
.543 .52 .78 r
.29083 .44045 .29701 .45551 .30741 .45373 .30113 .44011 Mtetra
.554 .547 .802 r
.30113 .44011 .30741 .45373 .31789 .45152 .31151 .43937 Mtetra
.57 .581 .825 r
.31151 .43937 .31789 .45152 .32845 .4488 .32199 .43807 Mtetra
.586 .618 .851 r
.32199 .43807 .32845 .4488 .33911 .4453 .33255 .43629 Mtetra
.596 .664 .886 r
.33255 .43629 .33911 .4453 .34984 .44108 .34318 .43418 Mtetra
.552 .711 .945 r
.34318 .43418 .34984 .44108 .36058 .43745 .35383 .43273 Mtetra
.427 .738 .992 r
.35383 .43273 .36058 .43745 .37131 .43507 .36449 .43226 Mtetra
.308 .746 .967 r
.36449 .43226 .37131 .43507 .38202 .43412 .37522 .43185 Mtetra
.325 .772 .96 r
.37522 .43185 .38202 .43412 .39274 .43443 .38603 .43092 Mtetra
.542 .835 .999 r
.38603 .43092 .39274 .43443 .40355 .43446 .39696 .42841 Mtetra
.673 .786 .934 r
.39696 .42841 .40355 .43446 .41445 .4335 .40801 .42416 Mtetra
.681 .695 .856 r
.40801 .42416 .41445 .4335 .42545 .43147 .41912 .41932 Mtetra
.663 .632 .809 r
.41912 .41932 .42545 .43147 .43654 .42835 .43026 .41456 Mtetra
.631 .592 .792 r
.43026 .41456 .43654 .42835 .44769 .42466 .44141 .41084 Mtetra
.605 .579 .797 r
.44141 .41084 .44769 .42466 .4589 .42041 .45259 .40816 Mtetra
.606 .606 .824 r
.45259 .40816 .4589 .42041 .47016 .41505 .46382 .40556 Mtetra
.629 .675 .874 r
.46382 .40556 .47016 .41505 .48148 .40862 .47511 .40238 Mtetra
.694 .793 .926 r
.47511 .40238 .48148 .40862 .49284 .40118 .48648 .39744 Mtetra
.747 .891 .944 r
.48648 .39744 .49284 .40118 .50422 .39343 .4979 .3909 Mtetra
.756 .934 .944 r
.4979 .3909 .50422 .39343 .51561 .38695 .50935 .38382 Mtetra
.76 .916 .942 r
.50935 .38382 .51561 .38695 .52703 .38191 .52082 .3768 Mtetra
.731 .844 .934 r
.52082 .3768 .52703 .38191 .5385 .37813 .53232 .37075 Mtetra
.703 .763 .899 r
.53232 .37075 .5385 .37813 .55002 .37495 .54385 .36537 Mtetra
.699 .705 .852 r
.54385 .36537 .55002 .37495 .56158 .37104 .55542 .35964 Mtetra
.697 .667 .817 r
.55542 .35964 .56158 .37104 .57318 .36632 .56702 .35341 Mtetra
.698 .643 .791 r
.56702 .35341 .57318 .36632 .58482 .3611 .57865 .34661 Mtetra
.694 .619 .769 r
.57865 .34661 .58482 .3611 .59648 .35541 .59029 .33937 Mtetra
.687 .598 .751 r
.59029 .33937 .59648 .35541 .60817 .34933 .60195 .33196 Mtetra
.68 .581 .738 r
.60195 .33196 .60817 .34933 .61988 .34286 .61363 .32444 Mtetra
.675 .569 .728 r
.61363 .32444 .61988 .34286 .63161 .33595 .62534 .31684 Mtetra
.671 .561 .723 r
.62534 .31684 .63161 .33595 .64336 .3287 .63707 .30925 Mtetra
.667 .557 .721 r
.63707 .30925 .64336 .3287 .65512 .32122 .64882 .3018 Mtetra
.664 .555 .722 r
.64882 .3018 .65512 .32122 .6669 .31364 .66061 .29458 Mtetra
.66 .556 .726 r
.66061 .29458 .6669 .31364 .67871 .30612 .67245 .2877 Mtetra
.658 .56 .734 r
.67245 .2877 .67871 .30612 .69055 .29874 .68433 .2812 Mtetra
.655 .567 .744 r
.68433 .2812 .69055 .29874 .70243 .29165 .69628 .27517 Mtetra
.652 .577 .758 r
.69628 .27517 .70243 .29165 .71436 .28487 .70828 .26957 Mtetra
.65 .59 .775 r
.70828 .26957 .71436 .28487 .72634 .27847 .72036 .26443 Mtetra
.648 .607 .794 r
.72036 .26443 .72634 .27847 .73839 .27243 .73251 .25967 Mtetra
.646 .627 .816 r
.73251 .25967 .73839 .27243 .7505 .26674 .74473 .25525 Mtetra
.645 .651 .841 r
.74473 .25525 .7505 .26674 .76267 .2613 .75702 .25107 Mtetra
.645 .679 .868 r
.75702 .25107 .76267 .2613 .7749 .25607 .76938 .24705 Mtetra
.644 .711 .896 r
.76938 .24705 .7749 .25607 .78718 .25095 .7818 .24311 Mtetra
.709 .762 .894 r
.12449 .45992 .13161 .46613 .14144 .46248 .13448 .45504 Mtetra
.701 .726 .869 r
.13448 .45504 .14144 .46248 .15129 .4589 .1445 .45017 Mtetra
.69 .692 .846 r
.1445 .45017 .15129 .4589 .16116 .45548 .15454 .44539 Mtetra
.677 .659 .824 r
.15454 .44539 .16116 .45548 .17105 .45229 .16459 .44076 Mtetra
.663 .627 .803 r
.16459 .44076 .17105 .45229 .18093 .44943 .17465 .43635 Mtetra
.648 .596 .783 r
.17465 .43635 .18093 .44943 .19082 .44695 .18471 .43223 Mtetra
.632 .568 .764 r
.18471 .43223 .19082 .44695 .20071 .44491 .19476 .42848 Mtetra
.616 .541 .746 r
.19476 .42848 .20071 .44491 .2106 .4433 .20481 .42514 Mtetra
.601 .516 .73 r
.20481 .42514 .2106 .4433 .2205 .44215 .21485 .42226 Mtetra
.588 .495 .716 r
.21485 .42226 .2205 .44215 .23042 .44138 .2249 .41983 Mtetra
.576 .476 .704 r
.2249 .41983 .23042 .44138 .24036 .44096 .23495 .41785 Mtetra
.566 .461 .693 r
.23495 .41785 .24036 .44096 .25034 .44077 .24501 .41628 Mtetra
.558 .448 .684 r
.24501 .41628 .25034 .44077 .26037 .44072 .25509 .41508 Mtetra
.553 .439 .678 r
.25509 .41508 .26037 .44072 .27046 .4407 .26521 .41415 Mtetra
.549 .432 .673 r
.26521 .41415 .27046 .4407 .28061 .44062 .27536 .4134 Mtetra
.547 .428 .67 r
.27536 .4134 .28061 .44062 .29083 .44045 .28557 .41277 Mtetra
.546 .426 .667 r
.28557 .41277 .29083 .44045 .30113 .44011 .29584 .41213 Mtetra
.55 .428 .666 r
.29584 .41213 .30113 .44011 .31151 .43937 .30618 .41125 Mtetra
.556 .432 .666 r
.30618 .41125 .31151 .43937 .32199 .43807 .3166 .41 Mtetra
.556 .433 .667 r
.3166 .41 .32199 .43807 .33255 .43629 .32709 .40869 Mtetra
.555 .434 .669 r
.32709 .40869 .33255 .43629 .34318 .43418 .33762 .40748 Mtetra
.552 .436 .675 r
.33762 .40748 .34318 .43418 .35383 .43273 .3482 .40655 Mtetra
.551 .438 .678 r
.3482 .40655 .35383 .43273 .36449 .43226 .35884 .4057 Mtetra
.572 .451 .676 r
.35884 .4057 .36449 .43226 .37522 .43185 .3696 .40343 Mtetra
.597 .46 .665 r
.3696 .40343 .37522 .43185 .38603 .43092 .38051 .39912 Mtetra
.612 .459 .649 r
.38051 .39912 .38603 .43092 .39696 .42841 .39154 .39284 Mtetra
.618 .453 .636 r
.39154 .39284 .39696 .42841 .40801 .42416 .40265 .38507 Mtetra
.608 .438 .626 r
.40265 .38507 .40801 .42416 .41912 .41932 .41377 .37766 Mtetra
.592 .422 .62 r
.41377 .37766 .41912 .41932 .43026 .41456 .42487 .37162 Mtetra
.57 .404 .617 r
.42487 .37162 .43026 .41456 .44141 .41084 .43593 .36784 Mtetra
.549 .389 .617 r
.43593 .36784 .44141 .41084 .45259 .40816 .44698 .36632 Mtetra
.535 .382 .619 r
.44698 .36632 .45259 .40816 .46382 .40556 .45806 .36618 Mtetra
.532 .384 .626 r
.45806 .36618 .46382 .40556 .47511 .40238 .46921 .36642 Mtetra
.549 .405 .638 r
.46921 .36642 .47511 .40238 .48648 .39744 .48046 .36518 Mtetra
.576 .434 .651 r
.48046 .36518 .48648 .39744 .4979 .3909 .49179 .36196 Mtetra
.606 .466 .664 r
.49179 .36196 .4979 .3909 .50935 .38382 .50318 .35666 Mtetra
.628 .487 .671 r
.50318 .35666 .50935 .38382 .52082 .3768 .51462 .34993 Mtetra
.628 .488 .673 r
.51462 .34993 .52082 .3768 .53232 .37075 .52608 .34327 Mtetra
.623 .482 .67 r
.52608 .34327 .53232 .37075 .54385 .36537 .53758 .33687 Mtetra
.619 .476 .666 r
.53758 .33687 .54385 .36537 .55542 .35964 .5491 .33057 Mtetra
.618 .473 .663 r
.5491 .33057 .55542 .35964 .56702 .35341 .56065 .32421 Mtetra
.622 .475 .662 r
.56065 .32421 .56702 .35341 .57865 .34661 .57223 .31745 Mtetra
.625 .477 .662 r
.57223 .31745 .57865 .34661 .59029 .33937 .58384 .31043 Mtetra
.625 .479 .663 r
.58384 .31043 .59029 .33937 .60195 .33196 .59547 .3034 Mtetra
.625 .48 .665 r
.59547 .3034 .60195 .33196 .61363 .32444 .60713 .29646 Mtetra
.624 .482 .668 r
.60713 .29646 .61363 .32444 .62534 .31684 .61882 .28971 Mtetra
.624 .485 .673 r
.61882 .28971 .62534 .31684 .63707 .30925 .63055 .28323 Mtetra
.622 .489 .679 r
.63055 .28323 .63707 .30925 .64882 .3018 .64233 .27712 Mtetra
.621 .495 .688 r
.64233 .27712 .64882 .3018 .66061 .29458 .65416 .27141 Mtetra
.62 .503 .699 r
.65416 .27141 .66061 .29458 .67245 .2877 .66605 .26616 Mtetra
.618 .513 .712 r
.66605 .26616 .67245 .2877 .68433 .2812 .678 .26138 Mtetra
.616 .525 .728 r
.678 .26138 .68433 .2812 .69628 .27517 .69003 .25707 Mtetra
.614 .539 .747 r
.69003 .25707 .69628 .27517 .70828 .26957 .70213 .25317 Mtetra
.612 .557 .768 r
.70213 .25317 .70828 .26957 .72036 .26443 .71431 .24966 Mtetra
.61 .577 .792 r
.71431 .24966 .72036 .26443 .73251 .25967 .72657 .24645 Mtetra
.608 .6 .818 r
.72657 .24645 .73251 .25967 .74473 .25525 .73891 .24348 Mtetra
.606 .627 .845 r
.73891 .24348 .74473 .25525 .75702 .25107 .75133 .24066 Mtetra
.604 .656 .874 r
.75133 .24066 .75702 .25107 .76938 .24705 .76381 .23793 Mtetra
.601 .689 .904 r
.76381 .23793 .76938 .24705 .7818 .24311 .77637 .23521 Mtetra
.732 .765 .88 r
.11732 .45366 .12449 .45992 .13448 .45504 .12744 .44795 Mtetra
.727 .742 .864 r
.12744 .44795 .13448 .45504 .1445 .45017 .13758 .44219 Mtetra
.72 .718 .848 r
.13758 .44219 .1445 .45017 .15454 .44539 .14775 .43643 Mtetra
.711 .694 .832 r
.14775 .43643 .15454 .44539 .16459 .44076 .15794 .43072 Mtetra
.7 .669 .816 r
.15794 .43072 .16459 .44076 .17465 .43635 .16814 .42508 Mtetra
.688 .643 .799 r
.16814 .42508 .17465 .43635 .18471 .43223 .17835 .4196 Mtetra
.674 .616 .782 r
.17835 .4196 .18471 .43223 .19476 .42848 .18856 .41434 Mtetra
.66 .59 .765 r
.18856 .41434 .19476 .42848 .20481 .42514 .19878 .40936 Mtetra
.644 .563 .749 r
.19878 .40936 .20481 .42514 .21485 .42226 .20898 .40472 Mtetra
.629 .538 .733 r
.20898 .40472 .21485 .42226 .2249 .41983 .21919 .40045 Mtetra
.615 .515 .718 r
.21919 .40045 .2249 .41983 .23495 .41785 .22938 .3966 Mtetra
.602 .494 .704 r
.22938 .3966 .23495 .41785 .24501 .41628 .23959 .39314 Mtetra
.591 .476 .691 r
.23959 .39314 .24501 .41628 .25509 .41508 .24979 .39008 Mtetra
.582 .461 .68 r
.24979 .39008 .25509 .41508 .26521 .41415 .26001 .38735 Mtetra
.574 .448 .67 r
.26001 .38735 .26521 .41415 .27536 .4134 .27026 .38489 Mtetra
.569 .438 .662 r
.27026 .38489 .27536 .4134 .28557 .41277 .28054 .38262 Mtetra
.566 .429 .654 r
.28054 .38262 .28557 .41277 .29584 .41213 .29086 .38045 Mtetra
.564 .424 .648 r
.29086 .38045 .29584 .41213 .30618 .41125 .30123 .37823 Mtetra
.565 .42 .643 r
.30123 .37823 .30618 .41125 .3166 .41 .31166 .37589 Mtetra
.561 .414 .64 r
.31166 .37589 .3166 .41 .32709 .40869 .32213 .37379 Mtetra
.556 .409 .637 r
.32213 .37379 .32709 .40869 .33762 .40748 .33263 .372 Mtetra
.556 .408 .635 r
.33263 .372 .33762 .40748 .3482 .40655 .34318 .37015 Mtetra
.561 .409 .633 r
.34318 .37015 .3482 .40655 .35884 .4057 .35382 .36784 Mtetra
.577 .417 .629 r
.35382 .36784 .35884 .4057 .3696 .40343 .36459 .36389 Mtetra
.593 .426 .624 r
.36459 .36389 .3696 .40343 .38051 .39912 .37549 .35795 Mtetra
.601 .428 .62 r
.37549 .35795 .38051 .39912 .39154 .39284 .38647 .35082 Mtetra
.604 .429 .618 r
.38647 .35082 .39154 .39284 .40265 .38507 .3975 .34314 Mtetra
.598 .425 .618 r
.3975 .34314 .40265 .38507 .41377 .37766 .40852 .33621 Mtetra
.586 .417 .619 r
.40852 .33621 .41377 .37766 .42487 .37162 .41951 .33068 Mtetra
.571 .408 .621 r
.41951 .33068 .42487 .37162 .43593 .36784 .43048 .32684 Mtetra
.555 .396 .62 r
.43048 .32684 .43593 .36784 .44698 .36632 .44146 .3247 Mtetra
.54 .384 .619 r
.44146 .3247 .44698 .36632 .45806 .36618 .45246 .32397 Mtetra
.532 .378 .617 r
.45246 .32397 .45806 .36618 .46921 .36642 .46351 .32399 Mtetra
.537 .381 .617 r
.46351 .32399 .46921 .36642 .48046 .36518 .47464 .32349 Mtetra
.55 .392 .62 r
.47464 .32349 .48046 .36518 .49179 .36196 .48585 .32179 Mtetra
.57 .409 .624 r
.48585 .32179 .49179 .36196 .50318 .35666 .49715 .31808 Mtetra
.588 .425 .628 r
.49715 .31808 .50318 .35666 .51462 .34993 .5085 .31272 Mtetra
.595 .433 .632 r
.5085 .31272 .51462 .34993 .52608 .34327 .51989 .30688 Mtetra
.597 .436 .635 r
.51989 .30688 .52608 .34327 .53758 .33687 .53132 .30097 Mtetra
.594 .436 .636 r
.53132 .30097 .53758 .33687 .5491 .33057 .54278 .29538 Mtetra
.593 .437 .639 r
.54278 .29538 .5491 .33057 .56065 .32421 .55427 .29001 Mtetra
.596 .442 .642 r
.55427 .29001 .56065 .32421 .57223 .31745 .56581 .28452 Mtetra
.599 .447 .647 r
.56581 .28452 .57223 .31745 .58384 .31043 .57738 .27897 Mtetra
.601 .453 .653 r
.57738 .27897 .58384 .31043 .59547 .3034 .58899 .27352 Mtetra
.602 .459 .66 r
.58899 .27352 .59547 .3034 .60713 .29646 .60064 .26825 Mtetra
.602 .466 .668 r
.60064 .26825 .60713 .29646 .61882 .28971 .61235 .26326 Mtetra
.602 .474 .678 r
.61235 .26326 .61882 .28971 .63055 .28323 .6241 .2586 Mtetra
.601 .483 .69 r
.6241 .2586 .63055 .28323 .64233 .27712 .63592 .25434 Mtetra
.6 .493 .704 r
.63592 .25434 .64233 .27712 .65416 .27141 .6478 .25049 Mtetra
.597 .505 .72 r
.6478 .25049 .65416 .27141 .66605 .26616 .65976 .24707 Mtetra
.595 .518 .738 r
.65976 .24707 .66605 .26616 .678 .26138 .67179 .24402 Mtetra
.592 .534 .759 r
.67179 .24402 .678 .26138 .69003 .25707 .6839 .24134 Mtetra
.588 .552 .781 r
.6839 .24134 .69003 .25707 .70213 .25317 .69609 .23895 Mtetra
.585 .571 .805 r
.69609 .23895 .70213 .25317 .71431 .24966 .70836 .23678 Mtetra
.581 .592 .829 r
.70836 .23678 .71431 .24966 .72657 .24645 .72072 .23478 Mtetra
.578 .615 .853 r
.72072 .23478 .72657 .24645 .73891 .24348 .73315 .23287 Mtetra
.574 .637 .876 r
.73315 .23287 .73891 .24348 .75133 .24066 .74566 .23101 Mtetra
.571 .66 .898 r
.74566 .23101 .75133 .24066 .76381 .23793 .75824 .22915 Mtetra
.567 .684 .919 r
.75824 .22915 .76381 .23793 .77637 .23521 .7709 .22725 Mtetra
.74 .766 .874 r
.1101 .44736 .11732 .45366 .12744 .44795 .12028 .44132 Mtetra
.739 .758 .868 r
.12028 .44132 .12744 .44795 .13758 .44219 .1305 .43518 Mtetra
.738 .748 .86 r
.1305 .43518 .13758 .44219 .14775 .43643 .14074 .42897 Mtetra
.735 .736 .852 r
.14074 .42897 .14775 .43643 .15794 .43072 .15101 .4227 Mtetra
.732 .723 .842 r
.15101 .4227 .15794 .43072 .16814 .42508 .16132 .41636 Mtetra
.726 .706 .831 r
.16132 .41636 .16814 .42508 .17835 .4196 .17164 .41002 Mtetra
.718 .686 .818 r
.17164 .41002 .17835 .4196 .18856 .41434 .18197 .40372 Mtetra
.707 .663 .804 r
.18197 .40372 .18856 .41434 .19878 .40936 .19232 .39752 Mtetra
.695 .638 .789 r
.19232 .39752 .19878 .40936 .20898 .40472 .20268 .39149 Mtetra
.681 .613 .773 r
.20268 .39149 .20898 .40472 .21919 .40045 .21303 .38567 Mtetra
.666 .587 .757 r
.21303 .38567 .21919 .40045 .22938 .3966 .22339 .38012 Mtetra
.652 .561 .74 r
.22339 .38012 .22938 .3966 .23959 .39314 .23374 .37486 Mtetra
.637 .538 .725 r
.23374 .37486 .23959 .39314 .24979 .39008 .2441 .36991 Mtetra
.625 .516 .71 r
.2441 .36991 .24979 .39008 .26001 .38735 .25446 .36523 Mtetra
.615 .497 .696 r
.25446 .36523 .26001 .38735 .27026 .38489 .26484 .36079 Mtetra
.606 .481 .684 r
.26484 .36079 .27026 .38489 .28054 .38262 .27524 .35656 Mtetra
.598 .467 .673 r
.27524 .35656 .28054 .38262 .29086 .38045 .28566 .35248 Mtetra
.592 .455 .663 r
.28566 .35248 .29086 .38045 .30123 .37823 .29611 .34855 Mtetra
.587 .445 .656 r
.29611 .34855 .30123 .37823 .31166 .37589 .30659 .34475 Mtetra
.58 .436 .65 r
.30659 .34475 .31166 .37589 .32213 .37379 .31708 .34132 Mtetra
.573 .427 .645 r
.31708 .34132 .32213 .37379 .33263 .372 .32759 .33826 Mtetra
.574 .425 .64 r
.32759 .33826 .33263 .372 .34318 .37015 .33817 .33491 Mtetra
.58 .424 .635 r
.33817 .33491 .34318 .37015 .35382 .36784 .34883 .33092 Mtetra
.588 .426 .63 r
.34883 .33092 .35382 .36784 .36459 .36389 .35958 .32587 Mtetra
.596 .43 .627 r
.35958 .32587 .36459 .36389 .37549 .35795 .37042 .31981 Mtetra
.595 .429 .627 r
.37042 .31981 .37549 .35795 .38647 .35082 .38128 .31382 Mtetra
.591 .429 .63 r
.38128 .31382 .38647 .35082 .3975 .34314 .39214 .30839 Mtetra
.588 .432 .637 r
.39214 .30839 .3975 .34314 .40852 .33621 .40301 .30364 Mtetra
.584 .435 .645 r
.40301 .30364 .40852 .33621 .41951 .33068 .4139 .29958 Mtetra
.584 .44 .652 r
.4139 .29958 .41951 .33068 .43048 .32684 .42482 .29569 Mtetra
.582 .439 .652 r
.42482 .29569 .43048 .32684 .44146 .3247 .43578 .29198 Mtetra
.571 .427 .646 r
.43578 .29198 .44146 .3247 .45246 .32397 .44676 .28896 Mtetra
.56 .413 .638 r
.44676 .28896 .45246 .32397 .46351 .32399 .45779 .28662 Mtetra
.552 .401 .63 r
.45779 .28662 .46351 .32399 .47464 .32349 .46885 .28486 Mtetra
.55 .397 .627 r
.46885 .28486 .47464 .32349 .48585 .32179 .47998 .28317 Mtetra
.561 .405 .627 r
.47998 .28317 .48585 .32179 .49715 .31808 .49118 .28046 Mtetra
.573 .416 .63 r
.49118 .28046 .49715 .31808 .5085 .31272 .50245 .2767 Mtetra
.582 .426 .635 r
.50245 .2767 .5085 .31272 .51989 .30688 .51376 .27227 Mtetra
.587 .433 .64 r
.51376 .27227 .51989 .30688 .53132 .30097 .52512 .26755 Mtetra
.584 .435 .645 r
.52512 .26755 .53132 .30097 .54278 .29538 .53653 .26321 Mtetra
.582 .437 .65 r
.53653 .26321 .54278 .29538 .55427 .29001 .54798 .25923 Mtetra
.583 .443 .656 r
.54798 .25923 .55427 .29001 .56581 .28452 .55948 .2554 Mtetra
.584 .45 .664 r
.55948 .2554 .56581 .28452 .57738 .27897 .57103 .2517 Mtetra
.585 .458 .674 r
.57103 .2517 .57738 .27897 .58899 .27352 .58264 .24817 Mtetra
.586 .468 .686 r
.58264 .24817 .58899 .27352 .60064 .26825 .5943 .24484 Mtetra
.586 .479 .699 r
.5943 .24484 .60064 .26825 .61235 .26326 .60603 .24177 Mtetra
.585 .492 .715 r
.60603 .24177 .61235 .26326 .6241 .2586 .61783 .23897 Mtetra
.583 .505 .733 r
.61783 .23897 .6241 .2586 .63592 .25434 .62969 .2365 Mtetra
.58 .521 .753 r
.62969 .2365 .63592 .25434 .6478 .25049 .64163 .23432 Mtetra
.576 .538 .775 r
.64163 .23432 .6478 .25049 .65976 .24707 .65365 .23242 Mtetra
.571 .557 .799 r
.65365 .23242 .65976 .24707 .67179 .24402 .66576 .23075 Mtetra
.566 .576 .823 r
.66576 .23075 .67179 .24402 .6839 .24134 .67794 .22926 Mtetra
.561 .597 .846 r
.67794 .22926 .6839 .24134 .69609 .23895 .6902 .22788 Mtetra
.557 .617 .868 r
.6902 .22788 .69609 .23895 .70836 .23678 .70254 .22654 Mtetra
.553 .635 .886 r
.70254 .22654 .70836 .23678 .72072 .23478 .71496 .22521 Mtetra
.552 .653 .902 r
.71496 .22521 .72072 .23478 .73315 .23287 .72746 .22382 Mtetra
.55 .668 .915 r
.72746 .22382 .73315 .23287 .74566 .23101 .74003 .22237 Mtetra
.549 .68 .925 r
.74003 .22237 .74566 .23101 .75824 .22915 .75267 .22084 Mtetra
.549 .692 .933 r
.75267 .22084 .75824 .22915 .7709 .22725 .76539 .21923 Mtetra
.729 .765 .882 r
.10283 .44102 .1101 .44736 .12028 .44132 .11299 .43536 Mtetra
.734 .778 .888 r
.11299 .43536 .12028 .44132 .1305 .43518 .12318 .4296 Mtetra
.74 .791 .894 r
.12318 .4296 .1305 .43518 .14074 .42897 .13341 .42371 Mtetra
.746 .803 .898 r
.13341 .42371 .14074 .42897 .15101 .4227 .14369 .41769 Mtetra
.751 .812 .901 r
.14369 .41769 .15101 .4227 .16132 .41636 .154 .4115 Mtetra
.756 .818 .902 r
.154 .4115 .16132 .41636 .17164 .41002 .16435 .40519 Mtetra
.758 .82 .901 r
.16435 .40519 .17164 .41002 .18197 .40372 .17473 .39876 Mtetra
.759 .817 .899 r
.17473 .39876 .18197 .40372 .19232 .39752 .18514 .39229 Mtetra
.757 .809 .894 r
.18514 .39229 .19232 .39752 .20268 .39149 .19557 .38582 Mtetra
.752 .796 .888 r
.19557 .38582 .20268 .39149 .21303 .38567 .20601 .3794 Mtetra
.745 .778 .88 r
.20601 .3794 .21303 .38567 .22339 .38012 .21647 .37309 Mtetra
.735 .755 .869 r
.21647 .37309 .22339 .38012 .23374 .37486 .22693 .36693 Mtetra
.723 .73 .856 r
.22693 .36693 .23374 .37486 .2441 .36991 .2374 .36096 Mtetra
.711 .703 .841 r
.2374 .36096 .2441 .36991 .25446 .36523 .24788 .35518 Mtetra
.697 .675 .825 r
.24788 .35518 .25446 .36523 .26484 .36079 .25837 .34961 Mtetra
.684 .649 .809 r
.25837 .34961 .26484 .36079 .27524 .35656 .26886 .34424 Mtetra
.672 .626 .794 r
.26886 .34424 .27524 .35656 .28566 .35248 .27937 .3391 Mtetra
.66 .604 .782 r
.27937 .3391 .28566 .35248 .29611 .34855 .2899 .33422 Mtetra
.648 .586 .772 r
.2899 .33422 .29611 .34855 .30659 .34475 .30043 .32963 Mtetra
.636 .571 .764 r
.30043 .32963 .30659 .34475 .31708 .34132 .31097 .32543 Mtetra
.625 .556 .757 r
.31097 .32543 .31708 .34132 .32759 .33826 .32153 .32157 Mtetra
.627 .549 .747 r
.32153 .32157 .32759 .33826 .33817 .33491 .33214 .31746 Mtetra
.633 .545 .738 r
.33214 .31746 .33817 .33491 .34883 .33092 .34283 .31288 Mtetra
.634 .541 .732 r
.34283 .31288 .34883 .33092 .35958 .32587 .35356 .30806 Mtetra
.634 .544 .734 r
.35356 .30806 .35958 .32587 .37042 .31981 .36432 .30326 Mtetra
.621 .549 .752 r
.36432 .30326 .37042 .31981 .38128 .31382 .37508 .29942 Mtetra
.604 .566 .785 r
.37508 .29942 .38128 .31382 .39214 .30839 .38583 .29668 Mtetra
.602 .61 .831 r
.38583 .29668 .39214 .30839 .40301 .30364 .39662 .29422 Mtetra
.613 .666 .877 r
.39662 .29422 .40301 .30364 .4139 .29958 .40747 .29151 Mtetra
.658 .721 .895 r
.40747 .29151 .4139 .29958 .42482 .29569 .41841 .2876 Mtetra
.695 .733 .88 r
.41841 .2876 .42482 .29569 .43578 .29198 .42944 .28247 Mtetra
.693 .698 .85 r
.42944 .28247 .43578 .29198 .44676 .28896 .44051 .27709 Mtetra
.671 .641 .812 r
.44051 .27709 .44676 .28896 .45779 .28662 .4516 .27198 Mtetra
.631 .58 .779 r
.4516 .27198 .45779 .28662 .46885 .28486 .46271 .26798 Mtetra
.602 .538 .755 r
.46271 .26798 .46885 .28486 .47998 .28317 .47386 .26494 Mtetra
.597 .522 .741 r
.47386 .26494 .47998 .28317 .49118 .28046 .48505 .26193 Mtetra
.601 .522 .737 r
.48505 .26193 .49118 .28046 .50245 .2767 .4963 .25868 Mtetra
.612 .533 .742 r
.4963 .25868 .50245 .2767 .51376 .27227 .5076 .25495 Mtetra
.619 .545 .749 r
.5076 .25495 .51376 .27227 .52512 .26755 .51895 .25097 Mtetra
.614 .55 .759 r
.51895 .25097 .52512 .26755 .53653 .26321 .53036 .24734 Mtetra
.608 .556 .77 r
.53036 .24734 .53653 .26321 .54798 .25923 .54181 .24409 Mtetra
.603 .563 .782 r
.54181 .24409 .54798 .25923 .55948 .2554 .55332 .24115 Mtetra
.599 .573 .797 r
.55332 .24115 .55948 .2554 .57103 .2517 .5649 .23848 Mtetra
.594 .588 .815 r
.5649 .23848 .57103 .2517 .58264 .24817 .57653 .23604 Mtetra
.589 .605 .836 r
.57653 .23604 .58264 .24817 .5943 .24484 .58823 .23381 Mtetra
.582 .625 .86 r
.58823 .23381 .5943 .24484 .60603 .24177 .60001 .23179 Mtetra
.573 .647 .885 r
.60001 .23179 .60603 .24177 .61783 .23897 .61185 .22998 Mtetra
.56 .668 .91 r
.61185 .22998 .61783 .23897 .62969 .2365 .62377 .22836 Mtetra
.546 .688 .932 r
.62377 .22836 .62969 .2365 .64163 .23432 .63577 .22691 Mtetra
.53 .705 .951 r
.63577 .22691 .64163 .23432 .65365 .23242 .64785 .22557 Mtetra
.517 .719 .964 r
.64785 .22557 .65365 .23242 .66576 .23075 .66 .2243 Mtetra
.508 .73 .973 r
.66 .2243 .66576 .23075 .67794 .22926 .67223 .22304 Mtetra
.505 .738 .978 r
.67223 .22304 .67794 .22926 .6902 .22788 .68454 .22173 Mtetra
.508 .743 .98 r
.68454 .22173 .6902 .22788 .70254 .22654 .69692 .22031 Mtetra
.516 .745 .978 r
.69692 .22031 .70254 .22654 .71496 .22521 .70936 .21876 Mtetra
.529 .744 .974 r
.70936 .21876 .71496 .22521 .72746 .22382 .72188 .21705 Mtetra
.541 .739 .967 r
.72188 .21705 .72746 .22382 .74003 .22237 .73446 .2152 Mtetra
.552 .732 .959 r
.73446 .2152 .74003 .22237 .75267 .22084 .74711 .21322 Mtetra
.562 .722 .949 r
.74711 .21322 .75267 .22084 .76539 .21923 .75983 .21113 Mtetra
.701 .761 .898 r
.09551 .43462 .10283 .44102 .11299 .43536 .10557 .42989 Mtetra
.708 .792 .916 r
.10557 .42989 .11299 .43536 .12318 .4296 .11567 .42504 Mtetra
.715 .825 .933 r
.11567 .42504 .12318 .4296 .13341 .42371 .12583 .42005 Mtetra
.72 .857 .947 r
.12583 .42005 .13341 .42371 .14369 .41769 .13603 .41488 Mtetra
.725 .888 .955 r
.13603 .41488 .14369 .41769 .154 .4115 .14629 .4095 Mtetra
.725 .915 .959 r
.14629 .4095 .154 .4115 .16435 .40519 .15659 .4039 Mtetra
.723 .937 .957 r
.15659 .4039 .16435 .40519 .17473 .39876 .16695 .39808 Mtetra
.717 .953 .951 r
.16695 .39808 .17473 .39876 .18514 .39229 .17735 .3921 Mtetra
.71 .963 .942 r
.17735 .3921 .18514 .39229 .19557 .38582 .18779 .38597 Mtetra
.701 .968 .934 r
.18779 .38597 .19557 .38582 .20601 .3794 .19826 .37975 Mtetra
.693 .97 .928 r
.19826 .37975 .20601 .3794 .21647 .37309 .20876 .37349 Mtetra
.688 .97 .926 r
.20876 .37349 .21647 .37309 .22693 .36693 .21928 .36725 Mtetra
.685 .969 .928 r
.21928 .36725 .22693 .36693 .2374 .36096 .22982 .36106 Mtetra
.685 .966 .933 r
.22982 .36106 .2374 .36096 .24788 .35518 .24037 .35497 Mtetra
.687 .962 .941 r
.24037 .35497 .24788 .35518 .25837 .34961 .25094 .34902 Mtetra
.686 .956 .95 r
.25094 .34902 .25837 .34961 .26886 .34424 .26152 .34326 Mtetra
.683 .947 .959 r
.26152 .34326 .26886 .34424 .27937 .3391 .2721 .33773 Mtetra
.675 .937 .966 r
.2721 .33773 .27937 .3391 .2899 .33422 .28269 .33249 Mtetra
.664 .926 .973 r
.28269 .33249 .2899 .33422 .30043 .32963 .29329 .32758 Mtetra
.654 .915 .978 r
.29329 .32758 .30043 .32963 .31097 .32543 .30391 .32294 Mtetra
.651 .902 .982 r
.30391 .32294 .31097 .32543 .32153 .32157 .31454 .31851 Mtetra
.669 .888 .978 r
.31454 .31851 .32153 .32157 .33214 .31746 .32522 .31395 Mtetra
.682 .876 .971 r
.32522 .31395 .33214 .31746 .34283 .31288 .33595 .30924 Mtetra
.654 .866 .979 r
.33595 .30924 .34283 .31288 .35356 .30806 .34668 .30509 Mtetra
.576 .867 .995 r
.34668 .30509 .35356 .30806 .36432 .30326 .3574 .30187 Mtetra
.346 .805 .937 r
.3574 .30187 .36432 .30326 .37508 .29942 .3681 .30012 Mtetra
.002 0 0 r
.3681 .30012 .37508 .29942 .38583 .29668 .37879 .29963 Mtetra
.151 0 0 r
.37879 .29963 .38583 .29668 .39662 .29422 .38956 .29896 Mtetra
.157 0 0 r
.38956 .29896 .39662 .29422 .40747 .29151 .40044 .29721 Mtetra
.023 0 0 r
.40044 .29721 .40747 .29151 .41841 .2876 .41146 .29328 Mtetra
0 0 0 r
.41146 .29328 .41841 .2876 .42944 .28247 .42259 .28714 Mtetra
.42259 .28714 .42944 .28247 .44051 .27709 .43379 .27993 Mtetra
.533 .908 .74 r
.43379 .27993 .44051 .27709 .4516 .27198 .44501 .27251 Mtetra
.601 .952 .886 r
.44501 .27251 .4516 .27198 .46271 .26798 .45623 .26637 Mtetra
.608 .925 .97 r
.45623 .26637 .46271 .26798 .47386 .26494 .46745 .26168 Mtetra
.602 .875 .992 r
.46745 .26168 .47386 .26494 .48505 .26193 .47869 .25795 Mtetra
.584 .844 .994 r
.47869 .25795 .48505 .26193 .4963 .25868 .48998 .25477 Mtetra
.59 .85 .993 r
.48998 .25477 .4963 .25868 .5076 .25495 .50132 .25144 Mtetra
.586 .863 .995 r
.50132 .25144 .5076 .25495 .51895 .25097 .51272 .24798 Mtetra
.55 .868 .995 r
.51272 .24798 .51895 .25097 .53036 .24734 .52417 .24474 Mtetra
.509 .864 .989 r
.52417 .24474 .53036 .24734 .54181 .24409 .53567 .24178 Mtetra
.463 .851 .98 r
.53567 .24178 .54181 .24409 .55332 .24115 .54724 .23915 Mtetra
.414 .835 .964 r
.54724 .23915 .55332 .24115 .5649 .23848 .55886 .23682 Mtetra
.364 .815 .942 r
.55886 .23682 .5649 .23848 .57653 .23604 .57056 .23473 Mtetra
.314 .792 .914 r
.57056 .23473 .57653 .23604 .58823 .23381 .58232 .23284 Mtetra
.269 .769 .883 r
.58232 .23284 .58823 .23381 .60001 .23179 .59416 .23109 Mtetra
.232 .747 .855 r
.59416 .23109 .60001 .23179 .61185 .22998 .60606 .22945 Mtetra
.207 .732 .835 r
.60606 .22945 .61185 .22998 .62377 .22836 .61804 .22788 Mtetra
.2 .727 .829 r
.61804 .22788 .62377 .22836 .63577 .22691 .6301 .22633 Mtetra
.211 .734 .838 r
.6301 .22633 .63577 .22691 .64785 .22557 .64222 .22473 Mtetra
.24 .752 .863 r
.64222 .22473 .64785 .22557 .66 .2243 .65442 .22306 Mtetra
.286 .777 .898 r
.65442 .22306 .66 .2243 .67223 .22304 .66668 .22124 Mtetra
.344 .804 .937 r
.66668 .22124 .67223 .22304 .68454 .22173 .67901 .21924 Mtetra
.409 .825 .971 r
.67901 .21924 .68454 .22173 .69692 .22031 .6914 .21702 Mtetra
.47 .834 .993 r
.6914 .21702 .69692 .22031 .70936 .21876 .70385 .21459 Mtetra
.522 .829 1 r
.70385 .21459 .70936 .21876 .72188 .21705 .71636 .21193 Mtetra
.559 .812 .992 r
.71636 .21193 .72188 .21705 .73446 .2152 .72892 .20908 Mtetra
.585 .787 .976 r
.72892 .20908 .73446 .2152 .74711 .21322 .74154 .20609 Mtetra
.601 .759 .954 r
.74154 .20609 .74711 .21322 .75983 .21113 .75422 .20298 Mtetra
.654 .751 .921 r
.08813 .42819 .09551 .43462 .10557 .42989 .09805 .42473 Mtetra
.654 .795 .95 r
.09805 .42473 .10557 .42989 .11567 .42504 .10801 .42119 Mtetra
.65 .841 .974 r
.10801 .42119 .11567 .42504 .12583 .42005 .11803 .41752 Mtetra
.637 .885 .986 r
.11803 .41752 .12583 .42005 .13603 .41488 .1281 .41366 Mtetra
.611 .917 .977 r
.1281 .41366 .13603 .41488 .14629 .4095 .13824 .40958 Mtetra
.564 .927 .939 r
.13824 .40958 .14629 .4095 .15659 .4039 .14844 .40526 Mtetra
.5 .908 .87 r
.14844 .40526 .15659 .4039 .16695 .39808 .15871 .40068 Mtetra
.42 .86 .774 r
.15871 .40068 .16695 .39808 .17735 .3921 .16904 .39586 Mtetra
.336 .794 .666 r
.16904 .39586 .17735 .3921 .18779 .38597 .17942 .39082 Mtetra
0 0 0 r
.17942 .39082 .18779 .38597 .19826 .37975 .18985 .38559 Mtetra
.18985 .38559 .19826 .37975 .20876 .37349 .20032 .38021 Mtetra
.20032 .38021 .20876 .37349 .21928 .36725 .21084 .37475 Mtetra
.21084 .37475 .21928 .36725 .22982 .36106 .22138 .36924 Mtetra
.22138 .36924 .22982 .36106 .24037 .35497 .23196 .36373 Mtetra
.021 0 0 r
.23196 .36373 .24037 .35497 .25094 .34902 .24256 .35827 Mtetra
.055 0 0 r
.24256 .35827 .25094 .34902 .26152 .34326 .25318 .35289 Mtetra
.085 0 0 r
.25318 .35289 .26152 .34326 .2721 .33773 .26382 .34762 Mtetra
.106 0 0 r
.26382 .34762 .2721 .33773 .28269 .33249 .27449 .34245 Mtetra
.117 0 0 r
.27449 .34245 .28269 .33249 .29329 .32758 .28519 .33736 Mtetra
.107 0 0 r
.28519 .33736 .29329 .32758 .30391 .32294 .29592 .33221 Mtetra
.078 0 0 r
.29592 .33221 .30391 .32294 .31454 .31851 .30669 .32692 Mtetra
.022 0 0 r
.30669 .32692 .31454 .31851 .32522 .31395 .31751 .32143 Mtetra
0 0 0 r
.31751 .32143 .32522 .31395 .33595 .30924 .32836 .31588 Mtetra
.32836 .31588 .33595 .30924 .34668 .30509 .3392 .31123 Mtetra
.09 0 0 r
.3392 .31123 .34668 .30509 .3574 .30187 .34999 .30793 Mtetra
.215 0 0 r
.34999 .30793 .3574 .30187 .3681 .30012 .36075 .30623 Mtetra
.306 0 0 r
.36075 .30623 .3681 .30012 .37879 .29963 .37151 .3058 Mtetra
.292 0 0 r
.37151 .3058 .37879 .29963 .38956 .29896 .38234 .30512 Mtetra
.212 0 0 r
.38234 .30512 .38956 .29896 .40044 .29721 .39329 .30329 Mtetra
.04 0 0 r
.39329 .30329 .40044 .29721 .41146 .29328 .40438 .29933 Mtetra
0 0 0 r
.40438 .29933 .41146 .29328 .42259 .28714 .41559 .29325 Mtetra
.41559 .29325 .42259 .28714 .43379 .27993 .42687 .286 Mtetra
.42687 .286 .43379 .27993 .44501 .27251 .43818 .27849 Mtetra
.43818 .27849 .44501 .27251 .45623 .26637 .44948 .27225 Mtetra
.44948 .27225 .45623 .26637 .46745 .26168 .46078 .26761 Mtetra
.101 0 0 r
.46078 .26761 .46745 .26168 .47869 .25795 .4721 .26433 Mtetra
.191 0 0 r
.4721 .26433 .47869 .25795 .48998 .25477 .48345 .26197 Mtetra
.219 0 0 r
.48345 .26197 .48998 .25477 .50132 .25144 .49487 .25955 Mtetra
.238 0 0 r
.49487 .25955 .50132 .25144 .51272 .24798 .50635 .25693 Mtetra
.256 0 0 r
.50635 .25693 .51272 .24798 .52417 .24474 .51789 .25417 Mtetra
.267 0 0 r
.51789 .25417 .52417 .24474 .53567 .24178 .52948 .25136 Mtetra
.275 0 0 r
.52948 .25136 .53567 .24178 .54724 .23915 .54114 .24862 Mtetra
.278 0 0 r
.54114 .24862 .54724 .23915 .55886 .23682 .55286 .24599 Mtetra
.277 0 0 r
.55286 .24599 .55886 .23682 .57056 .23473 .56464 .24348 Mtetra
.271 0 0 r
.56464 .24348 .57056 .23473 .58232 .23284 .57649 .24105 Mtetra
.26 0 0 r
.57649 .24105 .58232 .23284 .59416 .23109 .5884 .23868 Mtetra
.242 0 0 r
.5884 .23868 .59416 .23109 .60606 .22945 .60038 .23631 Mtetra
.216 0 0 r
.60038 .23631 .60606 .22945 .61804 .22788 .61243 .2339 Mtetra
.178 0 0 r
.61243 .2339 .61804 .22788 .6301 .22633 .62454 .23139 Mtetra
.124 0 0 r
.62454 .23139 .6301 .22633 .64222 .22473 .63671 .22873 Mtetra
.05 0 0 r
.63671 .22873 .64222 .22473 .65442 .22306 .64893 .22589 Mtetra
0 0 0 r
.64893 .22589 .65442 .22306 .66668 .22124 .66122 .22282 Mtetra
.66122 .22282 .66668 .22124 .67901 .21924 .67356 .2195 Mtetra
.315 .805 .813 r
.67356 .2195 .67901 .21924 .6914 .21702 .68594 .2159 Mtetra
.445 .873 .922 r
.68594 .2159 .6914 .21702 .70385 .21459 .69837 .21206 Mtetra
.545 .894 .979 r
.69837 .21206 .70385 .21459 .71636 .21193 .71085 .20797 Mtetra
.608 .877 .991 r
.71085 .20797 .71636 .21193 .72892 .20908 .72338 .20369 Mtetra
.641 .839 .976 r
.72338 .20369 .72892 .20908 .74154 .20609 .73595 .19927 Mtetra
.656 .796 .95 r
.73595 .19927 .74154 .20609 .75422 .20298 .74857 .19475 Mtetra
.587 .732 .944 r
.0807 .4217 .08813 .42819 .09805 .42473 .09045 .4196 Mtetra
.574 .777 .975 r
.09045 .4196 .09805 .42473 .10801 .42119 .10026 .41745 Mtetra
.551 .82 .996 r
.10026 .41745 .10801 .42119 .11803 .41752 .11012 .41519 Mtetra
.509 .854 .994 r
.11012 .41519 .11803 .41752 .1281 .41366 .12005 .41279 Mtetra
.445 .861 .953 r
.12005 .41279 .1281 .41366 .13824 .40958 .13004 .41018 Mtetra
.354 .828 .861 r
.13004 .41018 .13824 .40958 .14844 .40526 .14011 .40735 Mtetra
.25 .757 .728 r
.14011 .40735 .14844 .40526 .15871 .40068 .15025 .40425 Mtetra
0 0 0 r
.15025 .40425 .15871 .40068 .16904 .39586 .16047 .40091 Mtetra
.16047 .40091 .16904 .39586 .17942 .39082 .17075 .39731 Mtetra
.021 0 0 r
.17075 .39731 .17942 .39082 .18985 .38559 .1811 .39347 Mtetra
.081 0 0 r
.1811 .39347 .18985 .38559 .20032 .38021 .1915 .38943 Mtetra
.13 0 0 r
.1915 .38943 .20032 .38021 .21084 .37475 .20197 .38522 Mtetra
.17 0 0 r
.20197 .38522 .21084 .37475 .22138 .36924 .21248 .38089 Mtetra
.203 0 0 r
.21248 .38089 .22138 .36924 .23196 .36373 .22303 .37647 Mtetra
.23 0 .029 r
.22303 .37647 .23196 .36373 .24256 .35827 .23363 .372 Mtetra
.25 0 .062 r
.23363 .372 .24256 .35827 .25318 .35289 .24427 .36747 Mtetra
.265 0 .087 r
.24427 .36747 .25318 .35289 .26382 .34762 .25495 .36288 Mtetra
.272 0 .103 r
.25495 .36288 .26382 .34762 .27449 .34245 .26569 .35813 Mtetra
.27 0 .11 r
.26569 .35813 .27449 .34245 .28519 .33736 .27647 .35314 Mtetra
.256 0 .105 r
.27647 .35314 .28519 .33736 .29592 .33221 .28732 .34776 Mtetra
.233 0 .09 r
.28732 .34776 .29592 .33221 .30669 .32692 .29824 .34192 Mtetra
.21 0 .068 r
.29824 .34192 .30669 .32692 .31751 .32143 .3092 .33578 Mtetra
.196 0 .049 r
.3092 .33578 .31751 .32143 .32836 .31588 .3202 .32962 Mtetra
.228 0 .055 r
.3202 .32962 .32836 .31588 .3392 .31123 .33116 .3244 Mtetra
.281 0 .072 r
.33116 .3244 .3392 .31123 .34999 .30793 .34208 .32056 Mtetra
.331 0 .086 r
.34208 .32056 .34999 .30793 .36075 .30623 .35297 .31805 Mtetra
.362 0 .086 r
.35297 .31805 .36075 .30623 .37151 .3058 .36387 .31659 Mtetra
.339 0 .046 r
.36387 .31659 .37151 .3058 .38234 .30512 .37483 .31494 Mtetra
.279 0 0 r
.37483 .31494 .38234 .30512 .39329 .30329 .38589 .31244 Mtetra
.176 0 0 r
.38589 .31244 .39329 .30329 .40438 .29933 .39707 .30847 Mtetra
.082 0 0 r
.39707 .30847 .40438 .29933 .41559 .29325 .40835 .30302 Mtetra
.056 0 0 r
.40835 .30302 .41559 .29325 .42687 .286 .41969 .29671 Mtetra
.087 0 0 r
.41969 .29671 .42687 .286 .43818 .27849 .43107 .29021 Mtetra
.181 0 0 r
.43107 .29021 .43818 .27849 .44948 .27225 .44245 .28474 Mtetra
.266 0 .052 r
.44245 .28474 .44948 .27225 .46078 .26761 .45384 .28063 Mtetra
.332 0 .096 r
.45384 .28063 .46078 .26761 .4721 .26433 .46525 .2779 Mtetra
.374 0 .127 r
.46525 .2779 .4721 .26433 .48345 .26197 .4767 .27612 Mtetra
.38 0 .14 r
.4767 .27612 .48345 .26197 .49487 .25955 .48822 .27433 Mtetra
.377 0 .15 r
.48822 .27433 .49487 .25955 .50635 .25693 .49981 .27225 Mtetra
.368 0 .155 r
.49981 .27225 .50635 .25693 .51789 .25417 .51146 .26971 Mtetra
.358 0 .154 r
.51146 .26971 .51789 .25417 .52948 .25136 .52317 .26676 Mtetra
.35 0 .149 r
.52317 .26676 .52948 .25136 .54114 .24862 .53495 .26358 Mtetra
.34 0 .137 r
.53495 .26358 .54114 .24862 .55286 .24599 .54678 .26023 Mtetra
.329 0 .119 r
.54678 .26023 .55286 .24599 .56464 .24348 .55867 .25682 Mtetra
.315 0 .095 r
.55867 .25682 .56464 .24348 .57649 .24105 .57061 .25335 Mtetra
.296 0 .063 r
.57061 .25335 .57649 .24105 .5884 .23868 .58261 .24983 Mtetra
.271 0 .022 r
.58261 .24983 .5884 .23868 .60038 .23631 .59467 .24621 Mtetra
.237 0 0 r
.59467 .24621 .60038 .23631 .61243 .2339 .60678 .24247 Mtetra
.19 0 0 r
.60678 .24247 .61243 .2339 .62454 .23139 .61894 .23856 Mtetra
.125 0 0 r
.61894 .23856 .62454 .23139 .63671 .22873 .63116 .23443 Mtetra
.037 0 0 r
.63116 .23443 .63671 .22873 .64893 .22589 .64342 .23005 Mtetra
0 0 0 r
.64342 .23005 .64893 .22589 .66122 .22282 .65572 .2254 Mtetra
.65572 .2254 .66122 .22282 .67356 .2195 .66806 .22049 Mtetra
.387 .844 .78 r
.66806 .22049 .67356 .2195 .68594 .2159 .68044 .2153 Mtetra
.528 .919 .901 r
.68044 .2153 .68594 .2159 .69837 .21206 .69285 .20986 Mtetra
.626 .936 .962 r
.69285 .20986 .69837 .21206 .71085 .20797 .7053 .20421 Mtetra
.68 .911 .974 r
.7053 .20421 .71085 .20797 .72338 .20369 .71779 .1984 Mtetra
.703 .866 .959 r
.71779 .1984 .72338 .20369 .73595 .19927 .73031 .19246 Mtetra
.708 .818 .933 r
.73031 .19246 .73595 .19927 .74857 .19475 .74288 .18646 Mtetra
.518 .708 .957 r
.07322 .41517 .0807 .4217 .09045 .4196 .08283 .41415 Mtetra
.497 .74 .981 r
.08283 .41415 .09045 .4196 .10026 .41745 .09251 .41311 Mtetra
.467 .77 .996 r
.09251 .41311 .10026 .41745 .11012 .41519 .10224 .412 Mtetra
.426 .793 .995 r
.10224 .412 .11012 .41519 .12005 .41279 .11204 .41078 Mtetra
.37 .8 .967 r
.11204 .41078 .12005 .41279 .13004 .41018 .12192 .40941 Mtetra
.296 .783 .902 r
.12192 .40941 .13004 .41018 .14011 .40735 .13187 .40786 Mtetra
.212 .737 .802 r
.13187 .40786 .14011 .40735 .15025 .40425 .14189 .40608 Mtetra
0 0 0 r
.14189 .40608 .15025 .40425 .16047 .40091 .15199 .40408 Mtetra
.15199 .40408 .16047 .40091 .17075 .39731 .16218 .40183 Mtetra
.034 0 0 r
.16218 .40183 .17075 .39731 .1811 .39347 .17243 .39934 Mtetra
.095 0 0 r
.17243 .39934 .1811 .39347 .1915 .38943 .18276 .39664 Mtetra
.145 0 0 r
.18276 .39664 .1915 .38943 .20197 .38522 .19315 .39374 Mtetra
.185 0 0 r
.19315 .39374 .20197 .38522 .21248 .38089 .20361 .39067 Mtetra
.217 0 0 r
.20361 .39067 .21248 .38089 .22303 .37647 .21413 .38743 Mtetra
.242 0 0 r
.21413 .38743 .22303 .37647 .23363 .372 .22471 .38406 Mtetra
.259 0 .025 r
.22471 .38406 .23363 .372 .24427 .36747 .23534 .38051 Mtetra
.271 0 .054 r
.23534 .38051 .24427 .36747 .25495 .36288 .24604 .37677 Mtetra
.275 0 .074 r
.24604 .37677 .25495 .36288 .26569 .35813 .2568 .37276 Mtetra
.275 0 .089 r
.2568 .37276 .26569 .35813 .27647 .35314 .26763 .36843 Mtetra
.272 0 .099 r
.26763 .36843 .27647 .35314 .28732 .34776 .27853 .36374 Mtetra
.272 0 .111 r
.27853 .36374 .28732 .34776 .29824 .34192 .28949 .35874 Mtetra
.285 0 .132 r
.28949 .35874 .29824 .34192 .3092 .33578 .30049 .35371 Mtetra
.311 0 .16 r
.30049 .35371 .3092 .33578 .3202 .32962 .3115 .34894 Mtetra
.353 0 .198 r
.3115 .34894 .3202 .32962 .33116 .3244 .3225 .34502 Mtetra
.392 .033 .231 r
.3225 .34502 .33116 .3244 .34208 .32056 .33349 .34215 Mtetra
.414 .058 .249 r
.33349 .34215 .34208 .32056 .35297 .31805 .34448 .33992 Mtetra
.422 .067 .255 r
.34448 .33992 .35297 .31805 .36387 .31659 .35552 .33798 Mtetra
.41 .054 .246 r
.35552 .33798 .36387 .31659 .37483 .31494 .36664 .33564 Mtetra
.388 .029 .229 r
.36664 .33564 .37483 .31494 .38589 .31244 .37785 .33252 Mtetra
.361 .001 .211 r
.37785 .33252 .38589 .31244 .39707 .30847 .38916 .32854 Mtetra
.338 0 .2 r
.38916 .32854 .39707 .30847 .40835 .30302 .40054 .32369 Mtetra
.322 0 .201 r
.40054 .32369 .40835 .30302 .41969 .29671 .41199 .31807 Mtetra
.319 0 .207 r
.41199 .31807 .41969 .29671 .43107 .29021 .4235 .31202 Mtetra
.332 0 .217 r
.4235 .31202 .43107 .29021 .44245 .28474 .43503 .30627 Mtetra
.346 0 .221 r
.43503 .30627 .44245 .28474 .45384 .28063 .44658 .30116 Mtetra
.366 .008 .218 r
.44658 .30116 .45384 .28063 .46525 .2779 .45814 .2971 Mtetra
.378 .011 .209 r
.45814 .2971 .46525 .2779 .4767 .27612 .46974 .29391 Mtetra
.374 0 .189 r
.46974 .29391 .4767 .27612 .48822 .27433 .4814 .29097 Mtetra
.364 0 .169 r
.4814 .29097 .48822 .27433 .49981 .27225 .49311 .28801 Mtetra
.346 0 .147 r
.49311 .28801 .49981 .27225 .51146 .26971 .50489 .28474 Mtetra
.326 0 .126 r
.50489 .28474 .51146 .26971 .52317 .26676 .51672 .2811 Mtetra
.306 0 .105 r
.51672 .2811 .52317 .26676 .53495 .26358 .52861 .27713 Mtetra
.284 0 .08 r
.52861 .27713 .53495 .26358 .54678 .26023 .54055 .27289 Mtetra
.261 0 .05 r
.54055 .27289 .54678 .26023 .55867 .25682 .55254 .26845 Mtetra
.232 0 .011 r
.55254 .26845 .55867 .25682 .57061 .25335 .56458 .26383 Mtetra
.196 0 0 r
.56458 .26383 .57061 .25335 .58261 .24983 .57666 .25905 Mtetra
.149 0 0 r
.57666 .25905 .58261 .24983 .59467 .24621 .58879 .2541 Mtetra
.088 0 0 r
.58879 .2541 .59467 .24621 .60678 .24247 .60097 .24898 Mtetra
.007 0 0 r
.60097 .24898 .60678 .24247 .61894 .23856 .61319 .24364 Mtetra
0 0 0 r
.61319 .24364 .61894 .23856 .63116 .23443 .62544 .23807 Mtetra
.62544 .23807 .63116 .23443 .64342 .23005 .63773 .23225 Mtetra
.365 .816 .693 r
.63773 .23225 .64342 .23005 .65572 .2254 .65006 .22617 Mtetra
.5 .906 .819 r
.65006 .22617 .65572 .2254 .66806 .22049 .66241 .21983 Mtetra
.609 .953 .905 r
.66241 .21983 .66806 .22049 .68044 .2153 .6748 .21326 Mtetra
.681 .957 .948 r
.6748 .21326 .68044 .2153 .69285 .20986 .68721 .20648 Mtetra
.722 .934 .958 r
.68721 .20648 .69285 .20986 .7053 .20421 .69964 .19953 Mtetra
.741 .898 .949 r
.69964 .19953 .7053 .20421 .71779 .1984 .71211 .19246 Mtetra
.746 .859 .932 r
.71211 .19246 .71779 .1984 .73031 .19246 .7246 .1853 Mtetra
.743 .819 .911 r
.7246 .1853 .73031 .19246 .74288 .18646 .73713 .1781 Mtetra
.466 .687 .962 r
.06568 .40859 .07322 .41517 .08283 .41415 .07521 .40825 Mtetra
.447 .704 .976 r
.07521 .40825 .08283 .41415 .09251 .41311 .0848 .40791 Mtetra
.426 .722 .987 r
.0848 .40791 .09251 .41311 .10224 .412 .09446 .40753 Mtetra
.401 .738 .992 r
.09446 .40753 .10224 .412 .11204 .41078 .10418 .4071 Mtetra
.37 .752 .989 r
.10418 .4071 .11204 .41078 .12192 .40941 .11396 .40657 Mtetra
.333 .759 .973 r
.11396 .40657 .12192 .40941 .13187 .40786 .12383 .40591 Mtetra
.288 .758 .94 r
.12383 .40591 .13187 .40786 .14189 .40608 .13377 .40509 Mtetra
.234 .742 .885 r
.13377 .40509 .14189 .40608 .15199 .40408 .14379 .40408 Mtetra
.173 .709 .809 r
.14379 .40408 .15199 .40408 .16218 .40183 .15389 .40287 Mtetra
.107 .66 .713 r
.15389 .40287 .16218 .40183 .17243 .39934 .16406 .40145 Mtetra
0 0 0 r
.16406 .40145 .17243 .39934 .18276 .39664 .17432 .39983 Mtetra
.019 0 0 r
.17432 .39983 .18276 .39664 .19315 .39374 .18465 .39802 Mtetra
.072 0 0 r
.18465 .39802 .19315 .39374 .20361 .39067 .19506 .39601 Mtetra
.114 0 0 r
.19506 .39601 .20361 .39067 .21413 .38743 .20553 .3938 Mtetra
.148 0 0 r
.20553 .3938 .21413 .38743 .22471 .38406 .21608 .39139 Mtetra
.171 0 0 r
.21608 .39139 .22471 .38406 .23534 .38051 .2267 .38873 Mtetra
.186 0 0 r
.2267 .38873 .23534 .38051 .24604 .37677 .2374 .38582 Mtetra
.198 0 0 r
.2374 .38582 .24604 .37677 .2568 .37276 .24817 .38265 Mtetra
.209 0 0 r
.24817 .38265 .2568 .37276 .26763 .36843 .259 .37922 Mtetra
.228 0 0 r
.259 .37922 .26763 .36843 .27853 .36374 .2699 .37567 Mtetra
.256 0 .016 r
.2699 .37567 .27853 .36374 .28949 .35874 .28083 .37211 Mtetra
.299 0 .073 r
.28083 .37211 .28949 .35874 .30049 .35371 .2918 .36885 Mtetra
.343 0 .129 r
.2918 .36885 .30049 .35371 .3115 .34894 .30278 .36606 Mtetra
.381 0 .179 r
.30278 .36606 .3115 .34894 .3225 .34502 .31378 .36379 Mtetra
.404 .03 .211 r
.31378 .36379 .3225 .34502 .33349 .34215 .32481 .36194 Mtetra
.403 .035 .221 r
.32481 .36194 .33349 .34215 .34448 .33992 .33592 .3598 Mtetra
.388 .021 .215 r
.33592 .3598 .34448 .33992 .35552 .33798 .34712 .35705 Mtetra
.365 0 .195 r
.34712 .35705 .35552 .33798 .36664 .33564 .35841 .35368 Mtetra
.34 0 .171 r
.35841 .35368 .36664 .33564 .37785 .33252 .36978 .34975 Mtetra
.329 0 .155 r
.36978 .34975 .37785 .33252 .38916 .32854 .38119 .34576 Mtetra
.328 0 .154 r
.38119 .34576 .38916 .32854 .40054 .32369 .39266 .34171 Mtetra
.32 0 .162 r
.39266 .34171 .40054 .32369 .41199 .31807 .4042 .33709 Mtetra
.313 0 .172 r
.4042 .33709 .41199 .31807 .4235 .31202 .41581 .33185 Mtetra
.304 0 .179 r
.41581 .33185 .4235 .31202 .43503 .30627 .42747 .32599 Mtetra
.295 0 .174 r
.42747 .32599 .43503 .30627 .44658 .30116 .43918 .31983 Mtetra
.296 0 .162 r
.43918 .31983 .44658 .30116 .45814 .2971 .45092 .31408 Mtetra
.292 0 .137 r
.45092 .31408 .45814 .2971 .46974 .29391 .46268 .30887 Mtetra
.279 0 .098 r
.46268 .30887 .46974 .29391 .4814 .29097 .47448 .30412 Mtetra
.26 0 .052 r
.47448 .30412 .4814 .29097 .49311 .28801 .48632 .29966 Mtetra
.228 0 .001 r
.48632 .29966 .49311 .28801 .50489 .28474 .49821 .2952 Mtetra
.192 0 0 r
.49821 .2952 .50489 .28474 .51672 .2811 .51014 .2906 Mtetra
.149 0 0 r
.51014 .2906 .51672 .2811 .52861 .27713 .52213 .28575 Mtetra
.102 0 0 r
.52213 .28575 .52861 .27713 .54055 .27289 .53417 .28062 Mtetra
.047 0 0 r
.53417 .28062 .54055 .27289 .55254 .26845 .54625 .27522 Mtetra
0 0 0 r
.54625 .27522 .55254 .26845 .56458 .26383 .55837 .26957 Mtetra
.55837 .26957 .56458 .26383 .57666 .25905 .57053 .2637 Mtetra
.57053 .2637 .57666 .25905 .58879 .2541 .58273 .25762 Mtetra
.58273 .25762 .58879 .2541 .60097 .24898 .59496 .25133 Mtetra
.401 .837 .702 r
.59496 .25133 .60097 .24898 .61319 .24364 .60723 .24483 Mtetra
.509 .908 .801 r
.60723 .24483 .61319 .24364 .62544 .23807 .61952 .2381 Mtetra
.601 .952 .876 r
.61952 .2381 .62544 .23807 .63773 .23225 .63185 .23115 Mtetra
.67 .968 .922 r
.63185 .23115 .63773 .23225 .65006 .22617 .6442 .22398 Mtetra
.717 .962 .943 r
.6442 .22398 .65006 .22617 .66241 .21983 .65658 .2166 Mtetra
.745 .942 .948 r
.65658 .2166 .66241 .21983 .6748 .21326 .66898 .20904 Mtetra
.76 .916 .942 r
.66898 .20904 .6748 .21326 .68721 .20648 .6814 .20133 Mtetra
.767 .889 .932 r
.6814 .20133 .68721 .20648 .69964 .19953 .69385 .1935 Mtetra
.768 .861 .919 r
.69385 .1935 .69964 .19953 .71211 .19246 .70632 .1856 Mtetra
.765 .836 .906 r
.70632 .1856 .71211 .19246 .7246 .1853 .71882 .17764 Mtetra
.76 .811 .893 r
.71882 .17764 .7246 .1853 .73713 .1781 .73134 .16968 Mtetra
.463 .686 .962 r
.05808 .40196 .06568 .40859 .07521 .40825 .06762 .40164 Mtetra
.46 .686 .964 r
.06762 .40164 .07521 .40825 .0848 .40791 .07722 .40134 Mtetra
.459 .688 .965 r
.07722 .40134 .0848 .40791 .09446 .40753 .08687 .40104 Mtetra
.459 .691 .967 r
.08687 .40104 .09446 .40753 .10418 .4071 .09659 .40071 Mtetra
.459 .695 .969 r
.09659 .40071 .10418 .4071 .11396 .40657 .10637 .40033 Mtetra
.461 .702 .972 r
.10637 .40033 .11396 .40657 .12383 .40591 .11622 .39987 Mtetra
.464 .712 .976 r
.11622 .39987 .12383 .40591 .13377 .40509 .12615 .3993 Mtetra
.467 .723 .98 r
.12615 .3993 .13377 .40509 .14379 .40408 .13615 .39859 Mtetra
.471 .736 .985 r
.13615 .39859 .14379 .40408 .15389 .40287 .14622 .39772 Mtetra
.474 .751 .99 r
.14622 .39772 .15389 .40287 .16406 .40145 .15638 .39668 Mtetra
.476 .766 .994 r
.15638 .39668 .16406 .40145 .17432 .39983 .16661 .39546 Mtetra
.477 .781 .998 r
.16661 .39546 .17432 .39983 .18465 .39802 .17692 .39407 Mtetra
.477 .796 .999 r
.17692 .39407 .18465 .39802 .19506 .39601 .18731 .39248 Mtetra
.476 .811 .999 r
.18731 .39248 .19506 .39601 .20553 .3938 .19777 .39069 Mtetra
.474 .824 .997 r
.19777 .39069 .20553 .3938 .21608 .39139 .20831 .38871 Mtetra
.47 .836 .992 r
.20831 .38871 .21608 .39139 .2267 .38873 .21892 .38654 Mtetra
.462 .846 .984 r
.21892 .38654 .2267 .38873 .2374 .38582 .2296 .38418 Mtetra
.44 .849 .967 r
.2296 .38418 .2374 .38582 .24817 .38265 .24035 .3817 Mtetra
.399 .841 .935 r
.24035 .3817 .24817 .38265 .259 .37922 .25115 .37914 Mtetra
.323 .808 .873 r
.25115 .37914 .259 .37922 .2699 .37567 .26201 .37665 Mtetra
.214 .738 .769 r
.26201 .37665 .2699 .37567 .28083 .37211 .2729 .37429 Mtetra
0 0 0 r
.2729 .37429 .28083 .37211 .2918 .36885 .28384 .37211 Mtetra
.008 0 0 r
.28384 .37211 .2918 .36885 .30278 .36606 .29483 .37004 Mtetra
.027 0 0 r
.29483 .37004 .30278 .36606 .31378 .36379 .3059 .36766 Mtetra
0 0 0 r
.3059 .36766 .31378 .36379 .32481 .36194 .31706 .36465 Mtetra
.265 .758 .682 r
.31706 .36465 .32481 .36194 .33592 .3598 .32836 .36042 Mtetra
.547 .929 .89 r
.32836 .36042 .33592 .3598 .34712 .35705 .33977 .35497 Mtetra
.684 .932 .968 r
.33977 .35497 .34712 .35705 .35841 .35368 .35123 .34922 Mtetra
.701 .864 .959 r
.35123 .34922 .35841 .35368 .36978 .34975 .36271 .3438 Mtetra
.648 .801 .956 r
.36271 .3438 .36978 .34975 .38119 .34576 .37417 .33977 Mtetra
.577 .777 .974 r
.37417 .33977 .38119 .34576 .39266 .34171 .38561 .33716 Mtetra
.525 .808 .998 r
.38561 .33716 .39266 .34171 .4042 .33709 .39709 .33488 Mtetra
.449 .847 .976 r
.39709 .33488 .4042 .33709 .41581 .33185 .40865 .3323 Mtetra
.379 .844 .851 r
.40865 .3323 .41581 .33185 .42747 .32599 .42031 .32849 Mtetra
.327 .798 .706 r
.42031 .32849 .42747 .32599 .43918 .31983 .43206 .32346 Mtetra
0 0 0 r
.43206 .32346 .43918 .31983 .45092 .31408 .44387 .31778 Mtetra
.44387 .31778 .45092 .31408 .46268 .30887 .45573 .31178 Mtetra
.359 .811 .685 r
.45573 .31178 .46268 .30887 .47448 .30412 .46762 .30589 Mtetra
.434 .868 .778 r
.46762 .30589 .47448 .30412 .48632 .29966 .47955 .30017 Mtetra
.514 .915 .868 r
.47955 .30017 .48632 .29966 .49821 .2952 .49151 .29458 Mtetra
.577 .936 .927 r
.49151 .29458 .49821 .2952 .51014 .2906 .50352 .28905 Mtetra
.625 .94 .957 r
.50352 .28905 .51014 .2906 .52213 .28575 .51557 .28343 Mtetra
.658 .934 .969 r
.51557 .28343 .52213 .28575 .53417 .28062 .52766 .27769 Mtetra
.683 .925 .971 r
.52766 .27769 .53417 .28062 .54625 .27522 .5398 .27174 Mtetra
.702 .915 .968 r
.5398 .27174 .54625 .27522 .55837 .26957 .55197 .26559 Mtetra
.716 .904 .962 r
.55197 .26559 .55837 .26957 .57053 .2637 .56418 .25922 Mtetra
.727 .891 .955 r
.56418 .25922 .57053 .2637 .58273 .25762 .57642 .25265 Mtetra
.736 .878 .946 r
.57642 .25265 .58273 .25762 .59496 .25133 .5887 .24587 Mtetra
.743 .865 .937 r
.5887 .24587 .59496 .25133 .60723 .24483 .601 .23889 Mtetra
.748 .852 .927 r
.601 .23889 .60723 .24483 .61952 .2381 .61334 .23171 Mtetra
.752 .84 .918 r
.61334 .23171 .61952 .2381 .63185 .23115 .6257 .22435 Mtetra
.755 .829 .909 r
.6257 .22435 .63185 .23115 .6442 .22398 .63809 .2168 Mtetra
.757 .819 .901 r
.63809 .2168 .6442 .22398 .65658 .2166 .6505 .2091 Mtetra
.758 .811 .895 r
.6505 .2091 .65658 .2166 .66898 .20904 .66294 .20127 Mtetra
.759 .804 .89 r
.66294 .20127 .66898 .20904 .6814 .20133 .6754 .19333 Mtetra
.758 .799 .886 r
.6754 .19333 .6814 .20133 .69385 .1935 .68788 .18534 Mtetra
.758 .796 .883 r
.68788 .18534 .69385 .1935 .70632 .1856 .7004 .1773 Mtetra
.758 .793 .882 r
.7004 .1773 .70632 .1856 .71882 .17764 .71293 .16924 Mtetra
.757 .791 .881 r
.71293 .16924 .71882 .17764 .73134 .16968 .7255 .16118 Mtetra
.501 .701 .959 r
.05043 .39529 .05808 .40196 .06762 .40164 .06006 .39445 Mtetra
.507 .687 .948 r
.06006 .39445 .06762 .40164 .07722 .40134 .06973 .39365 Mtetra
.512 .673 .937 r
.06973 .39365 .07722 .40134 .08687 .40104 .07946 .39285 Mtetra
.518 .661 .925 r
.07946 .39285 .08687 .40104 .09659 .40071 .08925 .39206 Mtetra
.522 .649 .914 r
.08925 .39206 .09659 .40071 .10637 .40033 .09909 .39125 Mtetra
.527 .64 .904 r
.09909 .39125 .10637 .40033 .11622 .39987 .10899 .39041 Mtetra
.533 .633 .896 r
.10899 .39041 .11622 .39987 .12615 .3993 .11896 .3895 Mtetra
.539 .627 .888 r
.11896 .3895 .12615 .3993 .13615 .39859 .129 .38851 Mtetra
.545 .624 .881 r
.129 .38851 .13615 .39859 .14622 .39772 .13911 .3874 Mtetra
.551 .621 .875 r
.13911 .3874 .14622 .39772 .15638 .39668 .14929 .38616 Mtetra
.558 .62 .871 r
.14929 .38616 .15638 .39668 .16661 .39546 .15955 .38478 Mtetra
.564 .62 .867 r
.15955 .38478 .16661 .39546 .17692 .39407 .16988 .38325 Mtetra
.57 .621 .863 r
.16988 .38325 .17692 .39407 .18731 .39248 .18028 .38155 Mtetra
.576 .622 .861 r
.18028 .38155 .18731 .39248 .19777 .39069 .19075 .3797 Mtetra
.581 .623 .859 r
.19075 .3797 .19777 .39069 .20831 .38871 .2013 .3777 Mtetra
.585 .625 .858 r
.2013 .3777 .20831 .38871 .21892 .38654 .21191 .3756 Mtetra
.586 .628 .86 r
.21191 .3756 .21892 .38654 .2296 .38418 .22258 .37345 Mtetra
.584 .632 .866 r
.22258 .37345 .2296 .38418 .24035 .3817 .2333 .37134 Mtetra
.578 .64 .876 r
.2333 .37134 .24035 .3817 .25115 .37914 .24406 .36937 Mtetra
.568 .65 .891 r
.24406 .36937 .25115 .37914 .26201 .37665 .25487 .3676 Mtetra
.556 .666 .91 r
.25487 .3676 .26201 .37665 .2729 .37429 .26571 .36602 Mtetra
.555 .689 .928 r
.26571 .36602 .2729 .37429 .28384 .37211 .27663 .36435 Mtetra
.571 .711 .937 r
.27663 .36435 .28384 .37211 .29483 .37004 .28764 .36227 Mtetra
.624 .732 .924 r
.28764 .36227 .29483 .37004 .3059 .36766 .29879 .35901 Mtetra
.679 .726 .886 r
.29879 .35901 .3059 .36766 .31706 .36465 .3101 .35414 Mtetra
.715 .696 .831 r
.3101 .35414 .31706 .36465 .32836 .36042 .32158 .34736 Mtetra
.723 .655 .782 r
.32158 .34736 .32836 .36042 .33977 .35497 .33317 .33905 Mtetra
.698 .608 .752 r
.33317 .33905 .33977 .35497 .35123 .34922 .34477 .33093 Mtetra
.663 .566 .736 r
.34477 .33093 .35123 .34922 .36271 .3438 .35632 .3241 Mtetra
.608 .522 .732 r
.35632 .3241 .36271 .3438 .37417 .33977 .36776 .32003 Mtetra
.55 .488 .739 r
.36776 .32003 .37417 .33977 .38561 .33716 .37912 .31874 Mtetra
.518 .483 .757 r
.37912 .31874 .38561 .33716 .39709 .33488 .3905 .31876 Mtetra
.508 .506 .789 r
.3905 .31876 .39709 .33488 .40865 .3323 .40194 .31898 Mtetra
.552 .575 .831 r
.40194 .31898 .40865 .3323 .42031 .32849 .41352 .31767 Mtetra
.616 .657 .868 r
.41352 .31767 .42031 .32849 .43206 .32346 .42524 .31445 Mtetra
.672 .725 .889 r
.42524 .31445 .43206 .32346 .44387 .31778 .43705 .30959 Mtetra
.711 .761 .891 r
.43705 .30959 .44387 .31778 .45573 .31178 .44894 .30354 Mtetra
.722 .763 .885 r
.44894 .30354 .45573 .31178 .46762 .30589 .46088 .29706 Mtetra
.72 .748 .874 r
.46088 .29706 .46762 .30589 .47955 .30017 .47285 .29049 Mtetra
.709 .725 .862 r
.47285 .29049 .47955 .30017 .49151 .29458 .48486 .28409 Mtetra
.699 .703 .851 r
.48486 .28409 .49151 .29458 .50352 .28905 .4969 .27789 Mtetra
.691 .687 .841 r
.4969 .27789 .50352 .28905 .51557 .28343 .50898 .27182 Mtetra
.687 .677 .835 r
.50898 .27182 .51557 .28343 .52766 .27769 .52109 .2658 Mtetra
.686 .672 .83 r
.52109 .2658 .52766 .27769 .5398 .27174 .53325 .2597 Mtetra
.687 .67 .828 r
.53325 .2597 .5398 .27174 .55197 .26559 .54544 .2535 Mtetra
.691 .671 .826 r
.54544 .2535 .55197 .26559 .56418 .25922 .55768 .24713 Mtetra
.694 .673 .826 r
.55768 .24713 .56418 .25922 .57642 .25265 .56995 .2406 Mtetra
.698 .677 .825 r
.56995 .2406 .57642 .25265 .5887 .24587 .58225 .23388 Mtetra
.702 .68 .826 r
.58225 .23388 .5887 .24587 .601 .23889 .59459 .227 Mtetra
.706 .684 .827 r
.59459 .227 .601 .23889 .61334 .23171 .60695 .21996 Mtetra
.71 .689 .828 r
.60695 .21996 .61334 .23171 .6257 .22435 .61935 .21277 Mtetra
.714 .695 .831 r
.61935 .21277 .6257 .22435 .63809 .2168 .63178 .20545 Mtetra
.718 .702 .834 r
.63178 .20545 .63809 .2168 .6505 .2091 .64423 .19803 Mtetra
.722 .71 .839 r
.64423 .19803 .6505 .2091 .66294 .20127 .65672 .19052 Mtetra
.726 .72 .844 r
.65672 .19052 .66294 .20127 .6754 .19333 .66923 .18297 Mtetra
.729 .73 .851 r
.66923 .18297 .6754 .19333 .68788 .18534 .68178 .17539 Mtetra
.733 .742 .859 r
.68178 .17539 .68788 .18534 .7004 .1773 .69436 .16779 Mtetra
.736 .756 .868 r
.69436 .16779 .7004 .1773 .71293 .16924 .70697 .16019 Mtetra
.74 .77 .877 r
.70697 .16019 .71293 .16924 .7255 .16118 .71961 .15261 Mtetra
.569 .726 .948 r
.04273 .38856 .05043 .39529 .06006 .39445 .05252 .38667 Mtetra
.574 .695 .923 r
.05252 .38667 .06006 .39445 .06973 .39365 .06235 .3848 Mtetra
.577 .666 .899 r
.06235 .3848 .06973 .39365 .07946 .39285 .07223 .38295 Mtetra
.577 .639 .876 r
.07223 .38295 .07946 .39285 .08925 .39206 .08216 .38112 Mtetra
.577 .616 .855 r
.08216 .38112 .08925 .39206 .09909 .39125 .09214 .37931 Mtetra
.576 .596 .835 r
.09214 .37931 .09909 .39125 .10899 .39041 .10217 .37749 Mtetra
.576 .578 .818 r
.10217 .37749 .10899 .39041 .11896 .3895 .11225 .37565 Mtetra
.576 .563 .802 r
.11225 .37565 .11896 .3895 .129 .38851 .1224 .37376 Mtetra
.576 .55 .789 r
.1224 .37376 .129 .38851 .13911 .3874 .1326 .37181 Mtetra
.577 .54 .777 r
.1326 .37181 .13911 .3874 .14929 .38616 .14286 .36978 Mtetra
.577 .531 .766 r
.14286 .36978 .14929 .38616 .15955 .38478 .15319 .36765 Mtetra
.578 .523 .757 r
.15319 .36765 .15955 .38478 .16988 .38325 .16358 .36543 Mtetra
.579 .517 .749 r
.16358 .36543 .16988 .38325 .18028 .38155 .17404 .36309 Mtetra
.579 .511 .742 r
.17404 .36309 .18028 .38155 .19075 .3797 .18455 .36067 Mtetra
.58 .506 .736 r
.18455 .36067 .19075 .3797 .2013 .3777 .19513 .35816 Mtetra
.579 .501 .732 r
.19513 .35816 .2013 .3777 .21191 .3756 .20576 .35565 Mtetra
.577 .497 .728 r
.20576 .35565 .21191 .3756 .22258 .37345 .21643 .35318 Mtetra
.572 .492 .726 r
.21643 .35318 .22258 .37345 .2333 .37134 .22715 .35087 Mtetra
.566 .487 .725 r
.22715 .35087 .2333 .37134 .24406 .36937 .2379 .34882 Mtetra
.561 .483 .725 r
.2379 .34882 .24406 .36937 .25487 .3676 .24868 .34702 Mtetra
.556 .481 .726 r
.24868 .34702 .25487 .3676 .26571 .36602 .2595 .3454 Mtetra
.562 .485 .726 r
.2595 .3454 .26571 .36602 .27663 .36435 .27041 .34353 Mtetra
.575 .492 .723 r
.27041 .34353 .27663 .36435 .28764 .36227 .28143 .34098 Mtetra
.603 .506 .716 r
.28143 .34098 .28764 .36227 .29879 .35901 .29262 .33688 Mtetra
.633 .518 .705 r
.29262 .33688 .29879 .35901 .3101 .35414 .30399 .3308 Mtetra
.656 .524 .692 r
.30399 .3308 .3101 .35414 .32158 .34736 .31553 .32271 Mtetra
.667 .524 .681 r
.31553 .32271 .32158 .34736 .33317 .33905 .32718 .31315 Mtetra
.656 .511 .675 r
.32718 .31315 .33317 .33905 .34477 .33093 .33881 .30409 Mtetra
.631 .491 .673 r
.33881 .30409 .34477 .33093 .35632 .3241 .35036 .29676 Mtetra
.586 .459 .674 r
.35036 .29676 .35632 .3241 .36776 .32003 .36176 .29265 Mtetra
.535 .426 .676 r
.36176 .29265 .36776 .32003 .37912 .31874 .37305 .29176 Mtetra
.503 .407 .679 r
.37305 .29176 .37912 .31874 .3905 .31876 .38434 .29262 Mtetra
.492 .406 .686 r
.38434 .29262 .3905 .31876 .40194 .31898 .39568 .294 Mtetra
.521 .431 .695 r
.39568 .294 .40194 .31898 .41352 .31767 .40718 .29392 Mtetra
.56 .465 .704 r
.40718 .29392 .41352 .31767 .42524 .31445 .41882 .29181 Mtetra
.597 .496 .71 r
.41882 .29181 .42524 .31445 .43705 .30959 .43059 .28772 Mtetra
.625 .519 .713 r
.43059 .28772 .43705 .30959 .44894 .30354 .44246 .28205 Mtetra
.638 .529 .714 r
.44246 .28205 .44894 .30354 .46088 .29706 .45438 .27569 Mtetra
.642 .533 .715 r
.45438 .27569 .46088 .29706 .47285 .29049 .46634 .26907 Mtetra
.639 .531 .715 r
.46634 .26907 .47285 .29049 .48486 .28409 .47833 .26262 Mtetra
.635 .528 .716 r
.47833 .26262 .48486 .28409 .4969 .27789 .49036 .25642 Mtetra
.631 .526 .717 r
.49036 .25642 .4969 .27789 .50898 .27182 .50242 .25046 Mtetra
.628 .526 .719 r
.50242 .25046 .50898 .27182 .52109 .2658 .51452 .24467 Mtetra
.629 .528 .721 r
.51452 .24467 .52109 .2658 .53325 .2597 .52666 .23892 Mtetra
.63 .532 .724 r
.52666 .23892 .53325 .2597 .54544 .2535 .53885 .23315 Mtetra
.633 .538 .728 r
.53885 .23315 .54544 .2535 .55768 .24713 .55107 .22729 Mtetra
.637 .544 .733 r
.55107 .22729 .55768 .24713 .56995 .2406 .56334 .22132 Mtetra
.642 .552 .738 r
.56334 .22132 .56995 .2406 .58225 .23388 .57565 .21524 Mtetra
.647 .562 .745 r
.57565 .21524 .58225 .23388 .59459 .227 .58801 .20904 Mtetra
.652 .572 .752 r
.58801 .20904 .59459 .227 .60695 .21996 .60039 .20274 Mtetra
.657 .583 .76 r
.60039 .20274 .60695 .21996 .61935 .21277 .61282 .19635 Mtetra
.663 .596 .77 r
.61282 .19635 .61935 .21277 .63178 .20545 .62529 .18988 Mtetra
.669 .611 .781 r
.62529 .18988 .63178 .20545 .64423 .19803 .63779 .18335 Mtetra
.675 .627 .793 r
.63779 .18335 .64423 .19803 .65672 .19052 .65034 .17679 Mtetra
.682 .645 .807 r
.65034 .17679 .65672 .19052 .66923 .18297 .66292 .17021 Mtetra
.688 .666 .822 r
.66292 .17021 .66923 .18297 .68178 .17539 .67555 .16363 Mtetra
.695 .689 .84 r
.67555 .16363 .68178 .17539 .69436 .16779 .68821 .15707 Mtetra
.702 .714 .859 r
.68821 .15707 .69436 .16779 .70697 .16019 .70092 .15051 Mtetra
.708 .743 .879 r
.70092 .15051 .70697 .16019 .71961 .15261 .71368 .14397 Mtetra
.637 .747 .928 r
.03496 .38178 .04273 .38856 .05252 .38667 .04497 .37853 Mtetra
.635 .707 .898 r
.04497 .37853 .05252 .38667 .06235 .3848 .05501 .3753 Mtetra
.63 .67 .87 r
.05501 .3753 .06235 .3848 .07223 .38295 .0651 .3721 Mtetra
.624 .638 .844 r
.0651 .3721 .07223 .38295 .08216 .38112 .07521 .36894 Mtetra
.618 .61 .821 r
.07521 .36894 .08216 .38112 .09214 .37931 .08537 .36581 Mtetra
.612 .586 .8 r
.08537 .36581 .09214 .37931 .10217 .37749 .09557 .3627 Mtetra
.607 .565 .781 r
.09557 .3627 .10217 .37749 .11225 .37565 .10581 .35959 Mtetra
.603 .547 .765 r
.10581 .35959 .11225 .37565 .1224 .37376 .11609 .35649 Mtetra
.599 .532 .751 r
.11609 .35649 .1224 .37376 .1326 .37181 .12643 .35337 Mtetra
.595 .519 .738 r
.12643 .35337 .1326 .37181 .14286 .36978 .13681 .35022 Mtetra
.593 .507 .727 r
.13681 .35022 .14286 .36978 .15319 .36765 .14724 .34703 Mtetra
.59 .498 .718 r
.14724 .34703 .15319 .36765 .16358 .36543 .15772 .34381 Mtetra
.588 .489 .709 r
.15772 .34381 .16358 .36543 .17404 .36309 .16825 .34053 Mtetra
.586 .482 .702 r
.16825 .34053 .17404 .36309 .18455 .36067 .17883 .33724 Mtetra
.584 .475 .696 r
.17883 .33724 .18455 .36067 .19513 .35816 .18946 .33394 Mtetra
.581 .468 .691 r
.18946 .33394 .19513 .35816 .20576 .35565 .20012 .33069 Mtetra
.577 .462 .686 r
.20012 .33069 .20576 .35565 .21643 .35318 .21083 .32756 Mtetra
.572 .455 .682 r
.21083 .32756 .21643 .35318 .22715 .35087 .22156 .32465 Mtetra
.566 .449 .679 r
.22156 .32465 .22715 .35087 .2379 .34882 .23232 .32201 Mtetra
.56 .443 .676 r
.23232 .32201 .2379 .34882 .24868 .34702 .24311 .31962 Mtetra
.557 .438 .673 r
.24311 .31962 .24868 .34702 .2595 .3454 .25394 .31737 Mtetra
.561 .438 .669 r
.25394 .31737 .2595 .3454 .27041 .34353 .26485 .31481 Mtetra
.571 .441 .665 r
.26485 .31481 .27041 .34353 .28143 .34098 .27588 .31154 Mtetra
.59 .452 .661 r
.27588 .31154 .28143 .34098 .29262 .33688 .28707 .30678 Mtetra
.611 .464 .657 r
.28707 .30678 .29262 .33688 .30399 .3308 .29843 .30022 Mtetra
.629 .474 .653 r
.29843 .30022 .30399 .3308 .31553 .32271 .30993 .29196 Mtetra
.641 .481 .651 r
.30993 .29196 .31553 .32271 .32718 .31315 .32153 .28257 Mtetra
.634 .477 .652 r
.32153 .28257 .32718 .31315 .33881 .30409 .3331 .2738 Mtetra
.616 .466 .655 r
.3331 .2738 .33881 .30409 .35036 .29676 .34459 .26673 Mtetra
.58 .443 .659 r
.34459 .26673 .35036 .29676 .36176 .29265 .35594 .26256 Mtetra
.537 .414 .66 r
.35594 .26256 .36176 .29265 .37305 .29176 .36719 .26132 Mtetra
.509 .394 .658 r
.36719 .26132 .37305 .29176 .38434 .29262 .37843 .26178 Mtetra
.499 .386 .656 r
.37843 .26178 .38434 .29262 .39568 .294 .38972 .26289 Mtetra
.517 .398 .656 r
.38972 .26289 .39568 .294 .40718 .29392 .40114 .26287 Mtetra
.543 .416 .657 r
.40114 .26287 .40718 .29392 .41882 .29181 .41271 .26115 Mtetra
.569 .435 .659 r
.41271 .26115 .41882 .29181 .43059 .28772 .42441 .25762 Mtetra
.59 .452 .661 r
.42441 .25762 .43059 .28772 .44246 .28205 .43621 .25258 Mtetra
.601 .462 .664 r
.43621 .25258 .44246 .28205 .45438 .27569 .44807 .24682 Mtetra
.607 .468 .666 r
.44807 .24682 .45438 .27569 .46634 .26907 .45997 .24073 Mtetra
.606 .47 .67 r
.45997 .24073 .46634 .26907 .47833 .26262 .47192 .23479 Mtetra
.604 .471 .673 r
.47192 .23479 .47833 .26262 .49036 .25642 .48389 .22908 Mtetra
.602 .472 .676 r
.48389 .22908 .49036 .25642 .50242 .25046 .49591 .22365 Mtetra
.6 .474 .68 r
.49591 .22365 .50242 .25046 .51452 .24467 .50797 .21844 Mtetra
.6 .477 .684 r
.50797 .21844 .51452 .24467 .52666 .23892 .52008 .21334 Mtetra
.601 .482 .689 r
.52008 .21334 .52666 .23892 .53885 .23315 .53224 .20829 Mtetra
.603 .487 .694 r
.53224 .20829 .53885 .23315 .55107 .22729 .54444 .20323 Mtetra
.606 .494 .7 r
.54444 .20323 .55107 .22729 .56334 .22132 .5567 .19814 Mtetra
.61 .502 .707 r
.5567 .19814 .56334 .22132 .57565 .21524 .569 .193 Mtetra
.613 .512 .715 r
.569 .193 .57565 .21524 .58801 .20904 .58135 .18781 Mtetra
.618 .522 .724 r
.58135 .18781 .58801 .20904 .60039 .20274 .59375 .18258 Mtetra
.622 .534 .734 r
.59375 .18258 .60039 .20274 .61282 .19635 .6062 .17731 Mtetra
.627 .548 .746 r
.6062 .17731 .61282 .19635 .62529 .18988 .61871 .17202 Mtetra
.633 .564 .759 r
.61871 .17202 .62529 .18988 .63779 .18335 .63126 .16672 Mtetra
.638 .582 .775 r
.63126 .16672 .63779 .18335 .65034 .17679 .64386 .16142 Mtetra
.644 .602 .792 r
.64386 .16142 .65034 .17679 .66292 .17021 .65652 .15613 Mtetra
.65 .625 .812 r
.65652 .15613 .66292 .17021 .67555 .16363 .66923 .15088 Mtetra
.656 .652 .834 r
.66923 .15088 .67555 .16363 .68821 .15707 .68199 .14564 Mtetra
.662 .683 .86 r
.68199 .14564 .68821 .15707 .70092 .15051 .69481 .14044 Mtetra
.667 .718 .887 r
.69481 .14044 .70092 .15051 .71368 .14397 .70769 .13525 Mtetra
.693 .759 .903 r
.02714 .37496 .03496 .38178 .04497 .37853 .03739 .37024 Mtetra
.684 .718 .875 r
.03739 .37024 .04497 .37853 .05501 .3753 .04766 .36556 Mtetra
.674 .681 .849 r
.04766 .36556 .05501 .3753 .0651 .3721 .05796 .36093 Mtetra
.663 .648 .825 r
.05796 .36093 .0651 .3721 .07521 .36894 .06829 .35634 Mtetra
.654 .62 .803 r
.06829 .35634 .07521 .36894 .08537 .36581 .07864 .3518 Mtetra
.645 .595 .784 r
.07864 .3518 .08537 .36581 .09557 .3627 .08903 .3473 Mtetra
.636 .573 .767 r
.08903 .3473 .09557 .3627 .10581 .35959 .09944 .34285 Mtetra
.629 .554 .751 r
.09944 .34285 .10581 .35959 .11609 .35649 .10989 .33842 Mtetra
.622 .537 .738 r
.10989 .33842 .11609 .35649 .12643 .35337 .12037 .33403 Mtetra
.616 .523 .726 r
.12037 .33403 .12643 .35337 .13681 .35022 .13088 .32965 Mtetra
.611 .51 .715 r
.13088 .32965 .13681 .35022 .14724 .34703 .14143 .3253 Mtetra
.607 .499 .706 r
.14143 .3253 .14724 .34703 .15772 .34381 .15201 .32096 Mtetra
.602 .49 .698 r
.15201 .32096 .15772 .34381 .16825 .34053 .16264 .31663 Mtetra
.598 .481 .69 r
.16264 .31663 .16825 .34053 .17883 .33724 .17329 .31235 Mtetra
.595 .473 .684 r
.17329 .31235 .17883 .33724 .18946 .33394 .18399 .3081 Mtetra
.59 .466 .678 r
.18399 .3081 .18946 .33394 .20012 .33069 .19471 .30395 Mtetra
.586 .458 .673 r
.19471 .30395 .20012 .33069 .21083 .32756 .20546 .29992 Mtetra
.581 .451 .668 r
.20546 .29992 .21083 .32756 .22156 .32465 .21624 .29608 Mtetra
.576 .443 .664 r
.21624 .29608 .22156 .32465 .23232 .32201 .22704 .29246 Mtetra
.571 .436 .659 r
.22704 .29246 .23232 .32201 .24311 .31962 .23787 .28901 Mtetra
.567 .43 .654 r
.23787 .28901 .24311 .31962 .25394 .31737 .24874 .28566 Mtetra
.568 .427 .649 r
.24874 .28566 .25394 .31737 .26485 .31481 .25968 .2821 Mtetra
.573 .427 .645 r
.25968 .2821 .26485 .31481 .27588 .31154 .2707 .27804 Mtetra
.583 .432 .641 r
.2707 .27804 .27588 .31154 .28707 .30678 .28185 .27304 Mtetra
.596 .44 .64 r
.28185 .27304 .28707 .30678 .29843 .30022 .29312 .2669 Mtetra
.608 .45 .642 r
.29312 .2669 .29843 .30022 .30993 .29196 .30449 .25979 Mtetra
.618 .46 .646 r
.30449 .25979 .30993 .29196 .32153 .28257 .31593 .25207 Mtetra
.617 .465 .653 r
.31593 .25207 .32153 .28257 .3331 .2738 .32736 .24484 Mtetra
.607 .465 .662 r
.32736 .24484 .3331 .2738 .34459 .26673 .33874 .23876 Mtetra
.584 .454 .669 r
.33874 .23876 .34459 .26673 .35594 .26256 .35005 .23455 Mtetra
.555 .435 .67 r
.35005 .23455 .35594 .26256 .36719 .26132 .3613 .23221 Mtetra
.535 .417 .665 r
.3613 .23221 .36719 .26132 .37843 .26178 .37256 .23103 Mtetra
.526 .404 .656 r
.37256 .23103 .37843 .26178 .38972 .26289 .38387 .23035 Mtetra
.534 .403 .648 r
.38387 .23035 .38972 .26289 .40114 .26287 .39528 .22908 Mtetra
.546 .407 .643 r
.39528 .22908 .40114 .26287 .41271 .26115 .40679 .22682 Mtetra
.56 .415 .641 r
.40679 .22682 .41271 .26115 .42441 .25762 .41841 .22342 Mtetra
.572 .424 .642 r
.41841 .22342 .42441 .25762 .43621 .25258 .43012 .21907 Mtetra
.579 .431 .644 r
.43012 .21907 .43621 .25258 .44807 .24682 .4419 .21422 Mtetra
.584 .437 .648 r
.4419 .21422 .44807 .24682 .45997 .24073 .45372 .20915 Mtetra
.585 .442 .653 r
.45372 .20915 .45997 .24073 .47192 .23479 .46559 .20417 Mtetra
.584 .446 .658 r
.46559 .20417 .47192 .23479 .48389 .22908 .4775 .19937 Mtetra
.583 .449 .663 r
.4775 .19937 .48389 .22908 .49591 .22365 .48946 .19479 Mtetra
.583 .452 .668 r
.48946 .19479 .49591 .22365 .50797 .21844 .50147 .19039 Mtetra
.583 .456 .673 r
.50147 .19039 .50797 .21844 .52008 .21334 .51353 .18612 Mtetra
.583 .461 .679 r
.51353 .18612 .52008 .21334 .53224 .20829 .52565 .18194 Mtetra
.584 .466 .685 r
.52565 .18194 .53224 .20829 .54444 .20323 .53782 .1778 Mtetra
.586 .473 .691 r
.53782 .1778 .54444 .20323 .5567 .19814 .55005 .1737 Mtetra
.588 .481 .699 r
.55005 .1737 .5567 .19814 .569 .193 .56234 .16961 Mtetra
.591 .489 .708 r
.56234 .16961 .569 .193 .58135 .18781 .57468 .16554 Mtetra
.593 .5 .717 r
.57468 .16554 .58135 .18781 .59375 .18258 .58709 .16148 Mtetra
.596 .511 .729 r
.58709 .16148 .59375 .18258 .6062 .17731 .59956 .15745 Mtetra
.599 .524 .741 r
.59956 .15745 .6062 .17731 .61871 .17202 .61209 .15344 Mtetra
.603 .54 .756 r
.61209 .15344 .61871 .17202 .63126 .16672 .62468 .14946 Mtetra
.606 .557 .773 r
.62468 .14946 .63126 .16672 .64386 .16142 .63734 .14551 Mtetra
.61 .577 .792 r
.63734 .14551 .64386 .16142 .65652 .15613 .65007 .14161 Mtetra
.613 .6 .814 r
.65007 .14161 .65652 .15613 .66923 .15088 .66286 .13776 Mtetra
.616 .627 .839 r
.66286 .13776 .66923 .15088 .68199 .14564 .67572 .13396 Mtetra
.619 .658 .867 r
.67572 .13396 .68199 .14564 .69481 .14044 .68865 .13019 Mtetra
.619 .694 .897 r
.68865 .13019 .69481 .14044 .70769 .13525 .70165 .12647 Mtetra
.732 .765 .88 r
.01926 .36808 .02714 .37496 .03739 .37024 .02974 .362 Mtetra
.72 .729 .858 r
.02974 .362 .03739 .37024 .04766 .36556 .04024 .35598 Mtetra
.708 .696 .836 r
.04024 .35598 .04766 .36556 .05796 .36093 .05075 .35002 Mtetra
.696 .666 .817 r
.05075 .35002 .05796 .36093 .06829 .35634 .06127 .34413 Mtetra
.685 .64 .799 r
.06127 .34413 .06829 .35634 .07864 .3518 .07182 .3383 Mtetra
.675 .617 .783 r
.07182 .3383 .07864 .3518 .08903 .3473 .08238 .33254 Mtetra
.665 .596 .768 r
.08238 .33254 .08903 .3473 .09944 .34285 .09296 .32684 Mtetra
.656 .577 .754 r
.09296 .32684 .09944 .34285 .10989 .33842 .10356 .32121 Mtetra
.648 .56 .742 r
.10356 .32121 .10989 .33842 .12037 .33403 .11418 .31563 Mtetra
.641 .546 .731 r
.11418 .31563 .12037 .33403 .13088 .32965 .12483 .31013 Mtetra
.634 .532 .721 r
.12483 .31013 .13088 .32965 .14143 .3253 .1355 .30468 Mtetra
.628 .52 .712 r
.1355 .30468 .14143 .3253 .15201 .32096 .14619 .2993 Mtetra
.623 .51 .704 r
.14619 .2993 .15201 .32096 .16264 .31663 .1569 .29398 Mtetra
.618 .5 .697 r
.1569 .29398 .16264 .31663 .17329 .31235 .16764 .28873 Mtetra
.613 .492 .691 r
.16764 .28873 .17329 .31235 .18399 .3081 .17841 .28353 Mtetra
.609 .484 .685 r
.17841 .28353 .18399 .3081 .19471 .30395 .18921 .2784 Mtetra
.604 .476 .679 r
.18921 .2784 .19471 .30395 .20546 .29992 .20003 .27334 Mtetra
.6 .468 .673 r
.20003 .27334 .20546 .29992 .21624 .29608 .21088 .26833 Mtetra
.596 .46 .666 r
.21088 .26833 .21624 .29608 .22704 .29246 .22177 .26339 Mtetra
.591 .452 .66 r
.22177 .26339 .22704 .29246 .23787 .28901 .23268 .25851 Mtetra
.587 .443 .653 r
.23268 .25851 .23787 .28901 .24874 .28566 .24363 .25369 Mtetra
.583 .435 .646 r
.24363 .25369 .24874 .28566 .25968 .2821 .25461 .24894 Mtetra
.579 .429 .641 r
.25461 .24894 .25968 .2821 .2707 .27804 .26563 .24425 Mtetra
.577 .425 .639 r
.26563 .24425 .2707 .27804 .28185 .27304 .27668 .23962 Mtetra
.577 .427 .641 r
.27668 .23962 .28185 .27304 .29312 .2669 .28777 .23505 Mtetra
.579 .434 .648 r
.28777 .23505 .29312 .2669 .30449 .25979 .29889 .23054 Mtetra
.584 .447 .661 r
.29889 .23054 .30449 .25979 .31593 .25207 .31006 .2261 Mtetra
.591 .467 .68 r
.31006 .2261 .31593 .25207 .32736 .24484 .32127 .22172 Mtetra
.598 .489 .7 r
.32127 .22172 .32736 .24484 .33874 .23876 .33251 .2174 Mtetra
.602 .504 .715 r
.33251 .2174 .33874 .23876 .35005 .23455 .3438 .21315 Mtetra
.601 .503 .715 r
.3438 .21315 .35005 .23455 .3613 .23221 .35514 .20896 Mtetra
.594 .486 .701 r
.35514 .20896 .3613 .23221 .37256 .23103 .36651 .20483 Mtetra
.585 .463 .68 r
.36651 .20483 .37256 .23103 .38387 .23035 .37794 .20076 Mtetra
.576 .442 .661 r
.37794 .20076 .38387 .23035 .39528 .22908 .38941 .19676 Mtetra
.569 .427 .648 r
.38941 .19676 .39528 .22908 .40679 .22682 .40093 .19282 Mtetra
.566 .419 .641 r
.40093 .19282 .40679 .22682 .41841 .22342 .4125 .18894 Mtetra
.564 .416 .639 r
.4125 .18894 .41841 .22342 .43012 .21907 .42412 .18512 Mtetra
.564 .418 .642 r
.42412 .18512 .43012 .21907 .4419 .21422 .43579 .18137 Mtetra
.565 .423 .647 r
.43579 .18137 .4419 .21422 .45372 .20915 .44752 .17768 Mtetra
.566 .429 .654 r
.44752 .17768 .45372 .20915 .46559 .20417 .4593 .17406 Mtetra
.568 .436 .661 r
.4593 .17406 .46559 .20417 .4775 .19937 .47113 .1705 Mtetra
.569 .442 .668 r
.47113 .1705 .4775 .19937 .48946 .19479 .48303 .167 Mtetra
.57 .448 .675 r
.48303 .167 .48946 .19479 .50147 .19039 .49498 .16357 Mtetra
.571 .454 .681 r
.49498 .16357 .50147 .19039 .51353 .18612 .507 .16021 Mtetra
.571 .46 .688 r
.507 .16021 .51353 .18612 .52565 .18194 .51908 .1569 Mtetra
.572 .466 .695 r
.51908 .1569 .52565 .18194 .53782 .1778 .53122 .15366 Mtetra
.573 .472 .702 r
.53122 .15366 .53782 .1778 .55005 .1737 .54342 .15049 Mtetra
.573 .48 .71 r
.54342 .15049 .55005 .1737 .56234 .16961 .5557 .14738 Mtetra
.574 .488 .719 r
.5557 .14738 .56234 .16961 .57468 .16554 .56804 .14434 Mtetra
.575 .497 .73 r
.56804 .14434 .57468 .16554 .58709 .16148 .58045 .14137 Mtetra
.576 .508 .741 r
.58045 .14137 .58709 .16148 .59956 .15745 .59293 .13846 Mtetra
.577 .52 .755 r
.59293 .13846 .59956 .15745 .61209 .15344 .60549 .13561 Mtetra
.578 .534 .77 r
.60549 .13561 .61209 .15344 .62468 .14946 .61812 .13284 Mtetra
.579 .55 .787 r
.61812 .13284 .62468 .14946 .63734 .14551 .63082 .13013 Mtetra
.579 .569 .806 r
.63082 .13013 .63734 .14551 .65007 .14161 .64361 .12749 Mtetra
.579 .59 .828 r
.64361 .12749 .65007 .14161 .66286 .13776 .65647 .12491 Mtetra
.578 .614 .852 r
.65647 .12491 .66286 .13776 .67572 .13396 .66942 .12241 Mtetra
.574 .641 .879 r
.66942 .12241 .67572 .13396 .68865 .13019 .68245 .11997 Mtetra
.568 .672 .908 r
.68245 .11997 .68865 .13019 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Nooooo`;oTZCQ1?nA[>P00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo057ooooo001Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool07Oooool3o`0000;ooooo00?o0000ooooooooool0F?oo
ool2oi>MfPGoTZCQ0onA[>P00ol0003oTJcXooooo`0Eooooo`03o`000?oooooooooo053ooooo001P
ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0001cooooo0_l0001Kooooo`;oU9OC1_nC
WMX4oi:Th@?oTJcX00?o0000oijaiOooool05?ooool00ol0003oooooo`00001Aooooo`00H?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00006_ooool3o`0005Wooooo
0_nDTLh5oiBGd`GoTigJ1OnBY>400onA[>SoW[7Uo`000002oijaiAKooooo00?o0000ooooooooool0
Coooool0063ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0001So
oooo0_l0001Dooooo`;oThS51?nDS<T5oiBAcPCoU9OC1_nCWMX2oi:Th@;oWZSM0_nN/ND01?l0003o
W[7UoijaiOnN/NDFooooo`03o`000?oooooooooo04kooooo001Pooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00omgMgOoc<c<o`00000Eooooo`?o00000_ooool00ol0003oooooooooo`1=oooo
o`;oThG11OnCR<D4oiB<b@CoU97>1OnDUm<3oi>MfP;oWJ3F1OnNZ=d01OnN/NGo0000oijaiOnN/NGo
Z[OS01Kooooo00?o0000ooooooooool0C_ooool0063ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03onk^k_m4A4Co000001?ooooo0_l0001Aooooo`;oTh:m1OnCQL44oi>8a@CoU8c91OnDTLh2
oiBGd`;oW9W@1_nMX=H5oijXg@03o`000?nZ]n?oZ[OS00;oZ[OS5_ooool00ol0003oooooooooo`1=
ooooo`00H?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool03oooool3
o`0004oooooo0_nCOkX5oi>2_@CoThG11?nCR<D5oiB<b@;oU97>0_nLTlX5oibId0KoWJ3F0_nNZ=d2
ojV^g003o`000?nZ]n?oZ[OS00?oZ[OS5_ooool00ol0003oooooooooo`1<ooooo`00P_ooool2o`00
04kooooo0_nBO;P4oi=o^PGoTh:m1?nCQL45oi>8a@?oU8c900?oVhk5oibCb_nLTlX00onLTlX4oibI
d0GoWJ3F00?oYjKEojV^g?nY[]`00_nY[]`00ol0003oZ[OSojZgh`02ojZgh`03okFnhOoooooooooo
01Cooooo00?o0000ooooooooool0C?ooool007oooooo0ol00002ooooo`03o`000?oooooooooo04So
oooo00?oTWZeoi9l^?nBO;P00onBO;P4oi=o^PCoTh:m1OnCQL44oi>8a@03oiB<bOnKS/GoVhk500;o
Vhk51?nLTlX5oibId003oifPe_nWY]GoYjKE00?oYjKE0onY[]`00ol0003oZJkLojZgh`04okFnhACo
oooo0ol0001=ooooo`00O?ooool3o`0004cooooo0_nBN;<4oi9j]@CoTWbh1?nCOkX5oi>2_@CoThG1
0_nCR<D2oiZ:`@GoVhk51?nLTlX4oibId003ojJOconWY]GoYjKE00CoYjKE0onY[]`00ol0003o/kKK
okFnh@04okFnhAOooooo00?o0000ooooooooool0B_ooool007[ooooo0_l0001;ooooo`;oTWNa1?nB
N;<4oi9j]@GoTWbh0onCOkX5oi>2_@;oThG10_nIQ[d5oiZ:`@CoVhk51OnLTlX00onLVM3oYYo?ojJO
c`02ojJOc`KoYjKE00GoZJkLok>ffonc]]_o0000ok>ff`03okFnh@;o_LGP5_ooool00ol0003ooooo
ooooo`1:ooooo`00Moooool3o`0004Wooooo0_nBMK04oi9g/@GoTWRc1?nBN[D4oi9l^0CoTgnj0onC
P[d00onHP[[oVHJmoiV6_@03oiV6_@CoVX[11OnKS/D2oibCbP;oY9[:1OnVWll5ojNVe@07ok6`eonc
]]_o/kKKok>ffol0003o/kKKokFnh@05okg5h1Kooooo00?o0000ooooooooool0BOooool007Gooooo
0_l00002ooooo`03o`000?oooooooooo04?ooooo0_nBM:h4oi9e/0GoTWNa1?nBN;<4oi9j]@CoTWbh
1?nCOkX00onCP[goV8:joiR2^P02oiR2^PCoVHJm1?nJR/44oi^>a@03oj>Da_nTV/[oY9[:00?oY9[:
1OnVWll00onWY]Go/K3Gok6`e`02ok6`e`?o/kKK00?o0000okc1g_nmaN001?nmaN000oo1b^7ooooo
ooooo`0Eooooo`03o`000?oooooooooo04Sooooo001booooo`?o00001Oooool00ol0003ooooooooo
o`0nooooo`;oTG:/1?nBM:h5oi9e/0CoTWNa1?nBN;<4oi9j]@GoTWbh0_nCOkX00onGOkOoV8:joiR2
^P03oiR2^PCoVHJm1OnJR/400onKS/GoXiC6oj>DaP02oj>DaPCoY9[:1?nVWll00on`Z];o/K3Gok6`
e`04ok6`e`;o/kKK00?o0000okc1g_nl`Mh00onmaN03ol7:hAKooooo00?o0000ooooooooool0B?oo
ool0073ooooo0_l00016ooooo`03oi5aZonALZcoTG:/00;oTG:/1OnBM:h4oi9e/0CoTWNa1OnBN;<4
oi9j]@;oTWbh0_nGOKD4oiMo]`GoV8:j1?nIQ[d3oiZ:`@03oj:@`_nSU<KoXiC600CoXiC61?nTV/X0
0onVWloo/:[Bok2ZdP02ok2ZdPGo/K3G00?o/kKKokc1g_l000000onl`Mh00onmaN3o`L[Qol7:h@03
ol7:hAKooooo00?o0000ooooooooool0Aoooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool5o`00023ooooo0ol00014ooooo`;oTFnY0onALJ/5oi5b[0CoTWB^1?nBMK04
oi9g/@GoTWRc0_nBN[D2oiIk/PCoUgfe1?nGOkL5oiR2^PCoVHJm00?oVX[1oj:@`_nRT<800_nRT<85
oj>DaP?oY9[:00?o[ZG>ok2Zd_n`Z]800on`Z]84ok6`e`04ok^mfonl`Mko_<7No`0000;o_<7N00?o
`/_Qol7:hOo1b^400oo1b^400oo2cnCoooooooooo`0Cooooo`?o0000B?ooool003Sooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A401kooooo
0_l00003ooooo`03o`000?oooooooooo03kooooo00?oT6fWoi5_ZOnAKjT00_nAKjT4oi5aZ`CoTG:/
1?nBM:h4oi9e/0GoTWNa0onBN;<00onFNK3oUW^boiIk/P02oiIk/PGoUgfe1?nGOkL4oiR2^P?oVHJm
00?oX8bnoj:@`_nRT<801?nRT<85oj>DaP04ojBJb_n^YLko[ZG>ojjUcPGo/:[B00?o/K3Gok^mfonk
_M/00_nk_M/00onl`Mko0000okc1gP03ol;;h@?o`L[Q0oo2cn@Fooooo`03o`000?oooooooooo00Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo
02Wooooo000hooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Loooo
o`?o0000A?ooool3oi1]Y`GoTFnY0onALJ/4oi5b[0CoTWB^1OnBMK04oi9g/@04oi9h/onFNK3oUWV`
oiIi/0GoUW^b1?nGOKD4oiMo]`GoV8:j00CoVHJmoj2<__nPS;koX8bn1OnRT<84oj>DaP03ojbPbon^
YLko[ZG>00;o[ZG>1?n`Z]800onj^]Wo^kgKok^mf`04ok^mf`03o`000?o2bn7o`/_Q00?o`/_Q00?o
`L[Qol;?i?o2cn@00oo2cn@Fooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Zooooo`00>?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h06?ooool3o`0004Cooooo0_n@K:D5oi1]Y`CoTFnY
0onALJ/4oi5b[0GoTWB^1?nBMK02oi9g/@;oUGN_1OnFNK04oiIk/PCoUgfe1OnGOkL2oiR2^P;oWhRk
1?nPS;h6oj:@`P03oj>Da_n/X<_o[:3;00;o[:3;1?n^YLh00on`Z];o^[[IokZjf@02okZjf@Co^kgK
00?o`/_Ro`000?o2bn400oo2bn42ol?Fi`Co`/oT0_nndNTFooooo`03o`000?oooooooooo00Cooooo
00Go410@oooooooooooooooooa0@400;ooooo`Go0000:oooool003Sooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo01Gooooo0ol00013ooooo`03oi1[Y?n@K:GoT6bU00;o
T6bU1On@KJL4oi5_Z@?oTG6[1?nALZ`5oi9d[P;oTWF`0_nEMZd4oiEg[`GoUWV`1?nFNk85oiMm]@?o
Ugng00?oWXFioin8^onOR;/00onOR;/4oj2<_PCoXY3200?oZic7ojbPbon/X</00on/X</4ojjUcPKo
^[[I00Oo^kgKol;;h_o2bn;o`/_Ro`000?o2bn;o`/_Q00Go`mKW00?o`/oTokkAjOnndNT00onndNTE
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oM
gMgoooooo`0002cooooo000hooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Aooooo`?o00000oooool00ol0003oooooooooo`0looooo`;oT6ZS0on@Jj@5oi1/Y@CoT6fW
1?nAKjT3oi5aZ`GoTG:/0onBM:h00onEM:coUGJ]oiEf[@02oiEf[@GoUGN_1?nFNK04oiIk/PGoUgfe
00CoUgngoij5^OnNQKWoWXFi1OnOR;/4oj2<_P?oXY320on[W<L4ojbPb`?o[ZG>0_ni^=P4okZjf@03
ol;<h_o2bn;o`/_R00;o`/_R00?o0000olCLjoo4g>/01?o3e^L2okkKkPCo_]7Y00?o]M7^oooooooo
ool05?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000002oooool01?oM
gMgoEEEEooooool0000/ooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@400Aooooo`;o0000@Oooool2oi1[Y0CoT6ZS1?n@Jj@4oi1/Y@CoT6fW1?nA
KjT4oi5aZ`CoTG:/00CoTWB^oiEd[?nEM:coUGB/1OnEMZd4oiEg[`CoUWV`1OnFNk83oiMm]@03oib3
]onNQKWoWXFi00?oWXFi1?nOR;/5oj2<_P03oj:@`_n[W<OoZic700;oZic71On/X</01?n^YLko^KSH
okVhf?ni^=P3okZjf@?o`/cR0oo2bn801Ol0003oa=c[olCLjoo4g>_o`mKW00Go_]_^00?o_]7YokGA
k_nedNh00_nedNhFooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002cooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00kooooo0ol00010ooooo`03oi5]YOn@JjCoT6^T00;oT6^T1?n@
JZ<4oi1[Y0CoT6bU1?n@KJL5oi5_Z@?oTG6[0_nALZ`2oiEcZ`GoUGB/1?nEMZd4oiEg[`GoUWV`1?nF
Nk801?nGOKGoW8>goib3]onLPkL5oij5^@GoWhRk0onPS;h00onYV<GoZic7oj^La`03oj^La`Co[:3;
00?o^;GFokVhf?ni^=P00oni^=P00onj^]Wo`/cRol;<hP03ol;<hP03ol;;h_o4g>_o000000;oa=c[
0_nmiO84okkKkP;o/mge1OnedNhDooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?ok^k^odA4A?l00000;?ooool005Wooooo0ol00011ooooo`;oTFfU1?n@Jj@5oi1ZX`?oT6^T
1?n@K:D5oi1]Y`CoTFnY0_nALJ/00onELZWoUG>[oiEcZ`02oiEcZ`GoUGB/1?nEMZd4oiEg[`GoUWV`
0_nFNk82oib0]0GoW8>g1?nNQKT5oin8^`03oj2<__nYV<GoZIS500;oZIS51On[W<L00on/X<_o^;GF
okReeP02okReeP?o^KSH0_o2cN<4ol;<hP;oa>?^00?oa=c[o`000?o4g>/01?nmiO800onnfnko/mge
ok?Mm@03ok?Mm@;o]M7^0_nWbo<Cooooo`04o`000?ooooooooooo`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02_ooooo001Fooooo`?o00000oooool00ol0003o
ooooooooo`0kooooo`;oTg6Y0onAKJD5oi1[Y0CoT6ZS0on@Jj@4oi1/Y@GoT6fW1?nAKjT01?nALJ_o
UG:YoiEbZOnELZT4oiEcZ`CoUGB/1?nEMZd5oiEg[`?oUWV`00?oVgjcoib0]?nLP;@00_nLP;@5oib3
]`GoWXFi0onOR;/00onXUL;oZIS5ojVHa@03ojVHa@CoZic700?o]k?EokRee_nh]MH00onh]MH00oni
^=So`/gSol;=h`03ol;=h`03ol;<h_o4hnkoa>?^00?oa>?^00?o0000okgUl_nmiO800_nmiO82ojkY
n@Co/mge00?oY=KiojO;lonWbo<00onWbo<Fooooo`03o`000?oooooooooo043ooooo001Dooooo`;o
0000@?ooool2oiEf[PCoTg6Y1?nAKJD4oi1[Y0CoT6ZS0on@Jj@5oi1/Y@CoT6fW0_nAKjT2oiEbZ0Co
UG:Y1?nELj/4oiEd[0GoUGJ]1?nEMjl01?nFNK3oVgjcoi]n/onKO[<5oib0]0CoW8>g1OnNQKT00onO
R;_oZ9G2ojRE`P02ojRE`PGoZIS500?oZic7okNceOng/mD00_ng/mD4okReePGo`/gS0_o2j_44olCS
kP04okS_mOl0003o^>oeokgUlPGo[^Wi00?o/mgeojCFnOnTe_T00_nTe_T4ojO;laKooooo00?o0000
ooooooooool0@?ooool0057ooooo0ol0000oooooo`03oiQl/onEMZkoUGJ^00;oUGJ^1OnCLJT3oi5]
Y@CoT6^T1?n@JZ<4oi1[Y0CoT6bU0on@KJL00onELJOoUG:XoiEbZ002oiEbZ0CoUG:Y1?nELj/4oiEd
[0GoUGJ]0_nEMjl2oiYl/@GoVgjc1?nLP;@5oib3]`?oWXFi00?oYY;0ojRE`_nXUL800onXUL84ojVH
a@03okJae?ng/mGo]k?E00?o]k?E0onh]MH2ol;?i@?o`/gS1?o2j_401Oo4hnko^>oeokS_mOnhkoGo
000000?oX>of0_n^jOT2oi_Po@GoY=Ki0_nWbo<3oiW2m1Kooooo00?o0000ooooooooool0?oooool0
04kooooo1Ol0000oooooo`;oV7bc1OnEMZh4oi=aZ@?oTFfU1?n@Jj@4oi1ZX`CoT6^T1?n@K:D01?n@
KJOoUG6WoiEaYonELJL5oiEbZ0CoUG:Y0onELj/5oiEd[0?oUGJ]00?oVG^`oiYl/OnJO;400_nJO;45
oi]n/`CoW82d1OnLPkL00onNQKWoYY;0ojJB`002ojJB`0CoZ9G20onYV<D3okJae0Go]k?E00?o^;GF
ol;?iOo2cnD00_o2cnD00oo2cN?o`^[aol;Zl@02ol;Zl@?o[_Cb00?o^>oeoj3_m_l000000_nPkoH0
0on;i?[oVn3moi_Po@03oi_Po@;oY=Ki0onEbOT5oiW2m1Kooooo00?o0000ooooooooool0?_ooool0
04cooooo0_l00005ooooo`03o`000?oooooooooo03Wooooo0_nIP;L4oiQl/`CoUGJ^1?nCLJT3oi5]
Y@CoT6^T1On@JZ<3oi1[Y0;oT6bU0_nEKjD5oiEaY`CoUG:X1?nELZT3oiEcZ`GoUGB/00CoUGJ]oiUk
/?nINk3oVG^`1OnJO;44oi]n/`GoW82d0onLPkL00onUSkkoYY;0ojJB`003ojJB`0GoZ9G200?oZIS5
okJae?nf/M@00_nf/M@4okNce@03ol7Ai_o2cnGo`/oU00;o`/oU0onnlO800oo2j_7o[_CbojkdlP02
ojkdlP?oQn_V00?o0000oh_Tn_n;i?X00_n;i?X2oi_Po@?oSlom1OnEbOT2oiW2m0;oSkSb5_ooool0
0ol0003oooooooooo`0nooooo`00BOooool3o`00043ooooo00?oVX6goiV0]onIP;L00_nIP;L4oiQl
/`CoUGJ^1?nCLJT3oi5]Y@GoT6^T1?n@JZ<2oi1[Y003oiA^Y?nEKjGoUFnU00;oUFnU1OnELJL4oiEb
Z0CoUG:Y1?nELj/3oiEd[003oiUj[onINk3oVG^`00?oVG^`1?nJO;45oi]n/`CoW82d00?oW8>gojF?
__nUSkh00_nUSkh4ojJB`0CoZ9G200?o]K3CokJae?nf/M@01?nf/M@00ong/mGo`M7Vol7AiP02ol7A
iP03ol;?iOnnlO;o__7b00;o__7b0onKlnL01?n^m?;oQn_VohO[i_n7jnH2og7Ok003ogSEo_l0003o
QMCo00CoQMCo1?n?cod2oiG9n@?oSK_e1?n?^?8Dooooo`?o0000?oooool002;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Pooooo`;o0000@?ooool01?nIOK?oVX6goiZ1]onJPKL5oiV0]`?oV7bc1?nE
MZh4oi=aZ@CoTFfU1?n@Jj@4oi1ZX`03oi1[Y?nDKZCoU6jT00GoUFnU1?nELJL4oiEbZ0GoUG:Y0onE
Lj/01?nEM:coVGZ_oiUj[onINZl5oiUk/0CoVWba1OnKO[<2oib0]0;oY8fl1OnUSkh5ojJB`003ojRE
`_ne/=?o]K3C00;o]K3C1?nf/M@2ol7Dj0?o`M7V0ongm_401?nnlO;oVo?Woi_cionKlnL2of?Ha`;o
D<k@0omXdoP2ogSEoP04o`000?mheOkoQMCoohGDo`?oQkki1?n:_OL5ohfkm@CoSkSb5Oooool00ol0
003oooooooooo`0mooooo`008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo0ol00002oooo
o`03o`000?oooooooooo03_ooooo0onIOK<4oiZ1]`CoVH2g0onHO;<4oiEf[PGoTg6Y0onAKJD4oi1[
Y0;oT6ZS0_nBK:@3oiA^Y0GoUFnU1?nELJL4oiEbZ0GoUG:Y0_nELj/00onINJkoVGZ_oiUj[`03oiUj
[`CoVG^`1OnJO;43oi]n/`03oj>;^onTSKcoY8fl00?oY8fl1?nUSkh4ojJB`003okB_done/=?o]K3C
00Co]K3C00?o][7Dol7Dj?o1e>P00oo1e>P01?o1dNKo]oKaokOflOngm_42ogoWd@03o`000?m9a^Go
F<g_00?oF<g_0_mXdoP3oh:nnP04ohBnn_l0003oQ;kjohBnnPGoQkki1?n:_OL2ohfkm@;oS:k/1On<
/NhEooooo`03o`000?oooooooooo03cooooo000Rooooo`05oa0@4?ooooooooooooooool@41006ooo
ool2o`00047ooooo00?oUgN^oiUm/onIOK<00onIOK<3oiZ1]`CoVH2g0onHO;<5oiEf[PCoTg6Y0onA
KJD2oi1[Y0;oSfZT1?nBK:@4oiA^Y0CoUFnU1?nELJL5oiEbZ0?oUG:Y00CoVWR]oiUi[_nINJkoVGV^
1OnINZl4oiUk/0GoVWba00CoVgjcoj>;^onSRk_oXh^k1OnTSK`5ojF?_P03ojJB`?nd[m?o]:oC00;o
]:oC1?ne/=<00oo0en_o`MCXol7Dj003ol7Dj0;oZoO/00Co]oKaogoWdOmoim7oQ;Sf1?n2^_T4oh6l
nPGoP[kj00Co0000ohBnn_n4__[oQ;kj0_n7__T2ohfWiPCoS:_Z1On<[^`5ohbakQGooooo00?o0000
ooooooooool0>oooool002;ooooo00Go0000ooooooooooooooooo`00000Hooooo`?o0000?oooool2
oiEbZ@?oUgN^1OnIOK<3oiZ1]`GoVH2g0onHO;<4oiEf[PCoTg6Y0_nAKJD00on;J:CoSfZTohmZY002
ohmZY0GoTVbT0onDKZ@4oiE_Y@GoUG6W1?nELZP01?nELZWoVWR]oiYh[OnJN:d4oiUi[PCoVGZ_1OnI
Nk03oiYl/@03oj:9^_nSRk_oXh^k00?oXh^k1?nTSK`4ojF?_P03ok>^dond[m?o]:oC00?o]:oC0one
/=<3ol3Gj`?o`MCX0_n[mn`00omMd;7oQkCcohBhmP03ohBhmPCoP[[i1?n1_?X2oh:nnP;oSYgN00Co
0000ohfRh_n=X^;oSJ;R1On=YnH4ohb[jPGoS:k/0_n</Nh2oi6_jaGooooo00?o0000ooooooooool0
>oooool002;ooooo00Go0000ooooooooooooooooo`00000Fooooo`?o0000?_ooool00onDKjGoUG:Y
oiEbZ@02oiEbZ@CoUgN^1?nIOK<4oiZ1]`CoVH2g0onHO;<2oiEf[P;oQVNW1?n8IjD3oh]XY0CoSfZT
1OnBK:@3oiA^Y0CoUFnU1OnELJL3oiEbZ003oiYh[?nJN:goVWR]00?oVWR]0onINJh4oiUj[`GoVG^`
00CoVWbaoj:9^_nRRK[oXXVj1OnSRk/5ojB=_003ojF?__nc[]?o/jkC00;o/jkC1Ond[m<00one/=?o
`=O[ol3Gj`03ol3Gj`03ol7Dj?n[mncoZoO/00CoQkCc0_n4^?H00onBS/coT9?Boi2CdP02oi2CdPCo
SiSH1?n>WMh00ol0003oSJ;RohfRhP02ohfRhPGoSJOV1?n<ZnX2ohb^k0;oTZSU1OnA[n/Eooooo`03
o`000?oooooooooo03[ooooo000Rooooo`05oa0@4?ooooooooooooooool@41004oooool3o`0000;o
oooo00?o0000ooooooooool0>oooool2oiA_Y@CoUG:Y1?nGMjh5oiUm/`?oVX6g0_nIP;L2ohi_Z`?o
R6ZZ1?n6IjL4ohQWY@?oRfRT1On?JZ@4oi9/Y0?oU6jT1OnEKjD4oiEaY`04oiEbZ?nJN:coVWR/oiYh
[0GoVWR]0onINJh5oiUj[`?oVG^`00?oXHRioj:9^_nRRKX00onRRKX4oj>;^`CoY8fl00?o/ZgCok>^
donc[]<00onc[]<4okB_d`;o_m[]1?o0en/2oiWch0;oRk3^0_n7]?<2oi>9aPCoTXk<1?n@Tm84ohnH
f0?oSYgN00?o0000ohjMg_n=X^800on=X^82ohfWiP;oTigJ1?nBXn05oi:Xi@CoTJo[5_ooool00ol0
003oooooooooo`0iooooo`008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg013ooooo0ol00010oooo
o`;oTffT1?nDKjD3oiEbZ@CoUgN^1OnIOK<2oiZ1]`03oiEdZon>Kj_oSVn[00;oSVn[0on8JZX4ohIW
Y`CoR6NU1?n;J:@4ohmZY0CoTVbT0onDKZ@5oiE_Y@?oUG6W00?oVgR[oiYh[?nJN:`00onJN:`4oiYh
[@?oVGV^1OnINZl01?nINk3oXHRioj68^OnQR;T5oj:9^PGoXh^k0_nTSK`3ok:]d`Go/jkC00?o]:oC
okoJkOnof^d00onof^d00oo0en_oVO?PoiWch004oiB5`0CoThW61?nBS/`4oi2CdPGoSiSH0_n>WMh0
0ol0003oUI;>oiBGe003oiBGe0GoTigJ1?nBXn04oi:Xi@;oTJo[0onI/>LDooooo`;o0000>oooool0
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`;o0000@?ooool00onCK:?oTffToi=]Y002
oi=]Y0CoU6nU1?nELZT4oiMg[P?oVGfc00CoVgNYoiEdZonEM:_oUGB[1On>Kj/3ohQZZPCoQVNW0on8
IjD4oh]XY0CoSfZT1?nBK:@4oiA^Y0CoUFnU00CoUG6Woi]hZonKN:_oVgR[1OnJN:`4oiYh[@CoVGV^
0onINZl00onQQkSoXHRioj68^@03oj68^@CoXXVj1OnSRk/00onTSKco/ZgCok:]d`02ok:]d`Co/jkC
0_nngNl4okoJk@;oP^S=0onEPK/4oiB5`0CoThW60onBS/`5oi2CdP;oSiSH0_nFSLL2oiFBcP03o`00
0?nET/koUI;>00CoU9OD1?nCWMX5oi:Sh0;oTZSU00?oVZOOoiV`ionI/>L01?nI/>LEooooo`03o`00
0?oooooooooo03Sooooo000booooo`Go0000?_ooool3oi=/X`CoTffT1?nDKjD4oiEbZ@CoUgN^00Co
VGfcoi]gZOnKMjWoVgNY1?nEM:/4ohi_Z`?oR6ZZ1?n6IjL3ohQWY@CoRfRT1?n?JZ@5oi9/Y0?oU6jT
0onEKjD00onKMj[oVgR[oi]hZ`03oi]hZ`CoVWR/1?nJN:d4oiUi[P04oiUj[onQQkSoXHNhoj67^0Go
XHRi1OnRRKX3oj>;^`03ok6/donb[M?o/ZgC00Co/ZgC00?o/jkCokkMkonngNl00onngNl01?nof^go
P^S=oh;XcOnEOKL4oiF1^`CoU8G01?nCRLH4oi:>c0;oT9?B0_nGR<85oiJ=a`;o00000_nET/h5oiBG
e0CoTigJ0_nBXn02oi^Pf0CoVZOO1?nI/>L00onT]^Goooooooooo`0Dooooo`03o`000?oooooooooo
03Oooooo000`ooooo`;o0000@Oooool00onDKJCoTfbSoi=/X`02oi=/X`CoTffT1?nDKjD4oiEbZ@?o
UgN^00?oWGNWoi]gZOnKMjT00onKMjT3oiEdZ`CoSVn[0on8JZX4ohIWY`CoR6NU0on;J:@4ohmZY0Go
TVbT0onDKZ@01?nEKjGoVgNZoi]gZ_nKMjX5oi]hZ`CoVWR/1OnJN:d2oiUi[P03oj26^?nQQkSoXHNh
00?oXHNh1?nQR;T5oj:9^P03oj>;^ona[=?o/JcC00;o/JcC1?nb[M<2okcPlPCo_]g_00?oI]JcoiEm
]onEOKL00_nEOKL4oiF1^`CoU8G01?nCRLH2oi:>c0;oV8Bl1OnGR<801_nFSLOo0000o`000?l0003o
UI;>o`0000?oUI;>0_nDUm@2oibCbPCoViWA1OnKX=P4oiZWg`03oiV`ionT]^GoY;KU00;oY;KU5Ooo
ool00ol0003oooooooooo`0gooooo`00;Oooool3o`00043ooooo00CoUFnUoiA]Y?nDKJCoU6fT1OnC
K:<3oi=]Y0CoU6nU1?nELZT01?nGMjkoWGNWoiegYonMMjL5oi]gZ@?oUGB[1?n>Kj/3ohQZZPCoQVNW
1?n8IjD3oh]XY0GoSfZT1?nBK:@2oiA^Y003oiUfZOnKMj[oVgNZ00?oVgNZ1?nKN:/4oiYh[0GoVWR]
00CoVGV^oj26^?nPQ[SoX8Jh1?nQQkP5oj68^@?oXXVj00?o/:_Cok6/dona[=<01?na[=<00onb[M?o
_>3bokcPlP03okcPlP04okkMkonFN[;oUWZboiIj/PCoUGfg1OnEPK/4oiB5`0;oThW600?oV86hoiR4
_?nHQ;`00onHQ;`2oiN8`P?o00000onFSLL2oiFBcP03o`000?nET/koW8k400GoW9?:1?nKVM44oi^P
f0;oVZOO0_nU[Mh6ojBfiAGooooo00?o0000ooooooooool0=_ooool002cooooo0_l00011ooooo`;o
UFnU1?nDKJ@4oi=/X`CoTffT1?nDKjD3oiEbZ@GoWGNW1?nKMjT3oiEdZ`CoSVn[0on8JZX4ohIWY`Co
R6NU1?n;J:@4ohmZY0?oTVbT00CoUg>YoiUfZOnIMZWoVGJY1OnKMjX4oi]hZ`GoVWR/0onJN:d00onQ
Q[OoX8Jhoj26^002oj26^0CoXHNh1OnQR;T00onRRK[o/:_Cok2[d`02ok2[d`Co/JcC0_nji?@4okcP
lP;oUWN_0onFN[85oiEm]`CoUH6k0_nDQL02oiUn]0CoV86h0onHQ;`3o`0000;oUhS21OnFSLL00onE
T/koW8k4o`000002oib>a0CoW9?:1?nKVM42oi^Pf0;oYJKG1OnU[Mh4ojBfi@;o[[cT5Oooool00ol0
003oooooooooo`0eooooo`00;?ooool3o`0003gooooo0_nFLJL3oiE_Y@CoU6fT1?nCK:<4oi=]Y0Co
U6nU0_nELZT00onNMJGoWGNWoiegY`03oiegY`CoVgNY0onEM:/5ohi_Z`?oR6ZZ1?n6IjL3ohQWY@Co
RfRT1?n?JZ@01?nBK:CoUg>YoiMcZOnGLjT4oiUfZ@CoVgNZ1?nKN:/5oiYh[003oiYh[OnQQ[OoXHJg
00;oXHJg1?nPQ[P4oj67^0?oXHRi00?o[j_Cok2[don`Zm<00on`Zm<3ok6/d`Co^^Cd00?o_>3boiIg
[onFMjl00_nFMjl3oiIj/PGoUGfg0_nEPK/2oiUk/0GoVGjd0onHPKP3o`000003oiR4_?nGR<;oUhS2
00?oUhS20_nFSLL2oif9_`?oW8k400?o0000oib>a?nLTlX00onLTlX3oi^Id@03ojFPd?nUY]OoYJKG
00?oYJKG1OnU[Mh00onT]^Go[[cTojjli003ojjli1Cooooo00?o0000ooooooooool0=Oooool002co
oooo00Co0000ooooool0003o0000>Oooool00onGLjSoUW6WoiIaY`02oiIaY`CoUFnU0onDKJ@4oi=/
X`CoTffT1?nDKjD01?nELZWoWWFUoiieYOnNMJD4oiegY`CoVgNY1?nEM:/4ohi_Z`?oR6ZZ1?n6IjL3
ohQWY@CoRfRT0_n?JZ@2oi5_Z0GoUg>Y0onIMZT4oi]gZPGoVgR[0onJN:`00onRQkOoXHJgoj66]`03
oj66]`CoX8Jh1?nQQkP00onQR;Wo[j_Cojn[d`02ojn[d`Go/:_C00?o/JcCok[Tm?nji?@00_nji?@2
oiEe[0CoUWN_1?nFN[83oiEm]`03oiYi[OnINk3oVG^`00;oVG^`1OnIO[@3o`0000GoV8Bl0_nGR<82
oif6^PGoWHVo0_nLS/@00ol0003oW8k4oibCbP04oibCbP04oi^IdOnUX=3oYJ3@ojFPd0GoYJKG0_nU
[Mh3ojngg`Co[[cT00?o]LCUooooooooool04Oooool00ol0003oooooo`000008ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c00Iooooo`00
;?ooool2o`0000;ooooo00?o0000ooooooooool0=Oooool2oiMcZ0CoUW6W1?nEKjD3oiA]Y0CoTfbS
1?nCKJ@3oiA_Y@03oi]cY?nNMJGoWWFU00;oWWFU1?nMMjL5oi]gZ@?oUGB[0_n>Kj/2ohUYZ0?oPVBX
0omoHZL01?n6IjOoR6NUohQWYOn8IjD2oh]XY0;oRfZX1?nAKjP5oiMcZ@?oVGJY1?nKMjX5oi]hZ`03
oiYh[?nRQkOoXXNg00;oXXNg1?nQQ[L4oj26^0?oXHNh00?o[jcDojn[don_Zm<00on_Zm<4ok2[d`?o
]nOf00?o^^CdoiEe[?nEMJ`00_nEMJ`5oiIg[`?oUWZb00CoUGfgoiYi[OnJNJgoVWV]1OnINk001?nI
O[Co0000o`000?l00004oiR1^0?oV8Bl00?oWX>foif6^_nMQ[X00onMQ[X4oif9_`?oW8k400Co0000
oib>a?nLTl[oW9?:0_nUVl/4ojFPd0CoYJKG00?o[k;Kojnggon_]ml01?n_]ml00on^_>Co]LCUokG4
i@02okG4iAGooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B406Oooool002_ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0aooooo`;oV7FZ1?nGLjP3oiIaY`CoUFnU0onDKJ@5oi=/X`?oTffT
00CoU6nUoi]cY?nKLjCoVg>T1?nNMJD4oiegY`GoVgNY0_nEM:/00onDLJSoRFVXohUYZ002ohUYZ0?o
PVBX1?moHZL3ohAUY`CoRfZX1OnAKjP4oiMcZ@?oVGJY1OnKMjX3oi]hZ`03oj>7]onRQkOoXXNg00?o
XXNg1OnQQ[L4oj26^004oj67^?n_[=Co[jcDojn/e0Go[j_C00?o/:_CokOWm_ngioH00_ngioH2oiEc
Z@CoUGF/1OnFMjl2oiIj/P03oiYgZonJNJgoVWV]00?oVWV]0onINk02o`0000CoVGjd0onHPKP00onH
Q;coWX>foij3]P02oij3]PCoWHJj1?nMRKl4oib>a003o`000?nUVl_oYI_;00;oYI_;1OnUX=000onU
Y]Oo[k;Kojnbf`02ojnbf`Co[kOO00?o]/;SokG4iOnea>D00onea>DEooooo`03o`000?oooooooooo
00Gooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Ooo
ool002_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0]ooooo`03oiUg[?nHMJ[o
V7FZ00;oV7FZ1?nGLjP3oiIaY`CoUFnU1?nDKJ@4oi=/X`;oTffT00?oV72Soi]cY?nKLj@00onKLj@3
oiieY@GoWGNW0onKMjT01?nMMjOoU76XoiAaZ?nDLJP5ohUYZ0?oPVBX0omoHZL3ohAUY`GoRfZX1?nA
KjP4oiMcZ@?oVGJY1OnKMjX00onKN:_oXhNgoj>7]`02oj>7]`CoXXNg1OnQQ[L2oj26^0;o[jgE1On_
[=@2ojn[d`Co/n[g00?o]nOfoiEaYonELjT00_nELjT5oiEe[0?oUWN_00?oVWFXoiYgZonJMj/00_nJ
Mj/4oiYi[@?o000000?oVG^`oiUn]?nIO[@00onIO[@2oiR1^003oij0/_nNPkKoWX>f00?oWX>f1?nM
Q[X5oif9_`05oib>a?nVUlKoYYO6o`000?nVUlH01?nUVl/3ojFPd003ojn^eon_/]_o[k;K00Co[k;K
00?o[kOOokK2honf`^<00_nf`^<3okG4i@;o^<[X5Oooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q01Wooooo000[ooooo`?o
00001Oooool00ol0003oooooooooo`0[ooooo`;oVGN/1?nHMJX4oiMcZ0CoUW6W0onEKjD4oiA]Y0Co
TfbS00?oTffToiQ`XonHL:<01OnKLj@3oiieY@GoWGNW00CoVgNYoiegYonMMjOoWGNW1?nDLJP4ohUY
Z0?oPVBX1?moHZL3ohAUY`CoRfZX1?nAKjP4oiMcZ@CoVGJY0onKMjX00onTR;OoXhNgoj>7]`03oj>7
]`GoXXNg0onQQ[L00on`[mOo[jgEojn]e@03ojn]e@?o[jcD0_n^k?P4ok?Zm`?oUG6W0onELjT5oiEe
[004oiIg[onJMJSoVWFXoiYeZ0CoVWN[00CoVWV]o`000?l0003o00001OnINk03oiUn]003oiin/?nN
P;;oWX2b00;oWX2b1?nNPkH5oif6^P?oWHVo00?oYY?2ojJGa_nVUlH00_nVUlH00ol0003oYI_;ojFK
b`02ojFKb`03ojFPd?n_[]Oo[jkG00;o[jkG1?n_/]/00ong`^;o]/;SokK2h`03okK2h`03okG4iOnh
b^So^<[X00?o^<[X5Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oEEEEo`000?l@413oc<c<01Wooooo000[ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0:?ooool00onJNJgoVGN/oiUg[002oiUg[0?oV7FZ1?nGLjP4oiIaY`CoUFnU
0onDKJ@2oi=/X`;oUFjT0onHL:<5oi]cY0CoWWFU0onMMjL00onRNZKoWGNWoiegY`02oiegY`CoU76X
1?n9JJP3oh9TZ0CoOf:W0on4IJL4oh]ZZ0CoTFnX1OnGLjT3oiUfZ@03oi]gZ_nTR;OoY8Rg00;oY8Rg
1?nSQkL5oj:7]`03oj66]on`[mOo/:oG00;o/:oG1On_[MD00on_[=Co[^chojk/n002ojk/n003ok?Z
monDKjKoUG6W00?oUG6W1?nELjT3oiEe[003oiUcYonJMJSoVWFX00?oVWFX00CoVWN[o`000?l0003o
00000onJNJd5oiUk/004oiUn]?nNO[3oWWj`oiin/0CoWX2b1OnNPkH4oif6^P03oif9_onVTl;oYY?2
00;oYY?21?nVUlH01?l0003oYI_;ojFKbona[=<6ojn^e`03ojnbfong`^;o]l;R00;o]l;R0onf`^<2
okW@j`Co^<[X00?o]<c/ooooooooool04oooool00ol0003oooooooooo`03ooooo`05oa0@4?oooooo
ooooooooool@41002oooool00omEEEGoQhN7ooooo`0Kooooo`00:oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo02Gooooo0onJNJd4oiUg[0CoV7FZ0onGLjP4oiIaY`CoUFnU0_nDKJ@0
0onBKJGoUFjToiE^Y002oiE^Y0CoV72S1?nKLj@4oiieY@;oWGNW0_nRNZH4oiegY`CoU76X1?n9JJP3
oh9TZ0CoOf:W0on4IJL4oh]ZZ0CoTFnX1OnGLjT2oiUfZ@03oj>7]_nTR;OoY8Rg00?oY8Rg1OnSQkL3
oj:7]`03ok:cfOn`[mOo/:oG00?o/:oG1?n_[MD3ojS_n0;o[^ch0onDKjH5oiEaY`?oUG>Y00CoUGF/
oiUcYonILjOoVG>W0onJMJP3o`0000?oVWN[1?nJNJd3oiUk/003oimm[OnNO[3oWWj`00?oWWj`1?nN
P;84oij3]P;oWHJj0_nWTKh5ojJC`PGoYYO600Co0000ok6/dona[=?o/JcC1?n_[]L00oni`n;o]l;R
okO2hP04okO2hP03okK2honid>_o^M3[00;o^M3[00?o^<[XokC<k?ndc>`00_ndc>`Cooooo`?o0000
1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P06oooool0013ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Rooooo`03oi]k[onJNJgoVWV]00;o
VWV]1?nIMj`4oiQeZPCoUg>X0onFLJL4oiE_Y@03oiA]Y?nBKJGoTVfU00CoUFjT1?nHL:<4oi]cY0Co
WWFU00?oWGNWoj9jY_nRNZH00_nRNZH4oiegY`?oU76X1?n9JJP3oh9TZ0CoOf:W0on4IJL4oh]ZZ0Go
TFnX1?nGLjT00onIMZWoXhNfoj>7]P05ojB8]`GoXhNg00?oXXNgok:cfOnb/mT00_nb/mT5ok2_e`03
ojn]eOnXkoSoZ>oh00;oZ>oh0_nEKjD4oiA_YPGoUG6W0_nELjT00onILZGoVG>WoiUcY`02oiUcY`?o
00000_nJMJP4oiYgZ`CoVWV]00CoVG^`oimm[OnOOJgoWgf]1OnNO[04oij0/PCoWX>f1OnWTKh4ojJC
`PCoYYO600?o/Z[Ao`000?na[=<00ona[=<00on_[]Oo^L?RokW3hP02okW3hPCo]l;R00?o^]K^okW@
jonid>/00_nid>/2okGEl@Go]<c/5Oooool02Ol0003oooooooooooooooook^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@41Wooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01?ooool3o`0000[ooooo00?o0000oooooooo
ool07_ooool01?nLOK3oVg^_oi]k[onKNjl4oiYi[@CoVGN/1?nHMJX4oiMcZ0?oUW6W0_nEKjD2oi5]
YP?oTVfU1?nEKZ@4oiQ`X`GoVg>T0onNMJD5oj9jYPCoWGNW0onDLJP5ohUYZ0?oPVBX0omoHZL3ohAU
Y`GoRfZX1?nAKjP3oiMcZ@03oin4]_nSQkKoXhNf00;oXhNf1OnTR;L3oj>7]`03okFig?nb/mWo/[?I
00?o/[?I1?n`[mL3oio`m003ojS_n?nFKZ?oUFnU00;oUFnU1OnDKjH4oiEaY`04oiEcZOnILZGoVG:U
oiUcY`?o000000?oVG>WoiYeZ?nJMJP00_nJMJP4oiYgZ`?oVWV]00?oWgb/oimm[OnOOJd00onOOJd4
oiin/0CoWX2b0onNPkH2ojR?^`CoYi6n1OnVTl800onVUlKo/Z[Aok:Zd@02ok:Zd@04o`000?na[=?o
/JcCok_5hPKo^L?R00?o]l;Rok[Fk_nje^h00_nje^h00onid>_o]MGaokGEl@03okGEl@;o]<c/0_n]
bnlEooooo`03o`000?oooooooooo02oooooo0008ooooo`Ko00000_ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol00005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06ooo
ool3oiam/0CoVg^_1?nJNJd3oiUg[0CoV7FZ1?nGLjP2oiIaY`03oi5^YonAKJKoTFfV00;oTFfV1?nB
KJD3oiE^Y0CoV72S1OnKLj@2oiieY@03ojAkY_nRNZKoXWZV00?oXWZV1?nMMjL4oiAaZ0CoRFVX0on2
I:P4ogmRY`?oQ6FW1?n;JZP4oi5_Z004oiMcZOnOQ;KoWhBfoin4]PCoXhNf1OnTR;L00onSQkOo]KWL
okFig002okFig0Go/[?I00Co/:oGoio`m?nOl?CoWo3d1?nFKZ<4oiE_Y@CoU6nV0_nELJL2oiQaY0;o
VG:U0_l00004oiUcY`CoVWFX1OnJMj/00onJNJgoWgb/oiml[005oimm[@CoWWj`1OnNP;801?nNPkKo
Z8nkojR?^onXSk/4ojNA_PCoYY?200?o]:[?ok:ZdOnbZ]400onbZ]400ona[=?o0000ok_5hP02ok_5
hPCo^L?R00?o^mkbok[Fk_nje^h00_nje^h2ok?OmPCo]MGa00?oZmCfojg;kon]bnl00on]bnlEoooo
o`03o`000?oooooooooo02kooooo000@ooooo`05o`000?ooooooooooooooool000002oooool01?m4
A4CogMgMooooool00006ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06?ooool0
0onNOk;oW7f`oiam/003oiam/0?oVg^_1?nJNJd4oiUg[0?oV7FZ0_nGLjP2oi9_Z0?oTFjW1?nAKJH4
oi9]Y@CoUFjT0onHL:<5oi]cY004oiieYOnTNjKoY7^VojAkYPCoXWZV1?nMMjL4oiAaZ0CoRFVX0on2
I:P4ogmRY`?oQ6FW1?n;JZP2oi5_Z0;oV7je1OnOQ;H3oj>7]PCoY8Rg00?o^;oOokFig?ne^M`00one
^M`4ok:cf@;oTno]0onDKJ84oiI^X`CoUFnU0onDKjH01?nGKj?oV76ToiQaY?nHLJ@3o`0000;oVG:U
1?nILjL5oiYeZ0?oVWN[00?oWg^[oiml[?nOO:`00_nOO:`4oimm[@GoWWj`0onNP;800onXS[WoZ8nk
ojR?^`02ojR?^`GoYi6n00?oYY?2okBZcondZ/l00_ndZ/l3ok:Zd@03okg:i?nkaN;o000000Co^lGR
00?o^L?Rok_Nl_nkg_800_nkg_800onje^ko/mofok?OmP03ok?OmP03okGElOn[e?KoZmCf00;oZmCf
0_n]bnl3oj?4l1Gooooo00?o0000ooooooooool0;Oooool0013ooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Fooooo`;oWWnb1OnLOK03oi]k[`CoVWV]1?nIMj`2oiQeZP03oi=aZOnBKjSoTVnX00;o
TVnX1?nAKZL3oi5]YPCoTVfU1?nEKZ@4oiQ`X`?oVg>T00?oXGVWojAkY_nTNjH00_nTNjH4oj9jYPCo
WGNW0_nDLJP2oiIe[0CoR6f]0on0J:d3ogeW[`04ogmRYon4IJOoQ6FWohAUY`;oRfZX0_n?Mk@5oiQn
]@CoWhBf1?nSQkH2ojB8]`?o^;oO1One^M`00onb/mWoTno]oi?_k@02oi9ZX@?oU6fR1OnFKZ<3oiE_
Y@04oiA_Y_nGKj?oUfnSoiM_X`?o00000_nHLJ@3oiUbY@CoVG>W1OnJMJP01?nJMj_oWg^[oimkZonO
Nj/4oiml[0CoWgf]1OnNO[001?nNP;;oZ8jiojR>^OnXS[T5ojR?^`?oYi6n00?o]Zc?okBZcondZ/l0
1?ndZ/l01_nbZ]7o_L[Tokg:i?nmb^Co^lGRo`0000;o^lGR0onhjOD2ok_NlP?o[>Si0_ncgoH4ojGN
n`;oZmCf0_nQb_D5oj?4l1Cooooo00?o0000ooooooooool0;Oooool0013ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo0_l0000?ooooo`;o00005?ooool00onO
P[CoWWnboiio/P02oiio/PCoW7f`0onKNjl4oiYi[@;oVGN/0_nDLj/3oi=aZ@CoTVnX1?nAKZL3oi5]
YPCoTVfU1?nEKZ@4oiQ`X`;oVg>T0_nQNJL4ojAkYPGoXWZV0onMMjL4oiIe[0CoR6f]0on0J:d4ogeW
[`?oQFja1?n?Mk@5oiQn]@CoWhBf1?nSQkH00onTR;Oo^;oOokRog`03okRog`;o]KWL0_n3j]h00on?
Ij3oTVZQoi9ZX@02oi9ZX@?oU6fR1OnFKZ<2oiE_Y@03oiQ_X_nGKj?o000000;o00001OnHLJ@3oiUb
Y@GoVG>W0onJMJP00onONZ[oWg^[oimkZ`03oimkZ`?oWgb/1OnOOJd3oiin/003ojV>^?nXS[WoZ8ji
00?oZ8ji1?nXSk/00onWTKko]Zc?okJ/c`02okJ/c`Co]:[?00?o_m7Xokg:i?nmb^@00onmb^@00onk
aN;o0000okSYm@02okSYm@;oVnkf0_n/j?T4oiSTo@;oYMkk0_nKcoX5oj7:m@;oXlC`0_nM_>lEoooo
o`03o`000?oooooooooo02cooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^
k^koA4A4o`000006ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool01?nP
QKKoWh:doin2]?nOP[@4oiio/PCoW7f`1?nKNjl2oiYi[@03oiIe[?nDLj_oU7>[00;oU7>[1?nCLJT3
oi9_Z0CoTFjW1?nAKJH3oi9]Y@CoUFjT1?nHL:<01?nKLjCoXGVWoj5iYonQNJL4ojAkYPGoXWZV0_nM
MjL00onQOJcoUWF/oiIe[003oiIe[0?oR6f]1?n0J:d3ogeW[`?oQFja1On?Mk@4oiQn]@GoWhBf0_nS
QkH3okS3hP?o^;oO0_m_g/L4ohmWX0CoTVZQ1?nDKJ84oiI^X`04oiE_YOl0003o0000o`0000CoUfnS
1?nHLJ@3oiUbY@GoVG>W0_nJMJP2oimjZPGoWg^[0onOO:`5oimm[@03oiin/?nYS[SoZHjh00;oZHjh
1?nXS[T3ojR?^`03okR_d?nf[<oo]Zc?00?o]Zc?0ondZ/l3okoAj0?o_L[T0on_l_@00ol0003oVnkf
oi_^mP04oh3SmP;oV>Cm0_nCdOd5oi_?nP;oXL[e0_nK_O05oiflka?ooooo0_l0000^ooooo`004?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01Oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00_ooooo0onPQKH4oin2]0?oWWnb1OnLOK03oi]k[`03oiYi
[OnFMJcoUWF/00GoU7>[0onCLJT3oi9_Z0CoTFjW1?nAKJH4oi9]Y@?oUFjT0onHL:<00onLMZSoXGVW
oj5iY`02oj5iY`CoY7^V1OnRNZH01?nMMjOoXGf/oj5m[?nQOJ`4oiIe[0?oR6f]1?n0J:d4ogeW[`?o
QFja1?n?Mk@5oiQn]@CoWhBf00?oXhNfokS3h_nh`n800onh`n801?nh_mooKmk7ofoNaon<IJ04ohmW
X0GoTVZQ0onDKJ82oiI^X`?o00000_nHKj85oiM_X`CoV76T1?nILZD4oiUcY`03oiYeZ?nONZ[oWgZZ
00;oWgZZ1?nONj/4oiml[0?oWgf]00?oZXjhojV>^?nYS[P00onYS[P4ojR>^@03ojR?^onh[m3o^:o@
00;o^:o@1Onf[<l00ondZ/oo_m7XokoAj002okoAj004okg:i?n_l_Co[o;dojobm0;oNNGR00?o0000
oecDhOmLe>400_n0hoH2ohWAo`GoTm7m0_nKcoX3oiVkl0CoVkg`1?nM_>lEooooo`03o`000?oooooo
oooo02_ooooo000Yooooo`;o00005?ooool00ol0003oooooooooo`08ooooo`03oj:8^?nPQKKoX8Ff
00;oX8Ff1?nOP[@4oiio/PCoW7f`0_nKNjl00onGMjgoUWF/oiIe[002oiIe[0CoU7>[0onCLJT4oi9_
Z0?oTFjW1?nAKJH4oi9]Y@?oUFjT00CoV72SoiafZ?nLMZSoW7JX1?nQNJL5ojAkYP?oXWZV00?oYh:/
oj5m[?nQOJ`00_nQOJ`4oiIe[0CoR6f]0on0J:d4ogeW[`?oQFja1?n?Mk@5oiQn]@;oWhBf0onf`^@4
okS3hP03oe_?[on=IZ7oS6FP00;oS6FP1?n?Ij05oi9ZX@;oU6fR0ol00006oiQ_XPCoUfnS1?nHLJ@4
oiUbY@?oVG>W00?oWgZYoimjZ_nONZX00onONZX4oimkZ`CoWgb/00?oWgf]ojZ>^?nZS[P00_nZS[P4
ojV>^0CoZ8ji1Onh[m04okJ/c`;o`=c]0onodNP2oi?`i004od;2/_la^L;o<KW2oc6i`P;oG=CQ00Co
0000ogo?oomocoooOloo0on9dOl2oi?Ao@?oU[S_1OnI^o04oi^ml0;oWKc_0_nL^>`Eooooo`03o`00
0?oooooooooo02[ooooo000Yooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01_oo
ool3oj:8^0CoX8Ff0onOP[@4oiio/P;oW7f`0_nHNJl3oiMg[@CoUWF/1?nDLj/3oi=aZ@CoTVnX1?nA
KZL3oi5]YPCoTVfU0_nEKZ@00onGLjWoW7JXoiafZ003oiafZ0CoXGVW1?nTNjH2oj9jYP;oYh:/1?nQ
OJ`4oiIe[0CoR6f]0on0J:d4ogeW[`?oQFja1On?Mk@3oiQn]@03ojbihonf`^Co]/;T00Co]/;T00?o
^<?RoheVXOn=IZ400_n=IZ43ohaUX0GoSfNP1?nBJZ42o`000003oiQ^XOnHKj;oV6nR00KoV6nR1?nG
Kj<5oiQaY0?oVG:U00CoVG>WoimjZOnONZWoWgZY1OnONZX4oimkZ`CoWgb/1OnZS[P5ojV>^0;oZ8ji
0_nk]M@5okR_d003okJ/coo0g>go`=c]00?o`=c]00?o_m7Xoi?`i?mg`_h00omg`_h4ogO9o`04ogo?
ool0003oTj_Voi>[iPCoU;;/1OnF^>l2oiVkl0;oVk3V1?nK]>X5oibhk1Cooooo00?o0000oooooooo
ool0:_ooool002Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02ooooo`;oY8^k
1?nRR;P4oj25]PCoWh:d0_nNOk800onINk3oV7V_oiQi[`02oiQi[`CoUgN]0onFMJ`4oiAcZ`?oTg6Y
1?nBKjP4oi5^Y`?oTFfV0_nBKJD2oi9`ZP?oUg>Y1OnLMZP4oj5iY`CoY7^V00?oXWZVojN2[?nWPZ`0
0_nWPZ`3oj5m[0CoUWF/1?n8KJd4oh1X[@CoOFN_0on5K[44ohmg]003oiQn]On/^N?o[;WS00;o[;WS
1?nf`^@2ohmYX`CoSFJQ1?n<IJ04ohmWX004oi9ZXOl0003o0000o`0000?oV6jQ2?nHKj84oiM_X`Go
V76T0_nILZD6oimjZ@CoWgZZ1OnONj/2oiml[003oj^?^OnZS[SoZXjh00?oZXjh1OnYS[P01?nXS[Wo
^kGDok^ee?nk]M@4okR_d0?o_^_c0_o0g>d01?mKd;;oO;SiogbhnOml^?T2ogO2oP;oUIOC1?nCXMh2
oi>[iP03o`000?nCZnKoTj_V00CoU;;/0_nF^>l2oi^[hPGoVk3V1?nK]>X2oibhk0?oWkOY5?ooool0
0ol0003oooooooooo`0Yooooo`00:Oooool00ol0003oooooooooo`0Fooooo`03o`000?nUSkgoY8^k
00CoY8^k0onRR;P4oj25]PCoWh:d00?oWWnboiUk/?nINk001?nHNJl4oiMg[@?oUWF/1?nDLj/4oi=a
Z@?oTVnX1?nAKZL2oi5]YP03ohm`ZonBL:[oTW2Z00;oTW2Z1?nGLjT4oiafZ0CoXGVW0onTNjH00onZ
QZkoYh:/ojN2[003ojN2[0?oXGf/1OnFMJ`3ohQ][@CoP6R]1?mmIjl3ohE^/@;oSgNd0_nMZ=h6ojbi
h`03okK2i?nBKJGoTVfU00?oSfVS1?n=IZ43ohaUX0;oSfNP0ol00003oiI/X0?oV6jQ2?nHKj85oiM_
X`CoV76T00?oVG:UoimjZOnONZT01OnONZT4oimjZPGoWg^[00CoWgb/oj^?^On[SkWoZhni1OnZS[P3
ojV>^003oknofOnk]MCo^kGD00?o^kGD00?o^:o@okk[lonnjo<00_nnjo<00ol0003oQJ_]oiR6_P04
oiJ=b0GoUIOC1?nCXMh01?nCZnKo0000oi>[i_nCZnH2oiBbk0;oVjCL1OnKZn84oi^`iP;oVkCZ0_nO
/N@6oingjACooooo00?o0000ooooooooool0:?ooool002Wooooo0ol0000Fooooo`?oYHnm1?nTRk/4
oj:8^0?oX8Ff0_nOP[@2oiYm/PCoVG^`0onHNJl4oiMg[@?oUWF/1OnDLj/3oi=aZ@?oTVnX0_nAKZL2
ohi`[0?oSg2[1OnBL:X3oiMcZ@CoW7JX1?nQNJL2ojAkYP;oZXJ^1OnWPZ`4oj5m[0CoUWF/0_n8KJd0
0on<O;goQ7_1ohAk`@02ohAk`@CoPX791?n=Tm@4oifXgPCo[;WS00Co0000oi9]YOnBKJGoTVfU0on?
JJ<4oheVX@;oS6FP0ol00002oi5XW`CoUVbP1?nHKZ47oiQ_XPGoUfnS0onHLJ@00onONJWoWgZYoimj
Z@06oimjZ@GoWgZZ0onONj/00on/TK[oZhnioj^?^@02oj^?^@GoZXjh00?oZHjhoknofOno_mT00_no
_mT3ok^ee0?o[oKa00?o_^_coiZ0]OnJP;D01?nHQ[h4oiJ=b0CoUIOC1OnCXMh00onCZnKo0000oibN
e@05oi^Tg0GoVj_R0_nK/>H00onPZmooWk7Toinai003oinai0CoWkOY00?oYK[Xooooooooool04Ooo
ool2o`0002[ooooo000Yooooo`03o`000?oooooooooo01Cooooo00?oYi?1ojF?_OnUSkd00_nUSkd4
ojB;^`CoXXRh0_nPQKH00onKOkCoVWfboiYm/P02oiYm/PCoVG^`1?nHNJl3oiMg[@CoUWF/1?nDLj/2
oi=aZ@04oi1b[On?LJgoSg6]ohma[@CoSW2/1?n?L:/4oi9`ZP?oUg>Y1?nLMZP4oj5iY`03ojAkY_nZ
QZkoZXJ^00;oZXJ^1?nWPZ`4oj5m[0;oUWF/0_nKQK/4ohal_@CoQ7_11?n2PLT4ohfCe0CoWJSN00?o
[;WSo`000?nDL:H01?nBKJD3ohmYX`?oSFJQ0ol000000on<I9koTFROoi5XW`02oi5XW`CoUVbP1?nH
KZ48oiQ_XPCoUfnS00CoV76ToimiZOnONJWoWgVY2?nONZT5oimjZP03oimkZon/TK[o[96j00;o[96j
0on[SkT4ojZ>^003ol;<h_no_mWo_koI00Co_koI00Co^kGDojoflOn_m_7oW7b_1OnJP;D3oiR6_PCo
UXg81OnEUm<2oi>QgP;oWIO=0_nLW]D00ol0003oW9kEoi^Tg004oi^Tg0;oVj_R0_nQYMT4oj2[g`Go
Wk7T00?oWkOYojFjj?nU^^P00_nU^^PDooooo`03o`000?oooooooooo02Oooooo000>ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00005ooooo`03o`000?oooooooooo01Co
oooo0onWTl43ojF?_@GoY8^k0_nRR;P01?nLP[OoVgndoi]o]?nKOk@5oiYm/P?oVG^`1?nHNJl4oiMg
[@?oUWF/0_nDLj/2oi9d[P?oT7:]0on?LJd5ohi`[0?oSg2[1?nBL:X3oiMcZ@GoW7JX0_nQNJL00onW
Q[7oZXJ^ojZ6[P03ojZ6[PGoYh:/0_nQOJ`00onYT;coVhFkoi^5^`03oi^5^`?oS7bm1?n4Nl44oh:1
b@GoSI?D0_nMZ=h01?mCc;CoU72VoiA`Y_n>IIh4ohYRWP?oR62M0ol000001?n9HIgoS6BNohaTW_n<
I9h4oi5XW`CoUVbP1?nHKZ48oiQ_XP?oUfnS00?oWWVYoimiZOnONJT00onONJT7oimjZ@CoWgZZ00?o
[YBlojbA^_n/TKX00on/TKX4oj^?^@;oZXjh0oo2c>84oknof@03oh7Xd?nBSlgoW7b_00;oW7b_1OnJ
P;D3oiR6_PGoUXg80_nEUm<2oinAa@GoWIO=00CoW9kEo`000?nLW]GoW9kE0_nKY=`2oj:OdPGoXJGI
1?nPZml2oinai0;oY[GT1OnU^^PEooooo`03o`000?oooooooooo02Kooooo000>ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03
o`000?oooooooooo01;ooooo00?oZYS4ojNC`OnWTl400_nWTl44ojF?_@CoY8^k00?oXXRhoib2]onL
P[L01?nKOk@4oiYm/P?oVG^`1?nHNJl4oiMg[@;oUWF/00?oTgJ_oi9d[_nBM:h00_nBM:h4oi1b[@?o
Sg6]1?n>L:`3ohm`Z`CoTW2Z0onGLjT5oiafZ003oj5iYonWQ[7oYhJa00GoZXJ^1OnWPZ`01?nQOJco
ZI2lojV@_?nYT;`4oi^5^`CoS7bm0on4Nl44oh:1b@CoSI?D0_mQf=T2oi9XWP?oSVFN1?n:HYh3o`00
00CoRF6M0on<I9h5oi5XW`?oUVbP1?nHKZ48oiQ_XP04oiM_XonNNJWoWWVYoiiiZ@GoWgVY2?nONZT2
oimjZP?o[YBl1?n/TKX4oj^?^@03ojZ>^?o2c>;o`/cR00?o`/cR00Co_koIoh7Xd?n1j=3oWWVZ1OnL
O:l4oiZ0]@CoV8Jn0_nFSLP2oj:=_PGoWi751?nMUld2oibNe@03o`000?nTVlgoXYoB00CoXYoB1?nQ
YMT2oj2[g`?oYk3O1?nV]N@2ojFjj0?oZkkX5?ooool00ol0003oooooooooo`0Vooooo`001_ooool6
o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0_l0
000Aooooo`CoZYS40onWTl44ojF?_@;oY8^k0_nMQKT4oib2]`?oVgnd1?nJOK84oiUk/0?oV7V_0_nG
Mjd2oiAg/0?oTgJ_1?nBM:h4oi1b[@?oSg6]1?n>L:`3ohm`Z`CoTW2Z1?nGLjT3oiafZ003oj:4]?nW
Q[7oYhJa00;oYhJa1?nZQZh4ojN2[003ok:K`?nYT;coZI2l00;oZI2l1?nKQK/4ohal_@CoQ7_11?n2
PLT00on=TmCoHMSIof7Hf@04oi9XWP?oSVFN0_n:HYh2o`0000?oR62M1?n9HId4ohaTWPCoTFRO1?nF
K:03oiQ^X@OoV6nR00?oWWVZoiiiZOnNNJT00onNNJT4oimiZ@SoWgZY00?oWgZZojjD_?n^U;`00_n^
U;`5ojbA^P;oZhni0_o3h>d4ol;<hP03o`000?nIOkGoUXFo00;oWWVZ1OnLO:l5oiZ0]@;oV8Jn00?o
Y8Zioj:=__nRSKh00onRSKh4oinAa@?oWIO=00KoYYS7ojBKcOnTVlgoY9_=o`000?nTVld5oj:OdP;o
XJGI00?oZ:gKojN`gonW/=l01?nW/=l2ojJei0;o[;cU1On[_^PDooooo`03o`000?oooooooooo02Go
oooo000>ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05ooooo`03
o`000?oooooooooo00kooooo00?o[9g8ojZHa?nZV<@00onZV<@4ojNC`@;oYHnm00?oWhVloif5^OnM
QKT00onMQKT3oib2]`?oVgnd1OnJOK83oiUk/0;oV7V_00?oUGVboiAg/?nDMk000_nDMk04oi=f[`?o
TWB^1?n@LZd3ohma[@CoSW2/0on?L:/5oi9`ZP?oUg>Y00CoW7JXoj:4]?nRQ;CoXXBd1?nWQ[45ojZ6
[P;oYh:/0onbVl03ojV@_0GoVhFk1?n<O;d2ohAk`@?oQ/ko0_mbf?T00onEKjGoUVZNoiIZWP04oi9X
WP;oSVFN0ol00003ohYRWP?oR62M1?n9HId3ohaTWPCoTFRO1?nFK:04oiQ^X@GoV6nR0_nNNJX5oiii
Z@CoWgVY1onONZT00on_VL3o[YBlojjD_003ojjD_0Go[96j00?oZhniol?PkOo3h>d00_o3h>d01Oo2
c>;oVGneoiUo]OnIOkGoX7RV00CoWWVZ1?nLO:l5oiZ0]@04oiR6__nTR[WoY8ZiojB:^@CoXXfn1OnO
TLD01?nMUlgoYYS7ojJHaonVV<L3ojBKc@03o`000?nRWm;oXYoB00;oXYoB00?oZj_FojR]fonX[M/0
0_nX[M/4ojN`g`03ojfkhon/_>Go[;cU00?o[;cU0_n[_^P2ojk3jAGooooo00?o0000ooooooooool0
9?ooool000kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool03Oooool3ojbMb0CoZYS41?nWTl401?nUSkgoWhVloin9_?nORK`4oif5^@?o
W8:g1?nKOk@4oiYm/P;oVG^`00CoUW^coiEi/_nENK;oUGVb1OnDMk03oi=f[`CoTWB^0on@LZd3ohma
[@CoSW2/1?n?L:/4oi9`ZP;oUg>Y00?oVX6goj:4]?nRQ;@00onRQ;@3ojN6/@GoZXJ^00?oYh:/ok:K
`?nbVl000_nbVl04ojV@_0CoVhFk0_n<O;d3oi?6n@?oQ/ko0_nFKZ<01?nIK9koUVZNoiIZW_nFJYh3
oi9XWP?o00000_n>IIh4ohYRWP?oR62M1?n9HId3ohaTWPCoTFRO1?nFK:04oiQ^X@?oV6nR00?oWg^[
oiiiZ_nNNJX00_nNNJX4oiiiZ@CoWgVY1OnONZT4ojnI`0Go[YBl0on/TKX2okWdlP;o`n3]0onLNjd0
1?nIOkGoX7RVoj1hY_nPN:H4oiiiZPGoW7b_0onJP;D00onXRKCoY8ZiojB:^@02ojB:^@CoXXfn1?nO
TLD00onYU/?oYYS7ojJHa`02ojJHa`?oY9_=00?o0000ojBKcOnRWm801?n[ZmH4ojR]f`03ojN`gon]
^n?o[K_S00;o[K_S0on/_>D00on_a>Wo[/?Yojk3j@03ojk3jA?ooooo0_l00008ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c009ooooo`00
3_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00oooool2o`0000co
oooo00?o[j?<ojbMb?n/WLP00_n/WLP5ojZHa0;oYi?100?oXHg0oin9_?nORK`00_nORK`4oif5^@Co
W8:g0onKOk@2oiYm/P;oUWfe0onFNk<4oiEi/PCoU7N`0onCMZl4oi9d[P?oT7:]1?n?LJd4ohi`[0?o
Sg2[0_nBL:X2oi=m^@?oVX6g1OnRQ;@4ojN6/@?oZXJ^00?o^JO8ok:K`?nbVl000onbVl04ojV@_0;o
VhFk0onUcO@5oi?6n@03ohK>oonFKZ?oVFbN00;oVFbN0onFJYh3o`0000;oTVRN0on>IIh4ohYRWP?o
R62M1?n9HId3ohaTWPCoTFRO1?nFK:04oiQ^X@04oiQ_X_nONj_oWg^[oimkZ`CoWWVZ1?nNNJT5oimi
Z@;oWgZY00?o/Ik4ojnI`?n_VL000on_VL05ojjD_004ojbA^_nim?;o^OCbokWdlP;oWWRX1?nLNjd5
oj1hYP?oWWVZ1OnLO:l00onJP;GoZ8VdojR9]002ojR9]0?oY8Zi1OnRSKh01?nOTLGoZIK3ojVF`onY
U/<5ojJHa`;oY9_=00?o[ZWCo`000?n[ZmH01?n[ZmH2ojR]f`?o[k_R1?n]^n<00on/_>Go[lCYojo4
j@02ojo4j@?o[/?Y0_n^aN/Dooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Wooooo000>ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo0_l0000:oooo
o`03ok:ZdOn_Xlco[j?<00;o[j?<1?n/WLP2ojZHa0;oXY;41?nQSL03oin9_0GoWHFi0onLP[L2oi]o
]003oiMo]onFOKGoUWfe00;oUWfe1?nFNk<3oiEi/PCoU7N`0onCMZl4oi9d[PCoT7:]0on?LJd4ohi`
[0;oSg2[00?oSgbioi=m^OnCOKT00_nCOKT4oiZ1]`CoXXBd1?nWQ[400onZQZko^JO8okVWb002okVW
b0Go/Y_00_nYT;`3ok?Mm@CoYLgd0_nCa_T3oiM]X@CoVFbN0ol000000onFJYkoTVRNoi9XWP02oi9X
WP?oSVFN1?n:HYh3ohQPW@CoRF6M0on<I9h4oi5XW`CoUVbP0onHKZ400onPO:coWg^[oimkZ`03oimk
Z`?oWWVZ1?nNNJT5oimiZ@04oimjZOnaW/Co/Ik4ok6Na0Co[iW01?n^U;`3ohW/dP03okWdl_nNN:So
WWRX00;oWWRX0_nLNjd00onRNJGoX7RVoj1hYP03oj1hYP?oWWVZ1?nLO:l00on[R[;oZ8VdojR9]003
ojR9]0CoY8Zi0onRSKh00on/U/3oZIK3ojVF``03ojVF``?oYYS700?o/J_AojjYdon^ZM<00_n^ZM<0
1Ol0003oZj_Foj^[e_n[ZmKo/kgR00Ko[k_R0_n]^n<2ok36jPGo[lCY00?o[/?Yojk5jon^aN/00_n^
aN/Dooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`00
0?ooooooooooooooool000002Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool00ol0003oooooooooo`07ooooo`Co/Z[A0on_Xl`3ojbM
b003ojFHb?nRT/CoXY;400?oXY;40onQSL04oin9_0CoWHFi0_nLP[L01?nGPK[oUgngoiMo]onGOkL4
oiIm]@CoUW^c0onENK84oiAg/0CoTgJ_0onBM:h4oi1b[@;oSg6]00?oSg^iohik^On>NkT00_n>NkT3
ohml^@CoTgfi1?nJPKL4oj:4]0CoYhJa1OniYlP5ok:K`003ojV@_?ncgOGo/mge00?o/mge0_nUcO@3
oiQ]X0;oUffQ00?oVVfNoiU/W_l000000_l00004oiIZWPCoTVRN0on>IIh4ohYRWP?oR62M1?n9HId3
ohaTWPGoTFRO0onFK:001?nHKZ7oX7b/oj1l[?nPO:`5oimkZ`?oWWVZ1OnNNJT3oimiZ@03ok:Tb_na
W/Co/Ik400;o/Ik41On_VL001?n^U;coRNcBohW/d_n9k=82oj1gY@GoWWRX00CoW7^]oj9iYOnRNJGo
XWVU1?nPN:H4oiiiZP;oW7b_0_n[R[85ojR9]0CoY8Zi00?oXXfnojbF`?n/U/000_n/U/04ojVF``03
ojJHaonaZm7o/J_A00;o/J_A1?n^ZM<00ol0003o/kgRok>mhP02ok>mhPCo[k_R00?o/LW/ok36j_n`
a^X00on`a^X2ojo4j@;o[lW^1?n^aN/00on[aNgoooooooooo`0Booooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S802Oooool0
02Oooooo00?o0000ooooooooool01Oooool00one/]Ko/Z[Aok:Zd@03ok:Zd@Co[j?<00Co[9g8ojFH
b?nUV<SoYIS81?nRT/@3oj6=`0CoWhVl0_nMQKT2oiR4_0?oUh6j1?nGOkL4oiIm]@?oUW^c0onENK85
oiAg/0?oTgJ_0onBM:h2oi1b[@;oT7bi0on?NkT5ohik^@?oSgbi1?nCOKT3oiZ1]`GoXXBd0_nWQ[42
okNbe0Co^JO81?nbVl03ojo^m`;o/mge0onHKZ04oiQ]X004oiM]XOl0003o0000o`0000?oVFbN1?nF
JYh4oi9XWP?oSVFN1?n:HYh3ohQPW@CoRF6M0on<I9h5oi5XW`;oUVbP00?oX7b[oj1l[?nPO:`00onP
O:`4oimkZ`?oWWVZ1OnNNJT00onONJWo/ZC:ok:TbP02ok:TbP?o/Ik41?n_VL001?l0003oXGJSoj5f
XonQMZ<3oj1gY@CoWWRX00?oYG^Uoj9iYOnRNJD00_nRNJD4oj1hYPCoWWVZ00?oW7b_oj^:/_n[R[80
0_n[R[85ojR9]0;oY8Zi00?o/IVoojbF`?n/U/000on/U/03ojVF``03okJ_d_naZm7o/J_A00?o/J_A
0on^ZM<00onf`nCo0000ok>mhP04ok>mhP03ojnkh_nabNco/LW/00;o/LW/0on`a^X00on^co7o[lW^
ojo9kP03ojo9kP03ojk5jon[aNgoZlG]00;oZlG]5?ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Wooooo000Wooooo`;o
00001Oooool3okFbePGo/Z[A0_n_Xl`00onWW/goYIS8ojFHb003ojFHb0?oXY;41?nQSL02oin9_003
oiV8`?nHQ;coV8Bl00;oV8Bl1?nGPKX3oiMo]`CoUWfe0onFNk<4oiEi/PCoU7N`0_nCMZl01?nCOk[o
TWfioi9m^OnBOKT5oi1l^@?oSg^i1?n>NkT3ohml^@CoTgfi1?nJPKL4oj:4]004ojN6/Ong/]Co]k;D
okNbe0Go^JO800?o/Y_0ojo^mon_k_L00_n_k_L2oiI]X@CoV6jP0onHKJ02o`0000?oVVfN0onIK9h4
oiIZWPCoTVRN0on>IIh4ohYRWP?oR62M1?n9HId4ohaTWPCoTFRO00?oUVbPoj1lZonPO:/01OnPO:`4
oimkZ`CoWWVZ0onNNJT00onbZ]7o/ZC:ok:TbP03ok:TbPCo/Ik400?o[iW0oj5eXOnQMZ<01?nQMZ<4
oj1gY@;oWWRX0_nUNjD4oj9iY@CoX7RV1?nNNJX5oj^:/PGoZ8Vd00CoY8Ziok6I_onaVKoo/IVo1On/
U/001?nYU/?o]ZoBokJ_d_nf[m85ok6[d@05ojjYdonf`nCo]/?TokK3i?l000000onc_N800oncd>oo
/LW/ok79k003ok79k003ok36j_n^co7o[/oa00;o[/oa0_n_bNh3oj_9k`CoZlG]5Oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o
410@00Wooooo000Wooooo`03o`000?oooooooooo00;ooooo00?o^;[KokFbe_ne/]H00one/]H3ok:Z
d@03ojVUdonWW/goYik=00;oYik=1?nUV<P4oj:Ba0;oXHg000?oVXc3oiV8`?nIR<000_nIR<04oiR4
_0?oUh6j0onGOkL4oiIm]@CoUW^c0onENK82oiAg/0;oU82k0onCOkX4oi9m^@CoT7bi0on?NkT4ohik
^@?oSgbi1?nCOKT4oiZ1]`;oXXBd0_n]^N84okNbe0Co^JO80on<kN<00on_k_OoU6bRoiI]X@03oiI]
X@?oV6jP0ol000000onIKIkoVVfNoiY]WP02oiY]WPCoVFbN0onFJYh4oi9XWPCoSVFN1?n:HYh3ohQP
W@CoRF6M0on<I9h3oi5XW`03oi]gZOnPO:_oX7b[00;oX7b[1?nPO:`4oimkZ`CoWWVZ00?oWWVYok:Z
dOnbZ]400_nbZ]44ok:TbP?o/Ik41?nQMJ44oj5fX`CoX7NU00?oWWRXojEkYOnUNjD00_nUNjD3oj9i
Y@GoX7RV0_nNNJX2ojn=/PCoZhZb1?nXRK@00ongXL;o/IVook6I_`02ok6I_`Co[9K000?o^kOFokJ_
d_nf[m800_nf[m84ok6[d@03ok[>jOnf`nCo]/?T00?o]/?T00?o0000ok?@koncd>l00_ncd>l2ok79
k0Co[=Ge0_n^co42ojW=l`GoZlW_0_n[aNd2ojO2kA;ooooo0ol00004ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Wooooo000Wooooo`04o`000?oooooo
ooooooooo`?o^;[K1One/]H01?nbZ]7oZJGCojVUdonYYM<3ojNNc@GoYIS80_nRT/@00onKT<OoVXc3
oiZ<``02oiZ<``?oVHS01?nHQ;`3oiN1^PCoUgng0onFOKD4oiIk/`;oUGVb00?oU86loiB0^onDP;/0
0_nDP;/4oi=o^P?oTWfi1?n@O;T3ohmk^@GoSW^i0on?O;T3oi=m^@;oVX6g0_nO^n`5ojfihPCo]k;D
00?o^JO8ohc]honBK:<00_nBK:<3oiA/XPCoUVfQ0ol00004oiU]WPCoVVfN1?nIK9h3oiIZWPGoTVRN
0on>IIh4ohYRWP?oR62M1?n9HId3ohaTWP04oi5XWonKMjWoVgNYoi]gZ@CoX7b[1?nPO:`5oimkZ`;o
WWVZ00?o/[CJok:ZdOnbZ]400onbZ]45ok:TbP03ok6Na?nQMJ7oXGFQ00?oXGFQ1?nQMZ<4oj1gY@Go
YG^U0onRNJD5oj1hYP04oiiiZ_n_SK;o[hfbojn=/PGoZhZb0_nXRK@2okNQ`PCo/IVo0on/U/02ok^g
ePGo]ZoB00?o/J_Aok[>jOnjc^T00_njc^T2okK3i0;o/MWe00Co0000ok7ImOncd>oo/m3_0_nXgOX4
ojcEm@03ojGAmonYcO?oZLgc00?oZLgc0_n[bNl2ojK5k`GoYl;]5?ooool02Ol0003ooooooooooooo
ooook^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT02Oooool002Ko
oooo0ol000000onk`n7o^;[KokRjf`03okRjf`;o]K;F0_n/[]T4ojVUd`CoYik=0_nUV<P2oibFc0Co
Vi370onJS<<3oiV8`0CoV8Bl1?nGPKX3oiMo]`;oUWfe00?oU8BooiB2_OnDP[d00_nDP[d4oiB1_0?o
U82k1?nCOkX3oi9m^@GoT7bi0on?NkT4ohik^@?oSgbi0_nCOKT2oi:fk`CoWk_/1On]^N82okNbe0?o
TVfU0onBK:<3oiA/XP05oiI]XOl0003o0000o`000?nHKZ000_nGKIl4oiU]WPCoVVfN1?nIK9h4oiIZ
WPCoTVRN0on>IIh4ohYRWP?oR62M1?n9HId2ohaTWP03oi=_Y_nKMjWoVgNY00?oVgNY0onPO:/4oj1l
[0GoWg^[00CoWWVZok:df_nb]=[o/[CJ1OnbZ]42ok:TbP04oiE[W_nSMZ;oXgJRoj=fXPCoXGFQ1OnQ
MZ<3oj1gY@GoYG^U1?nRNJD3oj1hYP03ok>B]?n_SK;o[hfb00;o[hfb1On[R[800onXRKCo]j72okNQ
`P02okNQ`PCo/IVo00?o[9K0ok^ge_nk]mH00_nk]mH3okJ_dP;o^mob0onjc^T2ojWUnPCo/MWe00?o
0000ojSMn_nXgOX00onXgOX00on/eOGoYM7gojGAm`02ojGAm`;oZLgc0_nTao85ojK5k`;oYl;]0_nT
_ndEooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?nk`n7o^l?Q00;o^l?Q0onh^]/2
ojngg`Co[:kI1?nYYM<2ojNNc@03oijLd_nLU/coW9K<00?oW9K<0onKT<L3oiZ<``CoVHS01?nHQ;`3
oiN1^P;oUgng00?oThG1oiB4_onDQ;l00_nDQ;l4oiB2_@?oU86l1?nDP;/3oi=o^PCoTWfi1?n@O;T3
ohmk^@;oSW^i0_n>Z^P4ohj`k@CoT[K_1?nO^n`2ojfihP?oU6nV1?nBKJD3oi9/X`05oiA/X_l0003o
0000o`000?nFKJ400_nCJZ43oiM]W`CoVFfN1?nJKIh4oiU/WPCoUVZN1?nBJ9h2ohiUWP03ohaSWOn8
HIkoR66N00;oR66N0on8HZ04ohaWX`?oTfnV1OnKMjT3oj1lZ`GoX7b/0onONj/00onc`nKo/[CJok:d
fP02ok:dfPCo/Z[A0onGJY`4oj=fXPCoXGFQ1OnQMZ<2oj1gY@;oZWnV1?nUNjD4oj9iY@;oX7RV0onc
T[@4ojn=/P?oZhZb00?o`;3:okNQ`_ngXL800ongXL83ok6I_`03ol77gonk]mKo^kOF00?o^kOF00?o
]ZoBok_Ol_nkgo800onkgo800onjc^WoZNGjojWUnP02ojWUnP05ok7ImOnLhogoW>?moicSoOl00000
0_nXgOX3oioDnP;oYM7g0onQao<4ojC7lP;oY/G_0onS_nd4ojBokACooooo00?o0000ooooooooool0
7_ooool001_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooo^l?Q00?o^l?Q
00?o^;[Kojnggon_]ml00_n_]ml4ojb^f@;oZJGC00?oWj?HoijLd_nNW=800_nNW=84oibFc0?oVi37
1?nJS<<3oiV8`0CoV8Bl0_nGPKX00onCQlCoThG1oi>5`@02oi>5`@?oU8Bo1?nDP[d3oiB1_0CoU82k
1?nCOkX3oi9m^@;oT7bi0_nCXn03oi6Vi0GoSZ[X1?n>/>d4oi:fk`;oWk_/0onFLJL3oiA_YPCoTVfU
00KoTVbSo`000?l0003o0000oiA/X_n?J:84oi=ZX@CoUffO0onIKIh4oiY]WPCoVFbN1?nFJYh2oi9X
WP;oTFNM0on<Hid4ohQQWP?oR6:P1?n<Ij<4oi=_YPCoVgNY0onPO:/5oj1l[003oimkZonc`nKo/l?V
00;o/l?V1?nb]=X00onbZ]7oUVRJoiMZW002oiMZW003ojIjXonSMZ;oXgJR00;oXgJR1?nQMJ45oj5f
X`04oj1gYOnZOjKoZWnVojYoYPCoYG^U1?nRNJD00onPN:Ko/i:dok>B]002ok>B]0Co[hfb00?oZhZb
ol2`b_o0/<X00_o0/<X4okNQ`P03ok6I_oo1amoo`LOO00;o`LOO0onk]mH3ojcbm0;o^mob0on?jOL2
ojWUnPCoQ>;i0_nLhod00onFeOgo0000oiKEo@02oioDnP;oWLKe1OnQao<2ojC7lP;oX[o^1OnS_nd2
ojBok@;oY;g[5?ooool00ol0003oooooooooo`0Mooooo`006oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool00_nk`n43ok72i`Co[kOO0_n/[]T00onQZmkoWj?HoinSf002
oinSf0?oWYcB1?nLU/`4oi^@a`?oVXc30_nIR<000onCS<WoTh[6oi>:aP02oi>:aPCoThO40onCQL43
oiB4_`CoU8:m1?nDPK`3oiB0^`CoTgnj0_nBOKT00onEXMgoTj?Poi>Sh003oi>Sh0?oTJKT1On>Z^P2
ohj`k@?oVGN/1?nGM:T3oiIaY`?oU6nV0_nBKJD3o`0000;oSVRR0on?J:84oi=ZX@CoUffO1?nIKIh3
oiY]WPCoVFbN0onFJYh00onGK9koTFNMoi5WW@02oi5WW@?oS6>M1?n8HIh3ohQRX0GoS6NS0onCKjH4
oi]gZ@CoX7b[0onPO:`2ok_Hk`Go/l?V0_nb]=X3oiIXVP;oUfZL0_nVNZ<4oj=fXPGoXGFQ0onQMZ<0
0on^QZ[oZWnVojYoYP02ojYoYPGoYG^U0onRNJD5ok>B]0Co[hfb1Oo0/<X3okNQ`P;o`n;^1Oo1aml0
0onk]mKo[?;dojcbm004oe7>dP;oSnWg00?oH=G/oh?;oon3bol01On:d_l2oiKEo@03o`000?nJ`_Co
WLKe00CoWLKe0_nQao<2oj6mk@GoX[o^0_nS_nd2oj>kj`GoY;g[4oooool2o`0001kooooo000Koooo
o`05oa0@4?ooooooooooooooool@41001_ooool2o`0000;ooooo1Ona`^L2ojngg`03oj:diOnQZmko
XJ_N00;oXJ_N0onOXmP3oijLdPGoW9K<0_nKT<L01?nCTm7oTi3=oi>@cOnCT<d4oi><b@CoTh[60onC
Ql@3oi>5`@CoU8Bo1?nDP[d3oiB1_0;oU82k00?oUIoKoiJPg?nFX=`00_nFX=`4oiFQg@CoTj?P1?nA
Y^@2ohjZj0CoVg^_0onIMj`4oiMdZ@?oUW6W0_nDKjH3o`0000;oSVRS0on>J:83ohmXXPCoTfZQ1?nG
KIl4oiU]WPCoVVfN0onIK9h01?nFJYkoUfbNoiM/W_nGK9h4oi5WW@CoS6>M0on8HIh4ohQRX0CoS6NS
0onCKjH4oi]gZ@CoX7b[00?oX7b/ok_Hkonkf>l00onkf>l2ok?3iPCoU6BG0onFJ9X00onGJYcoYWZS
ojIjX`02ojIjX`CoXgJR1?nQMJ42oj5fX`;o[XJZ1?nZOjH5ojEkY@;oXWVU0_njW;X5ok>B]0;o[hfb
0_o>d=/5ol2`bP03okNQ`_o3h^ko`n;^00;o`n;^0_o1aml2of3D_P03ocjam?l]/mko;K?N00;oRK?a
1On1`?/3oh?;o`;oR];o0onG^_02oi[2m004o`000?nJ`_CoWLKeoig6m@?oWk[[1?nQ_Nd2oj:okP?o
XkWY1?nS^n/2ojBmj`;oYKg[4_ooool00ol0003oooooo`00000Nooooo`006oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool00_ooool2ok72i`;oXko]1?nR]>D3oj6[gPCo
Wj?H0onNW=82oibFc0;oTiSE1?nCTm43oi>@c@?oThc91?nCR/H3oi>7a0CoThG10onDQ;l4oiB2_@;o
U86l00?oU9oKoiFOfonEWm/00_nEWm/4oiJPg0CoUJ7M1?nCXn02oi6Vi004oe;>gonMOk;oWGnboieo
/P?oVg^_0onIMj`2oiMdZ@;oT6bU0on@Jj@2o`000003ohmYXon>J:?oSVRS00;oSVRS0on>J:84ohmX
XP?oTfZQ1?nGKIl4oiU]WPCoVVfN0_nIK9h00onKL:3oUfbNoiM/WP02oiM/WPCoTFNM1?n<Hid3ohQQ
WPCoR6:P1?n<Ij<3oi=_YPGoVgNY0_nPO:/3ol;Zl@;o^mS_0on@GiD5oiATU`?oUVRJ1OnVNZ<4oj=f
XPCoXGFQ00?oXGJSojj6Z_n^QZX00_n^QZX3ojYoYPGoYG^U00CoXWVUokZL^_njW;[o^Ybj1OncT[@0
1?n_SK;oc]3Kolk@foo>d=/4ol2`bP?oVo?W0_o3h^h2oibGcPCoTZ;O1On9/o42oh70n`;oVJCM1?nH
/>P5oiNjl0;oV/;d00?o0000oineionO^^/01?nO^^/2oj6mk@03oj>fi_nS^NWoXkWY00CoXkWY0_nS
^n/00onU^nWoYKg[ojFmj`03ojFmjaCooooo00?o0000ooooooooool06oooool001_ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo1?nS_nd4oj:di@?oXJ_N0_nO
XmP00onCXn3oTigJoi>MfP02oi>MfPCoTiSE0onCTm43oi>@c@?oThc91?nCR/H4oi>7a0?oThG10_nD
Q;l00onAW]coTioLoi>Og002oi>Og0CoU9oK1?nEWm/4oiJPg0;oUJ7M1?m`fOL2ofKGk`;oWhBe0onM
Ok83oi]k[`;oVGN/00?oT6fWoi1/YOn@K:D00_n@K:D3o`0000?oSfVS1?n>J:<4ohiXXP?oSfRR0onC
JZ44oiM]W`CoVFfN1?nJKIh00onIK9koVg2Poi]`X005oiM/WP?oTFNM1?n<Hid3ohQQWPCoR6:P1?n<
Ij<3oi=_YPGoVgNY00CoX7b[ol;ZlOo2j_7o`^[a0on<Fi<3oi1OU@GoU6BG0_nFJ9X00on/P:GoYWZS
ojIjX`03ojIjX`CoXgJR1?nQMJ45ojj6ZPCoZWnV0onUNjD00oo2[/Ko^YbjokZL^P02okZL^PCo/i:d
0_nnoN04olk@f`06ol2`b_nKlnOoVo?Woi_cion5TMSoY8no1OnLUlh4oi:Rg`;oRK?a0_nNVm05oiVT
g@CoV;3X0_nG^_02oj2^hP;oWkGW00?o0000oineionO]NL00_nO^^/2oj>bh`CoXkKV1?nS^NT00onU
^NOoYK_YojFkj@02ojFkj@?oYKg[00?oYkkZooooooooool04oooool00ol0003oooooooooo`0Joooo
o`006oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool01Oooool4oj>o
k@;oX[CU00CoT[7/oi>Zi_nCZ^KoTj[V1?nCXn04oi>MfP?oTiSE0onCTm43oi>@c@CoThc91?nCR/H2
oi>7a004ohjNg_n@W]goT9kMoi2Ng@CoTIkL1?nCWm`3oiBOf`GoUIoK0_nFX=`4ogKHn`;oL=Wg00?o
XhVioin4]OnOQ;D00_nOQ;D2oieo/P04oi9bZonAL:WoTG2Yoi5`Z@?oT6fW00CoT6bUo`000?l0003o
00001?n@Jj@3ohmYX`?oSVRS1?n>J:83ohmXXPCoTfZQ0onGKIl4oiU]WP?oVVfN00CoWW>Roi]`X?nK
L:3oVg2P1OnGK9h3oi5WW@CoS6>M1?n8HIh3ohQRX0CoS6NS1?nCKjH3oi]gZ@?o`Noa00?o`^[aohaK
Ton<Fi<00_n<Fi<3oi1OU@GoU6BG00CoUVRJojb0YOn/P:Go[82U1?nVNZ<4oj=fXPCoXGFQ1On^QZX4
ojYoYP;oYG^U0oo2[/H4okZL^P;o/i:d1?nnoN02olk@f`?oThC000?oZhfgojB?_onTSkl00_nTSkl5
oibGcP;oTZ;O00?oXiC5oijKd?nNVm000onNVm04oiVTg@;oV;3X0onSZ=X4oj2^hP;oWkGW00?o0000
ojB^gonS/^<01?nS/^<4oj>fiP03oj>ijOnU^NOoYKWW00;oYKWW1?nU^nT01?nU_N_oYkkZojNnj_nW
_^XDooooo`03o`000?oooooooooo01[ooooo000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2o`0000Oooooo0_nS_nd2oi6ilP?oT[7/0onCZ^H4oi>Sh0CoTigJ0onCV=D3oi>Cd@?oTi3=0_nC
S<T2oh^Oh@?oSIkO1?n>W]h3oi2Ng@CoTIkL1?nCWm`3oiBOf`;oUIoK1?mhe_d2ogKHn`;oYXnm0onS
RKT2oin4]@;oU7J^0onBLZ/3oi5`Z@04oi1]Yol0003o0000o`0000?oT6bU1?n@Jj@3ohmYX`?oSVRS
1?n>J:83ohmXXPCoTfZQ0onGKIl4oiU]WP;oVVfN0_nNLj84oi]`X0CoUfbN0onAIid4ohaSW@CoR66N
0on8HZ05ohaWX`?oTfnV00?oVgNYol7_lOo1ko400_o1ko42ohYIT@CoS5^C1?n@GiD4oiATU`Co[82U
1?nVNZ<5oj=fXP;oXGFQ0_ndT;44ojj6ZPCoZWnV00?oYG^Uol:^a_o2[/H00_o2[/H4okZL^P04ok>B
]?nnoN3o__gPokkmh0CoVgfa00?oThC0oj^=]on[SKL00_n[SKL3ojB?_`CoW9O>00?oZ9:noj>DaOnS
U<D00_nSU<D5oijKd0;oVJCM00?oYZ?Coj>Xf_nSZ=X01?nSZ=X2oj2^hP06ojJZf_nT[]ooY:kOojB^
gol0003oY:kO1?nS/^<2oj>fiP;oY[OU1OnU^NL2ojFkj@;oYkcX1OnW_^XDooooo`03o`000?oooooo
oooo01Wooooo000Kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`07
ooooo`CoTKWb0onB/N`3oi>ZiPCoTj?P0_nCWMX01?n5Y^WoQZ?WohJSion6XnL3ohRRi@?oRJ3S1On;
Wn43ohfNg`?oSYkN1?n@W]d4oi6Ng0;oTioL0omicol2ogWBo`;o[Yc50onZU/44ojJ?_@;oXhVi00?o
UgV`oiAf[_nDMZh00_nDMZh4oi9bZ`?o00000on@KJL3oi1/Y@CoT6^T0on?JJ<4ohiXX`?oSVRR0on?
J:84oi=ZX@CoUffO0onIKIh01?nJKIkoWW>RoiicX_nNLj84oi]`X0CoUfbN1?nAIid3ohaSW@CoR66N
0on8HZ05ohaWX`;oTfnV0onoi?400oo1ko7oRER@ohYIT@02ohYIT@CoS5^C1?n@GiD4oiATU`Co[82U
1?nVNZ<5oj=fXP04oj5eXOndT;7o]92aokB@/@Co[XJZ1?nZOjH5ol:^aP?o^Ybj00?oZh6Woj9lZOnR
O:T00_nRO:T4oi]m/@GoZhfg1?nTSkl00onLUlkoZ9:nojRB_P02ojRB_PCoXiC50_nNVm02oj^Pc0Co
YZ?C1?nSZ=X00onYZ=GoYZ[JojJZfP02ojJZfP?oY:kO00?o0000oj>bhonS/^<00onW]>84ojJgi@;o
YKWW0onX^^L4ojNlj0;oYkkZ0_nX_nXDooooo`03o`000?oooooooooo01Wooooo000Uooooo`03o`00
0?oooooooooo00Sooooo0_nA^O82oh2cm@?oPJob1?n3[>l3ohBYk0?oQJKY0on6XnL3ohRRi@?oRJ3S
1On;Wn43ohfNg`?oSYkN0_n@W]d3og[7o`CoN/_o0_micol2ok6Sb@?o[Yc51?nZU/42ojJ?_@04oiYn
]?nGNK3oUgV`oiMi/0CoU7J^00CoTW:[o`000?l0003o00000onAL:T3oi1]Y`CoT6bU0on@Jj@3ohmY
X`CoSVRS0on>J:83ohmXXPCoTfZQ1?nGKIl2oiU]WP03oiaeY_nNLj;oWW>R00?oWW>R0onKL:04oiM/
WPCoTFNM0on<Hid4ohQQWPCoR6:P1?n<Ij<00onCKjKo_nCaokoTl@02okoTl@;oRER@0on:FI44ohaK
T`CoT5nE0onDI9L2ok:7Z0?o[82U1OnVNZ<3oj=fXP03oknW`_ndT;7o]92a00;o]92a1On^QZX2ojYo
YP;oc]OQ1Oo2[/H00onjW;[oZh6Woj^1Y`05oj9lZ@;oVgfa0_ncT;84oj^=]`?oY8no00?o/9BjojRB
__nXT[h00onXT[h3oj>Da@03ok6Qaon[X<coZj3<00?oZj3<1?nVXm<00onSZ=[oZJSEojVXe@02ojVX
e@CoYZ[J0_nT[]l00ol0003oZK?OojNdhP04ojNdhP;oY[OU0_nY^ND5ojRji`;oYkcX0_nY_^T4ojRo
jQ;ooooo00?o0000ooooool000006_ooool002Gooooo00?o0000ooooooooool02_ooool3oh2cm@?o
PJob1?n3[>l3ohBYk0?oQJKY0on6XnL3ohRRi@?oRJ3S0_n;Wn43ogRlo0?oNL3m1Omia?h3og[7o`;o
N/_o1OnaXlT4ojjLa@;oZYK100CoWH>goiYn]?nJO[CoVWjd1?nGNK001?nDMZko0000o`000?l00003
oi9bZ`?oTG2Y0on@KJL4oi1/Y@?oT6^T0on?JJ<4ohiXX`CoSVRR0on?J:83oi=ZX@CoUffO00?oVFfN
oiaeY_nLMJH01OnNLj83oi]`X0CoUfbN1?nAIid4ohaSW@?oR66N1?n8HZ03ohaWX`;o/L_]0onoi?43
ohUHT0?oRUVA1On<Fi<3oi1OU@;oU6BG0onbQjP3ojb0Y@GoYWZS0_nSMZ82oknW`PCo]92a1On^QZX0
1?nZOjKoc]OQolkGhOo>en44ol:^aPCoZh6W1OnRO:T01?nKOK7o/i2bok>@/_ncT;85oj^=]`04ojB?
_on`U;[o/9Bjok2D^PGoZ9:n00CoXiC5ok6QaonaXLOo/J771?n[X<`2ojJSd`;o[ZSA1OnYZ=D2ojJZ
fP;o[K;L0onY/ml01?l0003oZK?OojNdh_nW]>82oj^ii0GoZKWU0_nX^^L2ojZnj0GoZKkY0_nX_nX2
ojW1jaCooooo00?o0000ooooooooool05oooool002Gooooo0_l0000<ooooo`?oP;?e0on1[o82oh>/
k`GoMK3g0ome/OP4ogJcn0?oM[Ki1?mg^OX3ogRlo0?oNL3m0_mia?h00onikoCo`]7Vol;AiP02ol;A
iP?o]:W=1?naXlT3ojjLa@04oj69^onMPkOoWH>goif3]`CoVWjd0_nGNK02o`0000?oU7J^0onBLZ/3
oi5`Z@?oT6fW1?n@K:D4oi1[Y0?oSfVS0on>J:<4ohiXXP?oSfRR0onCJZ42oiM]W`;oV7FZ0onLMJH5
oiicXP?oVg2P1?nGK9h4oi5WW@CoS6>M0on8HIh4ohQRX003ohaWXonabngo/L_]00?o/L_]00?o_nCa
ohYHT?n9F9000_n9F903ohYIT@GoS5^C0on@GiD00onDI9Oo/XNXok:7Z002ok:7Z0Co[82U1?nVNZ<0
1?nSMZ;o_jO2oknW`_noYl85okB@/@?o[XJZ00?oTNk9olkGhOo>en400oo>en400oo2[/KoYh6ZojN1
ZP04oj^1Y`GoXWbY1?ncT;84oj^=]`03okVL^on`U;[o/9Bj00;o/9Bj1?nXT[h00ongYLOo/J77ok6Q
a`02ok6Qa`?oZj3<00?o/jcAojjXdOn^Z=400on^Z=43ojVXe@03ok2dfon]/]co[K;L00?o[K;L0onY
/ml00ol0003oZkWToj^ii003oj^ii0;oZKWU0_n[_nP5ojZnj0;oZKkY0_nZ`N/5ojW1ja?ooooo00?o
0000ooooooooool05oooool002Cooooo00?o0000ooooooooool03Oooool3ogJ_mP?oMJof1ome/?L3
ogFan0CoM[?h0omf]_T2ogNinP;o>kgR00?o?l6jogoXg_nij_D00_nij_D00onikoCo`]7Vol;AiP02
ol;AiP03okN_dOndZLgo]:W=00;o]:W=1OnaXlT01?n^W<GoXHVkoj69^onQRK/3oif3]`;oVWjd0ol0
00000onGNK3oU7J^oiAf[P02oiAf[P?oTW:[0onAL:T4oi1]Y`?oT6bU1?n@Jj@3ohmYX`?oSVRS1?n>
J:83ohmXXP;oTfZQ00?oTW>]oiQeZ_nHMJX00_nHMJX4oiaeYPCoWW>R0onKL:05oiM/WP?oTFNM1?n<
Hid3ohQQWP;oR6:P0onQ[=l4ok7;k@?oRUR@0on9F903ohYIT@GoS5^C0on@GiD5ok:7Z0Co[82U0onV
NZ<00oo@k>So_jO2oknW`P03oknW`PCo]92a00?o[XJZoi7^bOnAk/T00_nAk/T2olkGh@;o[hBV0_nW
PJX2okJ;Z@?oZh6W1?nRO:T00onjUk?o/i2bok>@/P03ok>@/P;oZhfg0oniW;/3ok2D^P?oZ9:n0_ng
YLL5ok6Qa`04oj^Pc?nc[=7o/jcAok>/d@Go[ZSA00CoZJSEok2dfon`]=_o/;CK1?n]/]`01OnY/moo
[K[Sojfjhon]^^?o000000?oZkWT00?o[<3Xoj^oj?n[_nP00on[_nP2ojZnj0?oZ/;[1?nZ`N/4ojW1
jaCooooo00?o0000ooooooooool05_ooool002Cooooo00?o0000ooooooooool03_ooool3ogJ_mP?o
MJof1Ome/?L3ofJlo@CoG/3m0omE`_T2odW2l0;oF]?L0_n@kO03okWZm@Co`M7V00Co`]7VokN_dOng
[m7o]joA1?ndZLd2ok6Sb@;oY92o1?nQRK/2oif3]`?o000000CoVWjdoiMi/?nGNK3oUgV`1?nDMZh4
oi9bZ`?oTG2Y0on@KJL3oi1/Y@CoT6^T0on?JJ<3ohiXX`;oSVRR0_n=Kj`3ohe`[@?oTW>]1OnHMJX3
oiaeYPCoWW>R0onKL:05oiM/WP?oTFNM1?n<Hid2ohQQWP03oi^Kd_nQ[=ooXJcO00CoXJcO00?o/L_]
oh]IT?n:F9000on:F903ohUHT0?oRUVA1On<Fi<3oi1OU@Go/XNX1?n/P:D00onVNZ?od>cXom3/j002
om3/j0Co_jO20ondT;400onJJi_oTVRNokB7YP02okB7YPGo[hBV00CoYh6ZokJ;ZOnfRjWo]X^Y1?n[
PJL2oj9lZ@?o^YNc1?ncT;800on[SKOo^IbkokVL^`02okVL^`Co/9Bj00?oZ9:nokNUaongYLL00_ng
YLL3ok6Qa`03ok^fe?nc[=7o/jcA00;o/jcA1?n^Z=400one^Mco/;CKok2df`03ok2df`;o[K;L0_n`
_N@3ojfjh`03o`000?n]^^?oZkWT00?o[<3X0on[_nP2oj_3k0GoZ/;[0_nZ`N/2oj[2k0CoZL7[5?oo
ool00ol0003oooooooooo`0Eooooo`009?ooool3o`0000oooooo1?mg[oH4og:dn@?oKKSl0omV_?d2
oek0o@;oG/cg0omag?<3oicZnP?o^N?d00?o^N[eol7Ai_o1dNH00_o1dNH00oni]=Co]joAokN_d@02
okN_d@?o]:W=00?oZ9O3ojB@_onTT;l00_nTT;l3oj69^`?o000000?oWH>goiYn]?nJO[@00_nJO[@3
oiMi/0?oU7J^1?nBLZ/3oi5`Z@?oT6fW0on@K:D2oi1[Y0GoSVjZ0on>Kj/4ohe_[0?oSG2]1?nBLjd4
oiQeZP?oW7FV1?nNLj84oi]`X0CoUfbN0onAIid2ohaSW@;oVYC<1?nKVm84oj6/g`?oReV@1?n:F903
ohUHT0CoRUVA1?n<Fi<2oi1OU@;o]Hb[1OnbQjP3ojb0Y@03oj^1Yon^OJ3od>cX00;od>cX1?noYl80
1OndT;7oVV^KoiY[VonJJi_oTVRN00?o]8NV1On_Q:H4okJ;Z@CoZh6W00?oXWbYokZG/onjUk<00_nj
Uk<4ok>@/PGo^Ibk0on`U;X00oo1/L_o]jG7okNUa`03okNUa`03ok6Qaonk]]Co^kKD00;o^kKD1?nc
[=400on^Z=7o]KWLokFig002okFig0?o/;CK00?o//?Vok2mi?n`_N@00on`_N@2ojfjh`03ojg3jOl0
003o[<3X00Co[<3X00?oZkoXoj_3k?n[`n`00_n[`n`2oj[2j`;oZ/C/1OnZ`^`2ojW1j`;oZL7/4_oo
ool2o`0000Wooooo1?l000000ol@413oooooooooo`07ooooo`009?ooool00ol0003oooooooooo`0@
ooooo`CoMjof0_mb]?T2ognmn`CoMlGn0_m]boh3oh;JoP?oXn;l00?oW>[jokWSm?niho@00_niho@3
ol3?iP03ol7Ai_ni]=Co^KCD00;o^KCD1?ng[m401?ndZLgoZ9O3ojRG`onXUl<3ojB@_`?o00000_nQ
RK/3oif3]`?oVWjd0onGNK03oiAf[P;oTW:[0_n<KZ`3oha]Z`?oRffZ0on<KJX7ohi^ZP?oSVn[1?n=
Kj`4ohe`[@?oTW>]1?nHMJX3oiaeYPCoWW>R1?nKL:04oiM/WP;oTFNM00?oXIO:oiZDc?nJU<`00onJ
U<`4oi^KdP03oj6/gon=FY3oSEZ@00?oReV@1?n:F903ohUHT0CoRUVA1?n<Fi<01?n@GiGo]Hb[okF<
ZoneS:/5ok:7Z0;o[82U00?oZh6WokjCZ_n^OJ000on^OJ001?o@k>So_jO2oknW`_nRLI/4oiY[V`Co
]8NV1On_Q:H4okJ;Z@CoZh6W1OnjUk<4ok>@/P03olRba?niW;_o^Ibk00?o^Ibk00Co/9Bjol6aboo1
/L_o`K7;1?ngYLL5ok^fe0;o/jcA0onh`^84okFig003ok2dfonb`nKo//?V00;o//?V0on`_N@2ojk7
k0?o[L?Y00?o0000ojc0j?n/`>P00_n[a^d4oj_3k003ojW5k_nZa>coZ/C/00?oZ/C/0_nZ`^`2ojW3
k0GoZL7/4oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo
01;ooooo1?n4]O@3ognmn`;oMlGn1?n=dOh01?n2f_koXn;loj?Ro?nSh_`4okSKlP04okWSm?o0cnKo
`<oVol3?iP;o^kWG1Oni]=@2okN_d@03ojbMb?nXUl?oZ9O300;oZ9O30ol000000onTT;ooXHVkoj69
^`02oj69^`?oWH>g0_nJO[@01?n@M[7oSW:_ohib[on>LZl3ohe`[@CoS6j/0on<KJ/3oh]]ZP?oS6fZ
2?n>KZX3ohi_Z`?oSFn/1?n=L:d3oi9c[@CoV7FZ0onLMJH5oiicXP?oVg2P0_nGK9h2ojVQc`CoXIO:
1?nJU<`3oi^KdPCoSEZ@0on;FI04ohYHT0CoRER@0on:FI44ohaKT`Co]Hb[1OnbQjP01?n/P:GoZh6W
okjCZ_nnTjX4ojimX0CoXW6K0onJJi/00oniT:co]8NVokB7YP02okB7YPCo[hBV0_o?[;H3okJ;Z@Co
Zh6W00?ob:^lokZG/onjUk<00onjUk<2ok>@/P;ob;;41?niW;/00oo8b]_o`K7;ol6ab`02ol6ab`?o
]jG70_o2b=l3ok^fe003ok[Bk?nh`^;o^<;R00Co^<;R0_ne^M`2okC=k0Co//?V00?o/;gTojk7k?n^
an`00on^an`2ojg3j@03o`000?n[bNooZlK]00?oZlK]00?oZl?/ojW5k_nYaNh00_nYaNh2oj[4k0;o
Z<C]1OnY`n`2ojW1k0;oZ<7/5?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wo
oooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A006ooooo`03o`000?oooooooooo01?ooooo0_n4]O@2oiJkl@GoT/Ki0_n=dOh3ojKG
n@03oj?Ro?nhfo;o^=_b00;o^=_b0onncND00oo0cnKo^kWGok^ie`02ok^ie`?o^KCD00?o/:C<ojbM
b?n/WLP00_n/WLP3o`0000CoY92o0_nQRK/2oiIn]`?oTgVd0on@M[43ohib[`?oSG2]1?n<KZ`3oha]
Z`CoRffZ0on<KJX7ohi^ZP?oSVn[1?n=Kj`3ohe`[@?oTW>]1?nHMJX4oiaeYPCoWW>R0_nKL:000on^
/M_oZJ7?ojVQc`03ojVQc`?oXIO:1OnJU<`00onKVm;oSU^@oheJT003oheJT0?oReV@1?n:F904ohUH
T0?oRUVA0on<Fi<00oncS:go]Hb[okF<Z`02okF<Z`Co/XNX00?oZ7fToj^1YonnTjX00_nnTjX4ojim
X0CoXW6K0_nJJi/3okV@[0Co]8NV0_n_Q:H3oln/]PCo]X^Y0_n[PJL2olR[_0Go^YNc00Co/i2bolRb
a?o8//Cob;;40oniW;/2olS:f`Go`K7;00?o]jG7ol;8goo2b=l00_o2b=l01?nk]]Co^];/ok[Bk?nj
d^`4okS2hP03ojoIm_ndcNco]<g/00?o]<g/0_nb`nH3ojg=l@;o[/O/0_nYcO<3oj_9k`04o`000?n[
bNooZlK]oj_6k@;oZLO_0onYaNh2ojO5k`CoZ<C]0_nY`n`3ojO2k0CoZ<7/4oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo01Gooooo1?nF^o42oi;6n@CoYl_c
0_nVeoT4okOCkP05okSKl_nncNGo_/gUokk=iOnl_=X01_nk^ML01Oni]=Co/:C<ok2Tc?n`Y<co[9g8
00;o00001?nXUl<2ojB@_`03oiV4^_nFO[OoUWjg00;oUWjg0onCNK@4oi1f/@?oSW:_0on=L:d3oha^
[0?oS6f[1?n;KJX3oha]ZPOoSVjZ0on>Kj/4ohe_[0?oSG2]0onBLjd5oiQeZP?oW7FV1?nNLj801?nK
L:3o[[7Kojjafon^/M/4ojVQc`CoXIO:0_nJU<`01?n@G97oSU^@ohiKT?n>Fi04oheJT0?oReV@1?n:
F904ohUHT0?oRUVA0_n<Fi<3ok><[@Co]Hb[0_nbQjP2ojQmY0Co_Y>Z1?n^OJ04oj9aV`03oiY[Voni
T:co^I2/00;o^I2/1?ndQjH00on_Q:Kocjbfoln/]P02oln/]PCo]X^Y00CoZh6WolR[_?o8Zkcob:^l
1?njUk<00ooJj=oob;;4olRba003olRba003okVL^oo8b]_ob<[K00;ob<[K0oo1/L/00oo1jo7o`/SO
ol;8g`02ol;8g`;oZnGj1?njd^`00onh`^;o[mWfojoImP02ojoImP;o]<g/0_nXe?L4ojg=l@03ojCA
monYcO?oZLgc00?oZLgc0_n[bNl00onWbO7o0000ojW7k`04ojW7k`03ojW5k_nWaNooYlG_00;oYlG_
0_nXa>d2ojO2k@GoYl;/0_nX`N`2ojO0k1?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`09ooooo`002Oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1Oooool3o`0001Kooooo0_nF^o43ojO0j`?oYl_c0_neb^X4okOCkP?o_L[T00Co_/gUokblf_nl_=[o
_;cJ1?nk^ML00oncZm3o/:C<ok2Tc003o`0000?o[9g80_nXUl<01?nMR[koVHBjoiV4^_nIQ;X4oiIn
]`?oTgVd1?n@M[43ohib[`?oSG2]1?n<KZ`3oha]Z`?oRffZ0on<KJX7ohi^ZP?oSVn[1?n=Kj`4ohe`
[@?oTW>]1?nHMJX3oiaeYP;oWW>R0_n/bNl4ojjaf`GoZJ7?0_nQUlX01?nAGY;oT5bAoi1LTOn@G943
ohiKT0CoSEZ@1?n;FI03ohYHT0CoRER@0on:FI400on<Fi?o/hb]ok><[@02ok><[@Co]Hb[00Co/XNX
ojQmY?nXOJCoZ7fT1OnnTjX4ojimX0?oXW6K1OniT:`4okB7YPGocjbf1?nfRjT5olR[_0;o^YNc0ooJ
j=l3olRba0;o]_Ka1?o8b]/00oo1/L_o`N_aol7[l@02ol7[l@03ol;8gon[iO[oZnGj00?oZnGj0_nj
d^`3oi[To@;o[mWf0onJf?d3ojSDm`03ojg=lOnTdOOoY=7g00;oY=7g0_nYcO<2ojC;m0CoYlWa00?o
0000ojW7konYanl00onVa_02ojO5k`;oY/?^1OnW`^d2ojO2k0;oYl7/1OnW`>`Aooooo`?o00001ooo
ool00ol0003oooooooooo`09ooooo`002Oooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool01?ooool00ol0003oooooooooo`0Hooooo`CoYl3[00?oYl_cokG:j_neb^X00_ne
b^X00ongdnko_L[Tokg:i002okg:i003okbog?nl_=[o_;cJ00?o_;cJ00?o^kWGok>[d?ncZm000ol0
0003ok2Tc0;o[9g800?oXI73oif:__nMR[h00_nMR[h3oiV4^PCoUWjg0onCNK@3oi1f/@?oSW:_0on=
L:d4oha^[0?oS6f[0on;KJX3oha]ZPOoSVjZ1?n>Kj/3ohe_[0CoSG2]0onBLjd4oiQeZP;oW7FV0_n:
eOl4ojc9k`Co[[7K0_nYXLl00onBGi?oTEjBoi5NTP02oi5NTP?oT5bA0on>Fi04oheJT0CoReV@0on:
F904ohUHT0?oRUVA1OncS:d4okF<Z`03ojEiXonXOJCoZ7fT00;ogl_41?nnTjX4ojimX0?oXW6K1Oni
T:`4okB7YP03omkm_Oo?[;Kocjbf00?ocjbf0_nfRjT2omCIg0Cob:^l00?o^YNcom[XgooJj=l00ooJ
j=l00oo8//Co]_KaokKfl@02okKfl@;ob<[K0omLdl<2ol7[l@?oH]OW0_n[iOX3ofKGl@;oV^Cm0on2
eOl2oi[Ho@;oT=3m1OnKdo/2ojCAm`;oWl_f1?nTbo@2ojO9l@03ojC6lOl0003oY<Ka00?oY/K`0_nU
`^h4ojK3kP;oYl;]0_nV`N`5ojO1k0;oYl3/0_nW_n/>ooooo`Co000000?oooooo`000?ooool01_oo
ool00ol0003oooooooooo`09ooooo`002Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`;oYl3[0onc`^D2okG:jPCo^lOS00Co
_L[Tokbog?nl_mco_;oL0onl_=X01?nf/MCo0000o`000?l00002ok>[d0?o/:C<00?oYIS8oj6A`onQ
TL<00_nQTL<3oif:_P?oVHBj1?nFO[L3oi=i]0?oT7Ja0on>LZl3ohe`[@CoS6j/0on<KJ/3oh]]ZP?o
S6fZ2?n>KZX3ohi_Z`?oSFn/0_n=L:d4offlo@?oC[kg1?mCaOD3oh[Eo`Co[<W_0_n^/M/01?nBHIGo
TUnCoi9OTonBGi<4oi5NTP?oT5bA1?n>Fi03oheJT0CoReV@0on:F904ohUHT0;oRUVA00?o[HR_ok><
[OncS:d00oncS:d4okF<Z`03ojEiXonXOJCogl_400;ogl_41?nnTjX4ojimX0;oXW6K0_nnXK`4okV@
[0?o]8NV0_oNoKd5oln/]P04okJ;ZOoDfMcoe=WLomCIg0?ob:^l0_nITL/00ol0003of^SOom[Xg`03
oin?``;o]_Ka0_n4Umh00onVVl_oTj3Moi>Pg@02oi>Pg@CoO;3d1?mT^_d4ofc:oP;oP]Go0on6aod3
oi3@o@;oVm?k0_nJb?L5oio;mP;oY<_d0_nRa_83ojC6l@03o`000?nTa_7oY/K`00CoYL;^0_nV`nh2
ojK0k0CoY/7/0_nW`N`2ojJoj`GoYko[2_ooool3o`0000Gooooo00?o0000ooooooooool00oooool0
0omEEEGoIVIVo`00000;ooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4005ooooo`;o00006oooool3ok?2i@;o^/?Q1?nkan<00onm`]ko_;oLokbo
g003okbog0?o000000?o][7Dok>[d?ncZm000oncZm001?n`Y<coYIS8ojFHb?nUV<P3oj6A``?oWHZn
0onIQ;X4oiIn]`?oTgVd1?n@M[43ohib[`?oSG2]0on<KZ`3oha]Z`CoRffZ0on<KJX7ohi^ZP;oSVn[
0_nHZN85ohffl@;oKKcm0_n2H:83ogmNXP?oRf:L1?n<H9X2ohmQU`CoTV6E0onBGi<4oi5NTP?oT5bA
1?n>Fi03oheJT0CoReV@0on:F904ohUHT004ohYITOn]R:oo[HR_ojf8[`Go/hb]0_neS:/2ojEiX`04
ojQmY?oOblCogl_4omo;a0Co_Y>Z1?n^OJ001?nRLI_o_Z6lokjQ_?nnXK`5okV@[004okB7Y_oNoKgo
g_fmomkm_@Cocjbf00?oWh6bomCIg?oDfM`00ooDfM`01?o8Zkco[i6gojnA]onITL/3ojnA^0CoWho3
00?oQ9ONojJKbonVVl/00_nVVl/4oi>Pg@;oO;3d00?oW:?Johj]jon>[N/00_n>[N/5ohNln0;oQ/Om
0_nE^_45oiO3mP?oV/Sg0_nOboH3oio3lPCoX/Kb0_nTa_400onT`^ko0000ojC2kP02ojG2kP;oYKo/
1OnV`>`2ojK1k0KoY[o[1?nW_n/6ooooo`Co00002?ooool00ol0003oooooooooo`0Aooooo`002Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03
o`000?oooooooooo01_ooooo00?o/l;Uok[3hOnj`n400_nj`n400onkan?o_L;Nokg2gP02okg2gP04
okbog?l0003o0000o`0000Go][7D0_ncZm02ojVPc@CoYIS80onQTL<4oif:_P?oVHBj0onFO[L3oi=i
]0CoT7Ja0on>LZl3ohe`[@?oS6j/0on<KJ/4oh]]ZP?oS6fZ0_n>KZX00onAU=?oUYkIoiJNf@02oiJN
f@GoV:WR0_n=]_43ohARX`?oPV2R0omoGZ82ogUKX`03oh]RW?n<H9[oS62J00;oS62J0on?HIL3oi9Q
U@?oTUnC1?nAGY83oi1LT@CoSU^@0on=FY04oh]IT0?oRUR@0on9F9000onTPZoo[HR_ojf8[`02ojf8
[`Go/hb]00?o]Hb[ojEiXonUNJ<00_l00004omo;a0?o_Y>Z0on^OJ000ongd>co_Z6lokjQ_002okjQ
_0Go^I2/00Ko]8NVojZ9/_nZRK;o/8V/omkm_Oo?[;H2ok29[0;oWh6b0_oDfM`5ojnA]`Co[i6h0onO
Sl<00onfWKooYY_;ojJKb`03ojJKb`;oTj3M0_nYW/`4oibSfPCoSZg[0_n7_?P3oi^bj0CoUK[a0_nG
`oH2oijik0GoWKo`0_nO`o82oj:mk0CoXko^0_nT`^h00ol0003oYKk[ojFok004ojFok0;oY/3/0_nV
_^/9ojJoj`CoYko[0_ooool3o`0000cooooo00?o0000ooooooooool04Oooool002;ooooo00?o0000
ooooooooool07Oooool3ok[3h@?o_LCO00Go_L;No`000?l0003o0000okbog003okRgf@?o][7D00?o
[JSBojVPcOnYX<d00onYX<d3ojFHb0CoXI730onMR[h3oiV4^P;oUWjg00CoSX30oham__n<OKkoS7fn
1?n:Nkd3ohUk_@?oRG^n0on9OL03ohZ0``CoRhG70on=S<d4oi6Dd`CoUYkI0onHZN83ohIUY@?oQ6:S
0on2H:83ogmNXP?oNE^S1?n<H9X3ohmQU`?oTV6E0onBGi<4oi5NTP?oT5bA1?n>Fi03oheJT0CoReV@
0on:F9001?n9F93oY8:_ojB2[onTPZl4ojf8[`Co/hb]00CoX7FSojEiXonUNJ?oYHRf0_nXS[X01?l0
003ogl_4omo;a?oObl@3okjCZP03ojimX?ngd>co]m3/00;o]m3/0onnXK`4okV@[003ok><[OnZRK;o
ZXVb00;o^I:^1?n`RJ`00onOPK;o^9BbokRD/P02okRD/P?o[i6g00?o_iffojnA^?n_TKP00on_TKP0
1?nOSl?o]YfookJM_onfWKl4ojJKb`GoZIk<1?nLXmX2ohj]j`;oXZ[M1OnK/^P2oiFjl@;oX;;U1?nN
^N`2oifol0;oX[WY1OnR_N`2oj>okP;oY;cZ0_nU_^/01?l0003oYKk[ojFok?nU_n`3ojJmjPCoY[k[
0_nV_n/2ojJnjPGoY[o[1?nW_n/00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo013ooooo
000Rooooo`03o`000?oooooooooo01kooooo00Co^/?Qokg4gonma=oo_LCO0_l00002okg2gP;o^[gM
1?nh]mT01?nf/MCo[JSBojfXd_n]Z=84ojVPc@CoYIS80_nQTL<01?nHSlWoU8W5oiB9aOnDRLD3oi64
`PCoSX300on<OKh4ohYk_@?oRG^m0on9Nkh3ohUm`0?oRX331?n;QLL3ohf<c@?oTICC1OnFW]T00onH
ZN;oRFZYohIUY@02ohIUY@?oQ6:S0on2H:83ogmNXP?oNE^S0_maF:H2ohaPVP?oSf6G0onBHID3oi9O
T`CoTEjB0on@G944ohiKT0?oSEZ@1?n;FI02ohYHT003oiim[_nTPZooY8:_00?oY8:_1?n]R:l2ok><
[@;oX7FS00GoYGVSojF8]_nUR;KoYHRfojR>^P03ojZ4[0CoZH2X0_nVOJH3okO@k0Co_Z6l0_niT:`2
ok><[@04ojZ9/_niTZko^I:^okVB[PCo/8V/1OnhU;82ojnA]`?o_iff0on_TKP00onoY;ko]YfookJM
_`02okJM_`?oYY_;0_ndXLD4ojVNc0;oW:?J0on/Ym<4oj:Zg@;oVk;X0_nU[]d5oj2bi@;oW[W/0_nU
]^D4oj:ij@;oX[g/0_nU^NP5ojBljP;oYKk[00?o0000ojJmj_nV_NX01?nV_NX2ojJnj`;oYkgZ1?nV
_^X2ojJoj`OoYko[4?ooool00ol0003oooooooooo`0@ooooo`008_ooool2o`00023ooooo0ol00000
0onma=oo^l?QokZmg@04okZmg@;o^;OI00?o/;7HojfXd_n]Z=800on]Z=84ojVPc@;oYIS800?oW9K=
oiR?bOnHSlT00_nHSlT3oiB9a@?oTHC20on>P<03oham_PCoRW^m0on9Nkd3ohUk_P?oRGg00on:P<<4
oh^5a`CoSHc=0onAU=<2oiJNf@04oi1c[_n9JZWoRFZYohUZZ@?oQVFU1?n4HZ<2oh9PXPCoOejR0_mi
Fj<4og5HYP?oSf6G0onBHID3oi9OT`CoTEjB0on@G944ohiKT0?oSEZ@1?n;FI000on:F93oWWf^oiim
[P05ojB2[`Co[HR_00Co/hb]oj1eXonPMJ?oX7FS1?nUR;H4ojZ4[0CoZH2X1?nVOJH00onNN:So]m3/
okjQ_002okjQ_004okV@[?ncS:go/hb]ok><[@Co^I:^1?n`RJ`00oo3X[Oo^9BbokRD/P02okRD/P03
ojnA]onoWKKo_iff00;o_iff0_n_TKP3oknT_PCo]Yfo00CoYY_;okBQaOndXLGo]:750onYW/`00onf
Z/co[:OCojbWd`04ojbWd`;oXZ[M00?o[:cFojF^gOnU[]d00onU[]d2oj2bi@;oZ;;P1OnU]^D2oj:i
j@03ojJgiOnU^NSoYKWX00?oYKWX0onT_>X01OnW^nSoY[cYojJljOnV_>Wo000000CoY[gZ00?oYkcY
ojNmj_nW_NX00onW_NX2ojJnjP;oYkkZ2?nW_n/@ooooo`03o`000?oooooooooo013ooooo000Roooo
o`03o`000?oooooooooo01cooooo0ol000000ooooooo_LCOok_3h@03ok_3h@?o^[gM00?o/kWNok2a
f?n`/MP00_n`/MP5ojfXdP;oZJ3=00?oWigBoibFcOnLU/d00_nLU/d3oiR?b@?oU8W50onAQ<83ohj0
`0?oS7fn1?n:Nkd3ohUk_@?oRG^n0on9OL03ohZ0``GoRhG70_n=S<d01On;KJ_oQVNWohIWYon6IjOo
V7je00?oT7>^0on9JZT2ohIUY@CoQ6:S0on2H:83ogmNXP?oNE^S0omaF:H3ofmKZ`?oTV6E0onBGi<4
oi5NTP?oT5bA1?n>Fi03oheJT0;oReV@0_nJNZh4oiim[PCoY8:_1?n]R:l00onLLj?oX7FSoj1eX`02
oj:5]@;oYHRf00?oZHNaojZ4[?nZQ:`00_nZQ:`5ojV0Z0?oYWfV1?nfT:l4ok><[@03olJV^OniTZko
^I:^00?o^I:^0_n`RJ`2ol>R]`Co^9Bb1OnoWKH00on_TKSo_jBnoknT_P02oknT_PCo]Yfo1OndXLD0
1?nYW/co]Z[<okJZc?nfZ/`4ojbWd`03okB^don/[=Ko[:cF00;o[:cF0onU[]d00on]/]coZ;;PojRb
h003ojRbh0?oYKKU00?oZKGRojJgiOnV]nD00_nV]nD4ojFij003ojBlj_nW^nSoYk_X00;oYk_X0_nV
_>T00ol0003oY[cYojJmjP04ojNlj@?oYkgZ00?oYkkYojNnj_nW_^X00onW_^X8ojNoj`oooooo00?o
0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool06Oooool3o`0000Kooooo1?nk`n40
1?nj_Mgo/kWNok>ig_nc^Mh4ok2af0;o[JSB0_nSY]L4oinMdP?oW9K=0onHSlT3oiB9a@?oTHC21?n>
P<03oham_PCoRW^m0on9Nkd3ohUk_P?oRGg00on:P<<2oh^5a`;oTGF_0on;KJ/4ohIWY`?oPF:U0on9
JZT3ohIUY@?oQ6:S0on2H:83ogmNXP?oNE^S0omaF:H3ofmKZ`;oM6:`00CoTV6Eoi9OTonBGi?oTUnC
1?nAGY83oi1LT@CoSU^@0_n=FY000onINJkoVWZ^oiYj[P02oiYj[PCoWWf^1OnTPZl2ojf8[`;oW7>S
00GoX7FSoj:5]OnRQKGoXXFeojF8]P03ojV7/@?oZXB/1OnYP:P2ojImYP;o^9Vh1?nfT:l2ok><[@;o
aZJi1OniTZh01?n`RJco`j:gol>R]oo3X[L4okRD/P03olZ__onoWKKo_iff00;o_iff1OnoY;h3okJM
_`;o`jg40ondXLD00onn/Lgo]Z[<okJZc003okJZc003ojbWdond[]?o]:kC00;o]:kC1?n/[=H01?nU
[]go[K;Lojfbg?n]/]`4ojRbh003ojFfiOnY]N;oZKGR00;oZKGR1?nV]nD2ojFij0;oZ;WV1?nW^nP2
ojJlj@03ojNlj?l0003oYkcY00CoYkcY00?oYkgZojNnjOnW_^T00_nW_^T3ojNnjP03ojRoj_nW_n_o
Yko[00GoYko[00?oZ<3[ooooooooool03Oooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0
003oooooooooo`0Fooooo`?o00002_ooool2ok_3h@;o]L?T1?nc^Mh2ok2af003ojJ^gOnSY]OoXjKG
00?oXjKG0onOWM84oibFc@?oV8o90onDRLD3oi64`P?oSX300on<OKh4ohYk_@?oRG^m0on9Nkh2ohUm
`0;oAL;Y0onIOkH4oi5e[`?oRff[0on6IjL3oh5RY@?oOEnU0on6IJD3ohARX`?oPV2R0omoGZ83ogUK
X`?oLERV0om_Fj/3ogAR/0?oTUnC1?nAGY83oi1LT@;oSU^@0_nHNJl3oiUi[PGoVWZ^0onNOJh5ojB2
[`04ojf8[onLLj?oW7>Soif2]P;oXXFe0_nTQkD4ojV7/@?oZXB/1OnYP:P01?nVOJKo^9VhokRI^?nh
VKP4okJ@[`03ok><[Oo6Y[WoaZJi00;oaZJi0oniTZh00oo;^LWo`j:gol>R]`03ol>R]`;o^9Bb0_o:
[kl4oknM]P03olbhaonoY;ko_jBn00?o_jBn00?o]Yfool>]a?o3[L@00_o3[L@01?ndXLGo_[7=okja
cOnn/Ld3okJZc003okfgdond[]?o]:kC00?o]:kC0_n/[=H2ok>df@Go[K;L0_nX/^02ojfeg`CoZKGR
0_nV]nD2ojZii0GoZ;WV0_nW^nP2ojRki`?oYkcX00?o0000ojNljOnW_>T00_nX_NT5ojNnj@03ojNn
j_nX_n[oZ;oZ00;oZ;oZ0_nW_n/2ojRoj`CoZ<3[3_ooool00ol0003oooooooooo`0@ooooo`008_oo
ool2o`0001Cooooo0ol0000>ooooo`Co]L?T0_nc^Mh00onY]n?oYZkMojJ^g@02ojJ^g@GoXjKG0onO
WM82oibFc@04oi6Ng?n=V]_oSI[KohfJf`?oRYOJ0on7Um`3ohBHg`CoPIgU1?mmY^d4ogRcn0;oJ<;n
1?nQRk`3oiUo]P?oTGF_0on;KJ/3ohIWY`?oPF:U0ommGjD3og]PZ0?oQ6:S0on2H:83ogmNXP?oNE^S
0omaF:H4ofmKZ`;oM6:`0on0K;<4oi5NTP;oT5bA00?oU7RaoiQi[onHNJl00_nHNJl4oiUi[PCoVWZ^
1?nNOJh3ojB2[`05oiQ`XonLLj?oWH:foif2]_nMPkH01?nTQkD4ojV7/@CoZXB/0onYP:P00onjZ<Ko
^9VhokRI^002okRI^0Co]Y2_1Oo6Y[T2okVB[P?obkW91?o3X[L01?nhU;;obZnoolZ__oo:[kl3oknM
]P;oc;S71?noY;h00oo;`=3o`jg4ol>]a002ol>]a003olS3e_nn/Lgo_[7=00?o_[7=00Co]Z[<okfg
donm]m?o_KOC0ond[]<00onh^M[o/kCIok>df@03ok>df@;o[K;L0_n`]mh5ojfeg`;oZKGR0_n/^N<4
ojZii0;oZ;WV0_nY^nH5ojRki`;oYkcX00?oZ;gXo`000?nX_NT00onX_NT2ojNnj@;oZ;kY1OnX_nX5
ojRoj`CoZ<3[3Oooool00ol0003oooooooooo`0@ooooo`008Oooool2o`0001;ooooo0ol0000Boooo
o`;o]L?T0_n[`NX3ojVgh`CoYZkM0_nSY]L2oiRYhP?oUJ?O1?nAW]`3ohfJf`?oRYOJ0on7Um`3ohBH
g`CoPIgU1?mmY^d2ogRcn0CoZ9O40onQRk`3oiUo]P?oTGF_0on;KJ/3ohIWY`?oPF:U0ommGjD3og]P
Z0?oNVB^0on2H:84ogmNXP;oNE^S1?maF:H3ofmKZ`;oM6:`0on0K;<4ohee/`?oU7Ra1OnHNJl3oiUi
[PCoVWZ^1?nNOJh01OnTPZooV72SoiQ`XonHPKSoU7Zd00CoWH>f0onTQkD4ojV7/@CoZXB/00CoZH2X
okZXa_njZ<Ko^ZS61OnhVKP2okJ@[`;oeM?G1?o6Y[T00oniTZkobkW9ol^ib@02ol^ib@Co`j:g1Oo:
[kl01?noWKKoc;S7olbhaoo<^<L3oknT_P?obl3@0_o3[L@2olS3ePCo_[7=00?o`LCLokfgdonm]m<0
0onm]m<01?nd[]?o^;WJokRif_nh^MX3ok>df@03okFlgon`]mko/;ON00?o/;ON0_n]]Ml2ojnkhPGo
[;WS0_nZ^N@2oj^ki@CoZK_V0_nX^nL2ojVmj0?oZ;gX00Co0000ojRmj?nX_NWoZ;gY1_nX_^T5ojRo
jP;oZ;o[1onX`>/<ooooo`03o`000?oooooooooo013ooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
00oooooo0_l0000Fooooo`CoZl7Z0onY]n<2ojJ^g@;oVjoV1?nHZN83oiFSg`?oTIkL1?n=V]/3ohZG
fP?oQiOL0on4V=l2oh6Mi@?o@L;Q00?o`mo]olGIjOn`Y<`00_n`Y<`3ojRGa0?oXH^l0onIOkH3oi5e
[`?oRff[0on6IjL3oh5RY@CoOEnU0_mkH:P3ogYT[P?oO6ji1?moGZ83ogUKX`?oLERV0om_Fj/3ogAR
/0;oP6bc1?n=MK<4oiAh/@CoV7V_0onINJh5oiYj[P;oWWf^0_nFKZ<01?nHL:?oU7ZdoiAj]?nDN[@4
oif3]PCoY8Ne1?nYQk42ojZ4[003okNmg_njZ<Ko^ZS600?o^ZS61?nhVKP01?nfT:ooeM?GomGCeooE
dmL3olJV^@03okO^m_o;^LWobkW900?obkW90oo3X[L2omKNgP?obZno00?obmkVolbhaoo<^<L00oo<
^<L00onoY;kobl3@ol_0d002ol_0d003ol>]a?o8`mKob<?F00;ob<?F0_nn/Ld3ol74g0?o_KOC00?o
_LGPokRif_nh^MX00onh^MX01?nc]=Wo]KcOokFlgone_=l3ok2ggP03ok6nhon_^n;o[k_R00?o[k_R
0_n/^N<2ojfmi@GoZk_U0_nY^nH2oj^mi`CoZKgX0_nX_NP00onY_^Wo0000ojRnj@06ojRnj@GoZ;oZ
2_nX`>/=ooooo`03o`000?oooooooooo00oooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`?o0000
6Oooool2oj_1jP;oWKg_1?nL]^X3oi^_iPCoV:WR0onEXml3oi6Ng0;oSI[K0_mo]OH3ogVjn`CoL<;n
0_mNb?X4ol?Ok@03okF_don`Y<co/:C<00;o/:C<0onXUl@4oj6;_0?oVGnf0_nAMJl3oh]]Z`CoQVNW
0_n1HZD4ogeOY@?oNf2X0_mjI:h3oga^^@?oNXGB00CoOejRogUKXomiFj?oNE^S0omaF:H3ofmKZ`?o
M6:`0on0K;<4ohee/`?oU7Ra1?nHNJl3oiUi[PGoVWZ^00?oWWf^oiI^Xon<L:l00_n<L:l4oiAj]0?o
WH>f1?nTQkD4ojV7/@04ojZ4[?ng_Mko]kgNokNmgPCo^ZS60onhVKP2ofkK^PCoeM?G00CoaZJiokO^
m_ngk_Ko]nkf1Oo;^LT00oo3X[Ooe]kNomKNgP02omKNgP04olZ__oo;g^KobmkVol_NiP?oc;S70_o6
jNh3ol_0d0;o_mg^1?o8`mH00onn/Lgo`LCLol74g002ol74g003okfgdonmaN3o_LGP00;o_LGP0onh
^MX00onga>Co]KcOokFlg`03okFlg`04ok2gg_na_^?o/KkSok6nh`?o[k_R0_n_`>H4ojfmi@;oZk_U
0_n/_nP5oj^mi`;oZKgX0_nZ_nT3ojVnj@03o`000?nX_^WoZ;kY00;oZL3Z1_nX_nX6ojS0j`;oZ<7[
1?nX`>/<ooooo`03o`000?oooooooooo00oooooo0007ooooo`05oa0@4?ooooooooooooooool@4100
2oooool5o`0000Gooooo0_l0000:ooooo`?o00007Oooool4oifmk`CoW;KZ0onK[nH2oiRYhP;oSK?`
0on8/_43ohFbl`CoOkGf0omi^_/2og32oP05oi[akOnohO3o_n7`okoQl?o3gnd01?ne[m<3ok2Tc0Co
Z9O40onQRk`3oiUo]P?oTGF_0on;KJ/3ohIWY`?oPF:U0ommGjD3og]PZ0?oNVB^0omlK[T4ogZ5dP;o
Keb/0om[EZP4ofmKZ`;oM6:`0on0K;<4ohee/`?oU7Ra1?nHNJl4oiUi[P?oVWZ^0on6JJX3oha`[`Co
U7Zd1?nMPkH3ojB7]@;oZHNa0on^eOD3okNmgPCo^ZS600?o^9VhojRC`?nXTl000_nXTl001_m^fk[o
eM?GomGCeonSU/OoUYcHob0000?o]nkf0_o;^LT00onLW]GoMj;]ogNRk@02omKNgP;o;;Fl1Oo;g^H0
0oo<^<Ooa^W^olKYkP02olKYkP03ol_0d?nogNko_mg^00;o_mg^0_o8`mH2okgLk`?o`LCL0_ngd^h4
okg5h003okRif_nga>Co]lCT00;o]lCT0_ne_=l2ok?4i`Go/KkS00?o[k_Rojo0i_n_`>H00_n_`>H2
ojfmi@;o[<7Y1?n/_nP2oj^mi`;oZ/3Y1OnZ_nT2ojVnj@03o`000?nY`>[oZL3Z00?oZL3Z0_nX_nX5
ojS0j`OoZ<7[1?nX`>/;ooooo`03o`000?oooooooooo00oooooo0007ooooo`05o`000?oooooooooo
ooooool000002oooool01?m4A4CogMgMooooool00006ooooo`03o`000?oooooooooo00Kooooo0ol0
000Qooooo`;oWKg_0_nB^_84oi6gl@?oSkG`1?n=/o03ohRbl@?oQK;c0_mo]OH2oe?;k@;oI=[M0_nJ
lNd3okoQl0;o^;WI1?ne[m<4ok2Tc0;oZ9O400CoUXK1ohim_?n>OKcoSWfl0on6MKT3ogm_]`?oRff[
0on6IjL3oh5RY@?oOEnU0omkH:P3ogYT[P?oO6ji0omjQM801?n4L[KoKeb/ofmL[?m_G:`3of]FZ0;o
RF:M00CoKe^[ogAR/?mdH[3oM6:`0_n0K;<4ohee/`?oU7Ra1OnHNJl3oiUi[P03oiYj[_n3IJSoPfFX
00?oQVVZ1?n<L:l3oiAj]0CoWH>f0_nTQkD2oigPo@Go[]Ge0ong_Mh2okZXaP;oYi2m1?nXTl03oj>F
a`03ojnH`?n[VlKoZi_600;oZi_60onLW]D00on]WLOoXIoCoj6Od`03oj6Od`;oO:3Y0_o;g^H3obnC
l0;oa^W^0omQdo02okoMkP;oQ^3l1Onmg>l00oo1a=co]m;^okOBkP02okOBkP;o_LGP0_ndd>h3okO4
i0;o[l_^1?nca>L2ok6nh`;o[lCY1?n_`>H00on]a>_o[<7Yojc1j@03ojc1j@;o[;oX0_n[`^X4oj[0
j@;oZ[oY0_nY`N/3ojW0jP04o`000?nY`>[oZL3ZojW0jP;oZL7[0onX`>/:ojS1j`GoZ<3[2_ooool0
0ol0003oooooooooo`0?ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgM
oeEEEOoooooo00001_ooool00ol0003oooooooooo`03ooooo`?o00009_ooool3oi:jlPCoTKOa0on?
]O02ohfcl0?oPLCm0omhbOl2of[=o@;oM]kd0onKkOL2ok_OlP03okVogonh^MWo^;WI00?o^;WI0_ne
[m<00onTV/_oWI36oif@aP02oif@aP?oUXK11?n>OK`2ohIe^@?oOfng0omkKKP3ohIWY`?oPF:U0omm
GjD3og]PZ0?oNVB^1?mlK[T00omjQM;oQ7:fohAb]P03ofmL[0?oJeJX0_m/F:T01?n9HYgoP5RJoh1H
V_n0F9X3oh1//`CoSGFc0onDN;44oiQi[`;oVGV^00CoQVRYoh=UZ?n3IJSoPfFX0on6JJX4oha`[`Co
U7Zd0_nMPkH3oi_Oo@?oWN3m0_n^eOD4ojBJb`03ojB=_?nWT;goYi2m00;oYi2m1OnXTl001?nSU/Oo
[iS0ojnH`?n_V<04oj^KaP04oibNeOn]WLOo[Ig7ojfMa`CoXIoC0_mlX>T2oinTf@GoPJK/0om?YOP2
ob^Rk`?oQ^3l0_nmg>l4oiWKoP;o]m;^00?oX]OjokC@k_ndd>h00ondd>h00onga>Co[l_^ojo;kP02
ojo;kP;o/lCW0_n]bNh4ojo4j@03ojo0i_n]a>_o[LC[00;o[LC[0_n/`NT2oj_3k0GoZl;Z0_nZ`>T2
ojW2j`CoZL7[0_nY`>X00onY`N_o0000ojW1j`04ojW1j`03ojS0jonX`N_oZ<7[00CoZ<7[00?oZ<7/
ojS1jonX`N/00onX`N/4ojS0j`[ooooo00?o0000ooooooooool03oooool000Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Gooooo00Co0000oooooooooooooooo0ol0
000Zooooo`?oT[[b0_nA]o42oh^lmPCoQkoi0_n1a?d3oh_Bo`;oPm[n0onNiO`3okKKl`04ok_Ol_ni
_moo^KoOokVog`?o^;WI00?oZjCAojBJbonTV//00_nTV//3oif@aP?oUXK11?n>OK`3ohIe^@?oOfng
0_mkKKP3ogM^^`?oPF:U1?mmGjD3og]PZ0?oNVB^0_mlK[T2ogaSZ`;oKeVX00?oQ7:fofmL[?m_G:`0
0om[EZP3ofaHZ@?oP5RJ0omfDYX4ohee/`?oU7Ra0_nHNJl2ogAU/`?oQVRY0on3IJP4ohIYZP?oS72_
1?nDN[@01OnMPkKoVmomoi_OoOnKgogoZJ[H00CoY9k?0_nTV//00onPRkgoY8flojB=_002ojB=_0?o
Yi2m1?nXTl000on_Ukgo[iS0ojnH`002ojnH`0?oZi_600?o]9g1ojfMaon]WLL00on]WLL2oj6Od`;o
/:C;1?nOY=T2oh6Vk0;oWZOL1?n3Z^h2of6]n@04ob^RkomLao[oG<Ojoec7nP;oVM_n0omjcOl3oj;G
nP;o]=3^0onUd?H2ojo;kP;oYlgd1On]bNh2ojo4j@;oZlK^0on]a>/2ojW6kPCoZl?/0_n[`^X2ojW3
k0GoZL;[0_nY`N/2ojW2k0?oZL7[00?o0000ojW1jonY`N/00onX`N`2ojS1j`KoZ<7/1?nX`N/5ojS0
j`Wooooo00?o0000ooooooooool03oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000000Gooooo1?l0000^ooooo`CoSkWc0on;_?H2ohNon@?oSlWk0_n;d_l4oioK
o004oikUo?nffo?o]]_cokKKl`;o^L?R1?ni_ml01?nh^MWoZjCAoj^TdOn[Y=43ojBJb`CoWI360onF
Q/43ohim_0?oQWFi0omoKkL3og]]^0;oMfjk0omfM/D4ogeOY@?oNf2X0omjI:h01?mlK[WoSGBbogaS
ZomlHj/3ofmIZ0;oKeb/0om[EZP3ofaHZ@?oNVVc0omfDYX01?m]DIoo^M3[okW@jonid>/2ohV4a`;o
M6Rg0omdIK<3oga]]`CoPfFX0on6JJX3oha`[`;oU7Zd0onRd_T01?nd`^CoZJ[HojVZf?nYZ]P2ojBN
c`;oVhVo1?nPRkd3ojB=_0CoYi2m00CoZ9?0ojnG_On_Ukgo[iNm1On_V<001?n[VlKo]9g1okBM`Ond
WL43ojfMa`03okNTaOn`Y<_o/:C;00?o/:C;0_nOY=T00on^Y]3oWZOLoijWg003oijWg0CoPj[^0omQ
[OT4oenlo@;oN/go0_mj`_d4oi;>o0;oYM3f0_nJc?T4ojO=m0;o[LW^0_nWbO45oj_6kP03ojg4jonY
a^koZLK^00;oZLK^0_n[`n`2ojS4kPCoZL?/0_nY`^/2ojS3k@GoZL;/0_nY`N/00ol0003oZ<7/ojS1
k002ojS1k003ojS2k?nX`NcoZ<7/00OoZ<7/1?nX`N/4ojS0j`Wooooo00?o0000ooooooooool03ooo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Cooooo0_l0
000aooooo`;oSkWc0_nF^o44oi?2m`;oSlWk0onOdOT2oioKo0Co/]Gb00?o]]_cokW3h_ni`n800_ni
`n82okVog`03ojn]e_n[Y=7oZjCA00;oZjCA0onTV//4oif@aP?oUXK11?n>OK`2ohIe^@?oOfng0omk
KKP3ogM^^`;oMWK51OmfRmX3ofJfo004oin;__n=M;;oSGBbohed/P?oO6>[0_m_FJP00omLDJcoKeb/
of]FZ002of]FZ0?oK5RY0omjJK<5oiN=a`04okW@jon9Q<OoRHC7ohV4a`?oM6Rg0_mdIK<3oga]]`?o
QWg200CoPfFXohIYZ_n6JJ[oUYOB1OnO]NL01?nRd_Wo]<;TokC2i?nJTLT3oiV;``CoVhVo1?nPRkd3
ojB=_0?oYi2m00?o[IFnojnG_On_Ukd00on_Ukd3ojnH`003okJN_ondWL7o]9g100?o]9g100Co[Ig7
okNTaOngY<Go]jC51?n`Y</4ojjVd0?oWZOL00?o[JcGoi^/honK[><00_nK[><5ohN`l0?oN[Wj1?mj
`_d2oi;>o0?oS/Ok0onJc?T2ojO=m0;oX<We1?nWbO42oj_6kP?oYlO`0_nYa^h2ojO5k`GoZ<C^0_nY
`n`2ojS4kPCoZ<?]0_nY`^`2ojS2k@?oZ<;/00?o0000ojS1k?nX`^`00onX`^`9ojS1k0;oZ<7[0_nW
`N`4ojS0j`Sooooo00?o0000ooooooooool03oooool002;ooooo00?o0000ooooooooool0;oooool4
oiJkl@;oTl;g0onPao@2oioAn@Co[lk`0_nbeO82okO5i@?o^L?R00?o/KCJojn]e_n_[MH00_n_[MH4
oj^Td@?oY9[;0onMT<H3oiJ6`@CoSWfl0on6MKT3ogm_]`;oNffh0omgK[/3ogIfa@GoMX_J00?oI[Kl
oin;__nORkh00on=M;83ogaSZ`;oKeVX0_mLDJ`01?m_G:coJeJXof]FZ?m[EZP3ofaHZ@?oNVVc1?nG
SLL00omhJ;CoKEj`ofeN/002ohV4a`;oM6Rg0omdIK<3oga]]`?oQWg21?nFUm83oinei`03olOVkOnV
Y=CoVY7900?oVY790onIRl<4oi^9_`?oX8^m1?nTSK`01?nWT;go[IFnojfE__n]UKh4ojnG_@04ojnH
`?nfW[oo]YjookJN_`Co]9g100?o^jK4okNTaOngY<D00_ngY<D3ok2Tb`;o^JW91?n^Y]001?nNYmco
[JcGojf/eon][=L4oi^/h`;oQk3`0_nK/>H5ohjel@?oQ[ch0_n>ao/2oi?1mPCoUlKg1?nPbOD2ojO9
l@?oX/Oc0_nWao02ojC5l@CoYlG_0_nXa>h2ojO4k`GoZ<C^0_nX`nd00onW`ngoZ<;]ojS2k@03ojS2
k@?oZ<;/00Co0000ojS2k?nX`^coZ<;/0_nW`N`6ojS1k0OoYl7/0_nX`>/00onW`>_oooooooooo`07
ooooo`03o`000?oooooooooo00kooooo000Sooooo`03o`000?oooooooooo02oooooo0_nF^o42oj6n
kP?oX<Od0on]and3ojo>l0;o]LGV1?ngaND01?ni`n;o/KCJok6df_na]=X4ojn]eP;oZjCA00CoWYS>
oiR@b_nHT<[oV93:0on@RLP3ohV3aPCoPGo80omjPLl3ogm_]`?oNffh0_mgK[/4ogIfa@;oMX_J0_nd
Z<d3oin;_P?oSGBb0omlHj/3ofmIZ0;oG56/0om[EZP3ofaHZ@?oNVVc1?nGSLL00omhJ;CoKEj`ofeN
/002ofeN/0;oM6Rg0omdIK<3oga]]`CoQWg21?nFUm800onO]NOoYZCDojJTe002ojJTe0?oVY790onI
Rl<4oi^9_`CoX8^m0_nTSK`00onWT[oo[IFnojfE_P02ojfE_PCo[iNm1OnfW[l2okBM`@;o^jK41Ong
Y<D01?n`Y<_o^JW9okVYbOniZLT3ojjVd003okJ]d?n][=Oo[JcG00?o[JcG0_nK[><2ojR^g0CoVk3V
0_n>]O42oibej@CoTkWa1?nC`OH2oiO6m`;oVL7c1?nNa_@2oj;7l`;oXLCa1OnTaO42ojO5k`;oYLC_
1?nWa>l2ojS4kP;oYl?^1?nW`nd2ojS2k@?oYl;]0_nX`^`00ol0003oYl;/ojO1k004ojO1k0;oZ<7/
2?nW`N`6ojO0j`Sooooo00?o0000ooooooooool03_ooool002Cooooo00?o0000ooooooooool0;ooo
ool4oj6nkP03oj37m?n]ango[LO]00?o[LO]00?o[lk`okG5i_neaNH00_neaNH2okO5i@;o/kWN1?na
]=X2ojn]eP03ojBQd_nNV<koWYS>00;oWYS>0onHT<X3oi29b0?oRH?60on1OlP3ogZ1c`CoKX[M0_mC
XoL3ogM^^`;oMWK500?oal[LoinHcOn=Pl<00_n=Pl<3ogY`_0CoSGBb0_mlHj/3ofmIZ0;oG56/0_lj
G</01?m[EZSoK5RYofaHZOm/F:T3ogYY/`?oUhg70omhJ;@3ofeN/0;oJF2e00?oM6RgogAU/omdIK<0
0omlKKL5ohIm`P;oUYOB0onja>83ojJTe0?oVY790onIRl<4oi^9_`;oX8^m0_nQS/44ojNB_`?o[IFn
0on_Ukd2okFN`@Co]Yjo00?o]9g1ok^Va?nkY/@00_nkY/@3okNTa@03okf/b?niZLWo^JW900?o^JW9
00Co[ZK@okJ]d?nf[M3o]Zg@0on][=L00ond/=CoZ:kLojR^g003ojR^g0;oVk3V0_nV/^44oibej@Co
TkWa0_nC`OH2oiZml0CoVL7c0_nNa_@2oio2l@CoXLCa0_nTaO42oj?4l0GoYLC_0_nWa>l2ojK3kPCo
Yl?^0_nW`nd7ojO2k@;oYl;/00?o0000ojO2k?nW`N`02_nW`N`00onW`>coYl3[ojO0j`07ojO0j`Oo
oooo00?o0000ooooooooool03_ooool002Gooooo0_l0000`ooooo`;oXKk^0on[`NT2ojg7k@?o/lCV
0oneaNH2ok>mh@Co/kWN0_na]=X00onXZMOoY:7BojBQdP02ojBQdP?oWYS>0onHT<X3oi29b0?oRH?6
1?n1OlP3ogZ1c`CoKX[M00GoDj?gol[fjoo?i^OocnKWok2_e`04oinHc@?oSH?30_mjL;`3ofiV^@03
ohed/_mlHj_oO6>[00?oKeVX0omLDJ`2ocYLb`CoK5RY0omjJK<00onGSLOoKf^noij?a002ogQX]0?o
KEj`0omYH;D3ogAU/`?oO6fg0_n6OL800ol0003oe>[TomCZi004ok[4hPCoYZCD0onJTLT3oiV;``;o
VhVo00?oVH[2oj6>`OnQS/400_nQS/44ojNB_`Co[IFn00Co[iNmokFN`OneW/7o]Ik11?nfW[l5ok^V
a003okNTaOnm[<So_Jc800;o_Jc80oniZLT00onn/Lgo]Zg@okJ]d003okJ]d004ojf/eond/=Co];3D
okB`e0;oZ:kL0_n_/]X5ojJbh@;oW;GY0_nT]N@4oifhj`CoV[g`0_nI`O<00onM_^ooWl;aoio2l@03
oio2l@;oXLCa0_nR`_04oj?4l0;oYLC_0_nU`^l5ojK3kP;oYl?^0_nV`^h9ojO2k@;oYl;/00?o0000
ojO1k?nW`N`01onW`N`4ojO0k0WoYl3[1_ooool00ol0003oooooooooo`0>ooooo`009oooool00ol0
003oooooooooo`0^ooooo`?oZl7Y0ona`^H4ok?4iP03okG5i_nc_N7o/kgQ00;o/kgQ0_nc^Mh00on/
/=_oZ:WGojRYe`02ojRYe`?oY:7B1?nNV<h3oiR@bP?oT8W80on9PlH3oh5ob0CoNX7?0_m^R]d00omG
dMcob_K[okc4h@04ok2_e`?oWiS=0on=Pl<3ogY`_0?oKVJi0_mSI;d00omlHj_oKeVXofmIZ003oeaA
[0?o>Uc;00?oLmBFokFlgom/F:T00_mjJK<2oh>6cP;oKf^n0_mhJ;@3ofeN/0?oJF2e0om_NLd2oga]
]`;oPkkj00?oSNJ_omCZi?oDj^@00_oDj^@2ok[4hP03oiZMe_n@SLcoT8g<00;oT8g<0on>QlL3oi:7
a0CoVH[21?nQS/43ojNB_`?o[IFn00?o/Ik4okFN`OneW/400_neW/43okJN_`;o_:S61?nkY/@5okf/
b003okVYbOnn/Lgo_[7=00;o_[7=0onf[M001Onk/m;o];3DokB`e?nd/=Co^;KF00Go[k;J0_nV/^42
ojfegPGoY;GT0_nM^>/2ojBhi`CoX;_/0onM_^l2oio2l@;oXKo^1OnR`_02oj?4l0;oY<7^1?nU`^l2
ojK3kPGoY/;^0_nV`Nd6ojO2k@GoYl7/00?o0000ojO1k?nW`N`01onW`N`4ojO0k0SoYl3[1_ooool0
0ol0003oooooooooo`0>ooooo`00:?ooool00ol0003oooooooooo`0^ooooo`03oj_1jOna`^Ko/L;V
00?o/L;V0_nca>H2ok?0h`?o/kgQ00?o[[KOojb`fon//=/00_n//=/4ojRYe`?oY:7B0_nNV<h01?nD
W]_oSY_KohjKfon>Vm/3ohNJg`CoPj3V1Oml[_<2ogC9o`;ob_K[0onla>44ok2_e`;oWiS=0on=Pl<3
ogY`_0?oKVJi0omSI;d3ofmIZ0?oG56/00?o>Uc;oi_=nOne_=l00one_=l3oh>6cP;oKf^n0_mSHK/0
1?mhJ;CoKEj`ofeN/?m]G[03ofUP]@CoKgW=00CoPkkjolCk^_oJo]?of_kC0_oDj^@00onc_>3oVYgF
oiZMeP02oiZMeP?oT8g<1?n>QlL3oi:7a0?oVH[21?nQS/44ojNB_`04ojfE__naW/Co/Ik4ok6Na0Co
]Ik100Co]YjookbXa_nlZ<Ko_:S60onkY/@2okn`b`?o_Jc800?o`KG?okjacOnn/Ld00onn/Ld00onf
[M3o^k?Bok^cdP02ok^cdP04okB`e?nh]]Ko^;KFokRfeP?o[k;J00?o/kKKojfeg_n]]Mh00on]]Mh2
ojBei0;oZ[OR1OnT^>L2oj2kk0;oYK[X1?nR_>`3oj6okP;oX/;`0onS_nd4ojC1kP;oYL;_0onU`Nd2
ojK2kPKoY/7]0_nW`^d8ojO1k003o`000?nW`NcoYl7/00GoYl7/1onW`>`8ojO0j`Gooooo00?o0000
ooooooooool03_ooool002Wooooo00?o0000ooooooooool0;oooool2ok72iP?o/l;V1?nc`><01?nc
_N7o[[KOojjfgon^]]l4ojb`f`;oZ:WG00CoWjWNoiZTfonJY=_oVZCK1?nDW]/3ohjKf`?oQi[O1?n3
X>H2ogb^l`;oS^oT0_njn>h2ol3Dj0Co_<CQ0_n`[mL01?nFSLSoQWk3ohIn`on6O/<3ohf3``;oNW2l
0om^I[T3of=T_@?oKgkB0_mLDJ`2oi_=n@;oengR0one_=l3oh>6cP?oKf^n0_mSHK/3ofeN/0?oJF2e
0om_NLd01?n^joSoa?^jolCk^_oJo]<2olcNiP?o/kcP0onJWMH4oi2=c0?oSXO70onBQl@3oiV:`PCo
XHk10_nWT[l2oj^La`Co/Ik40oneW/400oniZl_o_:S6okbXaP03okbXaP03ok^Va?no/<_o_k3;00;o
_k3;00Co_Jc8ol6ecoo1]Loo`KG?0onn/Ld2ol2hd`?o^k?B00?o_KWFokRfe_nh]]H00onh]]H01?n_
/][o/kKKok>ffonc]]/3ojfegP03ok6hgonZ]n;oZ[OR00?oZ[OR0_nT^>L2ojVii@GoYK[X0_nR_>`0
0onU_>WoY;k/ojBnk003ojBnk0;oXko]0_nU_^`4ojG0k@;oYL7]0_nV`>`6ojK1k@;oY/7/2onW`N`0
1?l0003oYl7/ojO1k?nW`N`8ojO0k0_oYl3[1?ooool00ol0003oooooooooo`0>ooooo`00:_ooool2
o`00037ooooo1?nc`^H2ok?0h`;o/;cS1?n^]]l2ojb`f`03ojB_h?nOZMkoWjWN00;oWjWN0onJY=/4
oiBNf`?oSY_K0on7V]l2oh>PiP04of7ClOn>knCoS^oTohk_i0;o^_S^1?o0e>P2okc4h@03oj>MconF
SLSoUXg800;oUXg80_n6O/<3ogYe`P;oJFo700CoNW2lofiV^Om^I[WoKVJi0_mSI;d5ofmndP04oi_=
nOoGkN;oengRojVYe`?oR8?70_mVI[h2oh>6cP;oKf^n0_mSHK/3ofmca`CoJF2e00GoKgW=ojk[n?nJ
lL;oa?^jom[nd`04olcNiP?o/kcP0onJWMH3oi2=c0?oSXO70onBQl@4oiV:`P;oXHk100?oXiS9oj^L
aon[W<L00on[W<L4ok6Na004okFN`OniZl_o^J_;okV[b`?o_:S600?o_kG@okn`bono/</00ono/</5
ol6ec`03okjacOo0^=?o`;SC00;o`;SC00Co^k?Bokfie_nm^MKo_KWF0onh]]H2okZjfPCo/kKK00Co
[KGNok6hgona^=oo/KSO0onZ]n800on]^N;oZKWUojVii@03ojVii@;oYK[X0_nX^nL4ojFlj@;oY;k/
0_nV_NX5ojFnk0;oYL3]0_nV_n/4ojK0k0;oY/7]0_nV`>`4ojK1k0;oYl7/0_nW`>`6ojO1k003ojO0
k?l0003oYl3/00KoYl3/3onW`>/3ooooo`03o`000?oooooooooo00kooooo000/ooooo`03o`000?oo
oooooooo02oooooo0_nc`^H2ok32i`Co/;cS0_n^]]l2ojNfh`?oY:oP1?nOZMh3oiZTf`;oU9kK0_n=
]O44ohJmn@;oNL[o0_nAjOP2ojodlPCo`=c^0_o0e>P00on][MOoXig?oj>Mc`02oj>Mc`?oUXg80on6
O/<3ogYe`P;oJFo70om^I[T3of=T_@?oKgkB00?oeOkJolSAhOnYZML00onYZML3ohR3a`?oIVJn0_m_
Jkh3of=Q^`;oKg?71OnBY>401?nJlL;oa?^jom_cgooKlml2olcNiP;o[KKO0onHVmH3ohR:cP?oQHG;
0on9Q/X01?n>QlOoTXO4oi:7a?nBQl@2oiV:`P03oiZBb_nSV<WoXiS900;oXiS91?n[W<L2ok6Na0;o
]Jc@1OniZl/01?nlZ<Ko_kG@okned?no]M03okn`b`;o`K_D0oo1]Ll2ol6ne`?o`;SC00?o_koJokfi
e_nm^MH00onm^MH00onh]]Ko^[[JokZjfP02okZjfP;o/kKK0_ne^]d4ok6hg`04ojZgh_n]^N;o[KWR
ojfihP?oZKWU0_n/^n@4ojRki`;oYKcY0_nX_>P4ojJmjP;oYKk/0_nW_^X5ojJoj`;oY/3/00?oY[o[
ojK0k?nV`>`00onV`>`2ojK1k0KoYl3/0_nW`N`5ojO0k003o`000?nW`>coYl3/00goYl3[0_nW_n/5
ojO0j`?ooooo00?o0000ooooooooool03Oooool002gooooo00?o0000ooooooooool0;oooool4ok32
i`;o/;cS0_nY^nH4ojNfh`?oY:oP0_nOZMh2oiRcjP?oU;;/1?n=]O42ohJmn@;oT]gn0_nTkOT4ok[O
lP;o`=c^00?o]K_Nojf]eon][ML00_n][ML3oj>Mc`?oUXg80on6O/<3ogYe`P;oJFo70omOPM`3of=T
_@03ofmnd_oEo][oeOkJ00?ob=7Q0onYZML3ohR3a`?oIVJn0omQIl82of=Q^`?oKg?70onBY>400onJ
lL;oaOkOom_cg`02om_cg`Go[KKO0onHVmH3ohR:cP?oQHG;0on9Q/X3oi2<bPCoVY;:0onSV<T3oj^L
a`03ojj[eOne[=3o]Jc@00?o]Jc@0oniZl/00onk^]So_kG@okned003okned003okn`boo1^mCo`K_D
00;o`K_D00?o`KG?ol6neoo1_]L00_o1_]L01?o0^=?o_koJoknof_no_mX3okfieP03okbog?nj^][o
^[[J00;o^[[J00?o^KkNokFjgOne^]d00one^]d2ok6hg`03ok:kh?n]^N;o[KWR00?o[KWR00?oZKWU
ojbki?n/^n@00_n/^n@2ojRki`03ojZli_nX_>SoZ;cX00?oZ;cX0_nV_NX2ojRmj@CoYkkZ0_nV_n/2
ojNnjPCoY[o[0_nV`>`2ojNoj`OoYl3/00?oYl3[ojO0k?nW`>`01OnW`>`00ol0003oYl3[ojO0j`05
ojO0j`?oYko[0_nW`>/6ojNoj`;oYl3[0_nW_n/3ooooo`03o`000?oooooooooo00gooooo000^oooo
o`03o`000?oooooooooo02oooooo0_n``^L2oj[1jPCoZK_V0_nW]^<00onP^>WoWKGYoifej@02oife
j@CoV;?Z0onD/^`2ohfel@?oTm3m00?oT]gnojC]nOnTkOT01?njgo800onga>Co]K_NokFkgP02okFk
gPCo[JgG0onSWLl3oiJ=b0;oQWk30omjML83ofU_a`CoGh7L00?o?k?dolgofoo=om/00_oGk^<3olSA
h@?oZJWG0_n8PlL3ofIV_P?oHFO20om^PmL3ofmca`03oi:ThOo5o]ooaOkO00?ofo?O0_o9eN84ojff
g`?oV9_F0on8R/h3ohF5b`?oRHK:1?n@S<X3oiZBbPCoXiS900CoZic7ojj[eOn^ZmGo[Z_E1?ne[=00
0oniZl_o^k[Hok^jf002ok^jf0?o_kG@00?o_/7Lol6ke?o1^m@00_o1^m@00onoaMoo`KkGol6ne`02
ol6ne`03okk5gono_m[o_koJ00;o_koJ00?o_KWFokbog?nl_m`00_nl_m`00onj^][o^KkNokVngP02
okVngP?o]K[M00?o][kPok:kh?nb^n000_nb^n02ojfihP;o[k_S1?n/^n@00on]_>GoZ[cVojZliP02
ojZliP;oZ;cX0_nY_NL5ojRmj@;oYkkZ0_nX_^T4ojNnjP;oY[o[1_nW_n/2ojO0k0;oYko[1?nW`>/2
ojO0k0;oYko[0onW`>/01?l0003oYl3[ojO0jonW`>/CojNoj`;ooooo00?o0000ooooooooool03Ooo
ool002oooooo00?o0000ooooooooool0;oooool4oj[1jP;oZK_V0_nR_>/3oj2hj@CoWKGY0_nH/nX2
oiO1m0CoULOh0_nCd?d2oioSo0?o]=gd00?o^]obokO4i?nga>@00_nga>@4okFkgP;o[JgG00CoW9kF
oi2Cdon@Tm?oT9?C0on6Rm43ogZ7e0?oNWG20omYKlL2oen1g003oiW/moo=om_ocOoK00;oenkS00Co
_<OSoj:Xf_nRZ=[oXZSJ0omoQm43ofmgb`?oIVJn0omQIl84ofj3e`03ohk@o_o5o]ooaOkO00;og?[J
00?ofo?OolWEh_o9eN800_o9eN82ojffg`05oiFPfon6SmGoQXoEohJ?eOnHVmH00on8R/h2ohF5b`Co
RHK:1?n@S<X3oiZBbP;oXiS900?oYZSHojj[eOn^ZmD00on^ZmD2okF/d0;o][gO1?nk^]P00ono]M3o
_/7Lokk1g002okk1g003ol6ke?noaMoo_lGO00;o_lGO00?o`KkGokk5gonnaMl00_nnaMl2oknofP;o
_LGQ0onl_m`2ok[3h@Co^KkN00?o]K[MokJnh?nf_^000_nf_^02ok:kh0;o/[kR1?n_^n<00on/^nCo
[KcUojfli@02ojfli@;oZ[cV0_n/_NH4ojVmi`;oZ;gY0_nY_^P5ojRnj@;oYkkZ00?oZ;oZojNojonW
_n/02onW_n/2ojO0j`KoYko[0_nW`>/00onW_n_o0000ojNoj`0BojNoj`;oYl3[0_ooool00ol0003o
ooooooooo`0=ooooo`00<?ooool2o`00033ooooo0_nZ`NX2ojBok@CoX[c[0onP^>T2oifej@;oV[ka
1?nG`O@2oiG7n0;oWMWl0on]f?H2okCMm0;o]l[Y1?nga>@2okFkgP;oYJWJ1?nLW]H3oi2Cd`?oQX_A
0omjQm@3ogVAg`?oPK;d00?oRNcEolgofoo=om/00_oGk^<3okc7h`?oXZSJ0omoQm42ofmgb`;oI7C>
00CoIVJnof5W`_mQIl;oHFO20om^PmL2ok;Hm0;ocOoK0_oLn]X2omW/h@;obMGR0_n`^^43oiFPf`?o
QXoE0omnQm83oh69d`?oRHK:0_n@S<X2oi:Ie`?oWJ;H1?nVZ=P3ojj[e@03ojnniOnf_Moo][gO00?o
][gO0_nk^]P2okW6i@?o_/7L0_njc>L3oko5g`;o^/_W0onnaMl2ok[;i`Co_LGQ00?o_;oLok[3hOnj
`n400_nj`n42okVngP;o^<;R0onf_^02okC1h`Co/[kR0_n_^n<2ok2mi0?o[KcU0_n^_^H4ojbmiP;o
ZKgW0_n[_^L4ojVnj0;oZ;kY0_nY_^T4ojRojP;oYko[0_nX_nXCojNoj`03o`000?nW_n_oYko[013o
Yko[1?nW`>/00ooooooo0000ooooo`0>ooooo`00<_ooool00ol0003oooooooooo`0^ooooo`CoY;o]
0_nR_>/2oijmk`CoW;g`0onJ__42oiO1m0?oVm3j00CoWMWlojgHm_n]f?Ko[MSf0_ncc>d4okO:j@;o
]lCT0_n[/mh4ojFYfP?oW9kF1?n@Tm<2ohJ;d@CoNXOD0omiTMl00on1/_Co]oS^okOhkP02ol_hj@;o
a]_X1?nlan<3oj:XfP;oOhOA0om_Ml/2ofAdcPCoHFO200?oKX?Gok;Hm?nbf?@00_o=om/2omcjfP;o
fNcQ0_o6dn@4ok2jh@;oUJ3K1?n6SmD3ogj7dP;oPHWC0on9T=D5oi:Ie`?oWJ;H1?nVZ=P01?n^ZmGo
[kkUojnniOn__^D3okJmg`;o//[/1?nia^D00onn`Mco^/cWok[<i`02ok[<i`03oko5gonjbnOo^/_W
00;o^/_W00?o_/GOok[;ionjbnL00_njbnL2okg5h@;o^<SV0onj`n400onga^Ko^<;RokS2hP03okS2
hP03okJnh?nd`N?o]<7S00;o]<7S0_nb_^800onb`>Co/;gTok2mi003ok2mi003ojfliOn^_^Ko[[kV
00;o[[kV0_n/_NH00on/_^OoZkkWoj^ni`03oj^ni`;oZKkX0_nZ_^P4ojVnj@;oZ;oZ0_nY_nX4ojRo
jP;oYko[0_nX_n/?ojNoj`03o`000?nW_n_oYko[013oYko[0onW`>/00ooooooo0000ooooo`0>oooo
o`00<oooool00ol0003oooooooooo`0^ooooo`;oY;o]0_nO_^h4oijmk`;oW;g`0_nMa?<4oic9m`;o
Vm3j0onYdOD00on]f?Ko/lc]ok?<k@02ok?<k@;o]l[Y0_n_^^84oj^cgP?oYJWJ0_nLW]H00onBW=Wo
R9SMohRHg@02ohRHg@?oPikU0_mjQm@3ogjam003ohGIoongn>ko]oS^00;oboSY1?o6fnP2okc7h`04
oj2Vf_n:Sm?oRXoCohZ?d`?oKWc@0_m_Ml/3ofAdcPCoNiOS00?o/]Sdolgofoo=om/00_oLn]X2omW/
h@Coa]?T0_n`^^401?nLYmgoQiCJohNDf_n7U=X3ohJ?e@?oOXOB0on1RM<3ohV@e@CoTYWG1?nMX]P2
ojJXf0;oYk_W1?n__^D00onf_Moo//[/ok;:k002ok;:k0;o^LKU0onbd>l2ok[<i`;o/m3_0onjbnL0
0onccnko^/_Wok[;i`02ok[;i`03okC<k?nhb>Ko^<SV00?o^<SV00Co^/?QokO6i_nga^Ko]lKV0_nh
`^82okG4iPCo]<7S00?o//?Vok;0i?nb`>@00_nb`>@2ok2mi0;o[koV1?n^_^H00on^_nOo[;kWojbn
i`02ojbni`;oZkkW0_n[_nP5ojZnj0;oZKkY00?oZKoYojVoj_nY_nX00onY_nX5ojRojP?oZ;o[0_nW
_n/3ojRoj`;oYko[00?oZ;o[ojNojonW_n/01OnW_n/00ol0003oYko[ojNoj`0?ojNoj`CoYl3[00?o
0000ooooooooool03Oooool003Cooooo00?o0000ooooooooool0;_ooool4oinnkP;oW[g_0_nN`?44
oig4l`;oW<Wg0onVc?@2ojWAm@?o/<c^0_ncc>d2ok2oi@Co[k[R0_n[/mh01?nRZ=_oVZ;JoiZRf_nJ
X]X4oi:Lf@CoR9SM1?n3W^D2ogjam0;oY^;k0_nmm?42olSUk0;oa]_X0_nc^n04oj2VfP?oRXoC0_m^
O=03off3f0?oI7C>0_mkUn<2ojSRn`;oc?GZ0_oFm><3om7Si0;oa]?T00?o/KcRoibWgOnLYmd00_nL
Ymd2ohNDfP?oOXgH0omlSMT01?mnQm;oPHWCoh69don1RM<3ohV@e@;oTYWG00?oUJcVoinej?nO]NP0
0_nO]NP5ojNki`;o[kkU0_n/bo02ok;:k0?o[=?d0_nbd>l2oj_Cm@Go/m3_00Go^/_Wok??k_nccnko
/lo^ok[;i`04okC<k0;o^<SV0oncb^/2okO6iP;o/lOY1?nea>H00ond`N?o//?Vok;3iP02ok;3iP;o
//3T0_n``^L4ojnoiP03ojjni_n^_nOo[[oW00;o[[oW0_n/_^L2ojboj0CoZkoX0_nZ_^P2ojZoj@Co
ZKoY1?nY_nX9ojRojPSoZ;o[1onW_n/00ol0003oYko[ojNoj`0?ojNoj`;oYl3[00?oooooo`000?oo
ool03_ooool003Gooooo0_l0000_ooooo`GoWkk^0onN`?42oig4l`?oY<Ob0_nVc?@3ojc9k`;o/<c^
0_n``^L4ok2oi@;o[k[R00?oYjoNoj:XfonRZ=/00_nRZ=/3oiZRfPCoTYcI0on8V=d2oh>Ni@?oUlOh
00?oY^;kokgdlOnmm?400oo8iN`2okk>iPCo/k_P0onPY]X3ohZ?d`?oKWc@0om]PmP4ognTj`03ojSR
noo<mN[oc?GZ00;oe_CS0ooAhn@00oo4dNCo/KcRok6lhP02ok6lhPCoW:OM0_n7U=X3ogj=f0?oO8gI
0on1UMd4ohbQhP?oUJcV1?nO]NP2ojNki`?oY/Wb0_n/bo03ojKCm`;o[=?d0_nVe?P4oj_Cm@;o/m3_
0on/d_@2ok??kP?o[Lob0_ndc>`2ojk<k`?o/l[[0_n_b^d4ok?7j@;o]LCV0onbaNT2ok;3iP;o/<CX
1?n``^L2ojnoiP?o[l7W0_n^_nL2ojg1j0Co[;oX0_n[_nP2oj_0j@CoZ[oY0_nY_nT2oj[0jPCoZKoZ
1onX_nX2ojS0j`SoZ;o[1_nW_n/00ol0003oYko[ojNoj`0=ojNoj`Kooooo00?o0000ooooooooool0
3?ooool003Oooooo00?o0000ooooooooool0;_ooool2oinnkP;oXko]1?nS`^l2ojC7lP;oZ/K^0on/
bNl2ojk3j@Co/<;W0_n`_nD2ojZeh@?oYjoN1?nRZ=/3oiZRfP;oTYcI0_nB[>P4ohndk`;oUlOh0_nZ
ioX3okgUlP03olSUk?nnc^Ko_/kV00;o_/kV0onc^n04oj2VfP?oRXoC0_m^O=04off3f0;oOjC[0onb
fO@01?o;kncodNWVom7Yi_oAhn@4olCAi0Co/KcR0_nLYmd01?n?WmooP9CMoh2DgOn0U=d3ogj=f0?o
O8gI0on1UMd4ohbQhP?oUJcV0_nO]NP3oj35lP;oY/Wb0onSd_P2ojKCm`;oXmGi1?nVe?P2oj_Cm@?o
YM?h0_n/d_@3ojO@mP;o[Lob0_nXc_<4ojk<k`03ok?:jon_b^go[l[]00;o[l[]0_ncanT2ojo8k0?o
//GY00?o[lK[ok34j?n`a>P00on`a>P2ok32i`03ojo3jOn_`NOo[l7W00;o[l7W00?o[L;Yojg1j?n]
`NP00on]`NP2ojboj003ojc1jOn[`>WoZl3Y00?oZl3Y0_nZ_nT00onZ`>WoZ/3Zoj[0jP03oj[0jP;o
ZKoZ0onY`>X2ojRojPKoZ<3[2?nX_n/6ojNoj`03o`000?nW_n_oYko[00WoYko[2Oooool00ol0003o
ooooooooo`0<ooooo`00>?ooool00ol0003oooooooooo`0^ooooo`CoXko]0_nS`^l2ojS3k@CoZ/K^
00?o[<W_ojk3jOn^`nT00_n^`nT2ok32i`;o[;[S1?nZ]N43ojN_gP;oXZSK00?oVjcRoiFYi?nEZN@0
0_nEZN@4oi:/j0;oSkC_0onNe?/01?nZio[o_NGbokgUl_nmiO83okkHk@;o_/kV00Co[KWRoinYg_nO
ZMkoWjWN1?n;VM/3ogn@fP?oM93O0_m]PmP2ohR]k@?o/]Wd00Gobno/om7Yi_oAjNKodNWVolgOiP03
olCAi003okC1i?nO[^;oWjkR00;oWjkR1?n?Wml2oh2Dg@?oO9?O0omoV^<4ohNUj0?oTK;]1OnI_?02
oj35lP?oXLoh0_nSd_P00onReO[oXmGioj?En@03oj?En@;oY]Ch0onRe?T2ojGCn0;oX]3h0_nWd?H2
oj?>mPGoZ<kc0_n^c>l2oj[;l@;o[l[]0_n[bNl5ojo8k004ok;5jOn_a^_o[lK[ojo6j`;o/<CX0_n^
aN/4ojo3j@03ojo1ion]`^Wo[L;Y00;o[L;Y0_n]`NP2ojc2j@Co[<7Y0_n[`>T2oj_1jPCoZ/3Y0_nZ
`>X5ojW0jP;oZL7[2?nX`>/8ojRoj`OoYko[00?o0000ojNojonW_n/01OnW_n/<ooooo`03o`000?oo
oooooooo00cooooo000iooooo`03o`000?oooooooooo02kooooo0_nS_nd2ojO0j`CoZ<?]0_nZa^h3
ojg3jP;o[/?Y0_n/_>D4ojbjh`;oZ[GQ00?oY;?Soj2_h_nP[n800_nP[n83oi^/hPCoUJWT0_nB[>P3
oiW4mP;oW]Ck0oncg_H01OnmiO;o_]S]okkHkOnnf>go]<GV00Co[KWR0onOZMh4oh^If`?oOi3J0omd
T=l4ohR]k@03ok;Im?o;kncodNWV00;odNWV0oo=gnH01?o4dNCo]<7TokC1i?nd`N@4oin^hP?oSioO
0on0U=d3ogbCg`?oOi[S1?n7YNP3oi6bk@;oVKc`0onMbOL2oj7?n0;oX]?i1?nReOX2oj?En@?oXMCj
0_nRe?T3oj3An@;oX]3h0_nPc_L4oj?>mP;oZ<kc0onUbo@2oj[;l@;oYl[b1?n[bNl2ojo8k0?o[<O^
0_n_a^/2ojc6k@Co[/G[0_n_`nT3ojg4jP;o[L;Y0_n/`n/4ojc2j@;o[<7Y0_n[`^X4oj_1jP;oZ/3Y
0onZ`NX2ojW0jPKoZL7[2?nX`>/2ojRoj`;oZ<3[1?nX_n/7ojNoj`03o`000?nW_n_oYko[013ooooo
00?o0000ooooooooool03?ooool003[ooooo0_l0000_ooooo`CoYl3[0_nX`nd3ojc2jP;o[L?Z0_n]
_nL4ojbli@;o[;[S0_nW]n@3ojBch`CoX:oR0onK[>82oiFYi0?oUk[`0_nIa?H3ojSDm`;o/mkf0onj
fo001?nnf>go]<GVokC5i_ndaNH4ojfihP?oWjWN0on;VM/3ogn@fPCoM93O0_n8[Nd01OnXe_So_n;a
okoRlOnoh_7odNWV00?ocMoV0_o1d>H4okC1i0;oWjkR00CoU:KRohRMhOn8WN7oR9gQ0omoVN801?n0
U=goO9?OogbCgomlTml3ognJh`;oQjGX0_n>]O44oiO1m0;oWLWg0_nQd?P4oj;Cn@;oX]Gj0onRe?T2
oj7DnP?oXM7i0_nPdOT3oj3>n0?oX<kg0_nSc_H3oj;;m@;oYL_d0_nSbO<4ojO:lP;oZlW_0onXb?02
ojc7kP;oZ/O_1?n/a^d2ojk5j`;o[<G/0on]a>X00on/a>co[<?[ojc3j`03ojc3j`;o[<;Y00?oZl?[
oj_2j_n[`^X00on[`^X2oj_1jP;oZl;[0_nZ`NX2ojW2j`SoZL7[3OnX`>/2ojRoj`SoYko[00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`00??ooool00ol0003oooooooooo`0]oooo
o`;oYl3[0_n[`NX3ojc2jP;o[<3X1?n]_nL2ojbli@;oZK[V1?nW]n@3ojBch`;oX:oR0_nM]>P4oiZf
j`;oUk[`0_nRbO@3ojSDm`?o/]Sd0_njfo02okO=jPCo]<GV0_n]^N800onOZmooU:7MoiBQg@02oiBQ
g@?oQ9WO0on3W^D4oh^ak`04ojSFn?noh_7o_n;aokoRl@?oa^;/00?ocMoVol7@i_o1d>H00_o1d>H2
okC1i0;oY[GS0onDY^83ohRMh@?oOiWR0omoW^H4ohJYj`CoS[Ga0_nG`O@2oig:m`CoXM3h0_nRdoT3
ojCDn@;oX]Ci0onSd_P2oj7An@?oX/og0_nPc_P00onQboKoX<_foj3;mP03oj3;mP;oX/_e00?oXLWd
oj?9lonSbO<00onSbO<2ojO:lP?oYLSb0_nXb?000onWao3oZ/O_oj[7k`03oj[7k`;o[<K]00?oZ/K^
ojc5k?n/aN`00on/aN`01?n]a>[o[<C/ojc4k?n/a>`2ojc3j`;oZlC/1?n[`n/2oj_2jPGoZl;[0_nZ
`^/4ojW2j`SoZL7[3?nX`>/6ojNoj`Gooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0<ooooo`00?Oooool00ol0003oooooooooo`0]ooooo`CoZl7Z00?o[<;Zojc0j?n/`>P00_n/`>P2
ojfoi`;oZ[gW1?nY^^H2ojNgi003ojBhionQ]^OoXKKW00;oXKKW1?nM]>P2oiZfj`;oWl;a1?nRbO@0
1?nXe?Oo/]Sdok;Hm?nbf?@2okC?kPCo]lgZ0_ndaNH2ojVfhP?oWj_O1?nDXMd3ohBIg`?oPikU0_n;
/Nl3ojW>l`04okoRlOo6h^coa^;/olKRk0?o`mSY0_o1d>H2okC3i@CoY[GS0onDY^83ohRMh@?oOiWR
0omoW^H4ohJYj`;oS[Ga0onF`O@3oig:m`;oXM3h0onTd_P2ojCDn@?oYM;g0_nSd_P2ojC?mP;oX/og
0_nSc?D4oj7;mP;oX<_f1_nQbO@2oj?9l`?oXlOc0_nUb?82ojC7l@CoYlO`0_nZanl2ojS6k`CoZ/K^
0_n/aN`3oj[5k@;o[<C/0_nZa>d4oj_4k0;oZl?[0on[`n`2oj_2j`;oZ/?/1?nZ`^/2ojW2j`;oZL;/
1_nY`N/2ojS1j`coZ<3[0_nW_n/9ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3?ooool003kooooo00?o0000ooooooooool0;Oooool2oj_1jP?o[<7Y0_n/`>P2oj^oj0CoZ[gW0_nY
^^H2ojJji`?oY;SW1?nQ]^L2oifdj0;oWkk_1?nO`_42oj;9m0?oZm;e00?o/]SdokC?k_ndcnh00_nd
cnh2okO=jP;o[koU1?nY]^83oin[g`;oU:7M00?oT:KToh^Xj?n;Z>P00_n;Z>P4oiBgk`;oZLkc0_ni
fo42okoIk@?o`mSY0_nlc^P4okC3i@;oY[GS0_nM[n@3ohnUi0?oQj7U0on4XnP3ohN[k0CoSkKa0_nF
`O@2oig8mPCoX/og0_nTd_P3ojKBmP;oYM;g0onWd?H2ojC?mP;oYLgd1?nSc?D2oj7;mP?oX/Wd0_nQ
bO@6oj;7l`;oXlOc0_nSa_84ojC7l@;oYlO`0_nVa_04ojS6k`;oZ/K^0onYaNh2oj[5k@;oZLG^1?nZ
a>d2oj_4k0?oZ/C]0_n[`n`00onYa>goZ/?/oj[3k003oj[3k0;oZ/;[00?oZL?/ojW2k?nY`^`00onY
`^`2ojW1j`03ojS2k?nX`N_oZ<7[00?oZ<7[0_nX`>/2ojS1j`;oZ<3[4?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00cooooo000oooooo`;o0000;oooool2ojc1j@;oZ/7Z1?n[_nP2
ojZmi`;oYkcX1?nV^^L3ojBhi`;oXKKW0_nQ_>`4oinnk`;oWl;a0onVc?@2oj_Bm@?o/Lo`0_ndcnh2
ok75j@Co[koU0_nY]^82oj2`h`?oUjWS0on@Y^@4oh^Xj0;oU;O_0onUbo@00onifo7o_mW]okoIk@02
okoIk@03ol?HjOnlc^So_<kX00;o_<kX0_nd`nD00onY^^KoWJoToif_i003oif_i0?oSjGT0on7XND3
ohBSj0?oQj_/0_n?]_42oiO0m0CoWLSf0_nRcoL3ojK@mP;oY];f0onXd?D2ojO@mP;oYlgd1?nUcO@2
oj?<m@?oY<Wc0_nRbO@2oj?7lPKoX/Oc0_nRa_84oj?6lP;oY<Oa0onTaO43ojK6l0;oZ<K_0onWaNl2
ojW5kP03ojS5k_nYaNkoZLG^00?oZLG^0_nZa>d2ojW4k@;oZ/C]1_nYa>d2oj[3k0;oZL?]1?nY`n`2
ojW2k0KoZ<;/0_nX`N/3ojS1k0;oZ<7[5?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00_ooooo0011ooooo`03o`000?oooooooooo02gooooo1?nZ`NX2oj^oj0;oZ;kY1?nW_>P2ojJj
i`;oY;c[1?nR_>/3oj6lk0;oWkk_0onSa_82ojK<m0?o[<ga0_naco02ok78k0Co/LGY0_n__nD2ojNg
i0CoX;3S0onGZN<3oi2Vi0;oRjSX0onG^_02ojG;m0?o/];a0_nofNd2okkDj`;o_<kX0_nca>L4ojVj
iP;oWJoT0_nH[ND3ohfWiPCoRJSY0on:[Nd4ohnfl@?oUl3d0_nMb?H3oj?<m@;oY]3f0onXco@2ojS@
m@;oZLkc1?nWcO@2ojG=m0?oY/[c0_nTbO<00onTao;oXlOboj?7lP03oj?7lP;oX/Oc0_nRaO44oj;6
lP;oXlKb0_nSaO42ojC5l@;oY<C`1?nUaO02ojO5k`;oY/G_1?nXaNh2ojW5kP?oZ<G^0_nYa>d2ojS4
kPSoZLC]1?nY`nd2ojW3k0?oZ<?]2?nX`^`2ojS1k1Sooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0;ooooo`00@_ooool00ol0003oooooooooo`0]ooooo`;oZ/7Z0_nX`>/4ojRnj@;o
YkcX0_nU_N/4ojBlj`;oX[c[0_nR`Nl4oj;3l0;oXlKb0onXbO42ojc=l@;o[/W^1?nab>`2ok75j@;o
ZkcV1?nW]n@2oj2`h`03oib_iOnF[NOoUZgW00;oUZgW1?nD/>X2oiNjl0;oYLOa0onbd_42okODk`;o
_]C[0_nhc>T4ok?4i`;oZK[V0_nQ]>H4oiR]i@?oSJOV1?n9Z>T3ohZ]k@;oSkKa0_nG_O84oik6m0;o
Xlce0onVcO@2ojS?m003oj[>lonYc_?oZLkc00?oZLkc0_nWcO@2ojS;lP;oY/[c0_nVb?44ojC7lP;o
XlOb0onSaO42oj;5l@;oXlC`1?nSa?42oj?5l@;oXlC`1?nTa?02ojG5l0;oYLC`1?nVaNl2ojS5kP?o
YlG_0_nXaNh00onWa>koZ<C^ojS4kP03ojS4kP;oZLC]00?oZ<C^ojW4kOnYa>d00onYa>d2ojW3k@Ko
Z<?]1?nX`^d2ojS2k1gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`00
@oooool00ol0003oooooooooo`0]ooooo`CoZ<3[0_nX_^T2ojJnj`CoYKg[0_nT_>/2oj>ok@CoX/7_
0_nR`o03ojK6l0;oZ<Wa0_n/b>l4ojk9kP;o/LS/0_n]`NP4oj^liP;oYkOT00?oXK;Toib_iOnL[nD0
0_nL[nD4oiJ]i`;oU;3Z00?oWKg_ojG7lOnUao400onUao400onbd_7o]mC_okODk`02okK?k0Co^<cY
0_nca>L2oj^miPCoXKCV0onH[ND2ohfWiP;oSjcY0on>[n`3oi6ek`GoUkgb0_nNa_@2oj?9l`;oY/gd
0_nXc?<4oj[>l`;oZLkc0onYc?82ojS;lP?oZ<Sa0onVb?42ojC7lP?oYLG`0_nSaO42ojC4l0CoXlC`
0_nSa?42oj?3l0CoXlC`1?nTa?04ojG4l0;oY/G_0_nVa>l2ojO5k`;oYlC_1?nWa>h8ojS4kP;oZLC]
0onXa>h8ojS3k@;oZ<;]8?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
0014ooooo`03o`000?oooooooooo02gooooo0_nX`>/2ojJok0CoY[k[0_nU_N/2ojBok@CoXko]0_nR
`Nl3ojG4k`;oY/K`0_nYanl4ojc8k`;o[/W^0on]`nX3ojg1j0;oZkcV00?oY[OUoj6bi?nQ/^@00_nQ
/^@3oib_i@;oUZgW0_nJ]^`4oifmk`;oYLOa0on^c_400onge>oo]/o/okK?k002okK?k0;o^<cY0onb
aNP3oj^miP;oXKCV0_nL/^L3oiJ^j0CoSjcY0on>[n`3oi6ek`;oUkgb0onM`o<2oj?9l`;oY/[b1?nX
c?<2oj[>l`?oZ/ca0_nYc?83ojW9l0;oZ<Sa00?oZ<O_ojO6l?nWa_000onWa_02ojG5l003ojG4konT
a?3oY<C`00?oY<C`0_nSa?000onT`nooXl?`oj?3l003oj?3l0;oXlC`0_nT`nl4ojC4l0;oYLC`0_nU
a>l4ojK4k`CoYlC_1?nWa>h;ojS4kP03ojO4k_nX`ngoZ<?]00GoZ<?]9?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00_ooooo0015ooooo`;o0000;oooool3ojJok0;oY[k[0onT_n`3
ojBok@;oXko]0onU`^h2ojG4k`;oYlG_1?nYanl2ojc8k`?o[<C[0_n]`nX01?nZ_^SoZK_VojVki_nY
^nH4ojJgi@;oXK;T0_nN]>L4oibdj@?oV[K/0_nM_Nl3ojG6l@;o[/ka0onbc^h2okK?k0;o/lW[0onb
aNP2oj^oj0?oYKWW1?nL/^L3oiJ^j0;oSjcY0_nC/N`3oiBfkPCoV;ca0_nM`o<2oj;6lPCoY/[b0_nX
c?<3oj[;l@;oZ/ca0on[b_02ojW9l003ojW7konXanooZ<O_00;oZ<O_0_nWa_02ojO5k`CoYLC_0_nT
a?03ojG3k`?oY<?_0_nS`o07ojC3k`CoYL?_1?nUa>l4ojK4k`;oYlC_0_nVa>l4ojO4kP;oZ<C^0onW
a>h2ojS4kPGoYlC^0_nX`ndYooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02ooo
ool004Oooooo00?o0000ooooooooool0;Oooool4ojFok0;oY;o/0_nU`>d4ojC1k@;oYL;^0_nV`nh4
ojO5k`;oZLO_0_n[a>`3ojc4j`03oj_0jOnZ_^SoZ[kX00;oZ[kX0onY^nH2ojJgi@;oX[KW1?nN]>L2
oibdj@;oWk[/1?nP_nl2ojG6l@?o[<[`0_nbc^h2ok;<k@Co/lW[00?o//GXoj^oj?n[_nP00_n[_nP3
ojFii`;oW;;W0_nJ/^P3oiJ`j@CoTk7/0onD]^h2oiRll@;oWL7a1?nRa_82ojK:lP?oZ<[a0_nZbo42
oj[:l0;oZl[`0_nZb>l4ojW7k`;oZ<O_0_nXaNh4ojO5k`;oYLC_0onV`nh2ojG3k`;oYL?^1_nT`nl2
ojG2kPCoY<?_0onU`nl5ojG4k`SoY/C_0_nWa>h2ojO4k`[oYlC^;?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00_ooooo0018ooooo`03o`000?oooooooooo02gooooo1?nU_n`4ojG0
k@;oY<7]0_nV`^d4ojK3kP;oYlG_0_nY`nd4oj_4k004ojc4jon[`>WoZl3Yoj_0j@;oZ[kX0_nW^nL4
ojFii`?oX[KW0_nN]>L2oinhjPCoWk[/0_nP_nl2ojK5k`?o[<[`0_n^bnh4ok;<k@;o/lW[0on_a>T2
oj^oj004ojJkj?nQ]^OoXKKWoj6fi`GoV[;X0onF/>T2oi>ak003oiNgkOnI^nooVK__00?oVK__0onM
`O42oj;6lP;oYLOa0_nXb_43ojW9l0;oZ/[`0_n[b>l4oj[8k`;oZLO_0onYa^h3ojS5kP;oYlG_0onW
a>h3ojK3kPGoYL?^0_nT`nl6ojG2kP;oY<?_00?oYL?^ojG3konU`nl00_nU`nl2ojG4k`?oY/?_0_nV
a>l2ojK4kPSoYlC_1_nWa>h`ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02ooo
ool004Wooooo00?o0000ooooooooool0;Oooool4ojFok0;oYL3]0_nV`Nd4ojK2k@;oY/?^0onX`nd3
ojW3k@;oZlC/0_nZ`NX2oj_0j@;oZKgX1?nW^nL2ojFii`;oXkWX0onQ^>T4oinhjP;oWk[/0_nS`>h4
ojK5k`03ojc:l?n^bnko[/_^00;o[/_^0_nbc>d3ok37j`;o[lCY00?oZkoYojJkj?nV^nP00_nV^nP3
oj6fi`;oV[;X0_nJ]>X3oiRdj`CoUkO]0_nI^nl2oifol0CoXL?a0_nUao42ojO7l0?oZLW`0_nZb>l4
oj_8k`;oZ/S_0onZanh2ojW6kP03ojW5k_nXa>koZ<C^00?oZ<C^0_nWa>h00onW`ngoY/?^ojK3kP02
ojK3kP;oYL?^0_nV`^h9ojG2kP?oYL?^0_nU`nl3ojK3kP;oY/?_0_nV`nh4ojK4kP;oYlC_00?oYlC^
ojO4konWa>l00onWa>l2ojO4kSCooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:
ooooo`00B_ooool2o`0002kooooo0_nU_n`2ojJok0CoY/7]0_nV`^d3ojO2k0;oZ<?]00?oZL7[oj[1
jonZ`N/00_nZ`N/2oj[1jP;oZKkY1?nY_NP2ojNki`;oYK[X1?nS^NP3oj6hj@;oWkSZ0_nQ_Nd4oj?0
kP;oY/G_0onZb>l2ojk;kP;o[lS]0_n`an/2ojg3jPCoZkoY0_nV^nP2oj>ij0?oWkKY1?nJ]>X3oiRd
j`;oUkO]0_nK^nh4oifol0;oXL?a0onTaO03ojO7l003ojW9l?nZb>ooZ/S_00;oZ/S_0_n[b>l5oj[7
kP03oj[5k_nYaNkoZLG^00;oZLG^0_nXa>h2ojS3k@CoYl?]0_nV`nh3ojK2k@?oY/;^0_nU`^h3ojK2
kP;oYL;^1_nV`^h8ojK3kP;oY/C^1OnWa>h2ojO4kcWooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0:ooooo`00C?ooool00ol0003oooooooooo`0/ooooo`CoY[o/0_nV`Nd3ojO1k0;o
Yl;/00?oZ<7[ojW1jonY`N/00_nY`N/2oj[1j`;oZKoY1?nY_^T2ojVmj0;oYkcX1?nU^^P2oj>ij0;o
Xk_Z1?nR^n/3oj6mk@;oXl3^0onWa>l2oj[8k`;o[<S^0_n_b>d2ojg5k0Co[L?Z0_n[_nT2ojNmj@Co
XkWX0onO]^T2oiZdjP;oVkK[1?nJ^>d3oi^kkP;oWKo`0onQ`_02ojC5l0;oY/K`1?nXao02oj[8k`;o
Z/O_0_nZanh2oj[6kPCoZ/G^0_nYaNh2ojW4k@CoZ<?]0_nW`nd3ojO2k@;oY/;]00?oYl;]ojK2kOnV
`^d00onV`^d2ojK2kP03ojK2kOnV`^koY/;^00KoY/;^2OnV`nh5ojO4kScooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0:ooooo`00COooool00ol0003oooooooooo`0/ooooo`;oY[o/
0onW`>/2ojO1k0GoZ<7[0_nY`N/2ojW0jPCoZKoY0_nY_^T2ojRmj@CoYkcX0_nU^^P2ojBkj@CoXk_Z
0_nR^n/2ojBok@CoY<7^0_nWa>l01?nYa^ko[<S^ojc8k_n/b>h2ojg6k@Co[LG/0_n]`nX2oj[0j@Co
YkgY0_nS^NP2oj6ij@?oW[OZ1?nK]^/2oiZhk@;oWK_^1?nN_^l2oj72l003ojC3l?nVa_3oY/K`00?o
Y/K`0_nXao02ojW7k`;oZ/O_1_nZa^h2oj[5kP;oZLG]1?nYa>d5ojS3k@OoYl;]2?nV`^d2ojK2kP;o
Y/;]1?nV`^h7ojK3kT?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`00
C_ooool00ol0003oooooooooo`0]ooooo`;oYl3[00?oZ<3[ojS1jonX`N/01?nX`N/2ojW0j`CoZL3Z
0_nY_nT2ojRnj@CoZ;gY0_nW_>P2ojFlj@CoY;_Y0_nS^nX2oj>nk0CoY;o]0_nT`Nh00onWa>koZLK^
ojW6kP02ojW6kP03ojc8k_n]a^go[LK]00;o[LK]0_n]aN`2oj_2j`CoZ/3Y0_nW_NT2ojFkj@CoXKWY
0onN]nX2oi^fj`;oWKW/1?nM^nh2oijnk`03oj71konT`o3oY<?`00;oY<?`0_nVa_03ojO6k`;oZLO_
0_nYa^h6oj[6kP?oZ/G]0onYaNd2ojW4k@GoZ<?]00?oZ<;]ojO2kOnW`^d01_nW`^d<ojK2k@;oY/;^
0onW`^d2ojK3kTOooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`00Cooo
ool2o`0002kooooo0onX`>/2ojS1j`;oZ<3[1?nY`>/2ojW0jP;oZ;oZ1?nX_^T2ojRmj@;oY[gY1?nU
_>T2ojBkj@;oY;g[1?nS_^`2ojBok@;oY/;^0onWa>h2ojW6kP?oZlK^0_n]a^d2ojc4k0CoZl;[0_nZ
`>T2ojNnj@CoYK_Y0_nQ^NT00onQ^N[oW[W[oijij`03oijij`?oWKW/0_nM^nh00onO_^koXL7_oj71
k`02oj71k`;oY<?`0onUa>l2ojO6k`;oZ<K_1?nYa^h2oj[6kP?oZ/G^0_nZaNd5ojW4k@CoZ<?]1?nX
`^d8ojO2k@;oY/;]0onW`^d2ojK2k@OoYl;]C?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00[ooooo001Aooooo`03o`000?oooooooooo02cooooo1onX`>/2ojW0j`KoZ;oZ0_nX_^T3
ojNnj@?oY[gY0_nU_>T3ojFmj`?oY;g[0_nS_^`2ojG0k@;oY/;^0_nW`nh4ojW5kP;oZlK^0_n[a>`4
ojc4k0;oZl;[0onY`>X3ojNnj@;oYK_Y00?oXk_Zoj6ij_nQ^NX00_nQ^NX2oijij`;oWk_/1?nO_>d3
oinnkP;oXL7_0onS`^l2ojG4k`;oYlG_1?nXa^l4ojW6kP;oZ/G^0_nYaNd6ojW4k@KoZ<?]1OnX`^d5
ojO2k@;oYl7]2_nW`^e?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool0
05;ooooo00?o0000ooooooooool0:oooool9ojS0j`CoZ;oZ1?nW_^X2ojNnj@;oY[kZ1?nV_NX2ojFm
j`GoYKo/0_nU`>d2ojK2k@CoYl?^0_nYaNh2ojW4k@CoZlC/0_n/a>`3oj[2j`;oZL3Z00?oYkkZojFl
j_nU_>X00_nU_>X3oj>kjP;oXKWZ0_nQ^^/4oinkk0;oWkc]0_nQ_^h4oj;0kP;oXl;_0_nU`nl4ojO5
k`;oZ<K_0_nXaNh2ojW6kP;oZLG^1?nYaNd4ojW4k@KoZ<?]1OnX`^d5ojO2k0;oYl7]0_nW`N`6ojO2
kE?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`00Doooool00ol0003o
ooooooooo`0[ooooo`OoZ<3[0_nX_n/4ojRojPCoYkkZ1?nV_^X2ojJmjP03ojFnjonU_ncoYKo/00Co
YKo/0_nV`Nd4ojK2k@;oYl?^0_nXa>d4ojW4k@;oZlC/0onZ`n`2oj[2j`03ojS0jonW_^[oYkkZ00;o
YkkZ0_nU_>X2ojBljPCoX[_[0onQ^^/2oinkk0;oXKg]1?nQ_^h2oj;0kP;oXl7^1?nU`nl4ojO5k`Co
Z<G^1?nYaNh2ojW5k@KoZLC]1?nX`nd4ojS2k@SoYl;/1?nW`N`2ojO2kEOooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`09ooooo`00E?ooool2o`0002gooooo1?nX`>/4ojRoj`;oZ;oZ
0_nW_n/4ojNnjP;oY[kZ00?oY[o[ojFnjonU_^/00_nU_^/2ojFok0;oY/3/1?nV`Nd2ojK2k@?oYl?]
0onXa>d2ojW4k@?oZL?/0_nZ`n`00onY`N_oZ<3[ojS0j`02ojS0j`;oYkkZ0_nV_NX4ojBljP;oX[_[
0_nR_>/4oj6lk0?oXKg]0_nQ_^h3oj;0kP?oXl7^0_nU`nl2ojK4k`;oYlG_1_nXaNh5ojW5kPGoZLC]
1?nX`nd6ojS2k@SoYl;/0_nW`NaJooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2Oooool005Kooooo00?o0000ooooooooool0:oooool4ojS0j`;oZ;o[1_nW_n/2ojNnjPGoY[o[0_nU
_^/6ojK0k0;oY/7]0onW`^d2ojO3k@;oZ<?]1?nY`nd2ojW3k003ojW2k?nY`N_oZL7[00;oZL7[0_nX
`>/2ojNnjPCoY[gZ0_nT_>X2oj>lj`CoX[c[0_nQ_>`00onR_NgoX[k]oj:nk@02oj:nk@;oX/3^0_nT
`Nh4ojG3k`;oY/C_0_nWa>l9ojS5kP;oZLG^00?oZ<C^ojS4kOnXa>d00_nXa>d4ojS3k@KoZ<;]0onW
`^d5ojO2k5kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`00Eoooool0
0ol0003oooooooooo`0[ooooo`;oZ<3[0_nW`>/9ojNoj`CoY[o[0onV_n`5ojK0k0?oY/7]1?nW`^d4
ojS3k@;oZL?]1OnY`^`2ojW1j`?oZ<3[0onW_^X2ojJmjP;oYKg[1?nS_>/2oj:lj`03oj>mk?nR_Ngo
X[g]00;oX[g]0_nR_^d2oj?0kPCoY<7^0_nU`nl2ojK3k`CoYlC_1_nXaNh6ojS4kP;oZ<C]1_nX`nd2
ojS2k@CoYl;]I_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo001Hoooo
o`03o`000?oooooooooo02cooooo0onW`>/7ojNoj`OoY[o/0_nV`>`4ojK1k0;oY/7]1_nW`^d2ojS3
k@03ojS2k?nY`^coZL;/00CoZL;/0onX`N/2ojS0j`;oYko[1?nV_^/3ojFmj`;oXkc[0_nS_N/3oj>m
k0;oX[g]0_nS_nd4oj?0kP;oY<7^0onU`^h3ojK3k`;oYlC_0_nWa>h4ojS5kPWoZ<C^1OnX`nd2ojO3
k@;oYl;]J_ooool01Ol0003ooooooooooooooooo000000_ooooo001Iooooo`03o`000?oooooooooo
02cooooo1?nW`>/2ojNoj`OoY[o/1_nV`>`2ojK1k0;oYl7/1_nW`^d5ojS2k0;oZL;/0onX`N`2ojS1
j`;oYl3[1?nW_n/2ojJnj`03ojFnjonT_N_oY;g[00;oY;g[0_nS_N/2ojBnk0CoXkk]0onS_nd2oj?0
kP?oY<7^0_nU`^h00onU`nkoY/C_ojK4k`02ojK4k`CoYlC^1?nXaNh7ojS4kP03ojO4k_nW`ngoYl?]
00CoYl?]KOooool01Ol0003ooooooooooooooooo000000_ooooo001Jooooo`;o0000;Oooool2ojO0
j`;oYl3/1OnV_n`8ojK0k0KoYl7/0_nW`^d2ojO2k0CoZ<;/1_nX`N`2ojS0j`CoYl3[0_nW_n/00onV
_^_oYKk[ojFnj`02ojFnj`;oY;g[1_nT_^`2oj>nk@;oY;o]1?nT`>h2ojC1kP03ojG2k_nU`nkoYL?^
00;oYL?^1?nVa>l4ojO4kP;oZ<G^0onWa>h2ojS4kPGoYlC^0_nW`neaooooo`04o`000?oooooooooo
o`0000_ooooo001Looooo`03o`000?oooooooooo02_ooooo1?nW`>`00onV_ncoY/3/ojK0k009ojK0
k0SoYl7/00?oYl;/ojS1k?nX`N`01?nX`^`2ojS1k0;oZ<7[1?nX`>/2ojO0j`03ojNojonV_^_oY[k[
00;oY[k[1?nU_^/6ojBnk0KoY;o]0_nT`>h00onT`NkoYL;^ojG2kP02ojG2kP;oYL?^0onV`nh3ojK4
k`koYlC^MOooool00ol0003oooooo`00000;ooooo`00GOooool00ol0003oooooooooo`0[ooooo`;o
Yl3/3?nV`>`9ojO1k0CoZ<7/0_nX`^`2ojS1k0CoZ<7[0_nX`>/5ojNoj`GoY[k[0onU_^/2ojBnk0?o
Y;o/1OnT_nd2ojC1k@?oY<7^0_nU`^h3ojG3kP;oY/?^00?oY/C^ojO4konWa>l00onWa>l9ojO4kWSo
oooo00Co0000oooooooooooo00002_ooool005kooooo00?o0000ooooooooool0:oooool2ojK0k0;o
Yl3/1_nV`>`2ojO0k0_oYl7/2?nX`N`2ojS1j`;oZ<3[1?nW_n/4ojJoj`;oY[k[0_nV_n/4ojFnk0;o
Y;o/00?oYKo/ojC0kOnT`>d00_nT`>d2ojC1k@;oYL7^1?nU`^h2ojG3kP03ojK3k_nVa>koY/C^00;o
Y/C^1OnWa>l5ojO4kWcooooo00?o0000ooooool000002_ooool005oooooo0_l0000/ooooo`CoYl3/
0_nV`>`6ojO0k0WoYl7/1OnX`N`7ojS0j`KoYko[2?nV_n/2ojFnk0GoYKo/0_nT`>d2ojG1k@CoYL7^
0_nU`^h5ojK3kP;oY/C^0onWa>h2ojO4kh?ooooo0_l0000:ooooo`00HOooool00ol0003ooooooooo
o`0Zooooo`;oYl3/0onW`>/7ojO0k0CoYl7/1_nX`N`2ojS1j`KoZ<3[00?oYl3[ojNojonW_n/01_nW
_n/6ojJoj`03ojJok?nU_ncoYKo/00CoYKo/0onU`>d3ojG1k@;oYL7^0_nV`^h4ojK3kPCoY/C^0_nW
a>j5ooooo`?o00002_ooool006;ooooo00?o0000ooooooooool0:oooool8ojO0j`03ojO0k?nW`>_o
Yl3[00CoYl7/0_nX`N`2ojS0j`CoZ<7[0onX`>/4ojO0j`SoYko[1?nV_n/3ojJok0;oYKo/0onV`>`2
ojG0k@KoY/7]00?oY/;^ojK2kOnV`^d01?nV`nh2ojK4kXCooooo1?l0000=ooooo`00Hoooool00ol0
003oooooooooo`0[ooooo`_oYl3[0_nW`N`6ojS0j`;oZ<7[1OnX`>/2ojO0j`[oYko[1?nV_n/4ojJo
k0CoY/3/1_nV`Nd5ojK2k@;oY/?^Poooool4o`00017ooooo001Tooooo`;o0000;?ooool9ojO0ja;o
Z<3[2onW_n/4ojJoj`;oY[o/1_nV`>`2ojK1k@;oYl7]1OnV`^f3ooooo`?o00005Oooool006Kooooo
00?o0000ooooooooool0:oooool4ojO0jaCoZ<3[3OnW_n/2ojJoj`?oYko[1OnV`>`2ojO1k0;oYl7]
QOooool4o`0001Sooooo001Wooooo`03o`000?oooooooooo02[ooooo5OnX`>/3ojRoja7oYko[00?o
Yl3[ojO0k?nW`>`00_nW`>`2ojO1k8Cooooo1?l0000Looooo`00J?ooool00ol0003oooooooooo`0Z
oooooaCoZ<3[0_nX_n/@ojNoj`CoYl3[0_nW`>b3ooooo`Co00008?ooool006Wooooo0_l0000/oooo
oa7oZ<3[0_nX_n/BojNoj`;oYl3[P_ooool4o`0002Cooooo001[ooooo`03o`000?oooooooooo02[o
oooo3onX`>/4ojRoja3oYko[P_ooool3o`0002Sooooo001/ooooo`03o`000?oooooooooo02[ooooo
3onX`>/4ojRoj`[oYko[Poooool4o`0002_ooooo001]ooooo`03o`000?oooooooooo02_ooooo2_nX
`>/6ojRoj`SoYko[P_ooool4o`0002oooooo001^ooooo`03o`000?oooooooooo02[ooooo2onX`>/2
ojRoj`SoYko[POooool4o`0003?ooooo001_ooooo`;o0000:oooool9ojS0j`?oYl3[1OnW_n^0oooo
o`Co0000=oooool0077ooooo00?o0000ooooooooool0:_ooool5ojS0j`CoYl3[P_ooool4o`0003_o
oooo001booooo`03o`000?oooooooooo02[ooooo1OnW`>^2ooooo`?o0000?oooool007?ooooo00?o
0000ooooooooool0:_ooool00onW`>_oooooooooo`1oooooo`Co0000@_ooool007Cooooo0_l0000Z
ooooo`03o`000?oooooooooo07_ooooo1?l00016ooooo`00M_ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo07Sooooo1?l0001:ooooo`00Moooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo07Cooooo1?l0001>ooooo`00N?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo077ooooo0ol0001Booooo`00NOooool2o`0002Cooooo00?o0000ooooooooool0KOoo
ool4o`0005Gooooo001kooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0JOooool4
o`0005Wooooo001looooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0IOooool4o`00
05gooooo001mooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0HOooool4o`00067o
oooo001nooooo`;o00007oooool00ol0003oooooooooo`1Mooooo`Co0000IOooool0083ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`1Jooooo`?o0000JOooool0087ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`1Fooooo`Co0000K?ooool008;ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`1Booooo`Co0000L?ooool008?ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`1>ooooo`Co0000M?ooool008Cooooo0_l0000Iooooo`03o`00
0?oooooooooo04[ooooo1?l0001hooooo`00Q_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo04Kooooo1?l0001looooo`00Qoooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo04?ooooo0ol00020ooooo`00R?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
03oooooo1?l00023ooooo`00ROooool2o`0001Cooooo00?o0000ooooooooool0>oooool4o`0008Oo
oooo002;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0=oooool4o`0008_ooooo
002<ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<oooool4o`0008oooooo002=
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<?ooool3o`0009?ooooo002>oooo
o`;o00003oooool00ol0003oooooooooo`0/ooooo`Co0000U_ooool0093ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Xooooo`Co0000V_ooool0097ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Tooooo`Co0000W_ooool009;ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Qooooo`Co0000X_ooool009?ooooo0_l00009ooooo`03o`000?oooooo
oooo01gooooo1?l0002Vooooo`00UOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01[ooooo0ol0002Zooooo`00U_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Ko
oooo1?l0002]ooooo`00Uoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo
1?l0002aooooo`00V?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0
002eooooo`00VOooool2o`0000?ooooo00?o0000ooooooooool02_ooool4o`000;Wooooo002Koooo
o`04o`000?ooooooooooo`0000Wooooo0ol0002mooooo`00W?ooool00ol0003oooooo`000005oooo
o`Co0000`?ooool009gooooo0_l000000ooooooo0000o`000002o`000<Cooooo002Nooooo`;o0000
b?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00:[ooooo00GoV9RHo`000?l0003oA4A4okZj^P0:
ooooo`Co000000?o410@ooooooooool00_ooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1?ooool0
1Oo^k^ko<S8bo`000?l@413oc<c<09?ooooo002Zooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_oo
ool6o`0000Cooooo00?o0000ooooooooool01?ooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q1?oo
ool01OmEEEGoMgMgoooooonHV9So8B4Q09?ooooo002Zooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool01?ooool00onYZJWoEEEEooooo`0;ooooo`05o`000?ooooooooooooooool00000
Toooool00:[ooooo00?o0000ooooooooool01?ooool6o`0000Cooooo00?o0000ooooooooool01Ooo
ool00olQ8B7oooooooooo`0:ooooo`05o`000?nHV9SooooooiRHV?lQ8B40Toooool00:[ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03oeEEEOo<c<cooooo00[ooooo00Go
0000oeEEEOl0003o410@olc<c02Cooooo`00Z?ooool00ol@413o0000o`000003o`0000gooooo00?o
0000ooooooooool01Oooool00onYZJWoMgMgooooo`0:ooooo`03oeEEEOn7QhOooooo09Gooooo002Z
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo<S8b00_ooooo00?ogMgMoa0@4?nHV9P0UOooool00:[ooooo00?o0000ooooooooool03?ooool0
0omEEEGoIVIVo`000004ooooo`Go00003?ooool01?o<c<coA4A4o`000?l@412Cooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -20 0 ]
[.5 .82364 20 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(18.4) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .752 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69466 Mtetra
.656 .751 .92 r
.4053 .69466 .41061 .69934 .41957 .69681 .41428 .69211 Mtetra
.656 .751 .919 r
.41428 .69211 .41957 .69681 .42855 .69428 .42328 .68955 Mtetra
.657 .75 .919 r
.42328 .68955 .42855 .69428 .43756 .69174 .43231 .68698 Mtetra
.657 .75 .918 r
.43231 .68698 .43756 .69174 .4466 .68919 .44137 .6844 Mtetra
.657 .749 .918 r
.44137 .6844 .4466 .68919 .45567 .68663 .45046 .6818 Mtetra
.657 .748 .917 r
.45046 .6818 .45567 .68663 .46478 .68407 .45958 .6792 Mtetra
.45958 .6792 .46478 .68407 .47391 .68149 .46873 .67659 Mtetra
.657 .747 .916 r
.46873 .67659 .47391 .68149 .48307 .67891 .47792 .67397 Mtetra
.657 .746 .916 r
.47792 .67397 .48307 .67891 .49227 .67632 .48713 .67135 Mtetra
.657 .745 .915 r
.48713 .67135 .49227 .67632 .50149 .67371 .49638 .66873 Mtetra
.656 .745 .915 r
.49638 .66873 .50149 .67371 .51075 .6711 .50565 .66611 Mtetra
.656 .745 .916 r
.50565 .66611 .51075 .6711 .52004 .66849 .51496 .66349 Mtetra
.655 .746 .917 r
.51496 .66349 .52004 .66849 .52936 .66586 .5243 .66088 Mtetra
.654 .747 .918 r
.5243 .66088 .52936 .66586 .53871 .66322 .53367 .65828 Mtetra
.653 .749 .92 r
.53367 .65828 .53871 .66322 .54809 .66058 .54308 .6557 Mtetra
.652 .751 .923 r
.54308 .6557 .54809 .66058 .55751 .65792 .55252 .65311 Mtetra
.651 .755 .926 r
.55252 .65311 .55751 .65792 .56695 .65526 .56199 .65053 Mtetra
.65 .759 .929 r
.56199 .65053 .56695 .65526 .57643 .65259 .57149 .64794 Mtetra
.65 .763 .932 r
.57149 .64794 .57643 .65259 .58595 .6499 .58102 .64534 Mtetra
.65 .767 .935 r
.58102 .64534 .58595 .6499 .59549 .64721 .59059 .64271 Mtetra
.65 .77 .937 r
.59059 .64271 .59549 .64721 .60507 .64451 .6002 .64006 Mtetra
.651 .773 .938 r
.6002 .64006 .60507 .64451 .61468 .6418 .60983 .63737 Mtetra
.652 .775 .939 r
.60983 .63737 .61468 .6418 .62432 .63908 .6195 .63465 Mtetra
.652 .776 .939 r
.6195 .63465 .62432 .63908 .634 .63636 .6292 .6319 Mtetra
.653 .776 .939 r
.6292 .6319 .634 .63636 .64371 .63362 .63894 .62912 Mtetra
.653 .775 .938 r
.63894 .62912 .64371 .63362 .65345 .63087 .6487 .62634 Mtetra
.653 .774 .937 r
.6487 .62634 .65345 .63087 .66323 .62811 .65851 .62354 Mtetra
.653 .773 .937 r
.65851 .62354 .66323 .62811 .67304 .62535 .66834 .62075 Mtetra
.66834 .62075 .67304 .62535 .68289 .62257 .67821 .61796 Mtetra
.652 .773 .937 r
.67821 .61796 .68289 .62257 .69277 .61979 .68812 .61516 Mtetra
.68812 .61516 .69277 .61979 .70269 .61699 .69806 .61237 Mtetra
.652 .774 .938 r
.69806 .61237 .70269 .61699 .71264 .61418 .70804 .60957 Mtetra
.652 .775 .939 r
.70804 .60957 .71264 .61418 .72262 .61137 .71805 .60675 Mtetra
.652 .776 .939 r
.71805 .60675 .72262 .61137 .73264 .60854 .7281 .60392 Mtetra
.653 .776 .939 r
.7281 .60392 .73264 .60854 .7427 .60571 .73818 .60105 Mtetra
.654 .776 .938 r
.73818 .60105 .7427 .60571 .75279 .60286 .74829 .59815 Mtetra
.655 .775 .937 r
.74829 .59815 .75279 .60286 .76291 .60001 .75844 .59521 Mtetra
.657 .773 .935 r
.75844 .59521 .76291 .60001 .77308 .59714 .76863 .59225 Mtetra
.658 .769 .932 r
.76863 .59225 .77308 .59714 .78328 .59427 .77885 .58926 Mtetra
.659 .766 .929 r
.77885 .58926 .78328 .59427 .79351 .59138 .7891 .58625 Mtetra
.659 .761 .926 r
.7891 .58625 .79351 .59138 .80378 .58849 .79939 .58323 Mtetra
.659 .757 .923 r
.79939 .58323 .80378 .58849 .81409 .58558 .80972 .58022 Mtetra
.659 .754 .92 r
.80972 .58022 .81409 .58558 .82443 .58267 .82008 .57721 Mtetra
.658 .75 .918 r
.82008 .57721 .82443 .58267 .83482 .57974 .83048 .5742 Mtetra
.658 .748 .917 r
.83048 .5742 .83482 .57974 .84523 .5768 .84092 .57121 Mtetra
.657 .746 .916 r
.84092 .57121 .84523 .5768 .85569 .57385 .85141 .56822 Mtetra
.657 .745 .915 r
.85141 .56822 .85569 .57385 .86618 .57089 .86193 .56524 Mtetra
.656 .745 .915 r
.86193 .56524 .86618 .57089 .87672 .56792 .87249 .56225 Mtetra
.656 .745 .916 r
.87249 .56225 .87672 .56792 .88729 .56494 .88308 .55927 Mtetra
.656 .746 .916 r
.88308 .55927 .88729 .56494 .89789 .56195 .89372 .55628 Mtetra
.655 .746 .917 r
.89372 .55628 .89789 .56195 .90854 .55895 .9044 .55327 Mtetra
.655 .747 .917 r
.9044 .55327 .90854 .55895 .91923 .55594 .91511 .55026 Mtetra
.655 .748 .918 r
.91511 .55026 .91923 .55594 .92995 .55292 .92587 .54724 Mtetra
.655 .749 .918 r
.92587 .54724 .92995 .55292 .94071 .54988 .93666 .5442 Mtetra
.655 .749 .919 r
.93666 .5442 .94071 .54988 .95152 .54684 .9475 .54115 Mtetra
.655 .75 .919 r
.9475 .54115 .95152 .54684 .96236 .54378 .95837 .53808 Mtetra
.655 .75 .92 r
.95837 .53808 .96236 .54378 .97324 .54071 .96928 .53501 Mtetra
.655 .751 .92 r
.96928 .53501 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.657 .752 .92 r
.391 .69252 .39636 .6972 .4053 .69466 .39996 .68996 Mtetra
.657 .751 .92 r
.39996 .68996 .4053 .69466 .41428 .69211 .40895 .68738 Mtetra
.657 .751 .919 r
.40895 .68738 .41428 .69211 .42328 .68955 .41797 .6848 Mtetra
.41797 .6848 .42328 .68955 .43231 .68698 .42702 .6822 Mtetra
.657 .75 .919 r
.42702 .6822 .43231 .68698 .44137 .6844 .4361 .67959 Mtetra
.657 .75 .918 r
.4361 .67959 .44137 .6844 .45046 .6818 .44521 .67697 Mtetra
.658 .749 .918 r
.44521 .67697 .45046 .6818 .45958 .6792 .45436 .67433 Mtetra
.658 .749 .917 r
.45436 .67433 .45958 .6792 .46873 .67659 .46353 .67168 Mtetra
.658 .748 .916 r
.46353 .67168 .46873 .67659 .47792 .67397 .47273 .66903 Mtetra
.658 .747 .916 r
.47273 .66903 .47792 .67397 .48713 .67135 .48197 .66637 Mtetra
.657 .746 .916 r
.48197 .66637 .48713 .67135 .49638 .66873 .49123 .66372 Mtetra
.656 .745 .916 r
.49123 .66372 .49638 .66873 .50565 .66611 .50053 .66108 Mtetra
.655 .745 .916 r
.50053 .66108 .50565 .66611 .51496 .66349 .50986 .65846 Mtetra
.653 .745 .917 r
.50986 .65846 .51496 .66349 .5243 .66088 .51922 .65587 Mtetra
.652 .746 .919 r
.51922 .65587 .5243 .66088 .53367 .65828 .52861 .6533 Mtetra
.65 .747 .921 r
.52861 .6533 .53367 .65828 .54308 .6557 .53803 .65077 Mtetra
.648 .75 .923 r
.53803 .65077 .54308 .6557 .55252 .65311 .54749 .64826 Mtetra
.647 .753 .927 r
.54749 .64826 .55252 .65311 .56199 .65053 .55699 .64576 Mtetra
.646 .757 .93 r
.55699 .64576 .56199 .65053 .57149 .64794 .56651 .64326 Mtetra
.645 .761 .933 r
.56651 .64326 .57149 .64794 .58102 .64534 .57607 .64074 Mtetra
.646 .765 .936 r
.57607 .64074 .58102 .64534 .59059 .64271 .58567 .63818 Mtetra
.647 .769 .938 r
.58567 .63818 .59059 .64271 .6002 .64006 .59529 .63558 Mtetra
.649 .773 .939 r
.59529 .63558 .6002 .64006 .60983 .63737 .60495 .63291 Mtetra
.651 .775 .939 r
.60495 .63291 .60983 .63737 .6195 .63465 .61465 .63019 Mtetra
.653 .776 .939 r
.61465 .63019 .6195 .63465 .6292 .6319 .62437 .62742 Mtetra
.654 .777 .939 r
.62437 .62742 .6292 .6319 .63894 .62912 .63413 .62461 Mtetra
.654 .776 .938 r
.63413 .62461 .63894 .62912 .6487 .62634 .64392 .62179 Mtetra
.654 .775 .937 r
.64392 .62179 .6487 .62634 .65851 .62354 .65375 .61895 Mtetra
.654 .774 .937 r
.65375 .61895 .65851 .62354 .66834 .62075 .66361 .61613 Mtetra
.653 .773 .937 r
.66361 .61613 .66834 .62075 .67821 .61796 .67351 .61332 Mtetra
.652 .773 .938 r
.67351 .61332 .67821 .61796 .68812 .61516 .68344 .61052 Mtetra
.651 .773 .938 r
.68344 .61052 .68812 .61516 .69806 .61237 .69341 .60773 Mtetra
.65 .774 .939 r
.69341 .60773 .69806 .61237 .70804 .60957 .70341 .60493 Mtetra
.651 .775 .939 r
.70341 .60493 .70804 .60957 .71805 .60675 .71345 .60212 Mtetra
.652 .776 .939 r
.71345 .60212 .71805 .60675 .7281 .60392 .72352 .59927 Mtetra
.654 .777 .939 r
.72352 .59927 .7281 .60392 .73818 .60105 .73363 .59636 Mtetra
.656 .777 .938 r
.73363 .59636 .73818 .60105 .74829 .59815 .74377 .5934 Mtetra
.658 .776 .936 r
.74377 .5934 .74829 .59815 .75844 .59521 .75394 .59038 Mtetra
.66 .774 .933 r
.75394 .59038 .75844 .59521 .76863 .59225 .76415 .58731 Mtetra
.662 .77 .93 r
.76415 .58731 .76863 .59225 .77885 .58926 .77438 .5842 Mtetra
.663 .767 .927 r
.77438 .5842 .77885 .58926 .7891 .58625 .78466 .58106 Mtetra
.663 .762 .924 r
.78466 .58106 .7891 .58625 .79939 .58323 .79497 .57793 Mtetra
.663 .758 .921 r
.79497 .57793 .79939 .58323 .80972 .58022 .80531 .5748 Mtetra
.661 .754 .919 r
.80531 .5748 .80972 .58022 .82008 .57721 .8157 .5717 Mtetra
.66 .751 .917 r
.8157 .5717 .82008 .57721 .83048 .5742 .82612 .56862 Mtetra
.659 .748 .916 r
.82612 .56862 .83048 .5742 .84092 .57121 .83659 .56558 Mtetra
.658 .746 .916 r
.83659 .56558 .84092 .57121 .85141 .56822 .84709 .56255 Mtetra
.656 .746 .916 r
.84709 .56255 .85141 .56822 .86193 .56524 .85764 .55955 Mtetra
.656 .745 .916 r
.85764 .55955 .86193 .56524 .87249 .56225 .86823 .55656 Mtetra
.655 .745 .916 r
.86823 .55656 .87249 .56225 .88308 .55927 .87886 .55357 Mtetra
.655 .746 .917 r
.87886 .55357 .88308 .55927 .89372 .55628 .88952 .55058 Mtetra
.655 .747 .918 r
.88952 .55058 .89372 .55628 .9044 .55327 .90023 .54758 Mtetra
.90023 .54758 .9044 .55327 .91511 .55026 .91098 .54457 Mtetra
.655 .748 .919 r
.91098 .54457 .91511 .55026 .92587 .54724 .92176 .54154 Mtetra
.655 .749 .919 r
.92176 .54154 .92587 .54724 .93666 .5442 .93259 .53849 Mtetra
.655 .75 .919 r
.93259 .53849 .93666 .5442 .9475 .54115 .94345 .53543 Mtetra
.655 .75 .92 r
.94345 .53543 .9475 .54115 .95837 .53808 .95436 .53236 Mtetra
.655 .751 .92 r
.95436 .53236 .95837 .53808 .96928 .53501 .9653 .52927 Mtetra
.9653 .52927 .96928 .53501 .98024 .53192 .97628 .52616 Mtetra
.657 .752 .92 r
.38561 .68781 .391 .69252 .39996 .68996 .39459 .68523 Mtetra
.39459 .68523 .39996 .68996 .40895 .68738 .40359 .68264 Mtetra
.657 .751 .92 r
.40359 .68264 .40895 .68738 .41797 .6848 .41263 .68003 Mtetra
.657 .751 .919 r
.41263 .68003 .41797 .6848 .42702 .6822 .4217 .67741 Mtetra
.658 .751 .919 r
.4217 .67741 .42702 .6822 .4361 .67959 .4308 .67478 Mtetra
.4308 .67478 .4361 .67959 .44521 .67697 .43993 .67212 Mtetra
.658 .75 .918 r
.43993 .67212 .44521 .67697 .45436 .67433 .4491 .66946 Mtetra
.4491 .66946 .45436 .67433 .46353 .67168 .45829 .66678 Mtetra
.658 .749 .917 r
.45829 .66678 .46353 .67168 .47273 .66903 .46751 .66409 Mtetra
.658 .748 .917 r
.46751 .66409 .47273 .66903 .48197 .66637 .47677 .6614 Mtetra
.658 .748 .916 r
.47677 .6614 .48197 .66637 .49123 .66372 .48605 .65871 Mtetra
.656 .747 .916 r
.48605 .65871 .49123 .66372 .50053 .66108 .49537 .65605 Mtetra
.655 .746 .917 r
.49537 .65605 .50053 .66108 .50986 .65846 .50472 .65341 Mtetra
.653 .745 .918 r
.50472 .65341 .50986 .65846 .51922 .65587 .5141 .65082 Mtetra
.65 .745 .919 r
.5141 .65082 .51922 .65587 .52861 .6533 .52351 .64828 Mtetra
.647 .746 .921 r
.52351 .64828 .52861 .6533 .53803 .65077 .53296 .64578 Mtetra
.645 .748 .924 r
.53296 .64578 .53803 .65077 .54749 .64826 .54244 .64334 Mtetra
.643 .75 .927 r
.54244 .64334 .54749 .64826 .55699 .64576 .55195 .64092 Mtetra
.641 .754 .93 r
.55195 .64092 .55699 .64576 .56651 .64326 .5615 .63851 Mtetra
.641 .758 .933 r
.5615 .63851 .56651 .64326 .57607 .64074 .57109 .63607 Mtetra
.642 .763 .936 r
.57109 .63607 .57607 .64074 .58567 .63818 .5807 .6336 Mtetra
.644 .767 .938 r
.5807 .6336 .58567 .63818 .59529 .63558 .59036 .63105 Mtetra
.647 .772 .939 r
.59036 .63105 .59529 .63558 .60495 .63291 .60004 .62842 Mtetra
.65 .775 .94 r
.60004 .62842 .60495 .63291 .61465 .63019 .60976 .62571 Mtetra
.652 .777 .94 r
.60976 .62571 .61465 .63019 .62437 .62742 .61951 .62293 Mtetra
.654 .778 .939 r
.61951 .62293 .62437 .62742 .63413 .62461 .62929 .62009 Mtetra
.655 .777 .939 r
.62929 .62009 .63413 .62461 .64392 .62179 .63911 .61723 Mtetra
.655 .777 .938 r
.63911 .61723 .64392 .62179 .65375 .61895 .64896 .61436 Mtetra
.654 .775 .938 r
.64896 .61436 .65375 .61895 .66361 .61613 .65885 .61151 Mtetra
.653 .775 .938 r
.65885 .61151 .66361 .61613 .67351 .61332 .66877 .60868 Mtetra
.651 .774 .939 r
.66877 .60868 .67351 .61332 .68344 .61052 .67873 .60588 Mtetra
.65 .774 .939 r
.67873 .60588 .68344 .61052 .69341 .60773 .68872 .60309 Mtetra
.649 .775 .94 r
.68872 .60309 .69341 .60773 .70341 .60493 .69875 .60029 Mtetra
.65 .776 .94 r
.69875 .60029 .70341 .60493 .71345 .60212 .70882 .59747 Mtetra
.652 .777 .94 r
.70882 .59747 .71345 .60212 .72352 .59927 .71892 .59459 Mtetra
.655 .778 .939 r
.71892 .59459 .72352 .59927 .73363 .59636 .72905 .59164 Mtetra
.658 .778 .937 r
.72905 .59164 .73363 .59636 .74377 .5934 .73921 .58861 Mtetra
.662 .776 .934 r
.73921 .58861 .74377 .5934 .75394 .59038 .74941 .58549 Mtetra
.665 .774 .931 r
.74941 .58549 .75394 .59038 .76415 .58731 .75963 .5823 Mtetra
.667 .771 .928 r
.75963 .5823 .76415 .58731 .77438 .5842 .76989 .57906 Mtetra
.667 .767 .924 r
.76989 .57906 .77438 .5842 .78466 .58106 .78018 .5758 Mtetra
.667 .762 .921 r
.78018 .5758 .78466 .58106 .79497 .57793 .79051 .57255 Mtetra
.666 .758 .919 r
.79051 .57255 .79497 .57793 .80531 .5748 .80088 .56932 Mtetra
.664 .754 .917 r
.80088 .56932 .80531 .5748 .8157 .5717 .81128 .56614 Mtetra
.662 .751 .916 r
.81128 .56614 .8157 .5717 .82612 .56862 .82173 .563 Mtetra
.66 .748 .916 r
.82173 .563 .82612 .56862 .83659 .56558 .83222 .55992 Mtetra
.658 .747 .916 r
.83222 .55992 .83659 .56558 .84709 .56255 .84275 .55688 Mtetra
.656 .746 .916 r
.84275 .55688 .84709 .56255 .85764 .55955 .85333 .55386 Mtetra
.655 .746 .917 r
.85333 .55386 .85764 .55955 .86823 .55656 .86395 .55087 Mtetra
.654 .746 .918 r
.86395 .55087 .86823 .55656 .87886 .55357 .8746 .54788 Mtetra
.654 .747 .918 r
.8746 .54788 .87886 .55357 .88952 .55058 .8853 .54488 Mtetra
.654 .748 .919 r
.8853 .54488 .88952 .55058 .90023 .54758 .89604 .54188 Mtetra
.89604 .54188 .90023 .54758 .91098 .54457 .90682 .53886 Mtetra
.654 .749 .92 r
.90682 .53886 .91098 .54457 .92176 .54154 .91763 .53582 Mtetra
.654 .75 .92 r
.91763 .53582 .92176 .54154 .93259 .53849 .92849 .53277 Mtetra
.655 .75 .92 r
.92849 .53277 .93259 .53849 .94345 .53543 .93938 .52969 Mtetra
.655 .751 .92 r
.93938 .52969 .94345 .53543 .95436 .53236 .95031 .5266 Mtetra
.95031 .5266 .95436 .53236 .9653 .52927 .96129 .52349 Mtetra
.96129 .52349 .9653 .52927 .97628 .52616 .9723 .52037 Mtetra
.657 .752 .92 r
.38018 .68308 .38561 .68781 .39459 .68523 .38918 .68048 Mtetra
.38918 .68048 .39459 .68523 .40359 .68264 .3982 .67787 Mtetra
.3982 .67787 .40359 .68264 .41263 .68003 .40726 .67525 Mtetra
.40726 .67525 .41263 .68003 .4217 .67741 .41635 .67262 Mtetra
.658 .752 .92 r
.41635 .67262 .4217 .67741 .4308 .67478 .42547 .66996 Mtetra
.658 .752 .919 r
.42547 .66996 .4308 .67478 .43993 .67212 .43462 .66729 Mtetra
.43462 .66729 .43993 .67212 .4491 .66946 .4438 .6646 Mtetra
.659 .752 .919 r
.4438 .6646 .4491 .66946 .45829 .66678 .45302 .66189 Mtetra
.659 .751 .918 r
.45302 .66189 .45829 .66678 .46751 .66409 .46226 .65916 Mtetra
.46226 .65916 .46751 .66409 .47677 .6614 .47154 .65644 Mtetra
.658 .75 .918 r
.47154 .65644 .47677 .6614 .48605 .65871 .48084 .65372 Mtetra
.657 .749 .918 r
.48084 .65372 .48605 .65871 .49537 .65605 .49018 .65102 Mtetra
.655 .747 .918 r
.49018 .65102 .49537 .65605 .50472 .65341 .49955 .64836 Mtetra
.653 .746 .918 r
.49955 .64836 .50472 .65341 .5141 .65082 .50895 .64575 Mtetra
.649 .745 .92 r
.50895 .64575 .5141 .65082 .52351 .64828 .51838 .64321 Mtetra
.646 .745 .922 r
.51838 .64321 .52351 .64828 .53296 .64578 .52785 .64074 Mtetra
.642 .745 .924 r
.52785 .64074 .53296 .64578 .54244 .64334 .53735 .63834 Mtetra
.639 .747 .927 r
.53735 .63834 .54244 .64334 .55195 .64092 .54689 .63598 Mtetra
.637 .75 .93 r
.54689 .63598 .55195 .64092 .5615 .63851 .55646 .63366 Mtetra
.636 .754 .933 r
.55646 .63366 .5615 .63851 .57109 .63607 .56607 .63133 Mtetra
.637 .759 .936 r
.56607 .63133 .57109 .63607 .5807 .6336 .57571 .62894 Mtetra
.64 .765 .939 r
.57571 .62894 .5807 .6336 .59036 .63105 .58539 .62648 Mtetra
.643 .77 .94 r
.58539 .62648 .59036 .63105 .60004 .62842 .5951 .6239 Mtetra
.647 .774 .941 r
.5951 .6239 .60004 .62842 .60976 .62571 .60484 .62122 Mtetra
.651 .777 .941 r
.60484 .62122 .60976 .62571 .61951 .62293 .61461 .61844 Mtetra
.654 .779 .94 r
.61461 .61844 .61951 .62293 .62929 .62009 .62442 .61559 Mtetra
.655 .779 .94 r
.62442 .61559 .62929 .62009 .63911 .61723 .63426 .61269 Mtetra
.655 .779 .939 r
.63426 .61269 .63911 .61723 .64896 .61436 .64414 .60979 Mtetra
.654 .778 .939 r
.64414 .60979 .64896 .61436 .65885 .61151 .65405 .60691 Mtetra
.652 .777 .94 r
.65405 .60691 .65885 .61151 .66877 .60868 .664 .60407 Mtetra
.65 .776 .94 r
.664 .60407 .66877 .60868 .67873 .60588 .67398 .60125 Mtetra
.649 .776 .941 r
.67398 .60125 .67873 .60588 .68872 .60309 .68401 .59846 Mtetra
.648 .776 .942 r
.68401 .59846 .68872 .60309 .69875 .60029 .69406 .59566 Mtetra
.65 .777 .942 r
.69406 .59566 .69875 .60029 .70882 .59747 .70416 .59282 Mtetra
.652 .778 .941 r
.70416 .59282 .70882 .59747 .71892 .59459 .71428 .58991 Mtetra
.657 .779 .939 r
.71428 .58991 .71892 .59459 .72905 .59164 .72444 .58689 Mtetra
.661 .778 .936 r
.72444 .58689 .72905 .59164 .73921 .58861 .73463 .58377 Mtetra
.666 .777 .932 r
.73463 .58377 .73921 .58861 .74941 .58549 .74484 .58053 Mtetra
.669 .774 .928 r
.74484 .58053 .74941 .58549 .75963 .5823 .75509 .57721 Mtetra
.671 .77 .924 r
.75509 .57721 .75963 .5823 .76989 .57906 .76536 .57384 Mtetra
.672 .766 .921 r
.76536 .57384 .76989 .57906 .78018 .5758 .77567 .57045 Mtetra
.671 .761 .918 r
.77567 .57045 .78018 .5758 .79051 .57255 .78602 .56709 Mtetra
.668 .757 .917 r
.78602 .56709 .79051 .57255 .80088 .56932 .79641 .56377 Mtetra
.665 .753 .916 r
.79641 .56377 .80088 .56932 .81128 .56614 .80684 .56053 Mtetra
.662 .75 .916 r
.80684 .56053 .81128 .56614 .82173 .563 .81731 .55736 Mtetra
.66 .749 .916 r
.81731 .55736 .82173 .563 .83222 .55992 .82783 .55425 Mtetra
.657 .748 .917 r
.82783 .55425 .83222 .55992 .84275 .55688 .83839 .5512 Mtetra
.655 .747 .918 r
.83839 .5512 .84275 .55688 .85333 .55386 .849 .54818 Mtetra
.654 .748 .919 r
.849 .54818 .85333 .55386 .86395 .55087 .85964 .54519 Mtetra
.653 .748 .919 r
.85964 .54519 .86395 .55087 .8746 .54788 .87033 .54219 Mtetra
.653 .749 .92 r
.87033 .54219 .8746 .54788 .8853 .54488 .88106 .5392 Mtetra
.88106 .5392 .8853 .54488 .89604 .54188 .89182 .53618 Mtetra
.653 .75 .921 r
.89182 .53618 .89604 .54188 .90682 .53886 .90263 .53315 Mtetra
.654 .75 .921 r
.90263 .53315 .90682 .53886 .91763 .53582 .91347 .5301 Mtetra
.654 .751 .921 r
.91347 .5301 .91763 .53582 .92849 .53277 .92436 .52703 Mtetra
.92436 .52703 .92849 .53277 .93938 .52969 .93528 .52393 Mtetra
.655 .751 .921 r
.93528 .52393 .93938 .52969 .95031 .5266 .94625 .52081 Mtetra
.94625 .52081 .95031 .5266 .96129 .52349 .95725 .51768 Mtetra
.95725 .51768 .96129 .52349 .9723 .52037 .96829 .51454 Mtetra
.656 .751 .92 r
.37472 .67831 .38018 .68308 .38918 .68048 .38373 .67571 Mtetra
.656 .752 .92 r
.38373 .67571 .38918 .68048 .3982 .67787 .39278 .67309 Mtetra
.656 .752 .921 r
.39278 .67309 .3982 .67787 .40726 .67525 .40186 .67046 Mtetra
.657 .753 .921 r
.40186 .67046 .40726 .67525 .41635 .67262 .41097 .66782 Mtetra
.41097 .66782 .41635 .67262 .42547 .66996 .4201 .66516 Mtetra
.658 .754 .921 r
.4201 .66516 .42547 .66996 .43462 .66729 .42927 .66247 Mtetra
.42927 .66247 .43462 .66729 .4438 .6646 .43848 .65976 Mtetra
.659 .754 .92 r
.43848 .65976 .4438 .6646 .45302 .66189 .44771 .65703 Mtetra
.44771 .65703 .45302 .66189 .46226 .65916 .45697 .65428 Mtetra
.45697 .65428 .46226 .65916 .47154 .65644 .46627 .65152 Mtetra
.659 .753 .919 r
.46627 .65152 .47154 .65644 .48084 .65372 .4756 .64876 Mtetra
.658 .751 .919 r
.4756 .64876 .48084 .65372 .49018 .65102 .48495 .64602 Mtetra
.656 .75 .919 r
.48495 .64602 .49018 .65102 .49955 .64836 .49434 .64331 Mtetra
.653 .748 .919 r
.49434 .64331 .49955 .64836 .50895 .64575 .50377 .64066 Mtetra
.65 .746 .92 r
.50377 .64066 .50895 .64575 .51838 .64321 .51322 .63809 Mtetra
.645 .744 .921 r
.51322 .63809 .51838 .64321 .52785 .64074 .52271 .63561 Mtetra
.64 .743 .923 r
.52271 .63561 .52785 .64074 .53735 .63834 .53223 .63324 Mtetra
.636 .744 .926 r
.53223 .63324 .53735 .63834 .54689 .63598 .54179 .63094 Mtetra
.632 .745 .929 r
.54179 .63094 .54689 .63598 .55646 .63366 .55138 .62871 Mtetra
.631 .749 .933 r
.55138 .62871 .55646 .63366 .56607 .63133 .56101 .62648 Mtetra
.631 .754 .936 r
.56101 .62648 .56607 .63133 .57571 .62894 .57068 .62421 Mtetra
.634 .761 .939 r
.57068 .62421 .57571 .62894 .58539 .62648 .58038 .62184 Mtetra
.639 .767 .941 r
.58038 .62184 .58539 .62648 .5951 .6239 .59012 .61935 Mtetra
.644 .773 .942 r
.59012 .61935 .5951 .6239 .60484 .62122 .59989 .61672 Mtetra
.649 .778 .942 r
.59989 .61672 .60484 .62122 .61461 .61844 .60969 .61396 Mtetra
.653 .78 .942 r
.60969 .61396 .61461 .61844 .62442 .61559 .61952 .6111 Mtetra
.655 .782 .941 r
.61952 .6111 .62442 .61559 .63426 .61269 .62939 .60819 Mtetra
.655 .781 .941 r
.62939 .60819 .63426 .61269 .64414 .60979 .63929 .60526 Mtetra
.654 .781 .941 r
.63929 .60526 .64414 .60979 .65405 .60691 .64923 .60235 Mtetra
.652 .78 .942 r
.64923 .60235 .65405 .60691 .664 .60407 .6592 .59949 Mtetra
.649 .779 .943 r
.6592 .59949 .664 .60407 .67398 .60125 .66921 .59667 Mtetra
.648 .779 .943 r
.66921 .59667 .67398 .60125 .68401 .59846 .67926 .59386 Mtetra
.648 .779 .944 r
.67926 .59386 .68401 .59846 .69406 .59566 .68935 .59105 Mtetra
.65 .78 .943 r
.68935 .59105 .69406 .59566 .70416 .59282 .69946 .58817 Mtetra
.654 .781 .941 r
.69946 .58817 .70416 .59282 .71428 .58991 .70962 .58521 Mtetra
.66 .781 .938 r
.70962 .58521 .71428 .58991 .72444 .58689 .7198 .5821 Mtetra
.665 .78 .934 r
.7198 .5821 .72444 .58689 .73463 .58377 .73 .57886 Mtetra
.671 .777 .93 r
.73 .57886 .73463 .58377 .74484 .58053 .74024 .57548 Mtetra
.675 .774 .925 r
.74024 .57548 .74484 .58053 .75509 .57721 .7505 .57201 Mtetra
.676 .769 .92 r
.7505 .57201 .75509 .57721 .76536 .57384 .7608 .56849 Mtetra
.676 .764 .917 r
.7608 .56849 .76536 .57384 .77567 .57045 .77113 .56498 Mtetra
.673 .759 .915 r
.77113 .56498 .77567 .57045 .78602 .56709 .7815 .56152 Mtetra
.67 .755 .914 r
.7815 .56152 .78602 .56709 .79641 .56377 .79191 .55814 Mtetra
.666 .752 .914 r
.79191 .55814 .79641 .56377 .80684 .56053 .80236 .55487 Mtetra
.662 .75 .915 r
.80236 .55487 .80684 .56053 .81731 .55736 .81286 .55168 Mtetra
.659 .749 .917 r
.81286 .55168 .81731 .55736 .82783 .55425 .82341 .54858 Mtetra
.656 .749 .918 r
.82341 .54858 .82783 .55425 .83839 .5512 .834 .54554 Mtetra
.654 .749 .92 r
.834 .54554 .83839 .5512 .849 .54818 .84464 .54253 Mtetra
.653 .75 .921 r
.84464 .54253 .849 .54818 .85964 .54519 .85531 .53954 Mtetra
.652 .751 .922 r
.85531 .53954 .85964 .54519 .87033 .54219 .86603 .53654 Mtetra
.86603 .53654 .87033 .54219 .88106 .5392 .87679 .53354 Mtetra
.653 .752 .922 r
.87679 .53354 .88106 .5392 .89182 .53618 .88759 .53051 Mtetra
.88759 .53051 .89182 .53618 .90263 .53315 .89842 .52746 Mtetra
.654 .752 .922 r
.89842 .52746 .90263 .53315 .91347 .5301 .90929 .52438 Mtetra
.90929 .52438 .91347 .5301 .92436 .52703 .92021 .52128 Mtetra
.655 .752 .922 r
.92021 .52128 .92436 .52703 .93528 .52393 .93116 .51815 Mtetra
.655 .752 .921 r
.93116 .51815 .93528 .52393 .94625 .52081 .94215 .515 Mtetra
.94215 .515 .94625 .52081 .95725 .51768 .95319 .51184 Mtetra
.95319 .51184 .95725 .51768 .96829 .51454 .96426 .50866 Mtetra
.656 .751 .92 r
.36922 .67351 .37472 .67831 .38373 .67571 .37826 .67091 Mtetra
.656 .752 .921 r
.37826 .67091 .38373 .67571 .39278 .67309 .38732 .66829 Mtetra
.38732 .66829 .39278 .67309 .40186 .67046 .39642 .66566 Mtetra
.656 .753 .921 r
.39642 .66566 .40186 .67046 .41097 .66782 .40554 .66301 Mtetra
.656 .754 .922 r
.40554 .66301 .41097 .66782 .4201 .66516 .4147 .66035 Mtetra
.657 .755 .922 r
.4147 .66035 .4201 .66516 .42927 .66247 .42389 .65766 Mtetra
.658 .755 .922 r
.42389 .65766 .42927 .66247 .43848 .65976 .43311 .65495 Mtetra
.658 .756 .922 r
.43311 .65495 .43848 .65976 .44771 .65703 .44237 .65221 Mtetra
.659 .756 .922 r
.44237 .65221 .44771 .65703 .45697 .65428 .45165 .64944 Mtetra
.66 .756 .922 r
.45165 .64944 .45697 .65428 .46627 .65152 .46097 .64665 Mtetra
.66 .756 .921 r
.46097 .64665 .46627 .65152 .4756 .64876 .47032 .64385 Mtetra
.659 .755 .921 r
.47032 .64385 .4756 .64876 .48495 .64602 .4797 .64105 Mtetra
.658 .753 .92 r
.4797 .64105 .48495 .64602 .49434 .64331 .48911 .63828 Mtetra
.655 .751 .92 r
.48911 .63828 .49434 .64331 .50377 .64066 .49855 .63557 Mtetra
.651 .748 .92 r
.49855 .63557 .50377 .64066 .51322 .63809 .50803 .63294 Mtetra
.646 .745 .921 r
.50803 .63294 .51322 .63809 .52271 .63561 .51753 .63043 Mtetra
.64 .742 .923 r
.51753 .63043 .52271 .63561 .53223 .63324 .52708 .62804 Mtetra
.634 .74 .925 r
.52708 .62804 .53223 .63324 .54179 .63094 .53666 .62578 Mtetra
.629 .741 .928 r
.53666 .62578 .54179 .63094 .55138 .62871 .54627 .62362 Mtetra
.626 .743 .932 r
.54627 .62362 .55138 .62871 .56101 .62648 .55592 .6215 Mtetra
.625 .748 .935 r
.55592 .6215 .56101 .62648 .57068 .62421 .56561 .61935 Mtetra
.628 .755 .939 r
.56561 .61935 .57068 .62421 .58038 .62184 .57534 .61712 Mtetra
.633 .763 .941 r
.57534 .61712 .58038 .62184 .59012 .61935 .5851 .61474 Mtetra
.639 .771 .943 r
.5851 .61474 .59012 .61935 .59989 .61672 .5949 .6122 Mtetra
.646 .777 .943 r
.5949 .6122 .59989 .61672 .60969 .61396 .60473 .60949 Mtetra
.651 .782 .944 r
.60473 .60949 .60969 .61396 .61952 .6111 .61459 .60666 Mtetra
.654 .784 .944 r
.61459 .60666 .61952 .6111 .62939 .60819 .62448 .60373 Mtetra
.654 .785 .944 r
.62448 .60373 .62939 .60819 .63929 .60526 .63441 .60079 Mtetra
.653 .785 .944 r
.63441 .60079 .63929 .60526 .64923 .60235 .64437 .59786 Mtetra
.651 .784 .945 r
.64437 .59786 .64923 .60235 .6592 .59949 .65437 .59498 Mtetra
.648 .783 .946 r
.65437 .59498 .6592 .59949 .66921 .59667 .66441 .59214 Mtetra
.647 .783 .946 r
.66441 .59214 .66921 .59667 .67926 .59386 .67449 .58932 Mtetra
.67449 .58932 .67926 .59386 .68935 .59105 .6846 .58648 Mtetra
.651 .783 .945 r
.6846 .58648 .68935 .59105 .69946 .58817 .69474 .58355 Mtetra
.657 .784 .942 r
.69474 .58355 .69946 .58817 .70962 .58521 .70492 .58049 Mtetra
.664 .783 .937 r
.70492 .58049 .70962 .58521 .7198 .5821 .71512 .57726 Mtetra
.671 .781 .932 r
.71512 .57726 .7198 .5821 .73 .57886 .72535 .57386 Mtetra
.677 .777 .926 r
.72535 .57386 .73 .57886 .74024 .57548 .7356 .57032 Mtetra
.681 .772 .92 r
.7356 .57032 .74024 .57548 .7505 .57201 .74588 .56667 Mtetra
.681 .766 .916 r
.74588 .56667 .7505 .57201 .7608 .56849 .75619 .56301 Mtetra
.679 .761 .913 r
.75619 .56301 .7608 .56849 .77113 .56498 .76654 .55938 Mtetra
.675 .756 .912 r
.76654 .55938 .77113 .56498 .7815 .56152 .77694 .55585 Mtetra
.671 .752 .912 r
.77694 .55585 .7815 .56152 .79191 .55814 .78737 .55244 Mtetra
.665 .75 .914 r
.78737 .55244 .79191 .55814 .80236 .55487 .79786 .54917 Mtetra
.661 .749 .916 r
.79786 .54917 .80236 .55487 .81286 .55168 .80839 .546 Mtetra
.657 .749 .918 r
.80839 .546 .81286 .55168 .82341 .54858 .81897 .54293 Mtetra
.654 .75 .92 r
.81897 .54293 .82341 .54858 .834 .54554 .82959 .53991 Mtetra
.652 .751 .922 r
.82959 .53991 .834 .54554 .84464 .54253 .84026 .53692 Mtetra
.651 .752 .923 r
.84026 .53692 .84464 .54253 .85531 .53954 .85097 .53393 Mtetra
.652 .753 .924 r
.85097 .53393 .85531 .53954 .86603 .53654 .86171 .53093 Mtetra
.652 .754 .924 r
.86171 .53093 .86603 .53654 .87679 .53354 .8725 .5279 Mtetra
.653 .754 .924 r
.8725 .5279 .87679 .53354 .88759 .53051 .88332 .52485 Mtetra
.88332 .52485 .88759 .53051 .89842 .52746 .89419 .52176 Mtetra
.654 .754 .923 r
.89419 .52176 .89842 .52746 .90929 .52438 .90509 .51865 Mtetra
.655 .754 .923 r
.90509 .51865 .90929 .52438 .92021 .52128 .91603 .51551 Mtetra
.655 .753 .922 r
.91603 .51551 .92021 .52128 .93116 .51815 .92701 .51234 Mtetra
.656 .753 .922 r
.92701 .51234 .93116 .51815 .94215 .515 .93803 .50916 Mtetra
.656 .752 .921 r
.93803 .50916 .94215 .515 .95319 .51184 .94909 .50596 Mtetra
.94909 .50596 .95319 .51184 .96426 .50866 .9602 .50275 Mtetra
.655 .751 .921 r
.36369 .66869 .36922 .67351 .37826 .67091 .37275 .66608 Mtetra
.655 .752 .921 r
.37275 .66608 .37826 .67091 .38732 .66829 .38183 .66346 Mtetra
.655 .752 .922 r
.38183 .66346 .38732 .66829 .39642 .66566 .39094 .66084 Mtetra
.655 .753 .922 r
.39094 .66084 .39642 .66566 .40554 .66301 .40009 .65819 Mtetra
.655 .754 .923 r
.40009 .65819 .40554 .66301 .4147 .66035 .40927 .65554 Mtetra
.656 .755 .923 r
.40927 .65554 .4147 .66035 .42389 .65766 .41847 .65286 Mtetra
.656 .756 .924 r
.41847 .65286 .42389 .65766 .43311 .65495 .42772 .65015 Mtetra
.657 .758 .924 r
.42772 .65015 .43311 .65495 .44237 .65221 .43699 .64741 Mtetra
.658 .759 .924 r
.43699 .64741 .44237 .65221 .45165 .64944 .44629 .64464 Mtetra
.659 .76 .924 r
.44629 .64464 .45165 .64944 .46097 .64665 .45563 .64184 Mtetra
.66 .76 .924 r
.45563 .64184 .46097 .64665 .47032 .64385 .465 .639 Mtetra
.661 .759 .923 r
.465 .639 .47032 .64385 .4797 .64105 .4744 .63614 Mtetra
.66 .757 .922 r
.4744 .63614 .4797 .64105 .48911 .63828 .48384 .6333 Mtetra
.658 .754 .921 r
.48384 .6333 .48911 .63828 .49855 .63557 .4933 .63049 Mtetra
.654 .751 .921 r
.4933 .63049 .49855 .63557 .50803 .63294 .5028 .62777 Mtetra
.649 .746 .92 r
.5028 .62777 .50803 .63294 .51753 .63043 .51233 .62518 Mtetra
.642 .741 .921 r
.51233 .62518 .51753 .63043 .52708 .62804 .52189 .62274 Mtetra
.634 .738 .923 r
.52189 .62274 .52708 .62804 .53666 .62578 .53149 .62048 Mtetra
.626 .735 .926 r
.53149 .62048 .53666 .62578 .54627 .62362 .54113 .61837 Mtetra
.621 .737 .929 r
.54113 .61837 .54627 .62362 .55592 .6215 .5508 .61635 Mtetra
.618 .741 .934 r
.5508 .61635 .55592 .6215 .56561 .61935 .56052 .61437 Mtetra
.62 .748 .938 r
.56052 .61437 .56561 .61935 .57534 .61712 .57027 .6123 Mtetra
.625 .758 .942 r
.57027 .6123 .57534 .61712 .5851 .61474 .58005 .61008 Mtetra
.632 .767 .944 r
.58005 .61008 .5851 .61474 .5949 .6122 .58988 .60767 Mtetra
.641 .776 .946 r
.58988 .60767 .5949 .6122 .60473 .60949 .59973 .60505 Mtetra
.647 .783 .946 r
.59973 .60505 .60473 .60949 .61459 .60666 .60962 .60227 Mtetra
.652 .787 .947 r
.60962 .60227 .61459 .60666 .62448 .60373 .61954 .59936 Mtetra
.653 .789 .947 r
.61954 .59936 .62448 .60373 .63441 .60079 .6295 .59641 Mtetra
.652 .79 .948 r
.6295 .59641 .63441 .60079 .64437 .59786 .63949 .59347 Mtetra
.65 .789 .949 r
.63949 .59347 .64437 .59786 .65437 .59498 .64951 .59057 Mtetra
.647 .788 .949 r
.64951 .59057 .65437 .59498 .66441 .59214 .65958 .58771 Mtetra
.646 .788 .95 r
.65958 .58771 .66441 .59214 .67449 .58932 .66968 .58486 Mtetra
.648 .788 .949 r
.66968 .58486 .67449 .58932 .6846 .58648 .67982 .58196 Mtetra
.653 .788 .946 r
.67982 .58196 .6846 .58648 .69474 .58355 .68999 .57894 Mtetra
.661 .787 .942 r
.68999 .57894 .69474 .58355 .70492 .58049 .70018 .57576 Mtetra
.67 .786 .935 r
.70018 .57576 .70492 .58049 .71512 .57726 .71041 .57236 Mtetra
.678 .782 .928 r
.71041 .57236 .71512 .57726 .72535 .57386 .72065 .56876 Mtetra
.684 .776 .921 r
.72065 .56876 .72535 .57386 .7356 .57032 .73092 .56501 Mtetra
.687 .77 .915 r
.73092 .56501 .7356 .57032 .74588 .56667 .74122 .56117 Mtetra
.686 .763 .91 r
.74122 .56117 .74588 .56667 .75619 .56301 .75155 .55736 Mtetra
.682 .757 .908 r
.75155 .55736 .75619 .56301 .76654 .55938 .76192 .55363 Mtetra
.676 .752 .908 r
.76192 .55363 .76654 .55938 .77694 .55585 .77234 .55007 Mtetra
.669 .749 .91 r
.77234 .55007 .77694 .55585 .78737 .55244 .78281 .54667 Mtetra
.663 .748 .913 r
.78281 .54667 .78737 .55244 .79786 .54917 .79332 .54344 Mtetra
.657 .749 .917 r
.79332 .54344 .79786 .54917 .80839 .546 .80389 .54034 Mtetra
.654 .75 .921 r
.80389 .54034 .80839 .546 .81897 .54293 .8145 .53732 Mtetra
.651 .752 .924 r
.8145 .53732 .81897 .54293 .82959 .53991 .82516 .53434 Mtetra
.65 .754 .926 r
.82516 .53434 .82959 .53991 .84026 .53692 .83586 .53137 Mtetra
.65 .756 .927 r
.83586 .53137 .84026 .53692 .85097 .53393 .8466 .52838 Mtetra
.651 .757 .927 r
.8466 .52838 .85097 .53393 .86171 .53093 .85737 .52536 Mtetra
.652 .757 .927 r
.85737 .52536 .86171 .53093 .8725 .5279 .86819 .5223 Mtetra
.653 .757 .926 r
.86819 .5223 .8725 .5279 .88332 .52485 .87904 .5192 Mtetra
.654 .757 .925 r
.87904 .5192 .88332 .52485 .89419 .52176 .88993 .51607 Mtetra
.655 .756 .924 r
.88993 .51607 .89419 .52176 .90509 .51865 .90086 .5129 Mtetra
.656 .755 .923 r
.90086 .5129 .90509 .51865 .91603 .51551 .91183 .50972 Mtetra
.656 .754 .922 r
.91183 .50972 .91603 .51551 .92701 .51234 .92283 .50651 Mtetra
.92283 .50651 .92701 .51234 .93803 .50916 .93388 .50329 Mtetra
.656 .753 .921 r
.93388 .50329 .93803 .50916 .94909 .50596 .94497 .50005 Mtetra
.656 .752 .921 r
.94497 .50005 .94909 .50596 .9602 .50275 .9561 .4968 Mtetra
.654 .751 .921 r
.35813 .66383 .36369 .66869 .37275 .66608 .3672 .66122 Mtetra
.654 .752 .921 r
.3672 .66122 .37275 .66608 .38183 .66346 .3763 .6586 Mtetra
.654 .752 .922 r
.3763 .6586 .38183 .66346 .39094 .66084 .38543 .65598 Mtetra
.654 .753 .922 r
.38543 .65598 .39094 .66084 .40009 .65819 .3946 .65334 Mtetra
.654 .754 .923 r
.3946 .65334 .40009 .65819 .40927 .65554 .40379 .65069 Mtetra
.654 .755 .924 r
.40379 .65069 .40927 .65554 .41847 .65286 .41302 .64803 Mtetra
.655 .756 .924 r
.41302 .64803 .41847 .65286 .42772 .65015 .42228 .64534 Mtetra
.656 .758 .925 r
.42228 .64534 .42772 .65015 .43699 .64741 .43158 .64262 Mtetra
.657 .76 .926 r
.43158 .64262 .43699 .64741 .44629 .64464 .4409 .63986 Mtetra
.658 .761 .926 r
.4409 .63986 .44629 .64464 .45563 .64184 .45026 .63706 Mtetra
.66 .763 .926 r
.45026 .63706 .45563 .64184 .465 .639 .45965 .6342 Mtetra
.661 .763 .925 r
.45965 .6342 .465 .639 .4744 .63614 .46907 .63131 Mtetra
.662 .762 .924 r
.46907 .63131 .4744 .63614 .48384 .6333 .47853 .62838 Mtetra
.661 .759 .923 r
.47853 .62838 .48384 .6333 .4933 .63049 .48802 .62547 Mtetra
.659 .755 .921 r
.48802 .62547 .4933 .63049 .5028 .62777 .49754 .62262 Mtetra
.653 .749 .92 r
.49754 .62262 .5028 .62777 .51233 .62518 .50709 .6199 Mtetra
.645 .743 .92 r
.50709 .6199 .51233 .62518 .52189 .62274 .51667 .61736 Mtetra
.636 .736 .921 r
.51667 .61736 .52189 .62274 .53149 .62048 .52629 .61504 Mtetra
.625 .731 .923 r
.52629 .61504 .53149 .62048 .54113 .61837 .53595 .61295 Mtetra
.617 .73 .927 r
.53595 .61295 .54113 .61837 .5508 .61635 .54564 .61103 Mtetra
.611 .732 .931 r
.54564 .61103 .5508 .61635 .56052 .61437 .55538 .6092 Mtetra
.611 .739 .937 r
.55538 .6092 .56052 .61437 .57027 .6123 .56516 .60733 Mtetra
.615 .75 .941 r
.56516 .60733 .57027 .6123 .58005 .61008 .57497 .60533 Mtetra
.623 .762 .945 r
.57497 .60533 .58005 .61008 .58988 .60767 .58482 .60311 Mtetra
.633 .774 .948 r
.58482 .60311 .58988 .60767 .59973 .60505 .5947 .60063 Mtetra
.641 .783 .95 r
.5947 .60063 .59973 .60505 .60962 .60227 .60462 .59794 Mtetra
.648 .79 .95 r
.60462 .59794 .60962 .60227 .61954 .59936 .61457 .59508 Mtetra
.65 .794 .951 r
.61457 .59508 .61954 .59936 .6295 .59641 .62455 .59215 Mtetra
.65 .795 .952 r
.62455 .59215 .6295 .59641 .63949 .59347 .63457 .5892 Mtetra
.648 .795 .953 r
.63457 .5892 .63949 .59347 .64951 .59057 .64463 .58628 Mtetra
.646 .795 .954 r
.64463 .58628 .64951 .59057 .65958 .58771 .65472 .58339 Mtetra
.646 .794 .953 r
.65472 .58339 .65958 .58771 .66968 .58486 .66485 .58048 Mtetra
.65 .794 .951 r
.66485 .58048 .66968 .58486 .67982 .58196 .67501 .5775 Mtetra
.658 .793 .947 r
.67501 .5775 .67982 .58196 .68999 .57894 .6852 .57435 Mtetra
.668 .792 .941 r
.6852 .57435 .68999 .57894 .70018 .57576 .69542 .57099 Mtetra
.679 .788 .932 r
.69542 .57099 .70018 .57576 .71041 .57236 .70566 .56736 Mtetra
.687 .782 .923 r
.70566 .56736 .71041 .57236 .72065 .56876 .71592 .56351 Mtetra
.692 .774 .914 r
.71592 .56351 .72065 .56876 .73092 .56501 .7262 .55952 Mtetra
.693 .766 .908 r
.7262 .55952 .73092 .56501 .74122 .56117 .73652 .55548 Mtetra
.689 .758 .904 r
.73652 .55548 .74122 .56117 .75155 .55736 .74687 .55153 Mtetra
.683 .752 .904 r
.74687 .55153 .75155 .55736 .76192 .55363 .75726 .54775 Mtetra
.674 .748 .906 r
.75726 .54775 .76192 .55363 .77234 .55007 .76771 .54421 Mtetra
.666 .746 .91 r
.76771 .54421 .77234 .55007 .78281 .54667 .77821 .54088 Mtetra
.659 .747 .915 r
.77821 .54088 .78281 .54667 .79332 .54344 .78876 .53774 Mtetra
.653 .749 .92 r
.78876 .53774 .79332 .54344 .80389 .54034 .79937 .53473 Mtetra
.65 .752 .924 r
.79937 .53473 .80389 .54034 .8145 .53732 .81001 .53177 Mtetra
.648 .755 .927 r
.81001 .53177 .8145 .53732 .82516 .53434 .82071 .52884 Mtetra
.649 .758 .929 r
.82071 .52884 .82516 .53434 .83586 .53137 .83143 .52587 Mtetra
.65 .759 .929 r
.83143 .52587 .83586 .53137 .8466 .52838 .8422 .52287 Mtetra
.652 .76 .929 r
.8422 .52287 .8466 .52838 .85737 .52536 .85301 .5198 Mtetra
.653 .76 .928 r
.85301 .5198 .85737 .52536 .86819 .5223 .86385 .51669 Mtetra
.655 .759 .926 r
.86385 .51669 .86819 .5223 .87904 .5192 .87472 .51353 Mtetra
.656 .758 .925 r
.87472 .51353 .87904 .5192 .88993 .51607 .88564 .51034 Mtetra
.656 .757 .924 r
.88564 .51034 .88993 .51607 .90086 .5129 .8966 .50712 Mtetra
.657 .756 .923 r
.8966 .50712 .90086 .5129 .91183 .50972 .90759 .50388 Mtetra
.657 .755 .922 r
.90759 .50388 .91183 .50972 .92283 .50651 .91863 .50063 Mtetra
.657 .754 .921 r
.91863 .50063 .92283 .50651 .93388 .50329 .92971 .49736 Mtetra
.657 .753 .921 r
.92971 .49736 .93388 .50329 .94497 .50005 .94082 .49409 Mtetra
.657 .752 .92 r
.94082 .49409 .94497 .50005 .9561 .4968 .95198 .4908 Mtetra
.654 .751 .921 r
.35253 .65894 .35813 .66383 .3672 .66122 .36162 .65632 Mtetra
.36162 .65632 .3672 .66122 .3763 .6586 .37074 .6537 Mtetra
.654 .751 .922 r
.37074 .6537 .3763 .6586 .38543 .65598 .37989 .65107 Mtetra
.653 .752 .922 r
.37989 .65107 .38543 .65598 .3946 .65334 .38907 .64844 Mtetra
.653 .753 .923 r
.38907 .64844 .3946 .65334 .40379 .65069 .39829 .6458 Mtetra
.653 .754 .924 r
.39829 .6458 .40379 .65069 .41302 .64803 .40754 .64316 Mtetra
.653 .755 .925 r
.40754 .64316 .41302 .64803 .42228 .64534 .41681 .6405 Mtetra
.653 .757 .926 r
.41681 .6405 .42228 .64534 .43158 .64262 .42613 .63781 Mtetra
.654 .76 .927 r
.42613 .63781 .43158 .64262 .4409 .63986 .43547 .63509 Mtetra
.656 .762 .928 r
.43547 .63509 .4409 .63986 .45026 .63706 .44485 .63232 Mtetra
.659 .765 .928 r
.44485 .63232 .45026 .63706 .45965 .6342 .45426 .62947 Mtetra
.661 .766 .928 r
.45426 .62947 .45965 .6342 .46907 .63131 .46371 .62655 Mtetra
.664 .767 .926 r
.46371 .62655 .46907 .63131 .47853 .62838 .47319 .62356 Mtetra
.665 .765 .925 r
.47319 .62356 .47853 .62838 .48802 .62547 .4827 .62054 Mtetra
.664 .761 .922 r
.4827 .62054 .48802 .62547 .49754 .62262 .49224 .61753 Mtetra
.66 .755 .92 r
.49224 .61753 .49754 .62262 .50709 .6199 .50181 .61463 Mtetra
.652 .746 .919 r
.50181 .61463 .50709 .6199 .51667 .61736 .51142 .61192 Mtetra
.641 .737 .918 r
.51142 .61192 .51667 .61736 .52629 .61504 .52106 .60947 Mtetra
.627 .728 .92 r
.52106 .60947 .52629 .61504 .53595 .61295 .53074 .60734 Mtetra
.615 .723 .923 r
.53074 .60734 .53595 .61295 .54564 .61103 .54045 .60548 Mtetra
.604 .722 .928 r
.54045 .60548 .54564 .61103 .55538 .6092 .55021 .60382 Mtetra
.6 .728 .934 r
.55021 .60382 .55538 .6092 .56516 .60733 .56001 .60219 Mtetra
.602 .739 .941 r
.56001 .60219 .56516 .60733 .57497 .60533 .56985 .60046 Mtetra
.61 .754 .947 r
.56985 .60046 .57497 .60533 .58482 .60311 .57973 .59849 Mtetra
.622 .769 .951 r
.57973 .59849 .58482 .60311 .5947 .60063 .58964 .59622 Mtetra
.632 .783 .954 r
.58964 .59622 .5947 .60063 .60462 .59794 .59959 .59368 Mtetra
.641 .793 .955 r
.59959 .59368 .60462 .59794 .61457 .59508 .60957 .59091 Mtetra
.645 .799 .956 r
.60957 .59091 .61457 .59508 .62455 .59215 .61958 .58802 Mtetra
.647 .802 .957 r
.61958 .58802 .62455 .59215 .63457 .5892 .62963 .58508 Mtetra
.646 .803 .958 r
.62963 .58508 .63457 .5892 .64463 .58628 .63971 .58215 Mtetra
.645 .803 .959 r
.63971 .58215 .64463 .58628 .65472 .58339 .64983 .57921 Mtetra
.647 .802 .957 r
.64983 .57921 .65472 .58339 .66485 .58048 .65998 .57623 Mtetra
.653 .801 .954 r
.65998 .57623 .66485 .58048 .67501 .5775 .67017 .57312 Mtetra
.665 .8 .947 r
.67017 .57312 .67501 .5775 .6852 .57435 .68038 .56978 Mtetra
.677 .796 .938 r
.68038 .56978 .6852 .57435 .69542 .57099 .69062 .56616 Mtetra
.69 .79 .927 r
.69062 .56616 .69542 .57099 .70566 .56736 .70087 .56224 Mtetra
.698 .782 .916 r
.70087 .56224 .70566 .56736 .71592 .56351 .71114 .55808 Mtetra
.701 .771 .906 r
.71114 .55808 .71592 .56351 .7262 .55952 .72144 .5538 Mtetra
.699 .761 .9 r
.72144 .5538 .7262 .55952 .73652 .55548 .73177 .54955 Mtetra
.691 .752 .898 r
.73177 .54955 .73652 .55548 .74687 .55153 .74214 .54551 Mtetra
.682 .746 .9 r
.74214 .54551 .74687 .55153 .75726 .54775 .75257 .54173 Mtetra
.67 .743 .905 r
.75257 .54173 .75726 .54775 .76771 .54421 .76305 .53827 Mtetra
.66 .743 .911 r
.76305 .53827 .76771 .54421 .77821 .54088 .77359 .53508 Mtetra
.652 .746 .918 r
.77359 .53508 .77821 .54088 .78876 .53774 .78418 .53208 Mtetra
.647 .75 .925 r
.78418 .53208 .78876 .53774 .79937 .53473 .79482 .5292 Mtetra
.645 .755 .929 r
.79482 .5292 .79937 .53473 .81001 .53177 .80551 .52632 Mtetra
.645 .759 .932 r
.80551 .52632 .81001 .53177 .82071 .52884 .81623 .52342 Mtetra
.648 .762 .932 r
.81623 .52342 .82071 .52884 .83143 .52587 .82699 .52043 Mtetra
.65 .763 .932 r
.82699 .52043 .83143 .52587 .8422 .52287 .83778 .51738 Mtetra
.653 .763 .93 r
.83778 .51738 .8422 .52287 .85301 .5198 .84861 .51424 Mtetra
.655 .762 .928 r
.84861 .51424 .85301 .5198 .86385 .51669 .85948 .51105 Mtetra
.657 .76 .926 r
.85948 .51105 .86385 .51669 .87472 .51353 .87038 .50782 Mtetra
.658 .759 .924 r
.87038 .50782 .87472 .51353 .88564 .51034 .88132 .50456 Mtetra
.658 .757 .923 r
.88132 .50456 .88564 .51034 .8966 .50712 .8923 .50128 Mtetra
.658 .755 .922 r
.8923 .50128 .8966 .50712 .90759 .50388 .90333 .49799 Mtetra
.658 .754 .921 r
.90333 .49799 .90759 .50388 .91863 .50063 .91439 .49469 Mtetra
.658 .753 .921 r
.91439 .49469 .91863 .50063 .92971 .49736 .9255 .49139 Mtetra
.657 .753 .92 r
.9255 .49139 .92971 .49736 .94082 .49409 .93664 .48808 Mtetra
.657 .752 .92 r
.93664 .48808 .94082 .49409 .95198 .4908 .94784 .48476 Mtetra
.654 .751 .921 r
.34689 .65403 .35253 .65894 .36162 .65632 .356 .65139 Mtetra
.356 .65139 .36162 .65632 .37074 .6537 .36514 .64874 Mtetra
.653 .751 .921 r
.36514 .64874 .37074 .6537 .37989 .65107 .37431 .6461 Mtetra
.37431 .6461 .37989 .65107 .38907 .64844 .38352 .64346 Mtetra
.652 .751 .922 r
.38352 .64346 .38907 .64844 .39829 .6458 .39275 .64083 Mtetra
.652 .752 .923 r
.39275 .64083 .39829 .6458 .40754 .64316 .40201 .6382 Mtetra
.651 .753 .924 r
.40201 .6382 .40754 .64316 .41681 .6405 .41131 .63557 Mtetra
.651 .755 .925 r
.41131 .63557 .41681 .6405 .42613 .63781 .42064 .63293 Mtetra
.651 .757 .927 r
.42064 .63293 .42613 .63781 .43547 .63509 .43001 .63026 Mtetra
.653 .76 .928 r
.43001 .63026 .43547 .63509 .44485 .63232 .43941 .62754 Mtetra
.656 .764 .929 r
.43941 .62754 .44485 .63232 .45426 .62947 .44884 .62474 Mtetra
.66 .767 .929 r
.44884 .62474 .45426 .62947 .46371 .62655 .45831 .62184 Mtetra
.664 .77 .929 r
.45831 .62184 .46371 .62655 .47319 .62356 .46781 .61882 Mtetra
.668 .771 .927 r
.46781 .61882 .47319 .62356 .4827 .62054 .47734 .61571 Mtetra
.67 .768 .924 r
.47734 .61571 .4827 .62054 .49224 .61753 .48691 .61255 Mtetra
.667 .762 .921 r
.48691 .61255 .49224 .61753 .50181 .61463 .49651 .60944 Mtetra
.661 .753 .918 r
.49651 .60944 .50181 .61463 .51142 .61192 .50614 .60648 Mtetra
.649 .741 .917 r
.50614 .60648 .51142 .61192 .52106 .60947 .5158 .60383 Mtetra
.632 .728 .917 r
.5158 .60383 .52106 .60947 .53074 .60734 .52549 .60157 Mtetra
.615 .718 .919 r
.52549 .60157 .53074 .60734 .54045 .60548 .53523 .5997 Mtetra
.598 .713 .924 r
.53523 .5997 .54045 .60548 .55021 .60382 .54501 .59818 Mtetra
.589 .715 .931 r
.54501 .59818 .55021 .60382 .56001 .60219 .55483 .5968 Mtetra
.587 .725 .939 r
.55483 .5968 .56001 .60219 .56985 .60046 .56469 .59539 Mtetra
.594 .741 .946 r
.56469 .59539 .56985 .60046 .57973 .59849 .5746 .59375 Mtetra
.607 .761 .953 r
.5746 .59375 .57973 .59849 .58964 .59622 .58454 .59178 Mtetra
.619 .778 .957 r
.58454 .59178 .58964 .59622 .59959 .59368 .59452 .58947 Mtetra
.632 .793 .96 r
.59452 .58947 .59959 .59368 .60957 .59091 .60453 .58684 Mtetra
.639 .803 .962 r
.60453 .58684 .60957 .59091 .61958 .58802 .61457 .58404 Mtetra
.642 .808 .963 r
.61457 .58404 .61958 .58802 .62963 .58508 .62465 .58112 Mtetra
.643 .811 .963 r
.62465 .58112 .62963 .58508 .63971 .58215 .63476 .57816 Mtetra
.645 .811 .963 r
.63476 .57816 .63971 .58215 .64983 .57921 .64491 .57517 Mtetra
.65 .811 .96 r
.64491 .57517 .64983 .57921 .65998 .57623 .65509 .57206 Mtetra
.66 .809 .955 r
.65509 .57206 .65998 .57623 .67017 .57312 .6653 .56877 Mtetra
.675 .806 .945 r
.6653 .56877 .67017 .57312 .68038 .56978 .67553 .56517 Mtetra
.69 .8 .933 r
.67553 .56517 .68038 .56978 .69062 .56616 .68578 .56122 Mtetra
.703 .79 .919 r
.68578 .56122 .69062 .56616 .70087 .56224 .69604 .55692 Mtetra
.71 .779 .906 r
.69604 .55692 .70087 .56224 .71114 .55808 .70633 .55239 Mtetra
.709 .766 .897 r
.70633 .55239 .71114 .55808 .72144 .5538 .71663 .54782 Mtetra
.703 .754 .892 r
.71663 .54782 .72144 .5538 .73177 .54955 .72698 .54339 Mtetra
.691 .745 .893 r
.72698 .54339 .73177 .54955 .74214 .54551 .73738 .53931 Mtetra
.678 .74 .898 r
.73738 .53931 .74214 .54551 .75257 .54173 .74784 .53562 Mtetra
.664 .739 .906 r
.74784 .53562 .75257 .54173 .76305 .53827 .75836 .53234 Mtetra
.652 .741 .915 r
.75836 .53234 .76305 .53827 .77359 .53508 .76894 .52936 Mtetra
.644 .747 .924 r
.76894 .52936 .77359 .53508 .78418 .53208 .77958 .52653 Mtetra
.64 .753 .931 r
.77958 .52653 .78418 .53208 .79482 .5292 .79026 .52377 Mtetra
.641 .759 .934 r
.79026 .52377 .79482 .5292 .80551 .52632 .80098 .52095 Mtetra
.644 .763 .935 r
.80098 .52095 .80551 .52632 .81623 .52342 .81173 .51803 Mtetra
.649 .766 .934 r
.81173 .51803 .81623 .52342 .82699 .52043 .82252 .51499 Mtetra
.653 .766 .932 r
.82252 .51499 .82699 .52043 .83778 .51738 .83333 .51184 Mtetra
.656 .764 .929 r
.83333 .51184 .83778 .51738 .84861 .51424 .84419 .50862 Mtetra
.658 .762 .926 r
.84419 .50862 .84861 .51424 .85948 .51105 .85507 .50533 Mtetra
.659 .76 .924 r
.85507 .50533 .85948 .51105 .87038 .50782 .866 .50201 Mtetra
.66 .757 .922 r
.866 .50201 .87038 .50782 .88132 .50456 .87697 .49868 Mtetra
.659 .755 .921 r
.87697 .49868 .88132 .50456 .8923 .50128 .88798 .49534 Mtetra
.659 .754 .92 r
.88798 .49534 .8923 .50128 .90333 .49799 .89903 .49201 Mtetra
.658 .753 .92 r
.89903 .49201 .90333 .49799 .91439 .49469 .91012 .48868 Mtetra
.658 .752 .92 r
.91012 .48868 .91439 .49469 .9255 .49139 .92126 .48535 Mtetra
.657 .752 .92 r
.92126 .48535 .9255 .49139 .93664 .48808 .93244 .48202 Mtetra
.93244 .48202 .93664 .48808 .94784 .48476 .94366 .47868 Mtetra
.655 .751 .921 r
.34122 .64908 .34689 .65403 .356 .65139 .35035 .64641 Mtetra
.655 .751 .92 r
.35035 .64641 .356 .65139 .36514 .64874 .35951 .64373 Mtetra
.654 .75 .92 r
.35951 .64373 .36514 .64874 .37431 .6461 .3687 .64106 Mtetra
.653 .749 .92 r
.3687 .64106 .37431 .6461 .38352 .64346 .37792 .6384 Mtetra
.652 .749 .92 r
.37792 .6384 .38352 .64346 .39275 .64083 .38718 .63575 Mtetra
.651 .749 .921 r
.38718 .63575 .39275 .64083 .40201 .6382 .39646 .63312 Mtetra
.65 .749 .922 r
.39646 .63312 .40201 .6382 .41131 .63557 .40578 .63052 Mtetra
.649 .75 .924 r
.40578 .63052 .41131 .63557 .42064 .63293 .41513 .62792 Mtetra
.648 .752 .926 r
.41513 .62792 .42064 .63293 .43001 .63026 .42451 .62532 Mtetra
.649 .756 .928 r
.42451 .62532 .43001 .63026 .43941 .62754 .43393 .62268 Mtetra
.651 .761 .93 r
.43393 .62268 .43941 .62754 .44884 .62474 .44338 .61998 Mtetra
.655 .766 .931 r
.44338 .61998 .44884 .62474 .45831 .62184 .45287 .61716 Mtetra
.662 .772 .931 r
.45287 .61716 .45831 .62184 .46781 .61882 .46239 .61417 Mtetra
.668 .776 .93 r
.46239 .61417 .46781 .61882 .47734 .61571 .47195 .61102 Mtetra
.675 .776 .927 r
.47195 .61102 .47734 .61571 .48691 .61255 .48154 .60772 Mtetra
.676 .772 .923 r
.48154 .60772 .48691 .61255 .49651 .60944 .49116 .60438 Mtetra
.673 .763 .918 r
.49116 .60438 .49651 .60944 .50614 .60648 .50082 .60111 Mtetra
.661 .748 .915 r
.50082 .60111 .50614 .60648 .5158 .60383 .5105 .59814 Mtetra
.642 .731 .914 r
.5105 .59814 .5158 .60383 .52549 .60157 .52022 .59564 Mtetra
.62 .716 .914 r
.52022 .59564 .52549 .60157 .53523 .5997 .52997 .59366 Mtetra
.595 .703 .919 r
.52997 .59366 .53523 .5997 .54501 .59818 .53977 .59223 Mtetra
.579 .701 .925 r
.53977 .59223 .54501 .59818 .55483 .5968 .54961 .59109 Mtetra
.57 .707 .935 r
.54961 .59109 .55483 .5968 .56469 .59539 .5595 .59006 Mtetra
.573 .725 .945 r
.5595 .59006 .56469 .59539 .5746 .59375 .56943 .58885 Mtetra
.586 .748 .954 r
.56943 .58885 .5746 .59375 .58454 .59178 .57941 .58726 Mtetra
.602 .771 .961 r
.57941 .58726 .58454 .59178 .59452 .58947 .58942 .58527 Mtetra
.618 .791 .965 r
.58942 .58527 .59452 .58947 .60453 .58684 .59946 .58287 Mtetra
.628 .805 .967 r
.59946 .58287 .60453 .58684 .61457 .58404 .60953 .5802 Mtetra
.636 .814 .969 r
.60953 .5802 .61457 .58404 .62465 .58112 .61964 .57733 Mtetra
.64 .819 .969 r
.61964 .57733 .62465 .58112 .63476 .57816 .62978 .57436 Mtetra
.645 .82 .967 r
.62978 .57436 .63476 .57816 .64491 .57517 .63996 .57127 Mtetra
.656 .82 .963 r
.63996 .57127 .64491 .57517 .65509 .57206 .65016 .568 Mtetra
.67 .817 .954 r
.65016 .568 .65509 .57206 .6653 .56877 .66039 .56445 Mtetra
.689 .812 .941 r
.66039 .56445 .6653 .56877 .67553 .56517 .67064 .56048 Mtetra
.706 .802 .925 r
.67064 .56048 .67553 .56517 .68578 .56122 .6809 .5561 Mtetra
.717 .789 .908 r
.6809 .5561 .68578 .56122 .69604 .55692 .69117 .55134 Mtetra
.721 .774 .894 r
.69117 .55134 .69604 .55692 .70633 .55239 .70146 .54638 Mtetra
.716 .758 .886 r
.70146 .54638 .70633 .55239 .71663 .54782 .71178 .54153 Mtetra
.705 .746 .883 r
.71178 .54153 .71663 .54782 .72698 .54339 .72215 .53696 Mtetra
.687 .736 .888 r
.72215 .53696 .72698 .54339 .73738 .53931 .73258 .53295 Mtetra
.67 .733 .897 r
.73258 .53295 .73738 .53931 .74784 .53562 .74308 .52947 Mtetra
.653 .735 .91 r
.74308 .52947 .74784 .53562 .75836 .53234 .75364 .52647 Mtetra
.639 .74 .922 r
.75364 .52647 .75836 .53234 .76894 .52936 .76427 .52377 Mtetra
.634 .75 .932 r
.76427 .52377 .76894 .52936 .77958 .52653 .77495 .52114 Mtetra
.633 .758 .938 r
.77495 .52114 .77958 .52653 .79026 .52377 .78567 .51848 Mtetra
.639 .766 .939 r
.78567 .51848 .79026 .52377 .80098 .52095 .79642 .51566 Mtetra
.646 .769 .938 r
.79642 .51566 .80098 .52095 .81173 .51803 .8072 .51267 Mtetra
.653 .769 .935 r
.8072 .51267 .81173 .51803 .82252 .51499 .81801 .50951 Mtetra
.658 .767 .931 r
.81801 .50951 .82252 .51499 .83333 .51184 .82885 .50622 Mtetra
.66 .764 .926 r
.82885 .50622 .83333 .51184 .84419 .50862 .83972 .50287 Mtetra
.662 .76 .923 r
.83972 .50287 .84419 .50862 .85507 .50533 .85063 .49947 Mtetra
.662 .757 .921 r
.85063 .49947 .85507 .50533 .866 .50201 .86158 .49607 Mtetra
.661 .754 .919 r
.86158 .49607 .866 .50201 .87697 .49868 .87257 .49267 Mtetra
.66 .752 .918 r
.87257 .49267 .87697 .49868 .88798 .49534 .88361 .48929 Mtetra
.659 .751 .918 r
.88361 .48929 .88798 .49534 .89903 .49201 .89469 .48593 Mtetra
.658 .751 .918 r
.89469 .48593 .89903 .49201 .91012 .48868 .90581 .48258 Mtetra
.657 .75 .919 r
.90581 .48258 .91012 .48868 .92126 .48535 .91698 .47924 Mtetra
.657 .751 .919 r
.91698 .47924 .92126 .48535 .93244 .48202 .92819 .4759 Mtetra
.657 .751 .92 r
.92819 .4759 .93244 .48202 .94366 .47868 .93945 .47256 Mtetra
.656 .751 .92 r
.33552 .6441 .34122 .64908 .35035 .64641 .34467 .64138 Mtetra
.656 .75 .92 r
.34467 .64138 .35035 .64641 .35951 .64373 .35385 .63867 Mtetra
.655 .749 .919 r
.35385 .63867 .35951 .64373 .3687 .64106 .36306 .63596 Mtetra
.654 .748 .919 r
.36306 .63596 .3687 .64106 .37792 .6384 .3723 .63326 Mtetra
.653 .747 .919 r
.3723 .63326 .37792 .6384 .38718 .63575 .38157 .63058 Mtetra
.651 .746 .919 r
.38157 .63058 .38718 .63575 .39646 .63312 .39088 .62793 Mtetra
.649 .745 .92 r
.39088 .62793 .39646 .63312 .40578 .63052 .40021 .62532 Mtetra
.647 .745 .921 r
.40021 .62532 .40578 .63052 .41513 .62792 .40958 .62274 Mtetra
.645 .746 .923 r
.40958 .62274 .41513 .62792 .42451 .62532 .41898 .6202 Mtetra
.645 .749 .925 r
.41898 .6202 .42451 .62532 .43393 .62268 .42841 .61766 Mtetra
.645 .754 .928 r
.42841 .61766 .43393 .62268 .44338 .61998 .43788 .61508 Mtetra
.649 .76 .931 r
.43788 .61508 .44338 .61998 .45287 .61716 .44739 .61239 Mtetra
.656 .768 .932 r
.44739 .61239 .45287 .61716 .46239 .61417 .45693 .60952 Mtetra
.665 .776 .932 r
.45693 .60952 .46239 .61417 .47195 .61102 .46651 .60642 Mtetra
.676 .781 .929 r
.46651 .60642 .47195 .61102 .48154 .60772 .47613 .60305 Mtetra
.682 .781 .925 r
.47613 .60305 .48154 .60772 .49116 .60438 .48578 .59952 Mtetra
.685 .775 .919 r
.48578 .59952 .49116 .60438 .50082 .60111 .49546 .59591 Mtetra
.675 .76 .915 r
.49546 .59591 .50082 .60111 .5105 .59814 .50517 .59255 Mtetra
.657 .741 .912 r
.50517 .59255 .5105 .59814 .52022 .59564 .51491 .58965 Mtetra
.63 .719 .911 r
.51491 .58965 .52022 .59564 .52997 .59366 .52468 .58741 Mtetra
.598 .698 .913 r
.52468 .58741 .52997 .59366 .53977 .59223 .5345 .58595 Mtetra
.573 .688 .919 r
.5345 .58595 .53977 .59223 .54961 .59109 .54436 .58499 Mtetra
.553 .687 .928 r
.54436 .58499 .54961 .59109 .5595 .59006 .55427 .58436 Mtetra
.552 .702 .939 r
.55427 .58436 .5595 .59006 .56943 .58885 .56423 .58362 Mtetra
.562 .726 .951 r
.56423 .58362 .56943 .58885 .57941 .58726 .57423 .58253 Mtetra
.579 .755 .961 r
.57423 .58253 .57941 .58726 .58942 .58527 .58427 .58097 Mtetra
.601 .782 .967 r
.58427 .58097 .58942 .58527 .59946 .58287 .59435 .57888 Mtetra
.616 .802 .971 r
.59435 .57888 .59946 .58287 .60953 .5802 .60446 .57641 Mtetra
.629 .816 .972 r
.60446 .57641 .60953 .5802 .61964 .57733 .6146 .57363 Mtetra
.638 .824 .972 r
.6146 .57363 .61964 .57733 .62978 .57436 .62477 .57064 Mtetra
.649 .827 .969 r
.62477 .57064 .62978 .57436 .63996 .57127 .63497 .56743 Mtetra
.665 .827 .961 r
.63497 .56743 .63996 .57127 .65016 .568 .6452 .56392 Mtetra
.685 .822 .949 r
.6452 .56392 .65016 .568 .66039 .56445 .65545 .56001 Mtetra
.707 .813 .931 r
.65545 .56001 .66039 .56445 .67064 .56048 .66571 .55558 Mtetra
.723 .799 .911 r
.66571 .55558 .67064 .56048 .6809 .5561 .67597 .55066 Mtetra
.732 .782 .893 r
.67597 .55066 .6809 .5561 .69117 .55134 .68625 .54537 Mtetra
.731 .764 .879 r
.68625 .54537 .69117 .55134 .70146 .54638 .69654 .53997 Mtetra
.719 .747 .874 r
.69654 .53997 .70146 .54638 .71178 .54153 .70688 .53489 Mtetra
.703 .735 .876 r
.70688 .53489 .71178 .54153 .72215 .53696 .71727 .53032 Mtetra
.679 .728 .887 r
.71727 .53032 .72215 .53696 .73258 .53295 .72774 .52653 Mtetra
.657 .727 .901 r
.72774 .52653 .73258 .53295 .74308 .52947 .73829 .52341 Mtetra
.637 .733 .918 r
.73829 .52341 .74308 .52947 .75364 .52647 .74891 .52077 Mtetra
.624 .743 .932 r
.74891 .52077 .75364 .52647 .76427 .52377 .75959 .51838 Mtetra
.624 .756 .941 r
.75959 .51838 .76427 .52377 .77495 .52114 .77031 .51591 Mtetra
.63 .765 .944 r
.77031 .51591 .77495 .52114 .78567 .51848 .78107 .51328 Mtetra
.641 .771 .942 r
.78107 .51328 .78567 .51848 .79642 .51566 .79184 .51036 Mtetra
.651 .772 .937 r
.79184 .51036 .79642 .51566 .8072 .51267 .80264 .50721 Mtetra
.659 .77 .931 r
.80264 .50721 .8072 .51267 .81801 .50951 .81346 .50388 Mtetra
.664 .765 .926 r
.81346 .50388 .81801 .50951 .82885 .50622 .82432 .50042 Mtetra
.665 .76 .921 r
.82432 .50042 .82885 .50622 .83972 .50287 .83521 .49693 Mtetra
.665 .756 .918 r
.83521 .49693 .83972 .50287 .85063 .49947 .84614 .49343 Mtetra
.664 .752 .916 r
.84614 .49343 .85063 .49947 .86158 .49607 .85712 .48996 Mtetra
.662 .75 .916 r
.85712 .48996 .86158 .49607 .87257 .49267 .86814 .48652 Mtetra
.66 .749 .916 r
.86814 .48652 .87257 .49267 .88361 .48929 .8792 .48313 Mtetra
.659 .748 .916 r
.8792 .48313 .88361 .48929 .89469 .48593 .89032 .47976 Mtetra
.658 .749 .917 r
.89032 .47976 .89469 .48593 .90581 .48258 .90147 .47641 Mtetra
.657 .749 .918 r
.90147 .47641 .90581 .48258 .91698 .47924 .91268 .47307 Mtetra
.656 .75 .919 r
.91268 .47307 .91698 .47924 .92819 .4759 .92392 .46974 Mtetra
.656 .75 .92 r
.92392 .46974 .92819 .4759 .93945 .47256 .93521 .46639 Mtetra
.657 .752 .92 r
.32977 .63908 .33552 .6441 .34467 .64138 .33894 .63633 Mtetra
.657 .751 .919 r
.33894 .63633 .34467 .64138 .35385 .63867 .34814 .63356 Mtetra
.657 .749 .918 r
.34814 .63356 .35385 .63867 .36306 .63596 .35738 .63079 Mtetra
.656 .748 .917 r
.35738 .63079 .36306 .63596 .3723 .63326 .36664 .62804 Mtetra
.655 .746 .917 r
.36664 .62804 .3723 .63326 .38157 .63058 .37593 .6253 Mtetra
.653 .744 .916 r
.37593 .6253 .38157 .63058 .39088 .62793 .38526 .62259 Mtetra
.651 .742 .916 r
.38526 .62259 .39088 .62793 .40021 .62532 .39462 .61995 Mtetra
.648 .74 .917 r
.39462 .61995 .40021 .62532 .40958 .62274 .404 .61736 Mtetra
.644 .739 .918 r
.404 .61736 .40958 .62274 .41898 .6202 .41342 .61485 Mtetra
.641 .74 .921 r
.41342 .61485 .41898 .6202 .42841 .61766 .42287 .61238 Mtetra
.639 .743 .924 r
.42287 .61238 .42841 .61766 .43788 .61508 .43236 .60995 Mtetra
.641 .75 .928 r
.43236 .60995 .43788 .61508 .44739 .61239 .44188 .60745 Mtetra
.646 .76 .932 r
.44188 .60745 .44739 .61239 .45693 .60952 .45144 .6048 Mtetra
.657 .773 .935 r
.45144 .6048 .45693 .60952 .46651 .60642 .46104 .60188 Mtetra
.672 .784 .933 r
.46104 .60188 .46651 .60642 .47613 .60305 .47068 .59857 Mtetra
.686 .791 .93 r
.47068 .59857 .47613 .60305 .48578 .59952 .48036 .59493 Mtetra
.697 .789 .922 r
.48036 .59493 .48578 .59952 .49546 .59591 .49007 .59099 Mtetra
.693 .776 .915 r
.49007 .59099 .49546 .59591 .50517 .59255 .4998 .58715 Mtetra
.678 .755 .909 r
.4998 .58715 .50517 .59255 .51491 .58965 .50957 .58368 Mtetra
.648 .727 .906 r
.50957 .58368 .51491 .58965 .52468 .58741 .51936 .58099 Mtetra
.607 .697 .907 r
.51936 .58099 .52468 .58741 .5345 .58595 .52919 .57931 Mtetra
.572 .676 .91 r
.52919 .57931 .5345 .58595 .54436 .58499 .53907 .57842 Mtetra
.539 .665 .918 r
.53907 .57842 .54436 .58499 .55427 .58436 .549 .57815 Mtetra
.529 .675 .93 r
.549 .57815 .55427 .58436 .56423 .58362 .55898 .57796 Mtetra
.534 .698 .945 r
.55898 .57796 .56423 .58362 .57423 .58253 .56902 .57747 Mtetra
.552 .731 .959 r
.56902 .57747 .57423 .58253 .58427 .58097 .57909 .57646 Mtetra
.578 .766 .968 r
.57909 .57646 .58427 .58097 .59435 .57888 .5892 .5748 Mtetra
.599 .794 .974 r
.5892 .5748 .59435 .57888 .60446 .57641 .59934 .57262 Mtetra
.62 .814 .975 r
.59934 .57262 .60446 .57641 .6146 .57363 .60952 .56997 Mtetra
.637 .826 .973 r
.60952 .56997 .6146 .57363 .62477 .57064 .61972 .56696 Mtetra
.655 .832 .968 r
.61972 .56696 .62477 .57064 .63497 .56743 .62995 .56359 Mtetra
.68 .832 .956 r
.62995 .56359 .63497 .56743 .6452 .56392 .6402 .55975 Mtetra
.704 .824 .939 r
.6402 .55975 .6452 .56392 .65545 .56001 .65046 .55537 Mtetra
.727 .811 .917 r
.65046 .55537 .65545 .56001 .66571 .55558 .66073 .55034 Mtetra
.741 .792 .894 r
.66073 .55034 .66571 .55558 .67597 .55066 .671 .54477 Mtetra
.744 .77 .875 r
.671 .54477 .67597 .55066 .68625 .54537 .68127 .53889 Mtetra
.737 .751 .863 r
.68127 .53889 .68625 .54537 .69654 .53997 .69158 .53308 Mtetra
.718 .733 .863 r
.69158 .53308 .69654 .53997 .70688 .53489 .70193 .52789 Mtetra
.695 .723 .871 r
.70193 .52789 .70688 .53489 .71727 .53032 .71236 .5235 Mtetra
.665 .718 .888 r
.71236 .5235 .71727 .53032 .72774 .52653 .72288 .52013 Mtetra
.636 .721 .909 r
.72288 .52013 .72774 .52653 .73829 .52341 .73349 .51755 Mtetra
.616 .734 .93 r
.73349 .51755 .73829 .52341 .74891 .52077 .74417 .51535 Mtetra
.607 .748 .945 r
.74417 .51535 .74891 .52077 .75959 .51838 .7549 .51326 Mtetra
.617 .766 .951 r
.7549 .51326 .75959 .51838 .77031 .51591 .76566 .51087 Mtetra
.631 .775 .95 r
.76566 .51087 .77031 .51591 .78107 .51328 .77643 .50813 Mtetra
.649 .778 .942 r
.77643 .50813 .78107 .51328 .79184 .51036 .78722 .505 Mtetra
.662 .775 .933 r
.78722 .505 .79184 .51036 .80264 .50721 .79803 .50158 Mtetra
.668 .767 .925 r
.79803 .50158 .80264 .50721 .81346 .50388 .80887 .498 Mtetra
.671 .76 .918 r
.80887 .498 .81346 .50388 .82432 .50042 .81974 .49435 Mtetra
.669 .753 .914 r
.81974 .49435 .82432 .50042 .83521 .49693 .83065 .49073 Mtetra
.667 .749 .911 r
.83065 .49073 .83521 .49693 .84614 .49343 .8416 .48716 Mtetra
.664 .746 .911 r
.8416 .48716 .84614 .49343 .85712 .48996 .85261 .48366 Mtetra
.661 .745 .912 r
.85261 .48366 .85712 .48996 .86814 .48652 .86366 .48023 Mtetra
.659 .745 .913 r
.86366 .48023 .86814 .48652 .8792 .48313 .87476 .47685 Mtetra
.657 .745 .915 r
.87476 .47685 .8792 .48313 .89032 .47976 .88591 .4735 Mtetra
.656 .746 .916 r
.88591 .4735 .89032 .47976 .90147 .47641 .8971 .47017 Mtetra
.655 .747 .918 r
.8971 .47017 .90147 .47641 .91268 .47307 .90834 .46684 Mtetra
.655 .749 .919 r
.90834 .46684 .91268 .47307 .92392 .46974 .91962 .46352 Mtetra
.655 .75 .92 r
.91962 .46352 .92392 .46974 .93521 .46639 .93095 .46018 Mtetra
.658 .752 .919 r
.32399 .63404 .32977 .63908 .33894 .63633 .33318 .63124 Mtetra
.658 .751 .919 r
.33318 .63124 .33894 .63633 .34814 .63356 .34241 .62843 Mtetra
.658 .75 .918 r
.34241 .62843 .34814 .63356 .35738 .63079 .35166 .62561 Mtetra
.658 .749 .917 r
.35166 .62561 .35738 .63079 .36664 .62804 .36095 .62279 Mtetra
.657 .747 .916 r
.36095 .62279 .36664 .62804 .37593 .6253 .37026 .61998 Mtetra
.656 .744 .915 r
.37026 .61998 .37593 .6253 .38526 .62259 .37961 .6172 Mtetra
.653 .741 .914 r
.37961 .6172 .38526 .62259 .39462 .61995 .38899 .61446 Mtetra
.65 .738 .914 r
.38899 .61446 .39462 .61995 .404 .61736 .3984 .61181 Mtetra
.645 .735 .914 r
.3984 .61181 .404 .61736 .41342 .61485 .40783 .60926 Mtetra
.64 .733 .916 r
.40783 .60926 .41342 .61485 .42287 .61238 .4173 .60683 Mtetra
.634 .733 .919 r
.4173 .60683 .42287 .61238 .43236 .60995 .4268 .60451 Mtetra
.633 .737 .923 r
.4268 .60451 .43236 .60995 .44188 .60745 .43634 .6022 Mtetra
.634 .745 .929 r
.43634 .6022 .44188 .60745 .45144 .6048 .44591 .59983 Mtetra
.644 .76 .933 r
.44591 .59983 .45144 .6048 .46104 .60188 .45553 .5972 Mtetra
.661 .777 .935 r
.45553 .5972 .46104 .60188 .47068 .59857 .46519 .59414 Mtetra
.682 .793 .934 r
.46519 .59414 .47068 .59857 .48036 .59493 .47489 .59057 Mtetra
.704 .801 .926 r
.47489 .59057 .48036 .59493 .49007 .59099 .48463 .58643 Mtetra
.709 .795 .918 r
.48463 .58643 .49007 .59099 .4998 .58715 .4944 .58212 Mtetra
.703 .777 .909 r
.4944 .58212 .4998 .58715 .50957 .58368 .50419 .57796 Mtetra
.673 .744 .904 r
.50419 .57796 .50957 .58368 .51936 .58099 .51401 .57459 Mtetra
.627 .706 .903 r
.51401 .57459 .51936 .58099 .52919 .57931 .52386 .57241 Mtetra
.581 .673 .902 r
.52386 .57241 .52919 .57931 .53907 .57842 .53375 .57135 Mtetra
.533 .647 .907 r
.53375 .57135 .53907 .57842 .549 .57815 .5437 .57132 Mtetra
.511 .645 .917 r
.5437 .57132 .549 .57815 .55898 .57796 .5537 .57162 Mtetra
.507 .662 .931 r
.5537 .57162 .55898 .57796 .56902 .57747 .56376 .57181 Mtetra
.523 .696 .947 r
.56376 .57181 .56902 .57747 .57909 .57646 .57386 .57146 Mtetra
.554 .737 .961 r
.57386 .57146 .57909 .57646 .5892 .5748 .584 .57035 Mtetra
.583 .772 .969 r
.584 .57035 .5892 .5748 .59934 .57262 .59418 .56855 Mtetra
.614 .801 .971 r
.59418 .56855 .59934 .57262 .60952 .56997 .60439 .56608 Mtetra
.64 .818 .968 r
.60439 .56608 .60952 .56997 .61972 .56696 .61462 .56305 Mtetra
.668 .826 .959 r
.61462 .56305 .61972 .56696 .62995 .56359 .62488 .55946 Mtetra
.699 .825 .943 r
.62488 .55946 .62995 .56359 .6402 .55975 .63514 .55519 Mtetra
.725 .814 .92 r
.63514 .55519 .6402 .55975 .65046 .55537 .64542 .55023 Mtetra
.746 .797 .893 r
.64542 .55023 .65046 .55537 .66073 .55034 .65569 .54449 Mtetra
.754 .775 .87 r
.65569 .54449 .66073 .55034 .671 .54477 .66596 .5382 Mtetra
.75 .752 .854 r
.66596 .5382 .671 .54477 .68127 .53889 .67624 .53178 Mtetra
.738 .734 .847 r
.67624 .53178 .68127 .53889 .69158 .53308 .68655 .52569 Mtetra
.711 .718 .854 r
.68655 .52569 .69158 .53308 .70193 .52789 .69694 .52062 Mtetra
.68 .711 .871 r
.69694 .52062 .70193 .52789 .71236 .5235 .70742 .51669 Mtetra
.641 .711 .897 r
.70742 .51669 .71236 .5235 .72288 .52013 .71801 .51397 Mtetra
.606 .719 .925 r
.71801 .51397 .72288 .52013 .73349 .51755 .72868 .51206 Mtetra
.59 .74 .947 r
.72868 .51206 .73349 .51755 .74417 .51535 .73942 .5103 Mtetra
.591 .759 .958 r
.73942 .5103 .74417 .51535 .7549 .51326 .75019 .50837 Mtetra
.617 .777 .957 r
.75019 .50837 .7549 .51326 .76566 .51087 .76097 .50587 Mtetra
.643 .783 .949 r
.76097 .50587 .76566 .51087 .77643 .50813 .77176 .50284 Mtetra
.663 .779 .935 r
.77176 .50284 .77643 .50813 .78722 .505 .78255 .49936 Mtetra
.674 .77 .923 r
.78255 .49936 .78722 .505 .79803 .50158 .79337 .49561 Mtetra
.676 .759 .914 r
.79337 .49561 .79803 .50158 .80887 .498 .80421 .49179 Mtetra
.675 .751 .908 r
.80421 .49179 .80887 .498 .81974 .49435 .8151 .48799 Mtetra
.671 .745 .906 r
.8151 .48799 .81974 .49435 .83065 .49073 .82604 .4843 Mtetra
.667 .742 .906 r
.82604 .4843 .83065 .49073 .8416 .48716 .83702 .48072 Mtetra
.662 .74 .908 r
.83702 .48072 .8416 .48716 .85261 .48366 .84806 .47725 Mtetra
.659 .741 .91 r
.84806 .47725 .85261 .48366 .86366 .48023 .85915 .47386 Mtetra
.657 .742 .913 r
.85915 .47386 .86366 .48023 .87476 .47685 .87028 .47052 Mtetra
.655 .744 .915 r
.87028 .47052 .87476 .47685 .88591 .4735 .88147 .4672 Mtetra
.654 .746 .917 r
.88147 .4672 .88591 .4735 .8971 .47017 .8927 .4639 Mtetra
.654 .747 .918 r
.8927 .4639 .8971 .47017 .90834 .46684 .90397 .46059 Mtetra
.654 .749 .919 r
.90397 .46059 .90834 .46684 .91962 .46352 .91529 .45726 Mtetra
.654 .75 .92 r
.91529 .45726 .91962 .46352 .93095 .46018 .92665 .45393 Mtetra
.658 .752 .919 r
.31818 .62896 .32399 .63404 .33318 .63124 .32739 .62614 Mtetra
.659 .752 .919 r
.32739 .62614 .33318 .63124 .34241 .62843 .33663 .6233 Mtetra
.659 .752 .918 r
.33663 .6233 .34241 .62843 .35166 .62561 .3459 .62044 Mtetra
.659 .751 .918 r
.3459 .62044 .35166 .62561 .36095 .62279 .35521 .61757 Mtetra
.66 .749 .916 r
.35521 .61757 .36095 .62279 .37026 .61998 .36455 .61467 Mtetra
.659 .747 .915 r
.36455 .61467 .37026 .61998 .37961 .6172 .37392 .61178 Mtetra
.658 .743 .913 r
.37392 .61178 .37961 .6172 .38899 .61446 .38332 .60892 Mtetra
.655 .738 .911 r
.38332 .60892 .38899 .61446 .3984 .61181 .39276 .60613 Mtetra
.65 .733 .91 r
.39276 .60613 .3984 .61181 .40783 .60926 .40222 .60346 Mtetra
.643 .727 .91 r
.40222 .60346 .40783 .60926 .4173 .60683 .41171 .60095 Mtetra
.633 .722 .911 r
.41171 .60095 .4173 .60683 .4268 .60451 .42122 .59865 Mtetra
.627 .721 .915 r
.42122 .59865 .4268 .60451 .43634 .6022 .43078 .5965 Mtetra
.62 .726 .922 r
.43078 .5965 .43634 .6022 .44591 .59983 .44036 .59446 Mtetra
.625 .74 .93 r
.44036 .59446 .44591 .59983 .45553 .5972 .44999 .59225 Mtetra
.64 .762 .937 r
.44999 .59225 .45553 .5972 .46519 .59414 .45966 .58966 Mtetra
.667 .789 .939 r
.45966 .58966 .46519 .59414 .47489 .59057 .46938 .58641 Mtetra
.702 .811 .932 r
.46938 .58641 .47489 .59057 .48463 .58643 .47915 .58229 Mtetra
.722 .816 .923 r
.47915 .58229 .48463 .58643 .4944 .58212 .48895 .57762 Mtetra
.731 .803 .909 r
.48895 .57762 .4944 .58212 .50419 .57796 .49877 .57266 Mtetra
.706 .769 .902 r
.49877 .57266 .50419 .57796 .51401 .57459 .50862 .56837 Mtetra
.659 .725 .897 r
.50862 .56837 .51401 .57459 .52386 .57241 .51849 .56533 Mtetra
.603 .677 .893 r
.51849 .56533 .52386 .57241 .53375 .57135 .5284 .56378 Mtetra
.539 .634 .894 r
.5284 .56378 .53375 .57135 .5437 .57132 .53836 .56374 Mtetra
.502 .618 .899 r
.53836 .56374 .5437 .57132 .5537 .57162 .54838 .56443 Mtetra
.485 .622 .911 r
.54838 .56443 .5537 .57162 .56376 .57181 .55845 .5653 Mtetra
.496 .652 .929 r
.55845 .5653 .56376 .57181 .57386 .57146 .56859 .5657 Mtetra
.529 .697 .946 r
.56859 .5657 .57386 .57146 .584 .57035 .57876 .56526 Mtetra
.566 .74 .958 r
.57876 .56526 .584 .57035 .59418 .56855 .58897 .56395 Mtetra
.608 .777 .962 r
.58897 .56395 .59418 .56855 .60439 .56608 .59921 .56171 Mtetra
.646 .801 .957 r
.59921 .56171 .60439 .56608 .61462 .56305 .60948 .55867 Mtetra
.683 .811 .944 r
.60948 .55867 .61462 .56305 .62488 .55946 .61975 .5548 Mtetra
.718 .809 .921 r
.61975 .5548 .62488 .55946 .63514 .55519 .63003 .55 Mtetra
.743 .795 .894 r
.63003 .55 .63514 .55519 .64542 .55023 .64031 .54433 Mtetra
.76 .774 .865 r
.64031 .54433 .64542 .55023 .65569 .54449 .65058 .53779 Mtetra
.762 .751 .843 r
.65058 .53779 .65569 .54449 .66596 .5382 .66085 .53076 Mtetra
.751 .729 .832 r
.66085 .53076 .66596 .5382 .67624 .53178 .67114 .52391 Mtetra
.732 .713 .833 r
.67114 .52391 .67624 .53178 .68655 .52569 .68148 .51777 Mtetra
.695 .699 .85 r
.68148 .51777 .68655 .52569 .69694 .52062 .69192 .51317 Mtetra
.654 .697 .877 r
.69192 .51317 .69694 .52062 .70742 .51669 .70246 .51006 Mtetra
.605 .703 .913 r
.70246 .51006 .70742 .51669 .71801 .51397 .71312 .50824 Mtetra
.562 .719 .946 r
.71312 .50824 .71801 .51397 .72868 .51206 .72387 .5071 Mtetra
.561 .751 .966 r
.72387 .5071 .72868 .51206 .73942 .5103 .73466 .50568 Mtetra
.585 .777 .971 r
.73466 .50568 .73942 .5103 .75019 .50837 .74546 .50369 Mtetra
.631 .793 .96 r
.74546 .50369 .75019 .50837 .76097 .50587 .75625 .50082 Mtetra
.665 .79 .941 r
.75625 .50082 .76097 .50587 .77176 .50284 .76703 .49725 Mtetra
.681 .775 .922 r
.76703 .49725 .77176 .50284 .78255 .49936 .77782 .4933 Mtetra
.687 .761 .908 r
.77782 .4933 .78255 .49936 .79337 .49561 .78864 .48918 Mtetra
.682 .747 .9 r
.78864 .48918 .79337 .49561 .80421 .49179 .7995 .48516 Mtetra
.676 .739 .897 r
.7995 .48516 .80421 .49179 .8151 .48799 .81041 .48128 Mtetra
.669 .734 .899 r
.81041 .48128 .8151 .48799 .82604 .4843 .82137 .47762 Mtetra
.663 .733 .902 r
.82137 .47762 .82604 .4843 .83702 .48072 .8324 .47413 Mtetra
.658 .735 .907 r
.8324 .47413 .83702 .48072 .84806 .47725 .84348 .47076 Mtetra
.655 .738 .911 r
.84348 .47076 .84806 .47725 .85915 .47386 .85461 .46746 Mtetra
.653 .742 .914 r
.85461 .46746 .85915 .47386 .87028 .47052 .86578 .46419 Mtetra
.653 .745 .917 r
.86578 .46419 .87028 .47052 .88147 .4672 .877 .46092 Mtetra
.653 .747 .919 r
.877 .46092 .88147 .4672 .8927 .4639 .88827 .45763 Mtetra
.653 .749 .92 r
.88827 .45763 .8927 .4639 .90397 .46059 .89958 .45432 Mtetra
.653 .75 .921 r
.89958 .45432 .90397 .46059 .91529 .45726 .91093 .45098 Mtetra
.654 .75 .921 r
.91093 .45098 .91529 .45726 .92665 .45393 .92232 .44763 Mtetra
.657 .752 .92 r
.31232 .62385 .31818 .62896 .32739 .62614 .32155 .62104 Mtetra
.658 .753 .92 r
.32155 .62104 .32739 .62614 .33663 .6233 .33081 .61819 Mtetra
.659 .754 .92 r
.33081 .61819 .33663 .6233 .3459 .62044 .34011 .61532 Mtetra
.66 .754 .92 r
.34011 .61532 .3459 .62044 .35521 .61757 .34943 .61241 Mtetra
.661 .754 .919 r
.34943 .61241 .35521 .61757 .36455 .61467 .3588 .60946 Mtetra
.662 .753 .917 r
.3588 .60946 .36455 .61467 .37392 .61178 .36819 .60648 Mtetra
.663 .75 .915 r
.36819 .60648 .37392 .61178 .38332 .60892 .37762 .60347 Mtetra
.661 .745 .912 r
.37762 .60347 .38332 .60892 .39276 .60613 .38708 .6005 Mtetra
.657 .738 .909 r
.38708 .6005 .39276 .60613 .40222 .60346 .39657 .59762 Mtetra
.65 .729 .907 r
.39657 .59762 .40222 .60346 .41171 .60095 .40608 .59492 Mtetra
.639 .72 .906 r
.40608 .59492 .41171 .60095 .42122 .59865 .41562 .59249 Mtetra
.627 .712 .907 r
.41562 .59249 .42122 .59865 .43078 .5965 .42519 .59034 Mtetra
.612 .708 .913 r
.42519 .59034 .43078 .5965 .44036 .59446 .43479 .58851 Mtetra
.608 .715 .92 r
.43479 .58851 .44036 .59446 .44999 .59225 .44442 .58672 Mtetra
.613 .732 .931 r
.44442 .58672 .44999 .59225 .45966 .58966 .4541 .58477 Mtetra
.64 .766 .939 r
.4541 .58477 .45966 .58966 .46938 .58641 .46384 .58213 Mtetra
.685 .803 .938 r
.46384 .58213 .46938 .58641 .47915 .58229 .47362 .57842 Mtetra
.724 .828 .93 r
.47362 .57842 .47915 .58229 .48895 .57762 .48345 .5737 Mtetra
.754 .83 .911 r
.48345 .5737 .48895 .57762 .49877 .57266 .49332 .56807 Mtetra
.741 .803 .902 r
.49332 .56807 .49877 .57266 .50862 .56837 .5032 .56274 Mtetra
.702 .759 .896 r
.5032 .56274 .50862 .56837 .51849 .56533 .5131 .55848 Mtetra
.639 .699 .889 r
.5131 .55848 .51849 .56533 .5284 .56378 .52302 .55596 Mtetra
.56 .638 .885 r
.52302 .55596 .5284 .56378 .53836 .56374 .53299 .55548 Mtetra
.509 .602 .882 r
.53299 .55548 .53836 .56374 .54838 .56443 .54302 .55622 Mtetra
.475 .587 .886 r
.54302 .55622 .54838 .56443 .55845 .5653 .55311 .55761 Mtetra
.479 .606 .9 r
.55311 .55761 .55845 .5653 .56859 .5657 .56326 .55873 Mtetra
.511 .645 .916 r
.56326 .55873 .56859 .5657 .57876 .56526 .57347 .559 Mtetra
.554 .69 .93 r
.57347 .559 .57876 .56526 .58897 .56395 .58371 .55824 Mtetra
.606 .733 .935 r
.58371 .55824 .58897 .56395 .59921 .56171 .59398 .5563 Mtetra
.654 .761 .928 r
.59398 .5563 .59921 .56171 .60948 .55867 .60427 .55323 Mtetra
.696 .774 .912 r
.60427 .55323 .60948 .55867 .61975 .5548 .61456 .54903 Mtetra
.731 .772 .885 r
.61456 .54903 .61975 .5548 .63003 .55 .62486 .54364 Mtetra
.753 .759 .858 r
.62486 .54364 .63003 .55 .64031 .54433 .63514 .5372 Mtetra
.763 .74 .832 r
.63514 .5372 .64031 .54433 .65058 .53779 .64541 .52989 Mtetra
.76 .721 .816 r
.64541 .52989 .65058 .53779 .66085 .53076 .65568 .5223 Mtetra
.742 .703 .814 r
.65568 .5223 .66085 .53076 .67114 .52391 .66599 .51534 Mtetra
.717 .692 .825 r
.66599 .51534 .67114 .52391 .68148 .51777 .67637 .50961 Mtetra
.668 .684 .855 r
.67637 .50961 .68148 .51777 .69192 .51317 .68687 .50594 Mtetra
.61 .686 .897 r
.68687 .50594 .69192 .51317 .70246 .51006 .69751 .50404 Mtetra
.548 .702 .941 r
.69751 .50404 .70246 .51006 .71312 .50824 .70825 .50323 Mtetra
.505 .725 .971 r
.70825 .50323 .71312 .50824 .72387 .5071 .71906 .50273 Mtetra
.543 .771 .982 r
.71906 .50273 .72387 .5071 .73466 .50568 .72988 .50132 Mtetra
.603 .797 .974 r
.72988 .50132 .73466 .50568 .74546 .50369 .74069 .49887 Mtetra
.662 .799 .948 r
.74069 .49887 .74546 .50369 .75625 .50082 .75146 .49533 Mtetra
.692 .783 .921 r
.75146 .49533 .75625 .50082 .76703 .49725 .76223 .49108 Mtetra
.696 .76 .901 r
.76223 .49108 .76703 .49725 .77782 .4933 .77301 .48665 Mtetra
.693 .744 .891 r
.77301 .48665 .77782 .4933 .78864 .48918 .78384 .48226 Mtetra
.682 .732 .889 r
.78384 .48226 .78864 .48918 .7995 .48516 .79472 .47819 Mtetra
.672 .728 .891 r
.79472 .47819 .7995 .48516 .81041 .48128 .80567 .47441 Mtetra
.663 .728 .898 r
.80567 .47441 .81041 .48128 .82137 .47762 .81668 .47091 Mtetra
.656 .731 .904 r
.81668 .47091 .82137 .47762 .8324 .47413 .82775 .46759 Mtetra
.652 .736 .911 r
.82775 .46759 .8324 .47413 .84348 .47076 .83888 .46436 Mtetra
.65 .741 .916 r
.83888 .46436 .84348 .47076 .85461 .46746 .85005 .46117 Mtetra
.65 .746 .919 r
.85005 .46117 .85461 .46746 .86578 .46419 .86126 .45795 Mtetra
.651 .749 .921 r
.86126 .45795 .86578 .46419 .877 .46092 .87252 .4547 Mtetra
.652 .751 .922 r
.87252 .4547 .877 .46092 .88827 .45763 .88382 .4514 Mtetra
.653 .752 .922 r
.88382 .4514 .88827 .45763 .89958 .45432 .89516 .44806 Mtetra
.654 .752 .922 r
.89516 .44806 .89958 .45432 .91093 .45098 .90654 .44469 Mtetra
.654 .752 .921 r
.90654 .44469 .91093 .45098 .92232 .44763 .91796 .44128 Mtetra
.655 .751 .921 r
.30643 .61871 .31232 .62385 .32155 .62104 .31568 .61593 Mtetra
.656 .753 .922 r
.31568 .61593 .32155 .62104 .33081 .61819 .32495 .61312 Mtetra
.657 .756 .923 r
.32495 .61312 .33081 .61819 .34011 .61532 .33427 .61028 Mtetra
.658 .758 .923 r
.33427 .61028 .34011 .61532 .34943 .61241 .34361 .60738 Mtetra
.661 .759 .923 r
.34361 .60738 .34943 .61241 .3588 .60946 .353 .60441 Mtetra
.664 .76 .922 r
.353 .60441 .3588 .60946 .36819 .60648 .36241 .60136 Mtetra
.667 .759 .919 r
.36241 .60136 .36819 .60648 .37762 .60347 .37187 .59823 Mtetra
.668 .756 .916 r
.37187 .59823 .37762 .60347 .38708 .6005 .38135 .59507 Mtetra
.668 .749 .911 r
.38135 .59507 .38708 .6005 .39657 .59762 .39087 .5919 Mtetra
.662 .738 .906 r
.39087 .5919 .39657 .59762 .40608 .59492 .40042 .58887 Mtetra
.652 .724 .902 r
.40042 .58887 .40608 .59492 .41562 .59249 .40999 .5861 Mtetra
.636 .708 .899 r
.40999 .5861 .41562 .59249 .42519 .59034 .41958 .58372 Mtetra
.614 .694 .901 r
.41958 .58372 .42519 .59034 .43479 .58851 .42919 .58189 Mtetra
.597 .688 .906 r
.42919 .58189 .43479 .58851 .44442 .58672 .43884 .58041 Mtetra
.583 .694 .918 r
.43884 .58041 .44442 .58672 .4541 .58477 .44852 .57918 Mtetra
.601 .728 .934 r
.44852 .57918 .4541 .58477 .46384 .58213 .45826 .57744 Mtetra
.644 .778 .945 r
.45826 .57744 .46384 .58213 .47362 .57842 .46805 .57465 Mtetra
.705 .831 .942 r
.46805 .57465 .47362 .57842 .48345 .5737 .47791 .57037 Mtetra
.766 .857 .918 r
.47791 .57037 .48345 .5737 .49332 .56807 .48781 .56439 Mtetra
.775 .843 .903 r
.48781 .56439 .49332 .56807 .5032 .56274 .49773 .55803 Mtetra
.754 .803 .892 r
.49773 .55803 .5032 .56274 .5131 .55848 .50766 .55219 Mtetra
.691 .735 .885 r
.50766 .55219 .5131 .55848 .52302 .55596 .51761 .54816 Mtetra
.603 .658 .877 r
.51761 .54816 .52302 .55596 .53299 .55548 .52759 .54662 Mtetra
.535 .6 .865 r
.52759 .54662 .53299 .55548 .54302 .55622 .53763 .54691 Mtetra
.481 .562 .86 r
.53763 .54691 .54302 .55622 .55311 .55761 .54773 .5485 Mtetra
.475 .564 .866 r
.54773 .5485 .55311 .55761 .56326 .55873 .55789 .55017 Mtetra
.5 .592 .878 r
.55789 .55017 .56326 .55873 .57347 .559 .56812 .55113 Mtetra
.544 .634 .891 r
.56812 .55113 .57347 .559 .58371 .55824 .57838 .55096 Mtetra
.602 .678 .895 r
.57838 .55096 .58371 .55824 .59398 .5563 .58868 .54932 Mtetra
.655 .709 .887 r
.58868 .54932 .59398 .5563 .60427 .55323 .59899 .54623 Mtetra
.7 .725 .869 r
.59899 .54623 .60427 .55323 .61456 .54903 .6093 .54168 Mtetra
.734 .726 .844 r
.6093 .54168 .61456 .54903 .62486 .54364 .6196 .53566 Mtetra
.751 .716 .819 r
.6196 .53566 .62486 .54364 .63514 .5372 .62988 .52847 Mtetra
.756 .702 .801 r
.62988 .52847 .63514 .5372 .64541 .52989 .64016 .52057 Mtetra
.749 .688 .793 r
.64016 .52057 .64541 .52989 .65568 .5223 .65044 .51271 Mtetra
.724 .674 .801 r
.65044 .51271 .65568 .5223 .66599 .51534 .66079 .50617 Mtetra
.689 .669 .825 r
.66079 .50617 .66599 .51534 .67637 .50961 .67123 .50146 Mtetra
.622 .665 .871 r
.67123 .50146 .67637 .50961 .68687 .50594 .68183 .49928 Mtetra
.534 .672 .926 r
.68183 .49928 .68687 .50594 .69751 .50404 .69257 .49894 Mtetra
.459 .7 .971 r
.69257 .49894 .69751 .50404 .70825 .50323 .70339 .49914 Mtetra
.441 .737 .99 r
.70339 .49914 .70825 .50323 .71906 .50273 .71425 .49896 Mtetra
.553 .805 .992 r
.71425 .49896 .71906 .50273 .72988 .50132 .72508 .49706 Mtetra
.651 .82 .965 r
.72508 .49706 .72988 .50132 .74069 .49887 .73585 .49363 Mtetra
.701 .796 .924 r
.73585 .49363 .74069 .49887 .75146 .49533 .7466 .48913 Mtetra
.714 .766 .893 r
.7466 .48913 .75146 .49533 .76223 .49108 .75734 .48409 Mtetra
.703 .738 .878 r
.75734 .48409 .76223 .49108 .77301 .48665 .76813 .47929 Mtetra
.69 .723 .874 r
.76813 .47929 .77301 .48665 .78384 .48226 .77898 .47486 Mtetra
.674 .715 .88 r
.77898 .47486 .78384 .48226 .79472 .47819 .7899 .47098 Mtetra
.661 .717 .89 r
.7899 .47098 .79472 .47819 .80567 .47441 .80091 .46751 Mtetra
.652 .724 .901 r
.80091 .46751 .80567 .47441 .81668 .47091 .81197 .46431 Mtetra
.646 .732 .912 r
.81197 .46431 .81668 .47091 .82775 .46759 .8231 .46124 Mtetra
.645 .741 .919 r
.8231 .46124 .82775 .46759 .83888 .46436 .83427 .45817 Mtetra
.645 .748 .924 r
.83427 .45817 .83888 .46436 .85005 .46117 .84548 .45507 Mtetra
.648 .753 .926 r
.84548 .45507 .85005 .46117 .86126 .45795 .85673 .45187 Mtetra
.65 .756 .927 r
.85673 .45187 .86126 .45795 .87252 .4547 .86802 .4486 Mtetra
.653 .757 .926 r
.86802 .4486 .87252 .4547 .88382 .4514 .87935 .44524 Mtetra
.654 .757 .925 r
.87935 .44524 .88382 .4514 .89516 .44806 .89071 .44183 Mtetra
.656 .755 .923 r
.89071 .44183 .89516 .44806 .90654 .44469 .90212 .43837 Mtetra
.656 .754 .922 r
.90212 .43837 .90654 .44469 .91796 .44128 .91357 .43489 Mtetra
.652 .751 .922 r
.3005 .61354 .30643 .61871 .31568 .61593 .30976 .6108 Mtetra
.652 .753 .923 r
.30976 .6108 .31568 .61593 .32495 .61312 .31905 .60805 Mtetra
.653 .756 .925 r
.31905 .60805 .32495 .61312 .33427 .61028 .32838 .60526 Mtetra
.655 .759 .926 r
.32838 .60526 .33427 .61028 .34361 .60738 .33775 .60241 Mtetra
.658 .763 .927 r
.33775 .60241 .34361 .60738 .353 .60441 .34715 .59949 Mtetra
.662 .766 .927 r
.34715 .59949 .353 .60441 .36241 .60136 .35659 .59646 Mtetra
.668 .769 .926 r
.35659 .59646 .36241 .60136 .37187 .59823 .36606 .59329 Mtetra
.672 .769 .923 r
.36606 .59329 .37187 .59823 .38135 .59507 .37558 .58999 Mtetra
.677 .766 .918 r
.37558 .58999 .38135 .59507 .39087 .5919 .38513 .58657 Mtetra
.676 .757 .912 r
.38513 .58657 .39087 .5919 .40042 .58887 .39471 .58317 Mtetra
.67 .743 .905 r
.39471 .58317 .40042 .58887 .40999 .5861 .40431 .5799 Mtetra
.654 .722 .899 r
.40431 .5799 .40999 .5861 .41958 .58372 .41394 .57704 Mtetra
.629 .698 .895 r
.41394 .57704 .41958 .58372 .42919 .58189 .42358 .57483 Mtetra
.601 .677 .894 r
.42358 .57483 .42919 .58189 .43884 .58041 .43324 .57331 Mtetra
.567 .662 .902 r
.43324 .57331 .43884 .58041 .44852 .57918 .44293 .57253 Mtetra
.564 .677 .915 r
.44293 .57253 .44852 .57918 .45826 .57744 .45266 .57172 Mtetra
.585 .719 .936 r
.45266 .57172 .45826 .57744 .46805 .57465 .46245 .57028 Mtetra
.659 .797 .949 r
.46245 .57028 .46805 .57465 .47791 .57037 .47232 .56708 Mtetra
.752 .859 .928 r
.47232 .56708 .47791 .57037 .48781 .56439 .48225 .56151 Mtetra
.794 .877 .908 r
.48225 .56151 .48781 .56439 .49773 .55803 .49221 .55461 Mtetra
.804 .855 .888 r
.49221 .55461 .49773 .55803 .50766 .55219 .50219 .54717 Mtetra
.754 .794 .885 r
.50219 .54717 .50766 .55219 .51761 .54816 .51217 .54123 Mtetra
.666 .709 .88 r
.51217 .54123 .51761 .54816 .52759 .54662 .52217 .5379 Mtetra
.583 .627 .861 r
.52217 .5379 .52759 .54662 .53763 .54691 .53221 .53694 Mtetra
.509 .562 .845 r
.53221 .53694 .53763 .54691 .54773 .5485 .54231 .53807 Mtetra
.489 .542 .837 r
.54231 .53807 .54773 .5485 .55789 .55017 .55248 .53979 Mtetra
.503 .551 .838 r
.55248 .53979 .55789 .55017 .56812 .55113 .56271 .54117 Mtetra
.543 .581 .843 r
.56271 .54117 .56812 .55113 .57838 .55096 .57299 .54143 Mtetra
.597 .618 .843 r
.57299 .54143 .57838 .55096 .58868 .54932 .58331 .54005 Mtetra
.65 .648 .835 r
.58331 .54005 .58868 .54932 .59899 .54623 .59363 .53694 Mtetra
.692 .666 .82 r
.59363 .53694 .59899 .54623 .6093 .54168 .60395 .53207 Mtetra
.723 .673 .8 r
.60395 .53207 .6093 .54168 .6196 .53566 .61426 .52557 Mtetra
.739 .671 .784 r
.61426 .52557 .6196 .53566 .62988 .52847 .62455 .51792 Mtetra
.74 .664 .776 r
.62455 .51792 .62988 .52847 .64016 .52057 .63483 .5099 Mtetra
.73 .658 .779 r
.63483 .5099 .64016 .52057 .65044 .51271 .64515 .50247 Mtetra
.695 .651 .802 r
.64515 .50247 .65044 .51271 .66079 .50617 .65557 .49714 Mtetra
.644 .654 .845 r
.65557 .49714 .66079 .50617 .67123 .50146 .66611 .4942 Mtetra
.539 .655 .911 r
.66611 .4942 .67123 .50146 .68183 .49928 .67681 .49391 Mtetra
.392 .654 .963 r
.67681 .49391 .68183 .49928 .69257 .49894 .68765 .49515 Mtetra
.342 .7 .983 r
.68765 .49515 .69257 .49894 .70339 .49914 .69853 .49587 Mtetra
.427 .77 .997 r
.69853 .49587 .70339 .49914 .71425 .49896 .70941 .49524 Mtetra
.621 .835 .982 r
.70941 .49524 .71425 .49896 .72508 .49706 .7202 .49218 Mtetra
.713 .814 .928 r
.7202 .49218 .72508 .49706 .73585 .49363 .73092 .48733 Mtetra
.727 .767 .885 r
.73092 .48733 .73585 .49363 .7466 .48913 .74163 .48183 Mtetra
.721 .735 .862 r
.74163 .48183 .7466 .48913 .75734 .48409 .75236 .47627 Mtetra
.698 .713 .86 r
.75236 .47627 .75734 .48409 .76813 .47929 .76318 .47148 Mtetra
.678 .706 .869 r
.76318 .47148 .76813 .47929 .77898 .47486 .77408 .4674 Mtetra
.659 .709 .885 r
.77408 .4674 .77898 .47486 .7899 .47098 .78507 .46398 Mtetra
.644 .718 .901 r
.78507 .46398 .7899 .47098 .80091 .46751 .79614 .46098 Mtetra
.638 .732 .916 r
.79614 .46098 .80091 .46751 .81197 .46431 .80727 .45811 Mtetra
.635 .743 .927 r
.80727 .45811 .81197 .46431 .8231 .46124 .81845 .45526 Mtetra
.638 .754 .932 r
.81845 .45526 .8231 .46124 .83427 .45817 .82966 .45229 Mtetra
.642 .76 .934 r
.82966 .45229 .83427 .45817 .84548 .45507 .84091 .44918 Mtetra
.648 .763 .933 r
.84091 .44918 .84548 .45507 .85673 .45187 .85219 .44593 Mtetra
.652 .763 .931 r
.85219 .44593 .85673 .45187 .86802 .4486 .8635 .44256 Mtetra
.655 .762 .928 r
.8635 .44256 .86802 .4486 .87935 .44524 .87485 .43911 Mtetra
.657 .76 .926 r
.87485 .43911 .87935 .44524 .89071 .44183 .88624 .43559 Mtetra
.658 .758 .923 r
.88624 .43559 .89071 .44183 .90212 .43837 .89767 .43203 Mtetra
.659 .755 .921 r
.89767 .43203 .90212 .43837 .91357 .43489 .90915 .42846 Mtetra
.65 .75 .923 r
.29453 .60833 .3005 .61354 .30976 .6108 .30381 .60563 Mtetra
.649 .752 .925 r
.30381 .60563 .30976 .6108 .31905 .60805 .31312 .60294 Mtetra
.649 .755 .927 r
.31312 .60294 .31905 .60805 .32838 .60526 .32246 .60023 Mtetra
.65 .759 .929 r
.32246 .60023 .32838 .60526 .33775 .60241 .33184 .59748 Mtetra
.652 .764 .932 r
.33184 .59748 .33775 .60241 .34715 .59949 .34125 .59468 Mtetra
.656 .77 .933 r
.34125 .59468 .34715 .59949 .35659 .59646 .35071 .59175 Mtetra
.662 .777 .934 r
.35071 .59175 .35659 .59646 .36606 .59329 .3602 .58867 Mtetra
.67 .783 .933 r
.3602 .58867 .36606 .59329 .37558 .58999 .36974 .58538 Mtetra
.681 .786 .929 r
.36974 .58538 .37558 .58999 .38513 .58657 .37932 .58182 Mtetra
.688 .783 .923 r
.37932 .58182 .38513 .58657 .39471 .58317 .38893 .57809 Mtetra
.692 .772 .913 r
.38893 .57809 .39471 .58317 .40431 .5799 .39858 .57423 Mtetra
.681 .749 .902 r
.39858 .57423 .40431 .5799 .41394 .57704 .40826 .57063 Mtetra
.66 .719 .892 r
.40826 .57063 .41394 .57704 .42358 .57483 .41794 .56758 Mtetra
.624 .681 .883 r
.41794 .56758 .42358 .57483 .43324 .57331 .42763 .56548 Mtetra
.574 .644 .883 r
.42763 .56548 .43324 .57331 .44293 .57253 .43733 .56465 Mtetra
.54 .629 .888 r
.43733 .56465 .44293 .57253 .45266 .57172 .44706 .56455 Mtetra
.515 .64 .911 r
.44706 .56455 .45266 .57172 .46245 .57028 .45683 .56474 Mtetra
.578 .726 .944 r
.45683 .56474 .46245 .57028 .47232 .56708 .46669 .56335 Mtetra
.696 .834 .949 r
.46669 .56335 .47232 .56708 .48225 .56151 .47663 .55921 Mtetra
.785 .903 .924 r
.47663 .55921 .48225 .56151 .49221 .55461 .48663 .55261 Mtetra
.841 .908 .883 r
.48663 .55261 .49221 .55461 .50219 .54717 .49666 .54391 Mtetra
.819 .863 .88 r
.49666 .54391 .50219 .54717 .51217 .54123 .50669 .53585 Mtetra
.749 .782 .88 r
.50669 .53585 .51217 .54123 .52217 .5379 .51672 .52997 Mtetra
.656 .679 .86 r
.51672 .52997 .52217 .5379 .53221 .53694 .52677 .52683 Mtetra
.561 .586 .836 r
.52677 .52683 .53221 .53694 .54231 .53807 .53688 .52657 Mtetra
.524 .541 .815 r
.53688 .52657 .54231 .53807 .55248 .53979 .54704 .5276 Mtetra
.519 .527 .804 r
.54704 .5276 .55248 .53979 .56271 .54117 .55727 .52891 Mtetra
.548 .542 .8 r
.55727 .52891 .56271 .54117 .57299 .54143 .56755 .5293 Mtetra
.594 .569 .796 r
.56755 .5293 .57299 .54143 .58331 .54005 .57787 .52806 Mtetra
.64 .596 .788 r
.57787 .52806 .58331 .54005 .59363 .53694 .5882 .52492 Mtetra
.679 .615 .777 r
.5882 .52492 .59363 .53694 .60395 .53207 .59852 .51986 Mtetra
.706 .625 .765 r
.59852 .51986 .60395 .53207 .61426 .52557 .60883 .51316 Mtetra
.718 .629 .757 r
.60883 .51316 .61426 .52557 .62455 .51792 .61914 .50553 Mtetra
.715 .628 .759 r
.61914 .50553 .62455 .51792 .63483 .5099 .62946 .49817 Mtetra
.699 .629 .775 r
.62946 .49817 .63483 .5099 .64515 .50247 .63984 .49208 Mtetra
.646 .627 .817 r
.63984 .49208 .64515 .50247 .65557 .49714 .65035 .4889 Mtetra
.553 .633 .885 r
.65035 .4889 .65557 .49714 .66611 .4942 .66102 .4885 Mtetra
.362 .625 .953 r
.66102 .4885 .66611 .4942 .67681 .49391 .67184 .49032 Mtetra
.138 .583 .926 r
.67184 .49032 .67681 .49391 .68765 .49515 .68277 .49281 Mtetra
.243 .706 .948 r
.68277 .49281 .68765 .49515 .69853 .49587 .69367 .49318 Mtetra
.516 .84 .999 r
.69367 .49318 .69853 .49587 .70941 .49524 .7045 .49105 Mtetra
.714 .843 .944 r
.7045 .49105 .70941 .49524 .7202 .49218 .71522 .48611 Mtetra
.757 .783 .875 r
.71522 .48611 .7202 .49218 .73092 .48733 .72586 .47954 Mtetra
.734 .727 .844 r
.72586 .47954 .73092 .48733 .74163 .48183 .73655 .47326 Mtetra
.711 .699 .837 r
.73655 .47326 .74163 .48183 .75236 .47627 .74731 .46771 Mtetra
.679 .687 .851 r
.74731 .46771 .75236 .47627 .76318 .47148 .75819 .46347 Mtetra
.652 .691 .873 r
.75819 .46347 .76318 .47148 .77408 .4674 .76918 .4602 Mtetra
.633 .708 .9 r
.76918 .4602 .77408 .4674 .78507 .46398 .78026 .4575 Mtetra
.62 .727 .923 r
.78026 .4575 .78507 .46398 .79614 .46098 .7914 .45506 Mtetra
.621 .749 .938 r
.7914 .45506 .79614 .46098 .80727 .45811 .80259 .45249 Mtetra
.625 .764 .946 r
.80259 .45249 .80727 .45811 .81845 .45526 .81381 .44975 Mtetra
.636 .773 .946 r
.81381 .44975 .81845 .45526 .82966 .45229 .82505 .44673 Mtetra
.645 .776 .943 r
.82505 .44673 .82966 .45229 .84091 .44918 .83632 .44349 Mtetra
.652 .774 .938 r
.83632 .44349 .84091 .44918 .85219 .44593 .84762 .44008 Mtetra
.657 .771 .933 r
.84762 .44008 .85219 .44593 .8635 .44256 .85896 .43655 Mtetra
.659 .766 .929 r
.85896 .43655 .8635 .44256 .87485 .43911 .87033 .43295 Mtetra
.661 .763 .925 r
.87033 .43295 .87485 .43911 .88624 .43559 .88174 .42931 Mtetra
.661 .759 .923 r
.88174 .42931 .88624 .43559 .89767 .43203 .89319 .42564 Mtetra
.661 .756 .92 r
.89319 .42564 .89767 .43203 .90915 .42846 .90469 .42197 Mtetra
.648 .75 .923 r
.28853 .60308 .29453 .60833 .30381 .60563 .29782 .6004 Mtetra
.647 .75 .925 r
.29782 .6004 .30381 .60563 .31312 .60294 .30714 .59773 Mtetra
.646 .751 .926 r
.30714 .59773 .31312 .60294 .32246 .60023 .3165 .59507 Mtetra
.646 .754 .928 r
.3165 .59507 .32246 .60023 .33184 .59748 .3259 .5924 Mtetra
.645 .758 .931 r
.3259 .5924 .33184 .59748 .34125 .59468 .33532 .58973 Mtetra
.647 .764 .934 r
.33532 .58973 .34125 .59468 .35071 .59175 .34479 .58698 Mtetra
.652 .773 .937 r
.34479 .58698 .35071 .59175 .3602 .58867 .35429 .5841 Mtetra
.661 .784 .94 r
.35429 .5841 .3602 .58867 .36974 .58538 .36384 .581 Mtetra
.675 .795 .939 r
.36384 .581 .36974 .58538 .37932 .58182 .37344 .57755 Mtetra
.689 .804 .936 r
.37344 .57755 .37932 .58182 .38893 .57809 .38309 .57374 Mtetra
.706 .804 .926 r
.38309 .57374 .38893 .57809 .39858 .57423 .39278 .56951 Mtetra
.708 .79 .916 r
.39278 .56951 .39858 .57423 .40826 .57063 .4025 .56521 Mtetra
.699 .764 .902 r
.4025 .56521 .40826 .57063 .41794 .56758 .41224 .56107 Mtetra
.665 .719 .889 r
.41224 .56107 .41794 .56758 .42763 .56548 .42198 .55785 Mtetra
.61 .666 .879 r
.42198 .55785 .42763 .56548 .43733 .56465 .43172 .55608 Mtetra
.551 .616 .87 r
.43172 .55608 .43733 .56465 .44706 .56455 .44146 .55586 Mtetra
.479 .578 .877 r
.44146 .55586 .44706 .56455 .45683 .56474 .45122 .55717 Mtetra
.499 .622 .903 r
.45122 .55717 .45683 .56474 .46669 .56335 .46105 .55774 Mtetra
.589 .729 .941 r
.46105 .55774 .46669 .56335 .47663 .55921 .47098 .55612 Mtetra
.725 .868 .949 r
.47098 .55612 .47663 .55921 .48663 .55261 .48099 .55118 Mtetra
.84 .93 .889 r
.48099 .55118 .48663 .55261 .49666 .54391 .49107 .54252 Mtetra
.858 .928 .872 r
.49107 .54252 .49666 .54391 .50669 .53585 .50115 .53303 Mtetra
.833 .88 .877 r
.50115 .53303 .50669 .53585 .51672 .52997 .51123 .52442 Mtetra
.751 .779 .876 r
.51123 .52442 .51672 .52997 .52677 .52683 .52131 .51838 Mtetra
.641 .662 .854 r
.52131 .51838 .52677 .52683 .53688 .52657 .53142 .51564 Mtetra
.579 .58 .818 r
.53142 .51564 .53688 .52657 .54704 .5276 .54158 .51488 Mtetra
.55 .536 .792 r
.54158 .51488 .54704 .5276 .55727 .52891 .55179 .51522 Mtetra
.564 .531 .777 r
.55179 .51522 .55727 .52891 .56755 .5293 .56206 .51513 Mtetra
.595 .543 .766 r
.56206 .51513 .56755 .5293 .57787 .52806 .57238 .51373 Mtetra
.632 .562 .758 r
.57238 .51373 .57787 .52806 .5882 .52492 .5827 .51056 Mtetra
.664 .579 .75 r
.5827 .51056 .5882 .52492 .59852 .51986 .59304 .5056 Mtetra
.685 .592 .745 r
.59304 .5056 .59852 .51986 .60883 .51316 .60336 .49933 Mtetra
.695 .601 .747 r
.60336 .49933 .60883 .51316 .61914 .50553 .6137 .49262 Mtetra
.683 .606 .764 r
.6137 .49262 .61914 .50553 .62946 .49817 .62409 .48699 Mtetra
.653 .617 .801 r
.62409 .48699 .62946 .49817 .63984 .49208 .63456 .48336 Mtetra
.552 .62 .874 r
.63456 .48336 .63984 .49208 .65035 .4889 .6452 .48307 Mtetra
.324 .6 .946 r
.6452 .48307 .65035 .4889 .66102 .4885 .656 .4854 Mtetra
0 .502 .857 r
.656 .4854 .66102 .4885 .67184 .49032 .66691 .48863 Mtetra
0 .49 .771 r
.66691 .48863 .67184 .49032 .68277 .49281 .67787 .49105 Mtetra
.372 .804 .965 r
.67787 .49105 .68277 .49281 .69367 .49318 .68872 .48969 Mtetra
.701 .87 .962 r
.68872 .48969 .69367 .49318 .7045 .49105 .69945 .48494 Mtetra
.766 .785 .868 r
.69945 .48494 .7045 .49105 .71522 .48611 .71008 .47795 Mtetra
.76 .726 .821 r
.71008 .47795 .71522 .48611 .72586 .47954 .72069 .47019 Mtetra
.719 .686 .817 r
.72069 .47019 .72586 .47954 .73655 .47326 .7314 .46398 Mtetra
.684 .673 .833 r
.7314 .46398 .73655 .47326 .74731 .46771 .74225 .45935 Mtetra
.647 .68 .867 r
.74225 .45935 .74731 .46771 .75819 .46347 .75323 .45621 Mtetra
.614 .698 .904 r
.75323 .45621 .75819 .46347 .76918 .4602 .76432 .45402 Mtetra
.599 .73 .936 r
.76432 .45402 .76918 .4602 .78026 .4575 .77548 .452 Mtetra
.593 .755 .955 r
.77548 .452 .78026 .4575 .7914 .45506 .78669 .44991 Mtetra
.609 .777 .961 r
.78669 .44991 .7914 .45506 .80259 .45249 .79792 .44738 Mtetra
.626 .786 .959 r
.79792 .44738 .80259 .45249 .81381 .44975 .80916 .44448 Mtetra
.643 .787 .951 r
.80916 .44448 .81381 .44975 .82505 .44673 .82042 .44122 Mtetra
.654 .783 .943 r
.82042 .44122 .82505 .44673 .83632 .44349 .8317 .43772 Mtetra
.66 .776 .935 r
.8317 .43772 .83632 .44349 .84762 .44008 .84301 .43408 Mtetra
.663 .769 .929 r
.84301 .43408 .84762 .44008 .85896 .43655 .85436 .43036 Mtetra
.664 .764 .924 r
.85436 .43036 .85896 .43655 .87033 .43295 .86576 .42664 Mtetra
.664 .76 .922 r
.86576 .42664 .87033 .43295 .88174 .42931 .87719 .4229 Mtetra
.663 .757 .92 r
.87719 .4229 .88174 .42931 .89319 .42564 .88868 .41916 Mtetra
.662 .755 .919 r
.88868 .41916 .89319 .42564 .90469 .42197 .90021 .41544 Mtetra
.65 .75 .923 r
.28248 .59781 .28853 .60308 .29782 .6004 .29179 .59507 Mtetra
.648 .748 .922 r
.29179 .59507 .29782 .6004 .30714 .59773 .30114 .59235 Mtetra
.646 .747 .922 r
.30114 .59235 .30714 .59773 .3165 .59507 .31052 .58968 Mtetra
.644 .746 .923 r
.31052 .58968 .3165 .59507 .3259 .5924 .31993 .58704 Mtetra
.64 .747 .926 r
.31993 .58704 .3259 .5924 .33532 .58973 .32937 .58448 Mtetra
.639 .752 .93 r
.32937 .58448 .33532 .58973 .34479 .58698 .33884 .58193 Mtetra
.637 .76 .937 r
.33884 .58193 .34479 .58698 .35429 .5841 .34835 .57937 Mtetra
.643 .774 .943 r
.34835 .57937 .35429 .5841 .36384 .581 .35791 .57664 Mtetra
.654 .793 .949 r
.35791 .57664 .36384 .581 .37344 .57755 .36751 .57362 Mtetra
.674 .816 .951 r
.36751 .57362 .37344 .57755 .38309 .57374 .37717 .5701 Mtetra
.703 .834 .945 r
.37717 .5701 .38309 .57374 .39278 .56951 .38689 .5659 Mtetra
.724 .838 .935 r
.38689 .5659 .39278 .56951 .4025 .56521 .39665 .56115 Mtetra
.74 .823 .916 r
.39665 .56115 .4025 .56521 .41224 .56107 .40646 .55592 Mtetra
.721 .78 .899 r
.40646 .55592 .41224 .56107 .42198 .55785 .41628 .55112 Mtetra
.678 .718 .879 r
.41628 .55112 .42198 .55785 .43172 .55608 .42608 .54744 Mtetra
.601 .638 .859 r
.42608 .54744 .43172 .55608 .44146 .55586 .43587 .54593 Mtetra
.494 .556 .848 r
.43587 .54593 .44146 .55586 .45122 .55717 .44563 .54725 Mtetra
.452 .534 .851 r
.44563 .54725 .45122 .55717 .46105 .55774 .45543 .54944 Mtetra
.447 .575 .89 r
.45543 .54944 .46105 .55774 .47098 .55612 .46531 .55115 Mtetra
.585 .756 .959 r
.46531 .55115 .47098 .55612 .48099 .55118 .4753 .54939 Mtetra
.784 .925 .929 r
.4753 .54939 .48099 .55118 .49107 .54252 .4854 .54264 Mtetra
.851 .976 .868 r
.4854 .54264 .49107 .54252 .50115 .53303 .49554 .53309 Mtetra
.883 .965 .842 r
.49554 .53309 .50115 .53303 .51123 .52442 .50568 .52217 Mtetra
.85 .901 .871 r
.50568 .52217 .51123 .52442 .52131 .51838 .51581 .51287 Mtetra
.756 .783 .876 r
.51581 .51287 .52131 .51838 .53142 .51564 .52594 .50665 Mtetra
.666 .661 .835 r
.52594 .50665 .53142 .51564 .54158 .51488 .5361 .50293 Mtetra
.604 .577 .797 r
.5361 .50293 .54158 .51488 .55179 .51522 .54631 .50125 Mtetra
.594 .545 .769 r
.54631 .50125 .55179 .51522 .56206 .51513 .55656 .49989 Mtetra
.605 .537 .752 r
.55656 .49989 .56206 .51513 .57238 .51373 .56686 .49794 Mtetra
.627 .545 .742 r
.56686 .49794 .57238 .51373 .5827 .51056 .57718 .49474 Mtetra
.649 .557 .737 r
.57718 .49474 .5827 .51056 .59304 .5056 .58752 .49027 Mtetra
.66 .568 .74 r
.58752 .49027 .59304 .5056 .60336 .49933 .59788 .48522 Mtetra
.661 .581 .755 r
.59788 .48522 .60336 .49933 .6137 .49262 .60827 .48048 Mtetra
.628 .589 .791 r
.60827 .48048 .6137 .49262 .62409 .48699 .61875 .47778 Mtetra
.549 .607 .863 r
.61875 .47778 .62409 .48699 .63456 .48336 .62935 .47761 Mtetra
.261 .568 .937 r
.62935 .47761 .63456 .48336 .6452 .48307 .64012 .48057 Mtetra
0 .332 .693 r
.64012 .48057 .6452 .48307 .656 .4854 .65104 .48521 Mtetra
.33 0 0 r
.65104 .48521 .656 .4854 .66691 .48863 .66199 .48847 Mtetra
.033 0 0 r
.66199 .48847 .66691 .48863 .67787 .49105 .67291 .4889 Mtetra
.665 .917 .976 r
.67291 .4889 .67787 .49105 .68872 .48969 .68364 .48427 Mtetra
.799 .813 .863 r
.68364 .48427 .68872 .48969 .69945 .48494 .69422 .47608 Mtetra
.769 .714 .801 r
.69422 .47608 .69945 .48494 .71008 .47795 .70479 .46738 Mtetra
.737 .671 .785 r
.70479 .46738 .71008 .47795 .72069 .47019 .71541 .45956 Mtetra
.683 .646 .807 r
.71541 .45956 .72069 .47019 .7314 .46398 .72623 .45463 Mtetra
.632 .649 .849 r
.72623 .45463 .7314 .46398 .74225 .45935 .73722 .45191 Mtetra
.589 .682 .905 r
.73722 .45191 .74225 .45935 .75323 .45621 .74833 .45035 Mtetra
.549 .721 .953 r
.74833 .45035 .75323 .45621 .76432 .45402 .75954 .44924 Mtetra
.552 .768 .979 r
.75954 .44924 .76432 .45402 .77548 .452 .77076 .44764 Mtetra
.572 .797 .984 r
.77076 .44764 .77548 .452 .78669 .44991 .782 .44548 Mtetra
.613 .811 .976 r
.782 .44548 .78669 .44991 .79792 .44738 .79324 .4426 Mtetra
.643 .808 .963 r
.79324 .4426 .79792 .44738 .80916 .44448 .80448 .43922 Mtetra
.66 .796 .947 r
.80448 .43922 .80916 .44448 .82042 .44122 .81573 .43552 Mtetra
.669 .783 .934 r
.81573 .43552 .82042 .44122 .8317 .43772 .82702 .43165 Mtetra
.669 .77 .925 r
.82702 .43165 .8317 .43772 .84301 .43408 .83834 .42776 Mtetra
.669 .761 .92 r
.83834 .42776 .84301 .43408 .85436 .43036 .84971 .42388 Mtetra
.666 .755 .917 r
.84971 .42388 .85436 .43036 .86576 .42664 .86113 .42007 Mtetra
.664 .753 .916 r
.86113 .42007 .86576 .42664 .87719 .4229 .8726 .41631 Mtetra
.662 .752 .917 r
.8726 .41631 .87719 .4229 .88868 .41916 .88412 .41257 Mtetra
.661 .752 .918 r
.88412 .41257 .88868 .41916 .90021 .41544 .89569 .40886 Mtetra
.654 .751 .921 r
.27639 .59249 .28248 .59781 .29179 .59507 .28573 .58964 Mtetra
.653 .747 .919 r
.28573 .58964 .29179 .59507 .30114 .59235 .29511 .5868 Mtetra
.651 .743 .917 r
.29511 .5868 .30114 .59235 .31052 .58968 .30451 .58402 Mtetra
.647 .739 .916 r
.30451 .58402 .31052 .58968 .31993 .58704 .31394 .58131 Mtetra
.641 .735 .917 r
.31394 .58131 .31993 .58704 .32937 .58448 .3234 .57874 Mtetra
.636 .734 .919 r
.3234 .57874 .32937 .58448 .33884 .58193 .33289 .57627 Mtetra
.628 .735 .925 r
.33289 .57627 .33884 .58193 .34835 .57937 .3424 .57395 Mtetra
.627 .745 .932 r
.3424 .57395 .34835 .57937 .35791 .57664 .35196 .57162 Mtetra
.628 .761 .942 r
.35196 .57162 .35791 .57664 .36751 .57362 .36155 .56919 Mtetra
.644 .79 .952 r
.36155 .56919 .36751 .57362 .37717 .5701 .37121 .56633 Mtetra
.673 .824 .956 r
.37121 .56633 .37717 .5701 .38689 .5659 .38093 .56276 Mtetra
.71 .858 .953 r
.38093 .56276 .38689 .5659 .39665 .56115 .39071 .55829 Mtetra
.753 .873 .934 r
.39071 .55829 .39665 .56115 .40646 .55592 .40057 .55268 Mtetra
.766 .859 .919 r
.40057 .55268 .40646 .55592 .41628 .55112 .41045 .54668 Mtetra
.757 .812 .897 r
.41045 .54668 .41628 .55112 .42608 .54744 .42036 .5408 Mtetra
.685 .724 .88 r
.42036 .5408 .42608 .54744 .43587 .54593 .43022 .53689 Mtetra
.57 .615 .858 r
.43022 .53689 .43587 .54593 .44563 .54725 .44004 .53621 Mtetra
.477 .524 .828 r
.44004 .53621 .44563 .54725 .45543 .54944 .44985 .53818 Mtetra
.382 .467 .823 r
.44985 .53818 .45543 .54944 .46531 .55115 .45968 .54224 Mtetra
.448 .56 .876 r
.45968 .54224 .46531 .55115 .4753 .54939 .46962 .54411 Mtetra
.635 .762 .939 r
.46962 .54411 .4753 .54939 .4854 .54264 .4797 .54142 Mtetra
.787 .947 .926 r
.4797 .54142 .4854 .54264 .49554 .53309 .48986 .53436 Mtetra
.866 .992 .823 r
.48986 .53436 .49554 .53309 .50568 .52217 .50006 .52335 Mtetra
.873 .99 .82 r
.50006 .52335 .50568 .52217 .51581 .51287 .51025 .51213 Mtetra
.856 .956 .874 r
.51025 .51213 .51581 .51287 .52594 .50665 .52043 .5026 Mtetra
.79 .842 .891 r
.52043 .5026 .52594 .50665 .5361 .50293 .53062 .49544 Mtetra
.697 .711 .86 r
.53062 .49544 .5361 .50293 .54631 .50125 .54082 .49089 Mtetra
.651 .629 .814 r
.54082 .49089 .54631 .50125 .55656 .49989 .55107 .48749 Mtetra
.633 .587 .785 r
.55107 .48749 .55656 .49989 .56686 .49794 .56136 .48455 Mtetra
.635 .575 .77 r
.56136 .48455 .56686 .49794 .57718 .49474 .57169 .48131 Mtetra
.641 .578 .769 r
.57169 .48131 .57718 .49474 .58752 .49027 .58205 .47779 Mtetra
.635 .588 .784 r
.58205 .47779 .58752 .49027 .59788 .48522 .59245 .47473 Mtetra
.61 .609 .825 r
.59245 .47473 .59788 .48522 .60827 .48048 .60293 .47282 Mtetra
.488 .622 .908 r
.60293 .47282 .60827 .48048 .61875 .47778 .61352 .47354 Mtetra
.113 .542 .916 r
.61352 .47354 .61875 .47778 .62935 .47761 .62425 .47668 Mtetra
.415 0 0 r
.62425 .47668 .62935 .47761 .64012 .48057 .63512 .48156 Mtetra
.507 0 0 r
.63512 .48156 .64012 .48057 .65104 .48521 .64608 .48624 Mtetra
.192 0 0 r
.64608 .48624 .65104 .48521 .66199 .48847 .65697 .48694 Mtetra
.572 .908 .976 r
.65697 .48694 .66199 .48847 .67291 .4889 .66774 .48322 Mtetra
.8 .805 .856 r
.66774 .48322 .67291 .4889 .68364 .48427 .67833 .47483 Mtetra
.79 .71 .775 r
.67833 .47483 .68364 .48427 .69422 .47608 .68882 .4642 Mtetra
.736 .65 .764 r
.68882 .4642 .69422 .47608 .70479 .46738 .69942 .45567 Mtetra
.693 .633 .785 r
.69942 .45567 .70479 .46738 .71541 .45956 .71017 .44984 Mtetra
.626 .639 .843 r
.71017 .44984 .71541 .45956 .72623 .45463 .72115 .44731 Mtetra
.541 .664 .917 r
.72115 .44731 .72623 .45463 .73722 .45191 .73231 .44682 Mtetra
.483 .723 .976 r
.73231 .44682 .73722 .45191 .74833 .45035 .74353 .44645 Mtetra
.46 .766 .996 r
.74353 .44645 .74833 .45035 .75954 .44924 .7548 .44569 Mtetra
.528 .815 .998 r
.7548 .44569 .75954 .44924 .77076 .44764 .76604 .44376 Mtetra
.598 .831 .988 r
.76604 .44376 .77076 .44764 .782 .44548 .77727 .4409 Mtetra
.649 .82 .965 r
.77727 .4409 .782 .44548 .79324 .4426 .78848 .43731 Mtetra
.674 .8 .942 r
.78848 .43731 .79324 .4426 .80448 .43922 .7997 .43326 Mtetra
.679 .777 .925 r
.7997 .43326 .80448 .43922 .81573 .43552 .81095 .42911 Mtetra
.679 .762 .913 r
.81095 .42911 .81573 .43552 .82702 .43165 .82224 .42494 Mtetra
.674 .75 .909 r
.82224 .42494 .82702 .43165 .83834 .42776 .83359 .42091 Mtetra
.669 .745 .907 r
.83359 .42091 .83834 .42776 .84971 .42388 .84499 .417 Mtetra
.664 .743 .908 r
.84499 .417 .84971 .42388 .86113 .42007 .85645 .41322 Mtetra
.661 .743 .911 r
.85645 .41322 .86113 .42007 .8726 .41631 .86796 .40952 Mtetra
.659 .745 .914 r
.86796 .40952 .8726 .41631 .88412 .41257 .87952 .40587 Mtetra
.657 .748 .917 r
.87952 .40587 .88412 .41257 .89569 .40886 .89113 .40224 Mtetra
.661 .753 .918 r
.27027 .58715 .27639 .59249 .28573 .58964 .27964 .58413 Mtetra
.661 .747 .914 r
.27964 .58413 .28573 .58964 .29511 .5868 .28904 .58109 Mtetra
.659 .741 .91 r
.28904 .58109 .29511 .5868 .30451 .58402 .29848 .57811 Mtetra
.654 .733 .907 r
.29848 .57811 .30451 .58402 .31394 .58131 .30794 .57521 Mtetra
.649 .726 .905 r
.30794 .57521 .31394 .58131 .3234 .57874 .31742 .57245 Mtetra
.64 .718 .904 r
.31742 .57245 .3234 .57874 .33289 .57627 .32693 .56989 Mtetra
.628 .711 .906 r
.32693 .56989 .33289 .57627 .3424 .57395 .33646 .56762 Mtetra
.618 .71 .911 r
.33646 .56762 .3424 .57395 .35196 .57162 .34602 .56557 Mtetra
.605 .716 .923 r
.34602 .56557 .35196 .57162 .36155 .56919 .3556 .56375 Mtetra
.606 .74 .94 r
.3556 .56375 .36155 .56919 .37121 .56633 .36523 .56179 Mtetra
.616 .78 .96 r
.36523 .56179 .37121 .56633 .38093 .56276 .37492 .55945 Mtetra
.653 .842 .973 r
.37492 .55945 .38093 .56276 .39071 .55829 .38469 .55611 Mtetra
.715 .9 .962 r
.38469 .55611 .39071 .55829 .40057 .55268 .39455 .55126 Mtetra
.769 .932 .938 r
.39455 .55126 .40057 .55268 .41045 .54668 .40449 .54495 Mtetra
.818 .916 .904 r
.40449 .54495 .41045 .54668 .42036 .5408 .41449 .5372 Mtetra
.791 .847 .894 r
.41449 .5372 .42036 .5408 .43022 .53689 .42448 .53021 Mtetra
.708 .732 .869 r
.42448 .53021 .43022 .53689 .44004 .53621 .43442 .52548 Mtetra
.574 .582 .823 r
.43442 .52548 .44004 .53621 .44985 .53818 .44429 .5248 Mtetra
.411 .446 .787 r
.44429 .5248 .44985 .53818 .45968 .54224 .45411 .52903 Mtetra
.381 .432 .789 r
.45411 .52903 .45968 .54224 .46962 .54411 .46399 .5339 Mtetra
.418 .513 .848 r
.46399 .5339 .46962 .54411 .4797 .54142 .47399 .5368 Mtetra
.583 .774 .97 r
.47399 .5368 .4797 .54142 .48986 .53436 .48412 .53488 Mtetra
.779 .991 .887 r
.48412 .53488 .48986 .53436 .50006 .52335 .49435 .52689 Mtetra
.744 .974 .715 r
.49435 .52689 .50006 .52335 .51025 .51213 .50461 .51614 Mtetra
.754 .967 .683 r
.50461 .51614 .51025 .51213 .52043 .5026 .51486 .50447 Mtetra
.815 1 .806 r
.51486 .50447 .52043 .5026 .53062 .49544 .5251 .49419 Mtetra
.809 .951 .912 r
.5251 .49419 .53062 .49544 .54082 .49089 .53534 .48639 Mtetra
.754 .825 .908 r
.53534 .48639 .54082 .49089 .55107 .48749 .5456 .48045 Mtetra
.69 .725 .876 r
.5456 .48045 .55107 .48749 .56136 .48455 .5559 .47618 Mtetra
.654 .675 .858 r
.5559 .47618 .56136 .48455 .57169 .48131 .56624 .47292 Mtetra
.621 .662 .868 r
.56624 .47292 .57169 .48131 .58205 .47779 .57664 .47068 Mtetra
.544 .667 .917 r
.57664 .47068 .58205 .47779 .59245 .47473 .58712 .47012 Mtetra
.326 .658 .972 r
.58712 .47012 .59245 .47473 .60293 .47282 .59769 .47144 Mtetra
.29 0 0 r
.59769 .47144 .60293 .47282 .61352 .47354 .6084 .47528 Mtetra
.565 .011 0 r
.6084 .47528 .61352 .47354 .62425 .47668 .61923 .48054 Mtetra
.561 .05 0 r
.61923 .48054 .62425 .47668 .63512 .48156 .63014 .48491 Mtetra
.41 0 0 r
.63014 .48491 .63512 .48156 .64608 .48624 .64103 .48651 Mtetra
.496 .906 .876 r
.64103 .48651 .64608 .48624 .65697 .48694 .65177 .48196 Mtetra
.827 .83 .85 r
.65177 .48196 .65697 .48694 .66774 .48322 .66233 .4725 Mtetra
.787 .688 .755 r
.66233 .4725 .66774 .48322 .67833 .47483 .67281 .46101 Mtetra
.75 .634 .731 r
.67281 .46101 .67833 .47483 .68882 .4642 .6833 .45014 Mtetra
.679 .596 .756 r
.6833 .45014 .68882 .4642 .69942 .45567 .69404 .44426 Mtetra
.602 .594 .816 r
.69404 .44426 .69942 .45567 .71017 .44984 .70504 .44253 Mtetra
.485 .638 .922 r
.70504 .44253 .71017 .44984 .72115 .44731 .71623 .44312 Mtetra
.296 .662 .972 r
.71623 .44312 .72115 .44731 .73231 .44682 .72753 .4445 Mtetra
.279 .733 .956 r
.72753 .4445 .73231 .44682 .74353 .44645 .73882 .44441 Mtetra
.401 .815 .975 r
.73882 .44441 .74353 .44645 .7548 .44569 .75007 .44284 Mtetra
.579 .869 .995 r
.75007 .44284 .7548 .44569 .76604 .44376 .76127 .4397 Mtetra
.669 .85 .969 r
.76127 .4397 .76604 .44376 .77727 .4409 .77243 .43553 Mtetra
.694 .804 .933 r
.77243 .43553 .77727 .4409 .78848 .43731 .78361 .43095 Mtetra
.698 .77 .908 r
.78361 .43095 .78848 .43731 .7997 .43326 .7948 .42622 Mtetra
.688 .745 .895 r
.7948 .42622 .7997 .43326 .81095 .42911 .80606 .42173 Mtetra
.68 .732 .89 r
.80606 .42173 .81095 .42911 .82224 .42494 .81737 .41747 Mtetra
.67 .726 .891 r
.81737 .41747 .82224 .42494 .83359 .42091 .82876 .41349 Mtetra
.663 .725 .895 r
.82876 .41349 .83359 .42091 .84499 .417 .8402 .40972 Mtetra
.658 .728 .901 r
.8402 .40972 .84499 .417 .85645 .41322 .85171 .4061 Mtetra
.654 .733 .907 r
.85171 .4061 .85645 .41322 .86796 .40952 .86327 .40256 Mtetra
.652 .738 .913 r
.86327 .40256 .86796 .40952 .87952 .40587 .87489 .39907 Mtetra
.652 .744 .917 r
.87489 .39907 .87952 .40587 .89113 .40224 .88655 .39556 Mtetra
.665 .754 .916 r
.2641 .58177 .27027 .58715 .27964 .58413 .2735 .57861 Mtetra
.667 .75 .912 r
.2735 .57861 .27964 .58413 .28904 .58109 .28294 .5754 Mtetra
.666 .744 .908 r
.28294 .5754 .28904 .58109 .29848 .57811 .2924 .5722 Mtetra
.664 .737 .904 r
.2924 .5722 .29848 .57811 .30794 .57521 .3019 .56905 Mtetra
.66 .728 .9 r
.3019 .56905 .30794 .57521 .31742 .57245 .31142 .56597 Mtetra
.652 .716 .895 r
.31142 .56597 .31742 .57245 .32693 .56989 .32097 .5631 Mtetra
.64 .703 .892 r
.32097 .5631 .32693 .56989 .33646 .56762 .33053 .56053 Mtetra
.624 .689 .89 r
.33053 .56053 .33646 .56762 .34602 .56557 .3401 .55835 Mtetra
.602 .678 .894 r
.3401 .55835 .34602 .56557 .3556 .56375 .34969 .5567 Mtetra
.588 .678 .903 r
.34969 .5567 .3556 .56375 .36523 .56179 .35931 .55534 Mtetra
.572 .693 .923 r
.35931 .55534 .36523 .56179 .37492 .55945 .36896 .55418 Mtetra
.591 .744 .95 r
.36896 .55418 .37492 .55945 .38469 .55611 .37869 .55242 Mtetra
.636 .823 .972 r
.37869 .55242 .38469 .55611 .39455 .55126 .3885 .54944 Mtetra
.71 .915 .965 r
.3885 .54944 .39455 .55126 .40449 .54495 .39843 .54451 Mtetra
.799 .963 .914 r
.39843 .54451 .40449 .54495 .41449 .5372 .40847 .53701 Mtetra
.834 .966 .89 r
.40847 .53701 .41449 .5372 .42448 .53021 .41855 .52836 Mtetra
.841 .909 .883 r
.41855 .52836 .42448 .53021 .43442 .52548 .42864 .51959 Mtetra
.727 .762 .881 r
.42864 .51959 .43442 .52548 .44429 .5248 .43865 .51435 Mtetra
.533 .568 .837 r
.43865 .51435 .44429 .5248 .45411 .52903 .44855 .51474 Mtetra
.43 .446 .775 r
.44855 .51474 .45411 .52903 .46399 .5339 .45843 .51875 Mtetra
.357 .39 .759 r
.45843 .51875 .46399 .5339 .47399 .5368 .46836 .52496 Mtetra
.423 .483 .817 r
.46836 .52496 .47399 .5368 .48412 .53488 .47842 .52833 Mtetra
.611 .712 .916 r
.47842 .52833 .48412 .53488 .49435 .52689 .48862 .52625 Mtetra
.742 .966 .935 r
.48862 .52625 .49435 .52689 .50461 .51614 .4989 .51979 Mtetra
.687 .954 .697 r
.4989 .51979 .50461 .51614 .51486 .50447 .50921 .50973 Mtetra
.558 .858 .547 r
.50921 .50973 .51486 .50447 .5251 .49419 .51952 .49922 Mtetra
.477 .817 .526 r
.51952 .49922 .5251 .49419 .53534 .48639 .52982 .48989 Mtetra
.48 .857 .636 r
.52982 .48989 .53534 .48639 .5456 .48045 .54014 .48235 Mtetra
.431 .862 .748 r
.54014 .48235 .5456 .48045 .5559 .47618 .55048 .47708 Mtetra
.315 .804 .789 r
.55048 .47708 .5559 .47618 .56624 .47292 .56087 .4738 Mtetra
0 0 0 r
.56087 .4738 .56624 .47292 .57664 .47068 .57133 .47254 Mtetra
.292 0 0 r
.57133 .47254 .57664 .47068 .58712 .47012 .58188 .47355 Mtetra
.487 0 0 r
.58188 .47355 .58712 .47012 .59769 .47144 .59254 .47638 Mtetra
.561 .074 .055 r
.59254 .47638 .59769 .47144 .6084 .47528 .6033 .48043 Mtetra
.546 .059 .052 r
.6033 .48043 .6084 .47528 .61923 .48054 .61414 .48404 Mtetra
.305 0 0 r
.61414 .48404 .61923 .48054 .63014 .48491 .62496 .48404 Mtetra
.586 .93 .952 r
.62496 .48404 .63014 .48491 .64103 .48651 .63569 .47961 Mtetra
.811 .771 .815 r
.63569 .47961 .64103 .48651 .65177 .48196 .64626 .46964 Mtetra
.785 .666 .732 r
.64626 .46964 .65177 .48196 .66233 .4725 .6567 .45675 Mtetra
.733 .607 .718 r
.6567 .45675 .66233 .4725 .67281 .46101 .66722 .44608 Mtetra
.691 .593 .742 r
.66722 .44608 .67281 .46101 .6833 .45014 .6779 .43907 Mtetra
.588 .594 .826 r
.6779 .43907 .6833 .45014 .69404 .44426 .6889 .4378 Mtetra
.346 .594 .938 r
.6889 .4378 .69404 .44426 .70504 .44253 .70014 .44016 Mtetra
.024 .554 .855 r
.70014 .44016 .70504 .44253 .71623 .44312 .71146 .44242 Mtetra
0 .541 .738 r
.71146 .44242 .71623 .44312 .72753 .4445 .72279 .4435 Mtetra
.292 .78 .904 r
.72279 .4435 .72753 .4445 .73882 .44441 .73403 .44197 Mtetra
.589 .889 .99 r
.73403 .44197 .73882 .44441 .75007 .44284 .74519 .43841 Mtetra
.7 .844 .951 r
.74519 .43841 .75007 .44284 .76127 .4397 .75631 .4336 Mtetra
.722 .787 .904 r
.75631 .4336 .76127 .4397 .77243 .43553 .76742 .42815 Mtetra
.709 .742 .878 r
.76742 .42815 .77243 .43553 .78361 .43095 .77857 .42291 Mtetra
.696 .719 .867 r
.77857 .42291 .78361 .43095 .7948 .42622 .78978 .41796 Mtetra
.68 .707 .868 r
.78978 .41796 .7948 .42622 .80606 .42173 .80107 .41355 Mtetra
.669 .705 .875 r
.80107 .41355 .80606 .42173 .81737 .41747 .81244 .40955 Mtetra
.659 .709 .885 r
.81244 .40955 .81737 .41747 .82876 .41349 .82387 .40585 Mtetra
.653 .716 .894 r
.82387 .40585 .82876 .41349 .8402 .40972 .83538 .40237 Mtetra
.65 .724 .903 r
.83538 .40237 .8402 .40972 .85171 .4061 .84694 .39896 Mtetra
.647 .731 .91 r
.84694 .39896 .85171 .4061 .86327 .40256 .85855 .3956 Mtetra
.646 .737 .916 r
.85855 .3956 .86327 .40256 .87489 .39907 .87022 .39225 Mtetra
.647 .743 .919 r
.87022 .39225 .87489 .39907 .88655 .39556 .88193 .38884 Mtetra
.667 .754 .915 r
.25789 .57635 .2641 .58177 .2735 .57861 .26732 .57313 Mtetra
.67 .753 .913 r
.26732 .57313 .2735 .57861 .28294 .5754 .27678 .56983 Mtetra
.672 .751 .91 r
.27678 .56983 .28294 .5754 .2924 .5722 .28627 .56647 Mtetra
.673 .747 .906 r
.28627 .56647 .2924 .5722 .3019 .56905 .29581 .56307 Mtetra
.674 .739 .899 r
.29581 .56307 .3019 .56905 .31142 .56597 .30537 .55961 Mtetra
.67 .726 .892 r
.30537 .55961 .31142 .56597 .32097 .5631 .31497 .55624 Mtetra
.662 .709 .883 r
.31497 .55624 .32097 .5631 .33053 .56053 .32458 .55304 Mtetra
.646 .686 .874 r
.32458 .55304 .33053 .56053 .3401 .55835 .3342 .55027 Mtetra
.622 .662 .868 r
.3342 .55027 .3401 .55835 .34969 .5567 .34383 .54813 Mtetra
.594 .639 .865 r
.34383 .54813 .34969 .5567 .35931 .55534 .35346 .54673 Mtetra
.557 .622 .873 r
.35346 .54673 .35931 .55534 .36896 .55418 .36309 .54624 Mtetra
.538 .633 .893 r
.36309 .54624 .36896 .55418 .37869 .55242 .37275 .54603 Mtetra
.523 .678 .936 r
.37275 .54603 .37869 .55242 .3885 .54944 .38247 .54568 Mtetra
.568 .803 .988 r
.38247 .54568 .3885 .54944 .39843 .54451 .39231 .54374 Mtetra
.653 .94 .963 r
.39231 .54374 .39843 .54451 .40847 .53701 .40229 .5391 Mtetra
.709 .985 .829 r
.40229 .5391 .40847 .53701 .41855 .52836 .41241 .53123 Mtetra
.836 .998 .781 r
.41241 .53123 .41855 .52836 .42864 .51959 .42263 .51995 Mtetra
.873 .97 .851 r
.42263 .51995 .42864 .51959 .43865 .51435 .43283 .50947 Mtetra
.78 .806 .873 r
.43283 .50947 .43865 .51435 .44855 .51474 .44293 .50241 Mtetra
.592 .567 .794 r
.44293 .50241 .44855 .51474 .45843 .51875 .45292 .50107 Mtetra
.421 .402 .733 r
.45292 .50107 .45843 .51875 .46836 .52496 .46284 .50639 Mtetra
.388 .373 .722 r
.46284 .50639 .46836 .52496 .47842 .52833 .47282 .51311 Mtetra
.4 .418 .763 r
.47282 .51311 .47842 .52833 .48862 .52625 .48292 .51825 Mtetra
.474 .607 .903 r
.48292 .51825 .48862 .52625 .4989 .51979 .49315 .51921 Mtetra
.589 .931 .951 r
.49315 .51921 .4989 .51979 .50921 .50973 .50348 .51489 Mtetra
0 0 0 r
.50348 .51489 .50921 .50973 .51952 .49922 .51385 .50788 Mtetra
.51385 .50788 .51952 .49922 .52982 .48989 .52424 .49967 Mtetra
.097 0 0 r
.52424 .49967 .52982 .48989 .54014 .48235 .53463 .49224 Mtetra
.218 0 .054 r
.53463 .49224 .54014 .48235 .55048 .47708 .54505 .4867 Mtetra
.327 0 .101 r
.54505 .4867 .55048 .47708 .56087 .4738 .55552 .48342 Mtetra
.424 .011 .15 r
.55552 .48342 .56087 .4738 .57133 .47254 .56605 .4824 Mtetra
.493 .083 .191 r
.56605 .4824 .57133 .47254 .58188 .47355 .57667 .48328 Mtetra
.516 .104 .198 r
.57667 .48328 .58188 .47355 .59254 .47638 .58738 .48498 Mtetra
.466 .037 .138 r
.58738 .48498 .59254 .47638 .6033 .48043 .59813 .48548 Mtetra
.221 0 0 r
.59813 .48548 .6033 .48043 .61414 .48404 .60887 .48327 Mtetra
.772 .976 .916 r
.60887 .48327 .61414 .48404 .62496 .48404 .61951 .47572 Mtetra
.817 .738 .777 r
.61951 .47572 .62496 .48404 .63569 .47961 .63004 .46391 Mtetra
.761 .622 .706 r
.63004 .46391 .63569 .47961 .64626 .46964 .64048 .45048 Mtetra
.724 .579 .691 r
.64048 .45048 .64626 .46964 .6567 .45675 .65096 .43844 Mtetra
.649 .541 .719 r
.65096 .43844 .6567 .45675 .66722 .44608 .66171 .43314 Mtetra
.538 .536 .8 r
.66171 .43314 .66722 .44608 .6779 .43907 .67275 .43368 Mtetra
.133 .508 .91 r
.67275 .43368 .6779 .43907 .6889 .4378 .68403 .43773 Mtetra
.445 0 0 r
.68403 .43773 .6889 .4378 .70014 .44016 .69545 .44263 Mtetra
.345 0 0 r
.69545 .44263 .70014 .44016 .71146 .44242 .70677 .44404 Mtetra
0 0 0 r
.70677 .44404 .71146 .44242 .72279 .4435 .71799 .44217 Mtetra
.606 .932 .961 r
.71799 .44217 .72279 .4435 .73403 .44197 .72908 .43751 Mtetra
.754 .856 .925 r
.72908 .43751 .73403 .44197 .74519 .43841 .74009 .4312 Mtetra
.741 .758 .866 r
.74009 .4312 .74519 .43841 .75631 .4336 .75113 .42474 Mtetra
.721 .708 .837 r
.75113 .42474 .75631 .4336 .76742 .42815 .76221 .41855 Mtetra
.694 .68 .833 r
.76221 .41855 .76742 .42815 .77857 .42291 .77338 .41329 Mtetra
.675 .673 .84 r
.77338 .41329 .77857 .42291 .78978 .41796 .78465 .40879 Mtetra
.66 .676 .855 r
.78465 .40879 .78978 .41796 .80107 .41355 .79602 .40496 Mtetra
.649 .687 .872 r
.79602 .40496 .80107 .41355 .81244 .40955 .80746 .40155 Mtetra
.643 .702 .889 r
.80746 .40155 .81244 .40955 .82387 .40585 .81897 .39833 Mtetra
.64 .715 .902 r
.81897 .39833 .82387 .40585 .83538 .40237 .83054 .3952 Mtetra
.641 .728 .912 r
.83054 .3952 .83538 .40237 .84694 .39896 .84216 .39201 Mtetra
.642 .736 .917 r
.84216 .39201 .84694 .39896 .85855 .3956 .85382 .38876 Mtetra
.643 .742 .921 r
.85382 .38876 .85855 .3956 .87022 .39225 .86553 .38546 Mtetra
.645 .746 .922 r
.86553 .38546 .87022 .39225 .88193 .38884 .87727 .38207 Mtetra
.663 .753 .917 r
.25164 .57089 .25789 .57635 .26732 .57313 .26108 .56776 Mtetra
.666 .757 .919 r
.26108 .56776 .26732 .57313 .27678 .56983 .27055 .56454 Mtetra
.67 .762 .92 r
.27055 .56454 .27678 .56983 .28627 .56647 .28007 .56121 Mtetra
.675 .765 .918 r
.28007 .56121 .28627 .56647 .29581 .56307 .28963 .55774 Mtetra
.682 .765 .914 r
.28963 .55774 .29581 .56307 .30537 .55961 .29923 .55407 Mtetra
.685 .759 .907 r
.29923 .55407 .30537 .55961 .31497 .55624 .30887 .5503 Mtetra
.687 .746 .897 r
.30887 .5503 .31497 .55624 .32458 .55304 .31854 .54645 Mtetra
.677 .723 .885 r
.31854 .54645 .32458 .55304 .3342 .55027 .32823 .54282 Mtetra
.659 .694 .871 r
.32823 .54282 .3342 .55027 .34383 .54813 .33793 .53961 Mtetra
.629 .655 .857 r
.33793 .53961 .34383 .54813 .35346 .54673 .34762 .53724 Mtetra
.586 .614 .847 r
.34762 .53724 .35346 .54673 .36309 .54624 .35728 .53609 Mtetra
.546 .582 .841 r
.35728 .53609 .36309 .54624 .37275 .54603 .36695 .53604 Mtetra
.496 .561 .851 r
.36695 .53604 .37275 .54603 .38247 .54568 .37661 .53711 Mtetra
.492 .596 .885 r
.37661 .53711 .38247 .54568 .39231 .54374 .38635 .53789 Mtetra
.522 .701 .951 r
.38635 .53789 .39231 .54374 .40229 .5391 .3962 .53733 Mtetra
.644 .908 .982 r
.3962 .53733 .40229 .5391 .41241 .53123 .40622 .53334 Mtetra
.76 .995 .828 r
.40622 .53334 .41241 .53123 .42263 .51995 .41642 .52455 Mtetra
.739 .963 .68 r
.41642 .52455 .42263 .51995 .43283 .50947 .42671 .51312 Mtetra
.839 .992 .737 r
.42671 .51312 .43283 .50947 .44293 .50241 .43702 .50065 Mtetra
.83 .921 .895 r
.43702 .50065 .44293 .50241 .45292 .50107 .44721 .49227 Mtetra
.598 .64 .864 r
.44721 .49227 .45292 .50107 .46284 .50639 .45726 .49068 Mtetra
.472 .455 .758 r
.45726 .49068 .46284 .50639 .47282 .51311 .46729 .49379 Mtetra
.403 .377 .716 r
.46729 .49379 .47282 .51311 .48292 .51825 .47734 .50023 Mtetra
.425 .404 .732 r
.47734 .50023 .48292 .51825 .49315 .51921 .4875 .50551 Mtetra
.498 .499 .788 r
.4875 .50551 .49315 .51921 .50348 .51489 .49778 .50739 Mtetra
.576 .672 .904 r
.49778 .50739 .50348 .51489 .51385 .50788 .50815 .50616 Mtetra
.621 .912 .982 r
.50815 .50616 .51385 .50788 .52424 .49967 .51857 .50217 Mtetra
.295 .768 .651 r
.51857 .50217 .52424 .49967 .53463 .49224 .52903 .49747 Mtetra
.034 0 0 r
.52903 .49747 .53463 .49224 .54505 .4867 .53952 .49308 Mtetra
.203 0 0 r
.53952 .49308 .54505 .4867 .55552 .48342 .55005 .48979 Mtetra
.279 0 0 r
.55005 .48979 .55552 .48342 .56605 .4824 .56064 .48759 Mtetra
.247 0 0 r
.56064 .48759 .56605 .4824 .57667 .48328 .57128 .48571 Mtetra
0 0 0 r
.57128 .48571 .57667 .48328 .58738 .48498 .58195 .48313 Mtetra
.7 .933 .965 r
.58195 .48313 .58738 .48498 .59813 .48548 .59262 .47775 Mtetra
.778 .742 .821 r
.59262 .47775 .59813 .48548 .60887 .48327 .60323 .46924 Mtetra
.76 .637 .724 r
.60323 .46924 .60887 .48327 .61951 .47572 .61376 .45725 Mtetra
.739 .591 .692 r
.61376 .45725 .61951 .47572 .63004 .46391 .62424 .44407 Mtetra
.698 .56 .695 r
.62424 .44407 .63004 .46391 .64048 .45048 .63481 .43424 Mtetra
.654 .561 .738 r
.63481 .43424 .64048 .45048 .65096 .43844 .64556 .42915 Mtetra
.455 .565 .877 r
.64556 .42915 .65096 .43844 .66171 .43314 .65662 .43097 Mtetra
.382 0 0 r
.65662 .43097 .66171 .43314 .67275 .43368 .66793 .437 Mtetra
.563 .034 0 r
.66793 .437 .67275 .43368 .68403 .43773 .67931 .44199 Mtetra
.463 0 0 r
.67931 .44199 .68403 .43773 .69545 .44263 .69066 .44431 Mtetra
0 0 0 r
.69066 .44431 .69545 .44263 .70677 .44404 .70182 .44172 Mtetra
.73 .934 .955 r
.70182 .44172 .70677 .44404 .71799 .44217 .71283 .4356 Mtetra
.771 .784 .864 r
.71283 .4356 .71799 .44217 .72908 .43751 .72378 .42808 Mtetra
.749 .705 .811 r
.72378 .42808 .72908 .43751 .74009 .4312 .73472 .42026 Mtetra
.713 .663 .798 r
.73472 .42026 .74009 .4312 .75113 .42474 .74576 .41358 Mtetra
.69 .649 .804 r
.74576 .41358 .75113 .42474 .76221 .41855 .7569 .40802 Mtetra
.666 .65 .824 r
.7569 .40802 .76221 .41855 .77338 .41329 .76817 .40372 Mtetra
.647 .662 .85 r
.76817 .40372 .77338 .41329 .78465 .40879 .77955 .40027 Mtetra
.636 .684 .878 r
.77955 .40027 .78465 .40879 .79602 .40496 .79101 .39728 Mtetra
.627 .705 .902 r
.79101 .39728 .79602 .40496 .80746 .40155 .80254 .39451 Mtetra
.628 .727 .918 r
.80254 .39451 .80746 .40155 .81897 .39833 .81412 .39166 Mtetra
.63 .741 .928 r
.81412 .39166 .81897 .39833 .83054 .3952 .82574 .38869 Mtetra
.637 .751 .931 r
.82574 .38869 .83054 .3952 .84216 .39201 .8374 .38552 Mtetra
.642 .755 .931 r
.8374 .38552 .84216 .39201 .85382 .38876 .84909 .38221 Mtetra
.646 .755 .928 r
.84909 .38221 .85382 .38876 .86553 .38546 .86082 .37877 Mtetra
.649 .752 .925 r
.86082 .37877 .86553 .38546 .87727 .38207 .87259 .37524 Mtetra
.652 .751 .922 r
.24535 .5654 .25164 .57089 .26108 .56776 .25479 .56249 Mtetra
.654 .76 .927 r
.25479 .56249 .26108 .56776 .27055 .56454 .26427 .55952 Mtetra
.658 .771 .933 r
.26427 .55952 .27055 .56454 .28007 .56121 .27378 .55643 Mtetra
.666 .782 .936 r
.27378 .55643 .28007 .56121 .28963 .55774 .28335 .55313 Mtetra
.678 .792 .936 r
.28335 .55313 .28963 .55774 .29923 .55407 .29297 .54955 Mtetra
.69 .798 .932 r
.29297 .54955 .29923 .55407 .30887 .5503 .30264 .54565 Mtetra
.705 .797 .922 r
.30264 .54565 .30887 .5503 .31854 .54645 .31237 .54134 Mtetra
.71 .782 .908 r
.31237 .54134 .31854 .54645 .32823 .54282 .32213 .53685 Mtetra
.709 .753 .887 r
.32213 .53685 .32823 .54282 .33793 .53961 .33193 .53227 Mtetra
.686 .707 .863 r
.33193 .53227 .33793 .53961 .34762 .53724 .34173 .52817 Mtetra
.651 .652 .838 r
.34173 .52817 .34762 .53724 .35728 .53609 .35151 .52501 Mtetra
.601 .591 .813 r
.35151 .52501 .35728 .53609 .36695 .53604 .36125 .52339 Mtetra
.536 .532 .797 r
.36125 .52339 .36695 .53604 .37661 .53711 .37093 .52387 Mtetra
.484 .494 .792 r
.37093 .52387 .37661 .53711 .38635 .53789 .38061 .52592 Mtetra
.416 .478 .816 r
.38061 .52592 .38635 .53789 .3962 .53733 .3903 .52922 Mtetra
.413 .572 .902 r
.3903 .52922 .3962 .53733 .40622 .53334 .40012 .53112 Mtetra
.436 .817 .99 r
.40012 .53112 .40622 .53334 .41642 .52455 .41012 .5297 Mtetra
0 0 0 r
.41012 .5297 .41642 .52455 .42671 .51312 .42033 .52286 Mtetra
.42033 .52286 .42671 .51312 .43702 .50065 .43074 .50967 Mtetra
.43074 .50967 .43702 .50065 .44721 .49227 .44116 .49528 Mtetra
.86 .995 .76 r
.44116 .49528 .44721 .49227 .45726 .49068 .45151 .48279 Mtetra
.746 .718 .826 r
.45151 .48279 .45726 .49068 .46729 .49379 .46173 .47593 Mtetra
.548 .481 .732 r
.46173 .47593 .46729 .49379 .47734 .50023 .47185 .47639 Mtetra
.486 .402 .687 r
.47185 .47639 .47734 .50023 .4875 .50551 .48198 .48049 Mtetra
.459 .379 .679 r
.48198 .48049 .4875 .50551 .49778 .50739 .49218 .48622 Mtetra
.467 .407 .706 r
.49218 .48622 .49778 .50739 .50815 .50616 .50248 .49073 Mtetra
.507 .483 .765 r
.50248 .49073 .50815 .50616 .51857 .50217 .51288 .49257 Mtetra
.545 .603 .862 r
.51288 .49257 .51857 .50217 .52903 .49747 .52335 .49236 Mtetra
.592 .768 .963 r
.52335 .49236 .52903 .49747 .53952 .49308 .53388 .49024 Mtetra
.611 .869 .991 r
.53388 .49024 .53952 .49308 .55005 .48979 .54445 .48692 Mtetra
.681 .888 .974 r
.54445 .48692 .55005 .48979 .56064 .48759 .55505 .48242 Mtetra
.759 .813 .896 r
.55505 .48242 .56064 .48759 .57128 .48571 .56566 .47598 Mtetra
.756 .693 .791 r
.56566 .47598 .57128 .48571 .58195 .48313 .57626 .46747 Mtetra
.739 .611 .716 r
.57626 .46747 .58195 .48313 .59262 .47775 .58681 .45625 Mtetra
.714 .561 .679 r
.58681 .45625 .59262 .47775 .60323 .46924 .59733 .44377 Mtetra
.682 .524 .666 r
.59733 .44377 .60323 .46924 .61376 .45725 .60787 .4329 Mtetra
.65 .508 .677 r
.60787 .4329 .61376 .45725 .62424 .44407 .6185 .4257 Mtetra
.554 .484 .732 r
.6185 .4257 .62424 .44407 .63481 .43424 .62939 .42591 Mtetra
.163 .421 .86 r
.62939 .42591 .63481 .43424 .64556 .42915 .64056 .43186 Mtetra
.657 .139 0 r
.64056 .43186 .64556 .42915 .65662 .43097 .6519 .43979 Mtetra
.629 .203 .215 r
.6519 .43979 .65662 .43097 .66793 .437 .66332 .44653 Mtetra
.462 .041 .154 r
.66332 .44653 .66793 .437 .67931 .44199 .67455 .4468 Mtetra
0 0 0 r
.67455 .4468 .67931 .44199 .69066 .44431 .68558 .44155 Mtetra
.824 .926 .901 r
.68558 .44155 .69066 .44431 .70182 .44172 .69647 .43287 Mtetra
.793 .732 .796 r
.69647 .43287 .70182 .44172 .71283 .4356 .70728 .42273 Mtetra
.733 .643 .758 r
.70728 .42273 .71283 .4356 .72378 .42808 .71816 .41385 Mtetra
.699 .61 .753 r
.71816 .41385 .72378 .42808 .73472 .42026 .72915 .40657 Mtetra
.666 .599 .771 r
.72915 .40657 .73472 .42026 .74576 .41358 .74031 .40145 Mtetra
.64 .609 .803 r
.74031 .40145 .74576 .41358 .7569 .40802 .75161 .39792 Mtetra
.621 .638 .846 r
.75161 .39792 .7569 .40802 .76817 .40372 .76303 .39535 Mtetra
.603 .673 .89 r
.76303 .39535 .76817 .40372 .77955 .40027 .77454 .3933 Mtetra
.599 .716 .926 r
.77454 .3933 .77955 .40027 .79101 .39728 .7861 .39114 Mtetra
.6 .747 .948 r
.7861 .39114 .79101 .39728 .80254 .39451 .79771 .3888 Mtetra
.613 .771 .955 r
.79771 .3888 .80254 .39451 .81412 .39166 .80933 .38603 Mtetra
.626 .781 .955 r
.80933 .38603 .81412 .39166 .82574 .38869 .82098 .38294 Mtetra
.64 .782 .949 r
.82098 .38294 .82574 .38869 .8374 .38552 .83265 .37954 Mtetra
.65 .778 .942 r
.83265 .37954 .8374 .38552 .84909 .38221 .84435 .37593 Mtetra
.656 .771 .934 r
.84435 .37593 .84909 .38221 .86082 .37877 .85608 .37218 Mtetra
.658 .761 .926 r
.85608 .37218 .86082 .37877 .87259 .37524 .86786 .36837 Mtetra
.641 .748 .926 r
.23902 .55988 .24535 .5654 .25479 .56249 .24846 .55721 Mtetra
.639 .757 .934 r
.24846 .55721 .25479 .56249 .26427 .55952 .25793 .55455 Mtetra
.64 .77 .941 r
.25793 .55455 .26427 .55952 .27378 .55643 .26744 .5518 Mtetra
.646 .785 .948 r
.26744 .5518 .27378 .55643 .28335 .55313 .277 .54889 Mtetra
.654 .803 .954 r
.277 .54889 .28335 .55313 .29297 .54955 .28661 .54574 Mtetra
.67 .824 .958 r
.28661 .54574 .29297 .54955 .30264 .54565 .29629 .54219 Mtetra
.693 .843 .955 r
.29629 .54219 .30264 .54565 .31237 .54134 .30603 .5381 Mtetra
.715 .855 .949 r
.30603 .5381 .31237 .54134 .32213 .53685 .31583 .53346 Mtetra
.74 .852 .933 r
.31583 .53346 .32213 .53685 .33193 .53227 .3257 .52819 Mtetra
.744 .827 .916 r
.3257 .52819 .33193 .53227 .34173 .52817 .3356 .52274 Mtetra
.733 .778 .889 r
.3356 .52274 .34173 .52817 .35151 .52501 .34552 .5174 Mtetra
.689 .703 .858 r
.34552 .5174 .35151 .52501 .36125 .52339 .3554 .51314 Mtetra
.624 .619 .825 r
.3554 .51314 .36125 .52339 .37093 .52387 .36523 .51075 Mtetra
.551 .534 .789 r
.36523 .51075 .37093 .52387 .38061 .52592 .37499 .51076 Mtetra
.467 .458 .765 r
.37499 .51076 .38061 .52592 .3903 .52922 .38468 .51368 Mtetra
.424 .428 .76 r
.38468 .51368 .3903 .52922 .40012 .53112 .39439 .51792 Mtetra
.388 .441 .794 r
.39439 .51792 .40012 .53112 .41012 .5297 .40418 .52225 Mtetra
.488 .633 .918 r
.40418 .52225 .41012 .5297 .42033 .52286 .41418 .52268 Mtetra
.696 .966 .936 r
.41418 .52268 .42033 .52286 .43074 .50967 .42443 .51679 Mtetra
0 0 0 r
.42443 .51679 .43074 .50967 .44116 .49528 .43484 .50586 Mtetra
.43484 .50586 .44116 .49528 .45151 .48279 .44533 .49106 Mtetra
.44533 .49106 .45151 .48279 .46173 .47593 .45575 .47804 Mtetra
.707 .983 .812 r
.45575 .47804 .46173 .47593 .47185 .47639 .46607 .46975 Mtetra
.669 .734 .898 r
.46607 .46975 .47185 .47639 .48198 .48049 .47632 .46613 Mtetra
.53 .508 .776 r
.47632 .46613 .48198 .48049 .49218 .48622 .48656 .46696 Mtetra
.51 .448 .722 r
.48656 .46696 .49218 .48622 .50248 .49073 .49686 .46918 Mtetra
.521 .439 .704 r
.49686 .46918 .50248 .49073 .51288 .49257 .50722 .47113 Mtetra
.546 .457 .705 r
.50722 .47113 .51288 .49257 .52335 .49236 .51767 .47175 Mtetra
.582 .484 .709 r
.51767 .47175 .52335 .49236 .53388 .49024 .52818 .47034 Mtetra
.615 .509 .711 r
.52818 .47034 .53388 .49024 .54445 .48692 .53873 .46699 Mtetra
.643 .526 .706 r
.53873 .46699 .54445 .48692 .55505 .48242 .54931 .46169 Mtetra
.665 .535 .696 r
.54931 .46169 .55505 .48242 .56566 .47598 .55989 .45435 Mtetra
.677 .537 .688 r
.55989 .45435 .56566 .47598 .57626 .46747 .57047 .44565 Mtetra
.679 .538 .686 r
.57047 .44565 .57626 .46747 .58681 .45625 .58105 .43667 Mtetra
.673 .547 .703 r
.58105 .43667 .58681 .45625 .59733 .44377 .59167 .42907 Mtetra
.624 .561 .763 r
.59167 .42907 .59733 .44377 .60787 .4329 .6024 .42595 Mtetra
.402 .612 .935 r
.6024 .42595 .60787 .4329 .6185 .4257 .61331 .42757 Mtetra
.602 .056 0 r
.61331 .42757 .6185 .4257 .62939 .42591 .62445 .434 Mtetra
.661 .23 .214 r
.62445 .434 .62939 .42591 .64056 .43186 .63575 .44228 Mtetra
.577 .167 .228 r
.63575 .44228 .64056 .43186 .6519 .43979 .64703 .44667 Mtetra
.374 0 .009 r
.64703 .44667 .6519 .43979 .66332 .44653 .6582 .44593 Mtetra
.729 .98 .915 r
.6582 .44593 .66332 .44653 .67455 .4468 .66915 .43873 Mtetra
.816 .754 .794 r
.66915 .43873 .67455 .4468 .68558 .44155 .67993 .42752 Mtetra
.753 .638 .734 r
.67993 .42752 .68558 .44155 .69647 .43287 .6907 .41638 Mtetra
.718 .597 .721 r
.6907 .41638 .69647 .43287 .70728 .42273 .70153 .40657 Mtetra
.68 .58 .736 r
.70153 .40657 .70728 .42273 .71816 .41385 .71254 .39973 Mtetra
.649 .586 .77 r
.71254 .39973 .71816 .41385 .72915 .40657 .72372 .39536 Mtetra
.616 .613 .825 r
.72372 .39536 .72915 .40657 .74031 .40145 .73507 .39291 Mtetra
.576 .656 .891 r
.73507 .39291 .74031 .40145 .75161 .39792 .74655 .39158 Mtetra
.548 .716 .95 r
.74655 .39158 .75161 .39792 .76303 .39535 .7581 .39036 Mtetra
.527 .761 .983 r
.7581 .39036 .76303 .39535 .77454 .3933 .7697 .38898 Mtetra
.546 .8 .992 r
.7697 .38898 .77454 .3933 .7861 .39114 .78132 .38693 Mtetra
.576 .819 .99 r
.78132 .38693 .7861 .39114 .79771 .3888 .79294 .38432 Mtetra
.613 .824 .981 r
.79294 .38432 .79771 .3888 .80933 .38603 .80457 .38114 Mtetra
.639 .817 .969 r
.80457 .38114 .80933 .38603 .82098 .38294 .81622 .37755 Mtetra
.655 .804 .955 r
.81622 .37755 .82098 .38294 .83265 .37954 .82788 .37371 Mtetra
.664 .791 .942 r
.82788 .37371 .83265 .37954 .84435 .37593 .83958 .36968 Mtetra
.668 .779 .932 r
.83958 .36968 .84435 .37593 .85608 .37218 .85132 .36556 Mtetra
.668 .766 .923 r
.85132 .36556 .85608 .37218 .86786 .36837 .8631 .36144 Mtetra
.632 .745 .93 r
.23264 .55431 .23902 .55988 .24846 .55721 .24208 .55181 Mtetra
.626 .751 .936 r
.24208 .55181 .24846 .55721 .25793 .55455 .25155 .54939 Mtetra
.623 .76 .944 r
.25155 .54939 .25793 .55455 .26744 .5518 .26106 .54699 Mtetra
.621 .773 .953 r
.26106 .54699 .26744 .5518 .277 .54889 .27061 .54456 Mtetra
.618 .792 .965 r
.27061 .54456 .277 .54889 .28661 .54574 .28019 .54207 Mtetra
.623 .822 .977 r
.28019 .54207 .28661 .54574 .29629 .54219 .28984 .5393 Mtetra
.634 .857 .984 r
.28984 .5393 .29629 .54219 .30603 .5381 .29955 .53609 Mtetra
.656 .897 .981 r
.29955 .53609 .30603 .5381 .31583 .53346 .30934 .53217 Mtetra
.696 .929 .967 r
.30934 .53217 .31583 .53346 .3257 .52819 .31923 .52727 Mtetra
.737 .946 .949 r
.31923 .52727 .3257 .52819 .3356 .52274 .32919 .52143 Mtetra
.787 .933 .928 r
.32919 .52143 .3356 .52274 .34552 .5174 .33923 .51457 Mtetra
.794 .877 .908 r
.33923 .51457 .34552 .5174 .3554 .51314 .34929 .50753 Mtetra
.763 .778 .865 r
.34929 .50753 .3554 .51314 .36523 .51075 .35935 .50089 Mtetra
.687 .654 .811 r
.35935 .50089 .36523 .51075 .37499 .51076 .36934 .49607 Mtetra
.6 .541 .76 r
.36934 .49607 .37499 .51076 .38468 .51368 .37922 .49419 Mtetra
.52 .45 .717 r
.37922 .49419 .38468 .51368 .39439 .51792 .38901 .49587 Mtetra
.435 .378 .695 r
.38901 .49587 .39439 .51792 .40418 .52225 .39871 .50155 Mtetra
.384 .354 .702 r
.39871 .50155 .40418 .52225 .41418 .52268 .40844 .50867 Mtetra
.295 .373 .773 r
.40844 .50867 .41418 .52268 .42443 .51679 .4183 .51524 Mtetra
0 .561 .801 r
.4183 .51524 .42443 .51679 .43484 .50586 .42841 .51653 Mtetra
.154 0 .02 r
.42841 .51653 .43484 .50586 .44533 .49106 .43878 .50997 Mtetra
.16 0 .183 r
.43878 .50997 .44533 .49106 .45575 .47804 .4493 .49791 Mtetra
.041 0 .143 r
.4493 .49791 .45575 .47804 .46607 .46975 .45988 .4821 Mtetra
0 0 0 r
.45988 .4821 .46607 .46975 .47632 .46613 .4704 .46757 Mtetra
.847 .997 .824 r
.4704 .46757 .47632 .46613 .48656 .46696 .48083 .4568 Mtetra
.73 .672 .793 r
.48083 .4568 .48656 .46696 .49686 .46918 .49123 .44962 Mtetra
.623 .515 .711 r
.49123 .44962 .49686 .46918 .50722 .47113 .50161 .44577 Mtetra
.594 .467 .677 r
.50161 .44577 .50722 .47113 .51767 .47175 .51202 .44306 Mtetra
.589 .452 .662 r
.51202 .44306 .51767 .47175 .52818 .47034 .52248 .44043 Mtetra
.596 .453 .657 r
.52248 .44043 .52818 .47034 .53873 .46699 .53299 .43703 Mtetra
.604 .458 .656 r
.53299 .43703 .53873 .46699 .54931 .46169 .54352 .43287 Mtetra
.605 .462 .661 r
.54352 .43287 .54931 .46169 .55989 .45435 .5541 .42878 Mtetra
.596 .469 .677 r
.5541 .42878 .55989 .45435 .57047 .44565 .56472 .42585 Mtetra
.548 .47 .719 r
.56472 .42585 .57047 .44565 .58105 .43667 .57544 .42627 Mtetra
.355 .483 .85 r
.57544 .42627 .58105 .43667 .59167 .42907 .5863 .43031 Mtetra
.649 .108 0 r
.5863 .43031 .59167 .42907 .6024 .42595 .59733 .4382 Mtetra
.66 .273 .3 r
.59733 .4382 .6024 .42595 .61331 .42757 .60852 .44743 Mtetra
.588 .248 .36 r
.60852 .44743 .61331 .42757 .62445 .434 .61973 .4529 Mtetra
.501 .162 .324 r
.61973 .4529 .62445 .434 .63575 .44228 .63086 .45279 Mtetra
.115 0 .021 r
.63086 .45279 .63575 .44228 .64703 .44667 .64177 .4447 Mtetra
.912 .925 .81 r
.64177 .4447 .64703 .44667 .6582 .44593 .65248 .4312 Mtetra
.777 .642 .713 r
.65248 .4312 .6582 .44593 .66915 .43873 .66314 .41709 Mtetra
.716 .563 .68 r
.66314 .41709 .66915 .43873 .67993 .42752 .67384 .40444 Mtetra
.668 .527 .683 r
.67384 .40444 .67993 .42752 .6907 .41638 .68472 .39585 Mtetra
.634 .52 .707 r
.68472 .39585 .6907 .41638 .70153 .40657 .69581 .39089 Mtetra
.596 .538 .761 r
.69581 .39089 .70153 .40657 .71254 .39973 .7071 .38897 Mtetra
.541 .584 .847 r
.7071 .38897 .71254 .39973 .72372 .39536 .71856 .38892 Mtetra
.462 .669 .953 r
.71856 .38892 .72372 .39536 .73507 .39291 .73012 .38929 Mtetra
.342 .724 .985 r
.73012 .38929 .73507 .39291 .74655 .39158 .74175 .38949 Mtetra
.315 .768 .955 r
.74175 .38949 .74655 .39158 .7581 .39036 .75337 .38864 Mtetra
.374 .814 .954 r
.75337 .38864 .7581 .39036 .7697 .38898 .76499 .38683 Mtetra
.495 .866 .983 r
.76499 .38683 .7697 .38898 .78132 .38693 .77659 .384 Mtetra
.589 .879 .993 r
.77659 .384 .78132 .38693 .79294 .38432 .78818 .38042 Mtetra
.643 .861 .982 r
.78818 .38042 .79294 .38432 .80457 .38114 .79978 .37639 Mtetra
.669 .836 .963 r
.79978 .37639 .80457 .38114 .81622 .37755 .81141 .37206 Mtetra
.677 .81 .947 r
.81141 .37206 .81622 .37755 .82788 .37371 .82307 .36767 Mtetra
.679 .791 .934 r
.82307 .36767 .82788 .37371 .83958 .36968 .83476 .36323 Mtetra
.679 .777 .925 r
.83476 .36323 .83958 .36968 .85132 .36556 .84651 .35881 Mtetra
.675 .766 .919 r
.84651 .35881 .85132 .36556 .8631 .36144 .85831 .35446 Mtetra
.635 .746 .928 r
.22623 .54871 .23264 .55431 .24208 .55181 .23569 .54612 Mtetra
.63 .742 .929 r
.23569 .54612 .24208 .55181 .25155 .54939 .24518 .54365 Mtetra
.624 .739 .93 r
.24518 .54365 .25155 .54939 .26106 .54699 .2547 .54129 Mtetra
.617 .739 .934 r
.2547 .54129 .26106 .54699 .27061 .54456 .26425 .53906 Mtetra
.605 .744 .943 r
.26425 .53906 .27061 .54456 .28019 .54207 .27383 .537 Mtetra
.6 .76 .955 r
.27383 .537 .28019 .54207 .28984 .5393 .28344 .53495 Mtetra
.593 .787 .973 r
.28344 .53495 .28984 .5393 .29955 .53609 .2931 .53281 Mtetra
.599 .834 .989 r
.2931 .53281 .29955 .53609 .30934 .53217 .30284 .5302 Mtetra
.613 .89 .989 r
.30284 .5302 .30934 .53217 .31923 .52727 .31266 .52682 Mtetra
.632 .941 .958 r
.31266 .52682 .31923 .52727 .32919 .52143 .32258 .52229 Mtetra
.675 .973 .906 r
.32258 .52229 .32919 .52143 .33923 .51457 .33263 .51622 Mtetra
.716 .987 .866 r
.33263 .51622 .33923 .51457 .34929 .50753 .34276 .50887 Mtetra
.794 .995 .87 r
.34276 .50887 .34929 .50753 .35935 .50089 .35296 .50031 Mtetra
.827 .954 .899 r
.35296 .50031 .35935 .50089 .36934 .49607 .36316 .49192 Mtetra
.789 .833 .885 r
.36316 .49192 .36934 .49607 .37922 .49419 .37332 .48471 Mtetra
.675 .659 .826 r
.37332 .48471 .37922 .49419 .38901 .49587 .38336 .48049 Mtetra
.549 .506 .76 r
.38336 .48049 .38901 .49587 .39871 .50155 .39325 .48062 Mtetra
.461 .403 .706 r
.39325 .48062 .39871 .50155 .40844 .50867 .40306 .48492 Mtetra
.385 .334 .679 r
.40306 .48492 .40844 .50867 .4183 .51524 .41281 .49302 Mtetra
.396 .353 .692 r
.41281 .49302 .4183 .51524 .42841 .51653 .4227 .5002 Mtetra
.463 .447 .755 r
.4227 .5002 .42841 .51653 .43878 .50997 .43281 .50346 Mtetra
.62 .725 .922 r
.43281 .50346 .43878 .50997 .4493 .49791 .44313 .50102 Mtetra
.661 .959 .748 r
.44313 .50102 .4493 .49791 .45988 .4821 .45363 .49221 Mtetra
0 0 0 r
.45363 .49221 .45988 .4821 .4704 .46757 .46419 .48089 Mtetra
0 0 .005 r
.46419 .48089 .4704 .46757 .48083 .4568 .47474 .46918 Mtetra
.029 0 .009 r
.47474 .46918 .48083 .4568 .49123 .44962 .48525 .45906 Mtetra
.042 0 0 r
.48525 .45906 .49123 .44962 .50161 .44577 .49575 .45151 Mtetra
0 0 0 r
.49575 .45151 .50161 .44577 .51202 .44306 .50624 .44573 Mtetra
.50624 .44573 .51202 .44306 .52248 .44043 .51676 .44145 Mtetra
.317 .804 .784 r
.51676 .44145 .52248 .44043 .53299 .43703 .52731 .43803 Mtetra
.208 .731 .738 r
.52731 .43803 .53299 .43703 .54352 .43287 .5379 .43549 Mtetra
.141 0 0 r
.5379 .43549 .54352 .43287 .5541 .42878 .54856 .43446 Mtetra
.418 0 0 r
.54856 .43446 .5541 .42878 .56472 .42585 .55929 .43521 Mtetra
.552 .129 .192 r
.55929 .43521 .56472 .42585 .57544 .42627 .57012 .43857 Mtetra
.59 .2 .272 r
.57012 .43857 .57544 .42627 .5863 .43031 .58107 .44357 Mtetra
.582 .199 .282 r
.58107 .44357 .5863 .43031 .59733 .4382 .59211 .4482 Mtetra
.517 .099 .186 r
.59211 .4482 .59733 .4382 .60852 .44743 .60319 .4503 Mtetra
0 0 0 r
.60319 .4503 .60852 .44743 .61973 .4529 .61418 .44596 Mtetra
.814 .78 .82 r
.61418 .44596 .61973 .4529 .63086 .45279 .62502 .43582 Mtetra
.759 .615 .699 r
.62502 .43582 .63086 .45279 .64177 .4447 .63573 .42166 Mtetra
.729 .564 .667 r
.63573 .42166 .64177 .4447 .65248 .4312 .64637 .40652 Mtetra
.688 .532 .67 r
.64637 .40652 .65248 .4312 .66314 .41709 .65713 .39523 Mtetra
.656 .525 .693 r
.65713 .39523 .66314 .41709 .67384 .40444 .66807 .38818 Mtetra
.608 .539 .752 r
.66807 .38818 .67384 .40444 .68472 .39585 .67925 .38558 Mtetra
.517 .582 .859 r
.67925 .38558 .68472 .39585 .69581 .39089 .69063 .38605 Mtetra
.29 .64 .966 r
.69063 .38605 .69581 .39089 .7071 .38897 .70216 .38775 Mtetra
0 .51 .751 r
.70216 .38775 .7071 .38897 .71856 .38892 .71379 .38963 Mtetra
.14 0 0 r
.71379 .38963 .71856 .38892 .73012 .38929 .72542 .3903 Mtetra
.04 0 0 r
.72542 .3903 .73012 .38929 .74175 .38949 .73704 .38965 Mtetra
.221 .743 .793 r
.73704 .38965 .74175 .38949 .75337 .38864 .74862 .38741 Mtetra
.476 .882 .947 r
.74862 .38741 .75337 .38864 .76499 .38683 .76018 .38397 Mtetra
.627 .897 .986 r
.76018 .38397 .76499 .38683 .77659 .384 .77171 .37973 Mtetra
.682 .86 .967 r
.77171 .37973 .77659 .384 .78818 .38042 .78326 .375 Mtetra
.693 .818 .942 r
.78326 .375 .78818 .38042 .79978 .37639 .79483 .37017 Mtetra
.694 .79 .924 r
.79483 .37017 .79978 .37639 .81141 .37206 .80645 .36534 Mtetra
.687 .77 .915 r
.80645 .36534 .81141 .37206 .82307 .36767 .81812 .36068 Mtetra
.682 .761 .911 r
.81812 .36068 .82307 .36767 .83476 .36323 .82985 .35615 Mtetra
.677 .757 .911 r
.82985 .35615 .83476 .36323 .84651 .35881 .84164 .35173 Mtetra
.673 .756 .913 r
.84164 .35173 .84651 .35881 .85831 .35446 .85348 .34743 Mtetra
.65 .75 .923 r
.21976 .54307 .22623 .54871 .23569 .54612 .22928 .54013 Mtetra
.646 .737 .915 r
.22928 .54013 .23569 .54612 .24518 .54365 .23882 .53728 Mtetra
.639 .723 .909 r
.23882 .53728 .24518 .54365 .2547 .54129 .24838 .5346 Mtetra
.628 .71 .905 r
.24838 .5346 .2547 .54129 .26425 .53906 .25796 .53218 Mtetra
.612 .7 .907 r
.25796 .53218 .26425 .53906 .27383 .537 .26755 .53014 Mtetra
.595 .695 .912 r
.26755 .53014 .27383 .537 .28344 .53495 .27715 .52844 Mtetra
.571 .699 .928 r
.27715 .52844 .28344 .53495 .2931 .53281 .28677 .52715 Mtetra
.553 .724 .953 r
.28677 .52715 .2931 .53281 .30284 .5302 .29642 .52596 Mtetra
.523 .771 .988 r
.29642 .52596 .30284 .5302 .31266 .52682 .30613 .52471 Mtetra
.486 .842 .994 r
.30613 .52471 .31266 .52682 .32258 .52229 .31593 .52277 Mtetra
.408 .859 .877 r
.31593 .52277 .32258 .52229 .33263 .51622 .32584 .51961 Mtetra
0 0 0 r
.32584 .51961 .33263 .51622 .34276 .50887 .33589 .51468 Mtetra
.33589 .51468 .34276 .50887 .35296 .50031 .3461 .50742 Mtetra
.3461 .50742 .35296 .50031 .36316 .49192 .35641 .49825 Mtetra
.583 .872 .559 r
.35641 .49825 .36316 .49192 .37332 .48471 .3668 .4874 Mtetra
.833 .999 .8 r
.3668 .4874 .37332 .48471 .38336 .48049 .37719 .47646 Mtetra
.837 .835 .844 r
.37719 .47646 .38336 .48049 .39325 .48062 .38752 .4667 Mtetra
.691 .6 .749 r
.38752 .4667 .39325 .48062 .40306 .48492 .39773 .46018 Mtetra
.581 .459 .679 r
.39773 .46018 .40306 .48492 .41281 .49302 .40778 .45844 Mtetra
.507 .377 .638 r
.40778 .45844 .41281 .49302 .4227 .5002 .4177 .46217 Mtetra
.44 .322 .622 r
.4177 .46217 .4227 .5002 .43281 .50346 .42754 .47136 Mtetra
.394 .306 .637 r
.42754 .47136 .43281 .50346 .44313 .50102 .43747 .48179 Mtetra
.304 .317 .709 r
.43747 .48179 .44313 .50102 .45363 .49221 .44755 .49069 Mtetra
.374 0 0 r
.44755 .49069 .45363 .49221 .46419 .48089 .45784 .49511 Mtetra
.445 .075 .24 r
.45784 .49511 .46419 .48089 .47474 .46918 .46832 .49372 Mtetra
.427 .119 .339 r
.46832 .49372 .47474 .46918 .48525 .45906 .4789 .48872 Mtetra
.415 .126 .363 r
.4789 .48872 .48525 .45906 .49575 .45151 .48954 .48152 Mtetra
.42 .132 .367 r
.48954 .48152 .49575 .45151 .50624 .44573 .50019 .47452 Mtetra
.439 .145 .368 r
.50019 .47452 .50624 .44573 .51676 .44145 .51085 .46901 Mtetra
.467 .166 .371 r
.51085 .46901 .51676 .44145 .52731 .43803 .52154 .46561 Mtetra
.498 .193 .38 r
.52154 .46561 .52731 .43803 .5379 .43549 .53227 .46431 Mtetra
.519 .216 .392 r
.53227 .46431 .5379 .43549 .54856 .43446 .54307 .46451 Mtetra
.523 .222 .398 r
.54307 .46451 .54856 .43446 .55929 .43521 .55394 .46493 Mtetra
.495 .197 .389 r
.55394 .46493 .55929 .43521 .57012 .43857 .56485 .46315 Mtetra
.423 .117 .339 r
.56485 .46315 .57012 .43857 .58107 .44357 .57575 .45772 Mtetra
.08 0 .084 r
.57575 .45772 .58107 .44357 .59211 .4482 .58658 .4464 Mtetra
.933 .907 .773 r
.58658 .4464 .59211 .4482 .60319 .4503 .59729 .43053 Mtetra
.766 .601 .674 r
.59729 .43053 .60319 .4503 .61418 .44596 .60793 .41305 Mtetra
.695 .512 .636 r
.60793 .41305 .61418 .44596 .62502 .43582 .61855 .39678 Mtetra
.64 .463 .627 r
.61855 .39678 .62502 .43582 .63573 .42166 .6293 .38604 Mtetra
.603 .444 .639 r
.6293 .38604 .63573 .42166 .64637 .40652 .64024 .38084 Mtetra
.559 .446 .681 r
.64024 .38084 .64637 .40652 .65713 .39523 .65142 .38053 Mtetra
.464 .474 .783 r
.65142 .38053 .65713 .39523 .66807 .38818 .6628 .38354 Mtetra
.031 .477 .88 r
.6628 .38354 .66807 .38818 .67925 .38558 .67433 .38778 Mtetra
.487 0 0 r
.67433 .38778 .67925 .38558 .69063 .38605 .68596 .39197 Mtetra
.486 0 .014 r
.68596 .39197 .69063 .38605 .70216 .38775 .6976 .39444 Mtetra
.419 0 .011 r
.6976 .39444 .70216 .38775 .71379 .38963 .70922 .39496 Mtetra
.251 0 0 r
.70922 .39496 .71379 .38963 .72542 .3903 .72076 .3931 Mtetra
0 0 0 r
.72076 .3931 .72542 .3903 .73704 .38965 .73225 .38939 Mtetra
.522 .917 .894 r
.73225 .38939 .73704 .38965 .74862 .38741 .74371 .38443 Mtetra
.706 .917 .966 r
.74371 .38443 .74862 .38741 .76018 .38397 .75514 .37874 Mtetra
.727 .835 .932 r
.75514 .37874 .76018 .38397 .77171 .37973 .76661 .37298 Mtetra
.719 .779 .9 r
.76661 .37298 .77171 .37973 .78326 .375 .77812 .36731 Mtetra
.702 .745 .885 r
.77812 .36731 .78326 .375 .79483 .37017 .78969 .36206 Mtetra
.689 .729 .88 r
.78969 .36206 .79483 .37017 .80645 .36534 .80134 .35716 Mtetra
.677 .723 .884 r
.80134 .35716 .80645 .36534 .81812 .36068 .81306 .35264 Mtetra
.669 .725 .891 r
.81306 .35264 .81812 .36068 .82985 .35615 .82484 .3484 Mtetra
.664 .732 .9 r
.82484 .3484 .82985 .35615 .84164 .35173 .8367 .34433 Mtetra
.661 .742 .91 r
.8367 .34433 .84164 .35173 .85348 .34743 .84861 .34035 Mtetra
.67 .755 .914 r
.21326 .53739 .21976 .54307 .22928 .54013 .22284 .53395 Mtetra
.668 .738 .902 r
.22284 .53395 .22928 .54013 .23882 .53728 .23244 .53053 Mtetra
.662 .719 .891 r
.23244 .53053 .23882 .53728 .24838 .5346 .24207 .52724 Mtetra
.651 .698 .881 r
.24207 .52724 .24838 .5346 .25796 .53218 .25171 .5242 Mtetra
.636 .677 .872 r
.25171 .5242 .25796 .53218 .26755 .53014 .26136 .52153 Mtetra
.618 .654 .864 r
.26136 .52153 .26755 .53014 .27715 .52844 .27101 .51936 Mtetra
.593 .633 .86 r
.27101 .51936 .27715 .52844 .28677 .52715 .28065 .51786 Mtetra
.57 .618 .861 r
.28065 .51786 .28677 .52715 .29642 .52596 .29029 .51694 Mtetra
.54 .612 .874 r
.29029 .51694 .29642 .52596 .30613 .52471 .29994 .51666 Mtetra
.524 .633 .9 r
.29994 .51666 .30613 .52471 .31593 .52277 .30964 .51652 Mtetra
.505 .687 .949 r
.30964 .51652 .31593 .52277 .32584 .51961 .3194 .51619 Mtetra
.499 .799 .999 r
.3194 .51619 .32584 .51961 .33589 .51468 .32927 .51478 Mtetra
.446 .877 .909 r
.32927 .51478 .33589 .51468 .3461 .50742 .3393 .51155 Mtetra
0 0 0 r
.3393 .51155 .3461 .50742 .35641 .49825 .34949 .50596 Mtetra
.34949 .50596 .35641 .49825 .3668 .4874 .35984 .49746 Mtetra
.35984 .49746 .3668 .4874 .37719 .47646 .37031 .48667 Mtetra
.37031 .48667 .37719 .47646 .38752 .4667 .38085 .47406 Mtetra
.569 .841 .494 r
.38085 .47406 .38752 .4667 .39773 .46018 .39135 .46191 Mtetra
.822 .999 .836 r
.39135 .46191 .39773 .46018 .40778 .45844 .40176 .45196 Mtetra
.717 .753 .881 r
.40176 .45196 .40778 .45844 .4177 .46217 .41199 .44683 Mtetra
.52 .492 .765 r
.41199 .44683 .4177 .46217 .42754 .47136 .42206 .4479 Mtetra
.455 .384 .688 r
.42206 .4479 .42754 .47136 .43747 .48179 .43208 .45292 Mtetra
.432 .344 .656 r
.43208 .45292 .43747 .48179 .44755 .49069 .44214 .46031 Mtetra
.461 .359 .652 r
.44214 .46031 .44755 .49069 .45784 .49511 .45232 .46648 Mtetra
.509 .398 .663 r
.45232 .46648 .45784 .49511 .46832 .49372 .46267 .46948 Mtetra
.551 .446 .687 r
.46267 .46948 .46832 .49372 .4789 .48872 .47314 .46958 Mtetra
.601 .508 .721 r
.47314 .46958 .4789 .48872 .48954 .48152 .48371 .467 Mtetra
.634 .57 .765 r
.48371 .467 .48954 .48152 .50019 .47452 .49434 .46338 Mtetra
.653 .629 .813 r
.49434 .46338 .50019 .47452 .51085 .46901 .50501 .45954 Mtetra
.649 .661 .848 r
.50501 .45954 .51085 .46901 .52154 .46561 .51571 .45611 Mtetra
.637 .656 .852 r
.51571 .45611 .52154 .46561 .53227 .46431 .52646 .45307 Mtetra
.637 .621 .818 r
.52646 .45307 .53227 .46431 .54307 .46451 .53725 .44983 Mtetra
.646 .576 .762 r
.53725 .44983 .54307 .46451 .55394 .46493 .54808 .44554 Mtetra
.666 .546 .709 r
.54808 .44554 .55394 .46493 .56485 .46315 .55891 .43854 Mtetra
.676 .525 .673 r
.55891 .43854 .56485 .46315 .57575 .45772 .56973 .42859 Mtetra
.686 .516 .65 r
.56973 .42859 .57575 .45772 .58658 .4464 .58049 .41543 Mtetra
.689 .512 .643 r
.58049 .41543 .58658 .4464 .59729 .43053 .5912 .40099 Mtetra
.676 .508 .65 r
.5912 .40099 .59729 .43053 .60793 .41305 .60194 .38892 Mtetra
.659 .516 .678 r
.60194 .38892 .60793 .41305 .61855 .39678 .61277 .38082 Mtetra
.591 .532 .757 r
.61277 .38082 .61855 .39678 .6293 .38604 .62381 .37904 Mtetra
.285 .551 .924 r
.62381 .37904 .6293 .38604 .64024 .38084 .63507 .38217 Mtetra
.528 0 0 r
.63507 .38217 .64024 .38084 .65142 .38053 .64651 .38757 Mtetra
.603 .141 .13 r
.64651 .38757 .65142 .38053 .6628 .38354 .65808 .39347 Mtetra
.561 .136 .192 r
.65808 .39347 .6628 .38354 .67433 .38778 .66969 .39755 Mtetra
.498 .07 .157 r
.66969 .39755 .67433 .38778 .68596 .39197 .68127 .39929 Mtetra
.351 0 .002 r
.68127 .39929 .68596 .39197 .6976 .39444 .69279 .39806 Mtetra
0 0 0 r
.69279 .39806 .6976 .39444 .70922 .39496 .70424 .39439 Mtetra
.598 .946 .919 r
.70424 .39439 .70922 .39496 .72076 .3931 .71563 .38885 Mtetra
.758 .877 .933 r
.71563 .38885 .72076 .3931 .73225 .38939 .72697 .38217 Mtetra
.749 .773 .873 r
.72697 .38217 .73225 .38939 .74371 .38443 .73833 .37529 Mtetra
.729 .716 .838 r
.73833 .37529 .74371 .38443 .75514 .37874 .74972 .36853 Mtetra
.706 .684 .826 r
.74972 .36853 .75514 .37874 .76661 .37298 .76119 .36243 Mtetra
.69 .671 .826 r
.76119 .36243 .76661 .37298 .77812 .36731 .77273 .35693 Mtetra
.675 .668 .835 r
.77273 .35693 .77812 .36731 .78969 .36206 .78437 .35211 Mtetra
.664 .673 .849 r
.78437 .35211 .78969 .36206 .80134 .35716 .79609 .34781 Mtetra
.655 .684 .865 r
.79609 .34781 .80134 .35716 .81306 .35264 .80789 .34389 Mtetra
.649 .697 .881 r
.80789 .34389 .81306 .35264 .82484 .3484 .81977 .34023 Mtetra
.644 .712 .897 r
.81977 .34023 .82484 .3484 .8367 .34433 .83171 .33671 Mtetra
.643 .729 .911 r
.83171 .33671 .8367 .34433 .84861 .34035 .8437 .33321 Mtetra
.687 .758 .906 r
.20671 .53168 .21326 .53739 .22284 .53395 .21635 .52775 Mtetra
.688 .743 .893 r
.21635 .52775 .22284 .53395 .23244 .53053 .22603 .52374 Mtetra
.685 .725 .881 r
.22603 .52374 .23244 .53053 .24207 .52724 .23573 .51975 Mtetra
.678 .704 .867 r
.23573 .51975 .24207 .52724 .25171 .5242 .24546 .51586 Mtetra
.669 .68 .852 r
.24546 .51586 .25171 .5242 .26136 .52153 .25521 .51214 Mtetra
.652 .65 .836 r
.25521 .51214 .26136 .52153 .27101 .51936 .26495 .50883 Mtetra
.63 .619 .82 r
.26495 .50883 .27101 .51936 .28065 .51786 .27469 .5061 Mtetra
.604 .585 .805 r
.27469 .5061 .28065 .51786 .29029 .51694 .2844 .50419 Mtetra
.572 .553 .795 r
.2844 .50419 .29029 .51694 .29994 .51666 .29408 .50334 Mtetra
.541 .529 .791 r
.29408 .50334 .29994 .51666 .30964 .51652 .30375 .50349 Mtetra
.502 .512 .8 r
.30375 .50349 .30964 .51652 .3194 .51619 .31341 .50472 Mtetra
.47 .524 .831 r
.31341 .50472 .3194 .51619 .32927 .51478 .3231 .50641 Mtetra
.414 .573 .902 r
.3231 .50641 .32927 .51478 .3393 .51155 .33285 .50813 Mtetra
.269 .689 .968 r
.33285 .50813 .3393 .51155 .34949 .50596 .34273 .50878 Mtetra
.101 0 0 r
.34273 .50878 .34949 .50596 .35984 .49746 .35278 .50743 Mtetra
.251 0 .035 r
.35278 .50743 .35984 .49746 .37031 .48667 .36301 .50335 Mtetra
.26 0 .182 r
.36301 .50335 .37031 .48667 .38085 .47406 .37342 .4959 Mtetra
.253 0 .239 r
.37342 .4959 .38085 .47406 .39135 .46191 .38397 .48555 Mtetra
.204 0 .234 r
.38397 .48555 .39135 .46191 .40176 .45196 .39462 .47258 Mtetra
.067 0 .146 r
.39462 .47258 .40176 .45196 .41199 .44683 .40532 .45771 Mtetra
0 0 0 r
.40532 .45771 .41199 .44683 .42206 .4479 .41602 .44194 Mtetra
.861 .782 .772 r
.41602 .44194 .42206 .4479 .43208 .45292 .42662 .42803 Mtetra
.679 .523 .668 r
.42662 .42803 .43208 .45292 .44214 .46031 .4371 .41772 Mtetra
.596 .425 .62 r
.4371 .41772 .44214 .46031 .45232 .46648 .44746 .4122 Mtetra
.551 .378 .6 r
.44746 .4122 .45232 .46648 .46267 .46948 .45774 .41169 Mtetra
.533 .362 .595 r
.45774 .41169 .46267 .46948 .47314 .46958 .46803 .41374 Mtetra
.526 .359 .597 r
.46803 .41374 .47314 .46958 .48371 .467 .47839 .41673 Mtetra
.534 .37 .606 r
.47839 .41673 .48371 .467 .49434 .46338 .48884 .41856 Mtetra
.554 .392 .616 r
.48884 .41856 .49434 .46338 .50501 .45954 .49938 .41797 Mtetra
.58 .416 .623 r
.49938 .41797 .50501 .45954 .51571 .45611 .51 .41448 Mtetra
.604 .432 .623 r
.51 .41448 .51571 .45611 .52646 .45307 .52066 .40808 Mtetra
.616 .437 .616 r
.52066 .40808 .52646 .45307 .53725 .44983 .53134 .39925 Mtetra
.616 .43 .607 r
.53134 .39925 .53725 .44983 .54808 .44554 .54202 .38922 Mtetra
.604 .416 .6 r
.54202 .38922 .54808 .44554 .55891 .43854 .5527 .38012 Mtetra
.587 .402 .597 r
.5527 .38012 .55891 .43854 .56973 .42859 .56343 .37359 Mtetra
.558 .383 .601 r
.56343 .37359 .56973 .42859 .58049 .41543 .57425 .3721 Mtetra
.518 .37 .619 r
.57425 .3721 .58049 .41543 .5912 .40099 .58522 .37548 Mtetra
.429 .361 .679 r
.58522 .37548 .5912 .40099 .60194 .38892 .59636 .38254 Mtetra
0 .184 .692 r
.59636 .38254 .60194 .38892 .61277 .38082 .60767 .39152 Mtetra
.643 .233 .251 r
.60767 .39152 .61277 .38082 .62381 .37904 .61909 .39963 Mtetra
.592 .247 .354 r
.61909 .39963 .62381 .37904 .63507 .38217 .63056 .40585 Mtetra
.555 .226 .365 r
.63056 .40585 .63507 .38217 .64651 .38757 .64206 .40942 Mtetra
.512 .179 .34 r
.64206 .40942 .64651 .38757 .65808 .39347 .65354 .41004 Mtetra
.424 .07 .258 r
.65354 .41004 .65808 .39347 .66969 .39755 .66495 .40722 Mtetra
.205 0 .022 r
.66495 .40722 .66969 .39755 .68127 .39929 .67627 .40159 Mtetra
.514 .891 .703 r
.67627 .40159 .68127 .39929 .69279 .39806 .68753 .3939 Mtetra
.818 .886 .893 r
.68753 .3939 .69279 .39806 .70424 .39439 .69874 .38507 Mtetra
.767 .724 .813 r
.69874 .38507 .70424 .39439 .71563 .38885 .70996 .37626 Mtetra
.728 .652 .774 r
.70996 .37626 .71563 .38885 .72697 .38217 .72122 .36792 Mtetra
.697 .615 .761 r
.72122 .36792 .72697 .38217 .73833 .37529 .73257 .36067 Mtetra
.678 .601 .763 r
.73257 .36067 .73833 .37529 .74972 .36853 .74401 .35445 Mtetra
.661 .599 .775 r
.74401 .35445 .74972 .36853 .76119 .36243 .75556 .34932 Mtetra
.649 .607 .794 r
.75556 .34932 .76119 .36243 .77273 .35693 .76721 .34502 Mtetra
.64 .622 .817 r
.76721 .34502 .77273 .35693 .78437 .35211 .77896 .34134 Mtetra
.632 .641 .841 r
.77896 .34134 .78437 .35211 .79609 .34781 .79079 .33808 Mtetra
.629 .663 .864 r
.79079 .33808 .79609 .34781 .80789 .34389 .80269 .335 Mtetra
.626 .684 .885 r
.80269 .335 .80789 .34389 .81977 .34023 .81466 .33202 Mtetra
.624 .703 .902 r
.81466 .33202 .81977 .34023 .83171 .33671 .82669 .32906 Mtetra
.626 .722 .916 r
.82669 .32906 .83171 .33671 .8437 .33321 .83876 .32602 Mtetra
.691 .759 .904 r
.20012 .52592 .20671 .53168 .21635 .52775 .20979 .52187 Mtetra
.695 .757 .899 r
.20979 .52187 .21635 .52775 .22603 .52374 .2195 .51767 Mtetra
.698 .752 .893 r
.2195 .51767 .22603 .52374 .23573 .51975 .22926 .51335 Mtetra
.699 .742 .885 r
.22926 .51335 .23573 .51975 .24546 .51586 .23905 .50893 Mtetra
.7 .727 .872 r
.23905 .50893 .24546 .51586 .25521 .51214 .24888 .50439 Mtetra
.692 .704 .856 r
.24888 .50439 .25521 .51214 .26495 .50883 .25873 .49994 Mtetra
.679 .673 .837 r
.25873 .49994 .26495 .50883 .27469 .5061 .26859 .4957 Mtetra
.656 .634 .816 r
.26859 .4957 .27469 .5061 .2844 .50419 .27844 .49203 Mtetra
.627 .591 .794 r
.27844 .49203 .2844 .50419 .29408 .50334 .28827 .4892 Mtetra
.593 .546 .772 r
.28827 .4892 .29408 .50334 .30375 .50349 .29805 .48751 Mtetra
.554 .504 .753 r
.29805 .48751 .30375 .50349 .31341 .50472 .30778 .48729 Mtetra
.521 .469 .74 r
.30778 .48729 .31341 .50472 .3231 .50641 .31749 .48842 Mtetra
.485 .443 .735 r
.31749 .48842 .3231 .50641 .33285 .50813 .32717 .49093 Mtetra
.464 .438 .744 r
.32717 .49093 .33285 .50813 .34273 .50878 .3369 .49399 Mtetra
.448 .458 .777 r
.3369 .49399 .34273 .50878 .35278 .50743 .3467 .49698 Mtetra
.448 .538 .856 r
.3467 .49698 .35278 .50743 .36301 .50335 .35664 .4988 Mtetra
.439 .732 .989 r
.35664 .4988 .36301 .50335 .37342 .4959 .36675 .49851 Mtetra
0 0 0 r
.36675 .49851 .37342 .4959 .38397 .48555 .37705 .49516 Mtetra
.031 0 0 r
.37705 .49516 .38397 .48555 .39462 .47258 .38755 .48803 Mtetra
.058 0 .062 r
.38755 .48803 .39462 .47258 .40532 .45771 .39822 .47689 Mtetra
.023 0 .105 r
.39822 .47689 .40532 .45771 .41602 .44194 .40901 .46212 Mtetra
.046 0 .13 r
.40901 .46212 .41602 .44194 .42662 .42803 .41978 .44701 Mtetra
.086 0 .136 r
.41978 .44701 .42662 .42803 .4371 .41772 .43046 .43362 Mtetra
.155 0 .126 r
.43046 .43362 .4371 .41772 .44746 .4122 .44103 .42387 Mtetra
.244 0 .083 r
.44103 .42387 .44746 .4122 .45774 .41169 .4515 .41852 Mtetra
.234 0 0 r
.4515 .41852 .45774 .41169 .46803 .41374 .46194 .41583 Mtetra
.075 0 0 r
.46194 .41583 .46803 .41374 .47839 .41673 .4724 .41473 Mtetra
.36 .793 .967 r
.4724 .41473 .47839 .41673 .48884 .41856 .48292 .41356 Mtetra
.581 .777 .972 r
.48292 .41356 .48884 .41856 .49938 .41797 .4935 .41141 Mtetra
.657 .746 .915 r
.4935 .41141 .49938 .41797 .51 .41448 .50415 .4079 Mtetra
.704 .76 .896 r
.50415 .4079 .51 .41448 .52066 .40808 .51484 .40301 Mtetra
.741 .822 .914 r
.51484 .40301 .52066 .40808 .53134 .39925 .52556 .39713 Mtetra
.728 .932 .957 r
.52556 .39713 .53134 .39925 .54202 .38922 .53631 .39118 Mtetra
.304 .784 .7 r
.53631 .39118 .54202 .38922 .5527 .38012 .54709 .38683 Mtetra
.301 0 0 r
.54709 .38683 .5527 .38012 .56343 .37359 .55794 .38515 Mtetra
.536 .131 .222 r
.55794 .38515 .56343 .37359 .57425 .3721 .56891 .38793 Mtetra
.604 .235 .315 r
.56891 .38793 .57425 .3721 .58522 .37548 .58002 .39441 Mtetra
.621 .268 .35 r
.58002 .39441 .58522 .37548 .59636 .38254 .59129 .40268 Mtetra
.614 .266 .356 r
.59129 .40268 .59636 .38254 .60767 .39152 .60268 .41065 Mtetra
.566 .214 .332 r
.60268 .41065 .60767 .39152 .61909 .39963 .61409 .41496 Mtetra
.486 .115 .26 r
.61409 .41496 .61909 .39963 .63056 .40585 .62547 .41521 Mtetra
.284 0 .04 r
.62547 .41521 .63056 .40585 .64206 .40942 .6368 .41159 Mtetra
.467 .873 .716 r
.6368 .41159 .64206 .40942 .65354 .41004 .64805 .40485 Mtetra
.812 .846 .875 r
.64805 .40485 .65354 .41004 .66495 .40722 .65924 .39592 Mtetra
.767 .687 .774 r
.65924 .39592 .66495 .40722 .67627 .40159 .67038 .38577 Mtetra
.728 .613 .73 r
.67038 .38577 .67627 .40159 .68753 .3939 .68152 .37553 Mtetra
.704 .579 .712 r
.68152 .37553 .68753 .3939 .69874 .38507 .69268 .36583 Mtetra
.682 .56 .711 r
.69268 .36583 .69874 .38507 .70996 .37626 .70393 .35753 Mtetra
.666 .555 .72 r
.70393 .35753 .70996 .37626 .72122 .36792 .71527 .35061 Mtetra
.65 .558 .738 r
.71527 .35061 .72122 .36792 .73257 .36067 .72674 .3452 Mtetra
.637 .57 .762 r
.72674 .3452 .73257 .36067 .74401 .35445 .73832 .34096 Mtetra
.627 .59 .793 r
.73832 .34096 .74401 .35445 .75556 .34932 .75001 .3376 Mtetra
.617 .615 .826 r
.75001 .3376 .75556 .34932 .76721 .34502 .76179 .33482 Mtetra
.612 .644 .858 r
.76179 .33482 .76721 .34502 .77896 .34134 .77365 .33227 Mtetra
.609 .671 .884 r
.77365 .33227 .77896 .34134 .79079 .33808 .78558 .32981 Mtetra
.611 .695 .904 r
.78558 .32981 .79079 .33808 .80269 .335 .79756 .32723 Mtetra
.612 .712 .916 r
.79756 .32723 .80269 .335 .81466 .33202 .80958 .32455 Mtetra
.615 .724 .923 r
.80958 .32455 .81466 .33202 .82669 .32906 .82166 .32174 Mtetra
.62 .732 .927 r
.82166 .32174 .82669 .32906 .83876 .32602 .83378 .31877 Mtetra
.68 .757 .909 r
.19348 .52013 .20012 .52592 .20979 .52187 .20314 .51636 Mtetra
.686 .769 .914 r
.20314 .51636 .20979 .52187 .2195 .51767 .21285 .51243 Mtetra
.695 .78 .917 r
.21285 .51243 .2195 .51767 .22926 .51335 .22262 .50827 Mtetra
.705 .788 .916 r
.22262 .50827 .22926 .51335 .23905 .50893 .23244 .50381 Mtetra
.718 .79 .908 r
.23244 .50381 .23905 .50893 .24888 .50439 .24232 .49896 Mtetra
.726 .781 .896 r
.24232 .49896 .24888 .50439 .25873 .49994 .25225 .49379 Mtetra
.73 .76 .876 r
.25225 .49379 .25873 .49994 .26859 .4957 .26223 .48831 Mtetra
.721 .723 .851 r
.26223 .48831 .26859 .4957 .27844 .49203 .27224 .4828 Mtetra
.703 .676 .821 r
.27224 .4828 .27844 .49203 .28827 .4892 .28226 .47743 Mtetra
.673 .619 .787 r
.28226 .47743 .28827 .4892 .29805 .48751 .29226 .47265 Mtetra
.638 .563 .754 r
.29226 .47265 .29805 .48751 .30778 .48729 .30223 .46883 Mtetra
.6 .508 .722 r
.30223 .46883 .30778 .48729 .31749 .48842 .31214 .46636 Mtetra
.563 .461 .697 r
.31214 .46636 .31749 .48842 .32717 .49093 .32199 .46564 Mtetra
.532 .424 .677 r
.32199 .46564 .32717 .49093 .3369 .49399 .33178 .46669 Mtetra
.501 .395 .666 r
.33178 .46669 .3369 .49399 .3467 .49698 .34153 .46961 Mtetra
.477 .379 .665 r
.34153 .46961 .3467 .49698 .35664 .4988 .35129 .47388 Mtetra
.449 .372 .678 r
.35129 .47388 .35664 .4988 .36675 .49851 .36109 .47906 Mtetra
.425 .394 .721 r
.36109 .47906 .36675 .49851 .37705 .49516 .371 .4839 Mtetra
.362 .474 .839 r
.371 .4839 .37705 .49516 .38755 .48803 .38104 .48756 Mtetra
.295 0 0 r
.38104 .48756 .38755 .48803 .39822 .47689 .39121 .49028 Mtetra
.514 .13 .25 r
.39121 .49028 .39822 .47689 .40901 .46212 .4015 .49188 Mtetra
.511 .206 .386 r
.4015 .49188 .40901 .46212 .41978 .44701 .41191 .49182 Mtetra
.501 .225 .427 r
.41191 .49182 .41978 .44701 .43046 .43362 .42246 .48958 Mtetra
.483 .221 .44 r
.42246 .48958 .43046 .43362 .44103 .42387 .43314 .48393 Mtetra
.461 .205 .439 r
.43314 .48393 .44103 .42387 .4515 .41852 .44395 .47473 Mtetra
.44 .184 .429 r
.44395 .47473 .4515 .41852 .46194 .41583 .45479 .4637 Mtetra
.416 .156 .409 r
.45479 .4637 .46194 .41583 .4724 .41473 .46564 .45219 Mtetra
.4 .127 .379 r
.46564 .45219 .4724 .41473 .48292 .41356 .47645 .44234 Mtetra
.404 .109 .346 r
.47645 .44234 .48292 .41356 .4935 .41141 .48723 .43535 Mtetra
.444 .126 .331 r
.48723 .43535 .4935 .41141 .50415 .4079 .498 .43184 Mtetra
.503 .18 .352 r
.498 .43184 .50415 .4079 .51484 .40301 .5088 .43181 Mtetra
.545 .233 .39 r
.5088 .43181 .51484 .40301 .52556 .39713 .51965 .43466 Mtetra
.559 .264 .423 r
.51965 .43466 .52556 .39713 .53631 .39118 .5306 .43921 Mtetra
.552 .272 .444 r
.5306 .43921 .53631 .39118 .54709 .38683 .54164 .44331 Mtetra
.539 .268 .453 r
.54164 .44331 .54709 .38683 .55794 .38515 .55276 .44558 Mtetra
.517 .253 .453 r
.55276 .44558 .55794 .38515 .56891 .38793 .56393 .44428 Mtetra
.492 .229 .443 r
.56393 .44428 .56891 .38793 .58002 .39441 .5751 .43954 Mtetra
.46 .19 .417 r
.5751 .43954 .58002 .39441 .59129 .40268 .58627 .43257 Mtetra
.388 .1 .349 r
.58627 .43257 .59129 .40268 .60268 .41065 .59742 .4239 Mtetra
.11 0 .067 r
.59742 .4239 .60268 .41065 .61409 .41496 .60856 .41406 Mtetra
.859 .976 .861 r
.60856 .41406 .61409 .41496 .62547 .41521 .61966 .40325 Mtetra
.784 .682 .752 r
.61966 .40325 .62547 .41521 .6368 .41159 .63072 .3912 Mtetra
.721 .575 .69 r
.63072 .3912 .6368 .41159 .64805 .40485 .64176 .37878 Mtetra
.684 .525 .665 r
.64176 .37878 .64805 .40485 .65924 .39592 .65281 .36726 Mtetra
.661 .502 .658 r
.65281 .36726 .65924 .39592 .67038 .38577 .66392 .35709 Mtetra
.643 .49 .66 r
.66392 .35709 .67038 .38577 .68152 .37553 .67511 .34883 Mtetra
.63 .489 .672 r
.67511 .34883 .68152 .37553 .69268 .36583 .68641 .34238 Mtetra
.617 .496 .692 r
.68641 .34238 .69268 .36583 .70393 .35753 .69784 .33772 Mtetra
.606 .512 .721 r
.69784 .33772 .70393 .35753 .71527 .35061 .70939 .33445 Mtetra
.596 .54 .761 r
.70939 .33445 .71527 .35061 .72674 .3452 .72105 .33218 Mtetra
.586 .576 .809 r
.72105 .33218 .72674 .3452 .73832 .34096 .73282 .33052 Mtetra
.579 .622 .859 r
.73282 .33052 .73832 .34096 .75001 .3376 .74465 .32901 Mtetra
.573 .667 .902 r
.74465 .32901 .75001 .3376 .76179 .33482 .75656 .32747 Mtetra
.577 .708 .932 r
.75656 .32747 .76179 .33482 .77365 .33227 .76851 .32561 Mtetra
.583 .737 .948 r
.76851 .32561 .77365 .33227 .78558 .32981 .78049 .32343 Mtetra
.598 .755 .953 r
.78049 .32343 .78558 .32981 .79756 .32723 .79251 .32084 Mtetra
.611 .761 .95 r
.79251 .32084 .79756 .32723 .80958 .32455 .80455 .31793 Mtetra
.623 .759 .944 r
.80455 .31793 .80958 .32455 .82166 .32174 .81664 .31479 Mtetra
.631 .752 .934 r
.81664 .31479 .82166 .32174 .83378 .31877 .82876 .31146 Mtetra
.653 .751 .922 r
.18679 .51429 .19348 .52013 .20314 .51636 .19641 .51119 Mtetra
.656 .776 .937 r
.19641 .51119 .20314 .51636 .21285 .51243 .20608 .50796 Mtetra
.663 .804 .951 r
.20608 .50796 .21285 .51243 .22262 .50827 .2158 .50451 Mtetra
.674 .835 .96 r
.2158 .50451 .22262 .50827 .23244 .50381 .22559 .50071 Mtetra
.691 .863 .964 r
.22559 .50071 .23244 .50381 .24232 .49896 .23545 .49644 Mtetra
.71 .888 .962 r
.23545 .49644 .24232 .49896 .25225 .49379 .24539 .49163 Mtetra
.735 .904 .953 r
.24539 .49163 .25225 .49379 .26223 .48831 .2554 .48618 Mtetra
.756 .906 .943 r
.2554 .48618 .26223 .48831 .27224 .4828 .26548 .4802 Mtetra
.775 .889 .927 r
.26548 .4802 .27224 .4828 .28226 .47743 .27562 .47371 Mtetra
.776 .849 .906 r
.27562 .47371 .28226 .47743 .29226 .47265 .28579 .46707 Mtetra
.76 .785 .874 r
.28579 .46707 .29226 .47265 .30223 .46883 .29597 .46051 Mtetra
.723 .704 .833 r
.29597 .46051 .30223 .46883 .31214 .46636 .30613 .45456 Mtetra
.674 .621 .788 r
.30613 .45456 .31214 .46636 .32199 .46564 .31624 .44968 Mtetra
.623 .544 .745 r
.31624 .44968 .32199 .46564 .33178 .46669 .32628 .44633 Mtetra
.575 .48 .71 r
.32628 .44633 .33178 .46669 .34153 .46961 .33625 .44498 Mtetra
.538 .432 .682 r
.33625 .44498 .34153 .46961 .35129 .47388 .34616 .44558 Mtetra
.507 .396 .662 r
.34616 .44558 .35129 .47388 .36109 .47906 .35603 .44816 Mtetra
.488 .374 .65 r
.35603 .44816 .36109 .47906 .371 .4839 .36591 .45215 Mtetra
.474 .361 .646 r
.36591 .45215 .371 .4839 .38104 .48756 .37582 .45718 Mtetra
.452 .352 .65 r
.37582 .45718 .38104 .48756 .39121 .49028 .38578 .46326 Mtetra
.427 .349 .666 r
.38578 .46326 .39121 .49028 .4015 .49188 .39582 .4699 Mtetra
.436 .384 .702 r
.39582 .4699 .4015 .49188 .41191 .49182 .40602 .47498 Mtetra
.489 .463 .755 r
.40602 .47498 .41191 .49182 .42246 .48958 .41641 .4771 Mtetra
.599 .583 .807 r
.41641 .4771 .42246 .48958 .43314 .48393 .427 .47511 Mtetra
.723 .707 .835 r
.427 .47511 .43314 .48393 .44395 .47473 .43776 .46883 Mtetra
.793 .799 .857 r
.43776 .46883 .44395 .47473 .45479 .4637 .44858 .46047 Mtetra
.828 .888 .885 r
.44858 .46047 .45479 .4637 .46564 .45219 .45943 .45149 Mtetra
.784 .972 .916 r
.45943 .45149 .46564 .45219 .47645 .44234 .47027 .44359 Mtetra
.551 .931 .843 r
.47027 .44359 .47645 .44234 .48723 .43535 .48109 .43773 Mtetra
0 0 0 r
.48109 .43773 .48723 .43535 .498 .43184 .49192 .43419 Mtetra
.086 0 0 r
.49192 .43419 .498 .43184 .5088 .43181 .50277 .433 Mtetra
.205 0 0 r
.50277 .433 .5088 .43181 .51965 .43466 .51368 .43386 Mtetra
.15 0 0 r
.51368 .43386 .51965 .43466 .5306 .43921 .52466 .43583 Mtetra
.18 .641 .938 r
.52466 .43583 .5306 .43921 .54164 .44331 .53572 .43717 Mtetra
.506 .712 .964 r
.53572 .43717 .54164 .44331 .55276 .44558 .54684 .43646 Mtetra
.69 .697 .852 r
.54684 .43646 .55276 .44558 .56393 .44428 .55798 .4314 Mtetra
.738 .65 .762 r
.55798 .4314 .56393 .44428 .5751 .43954 .5691 .42216 Mtetra
.739 .605 .708 r
.5691 .42216 .5751 .43954 .58627 .43257 .58018 .4099 Mtetra
.721 .563 .675 r
.58018 .4099 .58627 .43257 .59742 .4239 .59121 .39602 Mtetra
.692 .524 .655 r
.59121 .39602 .59742 .4239 .60856 .41406 .60223 .38269 Mtetra
.67 .5 .645 r
.60223 .38269 .60856 .41406 .61966 .40325 .61325 .37039 Mtetra
.657 .487 .642 r
.61325 .37039 .61966 .40325 .63072 .3912 .62429 .35911 Mtetra
.648 .482 .646 r
.62429 .35911 .63072 .3912 .64176 .37878 .63537 .34926 Mtetra
.636 .483 .657 r
.63537 .34926 .64176 .37878 .65281 .36726 .64653 .34142 Mtetra
.626 .489 .676 r
.64653 .34142 .65281 .36726 .66392 .35709 .65779 .33556 Mtetra
.61 .502 .706 r
.65779 .33556 .66392 .35709 .67511 .34883 .66917 .33174 Mtetra
.593 .527 .75 r
.66917 .33174 .67511 .34883 .68641 .34238 .68068 .32951 Mtetra
.571 .569 .813 r
.68068 .32951 .68641 .34238 .69784 .33772 .69231 .32838 Mtetra
.537 .626 .888 r
.69231 .32838 .69784 .33772 .70939 .33445 .70404 .32788 Mtetra
.492 .693 .958 r
.70404 .32788 .70939 .33445 .72105 .33218 .71585 .32749 Mtetra
.441 .744 .992 r
.71585 .32749 .72105 .33218 .73282 .33052 .72773 .32694 Mtetra
.423 .782 .996 r
.72773 .32694 .73282 .33052 .74465 .32901 .73964 .32587 Mtetra
.44 .808 .994 r
.73964 .32587 .74465 .32901 .75656 .32747 .75159 .32426 Mtetra
.494 .833 .998 r
.75159 .32426 .75656 .32747 .76851 .32561 .76355 .32198 Mtetra
.549 .844 .998 r
.76355 .32198 .76851 .32561 .78049 .32343 .77553 .31914 Mtetra
.598 .84 .99 r
.77553 .31914 .78049 .32343 .79251 .32084 .78753 .31581 Mtetra
.63 .824 .975 r
.78753 .31581 .79251 .32084 .80455 .31793 .79956 .31211 Mtetra
.649 .801 .956 r
.79956 .31211 .80455 .31793 .81664 .31479 .81161 .30817 Mtetra
.657 .776 .937 r
.81161 .30817 .81664 .31479 .82876 .31146 .82371 .3041 Mtetra
.614 .74 .936 r
.18006 .50842 .18679 .51429 .19641 .51119 .18962 .50611 Mtetra
.608 .769 .957 r
.18962 .50611 .19641 .51119 .20608 .50796 .19922 .50379 Mtetra
.602 .803 .977 r
.19922 .50379 .20608 .50796 .2158 .50451 .20887 .50133 Mtetra
.596 .841 .991 r
.20887 .50133 .2158 .50451 .22559 .50071 .21859 .49863 Mtetra
.586 .879 .993 r
.21859 .49863 .22559 .50071 .23545 .49644 .22837 .49556 Mtetra
.572 .911 .972 r
.22837 .49556 .23545 .49644 .24539 .49163 .23824 .49198 Mtetra
.556 .927 .926 r
.23824 .49198 .24539 .49163 .2554 .48618 .2482 .48771 Mtetra
.539 .926 .86 r
.2482 .48771 .2554 .48618 .26548 .4802 .25825 .48266 Mtetra
.549 .927 .807 r
.25825 .48266 .26548 .4802 .27562 .47371 .26841 .47668 Mtetra
.58 .936 .783 r
.26841 .47668 .27562 .47371 .28579 .46707 .27864 .46988 Mtetra
.659 .969 .808 r
.27864 .46988 .28579 .46707 .29597 .46051 .28895 .46227 Mtetra
.75 .993 .865 r
.28895 .46227 .29597 .46051 .30613 .45456 .2993 .45418 Mtetra
.818 .961 .903 r
.2993 .45418 .30613 .45456 .31624 .44968 .30968 .44587 Mtetra
.808 .849 .88 r
.30968 .44587 .31624 .44968 .32628 .44633 .32005 .43781 Mtetra
.749 .71 .815 r
.32005 .43781 .32628 .44633 .33625 .44498 .33039 .43042 Mtetra
.685 .593 .747 r
.33039 .43042 .33625 .44498 .34616 .44558 .34069 .42396 Mtetra
.633 .509 .694 r
.34069 .42396 .34616 .44558 .35603 .44816 .35094 .41873 Mtetra
.592 .45 .656 r
.35094 .41873 .35603 .44816 .36591 .45215 .36114 .41523 Mtetra
.562 .409 .631 r
.36114 .41523 .36591 .45215 .37582 .45718 .37127 .41369 Mtetra
.548 .387 .615 r
.37127 .41369 .37582 .45718 .38578 .46326 .38141 .41333 Mtetra
.541 .374 .604 r
.38141 .41333 .38578 .46326 .39582 .4699 .39158 .4136 Mtetra
.544 .37 .595 r
.39158 .4136 .39582 .4699 .40602 .47498 .40183 .41334 Mtetra
.55 .369 .589 r
.40183 .41334 .40602 .47498 .41641 .4771 .41217 .41215 Mtetra
.546 .364 .586 r
.41217 .41215 .41641 .4771 .427 .47511 .42256 .4115 Mtetra
.539 .36 .587 r
.42256 .4115 .427 .47511 .43776 .46883 .43297 .41197 Mtetra
.53 .359 .594 r
.43297 .41197 .43776 .46883 .44858 .46047 .44341 .41368 Mtetra
.521 .364 .609 r
.44341 .41368 .44858 .46047 .45943 .45149 .45391 .41623 Mtetra
.528 .391 .638 r
.45391 .41623 .45943 .45149 .47027 .44359 .46451 .41774 Mtetra
.556 .442 .679 r
.46451 .41774 .47027 .44359 .48109 .43773 .47522 .41719 Mtetra
.61 .506 .711 r
.47522 .41719 .48109 .43773 .49192 .43419 .48603 .41362 Mtetra
.654 .533 .703 r
.48603 .41362 .49192 .43419 .50277 .433 .49691 .40702 Mtetra
.657 .508 .669 r
.49691 .40702 .50277 .433 .51368 .43386 .50782 .39834 Mtetra
.639 .468 .635 r
.50782 .39834 .51368 .43386 .52466 .43583 .51874 .3886 Mtetra
.611 .429 .611 r
.51874 .3886 .52466 .43583 .53572 .43717 .52967 .37968 Mtetra
.591 .404 .597 r
.52967 .37968 .53572 .43717 .54684 .43646 .54061 .372 Mtetra
.58 .39 .589 r
.54061 .372 .54684 .43646 .55798 .4314 .55157 .36543 Mtetra
.576 .386 .588 r
.55157 .36543 .55798 .4314 .5691 .42216 .56257 .3594 Mtetra
.583 .394 .591 r
.56257 .3594 .5691 .42216 .58018 .4099 .57357 .35242 Mtetra
.59 .403 .597 r
.57357 .35242 .58018 .4099 .59121 .39602 .58459 .34488 Mtetra
.592 .411 .605 r
.58459 .34488 .59121 .39602 .60223 .38269 .59564 .33798 Mtetra
.591 .418 .616 r
.59564 .33798 .60223 .38269 .61325 .37039 .60675 .33226 Mtetra
.581 .423 .632 r
.60675 .33226 .61325 .37039 .62429 .35911 .61794 .32855 Mtetra
.57 .435 .658 r
.61794 .32855 .62429 .35911 .63537 .34926 .62924 .32659 Mtetra
.559 .463 .702 r
.62924 .32659 .63537 .34926 .64653 .34142 .64065 .3259 Mtetra
.536 .511 .776 r
.64065 .3259 .64653 .34142 .65779 .33556 .65216 .32617 Mtetra
.472 .591 .891 r
.65216 .32617 .65779 .33556 .66917 .33174 .66378 .32714 Mtetra
.289 .661 .971 r
.66378 .32714 .66917 .33174 .68068 .32951 .67549 .3284 Mtetra
.004 .573 .782 r
.67549 .3284 .68068 .32951 .69231 .32838 .68728 .32943 Mtetra
.151 0 0 r
.68728 .32943 .69231 .32838 .70404 .32788 .69913 .32999 Mtetra
.16 0 0 r
.69913 .32999 .70404 .32788 .71585 .32749 .71102 .32972 Mtetra
.097 0 0 r
.71102 .32972 .71585 .32749 .72773 .32694 .72292 .3286 Mtetra
0 0 0 r
.72292 .3286 .72773 .32694 .73964 .32587 .73483 .32653 Mtetra
.219 .739 .749 r
.73483 .32653 .73964 .32587 .75159 .32426 .74675 .32365 Mtetra
.412 .86 .895 r
.74675 .32365 .75159 .32426 .76355 .32198 .75868 .32005 Mtetra
.553 .906 .97 r
.75868 .32005 .76355 .32198 .77553 .31914 .77061 .3159 Mtetra
.633 .896 .986 r
.77061 .3159 .77553 .31914 .78753 .31581 .78257 .31138 Mtetra
.671 .864 .973 r
.78257 .31138 .78753 .31581 .79956 .31211 .79455 .30659 Mtetra
.686 .828 .951 r
.79455 .30659 .79956 .31211 .81161 .30817 .80656 .30165 Mtetra
.689 .794 .93 r
.80656 .30165 .81161 .30817 .82371 .3041 .81861 .29669 Mtetra
.587 .732 .944 r
.17328 .5025 .18006 .50842 .18962 .50611 .18281 .50069 Mtetra
.575 .747 .958 r
.18281 .50069 .18962 .50611 .19922 .50379 .19236 .49896 Mtetra
.564 .767 .974 r
.19236 .49896 .19922 .50379 .20887 .50133 .20197 .49723 Mtetra
.55 .792 .989 r
.20197 .49723 .20887 .50133 .21859 .49863 .21162 .49545 Mtetra
.526 .821 .999 r
.21162 .49545 .21859 .49863 .22837 .49556 .22132 .49356 Mtetra
.494 .851 .992 r
.22132 .49356 .22837 .49556 .23824 .49198 .2311 .4914 Mtetra
.438 .862 .943 r
.2311 .4914 .23824 .49198 .2482 .48771 .24095 .48881 Mtetra
.356 .83 .826 r
.24095 .48881 .2482 .48771 .25825 .48266 .2509 .48559 Mtetra
.267 .754 .659 r
.2509 .48559 .25825 .48266 .26841 .47668 .26095 .48155 Mtetra
0 0 0 r
.26095 .48155 .26841 .47668 .27864 .46988 .27111 .47655 Mtetra
.27111 .47655 .27864 .46988 .28895 .46227 .28137 .47046 Mtetra
.28137 .47046 .28895 .46227 .2993 .45418 .29173 .46335 Mtetra
.29173 .46335 .2993 .45418 .30968 .44587 .30217 .45524 Mtetra
.30217 .45524 .30968 .44587 .32005 .43781 .31267 .44642 Mtetra
.31267 .44642 .32005 .43781 .33039 .43042 .3232 .43713 Mtetra
.3232 .43713 .33039 .43042 .34069 .42396 .33374 .42776 Mtetra
.668 .959 .74 r
.33374 .42776 .34069 .42396 .35094 .41873 .34427 .41867 Mtetra
.798 .976 .905 r
.34427 .41867 .35094 .41873 .36114 .41523 .35475 .41057 Mtetra
.77 .828 .897 r
.35475 .41057 .36114 .41523 .37127 .41369 .36516 .40384 Mtetra
.712 .676 .813 r
.36516 .40384 .37127 .41369 .38141 .41333 .37557 .39772 Mtetra
.666 .574 .742 r
.37557 .39772 .38141 .41333 .39158 .4136 .38599 .39199 Mtetra
.629 .508 .696 r
.38599 .39199 .39158 .4136 .40183 .41334 .3964 .38696 Mtetra
.602 .468 .671 r
.3964 .38696 .40183 .41334 .41217 .41215 .4068 .38303 Mtetra
.564 .432 .659 r
.4068 .38303 .41217 .41215 .42256 .4115 .41715 .38167 Mtetra
.523 .402 .657 r
.41715 .38167 .42256 .4115 .43297 .41197 .42747 .38321 Mtetra
.497 .389 .661 r
.42747 .38321 .43297 .41197 .44341 .41368 .43782 .38633 Mtetra
.486 .388 .669 r
.43782 .38633 .44341 .41368 .45391 .41623 .44824 .38992 Mtetra
.511 .409 .676 r
.44824 .38992 .45391 .41623 .46451 .41774 .45879 .39203 Mtetra
.553 .44 .679 r
.45879 .39203 .46451 .41774 .47522 .41719 .46945 .39157 Mtetra
.599 .471 .678 r
.46945 .39157 .47522 .41719 .48603 .41362 .48022 .38796 Mtetra
.637 .496 .673 r
.48022 .38796 .48603 .41362 .49691 .40702 .49107 .38119 Mtetra
.664 .513 .668 r
.49107 .38119 .49691 .40702 .50782 .39834 .50196 .37181 Mtetra
.676 .517 .663 r
.50196 .37181 .50782 .39834 .51874 .3886 .51286 .36094 Mtetra
.667 .508 .659 r
.51286 .36094 .51874 .3886 .52967 .37968 .52375 .35052 Mtetra
.647 .489 .655 r
.52375 .35052 .52967 .37968 .54061 .372 .53465 .34166 Mtetra
.615 .464 .654 r
.53465 .34166 .54061 .372 .55157 .36543 .54557 .33573 Mtetra
.587 .448 .659 r
.54557 .33573 .55157 .36543 .56257 .3594 .55654 .33238 Mtetra
.577 .451 .672 r
.55654 .33238 .56257 .3594 .57357 .35242 .56758 .33014 Mtetra
.572 .472 .702 r
.56758 .33014 .57357 .35242 .58459 .34488 .57868 .32863 Mtetra
.569 .521 .761 r
.57868 .32863 .58459 .34488 .59564 .33798 .58986 .32752 Mtetra
.543 .6 .861 r
.58986 .32752 .59564 .33798 .60675 .33226 .60111 .32703 Mtetra
.35 .67 .975 r
.60111 .32703 .60675 .33226 .61794 .32855 .61247 .32796 Mtetra
.151 0 0 r
.61247 .32796 .61794 .32855 .62924 .32659 .62394 .32991 Mtetra
.405 0 0 r
.62394 .32991 .62924 .32659 .64065 .3259 .63552 .33217 Mtetra
.466 0 0 r
.63552 .33217 .64065 .3259 .65216 .32617 .64718 .33436 Mtetra
.471 .01 .075 r
.64718 .33436 .65216 .32617 .66378 .32714 .65891 .33609 Mtetra
.454 .004 .091 r
.65891 .33609 .66378 .32714 .67549 .3284 .6707 .33712 Mtetra
.414 0 .064 r
.6707 .33712 .67549 .3284 .68728 .32943 .68252 .33712 Mtetra
.351 0 0 r
.68252 .33712 .68728 .32943 .69913 .32999 .69437 .33607 Mtetra
.244 0 0 r
.69437 .33607 .69913 .32999 .71102 .32972 .70622 .3339 Mtetra
.075 0 0 r
.70622 .3339 .71102 .32972 .72292 .3286 .71808 .33074 Mtetra
0 0 0 r
.71808 .33074 .72292 .3286 .73483 .32653 .72993 .32673 Mtetra
.433 .874 .844 r
.72993 .32673 .73483 .32653 .74675 .32365 .74179 .32205 Mtetra
.601 .933 .956 r
.74179 .32205 .74675 .32365 .75868 .32005 .75366 .31693 Mtetra
.677 .915 .975 r
.75366 .31693 .75868 .32005 .77061 .3159 .76556 .31151 Mtetra
.702 .876 .963 r
.76556 .31151 .77061 .3159 .78257 .31138 .77748 .30597 Mtetra
.71 .841 .945 r
.77748 .30597 .78257 .31138 .79455 .30659 .78943 .30036 Mtetra
.71 .813 .929 r
.78943 .30036 .79455 .30659 .80656 .30165 .80143 .29475 Mtetra
.706 .789 .916 r
.80143 .29475 .80656 .30165 .81861 .29669 .81347 .28921 Mtetra
.583 .731 .945 r
.16646 .49655 .17328 .5025 .18281 .50069 .17599 .49478 Mtetra
.574 .73 .948 r
.17599 .49478 .18281 .50069 .19236 .49896 .18555 .49316 Mtetra
.562 .731 .954 r
.18555 .49316 .19236 .49896 .20197 .49723 .19515 .49168 Mtetra
.547 .736 .963 r
.19515 .49168 .20197 .49723 .21162 .49545 .20477 .49036 Mtetra
.523 .746 .977 r
.20477 .49036 .21162 .49545 .22132 .49356 .21443 .48924 Mtetra
.492 .765 .992 r
.21443 .48924 .22132 .49356 .2311 .4914 .22412 .4882 Mtetra
.438 .787 .997 r
.22412 .4882 .2311 .4914 .24095 .48881 .23386 .48717 Mtetra
.348 .794 .956 r
.23386 .48717 .24095 .48881 .2509 .48559 .24367 .48596 Mtetra
.197 .726 .798 r
.24367 .48596 .2509 .48559 .26095 .48155 .25356 .48439 Mtetra
0 0 0 r
.25356 .48439 .26095 .48155 .27111 .47655 .26355 .48224 Mtetra
.111 0 0 r
.26355 .48224 .27111 .47655 .28137 .47046 .27364 .47929 Mtetra
.19 0 0 r
.27364 .47929 .28137 .47046 .29173 .46335 .28383 .47537 Mtetra
.229 0 .055 r
.28383 .47537 .29173 .46335 .30217 .45524 .29415 .47033 Mtetra
.251 0 .131 r
.29415 .47033 .30217 .45524 .31267 .44642 .30457 .46417 Mtetra
.259 0 .176 r
.30457 .46417 .31267 .44642 .3232 .43713 .31508 .45689 Mtetra
.267 0 .205 r
.31508 .45689 .3232 .43713 .33374 .42776 .32565 .44883 Mtetra
.271 0 .221 r
.32565 .44883 .33374 .42776 .34427 .41867 .33627 .44024 Mtetra
.269 0 .226 r
.33627 .44024 .34427 .41867 .35475 .41057 .34691 .43131 Mtetra
.253 0 .212 r
.34691 .43131 .35475 .41057 .36516 .40384 .35757 .42222 Mtetra
.202 0 .162 r
.35757 .42222 .36516 .40384 .37557 .39772 .36824 .41291 Mtetra
.121 0 .074 r
.36824 .41291 .37557 .39772 .38599 .39199 .37891 .40364 Mtetra
.085 0 0 r
.37891 .40364 .38599 .39199 .3964 .38696 .38951 .39602 Mtetra
.128 0 0 r
.38951 .39602 .3964 .38696 .4068 .38303 .40004 .39077 Mtetra
.202 0 0 r
.40004 .39077 .4068 .38303 .41715 .38167 .41053 .38738 Mtetra
.213 0 0 r
.41053 .38738 .41715 .38167 .42747 .38321 .42102 .38533 Mtetra
0 0 0 r
.42102 .38533 .42747 .38321 .43782 .38633 .43157 .38288 Mtetra
.625 .858 .987 r
.43157 .38288 .43782 .38633 .44824 .38992 .4422 .37937 Mtetra
.657 .647 .828 r
.4422 .37937 .44824 .38992 .45879 .39203 .45288 .37534 Mtetra
.634 .55 .743 r
.45288 .37534 .45879 .39203 .46945 .39157 .46361 .37108 Mtetra
.61 .506 .711 r
.46361 .37108 .46945 .39157 .48022 .38796 .47436 .36743 Mtetra
.6 .5 .712 r
.47436 .36743 .48022 .38796 .49107 .38119 .48515 .36439 Mtetra
.614 .539 .746 r
.48515 .36439 .49107 .38119 .50196 .37181 .49599 .36112 Mtetra
.649 .644 .831 r
.49599 .36112 .50196 .37181 .51286 .36094 .50688 .35733 Mtetra
.691 .876 .967 r
.50688 .35733 .51286 .36094 .52375 .35052 .51781 .35247 Mtetra
.403 .846 .742 r
.51781 .35247 .52375 .35052 .53465 .34166 .52877 .34719 Mtetra
.068 0 0 r
.52877 .34719 .53465 .34166 .54557 .33573 .53978 .34327 Mtetra
.293 0 0 r
.53978 .34327 .54557 .33573 .55654 .33238 .55085 .34124 Mtetra
.431 0 .082 r
.55085 .34124 .55654 .33238 .56758 .33014 .562 .3416 Mtetra
.506 .091 .187 r
.562 .3416 .56758 .33014 .57868 .32863 .57325 .34366 Mtetra
.517 .135 .255 r
.57325 .34366 .57868 .32863 .58986 .32752 .58458 .34578 Mtetra
.518 .158 .295 r
.58458 .34578 .58986 .32752 .60111 .32703 .59601 .34769 Mtetra
.519 .171 .317 r
.59601 .34769 .60111 .32703 .61247 .32796 .60751 .34947 Mtetra
.514 .17 .322 r
.60751 .34947 .61247 .32796 .62394 .32991 .61909 .35091 Mtetra
.504 .159 .314 r
.61909 .35091 .62394 .32991 .63552 .33217 .63075 .35182 Mtetra
.487 .136 .296 r
.63075 .35182 .63552 .33217 .64718 .33436 .64245 .35195 Mtetra
.457 .096 .263 r
.64245 .35195 .64718 .33436 .65891 .33609 .65419 .35093 Mtetra
.412 .033 .207 r
.65419 .35093 .65891 .33609 .6707 .33712 .66595 .34877 Mtetra
.336 0 .112 r
.66595 .34877 .6707 .33712 .68252 .33712 .67771 .34545 Mtetra
.207 0 0 r
.67771 .34545 .68252 .33712 .69437 .33607 .68947 .34113 Mtetra
0 0 0 r
.68947 .34113 .69437 .33607 .70622 .3339 .70124 .33598 Mtetra
.348 .803 .676 r
.70124 .33598 .70622 .3339 .71808 .33074 .71301 .33021 Mtetra
.608 .952 .907 r
.71301 .33021 .71808 .33074 .72993 .32673 .72479 .32407 Mtetra
.711 .939 .96 r
.72479 .32407 .72993 .32673 .74179 .32205 .73659 .31772 Mtetra
.734 .886 .95 r
.73659 .31772 .74179 .32205 .75366 .31693 .74843 .31137 Mtetra
.734 .842 .931 r
.74843 .31137 .75366 .31693 .76556 .31151 .7603 .3051 Mtetra
.725 .811 .918 r
.7603 .3051 .76556 .31151 .77748 .30597 .77223 .29902 Mtetra
.718 .792 .91 r
.77223 .29902 .77748 .30597 .78943 .30036 .7842 .2931 Mtetra
.712 .78 .906 r
.7842 .2931 .78943 .30036 .80143 .29475 .79622 .28732 Mtetra
.707 .774 .905 r
.79622 .28732 .80143 .29475 .81347 .28921 .8083 .28168 Mtetra
.614 .74 .936 r
.15958 .49055 .16646 .49655 .17599 .49478 .1692 .48819 Mtetra
.609 .719 .923 r
.1692 .48819 .17599 .49478 .18555 .49316 .17883 .48598 Mtetra
.601 .698 .912 r
.17883 .48598 .18555 .49316 .19515 .49168 .18849 .48398 Mtetra
.59 .679 .902 r
.18849 .48398 .19515 .49168 .20477 .49036 .19817 .48225 Mtetra
.574 .662 .897 r
.19817 .48225 .20477 .49036 .21443 .48924 .20785 .4809 Mtetra
.558 .649 .895 r
.20785 .4809 .21443 .48924 .22412 .4882 .21755 .47988 Mtetra
.54 .643 .9 r
.21755 .47988 .22412 .4882 .23386 .48717 .22727 .47923 Mtetra
.523 .648 .913 r
.22727 .47923 .23386 .48717 .24367 .48596 .23702 .47881 Mtetra
.502 .665 .935 r
.23702 .47881 .24367 .48596 .25356 .48439 .24682 .47854 Mtetra
.477 .702 .968 r
.24682 .47854 .25356 .48439 .26355 .48224 .25667 .4782 Mtetra
.429 .754 .995 r
.25667 .4782 .26355 .48224 .27364 .47929 .2666 .47762 Mtetra
.322 .78 .948 r
.2666 .47762 .27364 .47929 .28383 .47537 .27663 .47655 Mtetra
.131 .676 .708 r
.27663 .47655 .28383 .47537 .29415 .47033 .28675 .47478 Mtetra
.062 0 0 r
.28675 .47478 .29415 .47033 .30457 .46417 .29699 .47215 Mtetra
.174 0 0 r
.29699 .47215 .30457 .46417 .31508 .45689 .30733 .4685 Mtetra
.246 0 .051 r
.30733 .4685 .31508 .45689 .32565 .44883 .31777 .46398 Mtetra
.288 0 .148 r
.31777 .46398 .32565 .44883 .33627 .44024 .32829 .45865 Mtetra
.305 0 .204 r
.32829 .45865 .33627 .44024 .34691 .43131 .3389 .45233 Mtetra
.309 0 .235 r
.3389 .45233 .34691 .43131 .35757 .42222 .34958 .44502 Mtetra
.317 0 .255 r
.34958 .44502 .35757 .42222 .36824 .41291 .3603 .43723 Mtetra
.333 .02 .275 r
.3603 .43723 .36824 .41291 .37891 .40364 .37104 .4294 Mtetra
.373 .061 .302 r
.37104 .4294 .37891 .40364 .38951 .39602 .38174 .4227 Mtetra
.409 .097 .322 r
.38174 .4227 .38951 .39602 .40004 .39077 .3924 .41747 Mtetra
.408 .096 .322 r
.3924 .41747 .40004 .39077 .41053 .38738 .4031 .41214 Mtetra
.38 .064 .299 r
.4031 .41214 .41053 .38738 .42102 .38533 .41385 .40599 Mtetra
.307 0 .235 r
.41385 .40599 .42102 .38533 .43157 .38288 .42467 .39846 Mtetra
.172 0 .108 r
.42467 .39846 .43157 .38288 .4422 .37937 .43555 .38977 Mtetra
.016 0 0 r
.43555 .38977 .4422 .37937 .45288 .37534 .44641 .38176 Mtetra
0 0 0 r
.44641 .38176 .45288 .37534 .46361 .37108 .45725 .3754 Mtetra
.45725 .3754 .46361 .37108 .47436 .36743 .46807 .37173 Mtetra
.228 0 0 r
.46807 .37173 .47436 .36743 .48515 .36439 .47889 .37076 Mtetra
.405 0 0 r
.47889 .37076 .48515 .36439 .49599 .36112 .48976 .37146 Mtetra
.48 .052 .149 r
.48976 .37146 .49599 .36112 .50688 .35733 .50069 .37285 Mtetra
.475 .099 .245 r
.50069 .37285 .50688 .35733 .51781 .35247 .51171 .37309 Mtetra
.465 .122 .298 r
.51171 .37309 .51781 .35247 .52877 .34719 .5228 .37195 Mtetra
.464 .139 .33 r
.5228 .37195 .52877 .34719 .53978 .34327 .53395 .37 Mtetra
.468 .15 .343 r
.53395 .37 .53978 .34327 .55085 .34124 .54516 .36794 Mtetra
.49 .169 .349 r
.54516 .36794 .55085 .34124 .562 .3416 .55644 .36738 Mtetra
.505 .179 .348 r
.55644 .36738 .562 .3416 .57325 .34366 .56781 .36797 Mtetra
.503 .171 .337 r
.56781 .36797 .57325 .34366 .58458 .34578 .57925 .36855 Mtetra
.493 .155 .323 r
.57925 .36855 .58458 .34578 .59601 .34769 .59077 .36865 Mtetra
.47 .126 .3 r
.59077 .36865 .59601 .34769 .60751 .34947 .60233 .36775 Mtetra
.439 .082 .262 r
.60233 .36775 .60751 .34947 .61909 .35091 .61394 .36585 Mtetra
.393 .015 .198 r
.61394 .36585 .61909 .35091 .63075 .35182 .62558 .36311 Mtetra
.312 0 .087 r
.62558 .36311 .63075 .35182 .64245 .35195 .63725 .35948 Mtetra
.144 0 0 r
.63725 .35948 .64245 .35195 .65419 .35093 .64892 .35481 Mtetra
0 0 0 r
.64892 .35481 .65419 .35093 .66595 .34877 .66061 .34924 Mtetra
.56 .935 .853 r
.66061 .34924 .66595 .34877 .67771 .34545 .67229 .34293 Mtetra
.734 .944 .951 r
.67229 .34293 .67771 .34545 .68947 .34113 .68399 .33612 Mtetra
.762 .863 .924 r
.68399 .33612 .68947 .34113 .70124 .33598 .69569 .32903 Mtetra
.754 .797 .888 r
.69569 .32903 .70124 .33598 .71301 .33021 .70742 .32186 Mtetra
.739 .754 .864 r
.70742 .32186 .71301 .33021 .72479 .32407 .71918 .31484 Mtetra
.727 .727 .851 r
.71918 .31484 .72479 .32407 .73659 .31772 .73099 .30804 Mtetra
.714 .713 .847 r
.73099 .30804 .73659 .31772 .74843 .31137 .74285 .30161 Mtetra
.705 .708 .85 r
.74285 .30161 .74843 .31137 .7603 .3051 .75477 .29552 Mtetra
.697 .71 .858 r
.75477 .29552 .7603 .3051 .77223 .29902 .76676 .28981 Mtetra
.692 .717 .869 r
.76676 .28981 .77223 .29902 .7842 .2931 .77881 .28438 Mtetra
.688 .73 .882 r
.77881 .28438 .7842 .2931 .79622 .28732 .79092 .27916 Mtetra
.686 .746 .897 r
.79092 .27916 .79622 .28732 .8083 .28168 .80308 .27409 Mtetra
.659 .752 .919 r
.15266 .48451 .15958 .49055 .1692 .48819 .1624 .48114 Mtetra
.654 .719 .897 r
.1624 .48114 .1692 .48819 .17883 .48598 .17217 .47787 Mtetra
.644 .687 .876 r
.17217 .47787 .17883 .48598 .18849 .48398 .18195 .47479 Mtetra
.631 .656 .856 r
.18195 .47479 .18849 .48398 .19817 .48225 .19174 .472 Mtetra
.615 .626 .839 r
.19174 .472 .19817 .48225 .20785 .4809 .20153 .46962 Mtetra
.598 .599 .824 r
.20153 .46962 .20785 .4809 .21755 .47988 .21131 .46769 Mtetra
.58 .574 .811 r
.21131 .46769 .21755 .47988 .22727 .47923 .2211 .4663 Mtetra
.563 .554 .802 r
.2211 .4663 .22727 .47923 .23702 .47881 .23088 .46543 Mtetra
.546 .538 .798 r
.23088 .46543 .23702 .47881 .24682 .47854 .24067 .4651 Mtetra
.532 .53 .799 r
.24067 .4651 .24682 .47854 .25667 .4782 .25049 .46518 Mtetra
.518 .531 .808 r
.25049 .46518 .25667 .4782 .2666 .47762 .26033 .46559 Mtetra
.507 .543 .828 r
.26033 .46559 .2666 .47762 .27663 .47655 .27023 .46616 Mtetra
.495 .572 .863 r
.27023 .46616 .27663 .47655 .28675 .47478 .28019 .46671 Mtetra
.475 .628 .919 r
.28019 .46671 .28675 .47478 .29699 .47215 .29022 .46706 Mtetra
.419 .712 .984 r
.29022 .46706 .29699 .47215 .30733 .4685 .30035 .46702 Mtetra
.225 .727 .904 r
.30035 .46702 .30733 .4685 .31777 .46398 .31057 .46649 Mtetra
.08 0 0 r
.31057 .46649 .31777 .46398 .32829 .45865 .32089 .46534 Mtetra
.239 0 0 r
.32089 .46534 .32829 .45865 .3389 .45233 .33131 .46328 Mtetra
.304 0 .063 r
.33131 .46328 .3389 .45233 .34958 .44502 .34185 .46018 Mtetra
.364 0 .183 r
.34185 .46018 .34958 .44502 .3603 .43723 .35243 .45687 Mtetra
.408 .061 .262 r
.35243 .45687 .3603 .43723 .37104 .4294 .36306 .45364 Mtetra
.427 .102 .309 r
.36306 .45364 .37104 .4294 .38174 .4227 .37375 .45011 Mtetra
.428 .114 .329 r
.37375 .45011 .38174 .4227 .3924 .41747 .3845 .44588 Mtetra
.392 .086 .321 r
.3845 .44588 .3924 .41747 .4031 .41214 .39539 .43943 Mtetra
.333 .03 .292 r
.39539 .43943 .4031 .41214 .41385 .40599 .40639 .43043 Mtetra
.277 0 .251 r
.40639 .43043 .41385 .40599 .42467 .39846 .41743 .42029 Mtetra
.238 0 .213 r
.41743 .42029 .42467 .39846 .43555 .38977 .42848 .41001 Mtetra
.263 0 .209 r
.42848 .41001 .43555 .38977 .44641 .38176 .43949 .40128 Mtetra
.327 0 .229 r
.43949 .40128 .44641 .38176 .45725 .3754 .45045 .39494 Mtetra
.4 .054 .259 r
.45045 .39494 .45725 .3754 .46807 .37173 .46138 .39126 Mtetra
.461 .111 .284 r
.46138 .39126 .46807 .37173 .47889 .37076 .47232 .39026 Mtetra
.509 .155 .302 r
.47232 .39026 .47889 .37076 .48976 .37146 .48328 .39168 Mtetra
.537 .184 .318 r
.48328 .39168 .48976 .37146 .50069 .37285 .49431 .39466 Mtetra
.535 .19 .329 r
.49431 .39466 .50069 .37285 .51171 .37309 .50544 .39754 Mtetra
.519 .185 .342 r
.50544 .39754 .51171 .37309 .5228 .37195 .51665 .39927 Mtetra
.485 .164 .348 r
.51665 .39927 .5228 .37195 .53395 .37 .52795 .39845 Mtetra
.454 .141 .344 r
.52795 .39845 .53395 .37 .54516 .36794 .53931 .39539 Mtetra
.44 .125 .334 r
.53931 .39539 .54516 .36794 .55644 .36738 .55071 .39162 Mtetra
.422 .097 .308 r
.55071 .39162 .55644 .36738 .56781 .36797 .56216 .38755 Mtetra
.396 .05 .257 r
.56216 .38755 .56781 .36797 .57925 .36855 .57365 .38356 Mtetra
.345 0 .175 r
.57365 .38356 .57925 .36855 .59077 .36865 .58519 .37933 Mtetra
.217 0 .022 r
.58519 .37933 .59077 .36865 .60233 .36775 .59675 .37406 Mtetra
0 0 0 r
.59675 .37406 .60233 .36775 .61394 .36585 .60832 .36784 Mtetra
.489 .89 .745 r
.60832 .36784 .61394 .36585 .62558 .36311 .6199 .36097 Mtetra
.754 .954 .94 r
.6199 .36097 .62558 .36311 .63725 .35948 .6315 .35359 Mtetra
.778 .832 .894 r
.6315 .35359 .63725 .35948 .64892 .35481 .6431 .34579 Mtetra
.755 .739 .838 r
.6431 .34579 .64892 .35481 .66061 .34924 .65471 .33776 Mtetra
.732 .681 .8 r
.65471 .33776 .66061 .34924 .67229 .34293 .66634 .32971 Mtetra
.715 .646 .779 r
.66634 .32971 .67229 .34293 .68399 .33612 .678 .3218 Mtetra
.701 .625 .768 r
.678 .3218 .68399 .33612 .69569 .32903 .68969 .31421 Mtetra
.691 .613 .765 r
.68969 .31421 .69569 .32903 .70742 .32186 .70143 .30704 Mtetra
.681 .609 .768 r
.70143 .30704 .70742 .32186 .71918 .31484 .71323 .30042 Mtetra
.674 .611 .777 r
.71323 .30042 .71918 .31484 .73099 .30804 .7251 .29432 Mtetra
.667 .617 .79 r
.7251 .29432 .73099 .30804 .74285 .30161 .73704 .28877 Mtetra
.662 .629 .806 r
.73704 .28877 .74285 .30161 .75477 .29552 .74905 .2837 Mtetra
.658 .645 .826 r
.74905 .2837 .75477 .29552 .76676 .28981 .76114 .27904 Mtetra
.655 .666 .848 r
.76114 .27904 .76676 .28981 .77881 .28438 .7733 .27467 Mtetra
.653 .69 .872 r
.7733 .27467 .77881 .28438 .79092 .27916 .78553 .27051 Mtetra
.652 .719 .897 r
.78553 .27051 .79092 .27916 .80308 .27409 .79782 .26643 Mtetra
.698 .76 .9 r
.14569 .47843 .15266 .48451 .1624 .48114 .15557 .47398 Mtetra
.692 .727 .878 r
.15557 .47398 .1624 .48114 .17217 .47787 .16548 .46955 Mtetra
.682 .695 .856 r
.16548 .46955 .17217 .47787 .18195 .47479 .1754 .46524 Mtetra
.669 .663 .835 r
.1754 .46524 .18195 .47479 .19174 .472 .18534 .46112 Mtetra
.654 .631 .815 r
.18534 .46112 .19174 .472 .20153 .46962 .19528 .45729 Mtetra
.637 .6 .795 r
.19528 .45729 .20153 .46962 .21131 .46769 .20521 .45385 Mtetra
.619 .57 .777 r
.20521 .45385 .21131 .46769 .2211 .4663 .21513 .4509 Mtetra
.601 .541 .76 r
.21513 .4509 .2211 .4663 .23088 .46543 .22505 .44849 Mtetra
.583 .515 .744 r
.22505 .44849 .23088 .46543 .24067 .4651 .23495 .44671 Mtetra
.568 .493 .731 r
.23495 .44671 .24067 .4651 .25049 .46518 .24485 .44553 Mtetra
.553 .474 .72 r
.24485 .44553 .25049 .46518 .26033 .46559 .25475 .44495 Mtetra
.542 .46 .712 r
.25475 .44495 .26033 .46559 .27023 .46616 .26466 .44487 Mtetra
.533 .45 .708 r
.26466 .44487 .27023 .46616 .28019 .46671 .27461 .44524 Mtetra
.527 .446 .707 r
.27461 .44524 .28019 .46671 .29022 .46706 .28459 .44587 Mtetra
.524 .446 .71 r
.28459 .44587 .29022 .46706 .30035 .46702 .29463 .44663 Mtetra
.525 .453 .718 r
.29463 .44663 .30035 .46702 .31057 .46649 .30474 .4473 Mtetra
.53 .467 .73 r
.30474 .4473 .31057 .46649 .32089 .46534 .31494 .44772 Mtetra
.539 .487 .746 r
.31494 .44772 .32089 .46534 .33131 .46328 .32522 .4477 Mtetra
.553 .518 .771 r
.32522 .4477 .33131 .46328 .34185 .46018 .3356 .44712 Mtetra
.55 .553 .81 r
.3356 .44712 .34185 .46018 .35243 .45687 .34605 .44654 Mtetra
.538 .602 .865 r
.34605 .44654 .35243 .45687 .36306 .45364 .35654 .44605 Mtetra
.567 .691 .924 r
.35654 .44605 .36306 .45364 .37375 .45011 .36715 .44451 Mtetra
.631 .782 .954 r
.36715 .44451 .37375 .45011 .3845 .44588 .37789 .44135 Mtetra
.711 .841 .944 r
.37789 .44135 .3845 .44588 .39539 .43943 .38876 .43618 Mtetra
.772 .894 .93 r
.38876 .43618 .39539 .43943 .40639 .43043 .39973 .42921 Mtetra
.748 .957 .94 r
.39973 .42921 .40639 .43043 .41743 .42029 .41072 .42229 Mtetra
.508 .907 .795 r
.41072 .42229 .41743 .42029 .42848 .41001 .42171 .41623 Mtetra
0 0 0 r
.42171 .41623 .42848 .41001 .43949 .40128 .43269 .41117 Mtetra
.233 0 0 r
.43269 .41117 .43949 .40128 .45045 .39494 .44368 .40713 Mtetra
.307 0 .096 r
.44368 .40713 .45045 .39494 .46138 .39126 .45471 .40344 Mtetra
.323 0 .104 r
.45471 .40344 .46138 .39126 .47232 .39026 .46577 .40012 Mtetra
.323 0 .042 r
.46577 .40012 .47232 .39026 .48328 .39168 .47687 .39782 Mtetra
.276 0 0 r
.47687 .39782 .48328 .39168 .49431 .39466 .48801 .39652 Mtetra
.117 0 0 r
.48801 .39652 .49431 .39466 .50544 .39754 .4992 .39611 Mtetra
.18 .7 .878 r
.4992 .39611 .50544 .39754 .51665 .39927 .51047 .39576 Mtetra
.508 .825 1 r
.51047 .39576 .51665 .39927 .52795 .39845 .52181 .39359 Mtetra
.66 .831 .965 r
.52181 .39359 .52795 .39845 .53931 .39539 .5332 .3894 Mtetra
.725 .809 .917 r
.5332 .3894 .53931 .39539 .55071 .39162 .54462 .38355 Mtetra
.74 .752 .862 r
.54462 .38355 .55071 .39162 .56216 .38755 .55607 .37663 Mtetra
.715 .68 .815 r
.55607 .37663 .56216 .38755 .57365 .38356 .56754 .36978 Mtetra
.693 .625 .776 r
.56754 .36978 .57365 .38356 .58519 .37933 .57904 .36293 Mtetra
.685 .591 .744 r
.57904 .36293 .58519 .37933 .59675 .37406 .59056 .3555 Mtetra
.679 .568 .723 r
.59056 .3555 .59675 .37406 .60832 .36784 .60208 .3476 Mtetra
.674 .553 .709 r
.60208 .3476 .60832 .36784 .6199 .36097 .61362 .33941 Mtetra
.668 .541 .7 r
.61362 .33941 .6199 .36097 .6315 .35359 .62517 .33113 Mtetra
.663 .532 .695 r
.62517 .33113 .6315 .35359 .6431 .34579 .63674 .32296 Mtetra
.658 .527 .693 r
.63674 .32296 .6431 .34579 .65471 .33776 .64834 .31505 Mtetra
.653 .525 .695 r
.64834 .31505 .65471 .33776 .66634 .32971 .65998 .30758 Mtetra
.649 .526 .7 r
.65998 .30758 .66634 .32971 .678 .3218 .67167 .30061 Mtetra
.644 .529 .709 r
.67167 .30061 .678 .3218 .68969 .31421 .68342 .29426 Mtetra
.64 .536 .721 r
.68342 .29426 .68969 .31421 .70143 .30704 .69523 .28852 Mtetra
.636 .546 .736 r
.69523 .28852 .70143 .30704 .71323 .30042 .70712 .28342 Mtetra
.632 .558 .754 r
.70712 .28342 .71323 .30042 .7251 .29432 .71908 .27887 Mtetra
.628 .574 .775 r
.71908 .27887 .7251 .29432 .73704 .28877 .73113 .27484 Mtetra
.625 .593 .798 r
.73113 .27484 .73704 .28877 .74905 .2837 .74326 .2712 Mtetra
.622 .616 .824 r
.74326 .2712 .74905 .2837 .76114 .27904 .75547 .26786 Mtetra
.619 .641 .85 r
.75547 .26786 .76114 .27904 .7733 .27467 .76775 .26473 Mtetra
.617 .669 .877 r
.76775 .26473 .7733 .27467 .78553 .27051 .7801 .26172 Mtetra
.615 .699 .905 r
.7801 .26172 .78553 .27051 .79782 .26643 .79252 .25872 Mtetra
.724 .764 .885 r
.13868 .4723 .14569 .47843 .15557 .47398 .14868 .46699 Mtetra
.719 .739 .867 r
.14868 .46699 .15557 .47398 .16548 .46955 .15871 .46161 Mtetra
.712 .713 .85 r
.15871 .46161 .16548 .46955 .1754 .46524 .16876 .45623 Mtetra
.702 .687 .832 r
.16876 .45623 .1754 .46524 .18534 .46112 .17884 .45091 Mtetra
.691 .659 .813 r
.17884 .45091 .18534 .46112 .19528 .45729 .18893 .44567 Mtetra
.677 .63 .794 r
.18893 .44567 .19528 .45729 .20521 .45385 .19903 .44063 Mtetra
.662 .6 .775 r
.19903 .44063 .20521 .45385 .21513 .4509 .20912 .43587 Mtetra
.644 .569 .755 r
.20912 .43587 .21513 .4509 .22505 .44849 .21921 .4315 Mtetra
.626 .54 .737 r
.21921 .4315 .22505 .44849 .23495 .44671 .22929 .4276 Mtetra
.609 .512 .719 r
.22929 .4276 .23495 .44671 .24485 .44553 .23936 .42425 Mtetra
.593 .487 .703 r
.23936 .42425 .24485 .44553 .25475 .44495 .24941 .42149 Mtetra
.578 .465 .689 r
.24941 .42149 .25475 .44495 .26466 .44487 .25946 .41932 Mtetra
.566 .447 .677 r
.25946 .41932 .26466 .44487 .27461 .44524 .26951 .41775 Mtetra
.556 .432 .667 r
.26951 .41775 .27461 .44524 .28459 .44587 .27957 .41668 Mtetra
.548 .421 .659 r
.27957 .41668 .28459 .44587 .29463 .44663 .28966 .41603 Mtetra
.544 .413 .653 r
.28966 .41603 .29463 .44663 .30474 .4473 .29978 .41562 Mtetra
.543 .409 .648 r
.29978 .41562 .30474 .4473 .31494 .44772 .30996 .41531 Mtetra
.541 .406 .646 r
.30996 .41531 .31494 .44772 .32522 .4477 .32019 .41513 Mtetra
.539 .404 .646 r
.32019 .41513 .32522 .4477 .3356 .44712 .33048 .41504 Mtetra
.538 .405 .648 r
.33048 .41504 .3356 .44712 .34605 .44654 .34082 .41507 Mtetra
.538 .408 .651 r
.34082 .41507 .34605 .44654 .35654 .44605 .35123 .41509 Mtetra
.553 .42 .653 r
.35123 .41509 .35654 .44605 .36715 .44451 .36176 .41403 Mtetra
.572 .435 .656 r
.36176 .41403 .36715 .44451 .37789 .44135 .37241 .41159 Mtetra
.576 .44 .659 r
.37241 .41159 .37789 .44135 .38876 .43618 .38313 .40886 Mtetra
.575 .449 .671 r
.38313 .40886 .38876 .43618 .39973 .42921 .39388 .40649 Mtetra
.556 .46 .701 r
.39388 .40649 .39973 .42921 .41072 .42229 .40462 .40558 Mtetra
.521 .49 .763 r
.40462 .40558 .41072 .42229 .42171 .41623 .41538 .40616 Mtetra
.499 .593 .879 r
.41538 .40616 .42171 .41623 .43269 .41117 .42622 .40644 Mtetra
.473 .76 .993 r
.42622 .40644 .43269 .41117 .44368 .40713 .43716 .40541 Mtetra
.555 .899 .978 r
.43716 .40541 .44368 .40713 .45471 .40344 .44824 .4017 Mtetra
.724 .946 .953 r
.44824 .4017 .45471 .40344 .46577 .40012 .45941 .39531 Mtetra
.785 .851 .9 r
.45941 .39531 .46577 .40012 .47687 .39782 .47063 .38759 Mtetra
.743 .699 .809 r
.47063 .38759 .47687 .39782 .48801 .39652 .48187 .37956 Mtetra
.669 .574 .739 r
.48187 .37956 .48801 .39652 .4992 .39611 .49312 .37301 Mtetra
.621 .501 .695 r
.49312 .37301 .4992 .39611 .51047 .39576 .50438 .36792 Mtetra
.604 .468 .669 r
.50438 .36792 .51047 .39576 .52181 .39359 .51568 .3632 Mtetra
.601 .457 .658 r
.51568 .3632 .52181 .39359 .5332 .3894 .52702 .35818 Mtetra
.615 .463 .653 r
.52702 .35818 .5332 .3894 .54462 .38355 .53839 .35175 Mtetra
.624 .468 .65 r
.53839 .35175 .54462 .38355 .55607 .37663 .54978 .34421 Mtetra
.623 .465 .648 r
.54978 .34421 .55607 .37663 .56754 .36978 .56119 .33665 Mtetra
.62 .461 .645 r
.56119 .33665 .56754 .36978 .57904 .36293 .57262 .32919 Mtetra
.618 .458 .643 r
.57262 .32919 .57904 .36293 .59056 .3555 .58408 .32182 Mtetra
.617 .458 .644 r
.58408 .32182 .59056 .3555 .60208 .3476 .59556 .31457 Mtetra
.617 .46 .646 r
.59556 .31457 .60208 .3476 .61362 .33941 .60707 .3074 Mtetra
.617 .463 .65 r
.60707 .3074 .61362 .33941 .62517 .33113 .61861 .30047 Mtetra
.616 .466 .656 r
.61861 .30047 .62517 .33113 .63674 .32296 .63019 .29396 Mtetra
.614 .471 .663 r
.63019 .29396 .63674 .32296 .64834 .31505 .64182 .28795 Mtetra
.612 .477 .673 r
.64182 .28795 .64834 .31505 .65998 .30758 .65352 .28255 Mtetra
.61 .486 .686 r
.65352 .28255 .65998 .30758 .67167 .30061 .66527 .27775 Mtetra
.607 .496 .702 r
.66527 .27775 .67167 .30061 .68342 .29426 .6771 .27357 Mtetra
.604 .509 .72 r
.6771 .27357 .68342 .29426 .69523 .28852 .68902 .26994 Mtetra
.6 .525 .741 r
.68902 .26994 .69523 .28852 .70712 .28342 .70101 .2668 Mtetra
.597 .543 .765 r
.70101 .2668 .70712 .28342 .71908 .27887 .71309 .26407 Mtetra
.594 .565 .791 r
.71309 .26407 .71908 .27887 .73113 .27484 .72525 .26163 Mtetra
.591 .588 .817 r
.72525 .26163 .73113 .27484 .74326 .2712 .73749 .25939 Mtetra
.589 .613 .844 r
.73749 .25939 .74326 .2712 .75547 .26786 .7498 .25725 Mtetra
.586 .638 .869 r
.7498 .25725 .75547 .26786 .76775 .26473 .76219 .25517 Mtetra
.583 .664 .893 r
.76219 .25517 .76775 .26473 .7801 .26172 .77465 .25309 Mtetra
.581 .69 .916 r
.77465 .25309 .7801 .26172 .79252 .25872 .78718 .25095 Mtetra
.729 .765 .881 r
.13161 .46613 .13868 .4723 .14868 .46699 .14166 .46058 Mtetra
.73 .759 .875 r
.14166 .46058 .14868 .46699 .15871 .46161 .15175 .45491 Mtetra
.731 .751 .869 r
.15175 .45491 .15871 .46161 .16876 .45623 .16187 .44914 Mtetra
.73 .741 .861 r
.16187 .44914 .16876 .45623 .17884 .45091 .17202 .44328 Mtetra
.727 .727 .85 r
.17202 .44328 .17884 .45091 .18893 .44567 .18221 .43733 Mtetra
.722 .709 .838 r
.18221 .43733 .18893 .44567 .19903 .44063 .19242 .43136 Mtetra
.713 .687 .824 r
.19242 .43136 .19903 .44063 .20912 .43587 .20265 .42542 Mtetra
.701 .661 .807 r
.20265 .42542 .20912 .43587 .21921 .4315 .21288 .41963 Mtetra
.686 .631 .789 r
.21288 .41963 .21921 .4315 .22929 .4276 .22312 .41406 Mtetra
.669 .6 .77 r
.22312 .41406 .22929 .4276 .23936 .42425 .23336 .40881 Mtetra
.651 .569 .75 r
.23336 .40881 .23936 .42425 .24941 .42149 .24359 .40397 Mtetra
.633 .54 .731 r
.24359 .40397 .24941 .42149 .25946 .41932 .25381 .39957 Mtetra
.616 .512 .713 r
.25381 .39957 .25946 .41932 .26951 .41775 .26402 .39567 Mtetra
.601 .488 .697 r
.26402 .39567 .26951 .41775 .27957 .41668 .27424 .39224 Mtetra
.588 .467 .682 r
.27424 .39224 .27957 .41668 .28966 .41603 .28445 .38927 Mtetra
.579 .451 .67 r
.28445 .38927 .28966 .41603 .29978 .41562 .29469 .38666 Mtetra
.571 .437 .659 r
.29469 .38666 .29978 .41562 .30996 .41531 .30495 .38433 Mtetra
.564 .425 .651 r
.30495 .38433 .30996 .41531 .32019 .41513 .31524 .3824 Mtetra
.557 .415 .644 r
.31524 .3824 .32019 .41513 .33048 .41504 .32555 .38087 Mtetra
.554 .41 .639 r
.32555 .38087 .33048 .41504 .34082 .41507 .3359 .37946 Mtetra
.554 .406 .635 r
.3359 .37946 .34082 .41507 .35123 .41509 .34632 .37797 Mtetra
.56 .407 .63 r
.34632 .37797 .35123 .41509 .36176 .41403 .35682 .37592 Mtetra
.564 .408 .628 r
.35682 .37592 .36176 .41403 .37241 .41159 .3674 .37334 Mtetra
.553 .4 .627 r
.3674 .37334 .37241 .41159 .38313 .40886 .37798 .37179 Mtetra
.535 .39 .631 r
.37798 .37179 .38313 .40886 .39388 .40649 .38854 .37192 Mtetra
.513 .381 .638 r
.38854 .37192 .39388 .40649 .40462 .40558 .39911 .37371 Mtetra
.495 .377 .649 r
.39911 .37371 .40462 .40558 .41538 .40616 .40972 .37661 Mtetra
.509 .396 .661 r
.40972 .37661 .41538 .40616 .42622 .40644 .42045 .37846 Mtetra
.544 .426 .669 r
.42045 .37846 .42622 .40644 .43716 .40541 .43133 .37804 Mtetra
.592 .461 .671 r
.43133 .37804 .43716 .40541 .44824 .4017 .44236 .37428 Mtetra
.633 .487 .667 r
.44236 .37428 .44824 .4017 .45941 .39531 .45351 .36719 Mtetra
.654 .499 .661 r
.45351 .36719 .45941 .39531 .47063 .38759 .46472 .3578 Mtetra
.659 .496 .653 r
.46472 .3578 .47063 .38759 .48187 .37956 .47596 .34734 Mtetra
.641 .477 .645 r
.47596 .34734 .48187 .37956 .49312 .37301 .48719 .33797 Mtetra
.618 .454 .638 r
.48719 .33797 .49312 .37301 .50438 .36792 .49841 .33026 Mtetra
.598 .434 .631 r
.49841 .33026 .50438 .36792 .51568 .3632 .50963 .32423 Mtetra
.586 .423 .627 r
.50963 .32423 .51568 .3632 .52702 .35818 .52089 .31924 Mtetra
.591 .426 .627 r
.52089 .31924 .52702 .35818 .53839 .35175 .53218 .31371 Mtetra
.597 .433 .63 r
.53218 .31371 .53839 .35175 .54978 .34421 .54351 .3076 Mtetra
.6 .438 .634 r
.54351 .3076 .54978 .34421 .56119 .33665 .55487 .3014 Mtetra
.602 .443 .638 r
.55487 .3014 .56119 .33665 .57262 .32919 .56625 .29532 Mtetra
.6 .445 .643 r
.56625 .29532 .57262 .32919 .58408 .32182 .57768 .28963 Mtetra
.599 .449 .65 r
.57768 .28963 .58408 .32182 .59556 .31457 .58915 .28434 Mtetra
.6 .456 .658 r
.58915 .28434 .59556 .31457 .60707 .3074 .60066 .27934 Mtetra
.6 .465 .669 r
.60066 .27934 .60707 .3074 .61861 .30047 .61223 .2747 Mtetra
.599 .474 .682 r
.61223 .2747 .61861 .30047 .63019 .29396 .62386 .27052 Mtetra
.598 .486 .697 r
.62386 .27052 .63019 .29396 .64182 .28795 .63555 .26683 Mtetra
.595 .5 .716 r
.63555 .26683 .64182 .28795 .65352 .28255 .64731 .26365 Mtetra
.592 .516 .738 r
.64731 .26365 .65352 .28255 .66527 .27775 .65915 .26093 Mtetra
.587 .534 .763 r
.65915 .26093 .66527 .27775 .6771 .27357 .67107 .25863 Mtetra
.582 .555 .789 r
.67107 .25863 .6771 .27357 .68902 .26994 .68307 .25666 Mtetra
.577 .578 .817 r
.68307 .25666 .68902 .26994 .70101 .2668 .69516 .25493 Mtetra
.572 .602 .844 r
.69516 .25493 .70101 .2668 .71309 .26407 .70732 .25335 Mtetra
.568 .625 .869 r
.70732 .25335 .71309 .26407 .72525 .26163 .71956 .25182 Mtetra
.565 .647 .89 r
.71956 .25182 .72525 .26163 .73749 .25939 .73187 .25027 Mtetra
.564 .666 .906 r
.73187 .25027 .73749 .25939 .7498 .25725 .74425 .24863 Mtetra
.564 .681 .918 r
.74425 .24863 .7498 .25725 .76219 .25517 .7567 .24689 Mtetra
.565 .693 .927 r
.7567 .24689 .76219 .25517 .77465 .25309 .76922 .24506 Mtetra
.567 .703 .933 r
.76922 .24506 .77465 .25309 .78718 .25095 .7818 .24311 Mtetra
.719 .764 .888 r
.12449 .45992 .13161 .46613 .14166 .46058 .13452 .45472 Mtetra
.725 .776 .894 r
.13452 .45472 .14166 .46058 .15175 .45491 .1446 .44938 Mtetra
.731 .788 .898 r
.1446 .44938 .15175 .45491 .16187 .44914 .15471 .44387 Mtetra
.738 .798 .9 r
.15471 .44387 .16187 .44914 .17202 .44328 .16488 .43817 Mtetra
.746 .805 .9 r
.16488 .43817 .17202 .44328 .18221 .43733 .17509 .43223 Mtetra
.751 .807 .897 r
.17509 .43223 .18221 .43733 .19242 .43136 .18535 .42608 Mtetra
.755 .802 .891 r
.18535 .42608 .19242 .43136 .20265 .42542 .19565 .41974 Mtetra
.754 .79 .882 r
.19565 .41974 .20265 .42542 .21288 .41963 .20598 .41328 Mtetra
.75 .771 .869 r
.20598 .41328 .21288 .41963 .22312 .41406 .21633 .40677 Mtetra
.741 .744 .854 r
.21633 .40677 .22312 .41406 .23336 .40881 .22671 .40029 Mtetra
.728 .711 .835 r
.22671 .40029 .23336 .40881 .24359 .40397 .23709 .39393 Mtetra
.711 .675 .813 r
.23709 .39393 .24359 .40397 .25381 .39957 .24747 .38776 Mtetra
.693 .638 .79 r
.24747 .38776 .25381 .39957 .26402 .39567 .25786 .38184 Mtetra
.673 .601 .766 r
.25786 .38184 .26402 .39567 .27424 .39224 .26825 .37622 Mtetra
.654 .567 .744 r
.26825 .37622 .27424 .39224 .28445 .38927 .27864 .37094 Mtetra
.638 .537 .723 r
.27864 .37094 .28445 .38927 .29469 .38666 .28903 .36598 Mtetra
.623 .511 .706 r
.28903 .36598 .29469 .38666 .30495 .38433 .29943 .36135 Mtetra
.609 .489 .69 r
.29943 .36135 .30495 .38433 .31524 .3824 .30984 .35715 Mtetra
.597 .47 .677 r
.30984 .35715 .31524 .3824 .32555 .38087 .32025 .35339 Mtetra
.592 .457 .666 r
.32025 .35339 .32555 .38087 .3359 .37946 .3307 .34967 Mtetra
.589 .446 .655 r
.3307 .34967 .3359 .37946 .34632 .37797 .3412 .34584 Mtetra
.583 .435 .646 r
.3412 .34584 .34632 .37797 .35682 .37592 .35173 .34211 Mtetra
.576 .426 .64 r
.35173 .34211 .35682 .37592 .3674 .37334 .36228 .33882 Mtetra
.555 .409 .638 r
.36228 .33882 .3674 .37334 .37798 .37179 .37279 .33719 Mtetra
.53 .392 .637 r
.37279 .33719 .37798 .37179 .38854 .37192 .38327 .33756 Mtetra
.517 .384 .638 r
.38327 .33756 .38854 .37192 .39911 .37371 .39378 .3389 Mtetra
.515 .382 .637 r
.39378 .3389 .39911 .37371 .40972 .37661 .40436 .34041 Mtetra
.531 .39 .633 r
.40436 .34041 .40972 .37661 .42045 .37846 .41506 .34068 Mtetra
.553 .402 .629 r
.41506 .34068 .42045 .37846 .43133 .37804 .42589 .33899 Mtetra
.574 .414 .626 r
.42589 .33899 .43133 .37804 .44236 .37428 .43684 .33518 Mtetra
.594 .428 .626 r
.43684 .33518 .44236 .37428 .45351 .36719 .44789 .32925 Mtetra
.614 .444 .628 r
.44789 .32925 .45351 .36719 .46472 .3578 .459 .32133 Mtetra
.628 .456 .631 r
.459 .32133 .46472 .3578 .47596 .34734 .47016 .31217 Mtetra
.629 .46 .635 r
.47016 .31217 .47596 .34734 .48719 .33797 .48132 .30316 Mtetra
.621 .456 .637 r
.48132 .30316 .48719 .33797 .49841 .33026 .49248 .2951 Mtetra
.601 .441 .637 r
.49248 .2951 .49841 .33026 .50963 .32423 .50364 .28905 Mtetra
.584 .43 .638 r
.50364 .28905 .50963 .32423 .52089 .31924 .51483 .28468 Mtetra
.58 .429 .64 r
.51483 .28468 .52089 .31924 .53218 .31371 .52606 .28074 Mtetra
.581 .434 .646 r
.52606 .28074 .53218 .31371 .54351 .3076 .53733 .27692 Mtetra
.586 .445 .655 r
.53733 .27692 .54351 .3076 .55487 .3014 .54866 .27297 Mtetra
.59 .455 .666 r
.54866 .27297 .55487 .3014 .56625 .29532 .56003 .26906 Mtetra
.588 .464 .678 r
.56003 .26906 .56625 .29532 .57768 .28963 .57145 .26561 Mtetra
.586 .474 .693 r
.57145 .26561 .57768 .28963 .58915 .28434 .58294 .2626 Mtetra
.585 .488 .71 r
.58294 .2626 .58915 .28434 .60066 .27934 .59449 .25991 Mtetra
.583 .505 .732 r
.59449 .25991 .60066 .27934 .61223 .2747 .6061 .25756 Mtetra
.58 .525 .758 r
.6061 .25756 .61223 .2747 .62386 .27052 .61779 .25556 Mtetra
.575 .549 .788 r
.61779 .25556 .62386 .27052 .63555 .26683 .62955 .25388 Mtetra
.568 .577 .823 r
.62955 .25388 .63555 .26683 .64731 .26365 .64139 .25246 Mtetra
.559 .607 .858 r
.64139 .25246 .64731 .26365 .65915 .26093 .65331 .25124 Mtetra
.547 .638 .892 r
.65331 .25124 .65915 .26093 .67107 .25863 .66531 .25014 Mtetra
.535 .668 .922 r
.66531 .25014 .67107 .25863 .68307 .25666 .67739 .24909 Mtetra
.526 .693 .945 r
.67739 .24909 .68307 .25666 .69516 .25493 .68954 .24799 Mtetra
.521 .714 .96 r
.68954 .24799 .69516 .25493 .70732 .25335 .70176 .24678 Mtetra
.524 .73 .968 r
.70176 .24678 .70732 .25335 .71956 .25182 .71405 .24537 Mtetra
.532 .739 .97 r
.71405 .24537 .71956 .25182 .73187 .25027 .7264 .24376 Mtetra
.545 .744 .968 r
.7264 .24376 .73187 .25027 .74425 .24863 .7388 .24189 Mtetra
.558 .743 .963 r
.7388 .24189 .74425 .24863 .7567 .24689 .75127 .23983 Mtetra
.569 .738 .955 r
.75127 .23983 .7567 .24689 .76922 .24506 .76379 .23759 Mtetra
.579 .729 .946 r
.76379 .23759 .76922 .24506 .7818 .24311 .77637 .23521 Mtetra
.688 .758 .905 r
.11732 .45366 .12449 .45992 .13452 .45472 .12726 .44942 Mtetra
.694 .792 .925 r
.12726 .44942 .13452 .45472 .1446 .44938 .13725 .44504 Mtetra
.701 .827 .943 r
.13725 .44504 .1446 .44938 .15471 .44387 .14728 .44049 Mtetra
.706 .863 .956 r
.14728 .44049 .15471 .44387 .16488 .43817 .15738 .4357 Mtetra
.712 .896 .963 r
.15738 .4357 .16488 .43817 .17509 .43223 .16753 .43061 Mtetra
.713 .925 .963 r
.16753 .43061 .17509 .43223 .18535 .42608 .17775 .42522 Mtetra
.713 .946 .956 r
.17775 .42522 .18535 .42608 .19565 .41974 .18803 .4195 Mtetra
.709 .961 .944 r
.18803 .4195 .19565 .41974 .20598 .41328 .19836 .4135 Mtetra
.707 .969 .932 r
.19836 .4135 .20598 .41328 .21633 .40677 .20873 .40725 Mtetra
.705 .973 .924 r
.20873 .40725 .21633 .40677 .22671 .40029 .21915 .40082 Mtetra
.708 .975 .921 r
.21915 .40082 .22671 .40029 .23709 .39393 .2296 .39427 Mtetra
.716 .974 .925 r
.2296 .39427 .23709 .39393 .24747 .38776 .24007 .38769 Mtetra
.726 .969 .933 r
.24007 .38769 .24747 .38776 .25786 .38184 .25056 .38115 Mtetra
.735 .958 .943 r
.25056 .38115 .25786 .38184 .26825 .37622 .26106 .37473 Mtetra
.74 .939 .95 r
.26106 .37473 .26825 .37622 .27864 .37094 .27156 .36851 Mtetra
.741 .91 .951 r
.27156 .36851 .27864 .37094 .28903 .36598 .28207 .36252 Mtetra
.736 .875 .945 r
.28207 .36252 .28903 .36598 .29943 .36135 .29259 .3568 Mtetra
.725 .836 .934 r
.29259 .3568 .29943 .36135 .30984 .35715 .30311 .3514 Mtetra
.711 .794 .916 r
.30311 .3514 .30984 .35715 .32025 .35339 .31363 .34633 Mtetra
.706 .752 .888 r
.31363 .34633 .32025 .35339 .3307 .34967 .32419 .34121 Mtetra
.701 .714 .859 r
.32419 .34121 .3307 .34967 .3412 .34584 .3348 .33594 Mtetra
.682 .675 .836 r
.3348 .33594 .3412 .34584 .35173 .34211 .34541 .33101 Mtetra
.659 .641 .822 r
.34541 .33101 .35173 .34211 .36228 .33882 .35602 .32673 Mtetra
.623 .608 .815 r
.35602 .32673 .36228 .33882 .37279 .33719 .36661 .32361 Mtetra
.588 .567 .797 r
.36661 .32361 .37279 .33719 .38327 .33756 .3772 .3216 Mtetra
.588 .535 .763 r
.3772 .3216 .38327 .33756 .39378 .3389 .38784 .31943 Mtetra
.594 .505 .724 r
.38784 .31943 .39378 .3389 .40436 .34041 .39857 .31658 Mtetra
.595 .477 .689 r
.39857 .31658 .40436 .34041 .41506 .34068 .40937 .31305 Mtetra
.594 .459 .667 r
.40937 .31305 .41506 .34068 .42589 .33899 .42024 .30898 Mtetra
.587 .446 .656 r
.42024 .30898 .42589 .33899 .43684 .33518 .43114 .30512 Mtetra
.584 .444 .656 r
.43114 .30512 .43684 .33518 .44789 .32925 .44207 .30149 Mtetra
.595 .46 .667 r
.44207 .30149 .44789 .32925 .459 .32133 .45307 .29729 Mtetra
.613 .489 .687 r
.45307 .29729 .459 .32133 .47016 .31217 .46412 .29243 Mtetra
.639 .532 .717 r
.46412 .29243 .47016 .31217 .48132 .30316 .47522 .28687 Mtetra
.658 .574 .749 r
.47522 .28687 .48132 .30316 .49248 .2951 .48636 .28115 Mtetra
.648 .597 .784 r
.48636 .28115 .49248 .2951 .50364 .28905 .49752 .27654 Mtetra
.627 .61 .813 r
.49752 .27654 .50364 .28905 .51483 .28468 .50871 .2731 Mtetra
.611 .62 .835 r
.50871 .2731 .51483 .28468 .52606 .28074 .51995 .27032 Mtetra
.601 .64 .861 r
.51995 .27032 .52606 .28074 .53733 .27692 .53125 .26789 Mtetra
.606 .678 .892 r
.53125 .26789 .53733 .27692 .54866 .27297 .5426 .26531 Mtetra
.604 .718 .925 r
.5426 .26531 .54866 .27297 .56003 .26906 .55402 .26268 Mtetra
.577 .751 .96 r
.55402 .26268 .56003 .26906 .57145 .26561 .56549 .26038 Mtetra
.536 .778 .987 r
.56549 .26038 .57145 .26561 .58294 .2626 .57703 .25843 Mtetra
.483 .796 .999 r
.57703 .25843 .58294 .2626 .59449 .25991 .58864 .25675 Mtetra
.412 .798 .99 r
.58864 .25675 .59449 .25991 .6061 .25756 .60033 .25531 Mtetra
.329 .779 .955 r
.60033 .25531 .6061 .25756 .61779 .25556 .61209 .25408 Mtetra
.25 .748 .903 r
.61209 .25408 .61779 .25556 .62955 .25388 .62392 .25299 Mtetra
.19 .717 .851 r
.62392 .25299 .62955 .25388 .64139 .25246 .63583 .25194 Mtetra
.157 .697 .815 r
.63583 .25194 .64139 .25246 .65331 .25124 .64782 .25087 Mtetra
.154 .695 .804 r
.64782 .25087 .65331 .25124 .66531 .25014 .65987 .24968 Mtetra
.178 .712 .819 r
.65987 .24968 .66531 .25014 .67739 .24909 .67199 .24832 Mtetra
.231 .747 .857 r
.67199 .24832 .67739 .24909 .68954 .24799 .68418 .24669 Mtetra
.303 .787 .906 r
.68418 .24669 .68954 .24799 .70176 .24678 .69642 .24479 Mtetra
.386 .823 .954 r
.69642 .24479 .70176 .24678 .71405 .24537 .70871 .24254 Mtetra
.464 .842 .987 r
.70871 .24254 .71405 .24537 .7264 .24376 .72105 .23998 Mtetra
.529 .843 .999 r
.72105 .23998 .7264 .24376 .7388 .24189 .73344 .23711 Mtetra
.574 .826 .993 r
.73344 .23711 .7388 .24189 .75127 .23983 .74587 .234 Mtetra
.602 .8 .975 r
.74587 .234 .75127 .23983 .76379 .23759 .75836 .23069 Mtetra
.618 .769 .952 r
.75836 .23069 .76379 .23759 .77637 .23521 .7709 .22725 Mtetra
.637 .747 .928 r
.1101 .44736 .11732 .45366 .12726 .44942 .11991 .44437 Mtetra
.635 .791 .957 r
.11991 .44437 .12726 .44942 .13725 .44504 .12976 .44129 Mtetra
.628 .837 .981 r
.12976 .44129 .13725 .44504 .14728 .44049 .13967 .43806 Mtetra
.611 .88 .991 r
.13967 .43806 .14728 .44049 .15738 .4357 .14964 .43462 Mtetra
.581 .911 .976 r
.14964 .43462 .15738 .4357 .16753 .43061 .15969 .43088 Mtetra
.53 .915 .927 r
.15969 .43088 .16753 .43061 .17775 .42522 .1698 .42683 Mtetra
.463 .889 .843 r
.1698 .42683 .17775 .42522 .18803 .4195 .17999 .4224 Mtetra
.383 .835 .735 r
.17999 .4224 .18803 .4195 .19836 .4135 .19025 .41762 Mtetra
0 0 0 r
.19025 .41762 .19836 .4135 .20873 .40725 .20057 .41248 Mtetra
.20057 .41248 .20873 .40725 .21915 .40082 .21096 .40702 Mtetra
.21096 .40702 .21915 .40082 .2296 .39427 .22139 .40129 Mtetra
.22139 .40129 .2296 .39427 .24007 .38769 .23188 .39536 Mtetra
.23188 .39536 .24007 .38769 .25056 .38115 .24239 .38929 Mtetra
.24239 .38929 .25056 .38115 .26106 .37473 .25294 .38319 Mtetra
.25294 .38319 .26106 .37473 .27156 .36851 .26351 .37713 Mtetra
.26351 .37713 .27156 .36851 .28207 .36252 .27409 .37116 Mtetra
.004 0 0 r
.27409 .37116 .28207 .36252 .29259 .3568 .28469 .36532 Mtetra
.012 0 0 r
.28469 .36532 .29259 .3568 .30311 .3514 .29531 .35961 Mtetra
.008 0 0 r
.29531 .35961 .30311 .3514 .31363 .34633 .30595 .35402 Mtetra
0 0 0 r
.30595 .35402 .31363 .34633 .32419 .34121 .31662 .34829 Mtetra
.31662 .34829 .32419 .34121 .3348 .33594 .32734 .34237 Mtetra
.32734 .34237 .3348 .33594 .34541 .33101 .33806 .33674 Mtetra
.33806 .33674 .34541 .33101 .35602 .32673 .34879 .33155 Mtetra
.34879 .33155 .35602 .32673 .36661 .32361 .35955 .32645 Mtetra
.376 .824 .704 r
.35955 .32645 .36661 .32361 .3772 .3216 .37035 .32112 Mtetra
.711 .969 .934 r
.37035 .32112 .3772 .3216 .38784 .31943 .38125 .31453 Mtetra
.79 .843 .891 r
.38125 .31453 .38784 .31943 .39857 .31658 .39222 .30668 Mtetra
.74 .701 .814 r
.39222 .30668 .39857 .31658 .40937 .31305 .40319 .29904 Mtetra
.686 .613 .768 r
.40319 .29904 .40937 .31305 .42024 .30898 .41415 .29255 Mtetra
.623 .551 .753 r
.41415 .29255 .42024 .30898 .43114 .30512 .42504 .28865 Mtetra
.564 .518 .763 r
.42504 .28865 .43114 .30512 .44207 .30149 .43591 .28737 Mtetra
.53 .531 .801 r
.43591 .28737 .44207 .30149 .45307 .29729 .44681 .28724 Mtetra
.5 .598 .883 r
.44681 .28724 .45307 .29729 .46412 .29243 .45777 .28734 Mtetra
.485 .756 .99 r
.45777 .28734 .46412 .29243 .47522 .28687 .46883 .28618 Mtetra
.346 .818 .902 r
.46883 .28618 .47522 .28687 .48636 .28115 .47997 .28375 Mtetra
0 0 0 r
.47997 .28375 .48636 .28115 .49752 .27654 .49118 .2811 Mtetra
.094 0 0 r
.49118 .2811 .49752 .27654 .50871 .2731 .50244 .27855 Mtetra
.179 0 0 r
.50244 .27855 .50871 .2731 .51995 .27032 .51375 .27643 Mtetra
.23 0 0 r
.51375 .27643 .51995 .27032 .53125 .26789 .52512 .27463 Mtetra
.242 0 0 r
.52512 .27463 .53125 .26789 .5426 .26531 .53656 .27263 Mtetra
.254 0 0 r
.53656 .27263 .5426 .26531 .55402 .26268 .54806 .2705 Mtetra
.277 0 0 r
.54806 .2705 .55402 .26268 .56549 .26038 .55962 .26849 Mtetra
.292 0 0 r
.55962 .26849 .56549 .26038 .57703 .25843 .57125 .26662 Mtetra
.302 0 0 r
.57125 .26662 .57703 .25843 .58864 .25675 .58295 .26489 Mtetra
.305 0 0 r
.58295 .26489 .58864 .25675 .60033 .25531 .59472 .26325 Mtetra
.304 0 0 r
.59472 .26325 .60033 .25531 .61209 .25408 .60656 .26167 Mtetra
.293 0 0 r
.60656 .26167 .61209 .25408 .62392 .25299 .61847 .26006 Mtetra
.271 0 0 r
.61847 .26006 .62392 .25299 .63583 .25194 .63044 .25831 Mtetra
.236 0 0 r
.63044 .25831 .63583 .25194 .64782 .25087 .64248 .25636 Mtetra
.184 0 0 r
.64248 .25636 .64782 .25087 .65987 .24968 .65457 .25412 Mtetra
.108 0 0 r
.65457 .25412 .65987 .24968 .67199 .24832 .66672 .25157 Mtetra
.001 0 0 r
.66672 .25157 .67199 .24832 .68418 .24669 .67891 .24864 Mtetra
0 0 0 r
.67891 .24864 .68418 .24669 .69642 .24479 .69115 .24534 Mtetra
.298 .793 .786 r
.69115 .24534 .69642 .24479 .70871 .24254 .70342 .24166 Mtetra
.447 .877 .911 r
.70342 .24166 .70871 .24254 .72105 .23998 .71574 .23764 Mtetra
.56 .904 .975 r
.71574 .23764 .72105 .23998 .73344 .23711 .72809 .23332 Mtetra
.626 .886 .988 r
.72809 .23332 .73344 .23711 .74587 .234 .74048 .22876 Mtetra
.659 .847 .972 r
.74048 .22876 .74587 .234 .75836 .23069 .75291 .22405 Mtetra
.671 .802 .945 r
.75291 .22405 .75836 .23069 .7709 .22725 .76539 .21923 Mtetra
.573 .727 .947 r
.10283 .44102 .1101 .44736 .11991 .44437 .1125 .43924 Mtetra
.558 .767 .976 r
.1125 .43924 .11991 .44437 .12976 .44129 .12222 .43741 Mtetra
.534 .807 .996 r
.12222 .43741 .12976 .44129 .13967 .43806 .13199 .43549 Mtetra
.495 .839 .997 r
.13199 .43549 .13967 .43806 .14964 .43462 .14184 .43342 Mtetra
.435 .85 .962 r
.14184 .43342 .14964 .43462 .15969 .43088 .15175 .43113 Mtetra
.349 .824 .876 r
.15175 .43113 .15969 .43088 .1698 .42683 .16174 .42858 Mtetra
.248 .758 .744 r
.16174 .42858 .1698 .42683 .17999 .4224 .1718 .42571 Mtetra
0 0 0 r
.1718 .42571 .17999 .4224 .19025 .41762 .18195 .4225 Mtetra
.18195 .4225 .19025 .41762 .20057 .41248 .19217 .41893 Mtetra
.024 0 0 r
.19217 .41893 .20057 .41248 .21096 .40702 .20247 .41502 Mtetra
.084 0 0 r
.20247 .41502 .21096 .40702 .22139 .40129 .21283 .41078 Mtetra
.132 0 0 r
.21283 .41078 .22139 .40129 .23188 .39536 .22326 .40625 Mtetra
.17 0 0 r
.22326 .40625 .23188 .39536 .24239 .38929 .23374 .40148 Mtetra
.201 0 .01 r
.23374 .40148 .24239 .38929 .25294 .38319 .24427 .39654 Mtetra
.227 0 .052 r
.24427 .39654 .25294 .38319 .26351 .37713 .25485 .39149 Mtetra
.246 0 .084 r
.25485 .39149 .26351 .37713 .27409 .37116 .26546 .38633 Mtetra
.26 0 .106 r
.26546 .38633 .27409 .37116 .28469 .36532 .27611 .38108 Mtetra
.266 0 .12 r
.27611 .38108 .28469 .36532 .29531 .35961 .28681 .3757 Mtetra
.267 0 .127 r
.28681 .3757 .29531 .35961 .30595 .35402 .29754 .37016 Mtetra
.259 0 .124 r
.29754 .37016 .30595 .35402 .31662 .34829 .30832 .36438 Mtetra
.249 0 .118 r
.30832 .36438 .31662 .34829 .32734 .34237 .31915 .35833 Mtetra
.255 0 .12 r
.31915 .35833 .32734 .34237 .33806 .33674 .33 .35245 Mtetra
.26 0 .119 r
.33 .35245 .33806 .33674 .34879 .33155 .34086 .34678 Mtetra
.229 0 .096 r
.34086 .34678 .34879 .33155 .35955 .32645 .35178 .34056 Mtetra
.16 0 .041 r
.35178 .34056 .35955 .32645 .37035 .32112 .36277 .33341 Mtetra
.01 0 0 r
.36277 .33341 .37035 .32112 .38125 .31453 .37386 .3247 Mtetra
0 0 0 r
.37386 .3247 .38125 .31453 .39222 .30668 .38502 .31476 Mtetra
.38502 .31476 .39222 .30668 .40319 .29904 .39615 .30555 Mtetra
.39615 .30555 .40319 .29904 .41415 .29255 .40721 .29825 Mtetra
.029 0 0 r
.40721 .29825 .41415 .29255 .42504 .28865 .41818 .29434 Mtetra
.294 0 0 r
.41818 .29434 .42504 .28865 .43591 .28737 .42909 .29382 Mtetra
.421 0 0 r
.42909 .29382 .43591 .28737 .44681 .28724 .44001 .29524 Mtetra
.471 0 .051 r
.44001 .29524 .44681 .28724 .45777 .28734 .451 .2974 Mtetra
.444 0 .095 r
.451 .2974 .45777 .28734 .46883 .28618 .4621 .29835 Mtetra
.408 0 .127 r
.4621 .29835 .46883 .28618 .47997 .28375 .47331 .29773 Mtetra
.395 0 .156 r
.47331 .29773 .47997 .28375 .49118 .2811 .48461 .29618 Mtetra
.389 0 .173 r
.48461 .29618 .49118 .2811 .50244 .27855 .49597 .2941 Mtetra
.399 .012 .184 r
.49597 .2941 .50244 .27855 .51375 .27643 .50739 .29222 Mtetra
.406 .02 .191 r
.50739 .29222 .51375 .27643 .52512 .27463 .51888 .29052 Mtetra
.4 .015 .189 r
.51888 .29052 .52512 .27463 .53656 .27263 .53043 .28856 Mtetra
.393 .009 .187 r
.53043 .28856 .53656 .27263 .54806 .2705 .54204 .28635 Mtetra
.388 .004 .183 r
.54204 .28635 .54806 .2705 .55962 .26849 .55372 .28398 Mtetra
.382 0 .175 r
.55372 .28398 .55962 .26849 .57125 .26662 .56546 .28149 Mtetra
.373 0 .161 r
.56546 .28149 .57125 .26662 .58295 .26489 .57726 .2789 Mtetra
.361 0 .14 r
.57726 .2789 .58295 .26489 .59472 .26325 .58911 .27622 Mtetra
.344 0 .111 r
.58911 .27622 .59472 .26325 .60656 .26167 .60103 .27341 Mtetra
.319 0 .072 r
.60103 .27341 .60656 .26167 .61847 .26006 .613 .27043 Mtetra
.283 0 .018 r
.613 .27043 .61847 .26006 .63044 .25831 .62503 .2672 Mtetra
.232 0 0 r
.62503 .2672 .63044 .25831 .64248 .25636 .63711 .26368 Mtetra
.16 0 0 r
.63711 .26368 .64248 .25636 .65457 .25412 .64923 .25982 Mtetra
.059 0 0 r
.64923 .25982 .65457 .25412 .66672 .25157 .66139 .2556 Mtetra
0 0 0 r
.66139 .2556 .66672 .25157 .67891 .24864 .67358 .251 Mtetra
.67358 .251 .67891 .24864 .69115 .24534 .68581 .24604 Mtetra
.424 .867 .806 r
.68581 .24604 .69115 .24534 .70342 .24166 .69807 .24074 Mtetra
.565 .933 .919 r
.69807 .24074 .70342 .24166 .71574 .23764 .71036 .23517 Mtetra
.653 .937 .967 r
.71036 .23517 .71574 .23764 .72809 .23332 .72268 .22936 Mtetra
.697 .906 .969 r
.72268 .22936 .72809 .23332 .74048 .22876 .73502 .22338 Mtetra
.714 .862 .952 r
.73502 .22338 .74048 .22876 .75291 .22405 .74741 .21728 Mtetra
.716 .816 .927 r
.74741 .21728 .75291 .22405 .76539 .21923 .75983 .21113 Mtetra
.511 .705 .958 r
.09551 .43462 .10283 .44102 .1125 .43924 .10507 .43377 Mtetra
.489 .731 .979 r
.10507 .43377 .1125 .43924 .12222 .43741 .11468 .43293 Mtetra
.46 .757 .994 r
.11468 .43293 .12222 .43741 .13199 .43549 .12435 .43205 Mtetra
.419 .778 .996 r
.12435 .43205 .13199 .43549 .14184 .43342 .13408 .4311 Mtetra
.361 .786 .973 r
.13408 .4311 .14184 .43342 .15175 .43113 .14388 .43004 Mtetra
.283 .77 .912 r
.14388 .43004 .15175 .43113 .16174 .42858 .15375 .42881 Mtetra
.19 .722 .805 r
.15375 .42881 .16174 .42858 .1718 .42571 .1637 .42738 Mtetra
0 0 0 r
.1637 .42738 .1718 .42571 .18195 .4225 .17372 .42569 Mtetra
.004 0 0 r
.17372 .42569 .18195 .4225 .19217 .41893 .18383 .42371 Mtetra
.084 0 0 r
.18383 .42371 .19217 .41893 .20247 .41502 .19401 .42144 Mtetra
.146 0 0 r
.19401 .42144 .20247 .41502 .21283 .41078 .20428 .41885 Mtetra
.195 0 0 r
.20428 .41885 .21283 .41078 .22326 .40625 .21461 .41597 Mtetra
.231 0 0 r
.21461 .41597 .22326 .40625 .23374 .40148 .22503 .41281 Mtetra
.259 0 .018 r
.22503 .41281 .23374 .40148 .24427 .39654 .2355 .40938 Mtetra
.281 0 .066 r
.2355 .40938 .24427 .39654 .25485 .39149 .24604 .40571 Mtetra
.294 0 .102 r
.24604 .40571 .25485 .39149 .26546 .38633 .25665 .40176 Mtetra
.302 0 .128 r
.25665 .40176 .26546 .38633 .27611 .38108 .26732 .39752 Mtetra
.305 0 .146 r
.26732 .39752 .27611 .38108 .28681 .3757 .27805 .39295 Mtetra
.305 0 .158 r
.27805 .39295 .28681 .3757 .29754 .37016 .28885 .38804 Mtetra
.304 0 .166 r
.28885 .38804 .29754 .37016 .30832 .36438 .2997 .38285 Mtetra
.305 0 .175 r
.2997 .38285 .30832 .36438 .31915 .35833 .3106 .37743 Mtetra
.316 0 .188 r
.3106 .37743 .31915 .35833 .33 .35245 .32152 .37208 Mtetra
.325 0 .199 r
.32152 .37208 .33 .35245 .34086 .34678 .33248 .36679 Mtetra
.305 0 .195 r
.33248 .36679 .34086 .34678 .35178 .34056 .34351 .36069 Mtetra
.271 0 .181 r
.34351 .36069 .35178 .34056 .36277 .33341 .35464 .35343 Mtetra
.224 0 .159 r
.35464 .35343 .36277 .33341 .37386 .3247 .36586 .3448 Mtetra
.194 0 .148 r
.36586 .3448 .37386 .3247 .38502 .31476 .37713 .33523 Mtetra
.232 0 .17 r
.37713 .33523 .38502 .31476 .39615 .30555 .38837 .32651 Mtetra
.299 0 .206 r
.38837 .32651 .39615 .30555 .40721 .29825 .39955 .31965 Mtetra
.383 .035 .246 r
.39955 .31965 .40721 .29825 .41818 .29434 .41064 .31574 Mtetra
.45 .097 .273 r
.41064 .31574 .41818 .29434 .42909 .29382 .42168 .31476 Mtetra
.486 .128 .283 r
.42168 .31476 .42909 .29382 .44001 .29524 .43274 .31567 Mtetra
.501 .139 .284 r
.43274 .31567 .44001 .29524 .451 .2974 .44385 .31745 Mtetra
.483 .119 .272 r
.44385 .31745 .451 .2974 .4621 .29835 .45507 .3183 Mtetra
.454 .091 .259 r
.45507 .3183 .4621 .29835 .47331 .29773 .4664 .31778 Mtetra
.429 .068 .249 r
.4664 .31778 .47331 .29773 .48461 .29618 .47782 .3161 Mtetra
.41 .05 .24 r
.47782 .3161 .48461 .29618 .49597 .2941 .48931 .31361 Mtetra
.409 .047 .235 r
.48931 .31361 .49597 .2941 .50739 .29222 .50087 .31118 Mtetra
.408 .042 .228 r
.50087 .31118 .50739 .29222 .51888 .29052 .51248 .30883 Mtetra
.398 .029 .216 r
.51248 .30883 .51888 .29052 .53043 .28856 .52416 .30625 Mtetra
.386 .014 .204 r
.52416 .30625 .53043 .28856 .54204 .28635 .53589 .30339 Mtetra
.372 0 .189 r
.53589 .30339 .54204 .28635 .55372 .28398 .54768 .30017 Mtetra
.354 0 .169 r
.54768 .30017 .55372 .28398 .56546 .28149 .55953 .29663 Mtetra
.333 0 .144 r
.55953 .29663 .56546 .28149 .57726 .2789 .57143 .29278 Mtetra
.307 0 .109 r
.57143 .29278 .57726 .2789 .58911 .27622 .58337 .28865 Mtetra
.273 0 .063 r
.58337 .28865 .58911 .27622 .60103 .27341 .59536 .28426 Mtetra
.226 0 .001 r
.59536 .28426 .60103 .27341 .613 .27043 .6074 .2796 Mtetra
.161 0 0 r
.6074 .2796 .613 .27043 .62503 .2672 .61947 .27464 Mtetra
.073 0 0 r
.61947 .27464 .62503 .2672 .63711 .26368 .63158 .26937 Mtetra
0 0 0 r
.63158 .26937 .63711 .26368 .64923 .25982 .64373 .26378 Mtetra
.64373 .26378 .64923 .25982 .66139 .2556 .6559 .25787 Mtetra
.369 .816 .683 r
.6559 .25787 .66139 .2556 .67358 .251 .6681 .25164 Mtetra
.525 .918 .828 r
.6681 .25164 .67358 .251 .68581 .24604 .68032 .24514 Mtetra
.638 .96 .915 r
.68032 .24514 .68581 .24604 .69807 .24074 .69257 .23841 Mtetra
.704 .955 .951 r
.69257 .23841 .69807 .24074 .71036 .23517 .70485 .2315 Mtetra
.736 .925 .954 r
.70485 .2315 .71036 .23517 .72268 .22936 .71715 .22446 Mtetra
.748 .888 .943 r
.71715 .22446 .72268 .22936 .73502 .22338 .72947 .21733 Mtetra
.75 .851 .926 r
.72947 .21733 .73502 .22338 .74741 .21728 .74183 .21016 Mtetra
.745 .816 .907 r
.74183 .21016 .74741 .21728 .75983 .21113 .75422 .20298 Mtetra
.487 .696 .961 r
.08813 .42819 .09551 .43462 .10507 .43377 .09766 .42764 Mtetra
.477 .703 .968 r
.09766 .42764 .10507 .43377 .11468 .43293 .10725 .42713 Mtetra
.465 .711 .976 r
.10725 .42713 .11468 .43293 .12435 .43205 .11688 .42664 Mtetra
.452 .721 .983 r
.11688 .42664 .12435 .43205 .13408 .4311 .12657 .42615 Mtetra
.436 .733 .989 r
.12657 .42615 .13408 .4311 .14388 .43004 .13632 .42565 Mtetra
.418 .746 .994 r
.13632 .42565 .14388 .43004 .15375 .42881 .14613 .42509 Mtetra
.395 .76 .993 r
.14613 .42509 .15375 .42881 .1637 .42738 .15601 .42442 Mtetra
.365 .771 .983 r
.15601 .42442 .1637 .42738 .17372 .42569 .16597 .42361 Mtetra
.327 .776 .957 r
.16597 .42361 .17372 .42569 .18383 .42371 .176 .42261 Mtetra
.275 .766 .907 r
.176 .42261 .18383 .42371 .19401 .42144 .18611 .42139 Mtetra
.212 .736 .83 r
.18611 .42139 .19401 .42144 .20428 .41885 .1963 .41992 Mtetra
.143 .686 .729 r
.1963 .41992 .20428 .41885 .21461 .41597 .20657 .41819 Mtetra
0 0 0 r
.20657 .41819 .21461 .41597 .22503 .41281 .21692 .41618 Mtetra
.21692 .41618 .22503 .41281 .2355 .40938 .22735 .41389 Mtetra
.039 0 0 r
.22735 .41389 .2355 .40938 .24604 .40571 .23785 .41131 Mtetra
.08 0 0 r
.23785 .41131 .24604 .40571 .25665 .40176 .24843 .40844 Mtetra
.115 0 0 r
.24843 .40844 .25665 .40176 .26732 .39752 .25907 .40529 Mtetra
.15 0 0 r
.25907 .40529 .26732 .39752 .27805 .39295 .26978 .40194 Mtetra
.19 0 0 r
.26978 .40194 .27805 .39295 .28885 .38804 .28055 .39846 Mtetra
.24 0 0 r
.28055 .39846 .28885 .38804 .2997 .38285 .29135 .39507 Mtetra
.294 0 .056 r
.29135 .39507 .2997 .38285 .3106 .37743 .30219 .3919 Mtetra
.345 0 .13 r
.30219 .3919 .3106 .37743 .32152 .37208 .31305 .38909 Mtetra
.38 .001 .188 r
.31305 .38909 .32152 .37208 .33248 .36679 .32394 .38655 Mtetra
.383 .022 .223 r
.32394 .38655 .33248 .36679 .34351 .36069 .33492 .38333 Mtetra
.376 .031 .247 r
.33492 .38333 .34351 .36069 .35464 .35343 .34602 .37903 Mtetra
.368 .038 .268 r
.34602 .37903 .35464 .35343 .36586 .3448 .35722 .37356 Mtetra
.368 .05 .288 r
.35722 .37356 .36586 .3448 .37713 .33523 .3685 .36716 Mtetra
.39 .079 .313 r
.3685 .36716 .37713 .33523 .38837 .32651 .37979 .36102 Mtetra
.414 .107 .333 r
.37979 .36102 .38837 .32651 .39955 .31965 .39108 .35574 Mtetra
.438 .132 .348 r
.39108 .35574 .39955 .31965 .41064 .31574 .40236 .35182 Mtetra
.457 .149 .354 r
.40236 .35182 .41064 .31574 .42168 .31476 .41363 .34929 Mtetra
.466 .153 .351 r
.41363 .34929 .42168 .31476 .43274 .31567 .42493 .34762 Mtetra
.465 .146 .34 r
.42493 .34762 .43274 .31567 .44385 .31745 .43629 .34621 Mtetra
.444 .118 .316 r
.43629 .34621 .44385 .31745 .45507 .3183 .44774 .34388 Mtetra
.413 .078 .285 r
.44774 .34388 .45507 .3183 .4664 .31778 .45927 .34038 Mtetra
.374 .03 .247 r
.45927 .34038 .4664 .31778 .47782 .3161 .47087 .33577 Mtetra
.333 0 .202 r
.47087 .33577 .47782 .3161 .48931 .31361 .48253 .33048 Mtetra
.309 0 .155 r
.48253 .33048 .48931 .31361 .50087 .31118 .49423 .32546 Mtetra
.284 0 .1 r
.49423 .32546 .50087 .31118 .51248 .30883 .50596 .3208 Mtetra
.249 0 .032 r
.50596 .3208 .51248 .30883 .52416 .30625 .51775 .31636 Mtetra
.206 0 0 r
.51775 .31636 .52416 .30625 .53589 .30339 .52958 .312 Mtetra
.151 0 0 r
.52958 .312 .53589 .30339 .54768 .30017 .54145 .30751 Mtetra
.085 0 0 r
.54145 .30751 .54768 .30017 .55953 .29663 .55338 .30281 Mtetra
.004 0 0 r
.55338 .30281 .55953 .29663 .57143 .29278 .56535 .29782 Mtetra
0 0 0 r
.56535 .29782 .57143 .29278 .58337 .28865 .57736 .29253 Mtetra
.57736 .29253 .58337 .28865 .59536 .28426 .5894 .28693 Mtetra
.331 .79 .659 r
.5894 .28693 .59536 .28426 .6074 .2796 .60149 .28104 Mtetra
.46 .881 .779 r
.60149 .28104 .6074 .2796 .61947 .27464 .6136 .27485 Mtetra
.571 .94 .87 r
.6136 .27485 .61947 .27464 .63158 .26937 .62574 .26837 Mtetra
.655 .963 .925 r
.62574 .26837 .63158 .26937 .64373 .26378 .63791 .26163 Mtetra
.708 .957 .949 r
.63791 .26163 .64373 .26378 .6559 .25787 .65011 .25465 Mtetra
.739 .936 .952 r
.65011 .25465 .6559 .25787 .6681 .25164 .66232 .24746 Mtetra
.754 .91 .945 r
.66232 .24746 .6681 .25164 .68032 .24514 .67456 .24011 Mtetra
.76 .884 .934 r
.67456 .24011 .68032 .24514 .69257 .23841 .68683 .23263 Mtetra
.762 .86 .922 r
.68683 .23263 .69257 .23841 .70485 .2315 .69912 .22508 Mtetra
.76 .84 .912 r
.69912 .22508 .70485 .2315 .71715 .22446 .71144 .2175 Mtetra
.757 .823 .904 r
.71144 .2175 .71715 .22446 .72947 .21733 .72378 .2099 Mtetra
.754 .809 .897 r
.72378 .2099 .72947 .21733 .74183 .21016 .73616 .20231 Mtetra
.75 .797 .89 r
.73616 .20231 .74183 .21016 .75422 .20298 .74857 .19475 Mtetra
.506 .703 .959 r
.0807 .4217 .08813 .42819 .09766 .42764 .09028 .42088 Mtetra
.506 .694 .953 r
.09028 .42088 .09766 .42764 .10725 .42713 .09991 .42011 Mtetra
.506 .686 .948 r
.09991 .42011 .10725 .42713 .11688 .42664 .10958 .41941 Mtetra
.505 .679 .944 r
.10958 .41941 .11688 .42664 .12657 .42615 .1193 .41876 Mtetra
.502 .674 .941 r
.1193 .41876 .12657 .42615 .13632 .42565 .12907 .41818 Mtetra
.501 .671 .94 r
.12907 .41818 .13632 .42565 .14613 .42509 .13889 .41762 Mtetra
.5 .672 .941 r
.13889 .41762 .14613 .42509 .15601 .42442 .14877 .41707 Mtetra
.501 .677 .944 r
.14877 .41707 .15601 .42442 .16597 .42361 .15871 .41648 Mtetra
.502 .685 .949 r
.15871 .41648 .16597 .42361 .176 .42261 .16872 .4158 Mtetra
.504 .698 .956 r
.16872 .4158 .176 .42261 .18611 .42139 .1788 .41499 Mtetra
.507 .714 .965 r
.1788 .41499 .18611 .42139 .1963 .41992 .18895 .41402 Mtetra
.51 .734 .975 r
.18895 .41402 .1963 .41992 .20657 .41819 .19918 .41285 Mtetra
.514 .757 .984 r
.19918 .41285 .20657 .41819 .21692 .41618 .2095 .41144 Mtetra
.515 .78 .992 r
.2095 .41144 .21692 .41618 .22735 .41389 .21989 .4098 Mtetra
.514 .804 .998 r
.21989 .4098 .22735 .41389 .23785 .41131 .23036 .4079 Mtetra
.505 .825 1 r
.23036 .4079 .23785 .41131 .24843 .40844 .2409 .40579 Mtetra
.483 .841 .994 r
.2409 .40579 .24843 .40844 .25907 .40529 .25151 .40354 Mtetra
.425 .838 .969 r
.25151 .40354 .25907 .40529 .26978 .40194 .26217 .40134 Mtetra
.312 .797 .895 r
.26217 .40134 .26978 .40194 .28055 .39846 .27286 .39934 Mtetra
.115 .666 .722 r
.27286 .39934 .28055 .39846 .29135 .39507 .28357 .39785 Mtetra
.115 0 0 r
.28357 .39785 .29135 .39507 .30219 .3919 .29429 .39702 Mtetra
.287 0 0 r
.29429 .39702 .30219 .3919 .31305 .38909 .30503 .39686 Mtetra
.382 0 0 r
.30503 .39686 .31305 .38909 .32394 .38655 .31581 .3972 Mtetra
.406 0 .077 r
.31581 .3972 .32394 .38655 .33492 .38333 .32668 .3972 Mtetra
.408 0 .147 r
.32668 .3972 .33492 .38333 .34602 .37903 .33767 .39644 Mtetra
.409 .028 .202 r
.33767 .39644 .34602 .37903 .35722 .37356 .34877 .39486 Mtetra
.411 .054 .245 r
.34877 .39486 .35722 .37356 .3685 .36716 .35997 .39246 Mtetra
.418 .079 .281 r
.35997 .39246 .3685 .36716 .37979 .36102 .37126 .38956 Mtetra
.423 .095 .303 r
.37126 .38956 .37979 .36102 .39108 .35574 .38262 .38624 Mtetra
.42 .099 .313 r
.38262 .38624 .39108 .35574 .40236 .35182 .39405 .38233 Mtetra
.41 .09 .309 r
.39405 .38233 .40236 .35182 .41363 .34929 .40556 .37783 Mtetra
.395 .07 .293 r
.40556 .37783 .41363 .34929 .42493 .34762 .41712 .37291 Mtetra
.368 .034 .261 r
.41712 .37291 .42493 .34762 .43629 .34621 .42874 .36748 Mtetra
.316 0 .205 r
.42874 .36748 .43629 .34621 .44774 .34388 .44043 .36121 Mtetra
.238 0 .123 r
.44043 .36121 .44774 .34388 .45927 .34038 .45216 .35411 Mtetra
.125 0 .007 r
.45216 .35411 .45927 .34038 .47087 .33577 .46394 .34623 Mtetra
0 0 0 r
.46394 .34623 .47087 .33577 .48253 .33048 .47574 .33799 Mtetra
.47574 .33799 .48253 .33048 .49423 .32546 .48756 .33024 Mtetra
.48756 .33024 .49423 .32546 .50596 .3208 .49939 .32315 Mtetra
.441 .864 .735 r
.49939 .32315 .50596 .3208 .51775 .31636 .51125 .31674 Mtetra
.549 .931 .877 r
.51125 .31674 .51775 .31636 .52958 .312 .52315 .31082 Mtetra
.622 .945 .947 r
.52315 .31082 .52958 .312 .54145 .30751 .53508 .30511 Mtetra
.663 .931 .97 r
.53508 .30511 .54145 .30751 .55338 .30281 .54706 .29944 Mtetra
.692 .912 .971 r
.54706 .29944 .55338 .30281 .56535 .29782 .55907 .29361 Mtetra
.712 .89 .962 r
.55907 .29361 .56535 .29782 .57736 .29253 .57112 .28756 Mtetra
.726 .869 .948 r
.57112 .28756 .57736 .29253 .5894 .28693 .5832 .28125 Mtetra
.735 .848 .934 r
.5832 .28125 .5894 .28693 .60149 .28104 .59532 .27467 Mtetra
.741 .828 .919 r
.59532 .27467 .60149 .28104 .6136 .27485 .60746 .26784 Mtetra
.744 .81 .905 r
.60746 .26784 .6136 .27485 .62574 .26837 .61963 .26079 Mtetra
.745 .795 .893 r
.61963 .26079 .62574 .26837 .63791 .26163 .63182 .25356 Mtetra
.745 .782 .883 r
.63182 .25356 .63791 .26163 .65011 .25465 .64404 .24619 Mtetra
.744 .772 .875 r
.64404 .24619 .65011 .25465 .66232 .24746 .65629 .23871 Mtetra
.743 .765 .87 r
.65629 .23871 .66232 .24746 .67456 .24011 .66856 .23117 Mtetra
.742 .761 .868 r
.66856 .23117 .67456 .24011 .68683 .23263 .68087 .22363 Mtetra
.741 .759 .868 r
.68087 .22363 .68683 .23263 .69912 .22508 .6932 .21609 Mtetra
.74 .761 .87 r
.6932 .21609 .69912 .22508 .71144 .2175 .70557 .20862 Mtetra
.739 .764 .873 r
.70557 .20862 .71144 .2175 .72378 .2099 .71797 .20118 Mtetra
.739 .77 .877 r
.71797 .20118 .72378 .2099 .73616 .20231 .7304 .1938 Mtetra
.739 .776 .883 r
.7304 .1938 .73616 .20231 .74857 .19475 .74288 .18646 Mtetra
.564 .725 .949 r
.07322 .41517 .0807 .4217 .09028 .42088 .08293 .41344 Mtetra
.568 .697 .928 r
.08293 .41344 .09028 .42088 .09991 .42011 .09269 .41177 Mtetra
.569 .671 .907 r
.09269 .41177 .09991 .42011 .10958 .41941 .10248 .41018 Mtetra
.568 .646 .888 r
.10248 .41018 .10958 .41941 .1193 .41876 .11231 .40868 Mtetra
.564 .624 .87 r
.11231 .40868 .1193 .41876 .12907 .41818 .12218 .40728 Mtetra
.562 .605 .854 r
.12218 .40728 .12907 .41818 .13889 .41762 .13209 .40598 Mtetra
.56 .589 .84 r
.13209 .40598 .13889 .41762 .14877 .41707 .14205 .40474 Mtetra
.559 .576 .827 r
.14205 .40474 .14877 .41707 .15871 .41648 .15206 .40354 Mtetra
.559 .566 .817 r
.15206 .40354 .15871 .41648 .16872 .4158 .16212 .40234 Mtetra
.56 .558 .808 r
.16212 .40234 .16872 .4158 .1788 .41499 .17224 .40108 Mtetra
.563 .553 .801 r
.17224 .40108 .1788 .41499 .18895 .41402 .18243 .39974 Mtetra
.566 .55 .795 r
.18243 .39974 .18895 .41402 .19918 .41285 .19268 .39828 Mtetra
.571 .548 .791 r
.19268 .39828 .19918 .41285 .2095 .41144 .20301 .39667 Mtetra
.574 .548 .788 r
.20301 .39667 .2095 .41144 .21989 .4098 .21341 .39491 Mtetra
.578 .549 .786 r
.21341 .39491 .21989 .4098 .23036 .4079 .22387 .39301 Mtetra
.579 .55 .786 r
.22387 .39301 .23036 .4079 .2409 .40579 .23439 .39104 Mtetra
.579 .553 .789 r
.23439 .39104 .2409 .40579 .25151 .40354 .24497 .38907 Mtetra
.575 .555 .795 r
.24497 .38907 .25151 .40354 .26217 .40134 .25559 .38725 Mtetra
.567 .558 .803 r
.25559 .38725 .26217 .40134 .27286 .39934 .26624 .38571 Mtetra
.555 .559 .813 r
.26624 .38571 .27286 .39934 .28357 .39785 .27692 .38455 Mtetra
.54 .557 .821 r
.27692 .38455 .28357 .39785 .29429 .39702 .28763 .38384 Mtetra
.528 .554 .825 r
.28763 .38384 .29429 .39702 .30503 .39686 .29839 .38343 Mtetra
.522 .547 .822 r
.29839 .38343 .30503 .39686 .31581 .3972 .3092 .3832 Mtetra
.531 .543 .812 r
.3092 .3832 .31581 .3972 .32668 .3972 .32009 .38276 Mtetra
.543 .543 .805 r
.32009 .38276 .32668 .3972 .33767 .39644 .33108 .38197 Mtetra
.544 .544 .805 r
.33108 .38197 .33767 .39644 .34877 .39486 .34213 .38112 Mtetra
.547 .558 .817 r
.34213 .38112 .34877 .39486 .35997 .39246 .35326 .38016 Mtetra
.562 .592 .842 r
.35326 .38016 .35997 .39246 .37126 .38956 .36448 .37869 Mtetra
.591 .637 .865 r
.36448 .37869 .37126 .38956 .38262 .38624 .37581 .37637 Mtetra
.646 .684 .872 r
.37581 .37637 .38262 .38624 .39405 .38233 .38727 .37243 Mtetra
.691 .701 .855 r
.38727 .37243 .39405 .38233 .40556 .37783 .39884 .36686 Mtetra
.704 .684 .829 r
.39884 .36686 .40556 .37783 .41712 .37291 .41047 .36043 Mtetra
.703 .657 .802 r
.41047 .36043 .41712 .37291 .42874 .36748 .42216 .35348 Mtetra
.694 .631 .782 r
.42216 .35348 .42874 .36748 .44043 .36121 .43387 .34641 Mtetra
.689 .619 .772 r
.43387 .34641 .44043 .36121 .45216 .35411 .44562 .33926 Mtetra
.695 .621 .77 r
.44562 .33926 .45216 .35411 .46394 .34623 .4574 .33175 Mtetra
.702 .629 .773 r
.4574 .33175 .46394 .34623 .47574 .33799 .46921 .32401 Mtetra
.702 .637 .78 r
.46921 .32401 .47574 .33799 .48756 .33024 .48104 .31644 Mtetra
.698 .638 .785 r
.48104 .31644 .48756 .33024 .49939 .32315 .4929 .30917 Mtetra
.689 .631 .786 r
.4929 .30917 .49939 .32315 .51125 .31674 .50477 .30233 Mtetra
.679 .621 .784 r
.50477 .30233 .51125 .31674 .52315 .31082 .51668 .29588 Mtetra
.67 .61 .779 r
.51668 .29588 .52315 .31082 .53508 .30511 .52862 .2897 Mtetra
.664 .601 .775 r
.52862 .2897 .53508 .30511 .54706 .29944 .5406 .28366 Mtetra
.662 .596 .771 r
.5406 .28366 .54706 .29944 .55907 .29361 .55262 .27762 Mtetra
.662 .594 .768 r
.55262 .27762 .55907 .29361 .57112 .28756 .56468 .2715 Mtetra
.664 .595 .767 r
.56468 .2715 .57112 .28756 .5832 .28125 .57677 .26522 Mtetra
.667 .597 .767 r
.57677 .26522 .5832 .28125 .59532 .27467 .58889 .25879 Mtetra
.671 .601 .768 r
.58889 .25879 .59532 .27467 .60746 .26784 .60105 .25218 Mtetra
.675 .606 .771 r
.60105 .25218 .60746 .26784 .61963 .26079 .61324 .24544 Mtetra
.679 .612 .774 r
.61324 .24544 .61963 .26079 .63182 .25356 .62546 .2386 Mtetra
.682 .62 .779 r
.62546 .2386 .63182 .25356 .64404 .24619 .63771 .23169 Mtetra
.685 .628 .786 r
.63771 .23169 .64404 .24619 .65629 .23871 .65 .22477 Mtetra
.689 .639 .794 r
.65 .22477 .65629 .23871 .66856 .23117 .66232 .21788 Mtetra
.692 .651 .804 r
.66232 .21788 .66856 .23117 .68087 .22363 .67469 .21104 Mtetra
.695 .665 .816 r
.67469 .21104 .68087 .22363 .6932 .21609 .68709 .20428 Mtetra
.698 .682 .83 r
.68709 .20428 .6932 .21609 .70557 .20862 .69953 .19763 Mtetra
.702 .701 .846 r
.69953 .19763 .70557 .20862 .71797 .20118 .71202 .19106 Mtetra
.707 .723 .863 r
.71202 .19106 .71797 .20118 .7304 .1938 .72455 .18456 Mtetra
.711 .748 .881 r
.72455 .18456 .7304 .1938 .74288 .18646 .73713 .1781 Mtetra
.631 .745 .93 r
.06568 .40859 .07322 .41517 .08293 .41344 .07558 .40558 Mtetra
.629 .706 .902 r
.07558 .40558 .08293 .41344 .09269 .41177 .08552 .40262 Mtetra
.624 .67 .874 r
.08552 .40262 .09269 .41177 .10248 .41018 .09549 .39974 Mtetra
.617 .638 .849 r
.09549 .39974 .10248 .41018 .11231 .40868 .1055 .39696 Mtetra
.609 .61 .827 r
.1055 .39696 .11231 .40868 .12218 .40728 .11552 .39432 Mtetra
.601 .585 .807 r
.11552 .39432 .12218 .40728 .13209 .40598 .12558 .39179 Mtetra
.594 .563 .789 r
.12558 .39179 .13209 .40598 .14205 .40474 .13567 .38939 Mtetra
.589 .545 .773 r
.13567 .38939 .14205 .40474 .15206 .40354 .1458 .38706 Mtetra
.584 .53 .76 r
.1458 .38706 .15206 .40354 .16212 .40234 .15596 .3848 Mtetra
.581 .517 .747 r
.15596 .3848 .16212 .40234 .17224 .40108 .16618 .38256 Mtetra
.579 .506 .737 r
.16618 .38256 .17224 .40108 .18243 .39974 .17645 .3803 Mtetra
.578 .498 .728 r
.17645 .3803 .18243 .39974 .19268 .39828 .18677 .378 Mtetra
.577 .491 .721 r
.18677 .378 .19268 .39828 .20301 .39667 .19714 .37565 Mtetra
.576 .485 .714 r
.19714 .37565 .20301 .39667 .21341 .39491 .20757 .37327 Mtetra
.575 .48 .709 r
.20757 .37327 .21341 .39491 .22387 .39301 .21805 .37089 Mtetra
.572 .476 .706 r
.21805 .37089 .22387 .39301 .23439 .39104 .22858 .36857 Mtetra
.569 .472 .704 r
.22858 .36857 .23439 .39104 .24497 .38907 .23914 .36638 Mtetra
.566 .468 .703 r
.23914 .36638 .24497 .38907 .25559 .38725 .24975 .36433 Mtetra
.563 .465 .702 r
.24975 .36433 .25559 .38725 .26624 .38571 .2604 .36245 Mtetra
.561 .462 .699 r
.2604 .36245 .26624 .38571 .27692 .38455 .2711 .36058 Mtetra
.562 .459 .695 r
.2711 .36058 .27692 .38455 .28763 .38384 .28186 .35864 Mtetra
.565 .454 .686 r
.28186 .35864 .28763 .38384 .29839 .38343 .29271 .35644 Mtetra
.567 .447 .675 r
.29271 .35644 .29839 .38343 .3092 .3832 .30363 .35391 Mtetra
.565 .435 .663 r
.30363 .35391 .3092 .3832 .32009 .38276 .31461 .35128 Mtetra
.56 .424 .653 r
.31461 .35128 .32009 .38276 .33108 .38197 .32564 .34877 Mtetra
.548 .41 .645 r
.32564 .34877 .33108 .38197 .34213 .38112 .33668 .34703 Mtetra
.536 .4 .642 r
.33668 .34703 .34213 .38112 .35326 .38016 .34773 .34607 Mtetra
.538 .401 .642 r
.34773 .34607 .35326 .38016 .36448 .37869 .35886 .34497 Mtetra
.55 .411 .644 r
.35886 .34497 .36448 .37869 .37581 .37637 .3701 .34303 Mtetra
.576 .43 .646 r
.3701 .34303 .37581 .37637 .38727 .37243 .3815 .33903 Mtetra
.599 .446 .645 r
.3815 .33903 .38727 .37243 .39884 .36686 .39303 .33297 Mtetra
.607 .45 .643 r
.39303 .33297 .39884 .36686 .41047 .36043 .40462 .32607 Mtetra
.608 .449 .641 r
.40462 .32607 .41047 .36043 .42216 .35348 .41625 .31901 Mtetra
.599 .443 .641 r
.41625 .31901 .42216 .35348 .43387 .34641 .42788 .31271 Mtetra
.592 .441 .645 r
.42788 .31271 .43387 .34641 .44562 .33926 .43953 .3072 Mtetra
.594 .447 .651 r
.43953 .3072 .44562 .33926 .4574 .33175 .45121 .3018 Mtetra
.6 .459 .661 r
.45121 .3018 .4574 .33175 .46921 .32401 .46293 .29629 Mtetra
.61 .475 .672 r
.46293 .29629 .46921 .32401 .48104 .31644 .4747 .29045 Mtetra
.619 .489 .682 r
.4747 .29045 .48104 .31644 .4929 .30917 .48651 .28433 Mtetra
.624 .498 .689 r
.48651 .28433 .4929 .30917 .50477 .30233 .49835 .27812 Mtetra
.626 .503 .693 r
.49835 .27812 .50477 .30233 .51668 .29588 .51023 .27193 Mtetra
.624 .504 .695 r
.51023 .27193 .51668 .29588 .52862 .2897 .52215 .26589 Mtetra
.622 .504 .697 r
.52215 .26589 .52862 .2897 .5406 .28366 .53411 .26 Mtetra
.621 .504 .698 r
.53411 .26 .5406 .28366 .55262 .27762 .5461 .25422 Mtetra
.621 .506 .701 r
.5461 .25422 .55262 .27762 .56468 .2715 .55814 .24851 Mtetra
.623 .509 .704 r
.55814 .24851 .56468 .2715 .57677 .26522 .57022 .24278 Mtetra
.625 .515 .708 r
.57022 .24278 .57677 .26522 .58889 .25879 .58234 .23701 Mtetra
.628 .522 .714 r
.58234 .23701 .58889 .25879 .60105 .25218 .5945 .23118 Mtetra
.632 .53 .72 r
.5945 .23118 .60105 .25218 .61324 .24544 .6067 .22531 Mtetra
.636 .54 .728 r
.6067 .22531 .61324 .24544 .62546 .2386 .61895 .21941 Mtetra
.64 .55 .738 r
.61895 .21941 .62546 .2386 .63771 .23169 .63123 .21352 Mtetra
.644 .563 .748 r
.63123 .21352 .63771 .23169 .65 .22477 .64356 .20768 Mtetra
.647 .577 .761 r
.64356 .20768 .65 .22477 .66232 .21788 .65594 .20193 Mtetra
.651 .593 .776 r
.65594 .20193 .66232 .21788 .67469 .21104 .66837 .19629 Mtetra
.655 .611 .793 r
.66837 .19629 .67469 .21104 .68709 .20428 .68086 .19076 Mtetra
.659 .633 .813 r
.68086 .19076 .68709 .20428 .69953 .19763 .69339 .18537 Mtetra
.663 .659 .835 r
.69339 .18537 .69953 .19763 .71202 .19106 .70599 .18007 Mtetra
.668 .688 .86 r
.70599 .18007 .71202 .19106 .72455 .18456 .71864 .17485 Mtetra
.672 .722 .887 r
.71864 .17485 .72455 .18456 .73713 .1781 .73134 .16968 Mtetra
.688 .758 .905 r
.05808 .40196 .06568 .40859 .07558 .40558 .06821 .3975 Mtetra
.679 .716 .877 r
.06821 .3975 .07558 .40558 .08552 .40262 .07836 .39309 Mtetra
.669 .678 .85 r
.07836 .39309 .08552 .40262 .09549 .39974 .08854 .38875 Mtetra
.658 .645 .826 r
.08854 .38875 .09549 .39974 .1055 .39696 .09874 .38451 Mtetra
.646 .614 .804 r
.09874 .38451 .1055 .39696 .11552 .39432 .10896 .38041 Mtetra
.635 .588 .784 r
.10896 .38041 .11552 .39432 .12558 .39179 .11919 .37644 Mtetra
.625 .564 .766 r
.11919 .37644 .12558 .39179 .13567 .38939 .12945 .37261 Mtetra
.616 .544 .75 r
.12945 .37261 .13567 .38939 .1458 .38706 .13973 .3689 Mtetra
.609 .526 .736 r
.13973 .3689 .1458 .38706 .15596 .3848 .15004 .36529 Mtetra
.603 .511 .723 r
.15004 .36529 .15596 .3848 .16618 .38256 .16038 .36176 Mtetra
.597 .498 .713 r
.16038 .36176 .16618 .38256 .17645 .3803 .17075 .35828 Mtetra
.593 .487 .703 r
.17075 .35828 .17645 .3803 .18677 .378 .18116 .35486 Mtetra
.589 .478 .695 r
.18116 .35486 .18677 .378 .19714 .37565 .19161 .35147 Mtetra
.585 .47 .688 r
.19161 .35147 .19714 .37565 .20757 .37327 .2021 .34816 Mtetra
.581 .462 .682 r
.2021 .34816 .20757 .37327 .21805 .37089 .21262 .34495 Mtetra
.577 .456 .678 r
.21262 .34495 .21805 .37089 .22858 .36857 .22318 .34186 Mtetra
.574 .45 .673 r
.22318 .34186 .22858 .36857 .23914 .36638 .23377 .33891 Mtetra
.572 .445 .669 r
.23377 .33891 .23914 .36638 .24975 .36433 .24441 .33598 Mtetra
.571 .441 .665 r
.24441 .33598 .24975 .36433 .2604 .36245 .2551 .33299 Mtetra
.574 .439 .659 r
.2551 .33299 .2604 .36245 .2711 .36058 .26587 .32963 Mtetra
.579 .437 .652 r
.26587 .32963 .2711 .36058 .28186 .35864 .27673 .32574 Mtetra
.583 .434 .644 r
.27673 .32574 .28186 .35864 .29271 .35644 .28768 .32122 Mtetra
.585 .428 .635 r
.28768 .32122 .29271 .35644 .30363 .35391 .29871 .31615 Mtetra
.579 .418 .627 r
.29871 .31615 .30363 .35391 .31461 .35128 .30977 .31125 Mtetra
.568 .405 .62 r
.30977 .31125 .31461 .35128 .32564 .34877 .32082 .30698 Mtetra
.551 .389 .615 r
.32082 .30698 .32564 .34877 .33668 .34703 .33183 .30417 Mtetra
.535 .376 .612 r
.33183 .30417 .33668 .34703 .34773 .34607 .34281 .3028 Mtetra
.533 .374 .611 r
.34281 .3028 .34773 .34607 .35886 .34497 .35384 .30161 Mtetra
.54 .379 .611 r
.35384 .30161 .35886 .34497 .3701 .34303 .36497 .29971 Mtetra
.562 .395 .612 r
.36497 .29971 .3701 .34303 .3815 .33903 .37627 .29565 Mtetra
.582 .409 .613 r
.37627 .29565 .3815 .33903 .39303 .33297 .38771 .28943 Mtetra
.588 .413 .612 r
.38771 .28943 .39303 .33297 .40462 .32607 .39921 .28249 Mtetra
.586 .412 .612 r
.39921 .28249 .40462 .32607 .41625 .31901 .41074 .27571 Mtetra
.573 .403 .613 r
.41074 .27571 .41625 .31901 .42788 .31271 .42224 .27039 Mtetra
.561 .396 .616 r
.42224 .27039 .42788 .31271 .43953 .3072 .43374 .26652 Mtetra
.556 .396 .62 r
.43374 .26652 .43953 .3072 .45121 .3018 .44528 .2633 Mtetra
.556 .402 .627 r
.44528 .2633 .45121 .3018 .46293 .29629 .45686 .26025 Mtetra
.565 .415 .636 r
.45686 .26025 .46293 .29629 .4747 .29045 .46852 .25664 Mtetra
.576 .429 .644 r
.46852 .25664 .4747 .29045 .48651 .28433 .48024 .2524 Mtetra
.586 .442 .652 r
.48024 .2524 .48651 .28433 .49835 .27812 .49201 .24761 Mtetra
.593 .452 .658 r
.49201 .24761 .49835 .27812 .51023 .27193 .50384 .24245 Mtetra
.596 .458 .664 r
.50384 .24245 .51023 .27193 .52215 .26589 .51571 .23721 Mtetra
.598 .463 .668 r
.51571 .23721 .52215 .26589 .53411 .26 .52762 .232 Mtetra
.598 .466 .672 r
.52762 .232 .53411 .26 .5461 .25422 .53958 .22691 Mtetra
.598 .469 .676 r
.53958 .22691 .5461 .25422 .55814 .24851 .55158 .22196 Mtetra
.598 .473 .681 r
.55158 .22196 .55814 .24851 .57022 .24278 .56364 .21709 Mtetra
.599 .479 .687 r
.56364 .21709 .57022 .24278 .58234 .23701 .57574 .2123 Mtetra
.601 .486 .694 r
.57574 .2123 .58234 .23701 .5945 .23118 .5879 .20754 Mtetra
.604 .494 .702 r
.5879 .20754 .5945 .23118 .6067 .22531 .60011 .20284 Mtetra
.606 .504 .711 r
.60011 .20284 .6067 .22531 .61895 .21941 .61237 .19818 Mtetra
.609 .515 .723 r
.61237 .19818 .61895 .21941 .63123 .21352 .62468 .1936 Mtetra
.612 .528 .736 r
.62468 .1936 .63123 .21352 .64356 .20768 .63706 .18912 Mtetra
.614 .543 .75 r
.63706 .18912 .64356 .20768 .65594 .20193 .64949 .18476 Mtetra
.616 .559 .768 r
.64949 .18476 .65594 .20193 .66837 .19629 .66199 .18054 Mtetra
.618 .579 .788 r
.66199 .18054 .66837 .19629 .68086 .19076 .67456 .17646 Mtetra
.62 .602 .81 r
.67456 .17646 .68086 .19076 .69339 .18537 .68719 .17252 Mtetra
.622 .629 .836 r
.68719 .17252 .69339 .18537 .70599 .18007 .69989 .16867 Mtetra
.624 .66 .864 r
.69989 .16867 .70599 .18007 .71864 .17485 .71266 .1649 Mtetra
.625 .696 .896 r
.71266 .1649 .71864 .17485 .73134 .16968 .7255 .16118 Mtetra
.728 .765 .882 r
.05043 .39529 .05808 .40196 .06821 .3975 .06078 .38946 Mtetra
.717 .727 .859 r
.06078 .38946 .06821 .3975 .07836 .39309 .07114 .38367 Mtetra
.705 .693 .836 r
.07114 .38367 .07836 .39309 .08854 .38875 .08152 .37795 Mtetra
.692 .662 .816 r
.08152 .37795 .08854 .38875 .09874 .38451 .09192 .37232 Mtetra
.679 .634 .797 r
.09192 .37232 .09874 .38451 .10896 .38041 .10232 .36683 Mtetra
.667 .608 .779 r
.10232 .36683 .10896 .38041 .11919 .37644 .11274 .36146 Mtetra
.656 .585 .764 r
.11274 .36146 .11919 .37644 .12945 .37261 .12316 .35625 Mtetra
.646 .564 .749 r
.12316 .35625 .12945 .37261 .13973 .3689 .1336 .35117 Mtetra
.636 .546 .736 r
.1336 .35117 .13973 .3689 .15004 .36529 .14406 .34623 Mtetra
.628 .53 .724 r
.14406 .34623 .15004 .36529 .16038 .36176 .15453 .34141 Mtetra
.621 .516 .713 r
.15453 .34141 .16038 .36176 .17075 .35828 .16503 .33669 Mtetra
.614 .503 .704 r
.16503 .33669 .17075 .35828 .18116 .35486 .17554 .33209 Mtetra
.608 .492 .696 r
.17554 .33209 .18116 .35486 .19161 .35147 .18608 .32762 Mtetra
.602 .482 .689 r
.18608 .32762 .19161 .35147 .2021 .34816 .19664 .32329 Mtetra
.596 .473 .682 r
.19664 .32329 .2021 .34816 .21262 .34495 .20722 .31912 Mtetra
.591 .465 .677 r
.20722 .31912 .21262 .34495 .22318 .34186 .21783 .31509 Mtetra
.588 .458 .672 r
.21783 .31509 .22318 .34186 .23377 .33891 .22847 .31115 Mtetra
.587 .454 .666 r
.22847 .31115 .23377 .33891 .24441 .33598 .23916 .30709 Mtetra
.589 .45 .661 r
.23916 .30709 .24441 .33598 .2551 .33299 .24993 .30272 Mtetra
.594 .449 .654 r
.24993 .30272 .2551 .33299 .26587 .32963 .26078 .29769 Mtetra
.6 .448 .646 r
.26078 .29769 .26587 .32963 .27673 .32574 .27174 .29183 Mtetra
.604 .444 .638 r
.27174 .29183 .27673 .32574 .28768 .32122 .2828 .28519 Mtetra
.605 .439 .631 r
.2828 .28519 .28768 .32122 .29871 .31615 .29391 .27802 Mtetra
.595 .428 .625 r
.29391 .27802 .29871 .31615 .30977 .31125 .30502 .27131 Mtetra
.581 .413 .619 r
.30502 .27131 .30977 .31125 .32082 .30698 .31608 .2657 Mtetra
.56 .395 .615 r
.31608 .2657 .32082 .30698 .33183 .30417 .32705 .26198 Mtetra
.539 .379 .612 r
.32705 .26198 .33183 .30417 .34281 .3028 .33796 .26011 Mtetra
.535 .375 .611 r
.33796 .26011 .34281 .3028 .35384 .30161 .3489 .25862 Mtetra
.541 .379 .611 r
.3489 .25862 .35384 .30161 .36497 .29971 .35994 .25656 Mtetra
.561 .394 .611 r
.35994 .25656 .36497 .29971 .37627 .29565 .37114 .25245 Mtetra
.581 .407 .612 r
.37114 .25245 .37627 .29565 .38771 .28943 .38249 .24626 Mtetra
.586 .411 .612 r
.38249 .24626 .38771 .28943 .39921 .28249 .39389 .2395 Mtetra
.583 .409 .612 r
.39389 .2395 .39921 .28249 .41074 .27571 .4053 .23311 Mtetra
.566 .398 .613 r
.4053 .23311 .41074 .27571 .42224 .27039 .41668 .22859 Mtetra
.547 .386 .615 r
.41668 .22859 .42224 .27039 .43374 .26652 .42805 .22596 Mtetra
.536 .381 .619 r
.42805 .22596 .43374 .26652 .44528 .2633 .43944 .22445 Mtetra
.531 .383 .624 r
.43944 .22445 .44528 .2633 .45686 .26025 .45089 .22341 Mtetra
.539 .393 .631 r
.45089 .22341 .45686 .26025 .46852 .25664 .46242 .22184 Mtetra
.55 .407 .639 r
.46242 .22184 .46852 .25664 .48024 .2524 .47404 .21949 Mtetra
.563 .422 .647 r
.47404 .21949 .48024 .2524 .49201 .24761 .48573 .21629 Mtetra
.574 .435 .655 r
.48573 .21629 .49201 .24761 .50384 .24245 .49749 .21243 Mtetra
.58 .445 .661 r
.49749 .21243 .50384 .24245 .51571 .23721 .5093 .20825 Mtetra
.584 .452 .667 r
.5093 .20825 .51571 .23721 .52762 .232 .52117 .20395 Mtetra
.585 .457 .672 r
.52117 .20395 .52762 .232 .53958 .22691 .53309 .19974 Mtetra
.585 .461 .677 r
.53309 .19974 .53958 .22691 .55158 .22196 .54506 .19566 Mtetra
.584 .465 .683 r
.54506 .19566 .55158 .22196 .56364 .21709 .55708 .19174 Mtetra
.584 .471 .69 r
.55708 .19174 .56364 .21709 .57574 .2123 .56917 .18798 Mtetra
.584 .477 .698 r
.56917 .18798 .57574 .2123 .5879 .20754 .58132 .18434 Mtetra
.585 .485 .707 r
.58132 .18434 .5879 .20754 .60011 .20284 .59353 .18082 Mtetra
.586 .494 .718 r
.59353 .18082 .60011 .20284 .61237 .19818 .60581 .17742 Mtetra
.586 .505 .73 r
.60581 .17742 .61237 .19818 .62468 .1936 .61815 .17413 Mtetra
.587 .518 .744 r
.61815 .17413 .62468 .1936 .63706 .18912 .63056 .17098 Mtetra
.587 .532 .76 r
.63056 .17098 .63706 .18912 .64949 .18476 .64305 .16798 Mtetra
.587 .548 .778 r
.64305 .16798 .64949 .18476 .66199 .18054 .65561 .16513 Mtetra
.586 .567 .799 r
.65561 .16513 .66199 .18054 .67456 .17646 .66825 .16242 Mtetra
.584 .588 .822 r
.66825 .16242 .67456 .17646 .68719 .17252 .68097 .15985 Mtetra
.583 .613 .848 r
.68097 .15985 .68719 .17252 .69989 .16867 .69377 .15737 Mtetra
.58 .641 .876 r
.69377 .15737 .69989 .16867 .71266 .1649 .70665 .15497 Mtetra
.575 .674 .907 r
.70665 .15497 .71266 .1649 .7255 .16118 .71961 .15261 Mtetra
.751 .767 .866 r
.04273 .38856 .05043 .39529 .06078 .38946 .05324 .38174 Mtetra
.742 .741 .851 r
.05324 .38174 .06078 .38946 .07114 .38367 .06377 .37496 Mtetra
.732 .717 .837 r
.06377 .37496 .07114 .38367 .08152 .37795 .07431 .36825 Mtetra
.722 .694 .823 r
.07431 .36825 .08152 .37795 .09192 .37232 .08486 .36162 Mtetra
.711 .672 .81 r
.08486 .36162 .09192 .37232 .10232 .36683 .09541 .35512 Mtetra
.701 .651 .797 r
.09541 .35512 .10232 .36683 .11274 .36146 .10597 .34875 Mtetra
.69 .632 .786 r
.10597 .34875 .11274 .36146 .12316 .35625 .11653 .34253 Mtetra
.68 .614 .774 r
.11653 .34253 .12316 .35625 .1336 .35117 .12709 .33645 Mtetra
.671 .597 .764 r
.12709 .33645 .1336 .35117 .14406 .34623 .13767 .33051 Mtetra
.662 .581 .754 r
.13767 .33051 .14406 .34623 .15453 .34141 .14825 .32472 Mtetra
.654 .567 .744 r
.14825 .32472 .15453 .34141 .16503 .33669 .15885 .31905 Mtetra
.646 .554 .736 r
.15885 .31905 .16503 .33669 .17554 .33209 .16946 .31353 Mtetra
.639 .541 .728 r
.16946 .31353 .17554 .33209 .18608 .32762 .18008 .30817 Mtetra
.632 .53 .721 r
.18008 .30817 .18608 .32762 .19664 .32329 .19072 .30296 Mtetra
.625 .519 .714 r
.19072 .30296 .19664 .32329 .20722 .31912 .20137 .29791 Mtetra
.62 .51 .707 r
.20137 .29791 .20722 .31912 .21783 .31509 .21205 .29295 Mtetra
.616 .502 .7 r
.21205 .29295 .21783 .31509 .22847 .31115 .22276 .28801 Mtetra
.616 .496 .693 r
.22276 .28801 .22847 .31115 .23916 .30709 .23353 .28284 Mtetra
.618 .491 .685 r
.23353 .28284 .23916 .30709 .24993 .30272 .24437 .27726 Mtetra
.624 .488 .677 r
.24437 .27726 .24993 .30272 .26078 .29769 .2553 .27099 Mtetra
.63 .487 .669 r
.2553 .27099 .26078 .29769 .27174 .29183 .26633 .26391 Mtetra
.632 .483 .662 r
.26633 .26391 .27174 .29183 .2828 .28519 .27742 .25629 Mtetra
.631 .478 .657 r
.27742 .25629 .2828 .28519 .29391 .27802 .28855 .24845 Mtetra
.619 .468 .655 r
.28855 .24845 .29391 .27802 .30502 .27131 .29964 .24145 Mtetra
.6 .454 .655 r
.29964 .24145 .30502 .27131 .31608 .2657 .31064 .23587 Mtetra
.574 .437 .656 r
.31064 .23587 .31608 .2657 .32705 .26198 .32155 .23228 Mtetra
.547 .419 .658 r
.32155 .23228 .32705 .26198 .33796 .26011 .33239 .23051 Mtetra
.543 .417 .659 r
.33239 .23051 .33796 .26011 .3489 .25862 .34328 .22904 Mtetra
.553 .424 .659 r
.34328 .22904 .3489 .25862 .35994 .25656 .35427 .22692 Mtetra
.582 .444 .658 r
.35427 .22692 .35994 .25656 .37114 .25245 .36542 .22275 Mtetra
.608 .461 .657 r
.36542 .22275 .37114 .25245 .38249 .24626 .37672 .21654 Mtetra
.616 .466 .656 r
.37672 .21654 .38249 .24626 .39389 .2395 .38808 .20966 Mtetra
.612 .463 .656 r
.38808 .20966 .39389 .2395 .4053 .23311 .39945 .20308 Mtetra
.588 .447 .657 r
.39945 .20308 .4053 .23311 .41668 .22859 .41079 .19832 Mtetra
.56 .428 .657 r
.41079 .19832 .41668 .22859 .42805 .22596 .4221 .19556 Mtetra
.539 .413 .657 r
.4221 .19556 .42805 .22596 .43944 .22445 .43343 .19425 Mtetra
.526 .406 .658 r
.43343 .19425 .43944 .22445 .45089 .22341 .4448 .19378 Mtetra
.53 .411 .662 r
.4448 .19378 .45089 .22341 .46242 .22184 .45626 .19311 Mtetra
.539 .421 .667 r
.45626 .19311 .46242 .22184 .47404 .21949 .4678 .19189 Mtetra
.553 .436 .674 r
.4678 .19189 .47404 .21949 .48573 .21629 .47943 .18987 Mtetra
.565 .451 .682 r
.47943 .18987 .48573 .21629 .49749 .21243 .49113 .18715 Mtetra
.574 .463 .689 r
.49113 .18715 .49749 .21243 .5093 .20825 .5029 .18401 Mtetra
.58 .473 .697 r
.5029 .18401 .5093 .20825 .52117 .20395 .51473 .18063 Mtetra
.581 .48 .704 r
.51473 .18063 .52117 .20395 .53309 .19974 .52662 .17728 Mtetra
.582 .487 .712 r
.52662 .17728 .53309 .19974 .54506 .19566 .53858 .17402 Mtetra
.581 .493 .72 r
.53858 .17402 .54506 .19566 .55708 .19174 .55059 .17092 Mtetra
.579 .499 .728 r
.55059 .17092 .55708 .19174 .56917 .18798 .56267 .16799 Mtetra
.578 .506 .737 r
.56267 .16799 .56917 .18798 .58132 .18434 .57482 .16521 Mtetra
.576 .514 .748 r
.57482 .16521 .58132 .18434 .59353 .18082 .58704 .16259 Mtetra
.575 .523 .759 r
.58704 .16259 .59353 .18082 .60581 .17742 .59933 .1601 Mtetra
.573 .533 .771 r
.59933 .1601 .60581 .17742 .61815 .17413 .6117 .15776 Mtetra
.571 .544 .785 r
.6117 .15776 .61815 .17413 .63056 .17098 .62414 .15557 Mtetra
.568 .556 .801 r
.62414 .15557 .63056 .17098 .64305 .16798 .63667 .15353 Mtetra
.564 .57 .818 r
.63667 .15353 .64305 .16798 .65561 .16513 .64929 .15165 Mtetra
.56 .585 .836 r
.64929 .15165 .65561 .16513 .66825 .16242 .66198 .14991 Mtetra
.554 .601 .855 r
.66198 .14991 .66825 .16242 .68097 .15985 .67477 .14831 Mtetra
.548 .62 .876 r
.67477 .14831 .68097 .15985 .69377 .15737 .68765 .1468 Mtetra
.541 .641 .898 r
.68765 .1468 .69377 .15737 .70665 .15497 .70062 .14536 Mtetra
.532 .663 .92 r
.70062 .14536 .70665 .15497 .71961 .15261 .71368 .14397 Mtetra
.762 .768 .858 r
.03496 .38178 .04273 .38856 .05324 .38174 .04559 .37441 Mtetra
.757 .754 .85 r
.04559 .37441 .05324 .38174 .06377 .37496 .05622 .36708 Mtetra
.75 .741 .843 r
.05622 .36708 .06377 .37496 .07431 .36825 .06686 .35981 Mtetra
.744 .727 .837 r
.06686 .35981 .07431 .36825 .08486 .36162 .07751 .35263 Mtetra
.737 .714 .83 r
.07751 .35263 .08486 .36162 .09541 .35512 .08816 .34557 Mtetra
.729 .701 .824 r
.08816 .34557 .09541 .35512 .10597 .34875 .09881 .33863 Mtetra
.722 .688 .817 r
.09881 .33863 .10597 .34875 .11653 .34253 .10947 .33182 Mtetra
.714 .675 .811 r
.10947 .33182 .11653 .34253 .12709 .33645 .12012 .32516 Mtetra
.706 .663 .804 r
.12012 .32516 .12709 .33645 .13767 .33051 .13079 .31863 Mtetra
.699 .65 .798 r
.13079 .31863 .13767 .33051 .14825 .32472 .14145 .31224 Mtetra
.692 .639 .791 r
.14145 .31224 .14825 .32472 .15885 .31905 .15213 .30598 Mtetra
.685 .627 .785 r
.15213 .30598 .15885 .31905 .16946 .31353 .16281 .29987 Mtetra
.677 .616 .779 r
.16281 .29987 .16946 .31353 .18008 .30817 .17351 .29391 Mtetra
.671 .605 .773 r
.17351 .29391 .18008 .30817 .19072 .30296 .18421 .28809 Mtetra
.664 .594 .767 r
.18421 .28809 .19072 .30296 .20137 .29791 .19493 .2824 Mtetra
.659 .584 .76 r
.19493 .2824 .20137 .29791 .21205 .29295 .20568 .27675 Mtetra
.656 .575 .752 r
.20568 .27675 .21205 .29295 .22276 .28801 .21646 .27107 Mtetra
.656 .568 .744 r
.21646 .27107 .22276 .28801 .23353 .28284 .2273 .26513 Mtetra
.659 .562 .734 r
.2273 .26513 .23353 .28284 .24437 .27726 .2382 .25879 Mtetra
.663 .558 .726 r
.2382 .25879 .24437 .27726 .2553 .27099 .24918 .2519 Mtetra
.669 .556 .718 r
.24918 .2519 .2553 .27099 .26633 .26391 .26023 .24443 Mtetra
.67 .554 .714 r
.26023 .24443 .26633 .26391 .27742 .25629 .27132 .23673 Mtetra
.667 .552 .715 r
.27132 .23673 .27742 .25629 .28855 .24845 .28242 .22918 Mtetra
.653 .546 .721 r
.28242 .22918 .28855 .24845 .29964 .24145 .29346 .22264 Mtetra
.63 .537 .73 r
.29346 .22264 .29964 .24145 .31064 .23587 .30442 .21758 Mtetra
.597 .523 .742 r
.30442 .21758 .31064 .23587 .32155 .23228 .3153 .21425 Mtetra
.564 .506 .75 r
.3153 .21425 .32155 .23228 .33239 .23051 .32613 .21241 Mtetra
.56 .504 .75 r
.32613 .21241 .33239 .23051 .34328 .22904 .33701 .2107 Mtetra
.576 .512 .746 r
.33701 .2107 .34328 .22904 .35427 .22692 .348 .2083 Mtetra
.613 .531 .738 r
.348 .2083 .35427 .22692 .36542 .22275 .35914 .20409 Mtetra
.646 .55 .732 r
.35914 .20409 .36542 .22275 .37672 .21654 .37042 .19808 Mtetra
.659 .559 .731 r
.37042 .19808 .37672 .21654 .38808 .20966 .38177 .19136 Mtetra
.658 .56 .733 r
.38177 .19136 .38808 .20966 .39945 .20308 .39314 .18477 Mtetra
.631 .545 .739 r
.39314 .18477 .39945 .20308 .41079 .19832 .40448 .17967 Mtetra
.595 .522 .742 r
.40448 .17967 .41079 .19832 .4221 .19556 .4158 .17631 Mtetra
.561 .496 .74 r
.4158 .17631 .4221 .19556 .43343 .19425 .42712 .17445 Mtetra
.536 .477 .736 r
.42712 .17445 .43343 .19425 .4448 .19378 .43848 .17361 Mtetra
.533 .472 .733 r
.43848 .17361 .4448 .19378 .45626 .19311 .44992 .17293 Mtetra
.537 .475 .734 r
.44992 .17293 .45626 .19311 .4678 .19189 .46143 .17203 Mtetra
.551 .487 .737 r
.46143 .17203 .4678 .19189 .47943 .18987 .47303 .17055 Mtetra
.564 .5 .742 r
.47303 .17055 .47943 .18987 .49113 .18715 .48471 .16851 Mtetra
.574 .514 .75 r
.48471 .16851 .49113 .18715 .5029 .18401 .49646 .16607 Mtetra
.581 .526 .758 r
.49646 .16607 .5029 .18401 .51473 .18063 .50828 .16338 Mtetra
.583 .535 .767 r
.50828 .16338 .51473 .18063 .52662 .17728 .52016 .16065 Mtetra
.583 .543 .776 r
.52016 .16065 .52662 .17728 .53858 .17402 .53211 .15797 Mtetra
.581 .55 .785 r
.53211 .15797 .53858 .17402 .55059 .17092 .54413 .15542 Mtetra
.578 .557 .795 r
.54413 .15542 .55059 .17092 .56267 .16799 .55622 .15302 Mtetra
.574 .563 .804 r
.55622 .15302 .56267 .16799 .57482 .16521 .56838 .15078 Mtetra
.57 .57 .814 r
.56838 .15078 .57482 .16521 .58704 .16259 .58062 .14868 Mtetra
.566 .578 .824 r
.58062 .14868 .58704 .16259 .59933 .1601 .59293 .14673 Mtetra
.561 .586 .835 r
.59293 .14673 .59933 .1601 .6117 .15776 .60533 .14493 Mtetra
.556 .594 .847 r
.60533 .14493 .6117 .15776 .62414 .15557 .61781 .14327 Mtetra
.55 .602 .859 r
.61781 .14327 .62414 .15557 .63667 .15353 .63037 .14176 Mtetra
.543 .611 .871 r
.63037 .14176 .63667 .15353 .64929 .15165 .64302 .1404 Mtetra
.536 .62 .883 r
.64302 .1404 .64929 .15165 .66198 .14991 .65577 .13917 Mtetra
.527 .629 .895 r
.65577 .13917 .66198 .14991 .67477 .14831 .6686 .13807 Mtetra
.519 .639 .908 r
.6686 .13807 .67477 .14831 .68765 .1468 .68154 .13707 Mtetra
.511 .65 .92 r
.68154 .13707 .68765 .1468 .70062 .14536 .69457 .13614 Mtetra
.503 .661 .932 r
.69457 .13614 .70062 .14536 .71368 .14397 .70769 .13525 Mtetra
.762 .768 .858 r
.02714 .37496 .03496 .38178 .04559 .37441 .0378 .36756 Mtetra
.761 .768 .859 r
.0378 .36756 .04559 .37441 .05622 .36708 .04846 .36021 Mtetra
.759 .769 .861 r
.04846 .36021 .05622 .36708 .06686 .35981 .05913 .35294 Mtetra
.757 .769 .863 r
.05913 .35294 .06686 .35981 .07751 .35263 .06981 .34575 Mtetra
.755 .77 .865 r
.06981 .34575 .07751 .35263 .08816 .34557 .08049 .33867 Mtetra
.753 .77 .867 r
.08049 .33867 .08816 .34557 .09881 .33863 .09117 .3317 Mtetra
.75 .77 .869 r
.09117 .3317 .09881 .33863 .10947 .33182 .10186 .32484 Mtetra
.746 .769 .871 r
.10186 .32484 .10947 .33182 .12012 .32516 .11256 .31811 Mtetra
.743 .767 .873 r
.11256 .31811 .12012 .32516 .13079 .31863 .12326 .31149 Mtetra
.739 .765 .874 r
.12326 .31149 .13079 .31863 .14145 .31224 .13396 .30499 Mtetra
.735 .763 .875 r
.13396 .30499 .14145 .31224 .15213 .30598 .14468 .29861 Mtetra
.731 .76 .875 r
.14468 .29861 .15213 .30598 .16281 .29987 .15541 .29236 Mtetra
.727 .756 .875 r
.15541 .29236 .16281 .29987 .17351 .29391 .16615 .28623 Mtetra
.723 .751 .875 r
.16615 .28623 .17351 .29391 .18421 .28809 .1769 .28021 Mtetra
.718 .746 .874 r
.1769 .28021 .18421 .28809 .19493 .2824 .18767 .27429 Mtetra
.716 .74 .871 r
.18767 .27429 .19493 .2824 .20568 .27675 .19847 .2684 Mtetra
.715 .734 .867 r
.19847 .2684 .20568 .27675 .21646 .27107 .20929 .26247 Mtetra
.717 .73 .861 r
.20929 .26247 .21646 .27107 .2273 .26513 .22017 .25639 Mtetra
.721 .728 .856 r
.22017 .25639 .2273 .26513 .2382 .25879 .23109 .25007 Mtetra
.728 .731 .853 r
.23109 .25007 .2382 .25879 .24918 .2519 .24207 .24345 Mtetra
.736 .741 .855 r
.24207 .24345 .24918 .2519 .26023 .24443 .2531 .23658 Mtetra
.74 .758 .867 r
.2531 .23658 .26023 .24443 .27132 .23673 .26415 .22974 Mtetra
.739 .782 .888 r
.26415 .22974 .27132 .23673 .28242 .22918 .2752 .22322 Mtetra
.72 .811 .922 r
.2752 .22322 .28242 .22918 .29346 .22264 .28621 .21752 Mtetra
.677 .831 .958 r
.28621 .21752 .29346 .22264 .30442 .21758 .29717 .21291 Mtetra
.615 .831 .983 r
.29717 .21291 .30442 .21758 .3153 .21425 .30809 .20942 Mtetra
.56 .808 .991 r
.30809 .20942 .3153 .21425 .32613 .21241 .319 .20684 Mtetra
.571 .786 .98 r
.319 .20684 .32613 .21241 .33701 .2107 .32997 .20427 Mtetra
.608 .77 .958 r
.32997 .20427 .33701 .2107 .348 .2083 .34102 .20119 Mtetra
.661 .767 .928 r
.34102 .20119 .348 .2083 .35914 .20409 .3522 .19695 Mtetra
.702 .778 .911 r
.3522 .19695 .35914 .20409 .37042 .19808 .36348 .19155 Mtetra
.72 .803 .916 r
.36348 .19155 .37042 .19808 .38177 .19136 .37483 .18563 Mtetra
.721 .83 .932 r
.37483 .18563 .38177 .19136 .39314 .18477 .38621 .17973 Mtetra
.685 .846 .96 r
.38621 .17973 .39314 .18477 .40448 .17967 .39758 .17473 Mtetra
.628 .835 .98 r
.39758 .17473 .40448 .17967 .4158 .17631 .40896 .17085 Mtetra
.573 .798 .984 r
.40896 .17085 .4158 .17631 .42712 .17445 .42035 .16808 Mtetra
.537 .751 .975 r
.42035 .16808 .42712 .17445 .43848 .17361 .43177 .16614 Mtetra
.534 .713 .954 r
.43177 .16614 .43848 .17361 .44992 .17293 .44325 .16452 Mtetra
.54 .687 .934 r
.44325 .16452 .44992 .17293 .46143 .17203 .4548 .16295 Mtetra
.556 .675 .918 r
.4548 .16295 .46143 .17203 .47303 .17055 .46643 .16112 Mtetra
.57 .673 .908 r
.46643 .16112 .47303 .17055 .48471 .16851 .47813 .159 Mtetra
.58 .676 .906 r
.47813 .159 .48471 .16851 .49646 .16607 .48991 .15664 Mtetra
.585 .681 .907 r
.48991 .15664 .49646 .16607 .50828 .16338 .50175 .15412 Mtetra
.585 .687 .912 r
.50175 .15412 .50828 .16338 .52016 .16065 .51366 .15157 Mtetra
.583 .692 .917 r
.51366 .15157 .52016 .16065 .53211 .15797 .52564 .14906 Mtetra
.577 .695 .922 r
.52564 .14906 .53211 .15797 .54413 .15542 .53768 .14664 Mtetra
.57 .697 .927 r
.53768 .14664 .54413 .15542 .55622 .15302 .5498 .14435 Mtetra
.563 .698 .931 r
.5498 .14435 .55622 .15302 .56838 .15078 .56199 .14218 Mtetra
.556 .698 .935 r
.56199 .14218 .56838 .15078 .58062 .14868 .57426 .14015 Mtetra
.549 .698 .938 r
.57426 .14015 .58062 .14868 .59293 .14673 .58661 .13824 Mtetra
.542 .697 .94 r
.58661 .13824 .59293 .14673 .60533 .14493 .59903 .13646 Mtetra
.534 .695 .942 r
.59903 .13646 .60533 .14493 .61781 .14327 .61154 .13481 Mtetra
.527 .693 .944 r
.61154 .13481 .61781 .14327 .63037 .14176 .62414 .13329 Mtetra
.521 .69 .945 r
.62414 .13329 .63037 .14176 .64302 .1404 .63683 .13189 Mtetra
.514 .687 .945 r
.63683 .13189 .64302 .1404 .65577 .13917 .6496 .13061 Mtetra
.509 .683 .945 r
.6496 .13061 .65577 .13917 .6686 .13807 .66247 .12944 Mtetra
.504 .68 .945 r
.66247 .12944 .6686 .13807 .68154 .13707 .67543 .12837 Mtetra
.5 .677 .944 r
.67543 .12837 .68154 .13707 .69457 .13614 .68849 .12739 Mtetra
.497 .674 .944 r
.68849 .12739 .69457 .13614 .70769 .13525 .70165 .12647 Mtetra
.749 .767 .868 r
.01926 .36808 .02714 .37496 .0378 .36756 .02985 .36128 Mtetra
.751 .785 .88 r
.02985 .36128 .0378 .36756 .04846 .36021 .04045 .35457 Mtetra
.754 .805 .894 r
.04045 .35457 .04846 .36021 .05913 .35294 .05106 .34795 Mtetra
.755 .826 .907 r
.05106 .34795 .05913 .35294 .06981 .34575 .06167 .34142 Mtetra
.755 .848 .92 r
.06167 .34142 .06981 .34575 .08049 .33867 .07229 .33498 Mtetra
.753 .869 .933 r
.07229 .33498 .08049 .33867 .09117 .3317 .08293 .32863 Mtetra
.748 .89 .943 r
.08293 .32863 .09117 .3317 .10186 .32484 .09357 .32237 Mtetra
.741 .909 .951 r
.09357 .32237 .10186 .32484 .11256 .31811 .10423 .31619 Mtetra
.73 .926 .956 r
.10423 .31619 .11256 .31811 .12326 .31149 .11491 .31011 Mtetra
.716 .94 .958 r
.11491 .31011 .12326 .31149 .13396 .30499 .1256 .30411 Mtetra
.699 .95 .956 r
.1256 .30411 .13396 .30499 .14468 .29861 .1363 .2982 Mtetra
.678 .955 .949 r
.1363 .2982 .14468 .29861 .15541 .29236 .14703 .29238 Mtetra
.653 .957 .939 r
.14703 .29238 .15541 .29236 .16615 .28623 .15777 .28665 Mtetra
.626 .954 .925 r
.15777 .28665 .16615 .28623 .1769 .28021 .16853 .281 Mtetra
.597 .948 .908 r
.16853 .281 .1769 .28021 .18767 .27429 .17931 .27544 Mtetra
.565 .937 .887 r
.17931 .27544 .18767 .27429 .19847 .2684 .19012 .26997 Mtetra
.526 .921 .858 r
.19012 .26997 .19847 .2684 .20929 .26247 .20095 .26458 Mtetra
.475 .894 .815 r
.20095 .26458 .20929 .26247 .22017 .25639 .2118 .25928 Mtetra
.401 .846 .745 r
.2118 .25928 .22017 .25639 .23109 .25007 .22268 .25407 Mtetra
0 0 0 r
.22268 .25407 .23109 .25007 .24207 .24345 .23359 .24894 Mtetra
.23359 .24894 .24207 .24345 .2531 .23658 .24453 .2439 Mtetra
.24453 .2439 .2531 .23658 .26415 .22974 .25549 .23895 Mtetra
.066 0 0 r
.25549 .23895 .26415 .22974 .2752 .22322 .26649 .23408 Mtetra
.136 0 0 r
.26649 .23408 .2752 .22322 .28621 .21752 .27752 .2293 Mtetra
.171 0 0 r
.27752 .2293 .28621 .21752 .29717 .21291 .28858 .22461 Mtetra
.175 0 0 r
.28858 .22461 .29717 .21291 .30809 .20942 .29968 .22 Mtetra
.149 0 0 r
.29968 .22 .30809 .20942 .319 .20684 .31081 .21548 Mtetra
.086 0 0 r
.31081 .21548 .319 .20684 .32997 .20427 .32198 .21104 Mtetra
.006 0 0 r
.32198 .21104 .32997 .20427 .34102 .20119 .33319 .20669 Mtetra
0 0 0 r
.33319 .20669 .34102 .20119 .3522 .19695 .34444 .20243 Mtetra
.34444 .20243 .3522 .19695 .36348 .19155 .35573 .19825 Mtetra
.032 0 0 r
.35573 .19825 .36348 .19155 .37483 .18563 .36707 .19416 Mtetra
.122 0 0 r
.36707 .19416 .37483 .18563 .38621 .17973 .37845 .19016 Mtetra
.192 0 0 r
.37845 .19016 .38621 .17973 .39758 .17473 .38988 .18625 Mtetra
.225 0 0 r
.38988 .18625 .39758 .17473 .40896 .17085 .40135 .18242 Mtetra
.232 0 0 r
.40135 .18242 .40896 .17085 .42035 .16808 .41288 .17868 Mtetra
.214 0 0 r
.41288 .17868 .42035 .16808 .43177 .16614 .42446 .17503 Mtetra
.171 0 0 r
.42446 .17503 .43177 .16614 .44325 .16452 .43608 .17146 Mtetra
.105 0 0 r
.43608 .17146 .44325 .16452 .4548 .16295 .44777 .16799 Mtetra
.017 0 0 r
.44777 .16799 .4548 .16295 .46643 .16112 .4595 .1646 Mtetra
0 0 0 r
.4595 .1646 .46643 .16112 .47813 .159 .4713 .1613 Mtetra
.4713 .1613 .47813 .159 .48991 .15664 .48316 .15809 Mtetra
.205 .726 .716 r
.48316 .15809 .48991 .15664 .50175 .15412 .49507 .15497 Mtetra
.241 .756 .767 r
.49507 .15497 .50175 .15412 .51366 .15157 .50705 .15194 Mtetra
.268 .775 .806 r
.50705 .15194 .51366 .15157 .52564 .14906 .51909 .149 Mtetra
.289 .789 .837 r
.51909 .149 .52564 .14906 .53768 .14664 .5312 .14615 Mtetra
.311 .801 .866 r
.5312 .14615 .53768 .14664 .5498 .14435 .54338 .14339 Mtetra
.334 .811 .895 r
.54338 .14339 .5498 .14435 .56199 .14218 .55563 .14073 Mtetra
.358 .82 .923 r
.55563 .14073 .56199 .14218 .57426 .14015 .56795 .13815 Mtetra
.383 .825 .948 r
.56795 .13815 .57426 .14015 .58661 .13824 .58034 .13567 Mtetra
.407 .827 .969 r
.58034 .13567 .58661 .13824 .59903 .13646 .59281 .13328 Mtetra
.431 .824 .985 r
.59281 .13328 .59903 .13646 .61154 .13481 .60536 .13099 Mtetra
.452 .816 .995 r
.60536 .13099 .61154 .13481 .62414 .13329 .61799 .12879 Mtetra
.47 .804 .999 r
.61799 .12879 .62414 .13329 .63683 .13189 .6307 .12668 Mtetra
.486 .789 .998 r
.6307 .12668 .63683 .13189 .6496 .13061 .64349 .12467 Mtetra
.499 .77 .992 r
.64349 .12467 .6496 .13061 .66247 .12944 .65637 .12276 Mtetra
.509 .749 .982 r
.65637 .12276 .66247 .12944 .67543 .12837 .66935 .12094 Mtetra
.516 .728 .97 r
.66935 .12094 .67543 .12837 .68849 .12739 .68241 .11923 Mtetra
.52 .707 .956 r
.68241 .11923 .68849 .12739 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Nooooo`;oQ;[h1?n5]?@00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo057ooooo001Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool07Oooool3o`0000;ooooo00?o0000ooooooooool0Dooo
ool3ogo5o@CoP[ok1On4^_P3ohFdm003o`000?n5]?Cooooo01Gooooo00?o0000ooooooooool0D?oo
ool0063ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00007?ooool2o`0005?ooooo0omh
cOl4ogc9o`GoOlGm1?n2_o/5ohBjn0;oQKCd00?o0000ogn/lOooool05?ooool00ol0003oooooo`00
001Aooooo`00H?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
6_ooool3o`00057ooooo0omcd?h5ogS=o`CoO<Wo0_moaOd2oh:^l@CoPJka1_mo[O401?mo[?7o0000
ogn/lOmo[?4Fooooo`03o`000?oooooooooo04oooooo001Pooooo`05o`000?ooooooooooooooool0
00002oooool01?oMgMgoEEEEooooool0000Hooooo`;o0000D?ooool4ofkBo0CoLm3n0_mhcOl2ohF`
l@GoPjoa1?n2[_44oh6^l@KoOjga00Co0000ogn/lOmo[?7oOjca5_ooool00ol0003oooooooooo`1>
ooooo`00H?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000005Oooool3
o`0000;ooooo00?o0000ooooooooool0AOooool4of;ClPCoJ=?h0_m^d_`2ohRal@GoQ[7a1?n5/?45
oh>_l@CoPZka1?n1[_43ogn]l@;oPZK[00Co0000oh2Yk_n0ZNkoP:W^5_ooool00ol0003ooooooooo
o`1>ooooo`00H?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000004ooo
ool2o`0004Wooooo1?mKdN`2of;ClP;oS;;`1On:/_04ohRal@GoQ[7a1?n5/?42oh>_l@;oRIkR1?n6
XND4ohBSj0GoPZK[00?o0000oh2Yk_n0ZNh00_n0ZNhFooooo`03o`000?oooooooooo04gooooo001P
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0?ooooo`?o0000B?oo
ool2oeG?i@;oT;;^1?n>/^l4ohbbl0GoR[;`1?n8/O42ohJal@;oS9[K1?n;W=h5ohVNhPCoQZ7U1?n4
XnP4oh:Vj`03o`000?n0ZNkoP:W^00?oP:W^5_ooool00ol0003oooooooooo`1<ooooo`00P_ooool2
o`0004Oooooo0_m?cMd2oi6bk@GoT;;^1?n>/^l4ohbbl0;oR[;`0_n?U]D4ohjHf0GoS9[K1?n;W=h4
ohVNhPGoQZ7U1?n4XnP2oh:Vj`03ohZTiOl0003oR:W[00CoR:W[5_ooool00ol0003oooooooooo`1<
ooooo`00Ooooool3o`0000;ooooo00?o0000ooooooooool0@?ooool2odW9eP;oTk7/1OnA/^d5oi2b
kP;oS[;_00?oTI7@oi2Cd_n@Tm800_n@Tm85ohnFe@CoSYSH1?n<V]/5oh^LgPCoRIkR0_n6XND2ohfI
fPCoS9kP0on:Y>D00ol0003oRZCUohRYj`04ohRYjaCooooo0ol0001=ooooo`00O?ooool3o`00043o
oooo0_lm`L@2oiF_j@GoUK7Z1?nC/N`5oi6bk@;oT;;^0_nBT<d4oi6Ad0CoT9?B1?n?U]D4ohjHf0Go
S9[K0_n;W=h2oi2Ad@CoSiGF1On=VMX4ohbNh0;oRZCU00?o0000ohZTiOn:Y>D01?n8ZN/Gooooo`03
o`000?oooooooooo04[ooooo001jooooo`;o0000?oooool3ocBi]`03oiF^j?nE[nWoUJoY00?oUJoY
1OnE/NX4oi>ak0;oTK;]0_nCS//5oi:@c@?oTI7@1?n@Tm85ohnFe@CoSYSH0_n<V]/2oi6>c@GoT97A
1?n?UMH4ohfIfPGoS9kP0_n:Y>D00ol0003oU:CPoi>/j004oi>/j1Kooooo00?o0000ooooooooool0
B_ooool007Oooooo0ol0000nooooo`;o00000_nD[NL4oiF^j0GoUJoY0_nE/NX2oiF;aPCoU8c81OnC
S//4oi:@c@?oTI7@1On@Tm82ohnFe@;oTXS51?nBRlP5oi6>c@CoT97A1?n?UMH5ohfIfP;oS9kP0_nE
W=T2oiBTh003o`000?nDY>3oU:CP00GoTjcX5_ooool00ol0003oooooooooo`19ooooo`00MOooool2
o`0000;ooooo00?o0000ooooooooool0=_ooool00ol4003o0000oi6/j003oi6/j0GoU:gW1?nE[^P2
oiF_j@;oUHS41OnERlH4oiB<b0CoThk;1?nBT<d4oi6Ad0;oT9?B0_nCQL85oi:8a@CoTX_81?nAS/d4
oi2Ad@GoSiGF0_n=VMX2oiFFdPGoUIcI00CoU:CPo`000?nDY>3oU:CP1?nC[>P00onO/^Gooooooooo
o`0Eooooo`03o`000?oooooooooo04Sooooo001booooo`?o00001Oooool00ol0003oooooooooo`0^
ooooo`;o:`000olJ00000ol4003oSZc[ohj/j`02ohj/j`CoTJcX1OnD[NL2oiF^j003oiB6`_nER<Co
UHS400?oUHS41?nERlH4oiB<b0CoThk;1OnBT<d2oi6Ad003oi>3_onCQL;oThG200?oThG21?nBR<D4
oi:;b0CoTHk=1On@TM42ohnEeP;oUY7<1OnEU]84oiFLf@03oiBTh?l0003oU:CP00;oU:CP00?oTjcX
oinbiOnO/^D00_nO/^DFooooo`03o`000?oooooooooo04Sooooo001`ooooo`;o0000=_ooool00olf
003o:`00ob/00002ob/000;o6P000on:[nl4ohj/j`CoTJcX0_nD[NL2oi:3_`CoU8K21?nER<@4oiF;
aPGoU8c81?nCS//2oi:@c@;oTh6l1?nCPkl4oi>5`PCoTXS51?nBRlP5oi6>c@;oT97A0_nFS<L5oiJA
c0CoUIKB1OnEW=T01?l0003oU:CPoinXgOnOZ=d6oinbiAKooooo00?o0000ooooooooool0Aoooool0
03Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00023ooooo0ol0000a
ooooo`03ocT00?lk003o>`0000;o>`000olf0003ob/00003oaX00?n8]_CoR;Kd00CoRZo_0_n>[>/0
0on=O;coT7nmoi1o_@02oi1o_@GoTX>o0onDQ/84oiF8a0GoUH_60_nDS<P2oiAn^0CoU7nj1OnCPK`3
oi>3_`CoThG21OnBR<D4oi:;b0;oTHk=0_nFR<85oiJ<a`CoUY7<1OnEU]82oiFLf@;oWj7F00?o0000
oinXgOnOZ=d00_nOZ=d4oinbi@03ojbhhooooooooooo01?ooooo0ol00018ooooo`00>?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@07_oo
ool2o`0000?ooooo00?o0000ooooooooool0;?ooool3ocT000?o>`000olf00000ol[003oRL3iohUj
_004ohQh^`CoRGVk0on=O;`5oi1o_@CoTX>o0onDQ/85oiF8a0?oUH_600?oU7bfoiAn^?nDO[P00_nD
O[P5oiAo^PCoTh6l0onCPkl5oi>5`PCoTXS50_nBRlP2oiJ4_PGoUXS21?nFS<L5oiJAc0;oUIKB0_nN
V/l4oinQeP03o`000?nOZ=goWjSM00?oWjSM00?oWk;Uojbhhon/^><00_n/^><Fooooo`03o`000?oo
oooooooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@
4?oooooooooo02Wooooo000hooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Q
onk^kP0Looooo`?o0000<_ooool01?la003o>@00ocT00?li0003oc/00004ocH00?n?O[goSgjmohmn
_@?oRGZl1?n8N;/5ohUi^`?oSGbl1?n@Okd4oi:3_`CoU8K21?nER<@01?nERlKoU7bfoiAl]_nDO;H5
oiAn^0CoU7nj1?nCPK`4oi>3_`CoThG20_nBR<D2oiJ1^PGoUXBn1?nFR<84oiJ<a`CoUY7<00?oWYC9
oijJconNV/l00onNV/l3oinQeP04o`000?nOXMKoWjSMoinXg@;oZk3L1_n/^><Fooooo`03o`000?oo
oooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooo
ooooo`0Zooooo`00>?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
6?ooool3o`0003;ooooo00Co7`00oc400?la003o<@000oli00001?lk003oV8FmoiR5_OnHQKd4ohmn
_@?oRGZl1?n8N;/4ohUi^`?oSGbl1?n@Okd5oi:3_`?oU8K20_nER<@2oiAj]0GoU7bf1?nDO[P4oiAo
^PGoTh6l0onCPkl2oi>5`P;oUWjg1OnFPKX4oiJ4_PCoUXS21OnFS<L00onFTLcoWYC9oijDb@02oijD
b@CoWY[?0onOXMH00ol0003oZJSEoj^`g004oj^`g0Co[;SS0_nf_n4Fooooo`03o`000?oooooooooo
00Cooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000:oooool003Sooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo01Gooooo0ol0000booooo`?o7`000_la0000
0oli003oXH^moj6;_@02oj6;_@?oV8Fm1?n?O[d3ohUj_0CoR7Rk1?n9NK/3ohel_0GoT7nm1?nBPkl2
oiB6`P03oiAi/_nDN[CoU7Zd00;oU7Zd1OnDO;H4oiAn^0GoU7nj1?nCPK`2oi>3_`03oiEl]?nFO[Oo
UWjg00?oUWjg1?nFPKX4oiJ4_PGoUXS20_nFS<L2oif?a0GoWYC91OnNV/l00onOXMKoZJSEo`000002
ojVXe@GoZk3L00?o[;SSokJohOnf_n400onf_n4Eooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002cooooo000hooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`0Aooooo`?o00000oooool00ol0003ooooo
ooooo`0]ooooo`07o`P00?lO003o7`00oal00?la003o^=C^ojR?^`05oj6;_@?oV8Fm1?n?O[d3ohUj
_0CoR7Rk1On9NK/3ohel_0CoT7nm0_nBPkl2oi9f/0CoU7Vb1?nDN[@4oiAl]PGoU7jh1?nDOkX2oi>1
_0;oUGZb1?nEO;@4oiIn]`CoUX6j1OnFQ;h2oiJ8`P;oWH^o1OnMSl@4oijDb@CoWY[?00CoZ:;@ojVX
eOnYZ=Go00000_nYZ=D4oj^`g003okBig?nf_n7o][oQ00?o][oQ00?o_LKRooooooooool05?ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEoooo
ool0000/ooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@400Aooooo`;o0000=Oooool2o`P000;o7`0000?o^=C^ojR?^onXSk/00_nXSk/4oj6;_@Co
V8Fm1?n?O[d3ohUj_0CoR7Rk1?n9NK/3ohel_0;oT7nm0_n@Ljh4oi9f/0CoU7Vb1?nDN[@5oiAl]PCo
U7jh0_nDOkX2oiEh/0CoUGZb1?nEO;@4oiIn]`GoUX6j0onFQ;h00onLQkcoWH^ooif;_`03oif;_`Co
WHo41OnNU<T00onNV/ooZ:;@ojRRd002ojRRd003ojVXeOl0003oZJSE00;oZJSE00?oZk3LokBig?nd
^M`00_nd^M`3okJoh@?o_LKR5_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00omgMgOoc<c<o`00000/ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00>ooooo`?o0000=Oooool3o`P00003oal00?nhcN[o
Z8nk00GoZ8nk1OnQRkd3oiR5_@CoSgjm0on9N[`4ohQh^`;oRGVk0_n9JjX3ohe_[0CoT7>^1OnBM[04
oiAi/P?oU7Zd1OnDO;H2oiAn^0;oUGN^1?nEN;05oiEj/PCoUGbd1?nFO[L4oiJ1^P03oiJ4__nLQkco
W8Nl00;oW8Nl1?nMRkl4oif?a0CoWYC900?oYic;ojRRd?nXX]000onXX]001OnYZ=Go0000ojVXeOnY
Z=Go/k?H00Ko];WL00?o][oQokg6h_nma^800onma^8Dooooo`;o00001?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000;?ooool005Wooooo0ol0000eooooo`03o`000?l8
003o/lOY00;o/lOY00?o^<gZojR?^onXSk/01OnXSk/5oj6;_@;oV8Fm00?oSffXohUYZ?n9JJP00_n9
JJP3ohIWZ0CoQfVY1?n9JjX3ohe_[0GoT7>^1?nBM[04oiAi/PCoU7Zd0onDO;H00onEMZgoUGN^oiEg
[P02oiEg[PGoUGR`1?nEN[84oiEl]0CoUWjg0_nFPKX2oi^3^@GoW8Nl1?nMRkl5oif?a003oijDbOnW
W<_oYic;00;oYic;1OnXX]000ol0003o/k?Hok>cf002ok>cf0Co];WL0_nmaN04okg6hP03oko<hooo
oooooooo017ooooo00Co0000oooooooooooo00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00go
oooo00?oMgMgo`000?ooool0:oooool005Kooooo0ol00003ooooo`03o`000?oooooooooo02oooooo
00?o0000ojW4kOnYa>d01?ncanT00onUS;_oZ8nkojR?^`07ojR?^`?oXH^m00CoUW:Xohm]Z?n?KJSo
SffX1?n9JJP3ohIWZ0CoQfVY1On9JjX3ohe_[0CoT7>^1?nBM[04oiAi/PCoU7Zd00CoU7bfoiEf[OnE
MZgoUGJ]1OnEMjh4oiEh/0CoUGZb1?nEO;@3oiIn]`03oi^1]_nKPkWoVh>i00?oVh>i1?nLQk`5oif;
_`;oWHo40_nVUlH5ojNLb`CoZ:;@00?o/ZkDo`000?nc/mP01?nc/mP00ond^Mco_LGPokg5h003okg5
h003okg6h_noc>?o_lcS00;o_lcS5_ooool00ol0003oooooooooo`10ooooo`00E?ooool2o`0003Go
oooo00?o0@00oi_5mOnKaOD01?nYa>d00oncanWoYHbkojF<^`02ojF<^`SoZ8nk00CoXH^moiIbZ?nF
LZSoUW:X1?n?KJP4ohUYZ0?oQVNX1?n7JJT4ohU[ZP?oSFn/1?n@Ljh5oi9f/0CoU7Vb0_nDN[@00onE
M:coUGJ]oiEf[@03oiEf[@CoUGN^1?nEN;05oiEj/PCoUGbd00CoUWjgoi^1]_nKPKKoVh6f1?nKPkT5
oib7_0?oWH^o00?oYI?2ojJGa_nVUlH00onVUlH5ojNLb`05ojRRd?nb[]Co/ZkDok:^e?l000001?nc
/mP00onm`moo_LGPokg5h003okg5h003ol7?iOnoc>?o_lcS00?o_lcS5_ooool00ol0003ooooooooo
o`10ooooo`00DOooool3o`0003?ooooo00Co5P00o`400?l1003o0@001?nKaOD2ojW4k@03oib7_?nU
S;_oYHbk00?oYHbk1onXSk/00onLMZOoUW:XoiIbZ002oiIbZ0CoSffX1?n9JJP3ohIWZ0CoQfVY1?n9
JjX3ohe_[0CoT7>^1OnBM[02oiAi/P;oUG>Z0onEM:`5oiEf[@CoUGN^1?nEN;05oiEj/P;oUGbd0_nJ
O[<4oi^1]PCoVh>i1OnLQk`00onMRkooYI?2ojFC`P02ojFC`PCoYYO61?nWW</00onaZ]3o/ZkDok:^
e002ok:^e003o`000?nb[]Co/k?H00Co_L?O0onmaN03ol7?i@?o_lcS0_nnd>PFooooo`03o`000?oo
oooooooo03oooooo001>ooooo`Go0000<Oooool01?lV003o5P00oaH00?l10003oi;9nP;oVlGe0_nC
Pkh4oib7_0CoYHbk1OnXSk/3oiafY`CoUW:X1?n?KJP4ohUYZ0?oQVNX1?n7JJT4ohU[ZP?oSFn/1On@
Ljh3oi9f/003oiAaZOnELj[oUG>Z00;oUG>Z1?nEM:`4oiEf[@CoUGN^1OnEN;03oiEj/P03oiUl/OnJ
O[?oVWjc00;oVWjc1OnKPKH4oi^3^@?oW8Nl00?oY92oojFC`_nUTl800onUTl85ojJGaP03ojNLbona
Z]3o/J[@00;o/J[@0onb[]@00ol0003o_L;Nokg3g`05okg3g`03okg5h?o1cnGo`LoU00?o`LoU00?o
_lcSokk@j?nnd>P00_nnd>PFooooo`03o`000?oooooooooo03kooooo001<ooooo`;o00001Oooool0
0ol0003oooooooooo`0[ooooo`04ob`00?lV003o9P00obH000?oSlkm0_nBbOX00on?PKooTh>noi>3
_P03oi>3_P?oW8Nl1OnUS;/2ojR?^`03oiegYonLMZOoW7JW00?oW7JW0onFLZP4ohm]Z0CoRFVX0on6
IjP4ohMYZ@CoRF^Z1?n=Kj`4oi1c[P04oi9f/?nDLJWoU76YoiAaZ@GoUG>Z0onEM:`4oiEf[@GoUGN^
1?nEN;001?nEN[;oVGbaoiUl/OnIO;45oiYn/`CoVh6f1?nKPkT00onLQkcoY92oojB@_`02ojB@_`Co
YI?21?nVUlH00onaY/go/J[@ok6Zd003ok6Zd0?o/ZkD00?o0000okg2g_nm`]h01?nm`ml2ol7Bi`Co
`LoU00?o_mW]okk@j?nnd>P00_nnd>P00ongd>goooooooooo`0Dooooo`03o`000?oooooooooo03ko
oooo0019ooooo`?o0000<Oooool2ob/000;o;0000olV0004oi21_`CoSh6o1?nCPkh3oib7_0GoYHbk
00?oZ8nkoiegYonMMjL01OnLMZL4oiIbZ0?oSffX1?n9JJP3ohIWZ0CoQfVY1On9JjX3ohe_[0;oT7>^
0_nBKjL5oiAaZ@CoUG>Z0onEM:`4oiEf[@GoUGN^0_nEN;02oiUj[`GoVGba1?nJO[<4oi^1]P?oVh>i
00?oXhblojB@_onTT;l00onTT;l5ojFC`P03ojJGa_naY/go/JK=00;o/JK=1OnaZ]001?nb[]Co_L;N
okg2g_l00002okg2gP03okg3goo1d^Oo`M;W00?o`M;W00?o`LoUokoIkOnofNd00_nofNd00onnd>So
]m3]okO@k@02okO@kACooooo0ol0000oooooo`008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^023o
oooo0_l0000aooooo`03ob800?l[003o:`0000;o:`0000?o;000obH00?nHQKd00onHQKd4oi21_`?o
Sh6o1?nCPkh4oib7_0?oYHbk00?oVgJXoiegYonMMjL00_nMMjL4oiafY`CoUW:X1?n?KJP4ohUYZ0?o
QVNX1?n7JJT4ohU[ZP;oSFn/00?oT6bUoi9_YonBKjL00_nBKjL5oiAaZ@CoUG>Z0onEM:`5oiEf[@?o
UGN^00?oVGV^oiUj[onINZl00_nINZl5oiUl/@CoVWjc1OnKPKH01?nKPkWoXhbloj><_?nSS;`4ojB@
_`CoYI?200?o/:?;ok6VcOnaY/d00onaY/d4ok6Zd0Co_L;N00Co0000okg2g_o2enWo`]OY1?o1d^L0
0onoho7o_mW]okoIk@02okoIk@;o]]cc1Ongd>dEooooo`03o`000?oooooooooo03gooooo000Roooo
o`05ogMgMonHV9SooooooiRHV?mgMgL07Oooool3o`0000;ooooo00?o0000ooooooooool0;Oooool2
ob8000?o:`001?nQRKX3oiR5_@CoT86o0on?PKl5oi>3_P?oW8Nl00CoYHbkoi]fZ?nKMZSoVgJX1?nM
MjL4oiafY`CoUW:X1?n?KJP4ohUYZ0?oQVNX1?n7JJT2ohU[ZP;oS6RS0on@K:D5oi9_Y`CoU76Y1?nE
LjX4oiEd[0CoUGJ]00CoUGN^oiUi[_nINJkoVGV^1OnINZl4oiUl/@GoVWjc0onKPKH00onRR[[oXhbl
oj><_002oj><_0GoY92o0_nUTl83ok2Sb`Go/JK=00?o/J[@okg2g_nm`]h01?nm`]h00ol0003o`]OY
ol;Gj@02ol;Gj@03ol7Bionoho7o_n?a00;o_n?a00?o_mW]okKLlonfg?<00onfg?<2okO@k@?oZlga
5Oooool00ol0003oooooooooo`0looooo`008_ooool01Ol@413ooooooooooooooooo410@01_ooooo
0_l0000cooooo`03oa000?lR003o8P0000?o:`001OnQRKX3oiR5_@CoT86o1?n?PKl4oi>3_P;oW8Nl
00?oU76Xoi]fZ?nKMZP00onKMZP3oiegY`CoW7JW1?nFLZP4ohm]Z0;oRFVX0_n9HIh3ohMRW`CoRFBQ
1?n<J:<4oi1/Y@CoTVnW1?nDLJT4oiEcZPCoUGB/0_nEMZd2oiUh[@GoVGV^1?nINZl4oiUl/@GoVWjc
00?oVh6foj::^_nRR[X00_nRR[X3oj><_0GoY92o00?oYI?2ok2Sbon`Xl/00_n`Xl/4ok6Vc@So_L;N
00Go0000ol;GjOo2enWo`]OYokc/m004okoSl@;o/^Oh1?nfg?<2ojSHn0GoZlga5Oooool00ol0003o
ooooooooo`0kooooo`008_ooool01Ol0003ooooooooooooooooo000001Sooooo0ol0000cooooo`?o
400000?o8P00ob/00?nhcn`00onWRkP4oj69^PCoV8Fm1?n@PKl3ohn1_`;oTh>n0_n=K:P3oiAaZ0Go
VgJX0onMMjL5oiafY`?oUW:X0_n?KJP2ohaRW@CoRF6N0on7HYl4ohUTX@GoS6RS0on@K:D4oi9_Y`Co
U76Y1OnELjX2oiEd[003oiUg[?nIN:goVGR]00;oVGR]1OnINJh4oiUj[`GoVGba0onJO[<00onQQkSo
XXZjoj::^P03oj::^PCoXhbl0onTT;l00on_X<Wo/:?;ok2Sb`03ok2Sb`?o/JK=1onm`]h2ol?Lk003
o`000?o2enWo`]OY00?o_>cd00?o_n?aok;Wn?nbioP00onbioP00onfg??oZ=ShojSHn003ojSHn0;o
Zlga0_nNa?<Eooooo`03o`000?oooooooooo03_ooooo000Rooooo`05o`000?ooooooooooooooool0
00005_ooool3o`0003?ooooo00Co0000oa000?l@003o40000_nmb><00onZSKOoYh^hojN;^002ojN;
^0GoXHVj0onHQKd2oi21_`;oS6^X0on;JZP4ohe/Z0CoU76X1?nKMZP3oiegY`GoW7JW0_nFLZP00on@
IIcoS6:MohaRW@02ohaRW@CoRF6N0on7HYl4ohUTX@GoS6RS0on@K:D4oi9_Y`GoU76Y1?nELjX00onE
M:coVGN/oiUg[005oiUh[@CoVGV^1OnINZl4oiUl/@03oiYn/onQQkSoXHNh00;oXHNh1?nRR[X4oj><
_003ojB@_on_X<Wo[j3900;o[j391On`Xl/00onaY/go_L;Nokg2gP04okg2gPCo`mc/00?o0000ol;G
jOnlk?@00_nlk?@3ojO_m`;o/^Oh0onPh_`4ojSHn003oi[<nOnNa??oW/Cc00?oW/Cc5Oooool00ol0
003oooooooooo`0jooooo`008_ooool01Ol@413ooooooooooooooooo410@01?ooooo0ol00002oooo
o`03o`000?oooooooooo033ooooo00Go0000oa000?l@003o4000okg8h`04ojZ=]`?oYh^h1OnQRKX2
oiR5_@03oi9_Yon<JjSoS6^X00;oS6^X0on;JZP4ohe/Z0CoU76X1?nKMZP4oiegY`?oW7JW00CoUFRL
oi1UW?n@IIcoT6FL1?n<HYd4ohUQWPCoQf:O1?n9I:44ohaXX`?oT6bU1?nBKjL5oiAaZ@?oUG>Z00?o
VGJ[oiUg[?nIMj`00_nIMj`4oiUh[@CoVGV^1OnINZl2oiUl/@;oX8Ff1OnQQkP5oj::^P;oXhbl00?o
[Yk7ojnPbOn_X<T00on_X<T4ok2Sb`;o_/?N1?nm`]h2ol;Rk`Co`mc/00Co0000okCdlondm??o_>cd
0onWkoL3ohoWn@CoX>;l00?oZ=Shoi[<nOnJc?T00_nJc?T4oik4laKooooo00?o0000ooooooooool0
>Oooool002;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`?o0000=_ooool2o`000004oa00
0?nm`]go_L;Mokg2g@GoZXfg1?nWRkP3oj69^P04oiUdYonBKjOoTVnWoi9_Y`CoS6^X1?n;JZP3ohe/
Z0CoU76X1?nKMZP4oiegY`04oiafYonEJ9coUFRLoiEXW0?oT6FL1On<HYd3ohUQWPCoQf:O1?n9I:44
ohaXX`?oT6bU1OnBKjL4oiAaZ@04oiEcZ_nIMZ_oVGJ[oiUfZ`CoVGN/1?nIN:d5oiUi[P?oVGZ_00?o
Wh>eoj25]_nPQKH00onPQKH4oj67^0GoXXZj00CoXhblojjNaon^W/Oo[Yk71On_X<T00on`Xl_o_/?N
okk3gP03okk3gP03okg2g_o2h^oo`^;_00?o`^;_00Go`mc/okCdlondm??o0000okCdl`02oi3^j`04
ojO_mon?ioWoSnOiohoWn@?oQmOo1OnBdoh3oi[<n@;oW/Cc0onD^_8Dooooo`;o0000>oooool002;o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`;o0000=oooool2o`0000;o_;gJ0onm`]d00on[
SKKoZXfgojZ=]`03ojZ=]`CoYh^h00CoXHVjoiUdYonIM:OoVGBW1?nBKjL3oha[Z0CoRfZX0on=K:P4
oiAaZ0GoVgJX0_nMMjL00onFJIcoUFRLoiEXW002oiEXW0CoT6FL1?n<HYd3ohUQWPCoQf:O1?n9I:44
ohaXX`CoT6bU1?nBKjL2oiAaZ@;oV7FY1OnIMZ/3oiUg[0CoVGR]1OnINJh01?nINZooWh>eoin3]OnO
PkD5oj25]PGoXHNh0onRR[X00on]W<Ko[Yk7ojjNa`03ojjNa`?o[j3900?o_/GOokk3g_nn`mh00onn
`mh2ol7Xl@Co`^;_0onSmNX00ondm??o0000oi3^j`02og;Pj@?oM]Ol1On7eol2oi;CoP;oS[kf1?nA
_?@5oiBjlQGooooo00?o0000ooooooooool0>?ooool003;ooooo1Ol0000eooooo`?o00001?nl_MX0
1?nm`]goZhffoj^=]_n[SKH5ojZ=]`;oYh^h00?oWWNWoiUdYonIM:L00_nIM:L4oi9_Y`?oS6^X1?n;
JZP4ohe/Z0?oU76X1OnKMZP00onMMjOoUVVLoiIYW005oiEXW0?oT6FL1?n<HYd4ohUQWP?oQf:O1?n9
I:45ohaXX`?oT6bU0onBKjL00onGLjSoV7FYoiQeZ@02oiQeZ@GoVGJ[0onIMj`5oiUh[@?oVGV^00?o
Wh:doin3]OnOPkD00onOPkD4oj25]PGoXHNh00?oXXZjojfLa_n]W<H00_n]W<H5ojjNa`04ojnPbOnn
aMoo_/GOokk5g`?o_/?N1?o1j?401_o2h^ooXoGZoj?ej_nSmN[oK=g>odc;b@;o00000omRd_@4ogKG
o0;oQmOo0_n;__L5ohjnmPCoTKcd0_nD^_82oi6ckQKooooo00?o0000ooooooooool0=oooool0033o
oooo0_l0000iooooo`03o`000?nj^m[o^[_J00Co_;gJ00?oZhjgoj^=]_n[SKH00_n[SKH5ojZ=]`03
ojN;^?nNMjOoWWNW00CoVGBW1?nBKjL4oha[Z0?oRfZX1?n=K:P4oiAaZ0?oVgJX00CoU6RLoiIYW?nF
JIcoUVVL1OnEJ9`3oi1UW0CoS6:M1?n9HIh3ohMRW`CoRFBQ1On<J:<3oi1/Y@04oi9_YonGLjSoUg>X
oiMcZ0GoV7FY1?nIMZ/3oiUg[0GoVGR]00CoVGV^oin2]?nOP[CoWh:d1OnOPkD5oj25]P?oXHNh00?o
[9_5ojfLa_n]W<H00on]W<H4ojjNa`03okk8h_nnaMoo_/GO00?o_/GO00?o_/?Nol7XlOo1j?400_o1
j?42ohK[d`Go000000?oCLWWo`000?mRd_@00_n6^_L4ohRmn0GoRkkg1?n>__H2oi6lm0;oT;7]1OnA
/nhEooooo`03o`000?oooooooooo03Oooooo000]ooooo`?o0000>Oooool2o`0000Co^[_J00?o_;gJ
oj^>]on[S[L00_n[S[L3oj^=]PCoZXfg00?oXGZXoiigYonNMjL00_nNMjL3oiUdY`CoTVnW1?n<JjP3
oh]ZZ0CoSFbX1?nDLJP01?nKMZSoU6RLoiAXW?nDJ9`4oiIYW0CoUFRL0on@II`4ohaRW@CoRF6N0on7
HYl5ohUTX@CoS6RS0_n@K:D00onFLJKoUg>XoiMcZ003oiMcZ0CoV7FY1?nIMZ/4oiUg[0?oVGR]00?o
WX6coin2]?nOP[@00onOP[@4oin3]@GoX8Ff00?oXHNhojbKaOn/VlD00_n/VlD4ojfLaP?o[Yk70onn
b>83okk5g`?o_Noc00Co`NSaohK[don6jm?oQ[7a0ol000000on6/O7oQKKeohFfm@02ohFfm@04o`00
0?n6^_OoQ[[gohJjm`CoR;gh0_n;__L2oi2Zi`GoT:k[1?n@/Nd5oi6ckQGooooo00?o0000oooooooo
ool0=_ooool002cooooo0_l0000jooooo`03o`000?nh^]_o^;[K00?o^[_J00?oZHjioj^>]on[S[L0
0on[S[L4oj^=]P;oZXfg0_nQNZP4oiigY`CoVGBW0onBKjL4oha[Z0CoRfZX0on=K:P3oiAaZ003ohmT
W?nDJ9coU6RL00;oU6RL1?nFJI`4oiEXW0?oT6FL1?n<HYd4ohUQWPCoQf:O1?n9I:43ohaXX`04oi=]
Y?nFLJKoUW6VoiIaYPGoUg>X1?nHMJT4oiUfZ`CoVGN/00CoVGR]oij1/onNPK?oWX6c1OnOP[@5oin3
]@?oX8Ff00?oZiW4ojbKaOn/VlD00on/VlD5ojfLaP03ojjNaonnb>;o_/SR00;o_/SR00?o_/GOokg_
lonmko<00_nmko<00omNd:koR:_/o`000002o`0000GoQ[7a1?n5]_D00ol0003oQ[[goi6OgP04oi2U
h`GoT:[W1On@[^/4oi2ak@;oTK?^0onD/>XEooooo`03o`000?oooooooooo03Gooooo000/ooooo`?o
0000=oooool00omVf;ko^;[KokRjf`03okRjf`04okZkf_nYS[WoZHjiojV>^@CoZhjg1?n[SKH01?nZ
SKOoXGZXoj5jZ?nQNZP4oiigY`CoVGBW1?nBKjL3oha[Z0CoRfZX0on=K:P01?nDLJSoSfBLohmTW?n?
I9`4oiAXW0CoUVVL1?nEJ9`3oi1UW0CoS6:M1?n9HIh4ohMRW`CoRFBQ00CoS6RSoi=]Y?nCKJCoTffT
1?nFLJH4oiMcZ0CoV7FY1OnIMZ/2oiUg[003oij1/_nNPK?oWX6c00?oWX6c1?nOP[@5oin3]@03oj25
]_n[VLCoZiW400;oZiW41?n/VlD4ojfLaP;o_/_T0onnb>83okGdlP03okg_lon<XnCo000000;o0000
1?n8Zn`2ohJal@;oTi?A1?nBV]P01?nAWmko0000oi6Og_nAWmh4oi2Uh`GoT:[W0_n@[^/2oiJSgPGo
UJWT1OnD/>XDooooo`03o`000?oooooooooo03Gooooo000/ooooo`04o`000?oooooo0000o`0003Co
oooo00?oI]RnokNjg?ng^]`01?nh^]/00onXSk_oZHjiojV>^@02ojV>^@GoZhjg0_n[SKH00onQNjWo
XGZXoj5jZ002oj5jZ0CoWWNW1?nIM:L4oi9_Y`?oS6^X0_n;JZP2ohQOW0?oRV6L1?n?I9`4oiAXW0Co
UVVL1?nEJ9`3oi1UW0GoS6:M0on9HIh4ohMRW`;oRFBQ0_n@JZ85oi=]Y0?oUW6V1?nGLjP4oiQeZ@Go
VGJ[00CoVGN/oij1/_nNPK;oWX6b1?nNPK<5oin2]0?oWh>e00?oZYS4oj^Ia?n[VL@00on[VL@5ojbK
a@03ojfLa_nnbnCo_/_T00?o_/_T00Co_/SRokGdl_nem?;o]OCb0ol000000on<XnCoUXS3oiJ8``04
oiB>b@GoTi?A1?nBV]P01?l0003oTIoNoi6Og_nAWmh4oi2Uh`;oT:[W0_nFW=P5oiJSgPGoUJWT0_nD
/>X2oifbia?ooooo00?o0000ooooool000002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`06Oooool002cooooo0_l00002ooooo`03o`00
0?oooooooooo02oooooo0_mii=04okNjg003okRjfonXSk_oZ8nk00;oZ8nk0onYS[T5oj^>]`03oj^=
]_nQNjWoXG^Y00GoXGZX0onNMjL4oiUdY`?oTVnW00CoSfFMohUQW?n9HIcoRF6L1?n8Gi`3ohYQW0Go
SfBL0onDJ9`4oiIYW0CoUFRL1?n@II`4ohaRW@?oRF6N0_n7HYl2ohiVX0CoT6ZR1OnCKJ@3oiIaYPCo
Ug>X1OnHMJT3oiUfZ`03oin1/_nNPK;oWX6b00;oWX6b1?nNPK<5oin2]003oin3]OnZV<CoZYS400;o
ZYS41?n[VL@4ojbKa@;o_/oW1?nnbn@2ojOfk0?o000000?oSi_KoiN4_?nFR<<01?nFR<<4oiB>b@Co
Ti?A1?nBV]P01?nAWmko0000oiR@b_nHT<X4oiNFd@GoUYcH1OnFXmh2oiFYi0;oWJ_P1OnM/^LEoooo
o`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q01Wooooo000[ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0:oooool2ohK[f`?o]k_M0ong^]`00onWTKkoZ8nkojR?^`03ojR?^`CoZHji0on[S[L0
0onQO:_oXG^Yoj5kZ@02oj5kZ@CoXGZX1?nNMjL3oiUdY`04oi9_Yon?IIgoSfFMohmUW@?oRF6L1?n8
Gi`3ohYQW0GoSfBL0onDJ9`4oiIYW0GoUFRL0on@II`4ohaRW@;oRF6N00?oSVFNohiVX?n>IZ000_n>
IZ05oi1ZXPCoTffT0onFLJH5oiMcZ0CoV7FY00CoVGJ[oin1/_nOPK;oWh6b1OnNPK84oij1/`?oWh:d
00?oZIS4ojZHa?nZV<@00onZV<@5oj^Ia003ojbKaOnncnOo_/oW00?o_/oW00?o_/_TojOfk?nWm^`0
0_l00002oiQo]`CoUhBl1?nFR<<4oiB>b@GoTi?A0_nBV]P01?nHRl?oV93:oiR@b_l00002oiR@bPCo
UiKA1OnFW=P2oiJSgP;oWZCI1OnMZn04oifbiaGooooo00?o0000ooooooooool01Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Iooooo`00:oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo02Wooooo00?o]kgNokNkgOng^md01?ng^md01?ng
^]coYi6nojNA__nWTKh4ojR?^`CoZHji00CoZhjgoj5lZonQO:_oXGb[1?nQNjT4oj5jZ0CoWWNW0_nI
M:L00onDJIkoSfFMohmUW@02ohmUW@?oRF6L1?n8Gi`4ohYQW0CoSfBL1?nDJ9`3oiIYW0GoUFRL0on@
II`2ohaRW@;oSfFM0on>IIh4ohiVX0GoT6ZR1?nCKJ@3oiIaYPGoUg>X0onHMJT00onOPK7oWh6boin1
/P03oin1/PCoWX6b1?nNPK<00onOP[CoZIS4ojVHa002ojVHa0CoZYS41?n[VL@2okgCj`Co_/oW00Co
T_3No`000?l0003o00001OnHOkL3oiN4_0CoUXS31OnDS/T2oi>Cd@;oVHJm1?nHRl<01?nHT<[o0000
oiR@b_nHT<X5oiNFd@;oUYcH0_nOWM85oijTf@CoWJ_P0_nM/^L3ojJhiAGooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0I
ooooo`00:oooool3o`0000Gooooo00?o0000ooooooooool09_ooool01?n@kn?o]kgNokNmg_ng_Mh4
okNkg@03ojNC`?nWTKkoYi6n00;oYi6n1OnXSk/2ojV>^@03oiml[OnQO:_oXGb[00;oXGb[1?nQNjT4
oj5jZ0?oWWNW00CoV6fOoiAYW_nDJIkoU6VN1?n?IId4ohUQW0?oR5nL1?n:HI`4ohmTW0CoU6RL1?nF
JI`4oiEXW0;oT6FL00?oTVNLohmUWOn?IId00_n?IId3ohiUWPGoSVJP1?n@JZ84oi=]Y0CoUW6V1?nG
LjP01?nHMJWoWh6aoin1/OnOPK45oin1/PCoWX6b0onNPK<6ojVHa0GoZYS400?oZiW4okgCjonmdn/0
0onmdn/01?nncnOo0000o`000?l00003oiUl/PGoV7ng0onGQ;`5oiJ8``;oU8k90_nJP[P5oiV6_@?o
V8_30_nHT<X00ol0003oV93:oiR@bP02oiNFd@;oWiO<1OnOWM84oijTf@;oWJ_P0_nW/=l6ojJhiAGo
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEE
EOl0003o410@olc<c00Iooooo`00:oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02?ooooo00?oT>oSokNngong_Mh01?ng_Mh00ong^mgoYi?0ojNC`002ojNC`0?oYi6n1OnXSk/00onY
S[WoWgb]oiml[@04oj5lZ`CoXG^Y1?nQNZP01?nNMjOoV6fOoiQ]WonHKIl3oiAYWPCoSfFM1?n9HI`3
ohQOW0CoRV6L1?n?I9`4oiAXW0CoUVVL1?nEJ9`00on@IIcoTVNLoi9WW004ohmUW@CoSVFN1?n>IZ04
oi1ZXPGoTffT0onFLJH2oiMcZ0;oX82a1OnOPK44oin1/PGoWX6b00?oWX6cojVHa?nYV<@01OnYV<@4
ojZHa0;o_=W_0onmdn/3o`0000;oVGV^1OnIO;84oiQo]`CoUhBl0_nFR<<2oi]n/`GoVX:h1?nIQ[d3
oiR;``?oV93:00?o0000oj2Ba_nOUl`01?nOUl`4oinMdP?oWZCI00?oYj[IojN`gonW/=l00onW/=l4
ojJhi@03ojnniOoooooooooo01?ooooo00?o0000ooooooooool00oooool01Ol@413ooooooooooooo
oooo410@00_ooooo00?oEEEEohN7Qoooool06oooool002_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Pooooo`03oiSbj?ng_]oo]kkO00;o]kkO0ong_Mh00onXUL;oYi?0ojNC`003
ojNC`0CoYi6n0onXSk/00onNOJooWgb]oiml[@02oiml[@CoXGb[0onQNjT4oj5jZ0CoV6fO1?nDJIh3
ohmUW@CoRF6L0on8Gi`4ohYQW0CoSfBL1?nDJ9`4oiIYW0?oUFRL00CoUVVLoi9WW?nBIicoTVNL1On?
IId3ohiUWPCoSVJP1?n@JZ85oi=]Y0;oUW6V00?oWgn`oj20/OnPP;400_nPP;45oin1/@GoWh6b0onN
PK800onYV<GoZIS4ojVHa007ojVHa003ojZHa?nlfNoo_=W_00;o_=W_0ol000000omehLOoVGV^oiUi
[P03oiUi[PCoVGbb1OnHOkL2oiN4_003oial[onKO[?oVgjc00;oVgjc1OnJP[P4oiV6_@CoV8_300Go
V93:oj2Ba_nPT/Ko0000oj2BaP04oinGc0GoWigB00CoWZCIojNZfOnWZ]WoYj[I1OnW/=l00onV^>Go
[kkUojnni@02ojnniA?ooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooM
gMgo410@oiRHV00Kooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
01cooooo0_nPm>`2okW0g`Go]kkO00Co]kgNojRE`_nXUL;oZ9G21?nWTl04ojNA_P04ojR?^onNOJoo
WWf_oiim[`CoWgb]1?nQO:/4oj5kZ@;oXGZX00?oVW2QoiQ]WonHKIl00_nHKIl4oiAYWP?oSfFM1?n9
HI`4ohQOW0?oRV6L1?n?I9`4oiAXW0CoUVVL00CoUFRLoiIYW?nFJIcoUVVL1?nBIi`4ohmUW@?oSVFN
1?n>IZ05oi1ZXPCoTffT00?oUW6Voimo/?nOOk001OnPP;44oin1/@GoWh6b00?oWX6bojVHaOnYV<D0
0_nYV<D7ojVHa0;o^Mkb00Go_=W_o`000?l0003o0000oeC:Z004oiUgZ`CoVGV^1?nIO;85oiQo]`03
oiN4_?nLO:ooW7b_00GoVgjc1?nJP[P5oiV6_@;oV8_300KoXHk1oj2Ba_nPT/KoX9;6o`000?nPT/H5
oinGc0;oWigB0_nXYM<5ojNZf@;oYk3O0on`^^45ojnniAGooooo00Wo0000ooooooooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410Iooooo`004?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo0ol0000:oooo
o`03o`000?oooooooooo01Wooooo0onPm>`4okW0g`?o]kkO00?oZIS4ojRE`_nXUL800onXUL84ojNC
`0;oYi6n00?oWGjaoiim[onNOJl00onNOJl3oiml[@CoXGb[1?nQNjT00onQNZSoVW2QoiY`X@04oiQ]
W`CoU6VN1?n?IId3ohUQW0CoR5nL0on:HI`5ohmTW0?oU6RL2?nFJI`4oi9WW0CoSfFM0on>IIh4ohiV
X0GoT6ZR0onCKJ@00onNOJkoWgn`oimo/002oimo/0CoX82a1OnOPK43oin1/P03ojVIa_nYV<GoZIS5
00?oZIS51OnYV<@2okWNlP?o000000Co_=W_oiUdZ?nIM:SoVGBX1?nIMj/4oiUi[PGoVGbb0onHOkL0
0onLNZcoW7b_oial[`02oial[`CoVgjc1OnJP[P3oiV6_@03oj:;_?nQS/7oXHk100;oXHk10onPT/H0
0ol0003oWiO<oinGc002oinGc003ojVQc_nXYM?oZ:GC00?oZ:GC0onWZ]T00ona]mko/;[Qok2jh@04
ok2jh@;o[kkU0_nda^LEooooo`03o`000?oooooooooo02oooooo0008ooooo`Ko00000_ooool01Ol@
413ooooooooooooooooo410@00_ooooo1Ol00005ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool05_ooool3ojOdl003ok[1goni`=oo^L3O00Co^L3O00Co]kkOojVHa?nYV<CoZIS41?nX
UL84ojNC`003ojNA__nMO[7oWGja00GoWWf_0onOO:d4oj5lZ`?oXG^Y00?oVW6SoiY`XOnJL:400_nJ
L:43oiQ]W`CoU6VN1?n?IId3ohUQW0CoR5nL0on:HI`5ohmTW0?oU6RL2?nFJI`4oi9WW0CoSfFM0on>
IIh5ohiVX0CoT6ZR00CoTffToiim[_nNOJkoWWf^1?nOOk04oj20/@GoWh6a00?oWh6bojVIa_nYVLH0
0_nYVLH4ojVHa@?oZIS40_nfhoH2o`0000;o^Mkb00?oVG:VoiUdZ?nIM:P00onIM:P3oiUgZ`CoVGV^
1OnIO;801?nHOkOoW7Z/oiaj[?nLNZ`4oial[`CoVgjc1OnJP[P01?nIQ[goXX^loj:;_?nRRk`4oj6>
`@CoX9;600?o0000oinGc?nYXLh00onYXLh4ojRUd`03ojNZfOna]mko/KON00;o/KON1?n`^^400onf
anOo]<KWokC6i`03okC6iaGooooo00?o0000ooooooooool0;_ooool0013ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Dooooo`?oYoC`0onj`Ml4okW0g`03oj^JaOnYV<CoZIS400;oZIS41OnXUL82
ojNC`003oif0/onMO[7oWGja00;oWGja1?nNOJl3oiml[@CoXGb[00CoXG^YoiYaXonJLJ?oVW6S1?nJ
L:44oiQ]W`?oU6VN1?n?IId3ohUQW0CoR5nL1?n:HI`4ohmTW0?oU6RL2?nFJI`4oi9WW0CoSfFM0on>
IIh5ohiVX0?oT6ZR00?oW7V/oiim[_nNOJh00onNOJh3oimo/0GoX82a0onOPK400on[W<OoZIW6ojVI
aP03ojVIaPGoZIS500KoZIS4o`000?l0003o0000okKSm_nig_84oiUbYPCoVGBX0onIMj/5oiUi[P?o
VGbb00?oWGRYoiaj[?nLNZ`00onLNZ`3oial[`GoVgjc0onJP[P00onSRKSoXX^loj:;_002oj:;_0Co
XHk11?nPT/H00ol0003oZJ7>ojVQcP03ojVQcP?oZ:GC00?o/[GKok6gg_na]mh01?na]mh00on`^^7o
]/OWokK7i`02okK7i`?o]<KW0_ndbNXEooooo`03o`000?oooooooooo02gooooo000@ooooo`05o`00
0?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00006ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool04Oooool3ojgdlP;o^l;O1?nj`Ml00oni`=ooZi[5oj^Ja@02oj^J
a@?oZIS41?nXUL801?nNP[CoWH2coif0/onMP;<4oien/@CoWWf_1?nOO:d2oj5lZ`03oiUbYOnJLJ?o
VW6S00;oVW6S1?nJL:44oiQ]W`?oU6VN1?n?IId4ohUQW0?oR5nL1?n:HI`4ohmTW0?oU6RL2?nFJI`4
oi9WW0CoSfFM1?n>IIh4ohiVX004oi1ZX_nLNJcoW7V/oiai[0GoWWf^0onOOk05oj20/@03oin1/On[
W<OoZic700;oZic71?nYVLH3ojVHa@?o00000onfhoH00onILJCoVG:VoiUbYP03oiUbYPCoVGBX0onI
Mj/5oiUi[P04oiUl/_nMN:WoWGRYoiehZ@GoW7Z/0onLO:l5oi]n/`03oiZ2^?nSRKSoXhVh00;oXhVh
1?nRRk`4oj6>`@05oj2Ba_nZWL[oZYg:ojZMb_l000001OnYXLh01?nXYM?o/[GKok:efonb]M/4ok6g
gP03okO:j?nfanOo]/OW00?o]/OW00?o]<KWokC9j_ndbNX00ondbNXDooooo`03o`000?oooooooooo
02gooooo000@ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000006oooo
o`;o00003oooool2o`0000oooooo0on]m?85ok_2g`;o^/7O00?o[Ig7oj^JaOn[V/D00on[V/D4ojVH
a004ojRE`_nNP[CoWX:doij2]0CoWH2c0onMO[45oiim[`?oWgb]00?oXGb[oiUbYOnILZD01?nJLJ<4
oiY`X@CoV6fO0onDJIh4ohmUW@CoRF6L0on8Gi`4ohYQW0;oSfBL0_n?II`3oiAXW0WoUVVL0onBIi`4
ohmUW@CoSVFN0on>IZ000onIMJWoW7V/oiai[003oiai[0CoWWf^1?nOOk03oj20/@03ojfNb?n[W<Oo
Zic700?oZic71?nYVLH3o`0000Co/NWh00Co]^?foiUaY?nILJCoVG6T1?nILZH4oiUdZ0CoVGN[0onI
NJh00onMMjOoWGRYoiehZ@03oiehZ@CoW7Z/1?nLO:l3oi]n/`03ojB7]OnSRKSoXhVh00?oXhVh1?nR
Rk`3oj6>`@03ojbLa_nZWL[oZYg:00?oZYg:00Go0000ojVQc_nYXLkoZJ7>okBef@05ok:ef`03ok6g
g_ngb^So]l[X00;o]l[X0onfanL2okG@k@Co]<WZ00?o/<_^ooooooooool04oooool00ol0003ooooo
ooooo`0/ooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
1_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00[ooooo0onblo@3okc3g`?o^l;O
00?o[j38ojfMaon]WLL00_n]WLL5oj^Ja@;oZIS400?oWhBfoij2]?nNP[@00_nNP[@4oif0/`?oWGja
1OnNOJl2oiml[@04oiQbYonILZGoVG:UoiUbY@CoVW6S1?nJL:44oiQ]W`CoU6VN0on?IId4ohUQW0?o
R5nL1?n:HI`4ohmUW0CoU6RL2?nFJI`3oi9WW0GoSfFM0on>IIh01?n>IZ3oVGFYoiUeZOnIMJT5oiai
[0CoWWf^1?nOOk000onPP;7o[Ik8ojfNb002ojfNb0CoZic700CoZIW6o`000?l0003o00000onYk_P2
ok7Yn0;oVW6S1?nILJ@4oiUbYPCoVGBX1?nIMj/01?nINJkoWGNWoiegYonMMjL5oiehZ@CoW7Z/1?nL
O:l00onKO[?oY8NeojB7]@02ojB7]@CoXhVh1?nRRk`00onQS/7o[9c6ojbLaP02ojbLaPGoZYg:00?o
0000okBefOnd]MT00_nd]MT3ok:ef`;o^Lo[1Ongb^P00onfanOo]M3]okG@k@02okG@k@03okC9j_n`
bnko/<_^00;o/<_^4oooool2o`0002kooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Ooo
ool00omgMgOo0000ooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?oo
ool3ok;cm0Go_<?O00Co^l;OojnPb?n_X<So[j380on]WLL4oj^Ja@03oj67^?nOQ;KoWhBf00;oWhBf
1?nNP[@3oif0/`CoWGja0onNOJl01?nFLjWoV7:WoiQbYonHLZL4oiUbY@CoVW6S0onJL:44oiQ]W`Co
U6VN0on?IId2ohUQW0;oR62L0on8Gi`4ohYQW0CoSfFL1?nDJ9`8oiIYW0CoTVNL1?n?IId2ohiUWP03
oiQbY_nIMJWoVGFY00?oVGFY1?nLNJ`5oiim[P;oWgn`00?o/:79ojfNb?n]W/P00on]W/P2oj^La`?o
000000?oZIW6ojW^n?nYk_P00_nYk_P00onIL:;oVW6SoiYaX`02oiYaX`CoVG6T1?nILZH5oiUdZ0;o
VGN[00?oWGJVoiegYonMMjL00onMMjL4oiehZ@GoW7Z/0_nLO:l00onVQ[?oY8NeojB7]@03ojB7]@Go
XhVh0_nRRk`00on^VlCo[9c6ojbLaP03ojbLaPCoZYg:00?o][KHo`000?nd]MT00ond]MT00onb]M_o
^Lo[okW?j`03okW?j`;o]l[X0_neeo44okG@k@;o[m?c1?n`bnhEooooo`03o`000?oooooooooo02_o
oooo000Yooooo`;o00005?ooool00ol0003oooooooooo`05ooooo`?o]o3e0_nm`ml4okc3g`03ok6S
b_n_X<So[j3800;o[j381?n]WLL01?n[V/GoXHNhoj67^?nQQkP4oin4]PCoWX:d1?nMP;<3oien/@04
oiim[onFLjWoUW>YoiIcZ@CoV7:W0onILZD4oiYaX`?oVW2Q1?nHKIl4oiAYWP;oSfFM00?oSF>MohQP
W?n8H9`00_n8H9`3ohQOW0CoRV6L1?n?II`4oiAXW0SoUVVL1?nBIi`4ohmUW@03ohiUW_nHLZKoV7:V
00GoVGFY1?nLNJ`5oiim[P04oimo/?n`XLWo/:79ok2Qb@?o[Ik80ol00002oj^La`?oWo7b00CoZNkh
oiIaYonIL:;oVG2R1OnJLJ<3oiUaY0GoVG:V1?nIM:P01?nIMj_oWGJVoiefY_nMMZH4oiegY`CoWGRY
1OnLNZ`01?nLO:ooYXJcojJ6/onVQ[<4ojB7]@GoXhVh00CoXX^lojjKa?n^VlCo[Y_41On/W<H00onZ
WL[o][KHokJff002okJff003o`000?nd]MWo];GI00;o^mO^1?nicn/00onch?Ko]MOaokGGl@03okGG
l@03okG@kOn_do?o[m?c00?o[m?c0_n`bnh2ojS6kaGooooo00?o0000ooooooooool0:_ooool002Wo
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`;o]o3e1Onm`ml00onl`moo
/J?:ok6SbP02ok6SbP?o[j380on]WLL00onSR[[oXHNhoj67^003oj67^0?oWhBf1?nNP[@4oif0/`;o
WGja00?oUWBZoiIcZOnFLjT00_nFLjT4oiQbY`?oVG:U1?nJLJ<4oiY`X@?oV6fO0_nDJIh2oi5WWP?o
SF>M1?n8H9`3ohQOW0GoRV6L0on?II`4oiAXW0SoUVVL1?nBIi`2ohmUW@;oUg2U1?nHLZH4oiUeZ@Co
W7V/1?nNOJh00onbXlSo/:79ok2Qb@02ok2Qb@03ojfNb?l0003o000000;o[Ik800CoZic7oioal_nO
lO;oWo7b0_nDKjD01?nHKZ7oVG2RoiU`X_nIL:85oiYaX`?oVG6T1OnILZH3oiUdZ003oieeYOnMMZKo
WGJV00;oWGJV1?nMMjL5oiehZ@?oW7Z/00?oYhJaojJ6/onVQ[<00_nVQ[<5ojB7]@?oXhVh00?o/9c3
ojjKa?n^Vl@00_n^Vl@4ojbLaP03okZjfOnf]]So][KH00Co][KH00?o0000ok_Gk_nkenh00_nkenh0
0onicn_o/n3fok?PmP02ok?PmP;o]MOa1?n[gOT2ojoCl`;oY/gd1OnXa^lDooooo`03o`000?oooooo
oooo02[ooooo000Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00_njkO@3okk4
g`?o_L?O00?o/ZK<ok6Sb_naXlX00onaXlX4ojnPb004ojfMaonSR[[oXhZjoj>:^PCoXHNh1?nOQ;H3
oij2]0;oWH2c0_nFMJ`3oiIdZPCoUW>Y1?nHLZL3oiUbY@CoVW6S1?nJL:42oiQ]W`03oiA[X?nAIiko
TFNN00;oTFNN0on=Hid5ohQPW0?oR5nL1?n:HI`3ohmUW0CoU6RL2?nFJI`3oi9WW003oiUaY?nGL:Go
Ug2U00;oUg2U1?nHLZH4oiUeZ@GoW7V/0_nNOJh3ok:Sb004ok2QbOl0003o0000o`0000?o[Ik80_n<
k^02oiA]X`04oiA_YOnHKZ7oV6jQoiQ^X@CoVG2R1?nJLJ<4oiUaY0CoVG:V00CoVGBXoieeYOnMMJGo
WGFU1?nMMZH4oiegY`GoWGRY00CoW7Z/ojN6/OnWQ[7oYhJa1?nVQ[<5ojB7]@03oj>9^?n`W<?o/9c3
00;o/9c31?n^Vl@00on/W<Ko^[[IokZjf@02okZjf@Co][KH00?o^n;cok_Gk_l000000_nkenh3ojgZ
n@;o/n3f0onRiO`2oj_Mn@;oXM;i1OnVcO@2ojS6k`?oXL3_5?ooool00ol0003oooooooooo`0Yoooo
o`00:Oooool00ol0003oooooooooo`0Fooooo`?o^^gd1Onna=l01?nm`moo/ZK<ok:Vc?nbY/`5ok6S
bP;o[j3800?oYHfloj>:^_nSR[X00_nSR[X4oj67^0CoWhBf0_nNP[@00onGMjgoUWF/oiIe[002oiIe
[0CoUWBZ0onFLjT4oiQbY`?oVG:U1?nJLJ<4oiY`X@03oiQ]WonDJj3oU6^P00CoTFNN1?n=Hid4ohQP
W0?oR5nL1?n:HI`3ohmUW0CoU6RL2?nFJI`01?nBIicoVG6ToiUaY?nILJ@5oiM`Y@?oV7:V1?nIMJT5
oiai[003oiim[_nbXlSo/Z?800?o00000on`XLT00on]W/SoS>kPohc^h003oiA]X`03oiM]X?nHKZ7o
V6jQ00;oV6jQ1?nIL:84oiYaX`CoVG6T0onILZH00onMMJCoWGFUoieeY@03oieeY@CoWGJV0onMMjL4
oiehZ@03ojR6/OnWQ[7oYhJa00?oYhJa1?nVQ[<3ojB7]@03ok>Oa?n`W<?o/9c300?o/9c30on^Vl@0
0onm`Mgo^[[IokZjf@04okZjf@03okJff?nkh_?o^n;c00;o^n;c00?o0000ojgZnOn]j_T00_n]j_T0
0on=ioSoX^Gloj;Uo002oj;Uo0;oVMOm1?nQd_T2ojK=m0?oWl;a1OnQ`>lDooooo`03o`000?oooooo
oooo02Sooooo000Yooooo`?o00005?ooool3okgXl`;o_/CN1?nna=l00ondZLgo/ZK<ok:Vc002ok:V
c0Co/J?:00?oYi6nojF=_?nUSK`00_nUSK`3oj>:^PGoXHNh0_nOQ;H01?nHNJkoUgN]oiMg[OnGMjd4
oiIe[0CoUWBZ1?nFLjT3oiQbY`CoVG:U0onJLJ<2oiY`X@;oUFfR0onDJj05oi5WWP?oSF>M1?n8H9`3
ohQOW0CoRV6L1?n?II`3oiAXW0SoUVVL1?nILJ@5oiM`Y@?oV7:V1OnIMJT3oiai[004ok>Saol0003o
0000o`0000;o/Z?80on`XLT2og3M_0;oUFjS00CoU6fSoiM]X?nGKJ3oUffP1OnHKZ43oiU`XPCoVW6S
1?nILJ@01?nILZKoWGFToieeY?nMMJ@5oieeY@CoWGJV1?nMMjL2oiehZ@;oZ8Ja1OnWQ[44ojJ6/`03
ojB7]OncWlCo/io400;o/io41On`W<<01?n^VlCo_L7Mokg1gOnm`Md4okZjf@?o]_3e0_nkh_<2oiW^
m003o`000?n]j_WoSNOh00?oSNOh00?oX^GloiWGoOnIeod00onIeod2oj7Bn@;oW<;c1OnO`_42oj70
k`;oW[_]4oooool2o`0002[ooooo000Yooooo`03o`000?oooooooooo01?ooooo0onmj?<4okk4gP03
okk4gondZLgo]:W=00;o]:W=1?nbY/`00onaXl[oYi6nojNA_P02ojNA_P?oYHfl1?nSR[X4oj67^003
oin4]_nHNJkoV7V^00CoUgN]0onFMJ`4oiIdZPCoUW>Y1?nHLZL3oiUbY@;oVW6S00?oUFnToiE]X_nE
KJ800_nEKJ84oiA[X0CoTFNN0on=Hid4ohQPW0?oR5nL1?n:HI`4ohmUW0CoU6RL1_nFJI`00onKLZCo
VG6ToiUaY003oiUaY0CoUg2U0onHLZH5oiUeZ@05oiai[?l0003o0000o`000?ncXlL01OnbXlP00on`
XLWoVG2SoiU`X`02oiE^X`03oiI/X?nGKJ3oUffP00;oUffP1OnHKZ43oiU`XPGoVW6S0onILJ@4oiee
Y0GoWGFU1?nMMZH4oiegY`03oiehZOnXQ[7oZ8Ja00;oZ8Ja1?nWQ[44ojJ6/`Go/io41?n`W<<00oo1
c>?o_L7Mokg1g@03okg1g@03okZjfOnfl?Go]_3e00;o]_3e0_m^gmP2oiW^m0;oJMcU00?o0000ogkE
oon<f?l01?n<f?l2oiWGo@;oVL7c1OnL`_<2oio2l@;oWKW/1OnN^ndDooooo`03o`000?oooooooooo
02Oooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00005oooo
o`03o`000?oooooooooo01;ooooo0onoho400onoaMko_/CNokk4gP03okk4gPGo]:W=0onbY/`00onY
U<7oYi6nojNA_P03ojNA_P?oYHfl1?nSR[X2oj67^0;oVW^`1?nHNJh3oiMg[@CoUWF/0onFM:X4oiIc
Z@CoV7:W0onILZD00onJLJ?oUFnToiE_Y004oiE]XPCoU6^P1?nAIih3oheSW@CoR62L0on8Gi`4ohYQ
W0CoSfFL1?nDJ9`5oiIYW0;oVg:T1OnILJ@4oiM`Y@CoV7:V0_nIMJT3o`0000Co/j?71?nbXlP3oiU`
X`04oiU_XOnFK:3oUVbPoiI/X0GoUffP1?nHKZ43oiU`XPGoVW6S0_nILJ@00onNMJCoWGFToieeY003
oieeY0CoWGFU1OnMMZH2oiegY`03ojV8/OnXQ[7oZ8Ja00?oZ8Ja1OnWQ[42ojJ6/`;o]jG71?ncWl@3
ok2L``?o`LcS0onm`Md3oi_cj003okK`mOm^gmSoK]oH00;o>;fo0om`c_h01?mneOoo0000ogkEoomn
eOl2ohcHo`;oUKcb1OnI`O<2oic2l`;oW;KZ1OnM^N`4oijkkAGooooo00?o0000ooooooooool09_oo
ool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Gooooo00?o0000ooooooooool04Oooool2okoSl@Co_lGN0onna=h2okJ/c`Go]:W=
00Co/ZK<ojVD`OnYU<7oZIC11?nWTKh4ojF=_0;oXhZj00?oVgfboiYk/?nJNk000_nJNk04oiQi[P?o
UgN]1?nFMJ`3oiIdZPCoUW>Y1?nHLZL2oiUbY@04oiA_Y_nEKjCoUFnToiE_Y0GoUFfR0onDJj04oi5W
WP?oSF>M1?n8H9`3ohQOW0CoRV6L1?n?II`4oiAXW0?oUVVL00?oVg>Toi]bY?nKLZ@00_nKLZ@4oiUa
Y0CoUg2U0onHLZH3o`0000?o/j751OncXlL01?nbXlSoWWBSoiidXonIL:<3oiU_X@?oUVbP1OnGKJ04
oiQ^X@CoVG2R1?nJLJ<01?nILJCoWWFToiieY?nNMJ@4oieeY0CoWGFU1OnMMZH00onMMjOoZHRaojV8
/@05ojR6/@GoYhJa00CoYXJcokNUaongYLOo]jG71OncWl@00on`W<?o`LcSol7<h`02ol7<h`04okg1
gOnKlnSoVo?Xoi_cj0;o000000CoL;kmofc8o_m/b?koK<Sn0_m`c_h3oi:ZiP04oi>ek_l0003oTkG^
oi>ekPCoUKcb0_nI`O<2oibai`GoW;KZ1?nM^N`2oijkk@?oX;SZ5?ooool00ol0003oooooooooo`0V
ooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7o
k^k^00Kooooo0_l0000@ooooo`?o`=k^00?o`<GMoko5g_noaMh00onoaMh00onna=ko]Zc?okJ/c`02
okJ/c`?o]:W=00?oZiS3ojVD`OnYU<400_nYU<45ojNA_P?oYHfl00?oXhZjoi]m/_nKOK801?nJNk04
oiQi[P?oUgN]1?nFMJ`4oiIdZP?oUW>Y0_nHLZL2oi9`Z0?oU6nV1?nEKj@4oiE]XP?oU6^P1?nAIih3
oheSW@CoR62L0on8Gi`5ohYQW0?oSfFL1?nDJ9`01?nFJIcoVg>Toi]cY?nKLj@4oi]bY0CoVG6T1OnG
L:D2o`000003oiQbY_nIMJWo/j7500?o/j751?ncXlL01?nQMJ;oWWBSoiidXonNM:<4oiU_X@CoUVbP
1?nGKJ04oiQ^X@CoVG2R0onJLJ<00onNMZGoWWFToiieY002oiieY0CoWGFT1OnMMJD3oiefYP03oj^:
/onYR;7oZHRa00;oZHRa1OnXQ[43ojN6/@03ok^^c?ngYLOo]jG700;o]jG71?ncWl@2ol?Lk0?o`LcS
00CoFLf]ogfamOmm/OGoOK7e0_m`__d2oiJCc`CoU9oK1OnBZ^H01?nC]Nko0000oi>ek_nC]Nh2oiFl
lP03oi^[h_nL/NOoW;7W00?oW;7W1OnL]^X2oifik0;oWk?V1OnP^>XDooooo`03o`000?oooooooooo
02Gooooo000>ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05oooo
o`03o`000?oooooooooo00gooooo1?o0g^h3ol35g@?o_lGN00?o^;3AokJ/conf[<l01?nf[<l01?nd
ZLgoZiS3oj^H`on[V<<3ojVD`@GoYi6n0_nUSK`00onMP;CoVgfboi]m/P02oi]m/P?oVW^`1?nHNJh3
oiMg[@CoUWF/1?nFM:X2oiIcZ@03oi9`Z_nBL:SoTW2X00;oTW2X1?nDKjH3oiE_Y0CoUFfR0onDJj04
oi5WWP?oSF>M1On8H9`3ohQOW0CoRV6L0on?II`3oiAXW003oiUbYOnKLjCoVg>T00;oVg>T1?nKLZ@4
oiUaY0;oUg2U0ol00002oiQbYP03ok6NaOncXLGo/j7500Co/j7500Co/j?7oj5eX_nQMJ;oXGFR0onN
M:<5oiU_X@?oUVbP1?nGKJ05oiQ^X@?oVG2R00CoVW6SoiifYOnNMZGoWWJU1?nNMJ@4oieeY0GoWGFU
0_nMMZH2oj^:/`CoZHRa1OnXQ[401?nWQ[7o^jk<ok^^c?nk[/`5okNUa`03ok>Oa?o3g>co`mc/00?o
`mc/00?o`LcSoi^3^?nHR/800onHR/85oiJCc`CoU9oK0_nBZ^H2oifMd`;oW:CK00?o0000oibTfonK
Zn800onKZn85oibai`;oW;KZ0_nP[n85oinciP;oX;SZ0_nT^^TEooooo`03o`000?oooooooooo02Co
oooo000>ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`04ooooo`03
o`000?oooooooooo00_ooooo1?o1fN/00oo0g^ko`<GMol35g@03ol35g@04oko5g_nh/=7o^;3AokR`
d@Co]Zc?00?o[Yg6oj^H`on[V<<00_n[V<<4ojVD`@?oYi6n00CoWXBfoif0]?nMP;CoWH2d1?nKOK84
oiYk/0?oV7V^1?nGMjd3oiIe[0;oUWBZ0_nBLJ/3oi9`ZPCoTW2X1?nDKjH3oiE_Y0CoUFfR0onDJj04
oi5WWPCoSF>M1?n8H9`3ohQOW0CoRV6L0on?II`01?nDJ9coVG:UoiUbYOnILZD4oi]cY0CoVg:T0onI
LJ@3o`0000?oUg2U00CoV7:Vok6NaOnaW/Go/Ik51?ncXLD01OnPM:7oXGFRoj5eX_nQMJ;oY7ZU00?o
WWBS1OnIKj43oiI/X0CoUffP1OnHKZ42oiU`XP03oimgYOnNMZGoWWJU00?oWWJU1?nNMJ@3oieeY0Go
WGFU00?oWGJVoj^:/on[R[<00_n[R[<3ojV8/@CoZ8Ja00?o`KgFok^^c?nk[/`00onk[/`3okNUa`?o
^o7c0_o3g>`00onMO[7oVh>hoi^3^002oi^3^0CoV8[21?nFTll2oiBOf`;oX9O;1OnMWM<01?nLY=_o
0000oibTfonLY=/4oi^[hP;oW;7W0_nQZMd5oj2_hP;oWk?V0onT]^D4ojBjjA?ooooo0_l00008oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<
c009ooooo`003_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00ooo
ool2o`0000_ooooo1?o1fN/2ol75g@Co`<GM00?o^[?BokR`dOnh/=400onh/=400onf[<oo[Yg6ojjM
aP02ojjMaP?oZiS31?nYU<401?nWTKkoWXBfoij4]_nNQ;H4oif0]0?oVgfb1?nJNk04oiQi[P?oUgN]
0_nFMJ`00onBLjcoTW6[oi9aZ`02oi9aZ`CoTW2Z0onBL:P4oiA_YP?oUFnT1?nEKJ83oiA[X0GoTFNN
0on=Hid4ohQPW0?oR5nL1?n:HI`2ohmUW003oi=^YOnILZGoVG:U00;oVG:U1?nKLj@4oi]bY0?o0000
0_nILJ@3oiM`Y@03ok2NaOnaW/Go/Ik500;o/Ik50oncXLD2oj1dX@;oXGFR0_nTNZD4oiidX`CoVFnQ
0onFK:04oiM]X0GoV6jQ00?oVG2RoimgYOnOMjD01OnNMZD4oiieY0CoWGFT0onMMJD00on/SKGoZhZc
oj^:/`03oj^:/`CoZHRa0_nXQ[43ol6mePCo^jk<00?o]jG7ok_alonklO<00_nklO<01?nBTM3oWGja
oien/OnMO[44oi^3^0CoV8[20onFTll00onSTL?oX9O;oj2Gb`03oj2Gb`CoWIgC0_nLY=/01?l0003o
W:CKoi^[h_nKZn82oj6Te`GoXJWM0_nP[n82ojJbh@KoY;KU0_nT^^T2ojVmj1Cooooo00?o0000oooo
ooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9So
oooooiRHV?lQ8B402Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooooiRHV?l@41001?ooool2o`0000[ooooo0oo1dnP00oo1fN_o`LGMol75g@03ol75g@03ol35
gOnj/m;o^[?B00;o^[?B0onh/=400on`XLWo[Yg6ojjMaP03ojjMaPCoZiS30_nYU<400onPQkWoWXBf
oij4]P02oij4]PCoWH2d0onKOK84oiYk/0CoV7V^0_nGMjd01?nCM:goTW>/oi9c[?nBLj`4oi9aZ`Co
TW2Z0onBL:P4oiA_YP?oUFnT1?nEKJ84oiA[X0CoTFNN0on=Hid4ohQPW0?oR5nL0_n:HI`2ohaYY0?o
TfjU1OnILZD4oi]cY0?o000000?oVg:ToiUaY?nILJ@00_nILJ@00onGL:Go/9k5ok2Na@02ok2Na@Co
/Ik500Go/j75oj1dXOnPM:7oX7BQoj5eXP03ojAjY@CoWWBS1?nIKj43oiI/X0GoUffP0onHKZ401?nO
MjKoWgNUoimgYOnOMjD5oiifY@CoWWFT1?nMMJ@2oieeY@;o[8fe1On[R[<4ojV8/@03ojR6/Oo1_MKo
`KgF00;o`KgF0onk[/`3oho_fP03ok_alonGQ[ooXGf/00CoWGja1?nKPkP5oiR:`P04oiJCconSTL?o
Xi73oj>A``CoX9O;1OnMWM<2oibTf`03o`000?nQY=OoXJCG00?oXJCG0onQZMd00onW[mgoY[;QojJb
h@03ojJbh@CoY;KU00?oZK_VojVmj?nY_NP00onY_NPDooooo`03o`000?oooooooooo00Cooooo00Go
410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000002Oooool000kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool00ol0
003oooooooooo`07ooooo`Co`M?X0oo1a=`3ol75g@;o_;KD1Onj/m801?nh/=7o/:79ok2QbOn`XLT4
ojjMaP?oZiS300?oXX^loj27^OnPQkT00_nPQkT4oij4]P?oWH2d1?nKOK83oiYk/0;oV7V^0_nDMZh3
oi=d[@CoTW>/0onBLJ/4oi9`ZPCoTW2X0onDKjH4oiE_Y0CoUFfR0onDJj04oi5WWP;oSF>M00?oS6RU
ohUVY?n9IZ@01On9IZ@4ohaYY0CoTfjU1?nILZD01?nKLjCo0000o`000?l00004oi]bY0?oVG6T00?o
/J78ok2NaOn`W/D00on`W/D4ok6Na@CoX7BQ1OnTNZD3oiidX`CoVFnQ0onFK:05oiM]X0;oV6jQ0_nO
MjH4oimgY@CoWWJU1?nNMJ@4oieeY003oieeYOn/SKGo[8fe00;o[8fe1On[R[<2ojV8/@03olODi?o1
_MKo`KgF00Co`KgF00Go^jk<oho_f_n?km[oW82doiN6_`03oj5m[0GoWGja1?nKPkP2oiR:`P;oYXjl
1?nSTL<5oj2Gb`;oWIgC0_nVVl/3oj>Od@03o`000?nQY=OoXJCG00?oXJCG00CoXJWMojN_gOnW[mgo
YjoM1OnV/^400onT]^GoZK_VojVkiP02ojVkiP?oZKgX00?o[<7Yooooooooool04_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b00Wooooo000Wooooo`03o`000?oooooooooo00Gooooo1?o1c^@00oo1dnSo`LCLol74g003ol74
g003ol75gOnl]]Co_;KD00;o_;KD0onj/m800oncY/co/:79ok2Qb@02ok2Qb@Go[Yg600CoZiS3oj:;
_?nRRkcoXX^l0onPQkT4oij4]PCoWH2d0onKOK82oiYk/003oiEh/?nDMZkoU7J^00;oU7J^1?nCM:d3
oi9c[0CoTW6[0onBL:X4oi9`Z0CoU6nV0onEKj@4oiE]XP?oU6^P0_nAIih2ohm/Y`?oS6RU1on9IZ@4
ohaYY0CoTfjU0_nILZD3o`0000?oVg>T1?nKLZ@00onILJCo/J78ok6Qb002ok6Qb0Co/9k50onaW/D2
oieaX0?oX7BQ1OnTNZD3oiidX`CoVFnQ1?nFK:04oiM]X004oiQ^XOnOMjKoWgNVoimgYPCoWgNU1?nN
MZD5oiieY0;oWGFT00?o[I6iojb=]On/SKD00on/SKD5oj^:/`04ojV8/Oo7e>CoamCTolODi0Co`KgF
00?o0000oib0]?nLP;@00_nLP;@5oj5m[0CoWGja0onKPkP00onZS[SoYXjlojJ>_003ojJ>_0?oXi73
1?nPUl/00onYVLKoYY_;ojJKb`03ojJKb`;oXioA00Co0000oj>OdOnQY=OoXJCG0_nY[=T5ojN_g@;o
Y[;Q0_n[^N@5ojVkiP03ojVmj?n/`NWo[<7Y00;o[<7Y5?ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Wooooo000Woooo
o`;o00001Oooool5ol7>i003ol;4g?o1a=co`LCL00;o`LCL00?o_[[Fokbfe?nl]]@01?nl]]@01?nj
/m;o/jK<ok>Vc?ncY/`4ok2Qb@;o[Yg60_nUT;l4oj:;_0?oX8Ni1?nNQ;H4oif0]0;oVgfb00CoUWZa
oiEh/?nEN;3oUGR`1?nDMZh4oi=d[@?oTW>/1?nBLJ/3oi9`ZPCoTW2X1?nDKjH3oiE_Y0CoUFfR0_nD
Jj000on@KjWoSfbWohm/Y`02ohm/Y`?oS6RU2?n9IZ@3ohaYY0CoTfjU0_l00002oiUbY@CoVg>T0onK
LZ@00oncZ<go/J78ok6Qb003ok6Qb0Go/9k500Co/Ik5oieaX?nMLJ3oWG6P0_nPM:400onXOZOoY7ZU
ojAjY@03ojAjY@?oWWBS1OnIKj43oiI/X0?oUffP00?oWGJWoimgY_nOMjH00onOMjH3oimgY@GoWWJU
1?nNMJ@01?nMMJCo[I6iojfA^On]TKT4ojb=]@CoZhZc00?o`OC`olODi?o7e>@00oo7e>@00oo1_MKo
X7f]oj1m[@02oj1m[@;oW82d00?oY7fXoj5m[?nQOJ`00onQOJ`4oien/@;oVh>h0onZS[P4ojJ>_0Co
Xi7300?oX9O;ojVIa_nYVLH00_nYVLH4ojJKb`;oXioA00?o[:_Eo`000?nY[=T01?nY[=T3ojN_g@03
ojfih_n[^NCoZkWT00?oZkWT0_nY^nH3ojg1j@Co[<7Y5Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Wooooo000Woooo
o`03o`000?oooooooooo00;ooooo0oo0b>43ol7>i0?o`/CL00?o`LCLokjje_nn^]H00_nn^]H4okbf
e003okJ/concY/co/jK<00;o/jK<0on`XLT00onWUL?oYI2oojF@_`03ojF@_`?oXX^l1?nPQkT3oij4
]P;oWH2d0_nGO;<3oiIj/@CoUGR`0onDMZh4oi=d[@?oTW>/1?nBLJ/4oi9`ZP?oTW2X1?nDKjH2oiE_
Y003oi1d[onALZcoTG:/00;oTG:/0on@KjT4ohm/Y`CoS6RU1on9IZ@3ohaYY004oi=^YOl0003o0000
o`0000CoVG:U1?nKLj@2oi]bY0?o/jS=1?naXLP4ok2Na@GoWG6P00CoX7BQojQnYonXOZOoZ7jW1?nT
NZD3oiidX`GoVFnQ0onFK:001?nGKJ3oWGJWoiefYonMMZL5oimgYP?oWgNU1OnNMZD3oiieY003ojnG
__n]TKWo[I6i00;o[I6i1On/SKD2oj^:/`?o`OC`0_o7e>@2oj9kZ0GoX7f]00CoW82dojAmZ?nTOJSo
Y7fX1?nQOJ`4oien/@03oi^3^?nZS[SoZXjh00;oZXjh1?nVS[`3oj>A``03ojfI`onYVLKoZIW600?o
ZIW60onVVl/00on`Zm?o[:_Eojb[e@02ojb[e@03o`000?nY[=WoZJcI00;oZJcI00?oYjoMojfih_n]
^N800_n]^N83oj^ii0;o[/;Y1On]`NT2ojc1j@;o[<C[4_ooool3o`0000Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000002Oooool002Oooooo00Co0000oooo
oooooooooooo1Oo0b>400oo1c^Co`/CLol;4g002ol;4g003oknmeonn^]Ko_[[F00?o_[[F00?o_;KD
okJ/conf[<l00_nf[<l4ok>Vc004ok2QbOnWUL?oYiG3ojNE``CoYI2o1?nRRk`3oj27^@;oWXBf00?o
V7nfoiMl/onGO;<00_nGO;<4oiIj/@?oUGR`1?nDMZh3oi=d[@CoTW>/0onBLJ/4oi9`ZP?oTW2X0_nD
KjH2ohme/@?oT7B_1?nALZ`4oi1_Z@?oSfbW1?n<J:D7ohUVY004ohaYY?l0003o0000o`0000?oTfjU
1OnILZD3oi]cY003oi]bY?ncZ<go/jS=00;o/jS=1OnaXLP01?n`W/GoV6fPoiQ]X?nHKJ03oieaX003
ojMoZOnXOZOoZ7jW00;oZ7jW1?nTNZD4oiidX`CoVFnQ0_nFK:000onIM:SoWGJWoiefY`03oiefY`Co
WgNV0onOMjD5oiifY@03oiieY?n_Ukko[iNn00;o[iNn0on]TKT5ojb=]@04oj^:/oo1m?3o`OC`ol7d
l0;oYG^U0onRNjP4oj1m[@03ojV0Z?nTOJSoY7fX00;oY7fX1OnQOJ`2oien/@03ojj?]_nZS[SoZXjh
00?oZXjh1OnVS[`01?nSTL?o[IW3ojfI`on]VL<5ojVIaP04ojJKbon`Zm?o/:_Cok2[d`?o[:_E00Co
0000ojb[eOnY[=WoZJcI0_n`^^45ojfihP03oj^ii?n^`^Wo[/;Y00;o[/;Y0_n]`NT2ojg6k0Go[<C[
5?ooool02Ol0003oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o
0000oa0@4?nYZJT02Oooool002Kooooo0ol00002oko4gPCo`<SQ0_o2a=/3ol;4g0?o_kgG0onn^]H0
0onh/M;o]Zc?okJ/c`03okJ/c`?o/jK<00?oZY_7ojNE`onWUL<00_nWUL<4ojF@_`CoXX^l0_nPQkT0
1?nJP[WoV7nfoiQo]_nHOkH4oiMl/`CoUWZa0onEN;04oiAf[PCoTgB]0onBLj`3oi9aZ`;oTW2Z0_n@
Mk<3ohmf/PCoSgFa1?n@M:l3oi5b[0CoT6nY0on?K:L4ohaXY@GoRFJT0ol00003ohaYY0CoTfjU1?nI
LZD2oi]cY003okB_e?ncZ<go/jS=00?o/jS=1?naXLP00onBJJ3oV6fPoiQ]X002oiQ]X0;oWG6P0_nW
OjT4ojQnY`CoY7ZU1?nNM:<3oiU_X@04oiYgZonIM:SoVGBXoiUdZ0GoWGJW1?nOMjH4oimgY@?oWWJU
00?o/Io6ojnG__n_Ukh00on_Ukh4ojfA^@?o[8fe00?oON>noiA/XOnUNjD01?nUNjD4oj9kZ0;oX7f]
0_nYP:P4ojAmZ0GoXGf/00CoWGjaojj?]_n^SkKo[Xnf1OnZS[P3ojJ>_003ok:M`_n]VL?o[IW300;o
[IW31?nYVLH00ond[m?o/:_Cok2[d`02ok2[d`Co[:_E00?o0000ok2jhOn`^^400on`^^42ojfihP;o
[lGZ1?n^`^T00on]b^oo[LK/ojg6k003ojg6k0;o[<C[0_n[a>`Eooooo`03o`000?oooooooooo01ko
oooo000Vooooo`03o`000?noa=ko_lCN00?o_lCN00?o`<SQol;4foo2a=/00oo2a=/00oo2a=co_kgG
oknme`03oknme`04okjje_nh/M;o^;7BokRadPGo]Zc?00Co/jK<ojZKaonZVlOoZY_70onWUL<5ojF@
_`;oXX^l00CoVhJloiZ2^OnJP[WoVX:i1?nHOkH4oiMl/`?oUWZa0onEN;04oiAf[PCoTgB]0_nBLj`0
0onAN;CoT7Ncoi1g/`05oi1g/`?oSgJb1?n?MK44oi1d[`?oTG:/1?n@KjT4ohm/Y`?oS6RU0_n9IZ@3
o`0000;oRFJT1?n<JJ@4oi=^Y@CoVG:U00CoVg>TokB_e?nd[mCo]:oD1OncZ<d00onaXLSoTVVPoi9Y
X002oi9YX0?oV6fP00?oWG6PojMoZOnWOjT00_nWOjT3ojQnY`GoY7ZU0onNM:<01?nIKj7oVWN[oiYg
ZonJMj/4oiUdZ0CoWGJW1?nOMjH4oimgY@;oWWJU0onaWlH4ojnG_PCo[I6i00Co[8feoiM[WOnDK:7o
U6bQ0_nXO:@4ojEkY@CoXW^X00?oX7f]ojV0Z?nYP:P00_nYP:P3ojAmZ0CoXGf/00?o]9Bfojj?]_n^
SkH00_n^SkH5ojZ>^004ojJ>_?nbWL;o/Yg2ok:M`PGo[IW300CoZIW6okB_dond[m?o]:oC1On`Zm<0
1On/ZmGo/kkRok>nh_nc_^;o000000?o/;[Q0_nab^`4ojo5jP03ojk2jOn]b^oo[L[_00;o[L[_0on]
a^`2oj_7kPCoZlC/5?ooool00ol0003oooooooooo`0Nooooo`006oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Kooooo00?o0000oooooonoa=h00_noa=h3ol?4f`?o`/CK0_o1`MT4oknme`03ok^ge_nh
/M;o^;7B00?o^;7B0_nf[<l2ojfRc0CoZY_71?nWUL<2ojF@_`;oWH^o1?nKQ[`3oiZ2^@?oV7nf1?nG
O;<4oiIj/@?oUGR`0onDMZh2oi=d[@;oTWVd0onAN;@8oi1g/`?oSgJb0on?MK44oi1d[`CoTG:/0on@
KjT4ohm/Y`;oS6RU0ol00006ohUVY0?oS6VT1?nCKZD2oiUbY@;o/;?J1Ond[m@3ok>Xc@;oSFJQ1?nB
JJ02oiQ]X003oj9lZ_nWOjWoYgnY00?oYgnY0onXOZL5ojAjY@;oWWBS00?oWX2aoiYgZonJMj/00onJ
Mj/3oiUdZ0CoWGJW1OnOMjH3oimgY@03oiifYOnaWlKo/Io600;o/Io61On_Ukh2ojfA^@?oUf^M00Co
U6bQojQlY?nXO:CoZ7bT1?nUNjD4oj9kZ0GoZH2X1?nTOJP2oj5m[0?o]9Bf0on^SkH4ojZ>^003okZV
a_nbWL;o/Yg200?o/Yg20on]VL<00onj]mKo]:oCokB_d`03okB_d`?o/:_C0_nhanH4ok>nhP03o`00
0?nab^co/L[/00?o/L[/0_n_aNX2ojg?lPGo[L[_00?o[LK/oj_7k_n[anh00_n[anh2oj_4k0;oZ<;]
5?ooool00ol0003oooooooooo`0Mooooo`006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00Co0000oooooooooooo_lCN1Oo3a=/00oo2a=_o`L7Iol71f@02ol71f@03oknmeonk]mKo^kOF00;o
^kOF0onh/M800onaZM3o[J;<ojfRc003ojfRc0?oZY_70onWUL<00onOT<CoWH^ooif;_`02oif;_`Co
VhJl0onJP[T3oiQo]PCoUgbc1?nFN[43oiEh/0;oU7J^00?oTgZeoi9i]?nBNK@00_nBNK@4oi5h]0Oo
T7Nc0on?M[84ohme/@?oT7B_1?nALZ`3oi1_Z@?oSfbW0ol00002ohaXY@OoRFJT0on<JJ@3oi=^Y@03
ojF_gon`/m[o/;?J00?o/;?J1Ond[m@01?ncZ<goSFJQoheVXOn=IZ44oi9YX003oiQ]X?nRO:[oXWbZ
00GoYgnY1?nXOZL4ojAjY@03oiidXonNP;7oWX2a00GoVWN[0onIM:P4oiefY`GoWgNV0_nOMjD00ong
[]3o/Io6ok6OaP03ok6OaPGo[iNn00?o[I6ioiM[WOnGJid00_nGJid4ojQlY0GoYG^U0_nRNjP00on_
QZ[oZH2XojV0Z003ojV0Z0CoY7fX00?oXGf/okBD]_ndU;H00_ndU;H4ojj?]P;oZXjh0onjY/H4ok:M
`P03ojfI`onj]mKo^[OF00;o^[OF1?nd[m<00on`Zm?o^<OVokS7iP03okS7iP;o/kkR00?o/M7ao`00
0?nab^`00onab^`00on[e_Ko[Lobojg?lP03ojg?lP;o[L[_0_nYb_44oj_7kP03ojO5konX`^goZ<;]
00?oZ<;]4oooool2o`0001kooooo000Kooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`00
00;ooooo1_o3a=/3ol71f@;o_KgI1Onk]mH01?nh/M;o/JW@ok6Yd?naZM04ojfRc0CoZY_700CoYiG3
oin@a?nOT<CoWi340onMRkl4oi^6_0?oVX:i1?nHOkH3oiMl/`;oUWZa0_nCOKP3oi=l]P?oTgZe1OnB
NK@3oi5h]0OoT7Nc0on?M[84ohme/@?oT7B_1?nALZ`3oi1_Z@?o000000?oSfbWohaXYOn<J:D00_n<
J:D7ohUVY0?oS6VT00?oTfjUojF_gonU[ml00_nU[ml5ok2cfP;o]:oD0on7Hj83oheVX@;oTVVP0_nG
MZ/4oj9lZPCoYgnY1?nXOZL3ojAjY@03oj^B_OnNP;7oWX2a00;oWX2a1?nJMj/3oiUdZ0GoWGJW1?nO
MjH01?nOMjGo]jk@okN^d?ng[]05ok6OaP?o[iNn0_nGJIX3oiM[W@03oj]oYOnXO:CoZ7bT00;oZ7bT
1OnUNjD01?nRNjSo[hJZojn6Z_n_QZX4ojV0Z0CoY7fX1OndU;H4ojj?]P03ojZ>^?njY/Ko^ZK600;o
^ZK60onbWL800onoaMoo^[OFokZgeP04okZgeP;o]:oC0_njeNh4okS7iP03ojkLmonadO7o/M7a00;o
/M7a00?o0000ok7:k?n[e_H00on[e_H2ojg?lP;oYlgd1OnYb_400on[ankoYlG_ojO5k`02ojO5k`;o
Z<;]0_nV`>`Booooo`03o`000?oooooo000001kooooo000Kooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`02ooooo`Ko`lCK00?o`L7IokfmfOnm_MT00_nm_MT3ok^geP03
okBae_naZM3o/JW@00?o/JW@1?n]X/`2ojZKa`03oj:Fb?nOT<CoWi3400;oWi341?nMRkl4oi^6_0?o
VX:i0onHOkH2oiMl/`03oi=o^_nCOKSoTgfh00;oTgfh0onCO;H4oi=j]@CoTWVd0onAN;@7oi1g/`Co
SgJb0on?MK44oi1d[`?oTG:/00CoT6nYo`000?l0003oT6nY0on?K:L4ohaXY@GoRFJT0_n?UmL4oiNS
g@CoYJoO1?n`/mX2ogiPYPCoPVFY0on;KJ/4oiMfZ`CoXWbZ1?nWOjT4ojQnY`04ojAjYOn[T[goZi:m
oj^B_@CoWX2a1?nJMj/3oiUdZ0GoWGJW0onOMjH00onm`=co]jk@okN^d002okN^d0Go/Io600?o[iNn
oiMYV_nGJIX00_nGJIX2oiM[W@?oZgnU0onXO:@5ojEkY@Co[hJZ1?nYP:P4ojAmZ003okZL^_ndU;Ko
]9Bf00?o]9Bf0_n^SkH00oo4^M3o^ZK6okZVaP04okZVaP04ok:M`_noaMoo_lGOoko5g`Co^[OF00?o
]>[gok[Ek_njeNh00onjeNh00onhanKo[]cgojkLm`02ojkLm`;o/M7a0_nTg?/00ol0003oZmKfoj_F
mP03oj?An0CoYlgd0_nYb_43ojK7l@?oYlG_00?oYL7]ojK0k?nV`>`00onV`>`Dooooo`03o`000?oo
oooooooo01_ooooo000Kooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`03ooooo`Go`lCK00?o`<CMokfmfOnm_MT00onm_MT01?nk]mKo];7FokBae_nd/MH5ok6Yd0;o[J;<
00?oYIg=oj:Fb?nRU/P00_nRU/P3oin@a0CoWH^o1?nKQ[`3oiZ2^@;oV7nf00CoU86loi=o^_nCOk[o
Tgnj1OnCOKP3oi=l]P?oTgZe1?nBNK@3oi5h]0SoT7Nc0on?M[83ohme/@CoT7B_00CoTG:/o`000?l0
003o00000on@KjT2ohm/Y`GoRh_>0on<S]45ohnGe`CoUj?M1?nU[ml00on`/m[oPf6Soh=QX`02ogiP
YPCoPVFY0on;KJ/4oiMfZ`CoXWbZ1OnWOjT2ojQnY`03okjbcon[T[goZi:m00?oZi:m0onNP;44oiYg
Z`CoVGBX1?nMMZL00onOMjKo_L3Lokg0g002okg0g0Co]jk@0_naWlH3oiMWV0CoUfVJ00?oUf^Moj]o
YOn[OjD00_n[OjD4ojQlY0?oYG^U00?o^9>`ojn6Z_n_QZX00_n_QZX5ojV0Z0;oY7fX0_njW;X5okBD
]P04ojj?]_o4^M3oa;W@olBid0Co^ZK600?o`^3^oko5gonoaMl00onoaMl00onj]mKo]>[gokCZm`02
okCZm`;o^]G^1?nPiO`2ojkLm`?oU^7n0_nTg?/00ol0003oW=;koj?An004oj?An0;oYlgd0_nSb?85
ojK7l@04ojO5konU`NgoYL7]ojG1k@?oY/3/00?oYKk/ooooooooool04oooool00ol0003ooooooooo
o`0Jooooo`006oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool01Ooo
ool3ol?4f`?o`<CM0onm_MT00ong^]_o];7FokBaeP02okBaePCo/JW@00?oZ:GCojFMcOnUWLd00_nU
WLd3oj:Fb0CoWi340onMRkl2oi^6_0;oUHO20onDQ;l4oiB1_0?oTgnj1?nCOKP3oi=l]P?oTgZe1OnB
NK@3oi5h]0OoT7Nc0_n?M[801?n>Sm3oRXkBohZ>d_n:S]82ohN=d`?o00000_n5S=84ohN;c`SoRh_>
0on<S]44ohnGe`GoUj?M0_nU[ml4oh=QX`?oOV2V0on2IJT4oh]]Z`?oUgJ[1?nRO:X5ojMoZ@04ojQn
Yonn//oo_[;?okjbc`CoZi:m0onNP;45oiYgZ`?oVGBX0onMMZL2okW?jPGo_L3L0_ng[]02oiETU`Go
UfNH0onGJIX5oj]oY@CoZ7bT0_nUNjD3okRC/0?o[hJZ1OnYP:P01?nTOJSo^YbjokZL^_njW;X4okBD
]P03om7Ri?o4^M3oa;W@00;oa;W@0onjY/H3ol;PkP?o_lGO0on5j^@2okCZm`?oNN7b0_nPiO`3ogkM
n`;oU^7n0_nCdOd3oicBn`04o`000?nLd__oXm7hoj?An0;oX<Od1OnSb?82ojK7l@;oY<7^1OnU`Nd0
1?nV`>coYKk/ojFnk?nU_^`Dooooo`03o`000?oooooooooo01[ooooo000Kooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2o`0000Oooooo00?o`lCKol34gOo0a=d00oo0a=d01?nm_MWo]k[KokNj
fong^]/4okBaeP03ok6Yd?nXYM?oZ:GC00;oZ:GC0onUWLd3oj:Fb0CoWi340_nMRkl00onFRlGoUHO2
oiF7`P03oiF7`P?oU8Bo0onDPK`3oi=o^PCoTgfh0onCO;H4oi=j]@CoTWVd0onAN;@2oi1g/`03oi>>
bonAS/goTHk=00;oTHk=1?n>Sm001?n:S];o0000o`000?l00003ohN=d`?oQHcB1?n7Rll7oh^;cP?o
S8kA1On?UmL2oiNSg@04oheVX?n8Hj7oR6>QohQSX@CoPf6S0omnH:H3oh9UZ@CoRff[1?nGMZ/3oj9l
ZPCoYgnY00?ob=WVokjbconn//l00_nn//l4oj^B_@?oWX2a1OnJMj/3oiUdZ003oiefYonicn[o^LoZ
00?o^LoZ0_nm`=`3oi=RUP?oUFBG1OnGIiP3oiMYVPGoZgnU1?nXO:@00onUNjGo^9>`okRC/002okRC
/0?o[hJZ1?nYP:P00oo4[lKo^YbjokZL^P03okZL^P;o]9Bf0ooAh^@4olBid003okZVa_o2h>ko`^3^
00;o`^3^00Co_lGOohGZi?n5j^CoQN[T0olh_//2ogWQlP?oGm3d0_mngO/4oh_<o@?oTm7m0_nLd_/0
0onLaOCo0000oj37m004oj37m0;oXlSb0_nS`>h5ojC1kP;oYL7]0_nT_N/5ojFnk1Cooooo00?o0000
ooooooooool06Oooool001_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooo
oooo00Oooooo1?o0a=d2ok[3h@Co]k[K0_nd/MH2oj^]f@CoZ:GC1?nUWLd3oj:Fb0;oWi3400?oV939
oiJ;aOnFRlD00_nFRlD4oiF7`P?oU8Bo0onDPK`3oi=o^PGoTgfh0onCO;H3oi=j]@;oTWVd0_nDS<T3
oiB=b@CoThk;1?nAS/d01?n>Sm3o0000o`000?l00003ohZ>dP?oQhgC0on5S=84ohN;c`OoRh_>1?n<
S]42ohnGe`03oi1XX?n=IZ3oSFJP00;oSFJP0on8Hj44oh=QX`?oOV2V1?n2IJT3oh]]Z`CoUgJ[1?nR
O:X2ojMoZ@?ob=WV0onn//l5oj^B_@?oWX2a1?nJMj/2oiUdZ0;oZ=Cg1?nicnX2oiASUPCoTf:F0onE
I9L5oiMWV0;oUfVJ0_naQZL4oj]oY@CoZ7bT1OnhTk04ojn6ZP;oZH2X0oo4[lH4okZL^P03okBD]_oA
h^CodN;T00?odN;T0_o4^M03oiWbj`;o`^3^0_mfZo<2oeNio0?oTjOT0on<]o<5ohK2n`;oRlcm0_nI
]nd5oiVolP;oW<Gd00?o0000oj37m?nPao@00onQ_Nd4oj?0kP;oY<7^0onT_>X4ojBmj`;oYKk/0_nU
_^/Dooooo`03o`000?oooooooooo01Wooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o`<CM
ok[3hOnj`n400onj`n42okNjf`03ojfgh?n[[MWoZjgI00?oZjgI1?nXYM<2ojFMc@04oi^LdonIULko
VIG>oiVEcPCoV9390onFRlD4oiF7`P?oU8Bo1?nDPK`3oi=o^PCoTgfh0onCO;H2oi=j]@03oi><bOnD
S<WoU8c900?oU8c90onDSLT3oi>>b`;oTHk=0ol00003ohj?d0CoRXkB0on7SM<3ohF<dPCoQh_?1on;
Rlh2ohb>d@03ohmXXOn@J:3oT6RP00;oT6RP0on=IZ03ohQSX@CoPf6S0omnH:H4oh9UZ@?oRff[1?nG
MZ/4oj9lZP03ojMoZOo8fNKob=WV00;ob=WV1?nn//l4oj^B_@?oWX2a0_nJMj/3oh;Co`CoZ=Cg00?o
^LoZoiMWV?nDHiH00_nDHiH4oi=RUPCoUFBG1?nGIiP01?nGJI[o/HJWok66YonaQZL5oj]oY@?oZ7bT
1OnhTk04ojn6ZP03ojV0Z?o4[lKoa:o600;oa:o61?njW;X00on3i;?odN;Tom7Ri002om7Ri004oiR9
`_l0003oVO;[oiWbj`?oRYGH0_mfZo<00onMW=?oTjOToi>Wi004oi>Wi0?oS;Oc0_n6`_/2oiZ/h`Go
VKO]0_nI_o82oj2diP;oX;[[00?o0000oj2jjonQ_Nd01?nQ_Nd2oj?0kP;oY;[Y1OnT_>X2ojBmj`;o
YKcZ1?nU_^/Booooo`03o`000?oooooo000001[ooooo000Uooooo`03o`000?oooooooooo00[ooooo
0onj`n400on``^Oo[KOPojfgh002ojfgh0GoZjgI0_nXYM<00onMXmWoVicCoi^Ld`02oi^Ld`?oVIG>
0onHT<T3oiJ;a@GoUHO20onDQ;l3oiB1_0?oTgnj0_nCOKP2oi:<bP?oTXc91?nCS<T4oiB<b@?oU8g9
0_nCS//3o`0000?oTHk=0_n>Sm02oafZ^0?oU7>[1?nBKjP3oi1/YPCoSVZT0on=J:<3oheWXP?oSfRQ
1?n@J:03oheVX0CoR6>Q1?n3HJ<2ogiPYPCoPVFY0on;KJ/4oiMfZ`?oXWbZ0onil_<2olSIiP?oVGR]
1?nSOZ`4ojV3Z`03ojf4ZOnSMj;oXgNR00CoP]?o0_nXe?L3oiMWV0?oU6>F1?nCHYH4oiETU`CoUfNH
1?naQZL5oj]oY@;oZ7bT0_o8[/04okRC/0Co[hJZ1Oo4[lH3okZL^P?oPnBc00?odN;Toj:5]?nHRL80
0onHRL82ohZEf0;oYYK51?nMW=<4oi>Wi003oj>KcOnNXmSoWZ?H00;oWZ?H1?nJ[><2oiVgk@;oXZoP
1OnP]>H2oj2jj`04o`000?nP^^_oXKg]oj6mk@;oXkOV1OnT^^T2ojBljP;oYK_X1OnU_>X2ojFnj`;o
Y[kZ5?ooool00ol0003oooooooooo`0Gooooo`009Oooool2o`0000cooooo00Co^/?Qok32ion``^Oo
/<;W1?n]]n02oj^]f@;oWj_O1?nMXmT3oi^Ld`?oVIG>0onHT<T4oiJ;a@CoUHO20_nDQ;l01?n?S/ko
T8g=oi2=cOn@SLd3oi2<b`GoTXc:0onBS<T3oi><b@CoU8c90onDSLT2o`0000;oThk;0_nAS/d3odo<
i@?oUWN^1?nDLj/3oi9_Z0?oT6bV1?n>JZ@3oheXX`?oSFNR0on?J:44oi1XX0CoSFJP0on8Hj44oh=Q
X`?oOV2V0on2IJT4oh]]Z`?oUgJ[00GoXWbZokWblonil_?o^O;coh9X[@03ohe`[@CoVGR]1?nSOZ`2
ojV3Z`03ojR2ZonSMj;oXgNR00;oXgNR1?nLKI`4oiMWV0?oU6>F1?nCHYH4oiETU`?oUfNH00?o^92/
ok66YonaQZL00_naQZL5oj]oY@04ojQlY?o8[/3ob:k0olR^`0Go^9>`0_n_QZX2oloHg`Goa:o600?o
^Ybjoj^6[_n[QZh01?nRQK@3oiR9`P03ojjD_?nVU/GoYYK500?oYYK51?nMW=<01?nCYnCoXi_=oj>K
cOnSVld5oijSf0;oVZcS00?oYJWIoj:_h?nR[n000onR[n04oj2diP;oX;[[00?oY;?So`000?nT/n<0
1?nS]nH2ojBjj@;oY[WW1OnU^nP2ojFljP;oY[cY1OnV_^XCooooo`03o`000?oooooooooo01Oooooo
000Tooooo`03o`000?oooooooooo00gooooo1?n``^L2ojfgh0;oXKCV1?nOZml3oifSf@CoVicC0onI
ULh3oiR@b@;oUX_500?oSi?Cohn@dOn?T=400_n?T=44ohn>cP?oT8g=0on@S</4oi:<bP?oTXc90onC
S<T4oiB<b@?o00000omkeoh2ofcFn004oif3]_nIO;;oVGbboiUl/P?oUWN^1?nDLj/3oi9_Z0?oT6bV
1?n>JZ@3oheXX`?oSFNR0on?J:44oi1XX0CoSFJP0on8Hj44oh=QX`?oOV2V0on2IJT4oh]]Z`;oUgJ[
0_n>i_X4oh9X[@?oSG2]1?nIN:d4oj=n[003ojV3ZonXPZ_oZ8:[00GoXgNR0onLKI`4oiMWV0?oU6>F
1?nCHYH4oiETU`;oUfNH0onhT:`3ok66Y`GoZgnU1?o8[/05okRC/003ojn6Z_o?f=oocmSO00;ocmSO
0_o4[lH00onWQ[7oVhW0oj^6[P02oj^6[PGoXXFd00CoV8W2ojjD_?n^U;co[YBl1?nVU/D2oifLd`;o
ZYW51OnSVld3oijSf003ojZVd_nUZMWoYJWI00;oYJWI1OnR[n02oj2diP;oYZoO0onT/n<01?l0003o
Y;?Soj>gi_nS]nH2ojNgi0CoY[WW0_nU^nP3ojNkj0CoY[cY0_nV_^X2ojRojQCooooo00?o0000oooo
ooooool05_ooool002Cooooo00?o0000ooooooooool03_ooool2ok32i`?oXKk^0onQ]>H4oin[g`?o
WJ?I0_nKW=<01?n@WmkoSi[JohnJf_n?V]X3ohnFe`CoSi?C1?n?T=43ohn>cP?oT8g=0on@S</4oi:<
bPCoTXc90onCS<T3o`0000?oPM?o0_mkeoh01?nRR[_oWH>foif3]_nMPkH3oiUl/P?oUWN^1?nDLj/4
oi9_Z0?oT6bV0on>JZ@3oheXX`CoSFNR0on?J:43oi1XX0CoSFJP0_n8Hj400onCLZ_oSWFcohie/`02
ohie/`?oQGg31?moUn44ogW2oP03ogmSZOmlHj_oO6>[00CoPVR]0on=L:d4oiUh[@?oXgj/00CoYhRc
ojR2ZonXPZ_oZ8:[1OnSMj83oia]W0CoUfNH0onDHiH5oi=RUP?oUFBG00?oUfNHokR@[?nhT:`00_nh
T:`4ok66Y`?oZgnU0_oKnM`4olR^`0?o^9>`0omggkL2oloHg`CoYhJa1?n[QZh4oj:5]003okNH^?n^
U;co[YBl00;o[YBl1?nVU/D5ojZIa@CoXi_=00?oWZ?HojZVd_nZY]800_nZY]84ojFYf@;oXZoP0_nX
[MX5ojJ_g`;oY;?S00?o0000ojReh_nW]n@01?nW]n@2ojJii`;oZ;[V1OnW^nP2ojJlj@;oZ;kY1?nX
_nXDooooo`03o`000?oooooooooo01Gooooo000Tooooo`?o00003oooool5oj6nkP?oXKCV0_nOZml0
1?nAZnSoTJGSoi6UhonAYN<4oi2OgP?oSi[J0on?U]L4ohnCd`?oSi3A0on?S/h3oi2=c@CoT8c;1?nB
S<X2oi:<b@04oh?7oOl0003o0000o`0000?oPlgo0_n1dol4oj::^`?oWH>f1?nIO;83oiIg[P?oU7>[
1?nBKjP3oi1/YP?oSVZT0on=J:<4oheWXP?oSfRQ0on@J:02oheVX0;oTg2X0onCLZ/5ohie/`?oQGg3
1?moUn401?mi`_koOf>YogmSZOmoHjT3ogaSZ`?oPVR]0on=L:d4oiUh[@04oj=n[?nWR;?oYhRcojN8
/`CoZ8:[1?nSMj83oia]W0CoUfNH0onDHiH5oi=RUP?oUFBG1OnhT:`4ok66Y`;oZgnU0ooKnM`4olR^
`003okRC/?nJLJ?oVW6S00Go/8R[1?nWQ[45oj^6[P;oXXFd0ongV;P3ojjD_0?oYYK50_nbW<05ojZI
a@;oXi_=00?o/:K=ojZVd_nZY]801?nZY]82ojFYf@03ojb/eonX[M[oZ:gJ00?oZ:gJ0_nV[ml2oj^d
g`?oZ;GR00Co0000ojReh_nW]nCoYkOT0_nY^ND5ojRjiP;oYk_X0_nY_^T5ojRnj@;oZ;oZ0_nY`>/B
ooooo`;o00002Oooool4o`000003oa0@4?oooooooooo00Oooooo000Tooooo`03o`000?oooooooooo
013ooooo0_nQ_^h2oi2ilP?oTK;]1?nAZnP3oi6Uh`?oT9oN0on?V]X3ohnFe`GoSi?C0on?T=43ohn>
cP?oT8g=0_n@S</3oh:kn@;oPl7k0ol00002oh?7o@;oPlgo00?oZiW5ojJA_onVTKl00_nVTKl4oj::
^`?oWH>f0onIO;83oiIg[P?oU7>[1?nBKjP3oi1/YP?oSVZT0on=J:<4oheWXP?oSfRQ0_n@J:000onB
KjOoTg2Xoi=`Z002oi=`Z0CoTg:[1?n>MK<4ohEm``;oOiOQ0_n9G9H3ohMKV0?oQEfK1?n2J:d3ohe`
[@;oVGR]00?oW86fojN8/onWR;<00onWR;<3ojR2Z`CoXgNR0onLKI`4oiMWV0?oU6>F1OnCHYH3oiET
U`Go^92/1?naQZL00on[OjGofoWLom_ig003om_ig0;ob:k000?oXgJPoiYaXonJLJ<00_njT:X5ok28
Z`;oYhJa0_ngT:h4oj^6[P03oj:5]?ngV;So]iRh00;o]iRh1?n^U;`01?nVU/Go/Yc0ok:L`?nbW<04
ojZIa@03okJYc?n`Y/go/:K=00;o/:K=1?nZY]800ona[]Go[:cGojb/e`02ojb/e`?oZ:gJ00?o[[CN
oj^dgon[]=l00on[]=l3ojRehP03o`000?nY^NGoZKWU00?oZKWU0onX^^H00onY_^SoZKkYojVnj@03
ojVnj@;oZ;kY0_nY`>X5ojW0ja?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09
ooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool0
0ol0003oooooooooo`0Booooo`?oT;Wb0onA/^d4oi6[j0?oTJGS0on@Wmh3ohnJfP?oSiKG0_n?Tm<2
oh2]l@CoP:ob0on1/_@5oh6fm`05oh:knOl0003o0000o`000?n3`O/00_noaMh00on_XLWoZiW5oj^I
a@02oj^Ia@CoYY6o1?nRR[/3oif3]P;oVGbb00CoSVjZoha[Z?n<JjSoS6^X0on;JJL4oh]XY@?oRVNU
1_n9IjD4ohUXYP?oSF^W0onBKjL5oi=`Z0?oTg:[1?n>MK<3ohEm``;oP^S;0on9G9H3ohMKV0?oQEfK
0on7I:<01On2J:goSG2]ohe`[On=L:goVGR]00;oW86f1OnWR;<3ojR2Z`CoXgNR0onLKI`4oiMWV0Co
U6>F1?nCHYH2oiETU`;o_IZe1?nhT:`4ok66Y`Co/H>R1OnSMZ001?nJLJ?o^Y2ZokZ@Z_njT:X5ok28
Z`04ojN6/OngT:ko]i2^okN@[PCoZhJ^1OngV;P3ojjD_003ok^T`_nbW<3o/Yc000;o/Yc00onZVLD2
okJYc0Go/:K=00?oZZKBok6^eOna[]D00_na[]D4ojb/e`04ojR]f_n^]=ko[[CNojjdgPCoZkCO00Go
Z;GRoj^ii?n[^NCo0000oj^ii004ojVii@03ojRji_nY_^SoZKkX00;oZKkX0onY_^T6ojW0jP;oZL3[
0_nY`N/Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool000Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool04oooool3oi2ilP?oTK;]0_nAZnP00on1[o;oPJgaoh6]l@02oh6]l@?o
P:c`1?n0Zo03ogn/l0?oP:ga1?n0[o83oh6bm0;oPKKg0ol00003ol7:h@03ok>Yc_n_XLWo[j7900;o
[j790on[VLD4ojJA_`;oXXZk0_nCMk03oi1b[@?oSVjZ0on<JjP3oh]YY`CoRfRU0on:IjD6ohUWY@Co
RFRV0on=JjL4oi9_Y`CoTg2X0onCLZ/5ohie/`03ohEm`on2j<_oP^S;00CoREbF0on7FiP3ohEMV`Co
QfBS0on>LJd4oib1]PCoYhRc0onXPZ/4oj=gXP?oW6fL1?nGIiP4oiASUPCoTf:F00CoUFBGokfJ]Onm
V[Go_IZe1OnhT:`2ok66Y`03olBI[?naPj;o/H>R00;o/H>R1OnSMZ001?nJLJ?o^Y2ZokZ@Z_njT:X5
ok28Z`Co]i2^1?n[QZh00oo0Xk_o]iRhokNH^003okNH^004ojjD_?nkY<;o^jC2ok^T`PCo/Yc000?o
ZYW5okJYc?nfZL`00_nfZL`3ok2Vc@03okRee_na[]Go/JkE00?o/JkE0_n/[=L2ok:hg@Go[[CN0_n[
]=l2ojjkh`?oZkWT00Co0000oj^ii?nY^NGoZKWU0_n[_^P4ojVnj003ojVnjOnY`>[oZL3Z00CoZL3Z
1onY`N/Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool000Wooooo00Go
410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0
5Oooool3oh6cm@?oPK7c0on1[o84oh6]l@?oP:c`1?n0Zo03ogn/l0?oP:ga0_n0[o84oe?6m0;o0000
1?o1cN@01?o1b^7o/jW>ok>Yc_ncZLh3ojnQb@CoZiW50_nVTKl00onGO;?oTgN`oi=g/002oi=g/0?o
T7:]1?n>KZX3oha[Z0?oRfVW0on;J:D3ohYWY@OoRFNU0on9J:H4ohe[Y`?oTVnW1?nCL:P4oi=bZ`?o
SWFc0_nom?02oh]MUPCoREbF0on7FiP3ohEMV`CoQfBS1?n>LJd3oib1]PCoYhRc0onXPZ/4oj=gXPCo
W6fL1?nGIiP3oiASUP?oTf:F00?o_:K3okfJ]OnmV[D00_nmV[D5okR@[004ok66Yon]PZKoa9V/olBI
[0?o/H>R1OnSMZ04okZ@ZPCo/8R[00?oaZBfokN@[_ngT:h00ongT:h2oj^6[P;o`:>k1OngV;P4ok^T
`P?o/Yc000?o_kC?okJYc?nfZL`00onfZL`00on`Y/go^;GFokReeP02okReeP?o/JkE00?o]KgPok:h
gOnb^=d00onb^=d2ojjdgP;o/;kU1On^^n<2oj^ii003ojboj?l0003oZkkX00CoZkkX0_nY_^P2oj[1
jP?oZL3Z0_nY`^`9ojW1ja?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09oooo
o`002Oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`00
01Kooooo0on1/oD3oh6al`?oPJob0_n1[O43og>hn`?oKk_m1?m[__h3ofG2oP;oGLGk00?o?l:nogKS
eol000000_l000000oo0c^Go`LgTol7=i002ol7=i003okJ_d_ncZLko/jW>00;o/jW>1?n_XLT2oj^I
a@04oi^3^?nGO;?oUgbcoiMl/`CoTgN`0on@LZd4ohi^ZP?oS6^X0on;JJL3oh]XY@?oRVNU1on9IjD3
ohUXYPCoSF^W0onBKjL4oi=`Z0CoTg:[00CoSWFcokodl?nom?3o_oC`0on;GIH4ohULUPCoQe^H0on5
GI/3ohMTX`CoSW6]0onLPKH4ojN8/`CoZ8:[1?nSMj83oia]W0CoUfNH0onDHiH2oi=RUP?o_:K31?nm
V[D3okR@[003ok23Y?n]PZKoa9V/00;oa9V/0onaPj85oj=fX0Go^Y2Z0_n`R:/2olJT]PGo]i2^00Co
ZhJ^ol2S^oo0Xk_o`:>k1?ngV;P00oo;^l_o^jC2ok^T`P03ok^T`P04ok:L`?no]<oo_kC?okndc`?o
]ZW<00?o_L;MokRee_nh]MH01?nh]MH01?na[]Go]KgPokFmh?ne_N03ok:hg@03ok;5j?n`_^Go/;kU
00?o/;kU0_n^^n<3ojg3j@?o[;oX00?o0000oj^nj?n[_^P00_n[`^/5oj[1jP03ojW0j_nY`^coZL;/
00;oZL;/0_nY`N/2ojW2k0GoZL7[4Oooool3o`0000Oooooo00?o0000ooooooooool02Oooool000Wo
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000oooo
ooooool06?ooool3ogbbmP?oN[?g1?mg]_T3og>hn`?oKk_m0_m[__h2odS5j@?oFM;P0ol000000onf
k?Ko`<kUol3>i@02ol3>i@03ol7=i?nf[m;o]ZoB00;o]ZoB1?ncZLh2ojnQb@04oj2:_?nKPkSoVh>h
oi^3^0CoUgbc0onCMk03oi1b[@CoSVjZ0on<JjP3oh]YY`?oRfRU0on:IjD7ohUWY@?oRFRV1?n=JjL3
oi9_Y`CoTg2X1?nCLZ/2olGTkP03okodl?n<GYKoRefF00?oRefF0on9G9H4ohMKV0?oQEfK0on7I:<4
ohia[@CoW86f1?nWR;<3ojR2Z`CoXgNR0onLKI`4oiMWV0?oU6>F00?oTf:FokbV`onlY/<00_nlY/<4
okfJ]@05okR@[?n`PjCo/8>Tok23Y?n]PZH00oo4VJ`4ok63XP?oXgJP0_o2WK84okZ@ZP03ok28Zoo6
Y;KoaZBf00;oaZBf0ongT:h00oo@`L_o`:>kol2S^`03ol2S^`;o]iRh0oo;^l/3ok^T`P03olG8gOno
]<oo_kC?00?o_kC?00Co]ZW<okg2gOnm`]go_L;M1?nh]MH00onhbNOo]KgPokFmh003okFmh004ok:h
gOnbaNSo//GXok;5j0?o/;kU0_n]a^`5ojg3j@;o[;oX00?o0000oj_5k?n[`^/00on[`^/2oj[1jP;o
ZL?/1?nY`^`00onY`ncoZL;/ojW2k003ojW2k0;oZL7[0_nX`N/>ooooo`Co000000?oooooo`000?oo
ool01_ooool00ol0003oooooooooo`09ooooo`002Oooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`?oO;;f0omj/oL2ogNfn@?o
ML7n0om[aoh2oec9n@?oKmWf0ol00002okKUmP;o_/kV0oo0c^D00onh]MKo]ZoBokJ_dP03okJ_dP?o
/jW>00?oY971oj2:_?nPR[`00_nPR[`3oi^3^0?oUgbc1?nCMk03oi1b[@?oSVjZ0on<JjP3oh]YY`Co
RfRU0on:IjD6ohUWY@CoRFRV0on=JjL3oi9_Y`GoTg2X0_nCLZ/3olGTkP;oS5jF1?n;GIH3ohULUPCo
Qe^H0on5GI/4ohMTX`CoSW6]0onLPKH4ojN8/`?oZ8:[1?nSMj83oia]W0CoUfNH0_nDHiH00on`/][o
_:K3okbV``03okbV``Co_IZe1?n`Pj@4olBI[0Co/H>R0_nSMZ03ol:M/PCo^Y2Z1Oo6Y;H2okN@[P?o
d<7;1?o0Xk/00ongV;Sobk_;ol^kb`02ol^kb`03ok^T`_o5b=goaLSM00;oaLSM0ono]<l2ol7Kk0Co
_L;M00?o^;GFokS9ionhbNL00_nhbNL2okFmh0;o/Lg^1OnbaNP00on`_^Go[LK/ojg6k002ojg6k0;o
[L?Y0_n[b>l3oj_5k004o`000?n[aNcoZl;[oj_2j`;oZLC]1?nY`n`00onY`^coZL?/ojW3k002ojW3
k0;oZL;/0_nX`^`5ojS1j`[ooooo0ol00005ooooo`03o`000?oooooooooo00?ooooo00?oEEEEofIV
I_l000002oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001Oooool2o`0001_ooooo0on2]?D4ogfknP;oML7n1?n8c_h2ogkFo`?o00000ondg?@0
0onfiOKo_/kVokk>iP02okk>iP04ol3>iOnh]MKo^;GFokReePGo]ZoB00Co/jW>ojBA`OnTTL7oY971
0onPR[`3oi^3^0?oUgbc1?nCMk03oi1b[@?oSVjZ0on<JjP3oh]YY`CoRfRU0on:IjD6ohUWY@CoRFRV
0on=JjL4oi9_Y`CoTg2X00CoTg:[olGTk_o5i>koaNC^0on<GYH4oh]MUP?oREbF1?n7FiP3ohEMV`Co
QfBS1?n>LJd2oib1]P04ohQNVon=I9goSFBMoheTW@CoU6ZO0onJKYl01?nSMj;oW6fLoia]W?nLKI`4
oiMWV004oiASU_n`/][o/;;Jok2bfPGo_:K30_nmV[D5ok23Y004onkXaOo4VJcoa9V/olBI[0Co/H>R
00?oXgJPol:M/_o2WK800_o2WK84okZ@ZP03onW/coo6Y;KoaZBf00;oaZBf00?o]i2^om31boo@`L/0
0_o@`L/3ol2S^`;od^gV0oo;^l/00onjkoCoaLSMolG8g@03olG8g@03okndcoo1fnco`M_/00?o`M_/
0_nm`]d2ok?Hl`?o^<WW0_n[fOP4ok7=kP;o//GX0_n/c?44ojg6k003ojS;l_n[b>ooZlS_00?oZlS_
0_n[aN`00onXa^oo0000ojW4k@04ojW4k@;oZL?/0_nXa>d3ojW3k0;oZ<;]1?nX`^`2ojS1j`;oYl7/
1_ooool4o`0000Sooooo00?o0000ooooooooool04Oooool000Wooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`0Kooooo`?o
P[Ce0_mm^oX3ohk4n@;oR<kn00GoX=Kko`000?l0003o0000oicQo@04okCLm0;o_<cV0onnc^H00onj
^]Wo^;GFokReeP03okReeP;o]ZoB0_nYVLH4ojBA`@?oX8Zl0onKPkP4oiMl/`?oTgN`0on@LZd4ohi^
ZP?oS6^X0on;JJL3oh]XY@?oRVNU1on9IjD3ohUXYPCoSF^W0onBKjL2oi=`Z0Co]]Oa00?oaNC^oh]N
V?n<GYH00_n<GYH4oh]MUP?oREbF1?n7FiP3ohEMV`CoQfBS0on>LJd01?n=k]OoR5jKohQNVon8GY/4
oheTW@?oU6ZO0onJKYl3oie_W@;o;ZC`0on1]_H4ok2bfPGo_:K300?o_IZeojn4Y_n_Q:H00on`Pj@2
onkXa@Coa9V/0onaPj86ol:M/P;o^Y2Z0_oYk<l4olJT]PKod<7;00?o`:>kom;]i_oBkNH00_oBkNH0
1?o;^l_o^^odok[_m?njko@3olG8g@?oVnkf0_o1fn`2oiKSo@Go/mSc00?o^<WWoj_In?n[fOP00_n[
fOP2ok7=kP;oY]7g1?n/c?400on]a^coZ<_bojS;lP02ojS;lP;oZlS_0_nWb?43ojS6k`04o`000?nX
a^ooZLC]ojW4k@;oZ<G^1OnXa>d00onY`ncoZ<;]ojS2k@02ojS2k@;oZ<;/1_nW`N`2ooooo`?o0000
3?ooool00ol0003oooooooooo`0Aooooo`008_ooool00ol0003oooooooooo`0Mooooo`CoT[[b0_n>
a?T01?nRb_Co0000o`000?l00002oj3Fn`?o/m?a00?o]=cdokc<i_nlc>H00onlc>H01?nnc^Ko^[[I
okZjfOnj^]T3okReeP03ojfQbonYVLKoZIW600;oZIW61?nTTL44oj2:_0?oVh>h0onGO;<3oi=g/0?o
T7:]1?n>KZX3oha[Z0?oRfVW0on;J:D3ohYWY@OoRFNU0on9J:H4ohe[Y`;oTVnW0_nQb?@4okKGl@?o
RejH0on<GYH4oh]MUPCoREbF0on7FiP4ohEMV`?oQfBS00CoSW6]ohg^eon=k]OoQU^H0on8GY/4oheT
W@?oU6ZO1?nJKYl4oie_W@04oie^Von1]_KoPKKfoh6fmPCo/;;J0_nlY/<00on]QZco[hBVojn4YP02
ojn4YP;o/8>T0oo^j<D4olBI[0;o/H>R0_o@am45ol:M/P04okZ@Z_oYk<oojNc?onW/c`?oaZBf0_nj
n^X4om31b`;oUYSC0_oBkNH3o`0000Co^^od00?oaLSMoi_^m_nKk_H01?m:anL3oiKSo@;o/mSc0onD
g_h2oj_In0;oVMCl1OnVdOL2ojc<l@?oY<kf0_nXbo82ojC9l`CoYlSa0_nXa^l00onVa_3o0000ojK6
l004ojS5kP;oZ<C]0onW`nd2ojS2k@WoYl7/0_nW`>/00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo013ooooo000Rooooo`03o`000?oooooooooo01kooooo0_nB^_82oj>ok@;o00000_nRb_@2
ok7:k0?o/m?a0onkbND3okc<iP;o^[gL1?nj^]T01?nh]MKo[J7;ojfQbon]XL/4ojVIaPCoY9710onP
R[`3oi^3^0;oUgbc00CoSGVhohYe]_n:MKKoRWFf0on8LkD3ohIb]004ohi^Z_n<JjSoS6^Xoha[Z0?o
RfVW0on;J:D3ohYWY@OoRFNU0on9J:H2ohe[Y`?oTK3/1?nQb?@00onfeo7oRUnJohYOVP04oh]NV0?o
S5jF0on;GIH4ohULUP?oQe^H1?n5GI/2ohMTX`?ob?SZ0_n6FiP3ohQNV`CoSFBM0onDJYl4oiY^W`Co
WFnM0onMKY/01?nJJYWoPKKfok2bf_n`/]X4ojf6[0Co[hBV00?o/8>TonkXaOo^j<D00oo^j<D3olBI
[004ok63X_o@am7od<OAom37d@Co`Yfb0_nWSk`4onW/c`03olJT]_njn^[o^_[Z00;o^_[Z00?od<7;
ok2G_OnFV=<00_nFV=<00on]V<7oVYS@oiZHd002oiZHd0GoO:?/0om;ZOP4odNkm0CoI]3i0_nDg_h3
ohO@o`?oVMCl0_nVdOL3oic?n@;oY<kf0_nPbOD5ojC9l`;oYlSa0_nUa_43ojK6l004o`000?nVa_3o
Z<G^ojS5kP;oY/?^0onW`nd2ojO1k@KoYl7/0_nW`>`5ojO0ja3ooooo00?o0000ooooooooool04?oo
ool002;ooooo0_l0000Pooooo`?o00000_nS_nd00onRb_Co/L[/ok7:k002ok7:k003ok?ClOnkbNGo
^lWU00?o^lWU00?o_<cVokZmg?nj_M`00_nj_M`2okZjf@03ok2Xd?n]XL_o[J7;00;o[J7;1?nYVLH4
ojBA`@;oX8Zl00CoUH>noi5n^onAO[_oTGjk0on=NKP3ohYe]P?oR7>e1?n6L[@3ohIb]@?oQW>g0on7
MkX3ohUl_PCoSHC50on<SLl4ohVJg@GoTK3/0_nQb?@01?n<HigoRUnJohYOV_n:GiX4oh]NV0?oS5jF
0on;GIH4ohULUPCoQe^H0on5GI/01?n7I:?ob?SZolShj_o8n>X3ohIKV0?oR5jK1?n=I9d4oiAZW`?o
VVjO1?nMKid2oie^V`03ojFC`onZRkGoZX^e00;oZX^e1?n]QZ`4ojn4YP?o[8bc00?o]Xn]ojj6Z_o^
j<D00_o4VJ`00onVPZgo0000om37d@02om37d@?o`Yfb00?o/XnaojN?_?niU;000oniU;04ojJ:^0Go
/9Nm00CoUYSCojfH`On]V<7o[IS11?nJV=02ogbSk0?oX:?G0on:ZNX5og^in@?oMLCn0_n7d?l2ohg4
nPGoT/ck0_nLcoT2oi_6mPCoX<We0_nTbO<2oj;5lPGoYLKa0_nVa_000onU`nko0000ojK3kP04ojK3
kP03ojO3kOnW`NgoYl7]00;oYl7]0_nW`N`6ojO0k0;oYl3[0_nW_n/@ooooo`03o`000?oooooooooo
013ooooo000Rooooo`03o`000?oooooooooo01cooooo0ol000000oooooooXko]oj>ok@03ok32i`?o
/L[/0_nia^@4ok_9i@;o^l3N0onj_M`00onc[mCo/:S@ok2Xd002ok2Xd0Co[J7;0_nYVLH00onNTLKo
VH[2oiV:`P02oiV:`PCoUH>n0onAO[/3ohei^0?oRWFf0on8LkD3ohIb]0CoQW:e0on6LkL3ohMg^P?o
RGbn1?n=Q<D3ohb=c`CoRI[M0_nA/>`2ohmXX@CoS6>M0_n:GiX4oh]NV0?oS5jF0on;GIH4ohULUPCo
Qe^H0on5GI/2om?ShP03olShj_n8G9SoQU^H00;oQU^H1?n8GY/3oheTW@CoU6ZO0onJKYl2oie_W@;o
XikA1?nUTl<4ojZ;]@Co[HJ/0_n_Q:H00on]RJoo[8bcojb</`03okJ?[@Co[XJZ0_nVPZd3om37d@03
ol:M/_nbSk7o/Xna00Ko^IB`0_nVR[P2ok^K]`Co/9Nm1?n]V<43oiZHd003ok6Rb?nPXmOoX:?G00Co
X:?G0on:ZNX2og^in@;oUZkW1On<^?<3ohg4nP;oT/ck0_nG`O@5oi_6mP;oX<We0_nO`o84oj;5lP;o
YLKa0_nT`^l3ojG3kP04o`000?nU`nkoY/?^ojK3kP?oY/7]0_nW`Nd2ojK0k0OoYl3/1_nW_n/?oooo
o`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo01Wooooo0ol00006ooooo`Co
/<;W00?o/L[/okW6i?nia^@00_nia^@00onkbNGo^l3Nok_0gP03ok_0gP04okZmg?nc[mCo/joDok>_
e0Co/:S@0_n]XL/00onSVL_oWY76oijAaP02oijAaP?oVH[21?nEPkh3oi5n^`?oSGVh0on:MKH3ohQc
]@?oQW:d1?n6L[D3ohIc]`?oQgNj0on9O;h4ohf4a@CoS8g?0_n9V]d2ogaOYP?oNEbU1?n<Hid3ohYO
VP?oRejH0on<GYH3oh]MUPCoREbF1?n7FiP2ohEMV`;odn?R0on8G9P4ohIKV0?oR5jK0on=I9d4oiAZ
W`;oVVjO00?oXjOJoj>NdOnSW]400_nSW]44ojFC``CoZX^e1?n]QZ`01?n_Q:Ko[HV_ojf9[on/S;<4
okJ?[@Co[XJZ00CoYX:]okfG/OnmUk7o_INa1?nbSk400oo2WkCo^IB`okVD/003okVD/004ojJ:^?nk
VkOo^i^gok^K]`?o/9Nm0_noX[/4ojfH`@04oiZHd?naX/So/J;8ok6Rb0CoX:?G00?o[ZG>oj6VfOnQ
Y]T00_nQY]T4oiJ^i`;oS;Sc0_nM/^L5oiVjk`?oUl7d0_nKa_H2oijol0GoWl?b0_nRaO82oj?1kPCo
Y<;_0_nU`nh00onU`>go0000ojK1k@03ojK1k@03ojJojonV`>coY/3/00?oY/3/0_nW`>`:ojNoj`oo
oooo00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool05_ooool3o`0000[ooooo
0_n``^L3okS3h`;o^LKT0onj`]l3ok_0gP03okJffOnc[mCo/joD00;o/joD0on`Z=000onWXM3oXiW;
oj>Ib`02oj>Ib`?oWY761?nIR/83oiF3_P?oTGjk0on=NKP3ohYe]P?oR7>e1?n6L[@3ohIb]@?oQW>g
0on7MkX3ohUl_PGoSHC50_n<SLl3oh5UZ@;oO5nV0omiG:D2og=JYP;oS6>M0on:GiX3oh]NV0?oS5jF
0on;GIH4ohULUPCoQe^H00CoQEfKom?Sh_oChn;oSF2I0on8G9P4ohIKV0?oR5jK0on=I9d2oiAZW`;o
YZWI1?nSYmX4oj>Nd@?oYI?31?nZRkD3ojf6[0Co[HV_1OnfSjd4ojj6ZPGo_INa0_nbSk42ol:O]0Go
^IB`1OnkVkL01?n`Ukgo_j:koknR^onoX[/4ojfH`@Go/J;800?oX:?GojjUc_n^YLh00_n^YLh4oj6V
f@;oUZkW0_nU[]d4oifbi`;oVK[_0_nR]NH5oijjk0?oW[o`0_nO`o82oj:nk@GoXl7^0_nT`^l2ojFo
k0?oYL3]00?o0000ojK1kOnV_n/00onV_n/2ojK0k0ooYko[3_ooool00ol0003oooooooooo`0@oooo
o`008_ooool2o`0001Cooooo0ol0000>ooooo`?o^<?S0_nj`n45ok[2g`04ok_0g_nf]]Wo][KIokJf
f@Co/joD00Co/:S@ojNQd?nWXM3oYj7@0onSVL/3oijAaPCoVH[21?nEPkh3oi5n^`?oSGVh0on:MKH3
ohQc]@?oQW:d1?n6L[D3ohIc]`?oQgNj0on9O;h2ohf4a@04oi=j]On9KZkoRFj^ohU^[P?oPFFY0oml
GjH2ogULY@CoLeZV0on:GiX3oh]NV0?oS5jF1?n;GIH3ohULUP?oQe^H0_o;c=/00ooChn;oSF2IoheP
V@03ohQLV0CoQU^H0on8GY/2oheTW@03ojNQd?nVZMWoYZWI00?oYZWI0onSYmX4oj>Nd@CoYI?30onZ
RkD00on]QZco[HV`ojf9/004ojf9[`Go]Xn]1?n^QZX00oo2XkWo_INaokfG/@02okfG/@04ok:?/Oo2
WkCo`Yndol:O]0Co^IB`00?ob:Zkok^K]onkVkL00onkVkL4oknR^`?o[IS10_nlY/<4ok6Rb0Go[ZG>
0_nQY]T2ojn/e@GoYJkM0_nM/^L00onV/=ooX[GVoj:eiP03oj:eiP;oW[[/0_nT]nH4oj>kjPCoX[k]
0_nS`Nh2ojFmj`GoYKo/0_nU`>d00onV_^_o0000ojJoj`02ojJoj`;oYkkZ4OnW_n/=ooooo`03o`00
0?oooooooooo013ooooo000Qooooo`;o00004_ooool3o`0001;ooooo00?o^<?Sok[3hOnj`n400_nj
`n42ok[2g`?o^;gM1?nf]]T2ok>_e003oj^YeOnWXM3oYj7@00;oYj7@0onSVL/4oijAaP?oVH[21?nE
Pkh3oi5n^`?oSGVh0on:MKH3ohQc]@?oQW:d1?n6L[D3ohIc]`?oQgNj0_n9O;h00onORkkoTgZeoi=j
]@02oi=j]@;oRFj^0on1IJT3ogaOYP?oNEbU0omcFZH2ofeIZP04ohYOV_n;GYSoRejHoh]NV0?oS5jF
1?n;GIH3ohULUP;oQe^H0oo;c=/3ohePV@?oR5bH1?n6FiP2ohQNV`03oj:A`onWXM3oYj7@00;oYj7@
1OnVZMT3oj>WfP?oXikA1?nUTl<2ojZ;]@03ojZ8/_n]RK3o[HV`00;o[HV`0_n]RJl2okfL]`Go]Xn]
0_n^QZX2ol:S^@Co_INa1Oo2Wk@2okVD/0?ob:Zk0onkVkL00oo9/<7o_j:koknR^`03oknR^`04ojfH
`OnlY/?o_:K3okbV``?o/J;80_nlZlP3ojjUcP03okR_dOn_[=Go[jcE00?o[jcE0onU[]d00on][mWo
Y[3OojJ`g`02ojJ`g`?oX[GV00?oZ;GRojBgi_nT]nH00onT]nH4oj>kjP;oX[k]0_nU^nT4ojFmj`;o
YKo/0_nV_NX3ojJnj`03o`000?nV_^_oY[o[00CoYkkZ0_nW_n/2ojNnjPgoYko[3?ooool00ol0003o
ooooooooo`0@ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o
000000?o410@ooooooooool00oooool00ol0003oooooooooo`0?ooooo`;o00005_ooool3ok[3h@;o
^L?R1Onh_Md2okJff@03ojjafon[ZMGoZjWE00;oZjWE1?nWXM03oj>Ib`;oWY7600CoU9;?oi2=cOn@
SLgoT8g=1?n;RL`3ohR7c0?oQ8O>0on1Rm<3ogjBg0CoNJ3[1Om[]_/01?li^^OoT7Jboi1f/_n@M[83
ohQ/[@?oP6FZ00?oTgZeohU^[_n9KZh00on1IJT3ogaOYP?oNEbU0omcFZH3ofeIZP?oRejH0on<GYH4
oh]MUP?oREbF00?oQe^Hol_<foo;c=/00_o;c=/3oh9UZ@?oR5bH0_n6FiP2oiV2^0CoXY731?nWXM02
ojJYf@CoUW>Y0_nHLjP00onMP[KoY8JdojB6]002ojB6]0CoZXRb1?n]RK001?n]RJoo_IbgokfL]onm
W;L5okJ?[@04ojj6Z_o2XkWo`Z>iol:S^@Co_INa00?odKc6ol:O]?o2Wk@00_o2Wk@00oniU;3ob:Zk
olRZ^`02olRZ^`;o^i^g0oo9/<43oknR^`03olZea_nlY/?o_:K300?o_:K300?o/J;8okb[b?nlZlP0
0_nlZlP01?n^YLko^:oAokR_dOnh[m44ojn/e@03ojF^gOn][mWo[JoI00;o[JoI1?nV/=l01?nR]NKo
Z;GRojReh_nX]N84ojBgiP;oXk_Z0_nV^NH5ojFkj@;oYKg[0_nV_>T4ojJmjP;oY[k[00?oYkgYo`00
0?nW_^X02OnW_^X<ojNoj`gooooo00?o0000ooooooooool03oooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00cooooo0ol0000Iooooo`03ok[3hOni`n;o^L?R00;o^L?R0onh_Md00ona^^3o[[7Kojjaf`02ojja
f`CoZjWE0_nWXM001?nMX=KoVIWBoiVId_nIVM84oiBBc`?oT8g=1?n;RL`3ohR7c0?oQ8O>0on1Rm<3
ogjBg0CoNJ3[0_m[]_/3oiV2^0?oT7Jb0on8K:d4oh1UZP;oNV6Z00CoRFj^oh5UZOn1IJWoPFFY0_ml
GjH3ogULY@?oLeZV0om]FJX2ofmR/`04oh]NV?n<GYKoS5jFohaNUPCoRefF0_n9G9H2okVde@?oblcK
00CoMU^Voh9UZOn2IJWoPVFY0on=LZl5oiV2^0?oXY730onWXM03oiQg[@;oUW>Y0_nDNkD3oif2]PCo
Y8Jd1OnZR;82ojf9/003ol6ab_nmW;Oo_Ibg00;o_Ibg1?nfSjd00oo7_M;o`Z>iol:S^@03ol:S^@;o
_INa0_oA_<H4ol:O]0Gob:Zk00?o^i^golV``Oo9/<400_o9/<42oknR^`?ob[G60onlY/<00oo4]/go
_:_8okb[b002okb[b003ol:id_nh[m7o^:oA00?o^:oA0_n_[=D2okJbePCo[JoI0_nV/=l2ojfdgPGo
Z;GR0_nT]nH2ojVgh`CoY[WV0_nU^nT2ojNki`GoY[cY0_nV_NX2ojNlj@?oYkgY00?o0000ojNnj_nW
_^X01onW_^X=ojNoj`cooooo00?o0000ooooooooool03oooool000Oooooo00Go410@oooooooooooo
oooooa0@400;ooooo`Go00001Oooool2o`0000[ooooo0ol0000Mooooo`Go^L?R00Co^;gMok6jh?na
^^3o/K[P1?n^/M/2oj^Ye@03oj6WfonMX=KoWJ3F00;oWJ3F0onIVM83oiBBc`?oT8g=1?n;RL`3ohR7
c0?oQ8O>1?n1Rm<3ogjBg0;oNJ3[1?nST<43oiV2^0?oT7Jb0on8K:d3oh1UZP?oNV6Z0on1IJT2ogaO
YP?oNEbU0omcFZH3ofeIZP?oKf:c0on<GYH4oh]MUP03ohULU_ni]=Go^KCE00;o^KCE00?oblcKogIK
Y_mfFjH00on2IJT4oheb[`CoVH:h1?nRTL<00onWXM3oQG2doh]d]002oh]d]0CoU7^e1?nMP[H3ojB6
]0GoZXRb00Co[HV`ol6ab_o1/L[o`K7:1?nmW;L2okJ?[@;oakgB1Oo2XkT01?nmUk7odKc6om6la_oA
_<H3ol:O]0;oclG@1?o8Z[/5olV``@03oknR^oo:]LKob[G600;ob[G600?o_:K3olBfcOo4]/d00_o4
]/d2okb[b0?o`[WB0onh[m400onk^]So][;FokJbeP03okJbeP;o[JoI0_nb]]`4ojfdgP;oZ;GR0_n/
]n45ojVgh`;oY[WV0_nY^^D4ojNki`;oY[cY0_nX_>P5ojNlj@;oYkgY00?o0000ojRmjOnW_^X00_nW
_^X2ojRnjPCoYkkZ0_nW_n/2ojRoj`OoYko[0_nX`>/;ooooo`03o`000?oooooooooo00oooooo0007
ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00006ooooo`03o`00
0?oooooooooo00Kooooo0ol0000Qooooo`;o^L?R0onb`^H4ok6jh0;o[[7K00?oY:oPoj6WfonQYm/0
0_nQYm/3oifPePCoVIWB0onDT/l3oi2=c@CoRhW<0on8Ql`3ohB7cP;oPH_C0_mBao800oo6hngoa]WW
ojbNb@02ojbNb@?oXi310onIP[P3oi1f/P?oR6b]0on0IJX3ogYQZP?oLUn]0omlGjH2ogULY@CoLeZV
0om]FJX2ofmR/`?oOGK10_n;GIH2oiVEcPGo^KCE0omfFjH4oh9UZ@?oSG:_1?nIP[P3oj:A``03oh9b
^?n5L;CoQG2d00CoRgBd1?nDNkD3oif2]PCoY8Jd0onZR;800oo2d>Go`K7:ol6abP02ol6abPCo_Ibg
00?o]Xn]olNmd_o7_M800_o7_M83ol:S^@03olGij_oA_<KodKc600?odKc600Co`Yndolo5d?o?aM3o
clG@0oo8Z[/2om?Df@CobK311Oo:]LH5olBfc@03okb[b?o2^M;o`[WB00;o`[WB00?o^:oAok^jf?nk
^]P00_nk^]P3okJbeP03okRlg?nb]]co/[KL00?o/[KL0_n]]=h2ok2ig`Co[;OQ0_nY]n<2ojbji0Go
ZK[U0_nW^nL2ojVkiPCoZ;cX0_nW_>T2ojRmj0?oZ;gY00?o0000ojRmjOnW_^X01?nX_^X2ojNnjP;o
Z;oZ1?nX_n/2ojNoj`OoZ<3[2_ooool00ol0003oooooooooo`0?ooooo`001oooool01Ol0003ooooo
oooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003oooooooooo`03oooo
o`?o00009_ooool4ok;2iP;o/K[P0_nW^>D3ojB_h0CoXJOK0onMX=H2oiVIdP04ohjViOn:Y>KoRZCV
ohZTiPGoQJGY0on0Z^l4ogZcm`;oKL7n0oo6hnd00onc[M;o[9k9ojbNb@02ojbNb@?oXi310onIP[P3
oi1f/P?oR6b]0on0IJX3ogYQZP?oLUn]0_m/I;P01?mlGjKoNEbUogULYOmiG:D3og=JYP?oKEVZ0om_
H[<2ogef`@GoVIG>0oni]=D00om^F:OoMU^VogIKYP02ogIKYP?oPVFY0on=LZl5oiV2^003oj:A`on2
L[SoPW:h00?oQG2d0on;M;@4oiAk]@?oWH:f1?nTQ[@00onZR;;o`]3Uol;@i@02ol;@i@?o`K7:0onm
W;L2ok?^m`CoakgB0_o2XkT3olGijP?odKc600?oU^kcolo5d?o?aM000oo?aM001?o8Z[_odmCIom?D
fOoCe=T3olV``@;oc<kK0oo:]LH2olc@g0?oa;K=0_o4b=h3ol:idP03ol78gonk^]So^k[H00?o^k[H
00?o][;FokRlg?nh_=`00_nh_=`3ok:fg003ok>lh?n`^Moo/;WO00?o/;WO0_n/]n42ojjkh`Co[;[T
0_nY^^D2oj^kiPGoZK_V0_nX_>P2ojVmj0CoZ;gX0_nX_NT00onX_^Wo0000ojRnjP03ojRnjPKoZ;oZ
0onX_n/9ojS0j`[ooooo00?o0000ooooooooool03oooool000Oooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03ogMgMoo<c<co000000Gooooo00Co0000oooooooooooooooo0ol0000Zooooo`;o
//;V0_nX`>/4ojNhi@?oY:oP0_nQYm/00onG[NKoTZWUoi:Yi@02oi:Yi@?oSZKU0on:Y>H5ohFUj@?o
P:[_0_mj/oL3ol7Wl@03okRifOnc[M;o/jgB00;o/jgB0on/W/T4oj>@`@?oVH:h0_n@M[83ohQ/[@Co
P6FZ0_mjHJX4og9O[@;oK6Bh0omiG:D3og=JYP?oKEVZ0om_H[<3ogef`@GoVIG>00Co^KCEodeA]Om^
F:OoKURW0omfFjH3oh9UZ@CoSG:_0onIP[P01?meHJgoPW:hoh9b^?n2L[P3ohE`]0?oRgBd1?nDNkD4
oif2]P;oY8Jd0_n^hoT4ol;@i@Co`K7:00?o_Ibgok?^monck_L00_nck_L3olNmdP03ol:S^Oo5nN[o
aOWZ00;oaOWZ00?odKc6oiK^lonFk_<00_nFk_<3olo5d0;oO^OP1?oCe=T00oo9/<7oc<kKolc>f`02
olc>f`03olZea_o<d=coc=3L00;oc=3L00?oa;K=olC8g_o4b=h00_o4b=h01?o2^M;o`LSOol78goo1
b=l3ok^jf0;o^/CR1?nh_=`00onb]]co/kcPok>lh002ok>lh0?o/;WO00?o/KkTojjkhon^^n<00on^
^n<2ojbji0;o[KgU1?n[^nH2ojVkiP;oZ[gW1OnY_NP2ojRmj0;oZKkY0onX_^T00ol0003oZ;kZojRo
jP05ojRojP;oZ<3[1?nX_n/9ojS0j`Wooooo00?o0000ooooooooool03oooool000Oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Gooooo1?l0000^ooooo`CoZ<3[0_nW
^>D00onK^>coVK;YoiVbj@02oiVbj@?oUjgV1?nBZND3ohjVi@?oRZCV0_n5YNT3oeW;m005oe_Ddonl
io?o_>OcokcWloo1io401?nh^MT4ok>]dP?o[9k90onST<43oiV2^0?oT7Jb0_n8K:d4oh1UZP?oNV6Z
0ombGjd2ofaT^0?oG7WF0omcFZH4ofeIZP;oKf:c0ommM/44oiVEcP?oI4jS00?oCE6eofiHYomfFjH0
0_mfFjH3oh9UZ@CoSG:_00CoVH:hogEQ[OmeHJgoMF6]0_mgJ;@2oh9b^0;oQG2d1?n;M;@4oiAk]@?o
WH:f00?oY8JdojkSnOn^hoT00_n^hoT2ol;@i@;oXY?51?nTTl@3oj:Fb003ojRA_OnYU<7oZIC100;o
ZIC11?nPU/X2ohbKg0;oYig=00?oSIkOoiK^loo?aM000_n=W]l01?mBVO;oO^OPom?DfOoCe=T3oi;X
n@;oc<kK0_nZj_T3olc@g0;o/mkf0oo4b=h2okKGl@Co`LSO00?o^k[Hok[4h_nja>800_nja>82okRl
g0;o]/CT1?nc_>000on`^Moo/KkTok6ni002ok6ni0;o[[_S0_n^_nH5ojfmi@;oZk_V0_n[_^L4ojZm
i`;oZKgX1onY_^T2ojRnj@04o`000?nX_n[oZ;oZojRojPOoZ<3[0_nX_n/:ojS0j`Wooooo00?o0000
ooooooooool03oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003o
oooo00Cooooo0_l0000aooooo`;oZ<3[0_nM_Nl3oi^hk0CoVK;Y0onG[NH2oi:Yi@;oQKkj1Omm`od2
og39o`;oL=ca00CoS^g]okcWlonlio?o_>Oc0_nj`^05okRif@;o/jgB00CoX9O;oiN;aOnGRlGoUh_5
0on=PL03ohEh_@?oO76l0on8K:d3oh1UZP?oNV6Z0ombGjd3ofaT^0?oG7WF00?o[:SCohb1`_m]FJX0
0om]FJX3ofmR/`?oOGK100?oVIG>og1BWom`DYl00omTCZ<2odeA]@?oMU^V1?n2IJT2oheb[`?oO6J_
0_meHJd4ogMX]0?oQG2d0on;M;@4oiAk]@;oWH:f0onLg_d2ojkSn@;oXYK81?nRTlD4ojBCa004oj:F
b?nXTKgoZ96mojRA_@?oZIC10onPU/X00on^Vl?oYig=ojNMc@03ojNMc@;oSIkO0_nUX=44ohfRhP;o
G9oc0_l0OLD4oj[Zn@03olc@g?ncg_Ko/mkf00;o/mkf00?oa<SNokKGlOnfeo400_nfeo42ol78g`;o
]]3]0onja>82ok?;k0Co]/CT0_nc_>02ok;2iP?o/KkT0_n_`^P4ojjoiP;o[KgU0_n/`>P5oj^ni`;o
Z[gW0_nZ_nT6ojVnj@;oZKoZ0onX_nX00ol0003oZ<3[ojS0j`0DojS0j`Sooooo00?o0000oooooooo
ool03oooool002;ooooo00?o0000ooooooooool0;oooool4oifmk`?oVkS/0_nI/^T2ohnkm0CoS;cf
0on5__X2ogg3o@?oO]Wm0_nBjOP3okGSmP03okcWlonj`^3o^/;P00;o^/;P0_nh^MT2ojNRd0CoX9O;
0onGRlD3ohf1`0?oQGRm0_mlLK`3ogI`_P?oP6FZ0omjHJX4og9O[@?oK6Bh00?oG7WFojbXdon/Z=<0
0on<PL83ogIW]0;oHUF]0on1H:<3og1BW`?oI4jS1?m=DKD00onIXmgoPVFYoh9UZ@02oh9UZ@03oheb
[on<Nk_oO6J_00;oO6J_0omeHJd3ogMX]0?oPG_30_n;M;@2oh^Jg0CoUlCf0_nLg_d3ojJQd0?oXYK8
1?nRTlD2ojBCa0;oYXjl1?nXTKd4ojVD`@04oj2Fb_n^Vl?o[Y_3ojjK``?oYig=00?o/Z76ojFPdOnU
X=400onUX=44ohfRhP?oG9oc00?o8iG]o`1maOmOcOL00_mOcOL2ok?NmP?oQ=Oo0_nfeo42oikEn`Go
]]3]00?o^/CRok?;k?ncbn`00_ncbn`2okK4i0;o/LS[1?nb`^H00ona_^Co[l;Xojo2j002ojo2j0;o
[[oV0_n]`^T4ojc0j0;oZkkW0_n[`>T5ojZoj@;oZKkY00?oZL3ZojVoj_nY_nX00onY_nX01?nX_n[o
Z<3[ojS0jol00003ojS0j`;oZ<7[4?nX`>/9ooooo`03o`000?oooooooooo00kooooo000Sooooo`03
o`000?oooooooooo02oooooo0_nM_Nl2oiFkl@?oT[[b1?n?^o@2ohblmPCoS<[m0_n6d_l3oiKQoP04
oi;Yn?nehoKo]N?fokGSmP;o^LOU0onj`^000on][=KoYj;@ojNRd002ojNRd0CoX9O;0onGRlD3ohf1
`0?oQGRm0omlLK`2ogI`_P?oLWG60omjHJX4og9O[@;oK6Bh00?o0000oiV:`_n5LkL00_n5LkL3ohb1
`P;oMVNd0_mREJd2ofEJ/@03oh5PXom`DYooL5:O00;oL5:O0omTCZ<2odeA]@03ojWe_onIXmgoVJ?M
00;oN7C20_mWH;L2ohak^`;oO6J_0omeHJd3ogMX]0?oPG_31On;V]`2oiO4mP?o/[KL0onVXM04oj:F
b0;oXY?500?oX8^mojJ>_?nVS[`00_nVS[`4ojRA_@?oZIC100?o/IVoojjK`on^Vl<00on^Vl<01?nW
WLgo/Z76ok:Qa_nbXLH4ojFPd@;oSJ;R0_nTYmP3ohVWj@CoI:Of0_mG/o/00oln]?;oQ=OoohCGo`02
ofg5o`CoW]Gk0_nfd>d2ojKAm`Co/l_/00?oZLcbok78jonab>/00onab>/2ok;2iP03ojk6k?n_`^So
[l;X00;o[l;X00?o[<G/ojg2jOn]`^T00on]`^T2ojc0j0;oZl;[1?n[`>T2ojZoj@;oZ/7[1?nY`>X2
ojVojP?oZL7[0_nX`>/00ol0003oZ<7[ojS1j`04ojS1j`;oZ<3[0_nX`N/<ojS0j`Sooooo00?o0000
ooooooooool03_ooool002Cooooo00?o0000ooooooooool0;oooool4oiFkl@?oT[[b0_n?^o@3oi34
n@;oS<[m1?nHeod2oiKQoP?o/=cf00?o]N?fokW7iOnianD00_nianD01?nj`^3o[JcFojf/e_n][=H4
ojNRd0?oX9O;0onGRlD3ohf1`0?oQGRm0omlLK`3ogI`_P;oLWG61?mbRM/4og2ko@?oVH[20on5LkL3
ofmP/@;oMVNd0_mREJd3ofEJ/@CoL5:O0omTCZ<00om=DKGoW[W/omC[i@02oiVSg@?oN7C20omWH;L2
ogaV[`?oMF6]1?mgJ;@3oh5k``?oRi[L00?oBlBVol[Gi?o:en@01?nb]]`3ojJQd0;oXYK800?oVXW0
oj2;_OnPRkd00_nPRkd4ojJ>_0CoZ96m00CoZIC1ok6I_onaVKoo/IVo1?n^Vl<4ok:QaP?oYJ3A00?o
/JK=ojBWf?nTYmP00onTYmP3ohVWj@CoI:Of0omG/o/4ofg5o`;oW]Gk0on=c_d3ojKAm`03ok?;k?nY
c?;oZLcb00;oZLcb0_nab>/2oj[:l0Co[/K/00?o[l;Xojc5k?n/aN`00_n/aN`2ojg2j@;oZlC/1On[
`^/2oj_0j@;oZ/;[1?nZ`N/2ojW0jPGoZL7[0_nX`N`2ojS1j`04o`000?nX`N_oZ<7[ojS1j`;oZ<7/
1OnX`N/2ojS0j`03ojS1jonX`>_oZ<3[00GoZ<3[0_nW`>/7ooooo`03o`000?oooooooooo00kooooo
000Uooooo`;o0000<?ooool2oiFkl@;oU[_a1?nC_oD2oi34n@CoV/gj0_nHeod3ojcEm@;o/=cf0ong
b^P2okW7i@03ok6dfon][=Ko[JcF00;o[JcF1?nWX]04oj2Gb`?oUh_50on=PL03ohEh_@;oO76l0omf
L;h3og9eaPCoLXWK00?oL;_mojnWcon_Yll00onIR/83ohEc]`?oKf2a00?oHUZcogIW]?mREJd00_mR
EJd2ofEJ/@?oMW;100?oL5:OofA>XomTCZ<00_nN^N`01?oDjnGoUi7;of]V^om[I[/3ogQd`P?oIf2g
0_m/Ik/01?mlIZooMF6]ogEQ[OmeHJd3ogMX]0CoPG_300?oRi[Lol[Gi?o:en@00_o:en@2ok:fg0;o
VY?<0onHRl@4oiZ9`0?oX8^m1?nVS[`3ojRA_@03ojnG__naVKoo/IVo00;o/IVo0on^Vl<2okNP`PCo
/Z7600CoYJ3Aok6VcOnaY/go/JK=0onTYmP00on`Zm?oWj[NoinZgP02oinZgPCoR:c]1?me/oP3og2l
o@;oSLkm0_n;aO/5oi[<n@;oZLcb0_nQboD4oj[:l0;o[/K/0onYanl2ojc5k0;oZLK^1?n[a>`2oj_2
j`;oZL?]1OnZ`^/2oj[1j`03ojW2k?nY`N_oZL7[00;oZL7[00?oZ<;/ojS1k?nX`N`00onX`N`2ojS1
j`03o`000?nX`NcoZ<7/00?oZ<7/0_nX`N/2ojS1k0CoZ<7[0_nX`>/7ojO0j`Kooooo00?o0000oooo
ooooool03_ooool002Oooooo00?o0000ooooooooool0;_ooool4oiJkl@;oTkoe1?nKa?@2oi[=nP?o
ZLgc0_n/eOD2okC9jP?o]l[X00?o/k[Ook6dfona]=/00_na]=/4ojf/eP;oYj;@00?oVYG>oi:=bonB
SL/00_nBSL/3ohZ7bP?oP8?<0omhQ]@3ogaa_0;oMW2n1?mbMLH2og:9f`04ol?7gOn_Yloo[jO?ojnW
c`CoVH[20_n5LkL3ofmP/@;oHUZc00?oMVNdof9E[OmREJd00omUF[43ogIb`@?oW[W/1?nGTL/2of]V
^`;oN7C20omWH;L3ofaW^`?oMF6]0omgJ;@2oh5k``04oikYnoo1mjkofoCOom_dg`;ob]OT00?oZZWE
oiZCc?nJTl`00_nJTl`4oiR;a0?oVXW00onPRkd4ojJ>_004ojRA_On_Ukko[iNnojnG_PGo/IVo00Co
[Y_3okNP`_ngX<;o]j320onbXLH00onjZ<Oo/JK=ok6Vc@03ok6Vc@04ojBWf?n`Zm?o/:_Cok2[d`Co
Wj[N0_n8[>d2oib_i@CoS;?`1?n1^OP3oh_5n`;oV/ci0_nEa_P5oj7;m@;oZ/[`0_nTb?82ojW7k`;o
Y/Oa1OnYa^h2oj_4k0;oZ<G^1?nY`nd2oj[2j`;oZ<?]1?nY`^`00onY`N_oZ<;/ojS2k002ojS2k0;o
Z<7/0_nX`^`3ojS1k003o`000?nX`NcoZ<7/00OoZ<7/0_nX`N/2ojO1k0SoYl3[1_ooool00ol0003o
ooooooooo`0>ooooo`00:?ooool00ol0003oooooooooo`0^ooooo`;oU[_a1?nM_Nl2oi_4m0;oYlK_
0onYcO<2ok77jPCo]<WZ00Co]l[Xok>jgonc^]oo/k[O1?na]=/2ojf/eP03oj6NdOnJULkoVYG>00;o
VYG>0onBSL/3ohZ7bPCoP8?<0_mhQ]@4ofVBiP;oA;3g0_mbMLH00oo;h>So`lOMol?7g@02ol?7g@?o
[jO?0onIR/83ohEc]`;oKf2a0omRF[<2of9E[@?oIEZa1?mfL/400onN^NcoalkOolO>g`03oiNAb`;o
JfJk0_mSGkP00omhM<;oIf2gofMP]`03ofaW^`?oOgo91OnC[>L01?o1mjkofoCOom_dgoo1b>04ojZY
e@CoVY?<0onHRl@3oiZ9`0CoX8^m0_nVS[`00onYU;oo[iNnojnG_P03ojnG_P?o/IVo00?o]j71okNP
`_ngX<800ongX<801?nbXLKo^ZS7okZXaonjZ<L3ok6Vc@03okV/cOn`Zm?o/:_C00?o/:_C0_nOZ]h2
oj^_fPCoW:oU0_n</o02oiZcj@?oSkSb1On?`?L3oiG6n0;oXL_e0onMa_@2ojC8lP;oXLKc1?nVao42
ojW6kP;oY/G_1OnXaNh2ojW3k@;oZ<C^1?nX`nd2ojW2k0?oZ<?]0_nX`^`2ojS2k@CoZ<;/0_nX`N`0
0ol0003oYl7/ojS1k005ojS1k0OoYl7/2?nW`>/5ooooo`03o`000?oooooooooo00kooooo000Yoooo
o`03o`000?oooooooooo02oooooo0_nM_Nl3ojO0k0CoYlK_00?oZLgcok77j_naanX00_naanX2okC9
jP;o/[gR1?nc^]l2ok6df`03ojJVe_nQW]7oXIkA00;oXIkA0onJULh4oi:=b`?oRXO:0on0Pl`3ogR6
e0CoJI;V00?oA;3gol_Pj?o;h>P00_o;h>P2ol?7g@04oinNdon=R<WoSHS9ohf8b@?oMgG30on5LkL3
ofmP/@;oHUZc0_m;GlD00omREJgoIEZaofEJ/@03ogIb`@04omohfOo7c]ooalkOolO>g`?oUi7;0om[
I[/2of=O^0?oIf2g0om/Ik/3ogmob@?oTjcW00?o`ON^om_dgooKm=l00oo1b>03ojZYe@CoVY?<0onH
Rl@4oiZ9`0;oX8^m00?oXHo2ojVD_onYU;l00_nYU;l4ojnG_P04ok6I_ongXL7o]j71okNQ`@Co]j32
00?o_JW6okZXaonjZ<L00onjZ<L01?naY/go^Jc=okV/cOni[<d3ok2[d`03okNadon[[m[oZjoJ00?o
ZjoJ0_nL[nD2ojNbh0CoV[?Y0on?^?82oho0m`;oUkgb1OnG`_D2oig6m0;oWLCc1?nQa_<2ojK7l@;o
Y<Ga1?nVaNl2ojS5kP;oYlC_1OnXa>h2ojS3k@;oYl?]0_nX`nd2ojO3k@GoZ<;]0_nX`^`01_nW`^co
Yl7/ojO1k?nW`Nco0000ojO1k0;oZ<7/2?nW`N`2ojO0k0WoYl3[1?ooool00ol0003oooooooooo`0>
ooooo`00:_ooool2o`00037ooooo1?nW`>`2ojO6k`?o[lCY0_naanX2ok;0i0Co/[gR0_nc^]l00on[
[][oYZKFojJVeP02ojJVeP?oXIkA1?nJULh3oi:=b`?oRXO:1?n0Pl`3ogR6e0;oJI;V00?oL^3XolW^
kOo9k^d00_o;h>P00on`/m_oWikCoinNd`02oinNd`?oSHS90_mgML<2ofa]`P04ohEc]om_H;7oKf2a
ofmP/@?oHUZc0_m;GlD3ofEJ/@03ogIb`OoOn=Wo^/?Q00?oR97F00CoalkOoiNAbonGTL_oUi7;0_m[
I[/2of=O^0;oIV_300CoIf2gofaW^om/Ik_oK6Nk1?moOlT01OnC[>Oo__VgomomdOoOoM7ofNKN00Co
`LSP0onZZMD3oiZCc0CoV8_40_nJRL000onHRlCoXHo2oj6?`P02oj6?`P?oZIBo0on_Ukh00ondWl?o
]j71okNQ`@03okNQ`@;o]j320onmZLH3okZXa`03okn`boni[<go^Jc=00;o^Jc=00?o/:_CokNadong
/M<00_ng/M<2oj^_fP;o/K;I1OnW/^02oiZcj@;oY;KU1?nK^>`3oiNmlP;oUl;e0_nK_o45oig4l`;o
XLKc00?oXL?aojC5lOnTaO400onTaO42ojK5k`;oYLC`1?nWa>l2ojS4kP?oYlC^0_nW`nd2ojO3kPCo
Yl?]0_nX`^d2ojO2k@CoYl;/0onW`N`00ol0003oYl7/ojO1k005ojO1k0KoYl3/2OnW`>/3ooooo`03
o`000?oooooooooo00kooooo000/ooooo`03o`000?oooooooooo02oooooo0_nW`>`2ojk1j0?o[lCY
0_na`NH4ok;0i0;o/[gR00?o[KCMoj^^f_n[[]X00_n[[]X4ojJVeP?oXIkA0_nJULh01?nAW]coRYcO
ohZLgon:W=l4ohJRiPGoPJob0_moc?l01?n/nNOobNk]olW^kOnkan<4ok2cf`?oWikC0on=R<T3ogMe
``;oK6g20om_H;43of9J/`?oBeo50_nbmnl01?oOn=Wo^/?Qok[3hOnj`n43ohRAeP?oKW;60_m[I[/3
of=O^0;oIV_31?m/Ik/2ogmob@04okggkonnnKOogogAomomd@?ofNKN0_o1b>001?nTZM[oU9CAoiBD
dOnDU=43ohb9bPCoT8O61?nHRl@3oj6?`PCoZIBo00Co[iNnokBO`ondWl?o]9o31?ngXL400ongX<;o
_JW6okfYaP02okfYaP03okZXaono/<_o_k3;00;o_k3;0_ni[<d2okfcd0?o]k7C00?o^kKEok6bfOna
/]T00ona/]T2ojNbh0;o[[KN1OnT]^D2oi^hk003oj:hj?nM^nkoWK_^00?oWK_^0onK_o42oig4l`;o
Wl7`1?nQ`o42ojC5l@;oXlC`1OnUa?02ojO4k`?oY/C_0_nWa>h00onV`nkoYl?^ojO3kP03ojO3kP;o
Yl?]1_nW`^d2ojO2k0GoYl7/00?o0000ojO1k?nW`N`00_nW`N`7ojO0k0_oYl3[0oooool00ol0003o
ooooooooo`0=ooooo`00;Oooool00ol0003oooooooooo`0_ooooo`Co[/7X00?o[lCYok71i_na`NH0
0_na`NH2ok;0i0;o[kWQ0on]]=d4oj^^fP;oYZKF00?oWZOMoiNRg?nGX]`00_nGX]`3oi6Ng0?oRYcO
1?n6X^H2oh6_lP;oJ=_P0_n/nNL2olW^k@?o^lOS1?n`/m/3oinNd`;oSHS90omgML<2ofa]`P?oHg3;
1?mRF[<01Om;GlGo/_O_ok;gkooFolOoenSR00?o^/?Q0on8TMH3ofibaP;oFf?200?oJfJkof=O^?mS
GkP00omVJl<3ogVKi`;o_OO_00?o__VgomomdOoOoM400ooIi]h00oo0an3oY:WJojBYfP02ojBYfP?o
U9CA0on<RLX3oi27aPCoV8_40onQSl83ojVD_`03ojfMa_ndWl?o]9o300;o]9o30ongXL400onmZlSo
_JW6okfYaP03okfYaPGo_k3;00?o^Jc=okfcd?nm/m000_nm/m001?ng/M?o^kKEok^feOnk]]D3ok6b
f@03okJgf_n^]]ko[[KN00?o[[KN0_nT]^D2ojZgh`CoX[SX0_nM^nh2oj>kj`GoWkk^0onO`O02oj73
l@?oX/;`0onSa?02ojG4l0?oY<?_0_nVa>l2ojG3kPCoY/?^0_nW`nh2ojK2k@OoYl;]00?oYl7]ojO1
k?nW`N`01OnW`N`00ol0003oYl7/ojO1k003ojO1k0GoYl3/3?nW`>/3ooooo`03o`000?oooooooooo
00gooooo000^ooooo`03o`000?oooooooooo02oooooo0_n^`NP2ok32i`?o/L7V00?o/;kTojnihOn_
^N400on_^N43ojfdg@;oZjkJ0_nR[Ml3oijWg@CoUj;L0onAW]`3ohZLg`;oQZ;V0_mleoh3oj7`m@;o
_?;b0_nndnX4ok_7h`;o/;?K00CoVIO@ohV8c?n9R<coRHS<0omkO/X2ogMe``?oK6g20omSL</4ogbR
j`03ol;ndooFolOoenSR00;oenSR0onj`n43ohRAeP;oKW;60omKHl82of=O^0CoIV_300GoNI_Wokgg
konmmnooaogSomgmdP02on;ge`03omWVg_o0an3o`<OP00;o`<OP1?nTZMX2oiBDd@?oS8W:1?n@QlH3
oiR;a0CoXHo200CoZIBoojfMa_n]WLKo[Ig61?ndWl<01?ngXL7o_J_8okf[b?nmZlP3okfYaP;o`K?=
0ono/</00oo2^=3o_K?@okfcd003okfcd0Go^kKE00Co/K;IokJgf_nf]m[o][OJ0on^]]h2ok6igPCo
Z[OS0_nR^>P2ojRjiPCoXk_[0_nO_^h2oj>mk0CoX[o^0_nR`_02oj?0kPGoY<;_0_nT`nl2ojG2kPCo
YL?^0_nV`nh6ojK2k@;oYl;]0_nV`Nd4ojO1k@OoYl7/00Co0000ojO1k?nW`NcoYl7/1?nW`>`?ojO0
j`;ooooo00?o0000ooooooooool03Oooool002oooooo00?o0000ooooooooool0;oooool4ok32i`04
ok71i_n`_^Co/;kTok2ni0?o[kWQ00?oZKSTojJbhOnV/^400_nV/^44oj:]g`?oWZOM0_nGX]`2oi:b
k@CoSKWc0_n5aO`3oicSo@04oj7`mOnll_;o_?;bokcblPCo_]?Z0_nkan<00onVY]KoVIO@oiVGd002
oiVGd0?oRHS<0_mkO/X3ofYjd0;oK6g21?mSL</01?mlX^_o`_kCol;ndooFolL3omOXhP04okFkg_nB
U=;oTYCBoi:DdP?oJG;90om^L/H2oe]S`P?oK7_A0_mVJl<3oibfjP;oaogS0_oRmmL3omGQh0;o`<OP
00?oYjgLohnFe_n?U]H00_n?U]H3ohJ:d0?oS8W:0on@QlH4oiR;a0;oXHo200?oXiS9ojfMa_n]WLH0
0_n]WLH3okBO``03okV/c?nmZlSo_J_800?o_J_800?o_JW6ol6ccOo1/ld00_o1/ld01?no/<_o`[S@
ol:hd?o2^=03okfcd0;o`;[D0onk]]D2okbkf0Co][OJ00?o[[KNok6ig_na^Mh00_na^Mh2ojZgh`;o
[K[S1?nX^^H2oj>kj`;oYkcX1?nS_N`2oj:okP;oY;o/1?nS`>h2ojC2k`;oYL7]1OnU`^h2ojG3kPSo
Y/;]1_nV`Nd2ojO1k@SoYl7/00?oYl3/o`000?nW`>`00_nW`>`BojO0j`;ooooo00?o0000oooooooo
ool03Oooool0033ooooo0_l0000`ooooo`;o/<;W0_n_`^L4ok2ni004ojnihOnY^>CoZKSTojVhi0Co
Y[;Q0_nR[Ml00onL/nSoV;7YoiRaj@02oiRaj@CoT[;]0_n=^O<3oiWEo@;oW>?m0_nbkOL4okgJkP;o
_]?Z00?o[kCLojJVe_nVY]H00_nVY]H3oiVGd0?oRHS<0omkO/X2ofYjd0?oJI;V0_mSL</01?m_dOgo
`_kCol;ndoneo=@2omGgh`Co]K_N0onBU=82ofUbb@;oHFk900CoKW;6oe]S`_mKHl;oFf?20om/Nm43
oibfjP;oaogS0_oRmmL3omGQh003oko8hOnW[McoYjgL00;oYjgL0on?U]H3ohJ:d0?oQ8K=0on<R/`4
oiRAb`CoXiS91?n]WLH01?ndWl?o^Jc<okV/c?ni[<`3okf[b003ol2gdOo1/lgo`K?=00?o`K?=1Oo2
^=000onm/m3o`;[Dol2je002ol2je003ok^feOnl^mSo_;_H00;o_;_H0_nf]mX00ong^mco/KWNok6i
gP02ok6igP03ok>lh?n]^^?o[K[S00?o[K[S0_nX^^H00on[^nGoYkcXojNlj003ojNlj0;oXkg/0_nV
_NX4ojBok0;oXl3^0_nU_n`4ojG1k@;oYL;^0_nU`Nd6ojK2k@WoY/7]0_nV`N`6ojO1k0CoYl3/00?o
0000ojNojonW`>/01_nW`>/00onW_n_oYl3[ojO0j`0;ojO0j`03ooooool0003ooooo00kooooo000b
ooooo`03o`000?oooooooooo02kooooo1?n_`^L2ok2ni0;oZkcV1?nY^>@2ojJbh@;oX;GW0onL/nP4
oiRaj@;oT[;]0onGbOT2oiWEo@;oYnGk0_ngf_84okgJkP03okG0hon_]=co[kCL00;o[kCL1?nVY]H3
oiVGd0;oRHS<0omkO/X3ofYjd0?oJI;V0_nTj?/2okGle0;oeOOS0_o:f>@4okFkgP;oTYCB0omYL/T2
of5^b@?oFf?21?m/Nm400onL]^[oaogSolOmh`02omWigP;ofngO00CoeN7Poko8hOnob>7o_lSQ0onW
[M`4ohnFeP?oQX[@0on4Q/d3ohb:c0?oV97;1?nSV<T3ojfMaP03ok6ZdOni[<co^Jc<00?o^Jc<00Co
_J_8ol2gdOo0]m7o`;OA0oo1/ld2ol>me0?o`[S@00?o`l3Gol2je?o0^]@00_o0^]@00ono`=[o_;_H
okbkf002okbkf003okc0g?ng^mco]k_L00;o]k_L00?o/KWNok>lh?nc_>000_nc_>03ojfjh`03ojnl
hon[^nGoZk_U00;oZk_U0_nW_>P2ojVmi`GoY[gZ0_nT_n`00onV_^_oYKo/ojFok003ojFok0;oYL7]
0_nV`>`4ojG1k@;oY/;]2?nV`Nd3ojK0k0;oY/7/0_nV`>`6ojO0k0CoYko[00Co0000ojNojonW`>_o
Yl3[1_nW_n/2ojO0j`;oYko[2?nW`>/00ooooooo0000ooooo`0>ooooo`00<oooool00ol0003ooooo
ooooo`0^ooooo`;o[l;W0_n[`NT4oj^liP;oZKST0_nS^NP4oj2ei`?oW;?X0_nH/NT3oiW2m0;oUlWi
0onRfo/00onWiO_o]m[bokOJlP02okOJlP03okgJk_ne`>?o]L3S00;o]L3S0on_]=`2ojJVeP;oUYgH
0on;U=L3ogj?f@?oNgk:0omZN]000omYT^KoY>SkojCXn`02okGle0;oeOOS1?o:f>@2okFkgP04oi6M
fomjQ]?oNXKCogZ6d`;oJG;90_mQK/T3of^3f@03oe]S`_m/Nm7oK7_A00;oULKh00?obO;]omWig_oI
nMh00ooKkMl00ooAg>7o_lSQoko8h@02oko8h@?oYjgL0on?U]H3ohJ:d0?oQ8K=0on<R/`4oiRAb`Co
XiS900Co[Ig6ok6ZdOnaZ]7o/J[A0oni[<`00onk^MSo`;OAol2gd@03ol2gd@03ol6ccOo3_MCo`kgD
00;o`kgD00Go`[S@ol?0eoo3`=Oo`l3Gol2je004oko0fP03okbkf?nl`=co_<3L00;o_<3L0_ng^m`2
okRog`Co/kcP00?o[K[Sojnlhon__><00_n__><2oj^ki@;o[KgU1?nY_NL2ojJmjP;oZ;kY1?nV_^/2
ojFok0;oYko[1OnV`>`2ojG1k@03ojK0k?nV`NgoY/7]00GoY/7]2onV`>`2ojO0k0SoYko[00?o0000
ojNojonW_n/02onW_n/2ojO0j`;oYko[1?nW`>/00ol0003oooooooooo`0=ooooo`00=?ooool00ol0
003oooooooooo`0^ooooo`CoZl7Y0_n[_>H2ojFljPCoXkWX0_nP]NL2oifmk`CoV[ka0_nI`_@3oioB
nP;oX]_k0onaeo@2okOJlP?o]LSX0_ne`><01?nX/MkoXJOKoj6WfonQYm/4oiJMf0CoRiCG0omnSmT3
ogfHhP?oQK?c0_nWl?H2olcfj@?odN[W0_o:f>@00on_^N7oTIgKoi6Mf`02oi6Mf`;oNXKC0omQMm82
of5^b@CoJh?I00?oULKholWbkOo9l^d00_oInMh3om_]g`?odMcQ0_nob>401?nZ]N7oUJ3LoiFPg?nE
X=`3oh:?f0?oOH[F0on0SMH01?n4Q/goS8[<ohb:c?n<R/`3oiRAb`;oXiS90_nVYMD4ok6Zd@03okV/
c?nk^MSo^kWH00;o^kWH0oo0]m400oo0`]_o`kgDol>me002ol>me004ol;6gOo3`=Oo`l3Gol?0e`;o
`LKN0ono`=X2okk5g`Co_<3L00?o]k_LokRogonh_ml00_nh_ml2ok>lh0;o];kR0on__><2ok2ni0Co
[KgU0_nY_NL2oj^ni`CoZ;kY0_nV_^/2ojRojPCoYko[0_nV`>`3ojNoj`?oY/3/0_nV`Nd5ojK0k0;o
Yko[1_nV`>`=ojNoj`03o`000?nW_n_oYko[00ooYko[0_nW`>/00ooooooo0000ooooo`0>ooooo`00
=Oooool2o`0002oooooo0_n[`NT3ojJok0?oYKcZ0_nS^NP2oinmkPCoWKg_0_nJ__43oik:m`;oWm;j
0on[d_D2ok7Gm0;o]<c/0oneb>P00on]^N;oZ;7NojRagP02ojRagP?oXJOK1?nFWMP3oh^De`CoOXoI
0ommV>800on5/o?oYo3fojO`mP02olcfj@?odN[W00?o`LoUojnihOn_^N400_n_^N43oi6Mf`?oNXKC
0_mQMm83og:?h0;oJh?I0onR`o02olS/k@;oenkS00GofngOom7LhOoAg>7odMcQol7;hP04ojZeh@?o
UJ3L0on2SmP3ogf:eP?oP8gF0on;U=L3oiRNe`GoYZGE0_naZ]42ok>igPCo^kWH00?o`;OAol32foo0
`]/00_o0`]/00oo3_MCo`/KMol;6g@02ol;6g@03ol?0eoo1a]ko`LKN00;o`LKN00?o_l3Jokk5gonn
aMl00_nnaMl2okc0g0;o^l?Q0onh_ml2okO2hPCo];kR00?o[kcSok2ni?n`_^@00_n`_^@2ojfmi@03
ojjni_n[_^OoZkkW00?oZkkW0_nX_^T2ojZnj0CoZ;oZ0_nW_n/3ojRojP;oYko[00?oZ;o[ojNojonW
_n/00onW_n/2ojK0k0KoYko[0_nV`>`@ojNoj`03o`000?nW_n_oYko[00goYko[1_ooool00ol0003o
ooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`0^ooooo`;oY[o/0_nR_^d3oj6mk@CoWkg^
0_nM_Nl3oik5l`;oW/[g0_nWcO@3oj_Bm@;o/<c^1?ndc>`01?neb>So[KWRojfih_n]^N84ojRagP?o
XJOK0onFWMP2oh^De`;oRJ;T0on5[Nl4oi7=o0;o]N[g0_o4k_000ooAj^Oo`LoUol7?i@02ol7?i@;o
[kWQ00GoVJ?Kogj>fOmnS]WoOXkIoi6Mf`02ogZ6d`?oHGOB0ombSn03oj;3l0;ob>c]0ooGk^<2omOX
hP04om7LhOo1bn;o`L_Rol7;hPCoZ[GQ0onEX=`3oh:?f0;oOH[F1?n0SMH3oh^De`?oV9kG1?nVYMD0
0onaZ]7o/kWNok>igP02ok>igP;o^kWH0_nkaN83ol32f`;o_/_T0oo2a]d2okk<i0?o`LKN0_nmb^@3
okk5g`03ok_8i?nk`n7o^l?Q00?o^l?Q00?o^;oOokO2h_ng`^800_ng`^82okBnhP03ok?1i?n`_^Co
/;kT00;o/;kT00?o/<3Uojjni_n^_^H00_n^_^H2oj^ni`;o[;oW1OnZ_^P2ojRojP;oZKoY0_nX_nX2
ojVojPCoZ;o[7onW_n/00ol0003oYko[ojNoj`09ojNoj`Wooooo00?o0000ooooooooool03?ooool0
03Sooooo00?o0000ooooooooool0;_ooool4oj:nk@?oXKg]0_nO_Nh3oio2l@;oW/Gc0_nUb?84ojO=
m003oj_BmOn`c>ko/<c^00;o/<c^0_ndc>`2ojnni@Co[KWR0_nX/Mh00onOZMkoV:?MoiRSg@02oiRS
g@?oSYoO1?n9X^@3ohF]k`03oi7=o?nej_Oo]N[g00?oa>k`0oo4fn/2ol7?i@03ojfghOnIXm_oVJ?K
00;oVJ?K0omnS]T3og>8f@?oHGOB0ombSn000onR`o3ob>c]olS/k@03omO^h`;oenSR0_o=f^<2ol7;
hP03ok2lh_nJZ>3oVZSP00;oVZSP0on8VMd3og^?g0?oNI3M0on0SMH4oh^De`?oV9kG0_nVYMD2ojNe
h`?o/kWN0_nba^T4ok_5hP03ol32fonnbnCo_/_T00;o_/_T00?o`/KMokk<i?nnc>@00_nnc>@00oo1
a]ko_L[Tokg:i002okg:i004okk5gonkb>Co^lSTok_8i0;o^l?Q0onha^@2okO2hP;o]LCU1?nc`N@0
0on`_^Co/<3Uok30i@02ok30i@;o[[kV0_n^`>L4ojboi`;oZ[kX0on[_nP2ojVoj@;oZ[oY1?nY_nX2
ojRoj`;oZ;oZ3_nW_n/2ojNnj`ooYko[00?o0000ojNojonW_n/01OnW_n/<ooooo`03o`000?oooooo
oooo00cooooo000iooooo`03o`000?oooooooooo02kooooo0_nR_^d2oj6nkPCoX<3_0_nO`_42oj?5
l0CoYLSb0_nWcO@3ojg:k`;o/<c^0_n_`^P4ojnni@;o[KWR0_nU[ml3oinYgPCoV:?M0on>Wml2ohVR
i0;oUkkc0onRd_P3okOVmP04olC^l?o4fn_oa=_[olCKj`;o^<OV0on]]n43oiVSf`CoOXkI0_mcR=T4
og:Ch`?oUL7e0onig_800ooGk^?oenSRolgJh`02olgJh`;o`LgT0on`_>84oiZXh0?oR9WM0omkSm`3
ogV@g@;oOiOP1?n;X^@4oiZ]i@CoYkGS00?o/kWNok;6jOnba^T00_nba^T2ok_5hP?o]lo[0_nnbn@3
okW@j`;o_/cT0_njcnX2okg:i0;o^LcY0onkb>@2okO9j0?o^<KT0_neanL4okG4i@;o/l7T0onb`^H2
ok30i@;o/<;W1?n^`>L2ojboi`;o[L3X0on[_nP00on[`>WoZ[oYojZoj@03ojZoj@?oZKoZ1OnX_nX2
ojNoj`;oZ;oZ1_nW_n/2ojNnjPCoYkk[0_nW_n/2ojNnjPKoYko[0_nW_nX3ojNoj`03o`000?nW_n_o
Yko[013ooooo00?o0000ooooooooool03?ooool003[ooooo0_l0000_ooooo`CoXKk^0_nP`>l2oj?1
k`CoXlG`0_nUb?83oj[8k`;o[L[_0_n^`nT4ojo2j0;o[kkU0_nY]N84ojF_g`?oWjWN0_nHXmd2oiJ]
i`?oT[7/1?nG__<01?nRd_So]nKfokOVm_ngi_H3ol3Ok`03olCKjonhanKo^<OV00;o^<OV0on]]n43
oiVSf`?oOXkI0omcR=T4og:Ch`05oiG1mOnig_;o^MkbokWNl_o8in`00oo;h>P00oo=f^?o`LgTol7=
i002ol7=i0?o/;cR0_nJZ>001?n?Xn;oPY[Qoh:JhOn2V^44og^?g0?oNI3M0_moUn04oh^Ri0CoVZgU
0_nW]N<3ojO2k@;o//KY00?o[/oaokO?jongcn/00_ngcn/00onbdo7o^M3[okW@j`02okW@j`04okCB
l?njcn[o^/oZok[?jP;o]=3^1?nic>T00onkb>Co]lWXokO9j002okO9j003okS6i?neanOo]LOW00;o
]LOW0_nea>D2ok?5i`?o//;V00?o/LCXok32ion``^L00on``^L2ojk0i`03ojk1j?n]`>So[L3X00?o
[L3X00CoZkoXoj_0jOn[`>WoZl3Y0_nZ_nT2oj[0j@CoZKoZ2OnX_nX2ojNoj`KoYkkZ0_nW_^/6ojNn
jP;oYko[00?oYkkZojNoj_nW_nX00onW_nX2ojNoj`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool03?ooool003cooooo00?o0000ooooooooool0;Oooool2oj6nkP;oY;o]1?nS`Nl2oj?5l0?o
Z<G^0_nZb>l2ojc3j`Co[/?Y0_n_`^P2oj^ii0CoZKGR0_nU[ml00onO/>?oVZgToiZ]i002oiZ]i0Co
UZgW0onB/N`2oiNnl`;oYmOi0onefo<2ol3Ok`?o_M;Z0_nhanH00onZ^>?oW:[QoibZh@02oibZh@?o
SIgN0omjTn03ognOi`CoU[[`00?o^MkbolSWk?o8in`00oo;h>P2olKGi`?o`LgT00?o/l;Uoj>bhonS
/^<00_nS/^<3ohnShP?oPY[Q0omiU^83ogZKiP?oPZGZ0_n;X^@2ohf`kPCoVk__0_nW`^d2ojG=m0Co
[/oa00?o]lo[ok;ClOnbdo400_nbdo400onid>_o]=;`okCBl002okCBl003ok[?j_ndd>ko]=3^00;o
]=3^0_nic>T3okC=k0;o]lWX0_ncb^/3okG7i`03ok;8j_ncaNOo/lGW00?o/lGW00Co//;Vok74j?na
a>So/LCX0_n``^L2ojo3j0Co[/7X0_n]`>P3ojc1j@;oZl3Y0_n[`NT4oj[0j@CoZKoZ2?nX_nXDojNn
jP;oYkoZ1Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo000mooooo`03
o`000?oooooooooo02gooooo1?nT_nd2oj?1k`?oYl;]0_nXaNh2oj_3j`Co[<?[0_n^`nT2ojbmiPCo
ZkWT0_nY]N82oj>ci0?oWk3S1?nJ[N@2oiJ]i`;oVkg`1?nMaoD01?nWeoWo]M_cokGKlonefo<2okWF
k`?o_M;Z0_nb`nH3ojZhh`CoW:[Q0on=WMh3ogZCh0?oOioW0_nF^_02ok;ElP?o`=_]00?obn3XolKG
ioo6enL00_o6enL01?o1cNCo/l;Uok?2iOnc`^D4oj>bh`?oSj?R0on2V^43ogVFhP?oNY_V0on2YNX4
ohf`kP;oVk__0_nKa_H4ojG=m0;o[/oa0on[doD2ok;Cl@?o[]Cd0_ndd_03ojoBlP;o]=3^00?o/<o`
okC=k?ndcN`00_ndcN`00on`c>ko/l[[ok?:j`03ok?:j`04okG7ionbb>[o//SZok;8jP;o/lGW0ona
a^T2ok74j0;o[lGZ1?n_`nP2ojk1j0?o[L;Y0_n/`NT2ojc2jPCoZl7Y0_nZ`>T2oj[0jPCoZKoZ2?nX
_nXBojNnjPWooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`00?_ooool0
0ol0003oooooooooo`0]ooooo`;oY;o]0onV`>`2ojO2k@;oZ/7[1?n[`n/2ojc3j`;o[;oW1?n/_NH2
oj^ii0;oY[OU1?nS/n@3oin`h`;oVZgT0_nJ]n`4oi^ml0;oWLOe0on/d_@00onefo?o^MK_okWFk`02
okWFk`03okgBj_nb`nKo//?V00;o//?V0onZ^><2oibZh@04oi:Th_n:XN?oRZ7SohZQh`CoPj?Y1?nC
^O401?nbeO;o`=_]ol3KkOo0fnd3olCKj`;oa]OW0_nmcNH4ok?2i@;oXk;S0_nJ[N@3ohVRi0;oP9kV
0omlWnT4ogZKiP?oPZGZ0_n=/>h2oi2mm@CoVlKf0_nUcO@3oj?Am`;oZm?e0onWe?L2ojkDm0;oZ]?f
0_n_d_82oj_Am0Co/<o`00?o]<g/ok3<k_n`c>h00_n`c>h2ok?:j`?o/<[]0_nbb>X2ojo8k0?o/LKY
0_n_a^/4ojo5jP;o[l?X0_n^a>X3ojg2j@03ojg3j_n/`^[o[<;Z00?o[<;Z0_n[`NT00on[`N[oZ/3Z
oj[0jP03oj[0jP;oZKoZ00?oZL3ZojRoj_nX_nX01OnX_nX2ojRnjP[oYkkZ4?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00cooooo000oooooo`;o0000;oooool2ojK0k0;oZL3Z1?nZ
`N/2oj_3j`;o[<3X1?n/_nL2ojbmiP;oZ;[V1?nV]nD2oj>ci0;oX;KW0onN]NT4oiZgk0;oVkg`0onT
b_<2ojcBm0?o/mGa0_nie^l3okG:jP;o//?V00?oZ;SToin^h_nO[^800_nO[^83oi:ThP?oRZ7S1?n3
XnT2oi>il@?oZ<cb00Go`=_]olCKjoo4fn_oa=_[ol7Dj@05okg=iP;o/l;U00?oZ;WUoiZ]i?nJ[N@0
0onJ[N@3ohVRi0;oP9kV0omlWnT3ogjVk@CoQk;b1?n@_OD2oi_6mP?oWLgh0_nSdOL2oj?Cn@;oYmCg
0onVdoP2oj[CmP;oYm7f1?n[dO@2ok3?l0?o[<ka0_n`c>h3ojg;l0;o/<[]0_n]bNh4ojo8k003ok76
jOn_a^_o[lK[00;o[lK[0_n_aNX00on^aN_o[/CZojk4jP03ojk4jP04ojg2jOn]`n[o[L?Zojg3jP;o
[<;Z0_n[`^/4oj_1jP;oZ/3Z0_nY`NX4ojW0jPGoZ;oZ2?nX_^X2ojNnjQCooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0;ooooo`00@Oooool00ol0003oooooooooo`0]ooooo`CoZL3Z
0_nZ`N/2oj_0j@Co[<3X0_n/_nL2ojVli`CoZ;[V0_nV]nD2oj>gi`CoX;KW0onN]NT2oiZgk0?oX<;a
0_nTb_<3ojc@l`;o/mGa0ondcNd2okG:jP;o[[oV0onX^>@4oin^hP?oTZCR0on:XN<2oh>Sj@;oUKS_
0onXc?83okCDl@04olCKjoo1e>Wo`MCYol7Dj@;o_LgV0_nda>H4ojRii@;oVZgT0_nD[>H3ohRUj0?o
PZGZ0omlWnT3ogjVk@;oQk;b0_n=_?H4oiG5n0;oWLgh0onNd?T2oj?Cn@?oXm;h0_nVdoP2ojGAm`Co
Ym7f0_n[dO@3ojS?m0;o[<ka0onZc?82ojg;l003oj_:l?n]bNko[LW^00?o[LW^0_n_b>`2ojg8k@;o
[lK[0_n]a^d4ojk5j`;o[/CZ0on]a>/2ojg3jP;o[<C[1?n[`^/2oj_1jP;oZ/;[1?nY`NX2ojW0jP?o
Z<3Z0onX_nX7ojRnjQSooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`00
@_ooool00ol0003oooooooooo`0]ooooo`;oZL3Z0_nZ`NX4oj_0j@;o[<3X0_nZ_^P4ojVli`;oZ;[V
0_nV^NL4oj>gi`;oX;KW0_nP_>`4oj2nkP;oX<;a0onWbo82ojc@l`;o/<g_0ondcNd00onaaNWo[[oV
ojjoiP03ojjoiP?oZ;ST0_nO[^801?nI[NCoTJWVoi6Yi_nAZNH5oi2]jP?oUKS_00CoZ<cbokCDlOnd
e?7o]=Ca0_nidnh2ol7Dj@;o^lgX1?nda>H2ojRii@;oX;CW1?nD[>H3ohRUj0?oPZGZ1?n1ZNh3ohFb
lP?oSKcf0_nEaOP3oiW;n@;oW]3i0onQd?P2oj?Bn0;oXm7h1?nUdOL2ojOAmP?oY/oe0_nXco@2ojO=
m0;oZ/cb0_nXbo84oj_:l0;o[LW^0on[bNl2ojg8k@;oZlO^1?n]a^d2ojk5j`?o[<K/0_n]a>/00on[
aNco[<C[ojc4j`03ojc4j`;oZl;[00?oZ/?[oj[2jonZ`^/00onZ`^/2ojW1jP;oZL7[0_nX`>X2ojRo
j`CoZ;oZ0_nX_^XMooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool004?o
oooo00?o0000ooooooooool0;Oooool4oj[1jP;oZl3Y0_nZ_nT4ojZnj0;oZKcW0_nW^nP4ojJii`;o
XkOW0_nR^n/4oj2lk0;oX;k^0_nTa_43ojO;lP;o[<_`1?n`cNl01?ndcNgo/LGYok75jOnaaNT2ojjo
iP;oYkSV0onQ/^D4oiV]i0?oTJWV0_n@[NX2oiVjk`CoY<Oa00Co]=CaokWCk_nidnko^M?^0_nhd>`4
ok_=j0;o]<CV0_n/_^L4oj2di`?oU:cV0on8YNP4oh:UjP;oPJW^00?oR;;aohfkmOn=^oD00_n=^oD4
oi?4m`;oVL_i0onMcOP2oj7@n003oj;@n?nSdOSoXm7h00?oXm7h0_nUdOL2ojG?mP;oY/oe0onUcO@2
ojO=m0;oY/_c1?nXbo82oj_:l0?oZLWa0_n[bNl2ojW8k`CoZlO^0_n]a^d2oj_6kP;o[<K/0_n[a^d4
oj_5k0;o[<C[0_nZa>`4oj[3j`;oZ/;[0onY`^/2ojW1j`;oZ<7[1?nX_n/2ojRojR3ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`00A?ooool00ol0003oooooooooo`0]oooo
o`CoZ/7Z1?nZ_nT2ojZnj0;oZ;gX1?nW^nP2ojJii`;oY;cZ1?nR^n/2oj2lk0;oXl;_1?nTa_400onW
bo;o[<_`ojc;l002ojc;l0;o/<g_0_n`b>`2ok75j@;oZkkW1?nW^>H3oj6bi@;oVJgT0_nH/>L3oiFa
j`CoVK[_0_nTao43ojo=l003okWCk_nhd>co^=3/00;o^=3/0_nkcNP3ok?6j0?o[;kW0_nP]>L2oi^b
j0?oTZgX0on9Z^/4ohN/kP?oR;;a1?n=^oD2oi?4m`;oVLSg0_nMcOP2oj3>m`CoX]3h0_nSdOP3ojC?
mP;oYLof0onUcOD2ojG=m0;oYL_c1?nVbo<2ojS;lP?oYlWb0_nYbO400onXb?7oZLS_ojW8k`03ojW8
k`;oZlO^0_nZanl2oj_6kP;oZ/K^1?n[a^d2oj_5k0;oZ/G]1?nZa>`2oj[3j`?oZL?/0_nY`^/00onX
`NcoZ<7[ojS1j`03ojS1j`;oZ;o[9?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo0015ooooo`;o0000;oooool3oj[1jP;oZ[oY0onY_nT3ojRmj0;oYk_X0onU_NX3ojBljP;o
X[_[0onS`>h3oj?2k`;oY<Ka0onYb?02ojc;l0;o[/W]0_n`b>`2ojg1j@CoZkkW0_nW^>H00onR]NKo
WK7VoifaiP02oifaiPCoV;3W0onE/N/2oiVjk`?oXlC`0_n_cO03ok??kP;o^=3/0onebn/2ok?6j0;o
[L7X0onU^^L4oi^bj0?oTZgX0on9Z^/2ohN/kP;oSK?`0on?^O<4oiC1mP;oVLSg0onNb_L3oj3>m`;o
X]3h0onTc_H2ojC?mPGoYLge00?oYL_dojG;lonUbo<00onUbo<2ojK;l`;oYLWb0_nWbO82ojK8l@Co
Z<Sa0_nYb>l3ojS7l0;oZ/O_0_nYanl4oj[6kP;oZlK]0_nZa^h4oj[5k@;oZ/C/0onYa>d2ojW3k003
ojS2kOnX`NcoZ<7/00;oZ<7/0_nX`N/Yooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02oooool004Oooooo00?o0000ooooooooool0;Oooool4ojW0j`;oZKoY0_nW_n/4ojJnjP;oYKgZ
0_nT_^`4oj>ok@;oXl3^00?oYL?_ojK5konVaNl00_nVaNl2ojW8l0?oZlS^0_n^bNd2ojg4j`Co[L7Y
0_n[_^L2ojJiiP?oX[GV1?nM/NH2oiR`i`;oVkO[1?nL^nh2oj?4l0;oZ/W`0onccnh2okC=k@?o]L_[
00?o/LKZojg1j?n]`NP00on]`NP3ojFji`;oVk;X00?oVK;Yoi:`jonB/>/00_nB/>/4ohf_k@?oSK?`
0on?^O<2oiC1mP?oV/Gf0_nNb_L2oj7;m@CoXlgf0_nTc_H3ojG=m0;oYLge00?oYL_cojG;m?nUbo@0
0_nUbo@2ojG;l`?oYLWc0_nUbO82ojG8lPCoY/Sa0_nXb?43ojO7l0?oZ<O`1OnYanl2oj[6kP03ojW6
konZa^koZ/K^00?oZ/K^0_nZaNd2ojW5kP;oZLC]0_nXa>d4ojS2k@;oZ<7/;?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00_ooooo0018ooooo`03o`000?oooooooooo02gooooo0_nY
`>/2ojO0j`CoYko[0_nV_^X2ojFok0CoY;k/0_nS_nd00onU`^koYL?_ojG3k`02ojG3k`;oY/G_0onY
a^l2oj_8kP;o[<C/1?n]a>/2ojg1j@;oZKcW1?nV^NH3oj:eiP;oWK7V0_nL]NT4oi^gj`;oW;_^0_nS
`nl4oj[9l003ok??k_ndcNgo]<g]00;o]<g]00Co]L_[ok76j_naa^[o/LKZ0_n]`NP2ojRmj@?oXKSY
1?nI/^T4oi:`j`;oSJo]00CoTKC_oi:ilOnB^O7oT[Wa1OnF_o@2oi[5mP03oik7m?nQboGoXL_e00?o
XL_e0_nScOH2ojG<m0;oYLgd0_nVbo<4ojG;l`;oYL_d0onUbO82ojG9l`KoYLSb0_nVb?43ojK7l@;o
YlO`00?oY/O`ojS7l?nXao000_nXao02ojW7k`?oZ<O_0onYa^l2oj[6kP?oZ<K^0_nYaNh2ojS4kPCo
Z<C]0_nX`^d`ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool004Wooooo
00?o0000ooooooooool0;Oooool4ojO0j`;oYko[1_nU_n`2ojBnk003ojG1kOnU`^koYL;^00;oYL;^
0_nU`nl3ojO5kP;oZLK_0_n[a>d4ojc4k0;o[LC[0_n[_nT4ojVli`;oY[WV0_nS^>L4oj2fj0?oW;GY
0_nK]n/2oinmkPCoXl?_0_nZbO03ojk;k`;o]<g]0_nbbN`2ok76jP;o[<;Z1?nX_NT3oj6hj@;oVK;Y
0_nH/n/3oiBck0CoTKC_0onB^O42oiJom0?oVl;c0onNao@2oj7;m@?oY<_d0_nUc?@6ojK;l`;oYL_c
0onVbO82ojG9lPSoYLSb0_nUao42ojK7l@;oY/Ka1?nVao02ojS7l0?oYlO`0_nXanl2ojO6l0CoZ<K_
0_nXa^h00onXaNooZ<C^ojS4kP03ojS4kP;oZ<C]=?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo001:ooooo`;o0000;_ooool2ojO0j`;oY[o/1_nU_n`2ojG0k@?oYL7]0_nU
`^h3ojK3kP;oYlG^0_nYa>d4oj_4k@;o[<C/0_n[`NX4oj^oj@;oZKcW0_nV^^P4oj>hi`;oX;KX0_nP
^>X3oijik0CoWkg^0_nS`nl3ojW6k`;o[/__0_n_b^h2ok;9k0;o[lK[1?n/`^X2ojRmj@;oY;_Y1?nN
]nT3oiRcj`?oU;?/0_nA]>l2oiJil0CoV;gb0_nK`_<2oio4l`CoXLSd0_nTbo@3ojG:l`;oY/_c00?o
YlWbojK:l_nVb_800onVb_82ojK9lP;oY/Sa1OnUb?85ojG7l@;oYLKa1?nVa_42ojK7l0?oY/K`0_nW
ao06ojO6l0;oZ<K_00?oYlK_ojS5konXaNl00_nXaNl2ojS4kSWooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0:ooooo`00C?ooool00ol0003oooooooooo`0/ooooo`CoY[o/1?nU_n`4
ojG0k@04ojG1kOnV`^goY/;]ojK2k@;oY/?^0_nX`nd4ojW4k@;oZlC]0_nZ`^/4oj_1jP;oZkoY0_nX
_>P4ojJjj0;oXkSW0_nR^>T4oj2hjP?oW[W/0_nO_Nh2ojC2kP;oZLK_0_n/b>h3ojo:kP;o[/O/1?n_
a^/2ojc2jP;oZKoZ1?nT^nT2oijgj@;oWKO[0onI]^`4oiJgkP?oU[W`0_nH_O82oic1lPCoWlCc0_nQ
b?@3ojC8l`;oYL[c00?oY/WbojO9l_nWbO800_nWbO82ojK:lP?oYlSa0_nVb?46ojK7l@;oYLOa0_nV
a_04ojG6l@;oY/Ka1_nVa_09ojO6l0?oYlK_0_nXaNllooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02_ooool004gooooo00?o0000ooooooooool0;?ooool2ojJok0KoYKo/0_nU`>d2
ojK1k@;oY/;]0_nW`^d4ojS3k@;oZLC]0_nY`^`4oj[2j`;oZl7Z0_nY_^T4ojRlj0;oY[[X0_nT^^P4
oj:hj@;oX;SZ00?oX[c/oj:nkOnR_^d00_nR_^d2ojC2kP;oZ<G_1?n/b>h00on_b^ko[/O/ojk7k002
ojk7k0;o[lK[0_n/`n/4ojVojP;oY;_Y0_nQ^^X4oifgj`?oVKK/0_nF]nh00onI^^ooV[g`oiZml003
oiZml0?oW<7b0_nOa?<2oj;6lP;oY<Sc0_nUb?84ojK9lP;oYlWb1OnWb?42ojO7l0KoY/Oa1_nVa_02
ojG6l@[oY/K`1onWa_13ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool0
04kooooo00?o0000ooooooooool0;Oooool2ojFok003ojJok?nV`>coY/3/00;oY/3/0_nV`Nd2ojO1
k0CoYl;]0_nX`nd6ojW2k0;oZ/;[0onY_nX3ojVnj@;oZ;cX0_nV^nP4ojBjj0;oX[SY00?oX[_[oj:l
k?nR_>`00_nR_>`2oj:nk@;oYL;^1?nXaNl2ojc8kP?o[LO]0_n^an`2ojg5k0Co[<?[0_nY_nX2ojJm
jPCoXK[Z0_nM]n/00onM^NcoV[S]oiZhk@02oiZhk@?oVK[_0_nJ_O02oifol0CoWl?a0_nRa_82ojC6
lPCoYLSb0_nVbO85ojO8l@KoYlO`0_nVao4GojK6l0;oYlK`Aoooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00[ooooo001?ooooo`;o0000;_ooool3ojJok0CoY/3/1?nW`N`2ojO2k@;o
Z<;/1_nY`^`3ojW0jP;oZKoZ0_nX_^T4ojNlj@?oY[_X0_nT^^P2oj>kjP?oX[_[0_nR_>`2ojBok@Co
YL;^0_nXaNl3oj[6kP;o[LO]0_n/a^d4ojg5k0;o[<?[0_nY`>/4ojJmjP;oXK[Z00?oX;[[oifik?nM
^N`00_nM^N`2oiZhk@;oW;_^1?nL_Nl3oifol0;oWl?a0onQa?43ojC6lP;oYLSb0onVb?42ojO8l@03
ojO8l?nWao3oYlO`00OoYlO`0_nVa_02ojO6l0KoY/K`0onVaO09ojK6l4cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0:ooooo`00DOooool00ol0003oooooooooo`0/ooooo`03ojJo
k?nV`>coY/3/00CoY/3/0_nW`N`3ojS1k0?oZ<;/0_nY`^`3ojW1j`;oZL3Z0_nX_nX4ojRnj@;oYkcY
00?oY[cYojFljOnU_>T00_nU_>T2oj>kjP;oY;g[1?nS_^`3ojBok@;oYL;^0onWa>h2oj[6kP;oZlK^
1?n/a^d2ojg5k0;oZ/?[0_nY`>/2ojJnj`CoY;c[0onP^^/2oifik0;oWK[]1?nL^nh2oibmk`;oW[o`
1?nO`_42oj74l@;oXlGa1?nUa_42ojK8l@03ojO7lOnWb?3oYlS`00;oYlS`1onWao06ojO6l0;oY/K`
1?nVaO02ojK5k`KoY/K`Coooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo
001Booooo`03o`000?oooooooooo02_ooooo1_nV`>`3ojO0k0;oZ<7/1_nX`N/2ojW1j`KoZ;oZ0_nX
_^T00onW_NWoY[cYojJlj@02ojJlj@;oYKcY1_nT_N/2oj>nk0;oYL7]1?nV`^h2ojO4kP;oZLG^1?n[
a^h2ojc6k@;oZlC/0_nZ`n/2ojS1j`CoY[k[0_nT_>/2oj:lj`CoWk_/0onM^^d2oibkkP;oW[g_1?nN
_o02oio2l@03oj;3l?nSaO7oXlGa00?oXlGa0_nUa_42ojK7l@?oYlOa0_nWb?05ojO7l0SoYlK`0_nW
aNl2ojK5l0KoY/G_0_nVa_1Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_oo
ool005?ooooo00?o0000ooooooooool0:oooool2ojK0k0?oYl3[0_nW`>`2ojS0j`KoZ<7[0_nX`>/6
ojRojP03ojNnj_nW_NWoYkgY00;oYkgY0_nV_>T2ojFmjPKoY;g[0_nU_n`4ojG1k@;oY/;^0onWa>h3
ojW5kP;oZlK^0_n[aNd2oj_4k0;oZL;/1?nX`N/2ojJnj`;oYKk[1?nR_>/2oinkk003oj2lkOnN_>go
W[c]00?oW[c]0onN_Nl2oijol0;oX<7`0onR`o02oj?5l@?oY<Ga0_nVao42ojK6l0KoYlO`2?nWa_02
ojO6k`CoYlG_1_nVaNmGooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool0
05Cooooo0_l0000]ooooo`;oYl3[1_nX`>/2ojS1j`KoZ<3[0onX_nX4ojNnjP;oYkgY0_nV_NX4ojFm
jP;oY;g[0_nU_^`4ojFok0;oYL7]0onV`^h2ojO4kP03ojS4kOnYaNgoZLG]00;oZLG]0_n[aNd2oj[3
k0CoZL;/0_nX`N/2ojNoj`CoYKk[0_nR_>/00onR_>coX;c]oj2lk@02oj2lk@;oW[c]0_nP_^h4oino
k`;oX<7`0_nR`_04oj?4l0;oY<Ga0_nUa_04ojK6l0CoYlO`1?nWa_06ojO6k`KoYlG_0_nVaNmJoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool005Kooooo00?o0000oooooooo
ool0:oooool>ojS0j`GoZ;oZ1OnW_^X3ojJmjP;oYKgZ0onU_^/3ojFnk0;oYKo/0onV`Nd2ojK2kP03
ojO3kOnXa>goZ<C]00;oZ<C]0_nYaNd2ojW4k@CoZ/?/0_nY`^`3ojS1j`?oYko[0_nU_^/2ojBmj`?o
X[c/0_nP_>d2oj6mk@CoX;k^0_nO_nl2oj71k`CoX/;`0_nSa?02ojC5l0CoYLK`1?nVa_02ojO7l0Ko
YlK`1OnWa^l5ojO5kekooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`00
Eoooool00ol0003oooooooooo`0[ooooo`[oZ<3[0onX_n/2ojRojP03ojNoj_nW_^[oYkkZ00CoYkkZ
1_nV_^/2ojFnj`;oY[o/1?nU`>d2ojK1k@03ojO2kOnW`ngoYl?]00;oYl?]0_nXa>d6ojW4k@;oZ/?/
0onY`^`2ojS1j`03ojO0jonV_^_oY[k[00;oY[k[0_nT_N/2oj>mk0CoX[g/0onQ_Nd2oj2nkP;oXKo^
1?nQ`Nl2oj;2l0;oXl?`1?nTaO02ojG6l0CoY/K`2_nWa_02ojO6kfKooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`09ooooo`00F?ooool00ol0003oooooooooo`0/ooooo`SoZ<3[0onX
_n/4ojNojP;oYkkZ0_nW_n/6ojJnj`KoY[o/0_nU`>d00onV`NgoYl;]ojO2k@02ojO2k@;oYl?]0onX
`nd5ojW4k@?oZL?/0_nY`^`00onX`N_oYl3[ojO0j`02ojO0j`;oY[k[0_nU_^/4oj>mk0;oX[g/0_nR
_^d4oj6nk@?oXKo^0_nQ`Nl2oj?2k`;oXl?`0_nTa?04ojG5l0CoY/K`2_nWa_1Zooooo`05o`000?oo
ooooooooooooool000002oooool005Wooooo00?o0000ooooooooool0;?ooool7ojS0j`CoZ;o[0_nW
_nX6ojNoj`;oY[k[0_nV_n/6ojJok003ojK1k?nV`NgoY/7]00;oY/7]0_nW`^d3ojO3k@CoZ<?]1_nY
`n`00onX`NcoZ<7[ojS1j`02ojS1j`;oYl3[0_nV_n/4ojFnj`;oXkg/0_nS_^`4oj:nk@;oXKk]00?o
Xko^oj;1k_nR`Nh00_nR`Nh2oj?2k`;oY<?_1?nTa?02ojG5l0?oY/G`0onVa_02ojO6l0;oY/K`0_nW
a_1]ooooo`05o`000?ooooooooooooooool000002oooool005[ooooo0_l0000]ooooo`OoZ<3[0_nX
_n/8ojNoj`KoY[o[0_nV_n`2ojK0k0?oY/7/0_nV`Nd3ojO2k@;oYl?]0_nX`^d4ojS3k@;oZL?/00?o
ZL;/ojS1k?nX`N`00_nX`N`2ojS1j`?oYl3[0onV_n/5ojFnj`?oXkk/0_nR_^d00onS_ngoXko^oj>o
kP02oj>okP;oX/7^0onT`^h3ojC3k`;oY<C`0onUa?03ojK5l0KoY/K`LOooool01?l0003ooooooooo
ool0000;ooooo`00G?ooool00ol0003oooooooooo`0[ooooo`GoZ<3[2onW_n/5ojJoj`CoY/3/0_nW
`N`4ojO1k@;oYl;]1_nX`^d2ojS3k@;oZ<;/0onY`^`2ojS1k0?oZ<3[0_nW`>/2ojNoj`CoY[k[0_nU
_^/00onU_^coY;k/ojBnk002ojBnk0?oXko]0_nS_nh3ojC1kP;oY<;^0_nU`^h4ojG3k`;oYLC`00?o
Y/G_ojK5l?nVaO000_nVaO02ojK6l7Gooooo00?o0000ooooool000002oooool005gooooo00?o0000
ooooooooool0:oooool2ojS0j`;oYl3[0_nW_n/2ojO0j`KoYko[0_nW`>/6ojK0k0GoYl7/0_nW`Nd2
ojO2k0KoZ<;]1?nX`^`6ojS1j`;oZ<3[1_nW_n/3ojJnj`CoYKk/0_nT_^`2ojFok0CoY;o]0_nT`Nh0
0onU`NkoYL;^ojG2kP03ojG2kP;oYL?_00?oY/C_ojK5konVaNl00_nVaNl2ojK5l7Sooooo00Co0000
oooooooooooo00002_ooool005kooooo00?o0000ooooooooool0:oooool8ojO0j`;oYko[1_nW`>/2
ojK0k003ojO0k?nW`NcoYl7/00OoYl7/0onW`^`2ojS2k@CoZ<;/0_nX`N`6ojS1j`;oZ<3[1_nW_n/0
0onW_^_oY[k[ojJnj`02ojJnj`;oYKk/0_nU_^/4ojFok0;oY;o]00?oYL3]ojG1k_nU`Nh00_nU`Nh2
ojG2kP?oY/?^0onVa>l2ojK5kgcooooo00?o0000ooooool000002_ooool005oooooo0_l0000/oooo
o`koYl3[1OnW`>`9ojO1k0GoZ<;/1_nX`N`2ojS1j`KoZ<3[0onW_n/4ojNnj`GoY[k[0onU_^/4ojFo
k0?oYL3]0_nU`Nh3ojK2k@;oY/?^Poooool2o`0000[ooooo001Qooooo`03o`000?oooooooooo02[o
oooo2_nW`>/6ojO0k0coYl7/0_nX`^`7ojS1k0?oZ<7[1OnX`>/2ojRoj`?oYko[1OnW_^/4ojJnj`?o
Y[o[0_nU_n`2ojK0k0CoY/7]0_nV`^f5ooooo`?o00002_ooool006;ooooo00?o0000ooooooooool0
:oooool8ojO0j`OoYl3/2_nW`N`7ojS1k0GoZ<7[00?oZ<3[ojRojonX_n/01?nX_n/2ojNojPCoYkkZ
0_nW_^/2ojNnjPCoY[k[00?oY[o[ojNojonW_n/01?nV`>`2ojK1kHCooooo1?l0000=ooooo`00Hooo
ool00ol0003oooooooooo`0[ooooo`OoYl3[2?nW`>`6ojO1k0OoZ<7/1OnX`N/5ojS0j`;oZ;o[0_nX
_nX4ojNojPSoYkkZ0_nV_^/5ojNoj`;oY/3/Poooool4o`00017ooooo001Tooooo`;o0000;?ooool7
ojO0j`SoYl3/1?nW`N`2ojS1k0SoZ<7[1onX`>/6ojRojP;oYkoZ2_nW_^X5ojNojh?ooooo0ol0000E
ooooo`00I_ooool00ol0003oooooooooo`0[ooooo`OoYl3[0_nW`>`6ojO0j`03ojO1k?nX`>_oZ<3[
00KoZ<7[2?nX`>/7ojRojP?oZ;kZ2OnW_^Z5ooooo`Co00006?ooool006Oooooo00?o0000oooooooo
ool0:_ooool>ojO0j`GoZ<3[0_nX`N/8ojS0j`;oZ;o[2?nX_nX3ojRnjPKoYkkZQ?ooool4o`0001co
oooo001Xooooo`03o`000?oooooooooo02[ooooo3?nW`>/;ojS0j`KoZ;o[2?nX_nX5ojRnjP;oYkkZ
Poooool4o`00023ooooo001Yooooo`;o0000;?ooool9ojO0j`goZ<3[1?nX_n/7ojRojPKoZ;kZP_oo
ool4o`0002Cooooo001[ooooo`03o`000?oooooooooo02[ooooo1_nW`>/>ojS0j`KoZ;o[1onX_nX2
ojRnjX;ooooo0ol0000Xooooo`00K?ooool00ol0003oooooooooo`0Zooooo`;oYl3[3onX`>/7ojRo
j`GoZ;oZPoooool4o`0002_ooooo001]ooooo`03o`000?oooooooooo02_ooooo3_nX`>/8ojRoj`;o
Z;oZP_ooool4o`0002oooooo001^ooooo`03o`000?oooooooooo02[ooooo3OnX`>/8ojRojh7ooooo
1?l0000cooooo`00Koooool2o`0002_ooooo2OnX`>/3ojO0j`GoZ;o[P?ooool4o`0003Oooooo001a
ooooo`03o`000?oooooooooo02[ooooo1OnX`>/4ojO0jh;ooooo1?l0000kooooo`00L_ooool00ol0
003oooooooooo`0Zooooo`GoYl3[P_ooool3o`0003oooooo001cooooo`03o`000?oooooooooo02[o
oooo00?oYl3[ooooooooool0Ooooool4o`0004;ooooo001dooooo`;o0000:_ooool00ol0003ooooo
ooooo`1kooooo`Co0000A_ooool007Kooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`1hooooo`Co0000B_ooool007Oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1d
ooooo`Co0000C_ooool007Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1aoooo
o`?o0000D_ooool007Wooooo0_l0000Tooooo`03o`000?oooooooooo06gooooo1?l0001Eooooo`00
Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo06Wooooo1?l0001Iooooo`00O?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06Gooooo1?l0001Mooooo`00OOooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo067ooooo1?l0001Qooooo`00O_ooool2o`00
01oooooo00?o0000ooooooooool0GOooool4o`0006Gooooo0020ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0F_ooool3o`0006Wooooo0021ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0E_ooool4o`0006cooooo0022ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0D_ooool4o`00073ooooo0023ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0C_ooool4o`0007Cooooo0024ooooo`;o00006Oooool00ol0003oooooooooo`1:oooo
o`Co0000N?ooool008Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`16ooooo`Co
0000O?ooool008Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`13ooooo`?o0000
P?ooool008Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0oooooo`Co0000Pooo
ool008Wooooo0_l0000Dooooo`03o`000?oooooooooo03_ooooo1?l00027ooooo`00Roooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo03Oooooo1?l0002;ooooo`00S?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo03?ooooo1?l0002?ooooo`00SOooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo033ooooo0ol0002Cooooo`00S_ooool2o`0000oooooo00?o
0000ooooooooool0;?ooool4o`0009Kooooo002@ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0:?ooool4o`0009[ooooo002Aooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool09?ooool4o`0009kooooo002Booooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool08Oooool4o`000:;ooooo002Cooooo`;o00002Oooool00ol0003oooooooooo`0Mooooo`Co0000
Y_ooool009Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Jooooo`?o0000Z_oo
ool009Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`Co0000[Oooool0
09Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`Co0000/Oooool009So
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000]Oooool009Wooooo
0_l00003ooooo`03o`000?oooooooooo00[ooooo1?l0002iooooo`00Voooool01?l0003ooooooooo
ool00009ooooo`?o0000_Oooool009cooooo00?o0000ooooool000001Oooool4o`000<3ooooo002M
ooooo`;o000000?oooooo`000?l000000_l00034ooooo`00W_ooool2o`000<Sooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo002Zooooo`05oiRHV?l0003o0000odA4A?nj^[X02_ooool4o`000008oa0@
4?ooooooooooolc<c?lQ8B7o0000ob4Q8Oo<c<`5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooo
oooo097ooooo002Zooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool6o`0000Cooooo00?o0000
ooooooooool00_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Gooooo0_lQ8B47ooooo`03o`000?oo
oooooooo09;ooooo002Zooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000_ooooo1Ol0002Cooooo`00Z_ooool00ol0003oooooooooo`04
ooooo`Ko00001?ooool00ol0003oooooooooo`02ooooo`05oc8b<_nHV9SooooooiRHV?lb<S802ooo
ool01?m4A4CogMgMooooool0002Dooooo`00Z_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00;ooooo00Goc<c<o`000?l0003o0000olc<c00;ooooo`04omgMgOmEEEGoooooo`0009Co
oooo002Xooooo`03oa0@4?l0003o000000?o00003Oooool00ol0003oooooooooo`02ooooo`05oa0@
4?nj^[[ooooookZj^_l@41003?ooool00omgMgOoc<c<o`00002Dooooo`00Z_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00;ooooo00Go0000okZj^_oooooo^[Zjo`00000<ooooo`03
onk^k_m4A4Co000009Cooooo002Zooooo`03o`000?oooooooooo00cooooo00?oEEEEofIVI_l00000
1?ooool01OnYZJWo410@o`000?l@413oZJVY00gooooo00?oMgMgo`000?ooool0Toooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -20 0 ]
[.5 .82364 20 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(19.2) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.655 .751 .921 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69468 Mtetra
.655 .752 .921 r
.4053 .69468 .41061 .69934 .41957 .69681 .41427 .69216 Mtetra
.41427 .69216 .41957 .69681 .42855 .69428 .42327 .68962 Mtetra
.655 .753 .922 r
.42327 .68962 .42855 .69428 .43756 .69174 .4323 .68707 Mtetra
.4323 .68707 .43756 .69174 .4466 .68919 .44137 .68451 Mtetra
.656 .753 .922 r
.44137 .68451 .4466 .68919 .45567 .68663 .45046 .68194 Mtetra
.656 .754 .922 r
.45046 .68194 .45567 .68663 .46478 .68407 .45958 .67935 Mtetra
.656 .753 .922 r
.45958 .67935 .46478 .68407 .47391 .68149 .46873 .67675 Mtetra
.657 .753 .921 r
.46873 .67675 .47391 .68149 .48307 .67891 .47792 .67413 Mtetra
.657 .752 .92 r
.47792 .67413 .48307 .67891 .49227 .67632 .48713 .67149 Mtetra
.657 .751 .919 r
.48713 .67149 .49227 .67632 .50149 .67371 .49638 .66884 Mtetra
.658 .75 .918 r
.49638 .66884 .50149 .67371 .51075 .6711 .50565 .66617 Mtetra
.658 .748 .917 r
.50565 .66617 .51075 .6711 .52004 .66849 .51496 .6635 Mtetra
.658 .747 .915 r
.51496 .6635 .52004 .66849 .52936 .66586 .5243 .66081 Mtetra
.658 .745 .915 r
.5243 .66081 .52936 .66586 .53871 .66322 .53367 .65813 Mtetra
.657 .744 .914 r
.53367 .65813 .53871 .66322 .54809 .66058 .54308 .65546 Mtetra
.656 .743 .914 r
.54308 .65546 .54809 .66058 .55751 .65792 .55251 .65281 Mtetra
.654 .743 .915 r
.55251 .65281 .55751 .65792 .56695 .65526 .56198 .65018 Mtetra
.653 .745 .917 r
.56198 .65018 .56695 .65526 .57643 .65259 .57148 .64758 Mtetra
.651 .748 .921 r
.57148 .64758 .57643 .65259 .58595 .6499 .58102 .645 Mtetra
.649 .752 .925 r
.58102 .645 .58595 .6499 .59549 .64721 .59059 .64245 Mtetra
.647 .758 .93 r
.59059 .64245 .59549 .64721 .60507 .64451 .60019 .6399 Mtetra
.646 .765 .936 r
.60019 .6399 .60507 .64451 .61468 .6418 .60983 .63735 Mtetra
.645 .772 .941 r
.60983 .63735 .61468 .6418 .62432 .63908 .6195 .63478 Mtetra
.644 .78 .946 r
.6195 .63478 .62432 .63908 .634 .63636 .62921 .63219 Mtetra
.644 .786 .95 r
.62921 .63219 .634 .63636 .64371 .63362 .63895 .62956 Mtetra
.644 .792 .953 r
.63895 .62956 .64371 .63362 .65345 .63087 .64872 .62689 Mtetra
.644 .796 .956 r
.64872 .62689 .65345 .63087 .66323 .62811 .65853 .62417 Mtetra
.645 .799 .957 r
.65853 .62417 .66323 .62811 .67304 .62535 .66837 .62142 Mtetra
.646 .801 .957 r
.66837 .62142 .67304 .62535 .68289 .62257 .67824 .61863 Mtetra
.647 .802 .957 r
.67824 .61863 .68289 .62257 .69277 .61979 .68815 .61579 Mtetra
.649 .801 .956 r
.68815 .61579 .69277 .61979 .70269 .61699 .69809 .61292 Mtetra
.652 .799 .953 r
.69809 .61292 .70269 .61699 .71264 .61418 .70806 .61001 Mtetra
.654 .795 .95 r
.70806 .61001 .71264 .61418 .72262 .61137 .71807 .60705 Mtetra
.657 .79 .946 r
.71807 .60705 .72262 .61137 .73264 .60854 .72811 .60406 Mtetra
.659 .784 .941 r
.72811 .60406 .73264 .60854 .7427 .60571 .73818 .60103 Mtetra
.66 .777 .936 r
.73818 .60103 .7427 .60571 .75279 .60286 .74828 .59799 Mtetra
.661 .77 .93 r
.74828 .59799 .75279 .60286 .76291 .60001 .75843 .59494 Mtetra
.661 .763 .925 r
.75843 .59494 .76291 .60001 .77308 .59714 .7686 .59191 Mtetra
.66 .756 .921 r
.7686 .59191 .77308 .59714 .78328 .59427 .77882 .58889 Mtetra
.66 .751 .918 r
.77882 .58889 .78328 .59427 .79351 .59138 .78907 .58589 Mtetra
.658 .747 .915 r
.78907 .58589 .79351 .59138 .80378 .58849 .79936 .58292 Mtetra
.657 .744 .914 r
.79936 .58292 .80378 .58849 .81409 .58558 .8097 .57998 Mtetra
.656 .743 .914 r
.8097 .57998 .81409 .58558 .82443 .58267 .82007 .57705 Mtetra
.655 .743 .914 r
.82007 .57705 .82443 .58267 .83482 .57974 .83048 .57413 Mtetra
.655 .744 .915 r
.83048 .57413 .83482 .57974 .84523 .5768 .84093 .57121 Mtetra
.655 .746 .917 r
.84093 .57121 .84523 .5768 .85569 .57385 .85141 .56829 Mtetra
.654 .747 .918 r
.85141 .56829 .85569 .57385 .86618 .57089 .86194 .56535 Mtetra
.655 .749 .919 r
.86194 .56535 .86618 .57089 .87672 .56792 .8725 .5624 Mtetra
.655 .75 .92 r
.8725 .5624 .87672 .56792 .88729 .56494 .8831 .55943 Mtetra
.655 .752 .921 r
.8831 .55943 .88729 .56494 .89789 .56195 .89374 .55644 Mtetra
.655 .753 .922 r
.89374 .55644 .89789 .56195 .90854 .55895 .90442 .55343 Mtetra
.90442 .55343 .90854 .55895 .91923 .55594 .91513 .5504 Mtetra
.656 .753 .922 r
.91513 .5504 .91923 .55594 .92995 .55292 .92588 .54736 Mtetra
.656 .754 .922 r
.92588 .54736 .92995 .55292 .94071 .54988 .93668 .5443 Mtetra
.656 .753 .922 r
.93668 .5443 .94071 .54988 .95152 .54684 .94751 .54122 Mtetra
.656 .753 .921 r
.94751 .54122 .95152 .54684 .96236 .54378 .95838 .53813 Mtetra
.95838 .53813 .96236 .54378 .97324 .54071 .96929 .53503 Mtetra
.656 .752 .921 r
.96929 .53503 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.655 .751 .921 r
.391 .69252 .39636 .6972 .4053 .69468 .39996 .69 Mtetra
.655 .752 .921 r
.39996 .69 .4053 .69468 .41427 .69216 .40895 .68747 Mtetra
.40895 .68747 .41427 .69216 .42327 .68962 .41797 .68493 Mtetra
.655 .753 .922 r
.41797 .68493 .42327 .68962 .4323 .68707 .42702 .68237 Mtetra
.42702 .68237 .4323 .68707 .44137 .68451 .4361 .67981 Mtetra
.4361 .67981 .44137 .68451 .45046 .68194 .44521 .67722 Mtetra
.656 .754 .922 r
.44521 .67722 .45046 .68194 .45958 .67935 .45435 .67462 Mtetra
.45435 .67462 .45958 .67935 .46873 .67675 .46352 .67199 Mtetra
.657 .754 .921 r
.46352 .67199 .46873 .67675 .47792 .67413 .47273 .66934 Mtetra
.658 .753 .92 r
.47273 .66934 .47792 .67413 .48713 .67149 .48196 .66667 Mtetra
.659 .753 .919 r
.48196 .66667 .48713 .67149 .49638 .66884 .49123 .66396 Mtetra
.659 .751 .918 r
.49123 .66396 .49638 .66884 .50565 .66617 .50053 .66124 Mtetra
.66 .75 .917 r
.50053 .66124 .50565 .66617 .51496 .6635 .50986 .6585 Mtetra
.659 .748 .916 r
.50986 .6585 .51496 .6635 .5243 .66081 .51922 .65576 Mtetra
.659 .746 .915 r
.51922 .65576 .5243 .66081 .53367 .65813 .52861 .65303 Mtetra
.657 .745 .914 r
.52861 .65303 .53367 .65813 .54308 .65546 .53803 .65033 Mtetra
.655 .744 .915 r
.53803 .65033 .54308 .65546 .55251 .65281 .54749 .64767 Mtetra
.652 .743 .916 r
.54749 .64767 .55251 .65281 .56198 .65018 .55698 .64507 Mtetra
.649 .744 .919 r
.55698 .64507 .56198 .65018 .57148 .64758 .5665 .64254 Mtetra
.646 .746 .922 r
.5665 .64254 .57148 .64758 .58102 .645 .57606 .64006 Mtetra
.642 .75 .927 r
.57606 .64006 .58102 .645 .59059 .64245 .58566 .63764 Mtetra
.639 .755 .932 r
.58566 .63764 .59059 .64245 .60019 .6399 .59529 .63525 Mtetra
.637 .762 .938 r
.59529 .63525 .60019 .6399 .60983 .63735 .60495 .63287 Mtetra
.636 .77 .944 r
.60495 .63287 .60983 .63735 .6195 .63478 .61465 .63046 Mtetra
.636 .777 .948 r
.61465 .63046 .6195 .63478 .62921 .63219 .62439 .628 Mtetra
.637 .785 .952 r
.62439 .628 .62921 .63219 .63895 .62956 .63416 .62548 Mtetra
.639 .791 .955 r
.63416 .62548 .63895 .62956 .64872 .62689 .64396 .62289 Mtetra
.641 .796 .957 r
.64396 .62289 .64872 .62689 .65853 .62417 .6538 .62022 Mtetra
.643 .8 .958 r
.6538 .62022 .65853 .62417 .66837 .62142 .66366 .61748 Mtetra
.646 .802 .958 r
.66366 .61748 .66837 .62142 .67824 .61863 .67356 .61467 Mtetra
.649 .803 .957 r
.67356 .61467 .67824 .61863 .68815 .61579 .6835 .61179 Mtetra
.652 .803 .955 r
.6835 .61179 .68815 .61579 .69809 .61292 .69346 .60884 Mtetra
.656 .801 .952 r
.69346 .60884 .69809 .61292 .70806 .61001 .70346 .60581 Mtetra
.66 .798 .948 r
.70346 .60581 .70806 .61001 .71807 .60705 .71348 .6027 Mtetra
.664 .793 .943 r
.71348 .6027 .71807 .60705 .72811 .60406 .72354 .59954 Mtetra
.666 .787 .938 r
.72354 .59954 .72811 .60406 .73818 .60103 .73363 .59632 Mtetra
.668 .78 .933 r
.73363 .59632 .73818 .60103 .74828 .59799 .74375 .59307 Mtetra
.668 .772 .927 r
.74375 .59307 .74828 .59799 .75843 .59494 .75391 .58983 Mtetra
.667 .764 .923 r
.75391 .58983 .75843 .59494 .7686 .59191 .7641 .58662 Mtetra
.665 .757 .919 r
.7641 .58662 .7686 .59191 .77882 .58889 .77433 .58346 Mtetra
.663 .752 .916 r
.77433 .58346 .77882 .58889 .78907 .58589 .7846 .58036 Mtetra
.66 .747 .915 r
.7846 .58036 .78907 .58589 .79936 .58292 .79492 .57733 Mtetra
.658 .745 .914 r
.79492 .57733 .79936 .58292 .8097 .57998 .80527 .57435 Mtetra
.656 .744 .915 r
.80527 .57435 .8097 .57998 .82007 .57705 .81567 .57142 Mtetra
.654 .744 .916 r
.81567 .57142 .82007 .57705 .83048 .57413 .82611 .56851 Mtetra
.653 .745 .917 r
.82611 .56851 .83048 .57413 .84093 .57121 .83659 .56562 Mtetra
.653 .746 .918 r
.83659 .56562 .84093 .57121 .85141 .56829 .84711 .56272 Mtetra
.653 .748 .919 r
.84711 .56272 .85141 .56829 .86194 .56535 .85767 .5598 Mtetra
.653 .749 .92 r
.85767 .5598 .86194 .56535 .8725 .5624 .86826 .55687 Mtetra
.654 .751 .921 r
.86826 .55687 .8725 .5624 .8831 .55943 .87889 .5539 Mtetra
.654 .752 .922 r
.87889 .5539 .8831 .55943 .89374 .55644 .88956 .5509 Mtetra
.655 .753 .922 r
.88956 .5509 .89374 .55644 .90442 .55343 .90026 .54788 Mtetra
.90026 .54788 .90442 .55343 .91513 .5504 .91101 .54483 Mtetra
.656 .754 .922 r
.91101 .54483 .91513 .5504 .92588 .54736 .92179 .54176 Mtetra
.92179 .54176 .92588 .54736 .93668 .5443 .93261 .53867 Mtetra
.656 .753 .921 r
.93261 .53867 .93668 .5443 .94751 .54122 .94347 .53557 Mtetra
.657 .753 .921 r
.94347 .53557 .94751 .54122 .95838 .53813 .95437 .53245 Mtetra
.95437 .53245 .95838 .53813 .96929 .53503 .9653 .52931 Mtetra
.657 .752 .92 r
.9653 .52931 .96929 .53503 .98024 .53192 .97628 .52616 Mtetra
.654 .751 .921 r
.38561 .68781 .391 .69252 .39996 .69 .39458 .68529 Mtetra
.39458 .68529 .39996 .69 .40895 .68747 .40359 .68275 Mtetra
.654 .752 .921 r
.40359 .68275 .40895 .68747 .41797 .68493 .41263 .6802 Mtetra
.654 .752 .922 r
.41263 .6802 .41797 .68493 .42702 .68237 .4217 .67764 Mtetra
.655 .753 .922 r
.4217 .67764 .42702 .68237 .4361 .67981 .4308 .67507 Mtetra
.4308 .67507 .4361 .67981 .44521 .67722 .43993 .67247 Mtetra
.656 .754 .922 r
.43993 .67247 .44521 .67722 .45435 .67462 .44909 .66986 Mtetra
.44909 .66986 .45435 .67462 .46352 .67199 .45828 .66721 Mtetra
.657 .754 .921 r
.45828 .66721 .46352 .67199 .47273 .66934 .46751 .66454 Mtetra
.658 .754 .921 r
.46751 .66454 .47273 .66934 .48196 .66667 .47676 .66183 Mtetra
.66 .754 .92 r
.47676 .66183 .48196 .66667 .49123 .66396 .48605 .65909 Mtetra
.66 .753 .919 r
.48605 .65909 .49123 .66396 .50053 .66124 .49537 .65632 Mtetra
.661 .752 .918 r
.49537 .65632 .50053 .66124 .50986 .6585 .50472 .65353 Mtetra
.661 .751 .917 r
.50472 .65353 .50986 .6585 .51922 .65576 .5141 .65073 Mtetra
.66 .749 .916 r
.5141 .65073 .51922 .65576 .52861 .65303 .52351 .64795 Mtetra
.658 .747 .915 r
.52351 .64795 .52861 .65303 .53803 .65033 .53296 .6452 Mtetra
.655 .745 .916 r
.53296 .6452 .53803 .65033 .54749 .64767 .54243 .64253 Mtetra
.651 .744 .917 r
.54243 .64253 .54749 .64767 .55698 .64507 .55194 .63993 Mtetra
.646 .743 .92 r
.55194 .63993 .55698 .64507 .5665 .64254 .56149 .63745 Mtetra
.641 .744 .924 r
.56149 .63745 .5665 .64254 .57606 .64006 .57107 .63507 Mtetra
.636 .747 .929 r
.57107 .63507 .57606 .64006 .58566 .63764 .58069 .63278 Mtetra
.632 .752 .934 r
.58069 .63278 .58566 .63764 .59529 .63525 .59035 .63054 Mtetra
.628 .758 .94 r
.59035 .63054 .59529 .63525 .60495 .63287 .60004 .62832 Mtetra
.627 .766 .946 r
.60004 .62832 .60495 .63287 .61465 .63046 .60977 .62608 Mtetra
.628 .774 .951 r
.60977 .62608 .61465 .63046 .62439 .628 .61953 .62378 Mtetra
.63 .782 .955 r
.61953 .62378 .62439 .628 .63416 .62548 .62933 .62138 Mtetra
.633 .79 .957 r
.62933 .62138 .63416 .62548 .64396 .62289 .63916 .61888 Mtetra
.636 .796 .959 r
.63916 .61888 .64396 .62289 .6538 .62022 .64903 .61627 Mtetra
.641 .8 .959 r
.64903 .61627 .6538 .62022 .66366 .61748 .65893 .61355 Mtetra
.645 .803 .959 r
.65893 .61355 .66366 .61748 .67356 .61467 .66885 .61072 Mtetra
.65 .805 .957 r
.66885 .61072 .67356 .61467 .6835 .61179 .67881 .60779 Mtetra
.655 .805 .955 r
.67881 .60779 .6835 .61179 .69346 .60884 .6888 .60475 Mtetra
.661 .803 .951 r
.6888 .60475 .69346 .60884 .70346 .60581 .69882 .60159 Mtetra
.667 .8 .946 r
.69882 .60159 .70346 .60581 .71348 .6027 .70887 .59833 Mtetra
.671 .795 .941 r
.70887 .59833 .71348 .6027 .72354 .59954 .71894 .59497 Mtetra
.674 .788 .935 r
.71894 .59497 .72354 .59954 .73363 .59632 .72905 .59155 Mtetra
.676 .781 .929 r
.72905 .59155 .73363 .59632 .74375 .59307 .73918 .58809 Mtetra
.675 .773 .924 r
.73918 .58809 .74375 .59307 .75391 .58983 .74935 .58466 Mtetra
.673 .765 .92 r
.74935 .58466 .75391 .58983 .7641 .58662 .75956 .58128 Mtetra
.669 .758 .917 r
.75956 .58128 .7641 .58662 .77433 .58346 .76981 .57799 Mtetra
.665 .752 .915 r
.76981 .57799 .77433 .58346 .7846 .58036 .78011 .5748 Mtetra
.661 .748 .915 r
.78011 .5748 .7846 .58036 .79492 .57733 .79044 .57172 Mtetra
.657 .746 .915 r
.79044 .57172 .79492 .57733 .80527 .57435 .80083 .56873 Mtetra
.654 .745 .916 r
.80083 .56873 .80527 .57435 .81567 .57142 .81125 .5658 Mtetra
.652 .745 .917 r
.81125 .5658 .81567 .57142 .82611 .56851 .82172 .56291 Mtetra
.651 .746 .919 r
.82172 .56291 .82611 .56851 .83659 .56562 .83223 .56004 Mtetra
.651 .747 .92 r
.83223 .56004 .83659 .56562 .84711 .56272 .84278 .55716 Mtetra
.651 .749 .921 r
.84278 .55716 .84711 .56272 .85767 .5598 .85337 .55425 Mtetra
.652 .75 .922 r
.85337 .55425 .85767 .5598 .86826 .55687 .86399 .55132 Mtetra
.653 .752 .922 r
.86399 .55132 .86826 .55687 .87889 .5539 .87465 .54835 Mtetra
.654 .753 .922 r
.87465 .54835 .87889 .5539 .88956 .5509 .88535 .54534 Mtetra
.655 .753 .922 r
.88535 .54534 .88956 .5509 .90026 .54788 .89608 .5423 Mtetra
.655 .754 .922 r
.89608 .5423 .90026 .54788 .91101 .54483 .90686 .53922 Mtetra
.656 .754 .922 r
.90686 .53922 .91101 .54483 .92179 .54176 .91767 .53613 Mtetra
.91767 .53613 .92179 .54176 .93261 .53867 .92851 .53301 Mtetra
.657 .753 .921 r
.92851 .53301 .93261 .53867 .94347 .53557 .9394 .52987 Mtetra
.9394 .52987 .94347 .53557 .95437 .53245 .95033 .52672 Mtetra
.657 .753 .92 r
.95033 .52672 .95437 .53245 .9653 .52931 .9613 .52355 Mtetra
.657 .752 .92 r
.9613 .52355 .9653 .52931 .97628 .52616 .9723 .52037 Mtetra
.654 .751 .921 r
.38018 .68308 .38561 .68781 .39458 .68529 .38917 .68054 Mtetra
.38917 .68054 .39458 .68529 .40359 .68275 .3982 .67799 Mtetra
.3982 .67799 .40359 .68275 .41263 .6802 .40726 .67544 Mtetra
.654 .752 .922 r
.40726 .67544 .41263 .6802 .4217 .67764 .41634 .67287 Mtetra
.41634 .67287 .4217 .67764 .4308 .67507 .42546 .67029 Mtetra
.655 .753 .922 r
.42546 .67029 .4308 .67507 .43993 .67247 .43461 .66769 Mtetra
.43461 .66769 .43993 .67247 .44909 .66986 .44379 .66506 Mtetra
.656 .754 .922 r
.44379 .66506 .44909 .66986 .45828 .66721 .45301 .66241 Mtetra
.657 .754 .922 r
.45301 .66241 .45828 .66721 .46751 .66454 .46225 .65972 Mtetra
.658 .755 .921 r
.46225 .65972 .46751 .66454 .47676 .66183 .47153 .657 Mtetra
.66 .755 .921 r
.47153 .657 .47676 .66183 .48605 .65909 .48083 .65423 Mtetra
.661 .755 .92 r
.48083 .65423 .48605 .65909 .49537 .65632 .49017 .65143 Mtetra
.662 .755 .919 r
.49017 .65143 .49537 .65632 .50472 .65353 .49955 .64859 Mtetra
.662 .754 .918 r
.49955 .64859 .50472 .65353 .5141 .65073 .50895 .64574 Mtetra
.662 .752 .917 r
.50895 .64574 .5141 .65073 .52351 .64795 .51838 .6429 Mtetra
.659 .75 .917 r
.51838 .6429 .52351 .64795 .53296 .6452 .52785 .6401 Mtetra
.656 .748 .917 r
.52785 .6401 .53296 .6452 .54243 .64253 .53735 .63739 Mtetra
.651 .745 .919 r
.53735 .63739 .54243 .64253 .55194 .63993 .54688 .63479 Mtetra
.644 .743 .921 r
.54688 .63479 .55194 .63993 .56149 .63745 .55645 .63233 Mtetra
.637 .743 .925 r
.55645 .63233 .56149 .63745 .57107 .63507 .56605 .63001 Mtetra
.63 .744 .93 r
.56605 .63001 .57107 .63507 .58069 .63278 .57569 .62783 Mtetra
.624 .747 .935 r
.57569 .62783 .58069 .63278 .59035 .63054 .58537 .62575 Mtetra
.619 .753 .941 r
.58537 .62575 .59035 .63054 .60004 .62832 .59509 .62371 Mtetra
.618 .761 .947 r
.59509 .62371 .60004 .62832 .60977 .62608 .60485 .62165 Mtetra
.618 .77 .952 r
.60485 .62165 .60977 .62608 .61953 .62378 .61464 .61952 Mtetra
.621 .779 .957 r
.61464 .61952 .61953 .62378 .62933 .62138 .62447 .61727 Mtetra
.626 .788 .96 r
.62447 .61727 .62933 .62138 .63916 .61888 .63433 .61488 Mtetra
.632 .796 .961 r
.63433 .61488 .63916 .61888 .64903 .61627 .64423 .61234 Mtetra
.638 .801 .961 r
.64423 .61234 .64903 .61627 .65893 .61355 .65415 .60964 Mtetra
.644 .805 .96 r
.65415 .60964 .65893 .61355 .66885 .61072 .66411 .6068 Mtetra
.652 .808 .958 r
.66411 .6068 .66885 .61072 .67881 .60779 .67409 .6038 Mtetra
.659 .808 .955 r
.67409 .6038 .67881 .60779 .6888 .60475 .68411 .60065 Mtetra
.667 .806 .95 r
.68411 .60065 .6888 .60475 .69882 .60159 .69415 .59735 Mtetra
.674 .802 .944 r
.69415 .59735 .69882 .60159 .70887 .59833 .70421 .59391 Mtetra
.679 .797 .937 r
.70421 .59391 .70887 .59833 .71894 .59497 .71431 .59034 Mtetra
.683 .79 .931 r
.71431 .59034 .71894 .59497 .72905 .59155 .72443 .58669 Mtetra
.684 .781 .925 r
.72443 .58669 .72905 .59155 .73918 .58809 .73458 .58303 Mtetra
.682 .773 .92 r
.73458 .58303 .73918 .58809 .74935 .58466 .74477 .5794 Mtetra
.678 .765 .916 r
.74477 .5794 .74935 .58466 .75956 .58128 .75499 .57587 Mtetra
.673 .758 .915 r
.75499 .57587 .75956 .58128 .76981 .57799 .76526 .57247 Mtetra
.667 .753 .914 r
.76526 .57247 .76981 .57799 .78011 .5748 .77558 .56922 Mtetra
.661 .749 .915 r
.77558 .56922 .78011 .5748 .79044 .57172 .78595 .56612 Mtetra
.656 .747 .917 r
.78595 .56612 .79044 .57172 .80083 .56873 .79636 .56313 Mtetra
.653 .746 .918 r
.79636 .56313 .80083 .56873 .81125 .5658 .80681 .56021 Mtetra
.651 .747 .92 r
.80681 .56021 .81125 .5658 .82172 .56291 .81731 .55735 Mtetra
.65 .748 .921 r
.81731 .55735 .82172 .56291 .83223 .56004 .82785 .55449 Mtetra
.65 .749 .923 r
.82785 .55449 .83223 .56004 .84278 .55716 .83843 .55162 Mtetra
.65 .751 .923 r
.83843 .55162 .84278 .55716 .85337 .55425 .84905 .54871 Mtetra
.651 .752 .923 r
.84905 .54871 .85337 .55425 .86399 .55132 .8597 .54577 Mtetra
.653 .753 .923 r
.8597 .54577 .86399 .55132 .87465 .54835 .87039 .54277 Mtetra
.654 .753 .923 r
.87039 .54277 .87465 .54835 .88535 .54534 .88111 .53974 Mtetra
.655 .754 .922 r
.88111 .53974 .88535 .54534 .89608 .5423 .89188 .53667 Mtetra
.656 .754 .922 r
.89188 .53667 .89608 .5423 .90686 .53922 .90268 .53357 Mtetra
.90268 .53357 .90686 .53922 .91767 .53613 .91351 .53044 Mtetra
.657 .753 .921 r
.91351 .53044 .91767 .53613 .92851 .53301 .92439 .52729 Mtetra
.92439 .52729 .92851 .53301 .9394 .52987 .93531 .52412 Mtetra
.657 .753 .92 r
.93531 .52412 .9394 .52987 .95033 .52672 .94626 .52094 Mtetra
.94626 .52094 .95033 .52672 .9613 .52355 .95726 .51775 Mtetra
.657 .752 .92 r
.95726 .51775 .9613 .52355 .9723 .52037 .96829 .51454 Mtetra
.654 .751 .921 r
.37472 .67831 .38018 .68308 .38917 .68054 .38373 .67576 Mtetra
.38373 .67576 .38917 .68054 .3982 .67799 .39278 .6732 Mtetra
.39278 .6732 .3982 .67799 .40726 .67544 .40185 .67063 Mtetra
.40185 .67063 .40726 .67544 .41634 .67287 .41096 .66805 Mtetra
.654 .752 .921 r
.41096 .66805 .41634 .67287 .42546 .67029 .4201 .66546 Mtetra
.654 .752 .922 r
.4201 .66546 .42546 .67029 .43461 .66769 .42926 .66286 Mtetra
.655 .753 .922 r
.42926 .66286 .43461 .66769 .44379 .66506 .43846 .66024 Mtetra
.43846 .66024 .44379 .66506 .45301 .66241 .4477 .65759 Mtetra
.656 .754 .922 r
.4477 .65759 .45301 .66241 .46225 .65972 .45696 .6549 Mtetra
.658 .756 .922 r
.45696 .6549 .46225 .65972 .47153 .657 .46626 .65218 Mtetra
.659 .757 .922 r
.46626 .65218 .47153 .657 .48083 .65423 .47559 .6494 Mtetra
.661 .758 .922 r
.47559 .6494 .48083 .65423 .49017 .65143 .48495 .64658 Mtetra
.662 .758 .921 r
.48495 .64658 .49017 .65143 .49955 .64859 .49434 .64372 Mtetra
.663 .758 .92 r
.49434 .64372 .49955 .64859 .50895 .64574 .50376 .64082 Mtetra
.663 .757 .92 r
.50376 .64082 .50895 .64574 .51838 .6429 .51322 .63792 Mtetra
.661 .754 .919 r
.51322 .63792 .51838 .6429 .52785 .6401 .52271 .63506 Mtetra
.658 .751 .919 r
.52271 .63506 .52785 .6401 .53735 .63739 .53223 .63227 Mtetra
.652 .748 .92 r
.53223 .63227 .53735 .63739 .54688 .63479 .54178 .62963 Mtetra
.644 .744 .922 r
.54178 .62963 .54688 .63479 .55645 .63233 .55137 .62716 Mtetra
.635 .742 .925 r
.55137 .62716 .55645 .63233 .56605 .63001 .561 .62488 Mtetra
.625 .741 .93 r
.561 .62488 .56605 .63001 .57569 .62783 .57066 .62279 Mtetra
.617 .742 .936 r
.57066 .62279 .57569 .62783 .58537 .62575 .58036 .62085 Mtetra
.61 .747 .942 r
.58036 .62085 .58537 .62575 .59509 .62371 .59011 .619 Mtetra
.607 .754 .948 r
.59011 .619 .59509 .62371 .60485 .62165 .59989 .61714 Mtetra
.607 .764 .954 r
.59989 .61714 .60485 .62165 .61464 .61952 .60972 .61521 Mtetra
.611 .775 .959 r
.60972 .61521 .61464 .61952 .62447 .61727 .61958 .61314 Mtetra
.618 .786 .962 r
.61958 .61314 .62447 .61727 .63433 .61488 .62947 .61088 Mtetra
.625 .795 .964 r
.62947 .61088 .63433 .61488 .64423 .61234 .63939 .60843 Mtetra
.634 .803 .964 r
.63939 .60843 .64423 .61234 .65415 .60964 .64935 .60577 Mtetra
.643 .808 .962 r
.64935 .60577 .65415 .60964 .66411 .6068 .65933 .60291 Mtetra
.653 .811 .959 r
.65933 .60291 .66411 .6068 .67409 .6038 .66935 .59984 Mtetra
.664 .812 .954 r
.66935 .59984 .67409 .6038 .68411 .60065 .67938 .59657 Mtetra
.673 .81 .948 r
.67938 .59657 .68411 .60065 .69415 .59735 .68944 .5931 Mtetra
.682 .805 .941 r
.68944 .5931 .69415 .59735 .70421 .59391 .69953 .58944 Mtetra
.688 .799 .933 r
.69953 .58944 .70421 .59391 .71431 .59034 .70964 .58564 Mtetra
.692 .79 .926 r
.70964 .58564 .71431 .59034 .72443 .58669 .71978 .58175 Mtetra
.692 .781 .92 r
.71978 .58175 .72443 .58669 .73458 .58303 .72994 .57786 Mtetra
.688 .772 .915 r
.72994 .57786 .73458 .58303 .74477 .5794 .74015 .57405 Mtetra
.682 .764 .913 r
.74015 .57405 .74477 .5794 .75499 .57587 .75039 .57038 Mtetra
.675 .757 .913 r
.75039 .57038 .75499 .57587 .76526 .57247 .76069 .56691 Mtetra
.667 .752 .914 r
.76069 .56691 .76526 .57247 .77558 .56922 .77103 .56363 Mtetra
.66 .749 .916 r
.77103 .56363 .77558 .56922 .78595 .56612 .78142 .56054 Mtetra
.654 .748 .919 r
.78142 .56054 .78595 .56612 .79636 .56313 .79186 .55757 Mtetra
.651 .749 .921 r
.79186 .55757 .79636 .56313 .80681 .56021 .80235 .55469 Mtetra
.648 .75 .924 r
.80235 .55469 .80681 .56021 .81731 .55735 .81288 .55185 Mtetra
.648 .752 .925 r
.81288 .55185 .81731 .55735 .82785 .55449 .82345 .549 Mtetra
.649 .753 .926 r
.82345 .549 .82785 .55449 .83843 .55162 .83406 .54612 Mtetra
.65 .754 .926 r
.83406 .54612 .83843 .55162 .84905 .54871 .8447 .5432 Mtetra
.652 .755 .925 r
.8447 .5432 .84905 .54871 .8597 .54577 .85538 .54022 Mtetra
.653 .755 .924 r
.85538 .54022 .8597 .54577 .87039 .54277 .8661 .53719 Mtetra
.655 .755 .923 r
.8661 .53719 .87039 .54277 .88111 .53974 .87685 .53411 Mtetra
.656 .754 .922 r
.87685 .53411 .88111 .53974 .89188 .53667 .88764 .531 Mtetra
.657 .754 .922 r
.88764 .531 .89188 .53667 .90268 .53357 .89847 .52786 Mtetra
.657 .753 .921 r
.89847 .52786 .90268 .53357 .91351 .53044 .90933 .5247 Mtetra
.90933 .5247 .91351 .53044 .92439 .52729 .92024 .52152 Mtetra
.657 .753 .92 r
.92024 .52152 .92439 .52729 .93531 .52412 .93118 .51832 Mtetra
.657 .752 .92 r
.93118 .51832 .93531 .52412 .94626 .52094 .94217 .51512 Mtetra
.94217 .51512 .94626 .52094 .95726 .51775 .95319 .5119 Mtetra
.95319 .5119 .95726 .51775 .96829 .51454 .96426 .50866 Mtetra
.654 .751 .921 r
.36922 .67351 .37472 .67831 .38373 .67576 .37826 .67094 Mtetra
.37826 .67094 .38373 .67576 .39278 .6732 .38732 .66836 Mtetra
.38732 .66836 .39278 .6732 .40185 .67063 .39641 .66578 Mtetra
.39641 .66578 .40185 .67063 .41096 .66805 .40554 .66318 Mtetra
.40554 .66318 .41096 .66805 .4201 .66546 .4147 .66059 Mtetra
.4147 .66059 .4201 .66546 .42926 .66286 .42388 .65798 Mtetra
.42388 .65798 .42926 .66286 .43846 .66024 .4331 .65536 Mtetra
.654 .752 .922 r
.4331 .65536 .43846 .66024 .4477 .65759 .44236 .65272 Mtetra
.655 .754 .922 r
.44236 .65272 .4477 .65759 .45696 .6549 .45164 .65005 Mtetra
.656 .755 .923 r
.45164 .65005 .45696 .6549 .46626 .65218 .46096 .64734 Mtetra
.658 .757 .923 r
.46096 .64734 .46626 .65218 .47559 .6494 .47031 .64458 Mtetra
.66 .759 .923 r
.47031 .64458 .47559 .6494 .48495 .64658 .47969 .64177 Mtetra
.662 .76 .923 r
.47969 .64177 .48495 .64658 .49434 .64372 .4891 .63889 Mtetra
.663 .761 .923 r
.4891 .63889 .49434 .64372 .50376 .64082 .49855 .63597 Mtetra
.664 .761 .922 r
.49855 .63597 .50376 .64082 .51322 .63792 .50803 .63302 Mtetra
.663 .759 .921 r
.50803 .63302 .51322 .63792 .52271 .63506 .51753 .63008 Mtetra
.66 .756 .921 r
.51753 .63008 .52271 .63506 .53223 .63227 .52708 .62721 Mtetra
.654 .752 .921 r
.52708 .62721 .53223 .63227 .54178 .62963 .53665 .62448 Mtetra
.645 .747 .923 r
.53665 .62448 .54178 .62963 .55137 .62716 .54626 .62196 Mtetra
.634 .742 .925 r
.54626 .62196 .55137 .62716 .561 .62488 .55591 .61967 Mtetra
.622 .738 .93 r
.55591 .61967 .561 .62488 .57066 .62279 .56559 .61764 Mtetra
.611 .737 .935 r
.56559 .61764 .57066 .62279 .58036 .62085 .57532 .61583 Mtetra
.601 .739 .942 r
.57532 .61583 .58036 .62085 .59011 .619 .58509 .61416 Mtetra
.596 .746 .949 r
.58509 .61416 .59011 .619 .59989 .61714 .59491 .61253 Mtetra
.595 .756 .955 r
.59491 .61253 .59989 .61714 .60972 .61521 .60476 .61083 Mtetra
.599 .769 .961 r
.60476 .61083 .60972 .61521 .61958 .61314 .61465 .60897 Mtetra
.607 .782 .965 r
.61465 .60897 .61958 .61314 .62947 .61088 .62457 .60688 Mtetra
.617 .794 .967 r
.62457 .60688 .62947 .61088 .63939 .60843 .63453 .60454 Mtetra
.63 .804 .966 r
.63453 .60454 .63939 .60843 .64935 .60577 .64451 .60193 Mtetra
.642 .811 .964 r
.64451 .60193 .64935 .60577 .65933 .60291 .65453 .59905 Mtetra
.656 .815 .96 r
.65453 .59905 .65933 .60291 .66935 .59984 .66456 .5959 Mtetra
.669 .816 .954 r
.66456 .5959 .66935 .59984 .67938 .59657 .67462 .59248 Mtetra
.681 .813 .946 r
.67462 .59248 .67938 .59657 .68944 .5931 .68471 .5888 Mtetra
.692 .807 .937 r
.68471 .5888 .68944 .5931 .69953 .58944 .69481 .58489 Mtetra
.698 .799 .928 r
.69481 .58489 .69953 .58944 .70964 .58564 .70493 .58082 Mtetra
.701 .79 .92 r
.70493 .58082 .70964 .58564 .71978 .58175 .71508 .57667 Mtetra
.699 .779 .914 r
.71508 .57667 .71978 .58175 .72994 .57786 .72527 .57255 Mtetra
.693 .77 .91 r
.72527 .57255 .72994 .57786 .74015 .57405 .73549 .56858 Mtetra
.685 .762 .91 r
.73549 .56858 .74015 .57405 .75039 .57038 .74576 .56481 Mtetra
.675 .755 .911 r
.74576 .56481 .75039 .57038 .76069 .56691 .75608 .56131 Mtetra
.666 .752 .914 r
.75608 .56131 .76069 .56691 .77103 .56363 .76645 .55806 Mtetra
.658 .75 .918 r
.76645 .55806 .77103 .56363 .78142 .56054 .77687 .555 Mtetra
.651 .75 .922 r
.77687 .555 .78142 .56054 .79186 .55757 .78735 .55209 Mtetra
.648 .752 .925 r
.78735 .55209 .79186 .55757 .80235 .55469 .79786 .54925 Mtetra
.646 .754 .927 r
.79786 .54925 .80235 .55469 .81288 .55185 .80843 .54642 Mtetra
.647 .755 .928 r
.80843 .54642 .81288 .55185 .82345 .549 .81902 .54356 Mtetra
.649 .756 .928 r
.81902 .54356 .82345 .549 .83406 .54612 .82966 .54065 Mtetra
.651 .757 .927 r
.82966 .54065 .83406 .54612 .8447 .5432 .84033 .53768 Mtetra
.653 .757 .926 r
.84033 .53768 .8447 .5432 .85538 .54022 .85103 .53465 Mtetra
.655 .756 .924 r
.85103 .53465 .85538 .54022 .8661 .53719 .86178 .53156 Mtetra
.656 .755 .923 r
.86178 .53156 .8661 .53719 .87685 .53411 .87255 .52843 Mtetra
.657 .754 .922 r
.87255 .52843 .87685 .53411 .88764 .531 .88337 .52528 Mtetra
.657 .753 .921 r
.88337 .52528 .88764 .531 .89847 .52786 .89422 .52209 Mtetra
.658 .753 .92 r
.89422 .52209 .89847 .52786 .90933 .5247 .90512 .5189 Mtetra
.658 .752 .92 r
.90512 .5189 .90933 .5247 .92024 .52152 .91605 .51569 Mtetra
.91605 .51569 .92024 .52152 .93118 .51832 .92703 .51247 Mtetra
.657 .752 .92 r
.92703 .51247 .93118 .51832 .94217 .51512 .93804 .50924 Mtetra
.93804 .50924 .94217 .51512 .95319 .5119 .9491 .506 Mtetra
.9491 .506 .95319 .5119 .96426 .50866 .9602 .50275 Mtetra
.655 .751 .921 r
.36369 .66869 .36922 .67351 .37826 .67094 .37274 .66609 Mtetra
.655 .751 .92 r
.37274 .66609 .37826 .67094 .38732 .66836 .38183 .66348 Mtetra
.654 .75 .92 r
.38183 .66348 .38732 .66836 .39641 .66578 .39094 .66087 Mtetra
.39094 .66087 .39641 .66578 .40554 .66318 .40009 .65826 Mtetra
.654 .749 .92 r
.40009 .65826 .40554 .66318 .4147 .66059 .40926 .65564 Mtetra
.653 .749 .92 r
.40926 .65564 .4147 .66059 .42388 .65798 .41847 .65303 Mtetra
.653 .75 .921 r
.41847 .65303 .42388 .65798 .4331 .65536 .42771 .65041 Mtetra
.653 .751 .921 r
.42771 .65041 .4331 .65536 .44236 .65272 .43698 .64779 Mtetra
.653 .752 .922 r
.43698 .64779 .44236 .65272 .45164 .65005 .44628 .64514 Mtetra
.654 .754 .923 r
.44628 .64514 .45164 .65005 .46096 .64734 .45562 .64247 Mtetra
.655 .756 .924 r
.45562 .64247 .46096 .64734 .47031 .64458 .46499 .63976 Mtetra
.657 .759 .925 r
.46499 .63976 .47031 .64458 .47969 .64177 .47439 .63698 Mtetra
.66 .762 .926 r
.47439 .63698 .47969 .64177 .4891 .63889 .48383 .63413 Mtetra
.662 .765 .926 r
.48383 .63413 .4891 .63889 .49855 .63597 .49329 .63121 Mtetra
.665 .766 .925 r
.49329 .63121 .49855 .63597 .50803 .63302 .5028 .62821 Mtetra
.665 .765 .924 r
.5028 .62821 .50803 .63302 .51753 .63008 .51233 .6252 Mtetra
.664 .762 .923 r
.51233 .6252 .51753 .63008 .52708 .62721 .52189 .62222 Mtetra
.658 .757 .923 r
.52189 .62222 .52708 .62721 .53665 .62448 .53149 .61937 Mtetra
.649 .75 .923 r
.53149 .61937 .53665 .62448 .54626 .62196 .54112 .61673 Mtetra
.637 .742 .925 r
.54112 .61673 .54626 .62196 .55591 .61967 .55079 .61437 Mtetra
.621 .735 .929 r
.55079 .61437 .55591 .61967 .56559 .61764 .56049 .61236 Mtetra
.606 .731 .934 r
.56049 .61236 .56559 .61764 .57532 .61583 .57024 .61064 Mtetra
.592 .731 .94 r
.57024 .61064 .57532 .61583 .58509 .61416 .58004 .60917 Mtetra
.583 .736 .948 r
.58004 .60917 .58509 .61416 .59491 .61253 .58988 .60778 Mtetra
.58 .746 .956 r
.58988 .60778 .59491 .61253 .60476 .61083 .59976 .60635 Mtetra
.584 .761 .962 r
.59976 .60635 .60476 .61083 .61465 .60897 .60968 .60475 Mtetra
.594 .777 .967 r
.60968 .60475 .61465 .60897 .62457 .60688 .61964 .60288 Mtetra
.608 .792 .97 r
.61964 .60288 .62457 .60688 .63453 .60454 .62963 .60069 Mtetra
.624 .805 .969 r
.62963 .60069 .63453 .60454 .64451 .60193 .63964 .59815 Mtetra
.641 .814 .966 r
.63964 .59815 .64451 .60193 .65453 .59905 .64968 .59525 Mtetra
.659 .82 .961 r
.64968 .59525 .65453 .59905 .66456 .5959 .65975 .592 Mtetra
.676 .82 .952 r
.65975 .592 .66456 .5959 .67462 .59248 .66983 .58839 Mtetra
.691 .817 .942 r
.66983 .58839 .67462 .59248 .68471 .5888 .67993 .58446 Mtetra
.703 .81 .931 r
.67993 .58446 .68471 .5888 .69481 .58489 .69005 .58025 Mtetra
.709 .799 .921 r
.69005 .58025 .69481 .58489 .70493 .58082 .70019 .57586 Mtetra
.71 .788 .913 r
.70019 .57586 .70493 .58082 .71508 .57667 .71036 .57143 Mtetra
.706 .776 .907 r
.71036 .57143 .71508 .57667 .72527 .57255 .72055 .56708 Mtetra
.697 .766 .905 r
.72055 .56708 .72527 .57255 .73549 .56858 .7308 .56297 Mtetra
.686 .758 .906 r
.7308 .56297 .73549 .56858 .74576 .56481 .74109 .55916 Mtetra
.673 .753 .91 r
.74109 .55916 .74576 .56481 .75608 .56131 .75144 .55568 Mtetra
.662 .751 .916 r
.75144 .55568 .75608 .56131 .76645 .55806 .76184 .5525 Mtetra
.653 .751 .922 r
.76184 .5525 .76645 .55806 .77687 .555 .7723 .54954 Mtetra
.647 .753 .927 r
.7723 .54954 .77687 .555 .78735 .55209 .78281 .5467 Mtetra
.645 .756 .93 r
.78281 .5467 .78735 .55209 .79786 .54925 .79336 .5439 Mtetra
.645 .758 .932 r
.79336 .5439 .79786 .54925 .80843 .54642 .80395 .54108 Mtetra
.647 .76 .932 r
.80395 .54108 .80843 .54642 .81902 .54356 .81458 .53818 Mtetra
.65 .761 .93 r
.81458 .53818 .81902 .54356 .82966 .54065 .82524 .53521 Mtetra
.653 .76 .928 r
.82524 .53521 .82966 .54065 .84033 .53768 .83593 .53216 Mtetra
.655 .759 .926 r
.83593 .53216 .84033 .53768 .85103 .53465 .84666 .52904 Mtetra
.657 .757 .924 r
.84666 .52904 .85103 .53465 .86178 .53156 .85742 .52588 Mtetra
.658 .755 .922 r
.85742 .52588 .86178 .53156 .87255 .52843 .86823 .52269 Mtetra
.658 .754 .92 r
.86823 .52269 .87255 .52843 .88337 .52528 .87907 .51947 Mtetra
.658 .752 .919 r
.87907 .51947 .88337 .52528 .89422 .52209 .88995 .51625 Mtetra
.658 .751 .919 r
.88995 .51625 .89422 .52209 .90512 .5189 .90087 .51302 Mtetra
.90087 .51302 .90512 .5189 .91605 .51569 .91183 .50978 Mtetra
.657 .751 .919 r
.91183 .50978 .91605 .51569 .92703 .51247 .92284 .50655 Mtetra
.92284 .50655 .92703 .51247 .93804 .50924 .93389 .5033 Mtetra
.93389 .5033 .93804 .50924 .9491 .506 .94497 .50005 Mtetra
.657 .751 .92 r
.94497 .50005 .9491 .506 .9602 .50275 .9561 .4968 Mtetra
.655 .751 .92 r
.35813 .66383 .36369 .66869 .37274 .66609 .3672 .6612 Mtetra
.3672 .6612 .37274 .66609 .38183 .66348 .3763 .65856 Mtetra
.655 .75 .92 r
.3763 .65856 .38183 .66348 .39094 .66087 .38544 .65591 Mtetra
.655 .749 .919 r
.38544 .65591 .39094 .66087 .40009 .65826 .3946 .65327 Mtetra
.654 .749 .919 r
.3946 .65327 .40009 .65826 .40926 .65564 .4038 .65064 Mtetra
.653 .748 .919 r
.4038 .65064 .40926 .65564 .41847 .65303 .41302 .64801 Mtetra
.653 .748 .92 r
.41302 .64801 .41847 .65303 .42771 .65041 .42228 .64539 Mtetra
.652 .748 .92 r
.42228 .64539 .42771 .65041 .43698 .64779 .43157 .64277 Mtetra
.651 .749 .922 r
.43157 .64277 .43698 .64779 .44628 .64514 .44089 .64016 Mtetra
.651 .751 .923 r
.44089 .64016 .44628 .64514 .45562 .64247 .45025 .63754 Mtetra
.652 .754 .924 r
.45025 .63754 .45562 .64247 .46499 .63976 .45964 .63489 Mtetra
.654 .758 .926 r
.45964 .63489 .46499 .63976 .47439 .63698 .46906 .63218 Mtetra
.656 .762 .927 r
.46906 .63218 .47439 .63698 .48383 .63413 .47852 .62939 Mtetra
.66 .766 .928 r
.47852 .62939 .48383 .63413 .49329 .63121 .48801 .6265 Mtetra
.664 .769 .928 r
.48801 .6265 .49329 .63121 .5028 .62821 .49753 .6235 Mtetra
.667 .77 .927 r
.49753 .6235 .5028 .62821 .51233 .6252 .50709 .62043 Mtetra
.668 .769 .926 r
.50709 .62043 .51233 .6252 .52189 .62222 .51667 .61732 Mtetra
.664 .764 .924 r
.51667 .61732 .52189 .62222 .53149 .61937 .52629 .61432 Mtetra
.656 .756 .924 r
.52629 .61432 .53149 .61937 .54112 .61673 .53594 .6115 Mtetra
.642 .745 .924 r
.53594 .6115 .54112 .61673 .55079 .61437 .54563 .60901 Mtetra
.623 .735 .927 r
.54563 .60901 .55079 .61437 .56049 .61236 .55536 .60694 Mtetra
.604 .726 .931 r
.55536 .60694 .56049 .61236 .57024 .61064 .56513 .60527 Mtetra
.584 .721 .938 r
.56513 .60527 .57024 .61064 .58004 .60917 .57495 .60396 Mtetra
.571 .724 .946 r
.57495 .60396 .58004 .60917 .58988 .60778 .58482 .60283 Mtetra
.565 .733 .954 r
.58482 .60283 .58988 .60778 .59976 .60635 .59473 .60172 Mtetra
.568 .749 .962 r
.59473 .60172 .59976 .60635 .60968 .60475 .60468 .60043 Mtetra
.579 .768 .968 r
.60468 .60043 .60968 .60475 .61964 .60288 .61467 .59882 Mtetra
.596 .787 .972 r
.61467 .59882 .61964 .60288 .62963 .60069 .62469 .59683 Mtetra
.617 .804 .971 r
.62469 .59683 .62963 .60069 .63964 .59815 .63474 .59437 Mtetra
.641 .816 .967 r
.63474 .59437 .63964 .59815 .64968 .59525 .64481 .59146 Mtetra
.664 .823 .96 r
.64481 .59146 .64968 .59525 .65975 .592 .6549 .58808 Mtetra
.686 .824 .949 r
.6549 .58808 .65975 .592 .66983 .58839 .665 .58425 Mtetra
.703 .819 .937 r
.665 .58425 .66983 .58839 .67993 .58446 .67512 .58001 Mtetra
.715 .809 .924 r
.67512 .58001 .67993 .58446 .69005 .58025 .68525 .57545 Mtetra
.72 .797 .912 r
.68525 .57545 .69005 .58025 .70019 .57586 .6954 .57071 Mtetra
.718 .783 .904 r
.6954 .57071 .70019 .57586 .71036 .57143 .70558 .56598 Mtetra
.711 .771 .899 r
.70558 .56598 .71036 .57143 .72055 .56708 .7158 .56141 Mtetra
.698 .761 .9 r
.7158 .56141 .72055 .56708 .7308 .56297 .72607 .55722 Mtetra
.684 .754 .904 r
.72607 .55722 .7308 .56297 .74109 .55916 .73639 .55342 Mtetra
.669 .75 .911 r
.73639 .55342 .74109 .55916 .75144 .55568 .74677 .55005 Mtetra
.656 .75 .919 r
.74677 .55005 .75144 .55568 .76184 .5525 .75721 .54701 Mtetra
.647 .753 .926 r
.75721 .54701 .76184 .5525 .7723 .54954 .76771 .54417 Mtetra
.642 .756 .932 r
.76771 .54417 .7723 .54954 .78281 .5467 .77825 .54142 Mtetra
.642 .761 .935 r
.77825 .54142 .78281 .5467 .79336 .5439 .78883 .53863 Mtetra
.644 .763 .935 r
.78883 .53863 .79336 .5439 .80395 .54108 .79945 .53578 Mtetra
.649 .764 .933 r
.79945 .53578 .80395 .54108 .81458 .53818 .8101 .53281 Mtetra
.653 .764 .931 r
.8101 .53281 .81458 .53818 .82524 .53521 .82078 .52974 Mtetra
.656 .762 .927 r
.82078 .52974 .82524 .53521 .83593 .53216 .8315 .52658 Mtetra
.658 .759 .924 r
.8315 .52658 .83593 .53216 .84666 .52904 .84225 .52336 Mtetra
.659 .756 .922 r
.84225 .52336 .84666 .52904 .85742 .52588 .85304 .52011 Mtetra
.66 .754 .92 r
.85304 .52011 .85742 .52588 .86823 .52269 .86386 .51684 Mtetra
.659 .752 .919 r
.86386 .51684 .86823 .52269 .87907 .51947 .87473 .51358 Mtetra
.659 .751 .918 r
.87473 .51358 .87907 .51947 .88995 .51625 .88564 .51032 Mtetra
.658 .75 .918 r
.88564 .51032 .88995 .51625 .90087 .51302 .89659 .50706 Mtetra
.658 .749 .918 r
.89659 .50706 .90087 .51302 .91183 .50978 .90758 .50381 Mtetra
.657 .749 .918 r
.90758 .50381 .91183 .50978 .92284 .50655 .91862 .50056 Mtetra
.657 .75 .919 r
.91862 .50056 .92284 .50655 .93389 .5033 .9297 .49732 Mtetra
.656 .75 .919 r
.9297 .49732 .93389 .5033 .94497 .50005 .94082 .49406 Mtetra
.656 .751 .92 r
.94082 .49406 .94497 .50005 .9561 .4968 .95198 .4908 Mtetra
.656 .752 .92 r
.35253 .65894 .35813 .66383 .3672 .6612 .36162 .65627 Mtetra
.656 .751 .919 r
.36162 .65627 .3672 .6612 .3763 .65856 .37074 .65359 Mtetra
.656 .75 .919 r
.37074 .65359 .3763 .65856 .38544 .65591 .3799 .65091 Mtetra
.656 .749 .918 r
.3799 .65091 .38544 .65591 .3946 .65327 .38908 .64823 Mtetra
.655 .748 .918 r
.38908 .64823 .3946 .65327 .4038 .65064 .3983 .64556 Mtetra
.654 .747 .918 r
.3983 .64556 .4038 .65064 .41302 .64801 .40754 .6429 Mtetra
.653 .746 .918 r
.40754 .6429 .41302 .64801 .42228 .64539 .41682 .64027 Mtetra
.651 .746 .919 r
.41682 .64027 .42228 .64539 .43157 .64277 .42613 .63765 Mtetra
.65 .746 .92 r
.42613 .63765 .43157 .64277 .44089 .64016 .43547 .63507 Mtetra
.649 .747 .922 r
.43547 .63507 .44089 .64016 .45025 .63754 .44485 .63249 Mtetra
.648 .75 .924 r
.44485 .63249 .45025 .63754 .45964 .63489 .45425 .62992 Mtetra
.649 .754 .926 r
.45425 .62992 .45964 .63489 .46906 .63218 .4637 .62731 Mtetra
.651 .759 .928 r
.4637 .62731 .46906 .63218 .47852 .62939 .47317 .62462 Mtetra
.655 .765 .93 r
.47317 .62462 .47852 .62939 .48801 .6265 .48268 .62182 Mtetra
.661 .771 .931 r
.48268 .62182 .48801 .6265 .49753 .6235 .49223 .61886 Mtetra
.666 .775 .93 r
.49223 .61886 .49753 .6235 .50709 .62043 .50181 .61577 Mtetra
.671 .776 .928 r
.50181 .61577 .50709 .62043 .51667 .61732 .51142 .61255 Mtetra
.67 .772 .926 r
.51142 .61255 .51667 .61732 .52629 .61432 .52106 .60936 Mtetra
.665 .763 .924 r
.52106 .60936 .52629 .61432 .53594 .6115 .53074 .6063 Mtetra
.65 .75 .923 r
.53074 .6063 .53594 .6115 .54563 .60901 .54045 .60359 Mtetra
.629 .736 .924 r
.54045 .60359 .54563 .60901 .55536 .60694 .55019 .60136 Mtetra
.605 .722 .927 r
.55019 .60136 .55536 .60694 .56513 .60527 .55999 .59967 Mtetra
.579 .712 .934 r
.55999 .59967 .56513 .60527 .57495 .60396 .56983 .59849 Mtetra
.56 .71 .942 r
.56983 .59849 .57495 .60396 .58482 .60283 .57972 .59762 Mtetra
.547 .717 .951 r
.57972 .59762 .58482 .60283 .59473 .60172 .58965 .59687 Mtetra
.548 .733 .961 r
.58965 .59687 .59473 .60172 .60468 .60043 .59964 .59596 Mtetra
.56 .755 .969 r
.59964 .59596 .60468 .60043 .61467 .59882 .60966 .59469 Mtetra
.581 .779 .974 r
.60966 .59469 .61467 .59882 .62469 .59683 .61971 .59293 Mtetra
.61 .801 .973 r
.61971 .59293 .62469 .59683 .63474 .59437 .62979 .5906 Mtetra
.64 .817 .968 r
.62979 .5906 .63474 .59437 .64481 .59146 .63989 .58767 Mtetra
.67 .826 .958 r
.63989 .58767 .64481 .59146 .6549 .58808 .65001 .58413 Mtetra
.697 .826 .945 r
.65001 .58413 .6549 .58808 .665 .58425 .66013 .58002 Mtetra
.716 .819 .929 r
.66013 .58002 .665 .58425 .67512 .58001 .67027 .57541 Mtetra
.728 .807 .914 r
.67027 .57541 .67512 .58001 .68525 .57545 .68041 .57043 Mtetra
.732 .793 .901 r
.68041 .57043 .68525 .57545 .6954 .57071 .69058 .56529 Mtetra
.726 .777 .893 r
.69058 .56529 .6954 .57071 .70558 .56598 .70077 .56026 Mtetra
.715 .764 .891 r
.70077 .56026 .70558 .56598 .7158 .56141 .711 .55552 Mtetra
.698 .753 .895 r
.711 .55552 .7158 .56141 .72607 .55722 .7213 .55131 Mtetra
.68 .748 .902 r
.7213 .55131 .72607 .55722 .73639 .55342 .73165 .54763 Mtetra
.661 .746 .913 r
.73165 .54763 .73639 .55342 .74677 .55005 .74207 .54444 Mtetra
.647 .749 .924 r
.74207 .54444 .74677 .55005 .75721 .54701 .75256 .54161 Mtetra
.639 .755 .932 r
.75256 .54161 .75721 .54701 .76771 .54417 .76309 .53892 Mtetra
.636 .761 .938 r
.76309 .53892 .76771 .54417 .77825 .54142 .77367 .53625 Mtetra
.641 .766 .939 r
.77367 .53625 .77825 .54142 .78883 .53863 .78429 .53345 Mtetra
.646 .769 .938 r
.78429 .53345 .78883 .53863 .79945 .53578 .79493 .53051 Mtetra
.653 .769 .934 r
.79493 .53051 .79945 .53578 .8101 .53281 .8056 .52742 Mtetra
.658 .766 .93 r
.8056 .52742 .8101 .53281 .82078 .52974 .8163 .5242 Mtetra
.661 .762 .925 r
.8163 .5242 .82078 .52974 .8315 .52658 .82703 .5209 Mtetra
.662 .758 .921 r
.82703 .5209 .8315 .52658 .84225 .52336 .8378 .51756 Mtetra
.662 .755 .919 r
.8378 .51756 .84225 .52336 .85304 .52011 .84861 .51422 Mtetra
.662 .752 .917 r
.84861 .51422 .85304 .52011 .86386 .51684 .85946 .51088 Mtetra
.66 .749 .916 r
.85946 .51088 .86386 .51684 .87473 .51358 .87036 .50758 Mtetra
.659 .748 .916 r
.87036 .50758 .87473 .51358 .88564 .51032 .88129 .50429 Mtetra
.658 .748 .916 r
.88129 .50429 .88564 .51032 .89659 .50706 .89228 .50102 Mtetra
.657 .748 .917 r
.89228 .50102 .89659 .50706 .90758 .50381 .9033 .49777 Mtetra
.656 .748 .917 r
.9033 .49777 .90758 .50381 .91862 .50056 .91437 .49452 Mtetra
.656 .749 .918 r
.91437 .49452 .91862 .50056 .9297 .49732 .92548 .49127 Mtetra
.655 .749 .919 r
.92548 .49127 .9297 .49732 .94082 .49406 .93664 .48802 Mtetra
.655 .75 .92 r
.93664 .48802 .94082 .49406 .95198 .4908 .94784 .48476 Mtetra
.657 .752 .92 r
.34689 .65403 .35253 .65894 .36162 .65627 .35601 .65131 Mtetra
.657 .751 .919 r
.35601 .65131 .36162 .65627 .37074 .65359 .36515 .64859 Mtetra
.657 .75 .918 r
.36515 .64859 .37074 .65359 .3799 .65091 .37432 .64587 Mtetra
.657 .749 .918 r
.37432 .64587 .3799 .65091 .38908 .64823 .38353 .64315 Mtetra
.656 .748 .917 r
.38353 .64315 .38908 .64823 .3983 .64556 .39276 .64043 Mtetra
.655 .746 .917 r
.39276 .64043 .3983 .64556 .40754 .6429 .40203 .63774 Mtetra
.653 .745 .917 r
.40203 .63774 .40754 .6429 .41682 .64027 .41133 .63507 Mtetra
.651 .744 .917 r
.41133 .63507 .41682 .64027 .42613 .63765 .42066 .63244 Mtetra
.649 .743 .918 r
.42066 .63244 .42613 .63765 .43547 .63507 .43002 .62985 Mtetra
.647 .743 .92 r
.43002 .62985 .43547 .63507 .44485 .63249 .43941 .62731 Mtetra
.644 .745 .922 r
.43941 .62731 .44485 .63249 .45425 .62992 .44884 .62481 Mtetra
.644 .748 .925 r
.44884 .62481 .45425 .62992 .4637 .62731 .4583 .6223 Mtetra
.645 .753 .928 r
.4583 .6223 .4637 .62731 .47317 .62462 .46779 .61975 Mtetra
.649 .76 .931 r
.46779 .61975 .47317 .62462 .48268 .62182 .47732 .61709 Mtetra
.656 .768 .932 r
.47732 .61709 .48268 .62182 .49223 .61886 .48689 .61424 Mtetra
.664 .776 .933 r
.48689 .61424 .49223 .61886 .50181 .61577 .49649 .61119 Mtetra
.673 .781 .931 r
.49649 .61119 .50181 .61577 .51142 .61255 .50613 .6079 Mtetra
.676 .78 .928 r
.50613 .6079 .51142 .61255 .52106 .60936 .5158 .60453 Mtetra
.675 .773 .924 r
.5158 .60453 .52106 .60936 .53074 .6063 .52549 .60118 Mtetra
.662 .759 .922 r
.52549 .60118 .53074 .6063 .54045 .60359 .53523 .59816 Mtetra
.641 .741 .921 r
.53523 .59816 .54045 .60359 .55019 .60136 .54499 .59566 Mtetra
.612 .721 .923 r
.54499 .59566 .55019 .60136 .55999 .59967 .5548 .59383 Mtetra
.578 .704 .928 r
.5548 .59383 .55999 .59967 .56983 .59849 .56466 .59272 Mtetra
.551 .696 .935 r
.56466 .59272 .56983 .59849 .57972 .59762 .57458 .59208 Mtetra
.53 .697 .945 r
.57458 .59208 .57972 .59762 .58965 .59687 .58454 .5917 Mtetra
.528 .712 .956 r
.58454 .5917 .58965 .59687 .59964 .59596 .59456 .59121 Mtetra
.54 .736 .966 r
.59456 .59121 .59964 .59596 .60966 .59469 .60461 .59034 Mtetra
.566 .765 .972 r
.60461 .59034 .60966 .59469 .61971 .59293 .6147 .58888 Mtetra
.603 .793 .972 r
.6147 .58888 .61971 .59293 .62979 .5906 .62481 .5867 Mtetra
.642 .813 .965 r
.62481 .5867 .62979 .5906 .63989 .58767 .63494 .58375 Mtetra
.679 .824 .953 r
.63494 .58375 .63989 .58767 .65001 .58413 .64508 .58003 Mtetra
.71 .824 .935 r
.64508 .58003 .65001 .58413 .66013 .58002 .65522 .57558 Mtetra
.731 .815 .917 r
.65522 .57558 .66013 .58002 .67027 .57541 .66537 .57053 Mtetra
.741 .8 .9 r
.66537 .57053 .67027 .57541 .68041 .57043 .67553 .56509 Mtetra
.741 .784 .887 r
.67553 .56509 .68041 .57043 .69058 .56529 .6857 .55952 Mtetra
.731 .767 .882 r
.6857 .55952 .69058 .56529 .70077 .56026 .69591 .55422 Mtetra
.716 .755 .883 r
.69591 .55422 .70077 .56026 .711 .55552 .70616 .54938 Mtetra
.693 .745 .891 r
.70616 .54938 .711 .55552 .7213 .55131 .71649 .54527 Mtetra
.67 .741 .904 r
.71649 .54527 .7213 .55131 .73165 .54763 .72689 .54182 Mtetra
.65 .743 .918 r
.72689 .54182 .73165 .54763 .74207 .54444 .73736 .53892 Mtetra
.634 .749 .931 r
.73736 .53892 .74207 .54444 .75256 .54161 .74789 .53634 Mtetra
.63 .758 .939 r
.74789 .53634 .75256 .54161 .76309 .53892 .75846 .53379 Mtetra
.633 .766 .943 r
.75846 .53379 .76309 .53892 .77367 .53625 .76907 .53115 Mtetra
.642 .772 .942 r
.76907 .53115 .77367 .53625 .78429 .53345 .77971 .52828 Mtetra
.652 .773 .937 r
.77971 .52828 .78429 .53345 .79493 .53051 .79037 .52518 Mtetra
.659 .77 .931 r
.79037 .52518 .79493 .53051 .8056 .52742 .80106 .52191 Mtetra
.664 .766 .925 r
.80106 .52191 .8056 .52742 .8163 .5242 .81177 .51851 Mtetra
.666 .76 .92 r
.81177 .51851 .8163 .5242 .82703 .5209 .82252 .51506 Mtetra
.666 .755 .917 r
.82252 .51506 .82703 .5209 .8378 .51756 .83331 .51161 Mtetra
.664 .751 .915 r
.83331 .51161 .8378 .51756 .84861 .51422 .84415 .50819 Mtetra
.663 .749 .914 r
.84415 .50819 .84861 .51422 .85946 .51088 .85502 .50481 Mtetra
.66 .747 .914 r
.85502 .50481 .85946 .51088 .87036 .50758 .86595 .50149 Mtetra
.659 .746 .915 r
.86595 .50149 .87036 .50758 .88129 .50429 .87692 .49819 Mtetra
.657 .746 .916 r
.87692 .49819 .88129 .50429 .89228 .50102 .88793 .49493 Mtetra
.656 .747 .917 r
.88793 .49493 .89228 .50102 .9033 .49777 .89899 .49168 Mtetra
.655 .747 .918 r
.89899 .49168 .9033 .49777 .91437 .49452 .91009 .48844 Mtetra
.655 .748 .919 r
.91009 .48844 .91437 .49452 .92548 .49127 .92124 .48519 Mtetra
.655 .749 .919 r
.92124 .48519 .92548 .49127 .93664 .48802 .93243 .48194 Mtetra
.654 .75 .92 r
.93243 .48194 .93664 .48802 .94784 .48476 .94366 .47868 Mtetra
.658 .752 .919 r
.34122 .64908 .34689 .65403 .35601 .65131 .35036 .64633 Mtetra
.658 .751 .919 r
.35036 .64633 .35601 .65131 .36515 .64859 .35952 .64358 Mtetra
.658 .751 .918 r
.35952 .64358 .36515 .64859 .37432 .64587 .36871 .64081 Mtetra
.658 .75 .918 r
.36871 .64081 .37432 .64587 .38353 .64315 .37794 .63804 Mtetra
.658 .749 .917 r
.37794 .63804 .38353 .64315 .39276 .64043 .3872 .63527 Mtetra
.657 .747 .916 r
.3872 .63527 .39276 .64043 .40203 .63774 .39648 .63252 Mtetra
.655 .745 .916 r
.39648 .63252 .40203 .63774 .41133 .63507 .4058 .62979 Mtetra
.653 .743 .916 r
.4058 .62979 .41133 .63507 .42066 .63244 .41515 .62711 Mtetra
.65 .741 .916 r
.41515 .62711 .42066 .63244 .43002 .62985 .42453 .6245 Mtetra
.646 .739 .917 r
.42453 .6245 .43002 .62985 .43941 .62731 .43395 .62195 Mtetra
.642 .739 .919 r
.43395 .62195 .43941 .62731 .44884 .62481 .44339 .6195 Mtetra
.639 .74 .922 r
.44339 .6195 .44884 .62481 .4583 .6223 .45287 .61709 Mtetra
.637 .744 .926 r
.45287 .61709 .4583 .6223 .46779 .61975 .46238 .6147 Mtetra
.64 .752 .93 r
.46238 .6147 .46779 .61975 .47732 .61709 .47193 .61223 Mtetra
.646 .762 .933 r
.47193 .61223 .47732 .61709 .48689 .61424 .48152 .60959 Mtetra
.657 .774 .935 r
.48152 .60959 .48689 .61424 .49649 .61119 .49114 .60667 Mtetra
.671 .784 .934 r
.49114 .60667 .49649 .61119 .50613 .6079 .5008 .6034 Mtetra
.681 .788 .93 r
.5008 .6034 .50613 .6079 .5158 .60453 .51049 .59988 Mtetra
.687 .784 .924 r
.51049 .59988 .5158 .60453 .52549 .60118 .52022 .59621 Mtetra
.678 .77 .92 r
.52022 .59621 .52549 .60118 .53523 .59816 .52997 .59277 Mtetra
.657 .749 .917 r
.52997 .59277 .53523 .59816 .54499 .59566 .53976 .58986 Mtetra
.624 .723 .917 r
.53976 .58986 .54499 .59566 .5548 .59383 .54959 .58774 Mtetra
.582 .698 .921 r
.54959 .58774 .5548 .59383 .56466 .59272 .55947 .58657 Mtetra
.546 .681 .927 r
.55947 .58657 .56466 .59272 .57458 .59208 .5694 .5861 Mtetra
.516 .675 .936 r
.5694 .5861 .57458 .59208 .58454 .5917 .57939 .5861 Mtetra
.507 .687 .948 r
.57939 .5861 .58454 .5917 .59456 .59121 .58943 .58608 Mtetra
.518 .712 .96 r
.58943 .58608 .59456 .59121 .60461 .59034 .59952 .58568 Mtetra
.55 .746 .968 r
.59952 .58568 .60461 .59034 .6147 .58888 .60964 .58458 Mtetra
.595 .78 .969 r
.60964 .58458 .6147 .58888 .62481 .5867 .61979 .58259 Mtetra
.644 .806 .961 r
.61979 .58259 .62481 .5867 .63494 .58375 .62994 .57962 Mtetra
.689 .818 .944 r
.62994 .57962 .63494 .58375 .64508 .58003 .64011 .57567 Mtetra
.724 .817 .923 r
.64011 .57567 .64508 .58003 .65522 .57558 .65027 .57082 Mtetra
.745 .806 .901 r
.65027 .57082 .65522 .57558 .66537 .57053 .66043 .56526 Mtetra
.752 .789 .883 r
.66043 .56526 .66537 .57053 .67553 .56509 .67059 .55931 Mtetra
.749 .772 .872 r
.67059 .55931 .67553 .56509 .6857 .55952 .68077 .55332 Mtetra
.733 .755 .87 r
.68077 .55332 .6857 .55952 .69591 .55422 .691 .5478 Mtetra
.712 .742 .875 r
.691 .5478 .69591 .55422 .70616 .54938 .70128 .54298 Mtetra
.684 .734 .889 r
.70128 .54298 .70616 .54938 .71649 .54527 .71165 .53912 Mtetra
.656 .733 .907 r
.71165 .53912 .71649 .54527 .72689 .54182 .72209 .53606 Mtetra
.633 .74 .925 r
.72209 .53606 .72689 .54182 .73736 .53892 .73261 .53353 Mtetra
.619 .75 .94 r
.73261 .53353 .73736 .53892 .74789 .53634 .74319 .53125 Mtetra
.622 .764 .947 r
.74319 .53125 .74789 .53634 .75846 .53379 .7538 .52881 Mtetra
.632 .773 .948 r
.7538 .52881 .75846 .53379 .76907 .53115 .76444 .52611 Mtetra
.648 .778 .942 r
.76444 .52611 .76907 .53115 .77971 .52828 .7751 .52306 Mtetra
.661 .776 .934 r
.7751 .52306 .77971 .52828 .79037 .52518 .78577 .51972 Mtetra
.668 .77 .926 r
.78577 .51972 .79037 .52518 .80106 .52191 .79647 .51621 Mtetra
.672 .762 .919 r
.79647 .51621 .80106 .52191 .81177 .51851 .8072 .5126 Mtetra
.671 .755 .914 r
.8072 .5126 .81177 .51851 .82252 .51506 .81797 .50901 Mtetra
.669 .75 .911 r
.81797 .50901 .82252 .51506 .83331 .51161 .82878 .50547 Mtetra
.665 .746 .911 r
.82878 .50547 .83331 .51161 .84415 .50819 .83964 .50201 Mtetra
.662 .744 .911 r
.83964 .50201 .84415 .50819 .85502 .50481 .85055 .49863 Mtetra
.659 .744 .912 r
.85055 .49863 .85502 .50481 .86595 .50149 .8615 .49531 Mtetra
.657 .744 .914 r
.8615 .49531 .86595 .50149 .87692 .49819 .87251 .49204 Mtetra
.656 .745 .916 r
.87251 .49204 .87692 .49819 .88793 .49493 .88355 .48879 Mtetra
.655 .746 .917 r
.88355 .48879 .88793 .49493 .89899 .49168 .89465 .48556 Mtetra
.654 .747 .918 r
.89465 .48556 .89899 .49168 .91009 .48844 .90578 .48232 Mtetra
.654 .748 .919 r
.90578 .48232 .91009 .48844 .92124 .48519 .91696 .47908 Mtetra
.654 .749 .92 r
.91696 .47908 .92124 .48519 .93243 .48194 .92818 .47583 Mtetra
.654 .75 .92 r
.92818 .47583 .93243 .48194 .94366 .47868 .93945 .47256 Mtetra
.658 .752 .919 r
.33552 .6441 .34122 .64908 .35036 .64633 .34467 .64133 Mtetra
.34467 .64133 .35036 .64633 .35952 .64358 .35385 .63855 Mtetra
.659 .752 .919 r
.35385 .63855 .35952 .64358 .36871 .64081 .36307 .63576 Mtetra
.659 .751 .918 r
.36307 .63576 .36871 .64081 .37794 .63804 .37231 .63295 Mtetra
.37231 .63295 .37794 .63804 .3872 .63527 .38159 .63013 Mtetra
.658 .749 .917 r
.38159 .63013 .3872 .63527 .39648 .63252 .3909 .62731 Mtetra
.658 .747 .916 r
.3909 .62731 .39648 .63252 .4058 .62979 .40024 .62451 Mtetra
.656 .744 .915 r
.40024 .62451 .4058 .62979 .41515 .62711 .40961 .62175 Mtetra
.652 .741 .915 r
.40961 .62175 .41515 .62711 .42453 .6245 .41901 .61905 Mtetra
.648 .738 .915 r
.41901 .61905 .42453 .6245 .43395 .62195 .42845 .61646 Mtetra
.642 .735 .916 r
.42845 .61646 .43395 .62195 .44339 .6195 .43791 .61399 Mtetra
.637 .733 .918 r
.43791 .61399 .44339 .6195 .45287 .61709 .44741 .61164 Mtetra
.631 .734 .922 r
.44741 .61164 .45287 .61709 .46238 .6147 .45694 .60939 Mtetra
.631 .74 .927 r
.45694 .60939 .46238 .6147 .47193 .61223 .4665 .60713 Mtetra
.634 .75 .932 r
.4665 .60713 .47193 .61223 .48152 .60959 .47611 .60475 Mtetra
.646 .765 .936 r
.47611 .60475 .48152 .60959 .49114 .60667 .48575 .60207 Mtetra
.664 .781 .936 r
.48575 .60207 .49114 .60667 .5008 .6034 .49543 .59896 Mtetra
.682 .792 .933 r
.49543 .59896 .5008 .6034 .51049 .59988 .50515 .5954 Mtetra
.697 .795 .925 r
.50515 .5954 .51049 .59988 .52022 .59621 .5149 .59145 Mtetra
.695 .783 .919 r
.5149 .59145 .52022 .59621 .52997 .59277 .52468 .58755 Mtetra
.679 .762 .914 r
.52468 .58755 .52997 .59277 .53976 .58986 .53449 .58406 Mtetra
.644 .731 .912 r
.53449 .58406 .53976 .58986 .54959 .58774 .54434 .58147 Mtetra
.595 .697 .914 r
.54434 .58147 .54959 .58774 .55947 .58657 .55423 .58004 Mtetra
.55 .67 .917 r
.55423 .58004 .55947 .58657 .5694 .5861 .56418 .57959 Mtetra
.507 .652 .924 r
.56418 .57959 .5694 .5861 .57939 .5861 .57419 .57991 Mtetra
.492 .658 .934 r
.57419 .57991 .57939 .5861 .58943 .58608 .58426 .58035 Mtetra
.501 .68 .946 r
.58426 .58035 .58943 .58608 .59952 .58568 .59438 .58045 Mtetra
.537 .718 .956 r
.59438 .58045 .59952 .58568 .60964 .58458 .60453 .57975 Mtetra
.591 .757 .957 r
.60453 .57975 .60964 .58458 .61979 .58259 .61471 .57797 Mtetra
.649 .787 .948 r
.61471 .57797 .61979 .58259 .62994 .57962 .6249 .57499 Mtetra
.7 .801 .928 r
.6249 .57499 .62994 .57962 .64011 .57567 .63508 .57079 Mtetra
.736 .8 .903 r
.63508 .57079 .64011 .57567 .65027 .57082 .64526 .56549 Mtetra
.755 .788 .88 r
.64526 .56549 .65027 .57082 .66043 .56526 .65542 .55939 Mtetra
.759 .771 .863 r
.65542 .55939 .66043 .56526 .67059 .55931 .6656 .55293 Mtetra
.751 .754 .855 r
.6656 .55293 .67059 .55931 .68077 .55332 .67579 .54658 Mtetra
.73 .738 .858 r
.67579 .54658 .68077 .55332 .691 .5478 .68604 .541 Mtetra
.703 .729 .87 r
.68604 .541 .691 .5478 .70128 .54298 .69636 .5364 Mtetra
.668 .724 .891 r
.69636 .5364 .70128 .54298 .71165 .53912 .70678 .53297 Mtetra
.634 .727 .915 r
.70678 .53297 .71165 .53912 .72209 .53606 .71728 .53046 Mtetra
.612 .739 .936 r
.71728 .53046 .72209 .53606 .73261 .53353 .72786 .52836 Mtetra
.603 .754 .95 r
.72786 .52836 .73261 .53353 .74319 .53125 .73848 .52633 Mtetra
.619 .772 .954 r
.73848 .52633 .74319 .53125 .7538 .52881 .74912 .52389 Mtetra
.639 .78 .949 r
.74912 .52389 .7538 .52881 .76444 .52611 .75978 .521 Mtetra
.66 .78 .938 r
.75978 .521 .76444 .52611 .7751 .52306 .77044 .51766 Mtetra
.673 .774 .926 r
.77044 .51766 .7751 .52306 .78577 .51972 .78112 .514 Mtetra
.677 .764 .916 r
.78112 .514 .78577 .51972 .79647 .51621 .79183 .51023 Mtetra
.678 .756 .91 r
.79183 .51023 .79647 .51621 .8072 .5126 .80258 .50644 Mtetra
.673 .748 .907 r
.80258 .50644 .8072 .5126 .81797 .50901 .81337 .50275 Mtetra
.669 .744 .907 r
.81337 .50275 .81797 .50901 .82878 .50547 .82421 .49918 Mtetra
.664 .742 .908 r
.82421 .49918 .82878 .50547 .83964 .50201 .8351 .49573 Mtetra
.66 .742 .91 r
.8351 .49573 .83964 .50201 .85055 .49863 .84604 .49239 Mtetra
.657 .743 .913 r
.84604 .49239 .85055 .49863 .8615 .49531 .85703 .48912 Mtetra
.655 .744 .915 r
.85703 .48912 .8615 .49531 .87251 .49204 .86807 .48588 Mtetra
.654 .746 .917 r
.86807 .48588 .87251 .49204 .88355 .48879 .87915 .48266 Mtetra
.653 .747 .919 r
.87915 .48266 .88355 .48879 .89465 .48556 .89028 .47944 Mtetra
.653 .749 .92 r
.89028 .47944 .89465 .48556 .90578 .48232 .90145 .4762 Mtetra
.653 .75 .92 r
.90145 .4762 .90578 .48232 .91696 .47908 .91266 .47295 Mtetra
.653 .75 .921 r
.91266 .47295 .91696 .47908 .92818 .47583 .92392 .46968 Mtetra
.654 .75 .921 r
.92392 .46968 .92818 .47583 .93945 .47256 .93521 .46639 Mtetra
.657 .752 .92 r
.32977 .63908 .33552 .6441 .34467 .64133 .33894 .63632 Mtetra
.658 .752 .92 r
.33894 .63632 .34467 .64133 .35385 .63855 .34815 .63353 Mtetra
.658 .753 .92 r
.34815 .63353 .35385 .63855 .36307 .63576 .35738 .63073 Mtetra
.659 .753 .92 r
.35738 .63073 .36307 .63576 .37231 .63295 .36665 .6279 Mtetra
.66 .753 .919 r
.36665 .6279 .37231 .63295 .38159 .63013 .37595 .62504 Mtetra
.37595 .62504 .38159 .63013 .3909 .62731 .38528 .62216 Mtetra
.66 .751 .917 r
.38528 .62216 .3909 .62731 .40024 .62451 .39464 .61927 Mtetra
.659 .748 .916 r
.39464 .61927 .40024 .62451 .40961 .62175 .40404 .61639 Mtetra
.657 .744 .914 r
.40404 .61639 .40961 .62175 .41901 .61905 .41346 .61357 Mtetra
.653 .739 .913 r
.41346 .61357 .41901 .61905 .42845 .61646 .42292 .61084 Mtetra
.646 .733 .912 r
.42292 .61084 .42845 .61646 .43791 .61399 .4324 .60828 Mtetra
.638 .727 .913 r
.4324 .60828 .43791 .61399 .44741 .61164 .44192 .60589 Mtetra
.628 .724 .916 r
.44192 .60589 .44741 .61164 .45694 .60939 .45146 .60372 Mtetra
.623 .726 .92 r
.45146 .60372 .45694 .60939 .4665 .60713 .46104 .60166 Mtetra
.62 .733 .927 r
.46104 .60166 .4665 .60713 .47611 .60475 .47066 .59962 Mtetra
.629 .75 .934 r
.47066 .59962 .47611 .60475 .48575 .60207 .48033 .59732 Mtetra
.648 .771 .938 r
.48033 .59732 .48575 .60207 .49543 .59896 .49003 .59454 Mtetra
.675 .793 .937 r
.49003 .59454 .49543 .59896 .50515 .5954 .49977 .59112 Mtetra
.704 .805 .928 r
.49977 .59112 .50515 .5954 .5149 .59145 .50955 .58697 Mtetra
.712 .8 .919 r
.50955 .58697 .5149 .59145 .52468 .58755 .51936 .58259 Mtetra
.705 .78 .91 r
.51936 .58259 .52468 .58755 .53449 .58406 .52919 .57836 Mtetra
.671 .745 .906 r
.52919 .57836 .53449 .58406 .54434 .58147 .53906 .57506 Mtetra
.618 .703 .905 r
.53906 .57506 .54434 .58147 .55423 .58004 .54897 .57311 Mtetra
.563 .663 .905 r
.54897 .57311 .55423 .58004 .56418 .57959 .55893 .57246 Mtetra
.508 .632 .908 r
.55893 .57246 .56418 .57959 .57419 .57991 .56896 .57296 Mtetra
.484 .628 .915 r
.56896 .57296 .57419 .57991 .58426 .58035 .57905 .57381 Mtetra
.488 .645 .927 r
.57905 .57381 .58426 .58035 .59438 .58045 .58919 .57443 Mtetra
.527 .683 .937 r
.58919 .57443 .59438 .58045 .60453 .57975 .59938 .57417 Mtetra
.588 .726 .939 r
.59938 .57417 .60453 .57975 .61471 .57797 .60958 .57264 Mtetra
.654 .76 .928 r
.60958 .57264 .61471 .57797 .6249 .57499 .61979 .56963 Mtetra
.708 .776 .905 r
.61979 .56963 .6249 .57499 .63508 .57079 .63 .56514 Mtetra
.744 .775 .879 r
.63 .56514 .63508 .57079 .64526 .56549 .64018 .55937 Mtetra
.761 .764 .856 r
.64018 .55937 .64526 .56549 .65542 .55939 .65036 .5527 Mtetra
.76 .748 .842 r
.65036 .5527 .65542 .55939 .6656 .55293 .66054 .54579 Mtetra
.748 .733 .838 r
.66054 .54579 .6656 .55293 .67579 .54658 .67075 .53922 Mtetra
.721 .719 .848 r
.67075 .53922 .67579 .54658 .68604 .541 .68104 .53378 Mtetra
.687 .712 .868 r
.68104 .53378 .68604 .541 .69636 .5364 .69141 .52967 Mtetra
.644 .711 .897 r
.69141 .52967 .69636 .5364 .70678 .53297 .70188 .52693 Mtetra
.602 .719 .927 r
.70188 .52693 .70678 .53297 .71728 .53046 .71245 .52513 Mtetra
.585 .741 .95 r
.71245 .52513 .71728 .53046 .72786 .52836 .72308 .52348 Mtetra
.589 .763 .962 r
.72308 .52348 .72786 .52836 .73848 .52633 .73374 .5216 Mtetra
.624 .783 .958 r
.73374 .5216 .73848 .52633 .74912 .52389 .74441 .51899 Mtetra
.655 .788 .945 r
.74441 .51899 .74912 .52389 .75978 .521 .75507 .51571 Mtetra
.677 .781 .928 r
.75507 .51571 .75978 .521 .77044 .51766 .76573 .51195 Mtetra
.687 .768 .914 r
.76573 .51195 .77044 .51766 .78112 .514 .77642 .5079 Mtetra
.685 .755 .904 r
.77642 .5079 .78112 .514 .79183 .51023 .78714 .50388 Mtetra
.681 .745 .9 r
.78714 .50388 .79183 .51023 .80258 .50644 .7979 .49997 Mtetra
.673 .739 .9 r
.7979 .49997 .80258 .50644 .81337 .50275 .80872 .49627 Mtetra
.666 .737 .903 r
.80872 .49627 .81337 .50275 .82421 .49918 .81959 .49276 Mtetra
.66 .737 .907 r
.81959 .49276 .82421 .49918 .8351 .49573 .83052 .4894 Mtetra
.656 .739 .911 r
.83052 .4894 .8351 .49573 .84604 .49239 .84151 .48616 Mtetra
.653 .743 .915 r
.84151 .48616 .84604 .49239 .85703 .48912 .85254 .48296 Mtetra
.652 .746 .918 r
.85254 .48296 .85703 .48912 .86807 .48588 .86361 .47977 Mtetra
.652 .748 .92 r
.86361 .47977 .86807 .48588 .87915 .48266 .87473 .47657 Mtetra
.652 .75 .922 r
.87473 .47657 .87915 .48266 .89028 .47944 .88589 .47335 Mtetra
.653 .751 .922 r
.88589 .47335 .89028 .47944 .90145 .4762 .89709 .4701 Mtetra
.653 .752 .922 r
.89709 .4701 .90145 .4762 .91266 .47295 .90833 .46682 Mtetra
.654 .752 .922 r
.90833 .46682 .91266 .47295 .92392 .46968 .91962 .46351 Mtetra
.654 .751 .921 r
.91962 .46351 .92392 .46968 .93521 .46639 .93095 .46018 Mtetra
.656 .751 .92 r
.32399 .63404 .32977 .63908 .33894 .63632 .33318 .63129 Mtetra
.656 .753 .921 r
.33318 .63129 .33894 .63632 .34815 .63353 .3424 .62852 Mtetra
.657 .754 .922 r
.3424 .62852 .34815 .63353 .35738 .63073 .35165 .62572 Mtetra
.658 .755 .922 r
.35165 .62572 .35738 .63073 .36665 .6279 .36094 .62289 Mtetra
.659 .757 .922 r
.36094 .62289 .36665 .6279 .37595 .62504 .37026 .62002 Mtetra
.661 .757 .921 r
.37026 .62002 .37595 .62504 .38528 .62216 .37961 .6171 Mtetra
.663 .757 .92 r
.37961 .6171 .38528 .62216 .39464 .61927 .389 .61413 Mtetra
.663 .755 .918 r
.389 .61413 .39464 .61927 .40404 .61639 .39842 .61115 Mtetra
.663 .751 .916 r
.39842 .61115 .40404 .61639 .41346 .61357 .40787 .60817 Mtetra
.659 .745 .913 r
.40787 .60817 .41346 .61357 .42292 .61084 .41735 .60526 Mtetra
.653 .737 .911 r
.41735 .60526 .42292 .61084 .4324 .60828 .42686 .6025 Mtetra
.644 .728 .91 r
.42686 .6025 .4324 .60828 .44192 .60589 .4364 .59996 Mtetra
.631 .719 .911 r
.4364 .59996 .44192 .60589 .45146 .60372 .44596 .59774 Mtetra
.619 .714 .914 r
.44596 .59774 .45146 .60372 .46104 .60166 .45556 .59577 Mtetra
.608 .714 .92 r
.45556 .59577 .46104 .60166 .47066 .59962 .46519 .59404 Mtetra
.61 .727 .928 r
.46519 .59404 .47066 .59962 .48033 .59732 .47487 .59217 Mtetra
.625 .75 .936 r
.47487 .59217 .48033 .59732 .49003 .59454 .48459 .58993 Mtetra
.658 .782 .94 r
.48459 .58993 .49003 .59454 .49977 .59112 .49435 .58688 Mtetra
.701 .808 .932 r
.49435 .58688 .49977 .59112 .50955 .58697 .50416 .58279 Mtetra
.725 .815 .921 r
.50416 .58279 .50955 .58697 .51936 .58259 .514 .57805 Mtetra
.733 .803 .907 r
.514 .57805 .51936 .58259 .52919 .57836 .52386 .573 Mtetra
.704 .767 .901 r
.52386 .573 .52919 .57836 .53906 .57506 .53375 .56875 Mtetra
.651 .719 .898 r
.53375 .56875 .53906 .57506 .54897 .57311 .54367 .56593 Mtetra
.588 .668 .894 r
.54367 .56593 .54897 .57311 .55893 .57246 .55364 .56475 Mtetra
.521 .621 .892 r
.55364 .56475 .55893 .57246 .56896 .57296 .56368 .56515 Mtetra
.488 .603 .893 r
.56368 .56515 .56896 .57296 .57905 .57381 .57379 .56622 Mtetra
.485 .609 .9 r
.57379 .56622 .57905 .57381 .58919 .57443 .58395 .56726 Mtetra
.525 .642 .908 r
.58395 .56726 .58919 .57443 .59938 .57417 .59416 .56741 Mtetra
.588 .685 .908 r
.59416 .56741 .59938 .57417 .60958 .57264 .60439 .56611 Mtetra
.656 .719 .895 r
.60439 .56611 .60958 .57264 .61979 .56963 .61462 .56308 Mtetra
.71 .737 .873 r
.61462 .56308 .61979 .56963 .63 .56514 .62484 .55831 Mtetra
.744 .739 .848 r
.62484 .55831 .63 .56514 .64018 .55937 .63504 .55209 Mtetra
.758 .732 .828 r
.63504 .55209 .64018 .55937 .65036 .5527 .64523 .54495 Mtetra
.754 .72 .82 r
.64523 .54495 .65036 .5527 .66054 .54579 .65543 .53778 Mtetra
.739 .709 .824 r
.65543 .53778 .66054 .54579 .67075 .53922 .66566 .53125 Mtetra
.704 .699 .842 r
.66566 .53125 .67075 .53922 .68104 .53378 .67599 .52633 Mtetra
.661 .696 .872 r
.67599 .52633 .68104 .53378 .69141 .52967 .68643 .52305 Mtetra
.607 .701 .911 r
.68643 .52305 .69141 .52967 .70188 .52693 .69697 .52122 Mtetra
.557 .715 .946 r
.69697 .52122 .70188 .52693 .71245 .52513 .70761 .52021 Mtetra
.557 .748 .966 r
.70761 .52021 .71245 .52513 .72308 .52348 .71829 .51889 Mtetra
.587 .776 .97 r
.71829 .51889 .72308 .52348 .73374 .5216 .72898 .51692 Mtetra
.642 .794 .955 r
.72898 .51692 .73374 .5216 .74441 .51899 .73965 .51388 Mtetra
.68 .789 .932 r
.73965 .51388 .74441 .51899 .75507 .51571 .7503 .51002 Mtetra
.694 .772 .912 r
.7503 .51002 .75507 .51571 .76573 .51195 .76096 .50576 Mtetra
.697 .756 .898 r
.76096 .50576 .76573 .51195 .77642 .5079 .77165 .50137 Mtetra
.688 .742 .892 r
.77165 .50137 .77642 .5079 .78714 .50388 .78239 .4972 Mtetra
.679 .735 .893 r
.78239 .4972 .78714 .50388 .7979 .49997 .79318 .4933 Mtetra
.668 .732 .898 r
.79318 .4933 .7979 .49997 .80872 .49627 .80404 .48971 Mtetra
.66 .733 .904 r
.80404 .48971 .80872 .49627 .81959 .49276 .81496 .48636 Mtetra
.654 .737 .911 r
.81496 .48636 .81959 .49276 .83052 .4894 .82593 .48316 Mtetra
.65 .742 .916 r
.82593 .48316 .83052 .4894 .84151 .48616 .83696 .48003 Mtetra
.649 .747 .921 r
.83696 .48003 .84151 .48616 .85254 .48296 .84803 .4769 Mtetra
.649 .75 .923 r
.84803 .4769 .85254 .48296 .86361 .47977 .85914 .47376 Mtetra
.651 .753 .924 r
.85914 .47376 .86361 .47977 .87473 .47657 .87029 .47056 Mtetra
.652 .754 .925 r
.87029 .47056 .87473 .47657 .88589 .47335 .88148 .46731 Mtetra
.653 .755 .924 r
.88148 .46731 .88589 .47335 .89709 .4701 .89271 .46401 Mtetra
.654 .754 .923 r
.89271 .46401 .89709 .4701 .90833 .46682 .90398 .46068 Mtetra
.655 .754 .922 r
.90398 .46068 .90833 .46682 .91962 .46351 .91529 .45731 Mtetra
.655 .753 .921 r
.91529 .45731 .91962 .46351 .93095 .46018 .92665 .45393 Mtetra
.654 .751 .921 r
.31818 .62896 .32399 .63404 .33318 .63129 .32738 .62624 Mtetra
.654 .753 .922 r
.32738 .62624 .33318 .63129 .3424 .62852 .33662 .62351 Mtetra
.655 .755 .924 r
.33662 .62351 .3424 .62852 .35165 .62572 .34589 .62075 Mtetra
.656 .757 .925 r
.34589 .62075 .35165 .62572 .36094 .62289 .35519 .61795 Mtetra
.657 .76 .925 r
.35519 .61795 .36094 .62289 .37026 .62002 .36453 .6151 Mtetra
.66 .762 .925 r
.36453 .6151 .37026 .62002 .37961 .6171 .3739 .61218 Mtetra
.663 .763 .925 r
.3739 .61218 .37961 .6171 .389 .61413 .38331 .60918 Mtetra
.665 .763 .923 r
.38331 .60918 .389 .61413 .39842 .61115 .39276 .6061 Mtetra
.668 .761 .92 r
.39276 .6061 .39842 .61115 .40787 .60817 .40223 .60296 Mtetra
.667 .755 .916 r
.40223 .60296 .40787 .60817 .41735 .60526 .41174 .59982 Mtetra
.664 .747 .912 r
.41174 .59982 .41735 .60526 .42686 .6025 .42128 .59676 Mtetra
.655 .734 .908 r
.42128 .59676 .42686 .6025 .4364 .59996 .43085 .59392 Mtetra
.641 .72 .905 r
.43085 .59392 .4364 .59996 .44596 .59774 .44044 .59145 Mtetra
.623 .706 .905 r
.44044 .59145 .44596 .59774 .45556 .59577 .45005 .5894 Mtetra
.601 .696 .91 r
.45005 .5894 .45556 .59577 .46519 .59404 .4597 .58785 Mtetra
.592 .7 .918 r
.4597 .58785 .46519 .59404 .47487 .59217 .46938 .58645 Mtetra
.593 .718 .931 r
.46938 .58645 .47487 .59217 .48459 .58993 .47911 .58493 Mtetra
.628 .759 .941 r
.47911 .58493 .48459 .58993 .49435 .58688 .4889 .58257 Mtetra
.683 .802 .939 r
.4889 .58257 .49435 .58688 .50416 .58279 .49873 .5789 Mtetra
.729 .829 .927 r
.49873 .5789 .50416 .58279 .514 .57805 .50859 .57402 Mtetra
.76 .828 .905 r
.50859 .57402 .514 .57805 .52386 .573 .51849 .56817 Mtetra
.742 .795 .895 r
.51849 .56817 .52386 .573 .53375 .56875 .5284 .56275 Mtetra
.696 .745 .889 r
.5284 .56275 .53375 .56875 .54367 .56593 .53834 .55865 Mtetra
.627 .682 .882 r
.53834 .55865 .54367 .56593 .55364 .56475 .54832 .55647 Mtetra
.549 .62 .875 r
.54832 .55647 .55364 .56475 .56368 .56515 .55837 .55637 Mtetra
.506 .586 .869 r
.55837 .55637 .56368 .56515 .57379 .56622 .56848 .55734 Mtetra
.493 .577 .868 r
.56848 .55734 .57379 .56622 .58395 .56726 .57866 .55864 Mtetra
.528 .602 .871 r
.57866 .55864 .58395 .56726 .59416 .56741 .58888 .55909 Mtetra
.588 .639 .869 r
.58888 .55909 .59416 .56741 .60439 .56611 .59913 .55799 Mtetra
.653 .673 .857 r
.59913 .55799 .60439 .56611 .61462 .56308 .60938 .55494 Mtetra
.705 .693 .836 r
.60938 .55494 .61462 .56308 .62484 .55831 .61962 .54992 Mtetra
.736 .699 .816 r
.61962 .54992 .62484 .55831 .63504 .55209 .62983 .54335 Mtetra
.748 .696 .802 r
.62983 .54335 .63504 .55209 .64523 .54495 .64003 .53591 Mtetra
.74 .688 .801 r
.64003 .53591 .64523 .54495 .65543 .53778 .65025 .52878 Mtetra
.72 .682 .812 r
.65025 .52878 .65543 .53778 .66566 .53125 .66053 .52272 Mtetra
.676 .675 .842 r
.66053 .52272 .66566 .53125 .67599 .52633 .67092 .51876 Mtetra
.618 .677 .884 r
.67092 .51876 .67599 .52633 .68643 .52305 .68143 .51673 Mtetra
.549 .689 .931 r
.68143 .51673 .68643 .52305 .69697 .52122 .69206 .51605 Mtetra
.496 .711 .967 r
.69206 .51605 .69697 .52122 .70761 .52021 .70277 .51582 Mtetra
.535 .764 .982 r
.70277 .51582 .70761 .52021 .71829 .51889 .71348 .5146 Mtetra
.605 .798 .973 r
.71348 .5146 .71829 .51889 .72898 .51692 .72418 .51216 Mtetra
.674 .803 .944 r
.72418 .51216 .72898 .51692 .73965 .51388 .73483 .50838 Mtetra
.707 .784 .912 r
.73483 .50838 .73965 .51388 .7503 .51002 .74546 .50373 Mtetra
.708 .757 .891 r
.74546 .50373 .7503 .51002 .76096 .50576 .75612 .49896 Mtetra
.701 .739 .881 r
.75612 .49896 .76096 .50576 .77165 .50137 .76682 .49433 Mtetra
.684 .726 .882 r
.76682 .49433 .77165 .50137 .78239 .4972 .77758 .4902 Mtetra
.671 .723 .888 r
.77758 .4902 .78239 .4972 .79318 .4933 .78842 .48651 Mtetra
.658 .725 .899 r
.78842 .48651 .79318 .4933 .80404 .48971 .79933 .48319 Mtetra
.649 .731 .909 r
.79933 .48319 .80404 .48971 .81496 .48636 .81031 .48011 Mtetra
.645 .74 .918 r
.81031 .48011 .81496 .48636 .82593 .48316 .82133 .4771 Mtetra
.644 .748 .925 r
.82133 .4771 .82593 .48316 .83696 .48003 .8324 .4741 Mtetra
.646 .754 .928 r
.8324 .4741 .83696 .48003 .84803 .4769 .8435 .47103 Mtetra
.648 .758 .929 r
.8435 .47103 .84803 .4769 .85914 .47376 .85465 .46787 Mtetra
.651 .76 .929 r
.85465 .46787 .85914 .47376 .87029 .47056 .86583 .46463 Mtetra
.653 .76 .928 r
.86583 .46463 .87029 .47056 .88148 .46731 .87705 .46132 Mtetra
.655 .759 .926 r
.87705 .46132 .88148 .46731 .89271 .46401 .8883 .45795 Mtetra
.656 .758 .924 r
.8883 .45795 .89271 .46401 .90398 .46068 .8996 .45453 Mtetra
.657 .756 .923 r
.8996 .45453 .90398 .46068 .91529 .45731 .91094 .45109 Mtetra
.657 .754 .921 r
.91094 .45109 .91529 .45731 .92665 .45393 .92232 .44763 Mtetra
.652 .75 .922 r
.31232 .62385 .31818 .62896 .32738 .62624 .32154 .62116 Mtetra
.651 .752 .923 r
.32154 .62116 .32738 .62624 .33662 .62351 .3308 .61847 Mtetra
.652 .754 .925 r
.3308 .61847 .33662 .62351 .34589 .62075 .34008 .61575 Mtetra
.653 .757 .926 r
.34008 .61575 .34589 .62075 .35519 .61795 .34941 .613 Mtetra
.654 .76 .927 r
.34941 .613 .35519 .61795 .36453 .6151 .35876 .6102 Mtetra
.657 .763 .928 r
.35876 .6102 .36453 .6151 .3739 .61218 .36815 .60733 Mtetra
.66 .767 .929 r
.36815 .60733 .3739 .61218 .38331 .60918 .37758 .60436 Mtetra
.665 .77 .928 r
.37758 .60436 .38331 .60918 .39276 .6061 .38705 .60127 Mtetra
.671 .771 .925 r
.38705 .60127 .39276 .6061 .40223 .60296 .39655 .59802 Mtetra
.674 .769 .922 r
.39655 .59802 .40223 .60296 .41174 .59982 .40609 .59469 Mtetra
.676 .763 .916 r
.40609 .59469 .41174 .59982 .42128 .59676 .41566 .59131 Mtetra
.67 .75 .91 r
.41566 .59131 .42128 .59676 .43085 .59392 .42525 .58807 Mtetra
.658 .733 .905 r
.42525 .58807 .43085 .59392 .44044 .59145 .43488 .58514 Mtetra
.636 .711 .901 r
.43488 .58514 .44044 .59145 .45005 .5894 .44452 .58276 Mtetra
.606 .69 .902 r
.44452 .58276 .45005 .5894 .4597 .58785 .45418 .5811 Mtetra
.583 .678 .906 r
.45418 .5811 .4597 .58785 .46938 .58645 .46388 .57997 Mtetra
.562 .68 .918 r
.46388 .57997 .46938 .58645 .47911 .58493 .47361 .5792 Mtetra
.587 .717 .933 r
.47361 .5792 .47911 .58493 .4889 .58257 .4834 .57776 Mtetra
.644 .773 .942 r
.4834 .57776 .4889 .58257 .49873 .5789 .49325 .57499 Mtetra
.715 .828 .935 r
.49325 .57499 .49873 .5789 .50859 .57402 .50315 .57046 Mtetra
.776 .848 .906 r
.50315 .57046 .50859 .57402 .51849 .56817 .51308 .56409 Mtetra
.778 .829 .892 r
.51308 .56409 .51849 .56817 .5284 .56275 .52302 .55752 Mtetra
.747 .784 .883 r
.52302 .55752 .5284 .56275 .53834 .55865 .53298 .55178 Mtetra
.679 .714 .875 r
.53298 .55178 .53834 .55865 .54832 .55647 .54298 .54808 Mtetra
.592 .638 .865 r
.54298 .54808 .54832 .55647 .55837 .55637 .55302 .54687 Mtetra
.539 .586 .85 r
.55302 .54687 .55837 .55637 .56848 .55734 .56313 .54722 Mtetra
.512 .559 .84 r
.56313 .54722 .56848 .55734 .57866 .55864 .57331 .54838 Mtetra
.538 .57 .835 r
.57331 .54838 .57866 .55864 .58888 .55909 .58355 .54888 Mtetra
.589 .597 .829 r
.58355 .54888 .58888 .55909 .59913 .55799 .59381 .54788 Mtetra
.647 .627 .817 r
.59381 .54788 .59913 .55799 .60938 .55494 .60407 .5448 Mtetra
.693 .648 .8 r
.60407 .5448 .60938 .55494 .61962 .54992 .61431 .53964 Mtetra
.721 .658 .787 r
.61431 .53964 .61962 .54992 .62983 .54335 .62454 .53297 Mtetra
.731 .661 .78 r
.62454 .53297 .62983 .54335 .64003 .53591 .63476 .52562 Mtetra
.718 .657 .788 r
.63476 .52562 .64003 .53591 .65025 .52878 .64502 .51906 Mtetra
.693 .657 .81 r
.64502 .51906 .65025 .52878 .66053 .52272 .65536 .51407 Mtetra
.632 .655 .854 r
.65536 .51407 .66053 .52272 .67092 .51876 .66583 .5116 Mtetra
.547 .659 .91 r
.66583 .5116 .67092 .51876 .68143 .51673 .67644 .51119 Mtetra
.462 .68 .959 r
.67644 .51119 .68143 .51673 .69206 .51605 .68715 .51164 Mtetra
.427 .713 .984 r
.68715 .51164 .69206 .51605 .70277 .51582 .69791 .51189 Mtetra
.543 .791 .99 r
.69791 .51189 .70277 .51582 .71348 .5146 .70864 .51028 Mtetra
.653 .815 .961 r
.70864 .51028 .71348 .5146 .72418 .51216 .71931 .50688 Mtetra
.711 .794 .916 r
.71931 .50688 .72418 .51216 .73483 .50838 .72993 .50211 Mtetra
.727 .764 .882 r
.72993 .50211 .73483 .50838 .74546 .50373 .74054 .49666 Mtetra
.712 .735 .869 r
.74054 .49666 .74546 .50373 .75612 .49896 .75121 .49157 Mtetra
.695 .72 .869 r
.75121 .49157 .75612 .49896 .76682 .49433 .76193 .487 Mtetra
.673 .714 .879 r
.76193 .487 .76682 .49433 .77758 .4902 .77275 .48318 Mtetra
.656 .718 .894 r
.77275 .48318 .77758 .4902 .78842 .48651 .78365 .47991 Mtetra
.644 .727 .909 r
.78365 .47991 .78842 .48651 .79933 .48319 .79462 .47697 Mtetra
.636 .738 .922 r
.79462 .47697 .79933 .48319 .81031 .48011 .80565 .47418 Mtetra
.636 .75 .93 r
.80565 .47418 .81031 .48011 .82133 .4771 .81672 .47133 Mtetra
.639 .758 .935 r
.81672 .47133 .82133 .4771 .8324 .4741 .82783 .46839 Mtetra
.644 .763 .935 r
.82783 .46839 .8324 .4741 .8435 .47103 .83897 .46529 Mtetra
.649 .765 .934 r
.83897 .46529 .8435 .47103 .85465 .46787 .85014 .46206 Mtetra
.653 .765 .931 r
.85014 .46206 .85465 .46787 .86583 .46463 .86134 .45873 Mtetra
.656 .763 .929 r
.86134 .45873 .86583 .46463 .87705 .46132 .87259 .45531 Mtetra
.657 .761 .926 r
.87259 .45531 .87705 .46132 .8883 .45795 .88387 .45185 Mtetra
.659 .759 .924 r
.88387 .45185 .8883 .45795 .8996 .45453 .89519 .44835 Mtetra
.659 .757 .922 r
.89519 .44835 .8996 .45453 .91094 .45109 .90655 .44482 Mtetra
.659 .755 .921 r
.90655 .44482 .91094 .45109 .92232 .44763 .91796 .44128 Mtetra
.65 .75 .922 r
.30643 .61871 .31232 .62385 .32154 .62116 .31567 .61603 Mtetra
.65 .751 .924 r
.31567 .61603 .32154 .62116 .3308 .61847 .32494 .61336 Mtetra
.649 .753 .925 r
.32494 .61336 .3308 .61847 .34008 .61575 .33424 .61069 Mtetra
.649 .755 .927 r
.33424 .61069 .34008 .61575 .34941 .613 .34358 .60799 Mtetra
.649 .758 .929 r
.34358 .60799 .34941 .613 .35876 .6102 .35295 .60528 Mtetra
.651 .762 .931 r
.35295 .60528 .35876 .6102 .36815 .60733 .36236 .60251 Mtetra
.654 .768 .933 r
.36236 .60251 .36815 .60733 .37758 .60436 .3718 .59966 Mtetra
.66 .775 .934 r
.3718 .59966 .37758 .60436 .38705 .60127 .38129 .59665 Mtetra
.669 .781 .933 r
.38129 .59665 .38705 .60127 .39655 .59802 .39081 .59343 Mtetra
.677 .784 .931 r
.39081 .59343 .39655 .59802 .40609 .59469 .40038 .59 Mtetra
.686 .783 .924 r
.40038 .59 .40609 .59469 .41566 .59131 .40998 .58633 Mtetra
.687 .773 .917 r
.40998 .58633 .41566 .59131 .42525 .58807 .41961 .58264 Mtetra
.682 .756 .907 r
.41961 .58264 .42525 .58807 .43488 .58514 .42927 .57906 Mtetra
.661 .728 .899 r
.42927 .57906 .43488 .58514 .44452 .58276 .43895 .57602 Mtetra
.628 .696 .894 r
.43895 .57602 .44452 .58276 .45418 .5811 .44864 .57383 Mtetra
.589 .665 .891 r
.44864 .57383 .45418 .5811 .46388 .57997 .45835 .57262 Mtetra
.542 .643 .9 r
.45835 .57262 .46388 .57997 .47361 .5792 .46809 .57243 Mtetra
.541 .663 .916 r
.46809 .57243 .47361 .5792 .4834 .57776 .47788 .57209 Mtetra
.577 .718 .939 r
.47788 .57209 .4834 .57776 .49325 .57499 .48774 .57079 Mtetra
.674 .808 .947 r
.48774 .57079 .49325 .57499 .50315 .57046 .49765 .56725 Mtetra
.776 .864 .915 r
.49765 .56725 .50315 .57046 .51308 .56409 .50762 .56092 Mtetra
.808 .866 .891 r
.50762 .56092 .51308 .56409 .52302 .55752 .5176 .5534 Mtetra
.802 .83 .873 r
.5176 .5534 .52302 .55752 .53298 .55178 .52759 .54576 Mtetra
.741 .758 .866 r
.52759 .54576 .53298 .55178 .54298 .54808 .5376 .53997 Mtetra
.653 .672 .855 r
.5376 .53997 .54298 .54808 .55302 .54687 .54765 .53693 Mtetra
.587 .601 .833 r
.54765 .53693 .55302 .54687 .56313 .54722 .55776 .53596 Mtetra
.544 .554 .815 r
.55776 .53596 .56313 .54722 .57331 .54838 .56793 .53642 Mtetra
.556 .549 .802 r
.56793 .53642 .57331 .54838 .58355 .54888 .57815 .53658 Mtetra
.592 .564 .792 r
.57815 .53658 .58355 .54888 .59381 .54788 .58842 .53549 Mtetra
.639 .587 .78 r
.58842 .53549 .59381 .54788 .60407 .5448 .59868 .53238 Mtetra
.678 .607 .769 r
.59868 .53238 .60407 .5448 .61431 .53964 .60894 .52727 Mtetra
.7 .618 .762 r
.60894 .52727 .61431 .53964 .62454 .53297 .61918 .52087 Mtetra
.707 .626 .764 r
.61918 .52087 .62454 .53297 .63476 .52562 .62943 .51417 Mtetra
.686 .625 .782 r
.62943 .51417 .63476 .52562 .64502 .51906 .63975 .5089 Mtetra
.648 .629 .818 r
.63975 .5089 .64502 .51906 .65536 .51407 .65018 .50571 Mtetra
.558 .629 .878 r
.65018 .50571 .65536 .51407 .66583 .5116 .66075 .5053 Mtetra
.418 .627 .94 r
.66075 .5053 .66583 .5116 .67644 .51119 .67147 .50677 Mtetra
.328 .661 .973 r
.67147 .50677 .67644 .51119 .68715 .51164 .68225 .50815 Mtetra
.373 .73 .989 r
.68225 .50815 .68715 .51164 .69791 .51189 .69304 .50832 Mtetra
.597 .83 .988 r
.69304 .50832 .69791 .51189 .70864 .51028 .70374 .50566 Mtetra
.718 .822 .93 r
.70374 .50566 .70864 .51028 .71931 .50688 .71436 .50073 Mtetra
.741 .772 .879 r
.71436 .50073 .71931 .50688 .72993 .50211 .72494 .49479 Mtetra
.735 .736 .852 r
.72494 .49479 .72993 .50211 .74054 .49666 .73554 .4887 Mtetra
.705 .709 .851 r
.73554 .4887 .74054 .49666 .75121 .49157 .74623 .48363 Mtetra
.678 .7 .863 r
.74623 .48363 .75121 .49157 .76193 .487 .75702 .47956 Mtetra
.652 .704 .885 r
.75702 .47956 .76193 .487 .77275 .48318 .76791 .47638 Mtetra
.632 .716 .908 r
.76791 .47638 .77275 .48318 .78365 .47991 .77889 .47374 Mtetra
.624 .736 .927 r
.77889 .47374 .78365 .47991 .79462 .47697 .78992 .47123 Mtetra
.622 .752 .94 r
.78992 .47123 .79462 .47697 .80565 .47418 .801 .46868 Mtetra
.629 .766 .945 r
.801 .46868 .80565 .47418 .81672 .47133 .81211 .46589 Mtetra
.638 .773 .945 r
.81211 .46589 .81672 .47133 .82783 .46839 .82325 .46289 Mtetra
.647 .775 .941 r
.82325 .46289 .82783 .46839 .83897 .46529 .83441 .45966 Mtetra
.653 .773 .937 r
.83441 .45966 .83897 .46529 .85014 .46206 .8456 .45627 Mtetra
.657 .769 .932 r
.8456 .45627 .85014 .46206 .86134 .45873 .85683 .45279 Mtetra
.66 .765 .928 r
.85683 .45279 .86134 .45873 .87259 .45531 .86809 .44924 Mtetra
.661 .761 .925 r
.86809 .44924 .87259 .45531 .88387 .45185 .8794 .44567 Mtetra
.661 .759 .922 r
.8794 .44567 .88387 .45185 .89519 .44835 .89074 .44208 Mtetra
.661 .756 .921 r
.89074 .44208 .89519 .44835 .90655 .44482 .90213 .43849 Mtetra
.66 .755 .92 r
.90213 .43849 .90655 .44482 .91796 .44128 .91357 .43489 Mtetra
.651 .75 .922 r
.3005 .61354 .30643 .61871 .31567 .61603 .30976 .61084 Mtetra
.65 .75 .923 r
.30976 .61084 .31567 .61603 .32494 .61336 .31905 .60815 Mtetra
.649 .75 .923 r
.31905 .60815 .32494 .61336 .33424 .61069 .32837 .60548 Mtetra
.647 .75 .924 r
.32837 .60548 .33424 .61069 .34358 .60799 .33772 .60282 Mtetra
.646 .752 .926 r
.33772 .60282 .34358 .60799 .35295 .60528 .34711 .60019 Mtetra
.646 .755 .929 r
.34711 .60019 .35295 .60528 .36236 .60251 .35653 .59753 Mtetra
.646 .761 .932 r
.35653 .59753 .36236 .60251 .3718 .59966 .36599 .59484 Mtetra
.651 .769 .935 r
.36599 .59484 .3718 .59966 .38129 .59665 .37549 .59201 Mtetra
.66 .779 .937 r
.37549 .59201 .38129 .59665 .39081 .59343 .38503 .58897 Mtetra
.671 .79 .937 r
.38503 .58897 .39081 .59343 .40038 .59 .39461 .58563 Mtetra
.688 .798 .933 r
.39461 .58563 .40038 .59 .40998 .58633 .40424 .5819 Mtetra
.698 .798 .927 r
.40424 .5819 .40998 .58633 .41961 .58264 .41391 .5779 Mtetra
.705 .788 .915 r
.41391 .5779 .41961 .58264 .42927 .57906 .42361 .57368 Mtetra
.692 .762 .905 r
.42361 .57368 .42927 .57906 .43895 .57602 .43334 .56979 Mtetra
.664 .726 .895 r
.43334 .56979 .43895 .57602 .44864 .57383 .44307 .56663 Mtetra
.615 .679 .887 r
.44307 .56663 .44864 .57383 .45835 .57262 .45281 .56476 Mtetra
.547 .631 .886 r
.45281 .56476 .45835 .57262 .46809 .57243 .46256 .56454 Mtetra
.513 .615 .891 r
.46256 .56454 .46809 .57243 .47788 .57209 .47235 .56503 Mtetra
.501 .637 .914 r
.47235 .56503 .47788 .57209 .48774 .57079 .4822 .56546 Mtetra
.599 .742 .944 r
.4822 .56546 .48774 .57079 .49765 .56725 .49212 .56362 Mtetra
.74 .846 .929 r
.49212 .56362 .49765 .56725 .50762 .56092 .50211 .55834 Mtetra
.815 .89 .897 r
.50211 .55834 .50762 .56092 .5176 .5534 .51214 .55063 Mtetra
.847 .878 .863 r
.51214 .55063 .5176 .5534 .52759 .54576 .52217 .54136 Mtetra
.808 .822 .861 r
.52217 .54136 .52759 .54576 .5376 .53997 .53221 .53327 Mtetra
.73 .737 .857 r
.53221 .53327 .5376 .53997 .54765 .53693 .54226 .52771 Mtetra
.651 .646 .833 r
.54226 .52771 .54765 .53693 .55776 .53596 .55236 .52461 Mtetra
.589 .576 .807 r
.55236 .52461 .55776 .53596 .56793 .53642 .56252 .5236 Mtetra
.582 .551 .785 r
.56252 .5236 .56793 .53642 .57815 .53658 .57273 .52285 Mtetra
.6 .549 .77 r
.57273 .52285 .57815 .53658 .58842 .53549 .58298 .52136 Mtetra
.633 .563 .758 r
.58298 .52136 .58842 .53549 .59868 .53238 .59325 .51823 Mtetra
.662 .579 .751 r
.59325 .51823 .59868 .53238 .60894 .52727 .60351 .51345 Mtetra
.677 .59 .751 r
.60351 .51345 .60894 .52727 .61918 .52087 .61379 .50792 Mtetra
.677 .601 .763 r
.61379 .50792 .61918 .52087 .62943 .51417 .62409 .50263 Mtetra
.642 .603 .795 r
.62409 .50263 .62943 .51417 .63975 .5089 .63449 .49946 Mtetra
.574 .61 .851 r
.63449 .49946 .63975 .5089 .65018 .50571 .64502 .49877 Mtetra
.412 .601 .924 r
.64502 .49877 .65018 .50571 .66075 .5053 .6557 .50064 Mtetra
.177 .559 .933 r
.6557 .50064 .66075 .5053 .67147 .50677 .66651 .50373 Mtetra
.189 .641 .943 r
.66651 .50373 .67147 .50677 .68225 .50815 .67733 .50525 Mtetra
.431 .789 .996 r
.67733 .50525 .68225 .50815 .69304 .50832 .6881 .50433 Mtetra
.695 .843 .954 r
.6881 .50433 .69304 .50832 .70374 .50566 .69875 .4999 Mtetra
.764 .792 .875 r
.69875 .4999 .70374 .50566 .71436 .50073 .70929 .49314 Mtetra
.748 .733 .839 r
.70929 .49314 .71436 .50073 .72494 .49479 .71985 .48631 Mtetra
.725 .704 .83 r
.71985 .48631 .72494 .49479 .73554 .4887 .73047 .48019 Mtetra
.685 .688 .848 r
.73047 .48019 .73554 .4887 .74623 .48363 .74123 .47576 Mtetra
.649 .691 .875 r
.74123 .47576 .74623 .48363 .75702 .47956 .75211 .47265 Mtetra
.621 .709 .908 r
.75211 .47265 .75702 .47956 .76791 .47638 .76309 .4703 Mtetra
.601 .731 .936 r
.76309 .4703 .76791 .47638 .77889 .47374 .77415 .46828 Mtetra
.604 .757 .952 r
.77415 .46828 .77889 .47374 .78992 .47123 .78524 .46604 Mtetra
.613 .773 .957 r
.78524 .46604 .78992 .47123 .801 .46868 .79635 .46352 Mtetra
.631 .782 .954 r
.79635 .46352 .801 .46868 .81211 .46589 .80749 .46059 Mtetra
.645 .783 .947 r
.80749 .46059 .81211 .46589 .82325 .46289 .81864 .45736 Mtetra
.655 .778 .939 r
.81864 .45736 .82325 .46289 .83441 .45966 .82981 .4539 Mtetra
.661 .773 .932 r
.82981 .4539 .83441 .45966 .8456 .45627 .84102 .4503 Mtetra
.663 .766 .926 r
.84102 .4503 .8456 .45627 .85683 .45279 .85226 .44665 Mtetra
.664 .761 .922 r
.85226 .44665 .85683 .45279 .86809 .44924 .86355 .44299 Mtetra
.663 .757 .92 r
.86355 .44299 .86809 .44924 .8794 .44567 .87488 .43934 Mtetra
.662 .755 .919 r
.87488 .43934 .8794 .44567 .89074 .44208 .88626 .4357 Mtetra
.661 .754 .919 r
.88626 .4357 .89074 .44208 .90213 .43849 .89768 .43207 Mtetra
.66 .753 .919 r
.89768 .43207 .90213 .43849 .91357 .43489 .90915 .42846 Mtetra
.653 .751 .922 r
.29453 .60833 .3005 .61354 .30976 .61084 .30381 .60556 Mtetra
.652 .749 .921 r
.30381 .60556 .30976 .61084 .31905 .60815 .31312 .60281 Mtetra
.65 .746 .92 r
.31312 .60281 .31905 .60815 .32837 .60548 .32247 .60009 Mtetra
.648 .745 .92 r
.32247 .60009 .32837 .60548 .33772 .60282 .33184 .59741 Mtetra
.644 .744 .921 r
.33184 .59741 .33772 .60282 .34711 .60019 .34125 .5948 Mtetra
.642 .745 .923 r
.34125 .5948 .34711 .60019 .35653 .59753 .35068 .59224 Mtetra
.638 .748 .928 r
.35068 .59224 .35653 .59753 .36599 .59484 .36015 .58973 Mtetra
.639 .756 .933 r
.36015 .58973 .36599 .59484 .37549 .59201 .36966 .58716 Mtetra
.643 .768 .939 r
.36966 .58716 .37549 .59201 .38503 .58897 .3792 .58448 Mtetra
.655 .786 .944 r
.3792 .58448 .38503 .58897 .39461 .58563 .3888 .58148 Mtetra
.675 .805 .945 r
.3888 .58148 .39461 .58563 .40424 .5819 .39844 .578 Mtetra
.697 .821 .941 r
.39844 .578 .40424 .5819 .41391 .5779 .40814 .57398 Mtetra
.722 .824 .928 r
.40814 .57398 .41391 .5779 .42361 .57368 .41789 .56931 Mtetra
.725 .808 .916 r
.41789 .56931 .42361 .57368 .43334 .56979 .42766 .56451 Mtetra
.714 .773 .899 r
.42766 .56451 .43334 .56979 .44307 .56663 .43745 .55996 Mtetra
.665 .714 .885 r
.43745 .55996 .44307 .56663 .45281 .56476 .44724 .55673 Mtetra
.588 .646 .875 r
.44724 .55673 .45281 .56476 .46256 .56454 .45702 .55558 Mtetra
.515 .588 .866 r
.45702 .55558 .46256 .56454 .47235 .56503 .46681 .55626 Mtetra
.436 .553 .876 r
.46681 .55626 .47235 .56503 .4822 .56546 .47664 .55842 Mtetra
.495 .637 .917 r
.47664 .55842 .4822 .56546 .49212 .56362 .48656 .55891 Mtetra
.648 .784 .947 r
.48656 .55891 .49212 .56362 .50211 .55834 .49656 .55594 Mtetra
.786 .901 .923 r
.49656 .55594 .50211 .55834 .51214 .55063 .50662 .54924 Mtetra
.872 .923 .858 r
.50662 .54924 .51214 .55063 .52217 .54136 .5167 .53906 Mtetra
.867 .892 .85 r
.5167 .53906 .52217 .54136 .53221 .53327 .52678 .52879 Mtetra
.817 .821 .853 r
.52678 .52879 .53221 .53327 .54226 .52771 .53685 .52019 Mtetra
.734 .717 .836 r
.53685 .52019 .54226 .52771 .55236 .52461 .54695 .51414 Mtetra
.651 .623 .809 r
.54695 .51414 .55236 .52461 .56252 .5236 .55709 .5108 Mtetra
.62 .572 .779 r
.55709 .5108 .56252 .5236 .57273 .52285 .56728 .50844 Mtetra
.614 .55 .758 r
.56728 .50844 .57273 .52285 .58298 .52136 .57752 .50619 Mtetra
.63 .551 .747 r
.57752 .50619 .58298 .52136 .59325 .51823 .58778 .50302 Mtetra
.646 .559 .743 r
.58778 .50302 .59325 .51823 .60351 .51345 .59806 .49895 Mtetra
.646 .567 .752 r
.59806 .49895 .60351 .51345 .61379 .50792 .60838 .49498 Mtetra
.633 .579 .776 r
.60838 .49498 .61379 .50792 .62409 .50263 .61875 .49199 Mtetra
.562 .579 .828 r
.61875 .49199 .62409 .50263 .63449 .49946 .62926 .49173 Mtetra
.406 .572 .904 r
.62926 .49173 .63449 .49946 .64502 .49877 .63991 .49406 Mtetra
.078 .493 .897 r
.63991 .49406 .64502 .49877 .6557 .50064 .6507 .4981 Mtetra
0 .399 .752 r
.6507 .4981 .6557 .50064 .66651 .50373 .66158 .50207 Mtetra
.154 .669 .892 r
.66158 .50207 .66651 .50373 .67733 .50525 .67238 .50254 Mtetra
.608 .874 .992 r
.67238 .50254 .67733 .50525 .6881 .50433 .68308 .49922 Mtetra
.772 .817 .888 r
.68308 .49922 .6881 .50433 .69875 .4999 .69363 .49237 Mtetra
.782 .745 .819 r
.69363 .49237 .69875 .4999 .70929 .49314 .70411 .48381 Mtetra
.736 .69 .807 r
.70411 .48381 .70929 .49314 .71985 .48631 .71468 .47673 Mtetra
.696 .67 .82 r
.71468 .47673 .71985 .48631 .73047 .48019 .72538 .47153 Mtetra
.646 .669 .858 r
.72538 .47153 .73047 .48019 .74123 .47576 .73624 .46844 Mtetra
.598 .686 .904 r
.73624 .46844 .74123 .47576 .75211 .47265 .74724 .46672 Mtetra
.572 .725 .945 r
.74724 .46672 .75211 .47265 .76309 .4703 .75832 .46525 Mtetra
.562 .758 .969 r
.75832 .46525 .76309 .4703 .77415 .46828 .76944 .46366 Mtetra
.589 .788 .975 r
.76944 .46366 .77415 .46828 .78524 .46604 .78056 .4614 Mtetra
.618 .8 .969 r
.78056 .4614 .78524 .46604 .79635 .46352 .79169 .45857 Mtetra
.645 .798 .956 r
.79169 .45857 .79635 .46352 .80749 .46059 .80282 .45525 Mtetra
.661 .789 .942 r
.80282 .45525 .80749 .46059 .81864 .45736 .81397 .45161 Mtetra
.668 .776 .931 r
.81397 .45161 .81864 .45736 .82981 .4539 .82515 .44783 Mtetra
.67 .766 .922 r
.82515 .44783 .82981 .4539 .84102 .4503 .83637 .44399 Mtetra
.668 .757 .917 r
.83637 .44399 .84102 .4503 .85226 .44665 .84764 .44021 Mtetra
.666 .752 .915 r
.84764 .44021 .85226 .44665 .86355 .44299 .85895 .43647 Mtetra
.663 .75 .914 r
.85895 .43647 .86355 .44299 .87488 .43934 .87031 .43279 Mtetra
.661 .749 .915 r
.87031 .43279 .87488 .43934 .88626 .4357 .88172 .42917 Mtetra
.66 .749 .916 r
.88172 .42917 .88626 .4357 .89768 .43207 .89319 .42556 Mtetra
.659 .751 .918 r
.89319 .42556 .89768 .43207 .90915 .42846 .90469 .42197 Mtetra
.656 .752 .92 r
.28853 .60308 .29453 .60833 .30381 .60556 .29783 .60022 Mtetra
.656 .748 .918 r
.29783 .60022 .30381 .60556 .31312 .60281 .30717 .59735 Mtetra
.654 .745 .916 r
.30717 .59735 .31312 .60281 .32247 .60009 .31654 .59452 Mtetra
.651 .741 .915 r
.31654 .59452 .32247 .60009 .33184 .59741 .32593 .59175 Mtetra
.647 .737 .915 r
.32593 .59175 .33184 .59741 .34125 .5948 .33536 .58908 Mtetra
.642 .734 .915 r
.33536 .58908 .34125 .5948 .35068 .59224 .34481 .58651 Mtetra
.635 .732 .918 r
.34481 .58651 .35068 .59224 .36015 .58973 .35429 .58409 Mtetra
.631 .735 .923 r
.35429 .58409 .36015 .58973 .36966 .58716 .36381 .58174 Mtetra
.627 .742 .93 r
.36381 .58174 .36966 .58716 .3792 .58448 .37336 .57944 Mtetra
.634 .76 .939 r
.37336 .57944 .3792 .58448 .3888 .58148 .38296 .57694 Mtetra
.648 .784 .947 r
.38296 .57694 .3888 .58148 .39844 .578 .3926 .57405 Mtetra
.676 .816 .95 r
.3926 .57405 .39844 .578 .40814 .57398 .40231 .57047 Mtetra
.716 .842 .942 r
.40231 .57047 .40814 .57398 .41789 .56931 .41208 .56592 Mtetra
.743 .85 .93 r
.41208 .56592 .41789 .56931 .42766 .56451 .4219 .56066 Mtetra
.759 .833 .909 r
.4219 .56066 .42766 .56451 .43745 .55996 .43175 .55485 Mtetra
.727 .783 .897 r
.43175 .55485 .43745 .55996 .44724 .55673 .44161 .54987 Mtetra
.661 .709 .883 r
.44161 .54987 .44724 .55673 .45702 .55558 .45145 .5467 Mtetra
.56 .612 .862 r
.45145 .5467 .45702 .55558 .46681 .55626 .46127 .5463 Mtetra
.427 .519 .849 r
.46127 .5463 .46681 .55626 .47664 .55842 .47109 .54906 Mtetra
.424 .533 .863 r
.47109 .54906 .47664 .55842 .48656 .55891 .48098 .55164 Mtetra
.507 .637 .911 r
.48098 .55164 .48656 .55891 .49656 .55594 .49097 .55196 Mtetra
.693 .827 .948 r
.49097 .55196 .49656 .55594 .50662 .54924 .50105 .54785 Mtetra
.854 .931 .877 r
.50105 .54785 .50662 .54924 .5167 .53906 .51117 .53856 Mtetra
.89 .947 .84 r
.51117 .53856 .5167 .53906 .52678 .52879 .5213 .52737 Mtetra
.888 .919 .839 r
.5213 .52737 .52678 .52879 .53685 .52019 .53142 .51616 Mtetra
.832 .838 .852 r
.53142 .51616 .53685 .52019 .54695 .51414 .54154 .50701 Mtetra
.741 .732 .843 r
.54154 .50701 .54695 .51414 .55709 .5108 .55168 .50075 Mtetra
.681 .645 .808 r
.55168 .50075 .55709 .5108 .56728 .50844 .56185 .4962 Mtetra
.644 .593 .782 r
.56185 .4962 .56728 .50844 .57752 .50619 .57208 .49283 Mtetra
.636 .574 .768 r
.57208 .49283 .57752 .50619 .58778 .50302 .58234 .48963 Mtetra
.632 .572 .769 r
.58234 .48963 .58778 .50302 .59806 .49895 .59265 .48663 Mtetra
.608 .574 .791 r
.59265 .48663 .59806 .49895 .60838 .49498 .60302 .4848 Mtetra
.554 .585 .84 r
.60302 .4848 .60838 .49498 .61875 .49199 .61349 .48469 Mtetra
.355 .559 .913 r
.61349 .48469 .61875 .49199 .62926 .49173 .6241 .48752 Mtetra
0 .402 .824 r
.6241 .48752 .62926 .49173 .63991 .49406 .63486 .49245 Mtetra
.361 0 0 r
.63486 .49245 .63991 .49406 .6507 .4981 .64572 .49737 Mtetra
.264 0 0 r
.64572 .49737 .6507 .4981 .66158 .50207 .65659 .50042 Mtetra
.452 .85 .975 r
.65659 .50042 .66158 .50207 .67238 .50254 .66732 .49821 Mtetra
.774 .847 .907 r
.66732 .49821 .67238 .50254 .68308 .49922 .67789 .49151 Mtetra
.787 .742 .812 r
.67789 .49151 .68308 .49922 .69363 .49237 .68836 .48249 Mtetra
.766 .691 .78 r
.68836 .48249 .69363 .49237 .70411 .48381 .69883 .47326 Mtetra
.706 .656 .798 r
.69883 .47326 .70411 .48381 .71468 .47673 .70948 .46723 Mtetra
.647 .65 .84 r
.70948 .46723 .71468 .47673 .72538 .47153 .72032 .46405 Mtetra
.582 .675 .903 r
.72032 .46405 .72538 .47153 .73624 .46844 .73132 .46271 Mtetra
.514 .707 .958 r
.73132 .46271 .73624 .46844 .74724 .46672 .74244 .46224 Mtetra
.51 .76 .986 r
.74244 .46224 .74724 .46672 .75832 .46525 .75358 .46121 Mtetra
.542 .795 .992 r
.75358 .46121 .75832 .46525 .76944 .46366 .76472 .45945 Mtetra
.605 .815 .98 r
.76472 .45945 .76944 .46366 .78056 .4614 .77584 .45669 Mtetra
.649 .81 .961 r
.77584 .45669 .78056 .4614 .79169 .45857 .78696 .45322 Mtetra
.67 .792 .939 r
.78696 .45322 .79169 .45857 .80282 .45525 .79808 .44934 Mtetra
.679 .775 .923 r
.79808 .44934 .80282 .45525 .81397 .45161 .80923 .44525 Mtetra
.677 .759 .913 r
.80923 .44525 .81397 .45161 .82515 .44783 .82042 .4412 Mtetra
.674 .749 .907 r
.82042 .4412 .82515 .44783 .83637 .44399 .83165 .43723 Mtetra
.669 .743 .906 r
.83165 .43723 .83637 .44399 .84764 .44021 .84295 .4334 Mtetra
.664 .741 .907 r
.84295 .4334 .84764 .44021 .85895 .43647 .85429 .42968 Mtetra
.66 .741 .91 r
.85429 .42968 .85895 .43647 .87031 .43279 .8657 .42606 Mtetra
.658 .742 .912 r
.8657 .42606 .87031 .43279 .88172 .42917 .87715 .4225 Mtetra
.656 .745 .915 r
.87715 .4225 .88172 .42917 .89319 .42556 .88866 .41897 Mtetra
.655 .748 .918 r
.88866 .41897 .89319 .42556 .90469 .42197 .90021 .41544 Mtetra
.661 .753 .918 r
.28248 .59781 .28853 .60308 .29783 .60022 .29181 .59482 Mtetra
.661 .749 .915 r
.29181 .59482 .29783 .60022 .30717 .59735 .30118 .59181 Mtetra
.66 .744 .912 r
.30118 .59181 .30717 .59735 .31654 .59452 .31057 .58882 Mtetra
.658 .739 .909 r
.31057 .58882 .31654 .59452 .32593 .59175 .32 .58588 Mtetra
.654 .732 .907 r
.32 .58588 .32593 .59175 .33536 .58908 .32945 .58302 Mtetra
.648 .725 .905 r
.32945 .58302 .33536 .58908 .34481 .58651 .33893 .58031 Mtetra
.639 .718 .905 r
.33893 .58031 .34481 .58651 .35429 .58409 .34843 .57782 Mtetra
.629 .713 .907 r
.34843 .57782 .35429 .58409 .36381 .58174 .35796 .57554 Mtetra
.617 .712 .914 r
.35796 .57554 .36381 .58174 .37336 .57944 .36751 .57354 Mtetra
.612 .722 .924 r
.36751 .57354 .37336 .57944 .38296 .57694 .3771 .57159 Mtetra
.61 .743 .939 r
.3771 .57159 .38296 .57694 .3926 .57405 .38674 .56957 Mtetra
.633 .785 .955 r
.38674 .56957 .3926 .57405 .40231 .57047 .39643 .56694 Mtetra
.675 .836 .96 r
.39643 .56694 .40231 .57047 .41208 .56592 .4062 .56328 Mtetra
.727 .881 .952 r
.4062 .56328 .41208 .56592 .4219 .56066 .41604 .55831 Mtetra
.783 .895 .923 r
.41604 .55831 .4219 .56066 .43175 .55485 .42596 .55182 Mtetra
.79 .868 .907 r
.42596 .55182 .43175 .55485 .44161 .54987 .43589 .54503 Mtetra
.761 .799 .884 r
.43589 .54503 .44161 .54987 .45145 .5467 .44582 .53888 Mtetra
.652 .68 .864 r
.44582 .53888 .45145 .5467 .46127 .5463 .45571 .53589 Mtetra
.49 .544 .838 r
.45571 .53589 .46127 .5463 .47109 .54906 .46555 .53743 Mtetra
.412 .476 .816 r
.46555 .53743 .47109 .54906 .48098 .55164 .47543 .5411 Mtetra
.367 .474 .837 r
.47543 .5411 .48098 .55164 .49097 .55196 .48537 .54518 Mtetra
.512 .658 .926 r
.48537 .54518 .49097 .55196 .50105 .54785 .49543 .54522 Mtetra
.764 .894 .935 r
.49543 .54522 .50105 .54785 .51117 .53856 .50559 .53912 Mtetra
.855 .986 .851 r
.50559 .53912 .51117 .53856 .5213 .52737 .51577 .52905 Mtetra
.893 .987 .787 r
.51577 .52905 .5213 .52737 .53142 .51616 .52595 .51644 Mtetra
.896 .968 .824 r
.52595 .51644 .53142 .51616 .54154 .50701 .53611 .50467 Mtetra
.851 .902 .871 r
.53611 .50467 .54154 .50701 .55168 .50075 .54627 .49531 Mtetra
.776 .792 .866 r
.54627 .49531 .55168 .50075 .56185 .4962 .55645 .48823 Mtetra
.699 .699 .846 r
.55645 .48823 .56185 .4962 .57208 .49283 .56667 .48346 Mtetra
.651 .648 .834 r
.56667 .48346 .57208 .49283 .58234 .48963 .57695 .48024 Mtetra
.604 .627 .847 r
.57695 .48024 .58234 .48963 .59265 .48663 .5873 .47859 Mtetra
.5 .613 .895 r
.5873 .47859 .59265 .48663 .60302 .4848 .59774 .47926 Mtetra
.243 .565 .937 r
.59774 .47926 .60302 .4848 .61349 .48469 .60831 .48222 Mtetra
.335 0 0 r
.60831 .48222 .61349 .48469 .6241 .48752 .61903 .48765 Mtetra
.57 0 0 r
.61903 .48765 .6241 .48752 .63486 .49245 .62987 .49396 Mtetra
.478 0 0 r
.62987 .49396 .63486 .49245 .64572 .49737 .64072 .49773 Mtetra
.015 0 0 r
.64072 .49773 .64572 .49737 .65659 .50042 .65151 .4975 Mtetra
.766 .903 .936 r
.65151 .4975 .65659 .50042 .66732 .49821 .6621 .49104 Mtetra
.817 .762 .801 r
.6621 .49104 .66732 .49821 .67789 .49151 .67253 .48047 Mtetra
.767 .674 .76 r
.67253 .48047 .67789 .49151 .68836 .48249 .68297 .47028 Mtetra
.726 .64 .762 r
.68297 .47028 .68836 .48249 .69883 .47326 .69351 .46225 Mtetra
.647 .621 .81 r
.69351 .46225 .69883 .47326 .70948 .46723 .70432 .45882 Mtetra
.542 .628 .887 r
.70432 .45882 .70948 .46723 .72032 .46405 .71536 .45864 Mtetra
.442 .685 .968 r
.71536 .45864 .72032 .46405 .73132 .46271 .7265 .45911 Mtetra
.367 .728 .989 r
.7265 .45911 .73132 .46271 .74244 .46224 .7377 .4593 Mtetra
.457 .806 .998 r
.7377 .4593 .74244 .46224 .75358 .46121 .74885 .45793 Mtetra
.574 .845 .996 r
.74885 .45793 .75358 .46121 .76472 .45945 .75997 .45522 Mtetra
.657 .834 .968 r
.75997 .45522 .76472 .45945 .77584 .45669 .77105 .45144 Mtetra
.691 .804 .935 r
.77105 .45144 .77584 .45669 .78696 .45322 .78212 .44702 Mtetra
.693 .77 .911 r
.78212 .44702 .78696 .45322 .79808 .44934 .79323 .44252 Mtetra
.689 .748 .897 r
.79323 .44252 .79808 .44934 .80923 .44525 .80438 .43807 Mtetra
.679 .734 .892 r
.80438 .43807 .80923 .44525 .82042 .4412 .81559 .43391 Mtetra
.671 .728 .892 r
.81559 .43391 .82042 .4412 .83165 .43723 .82686 .42996 Mtetra
.664 .727 .896 r
.82686 .42996 .83165 .43723 .84295 .4334 .8382 .42624 Mtetra
.658 .728 .901 r
.8382 .42624 .84295 .4334 .85429 .42968 .84959 .42267 Mtetra
.655 .733 .906 r
.84959 .42267 .85429 .42968 .8657 .42606 .86104 .41918 Mtetra
.653 .737 .911 r
.86104 .41918 .8657 .42606 .87715 .4225 .87254 .41574 Mtetra
.652 .741 .915 r
.87254 .41574 .87715 .4225 .88866 .41897 .88409 .41231 Mtetra
.652 .746 .919 r
.88409 .41231 .88866 .41897 .90021 .41544 .89569 .40886 Mtetra
.663 .753 .917 r
.27639 .59249 .28248 .59781 .29181 .59482 .28575 .58942 Mtetra
.665 .751 .915 r
.28575 .58942 .29181 .59482 .30118 .59181 .29514 .58631 Mtetra
.665 .748 .912 r
.29514 .58631 .30118 .59181 .31057 .58882 .30456 .58318 Mtetra
.664 .744 .909 r
.30456 .58318 .31057 .58882 .32 .58588 .31402 .58006 Mtetra
.663 .738 .905 r
.31402 .58006 .32 .58588 .32945 .58302 .32351 .57695 Mtetra
.658 .729 .901 r
.32351 .57695 .32945 .58302 .33893 .58031 .33302 .57397 Mtetra
.65 .718 .898 r
.33302 .57397 .33893 .58031 .34843 .57782 .34255 .57118 Mtetra
.638 .705 .895 r
.34255 .57118 .34843 .57782 .35796 .57554 .35211 .5687 Mtetra
.62 .693 .896 r
.35211 .5687 .35796 .57554 .36751 .57354 .36168 .56665 Mtetra
.605 .687 .9 r
.36168 .56665 .36751 .57354 .3771 .57159 .37127 .56495 Mtetra
.586 .689 .913 r
.37127 .56495 .3771 .57159 .38674 .56957 .38089 .56362 Mtetra
.59 .715 .93 r
.38089 .56362 .38674 .56957 .39643 .56694 .39056 .56207 Mtetra
.612 .765 .953 r
.39056 .56207 .39643 .56694 .4062 .56328 .4003 .55987 Mtetra
.671 .842 .965 r
.4003 .55987 .4062 .56328 .41604 .55831 .41013 .55621 Mtetra
.753 .907 .944 r
.41013 .55621 .41604 .55831 .42596 .55182 .42006 .55046 Mtetra
.807 .933 .915 r
.42006 .55046 .42596 .55182 .43589 .54503 .43005 .54305 Mtetra
.839 .904 .883 r
.43005 .54305 .43589 .54503 .44582 .53888 .44008 .53441 Mtetra
.769 .815 .889 r
.44008 .53441 .44582 .53888 .45571 .53589 .45007 .52801 Mtetra
.621 .668 .874 r
.45007 .52801 .45571 .53589 .46555 .53743 .45999 .5259 Mtetra
.476 .515 .818 r
.45999 .5259 .46555 .53743 .47543 .5411 .46989 .52803 Mtetra
.334 .405 .786 r
.46989 .52803 .47543 .5411 .48537 .54518 .4798 .53392 Mtetra
.389 .472 .825 r
.4798 .53392 .48537 .54518 .49543 .54522 .48982 .53788 Mtetra
.569 .666 .904 r
.48982 .53788 .49543 .54522 .50559 .53912 .49996 .53693 Mtetra
.761 .914 .941 r
.49996 .53693 .50559 .53912 .51577 .52905 .51017 .53077 Mtetra
.85 .998 .807 r
.51017 .53077 .51577 .52905 .52595 .51644 .52041 .51973 Mtetra
.814 .988 .725 r
.52041 .51973 .52595 .51644 .53611 .50467 .53064 .50766 Mtetra
.785 .987 .738 r
.53064 .50766 .53611 .50467 .54627 .49531 .54085 .49658 Mtetra
.777 .998 .84 r
.54085 .49658 .54627 .49531 .55645 .48823 .55107 .48771 Mtetra
.702 .966 .937 r
.55107 .48771 .55645 .48823 .56667 .48346 .56133 .48178 Mtetra
.565 .894 .985 r
.56133 .48178 .56667 .48346 .57695 .48024 .57165 .47855 Mtetra
.281 .751 .941 r
.57165 .47855 .57695 .48024 .5873 .47859 .58205 .47801 Mtetra
.229 0 0 r
.58205 .47801 .5873 .47859 .59774 .47926 .59257 .48044 Mtetra
.526 0 0 r
.59257 .48044 .59774 .47926 .60831 .48222 .60322 .48511 Mtetra
.605 .085 0 r
.60322 .48511 .60831 .48222 .61903 .48765 .61398 .49082 Mtetra
.568 .044 0 r
.61398 .49082 .61903 .48765 .62987 .49396 .62482 .49551 Mtetra
.147 0 0 r
.62482 .49551 .62987 .49396 .64072 .49773 .63558 .49529 Mtetra
.72 .916 .961 r
.63558 .49529 .64072 .49773 .65151 .4975 .64621 .48981 Mtetra
.809 .748 .796 r
.64621 .48981 .65151 .4975 .6621 .49104 .65667 .47932 Mtetra
.787 .672 .738 r
.65667 .47932 .6621 .49104 .67253 .48047 .66704 .46685 Mtetra
.724 .622 .744 r
.66704 .46685 .67253 .48047 .68297 .47028 .67756 .45817 Mtetra
.662 .612 .787 r
.67756 .45817 .68297 .47028 .69351 .46225 .6883 .45381 Mtetra
.532 .624 .888 r
.6883 .45381 .69351 .46225 .70432 .45882 .69932 .45383 Mtetra
.271 .609 .955 r
.69932 .45383 .70432 .45882 .71536 .45864 .71053 .45615 Mtetra
.173 .656 .926 r
.71053 .45615 .71536 .45864 .7265 .45911 .72175 .45723 Mtetra
.293 .756 .948 r
.72175 .45723 .7265 .45911 .7377 .4593 .73293 .45662 Mtetra
.55 .861 .997 r
.73293 .45662 .7377 .4593 .74885 .45793 .74403 .45386 Mtetra
.677 .848 .965 r
.74403 .45386 .74885 .45793 .75997 .45522 .75507 .44959 Mtetra
.709 .795 .918 r
.75507 .44959 .75997 .45522 .77105 .45144 .76611 .44465 Mtetra
.711 .757 .888 r
.76611 .44465 .77105 .45144 .78212 .44702 .77716 .43947 Mtetra
.697 .729 .876 r
.77716 .43947 .78212 .44702 .79323 .44252 .78827 .43466 Mtetra
.684 .716 .873 r
.78827 .43466 .79323 .44252 .80438 .43807 .79944 .43022 Mtetra
.671 .712 .879 r
.79944 .43022 .80438 .43807 .81559 .43391 .8107 .42622 Mtetra
.661 .713 .887 r
.8107 .42622 .81559 .43391 .82686 .42996 .82202 .42254 Mtetra
.655 .719 .896 r
.82202 .42254 .82686 .42996 .8382 .42624 .83341 .41905 Mtetra
.65 .726 .904 r
.83341 .41905 .8382 .42624 .84959 .42267 .84486 .41569 Mtetra
.649 .733 .91 r
.84486 .41569 .84959 .42267 .86104 .41918 .85636 .41234 Mtetra
.648 .738 .915 r
.85636 .41234 .86104 .41918 .87254 .41574 .8679 .409 Mtetra
.648 .742 .918 r
.8679 .409 .87254 .41574 .88409 .41231 .8795 .40565 Mtetra
.649 .746 .92 r
.8795 .40565 .88409 .41231 .89569 .40886 .89113 .40224 Mtetra
.663 .753 .917 r
.27027 .58715 .27639 .59249 .28575 .58942 .27964 .58407 Mtetra
.665 .754 .916 r
.27964 .58407 .28575 .58942 .29514 .58631 .28905 .58092 Mtetra
.667 .754 .915 r
.28905 .58092 .29514 .58631 .30456 .58318 .2985 .57771 Mtetra
.669 .752 .913 r
.2985 .57771 .30456 .58318 .31402 .58006 .30799 .57445 Mtetra
.672 .749 .908 r
.30799 .57445 .31402 .58006 .32351 .57695 .31751 .57109 Mtetra
.671 .74 .902 r
.31751 .57109 .32351 .57695 .33302 .57397 .32706 .56775 Mtetra
.668 .728 .895 r
.32706 .56775 .33302 .57397 .34255 .57118 .33664 .56447 Mtetra
.657 .71 .887 r
.33664 .56447 .34255 .57118 .35211 .5687 .34624 .56146 Mtetra
.639 .689 .881 r
.34624 .56146 .35211 .5687 .36168 .56665 .35585 .55891 Mtetra
.616 .667 .876 r
.35585 .55891 .36168 .56665 .37127 .56495 .36546 .55696 Mtetra
.584 .648 .879 r
.36546 .55696 .37127 .56495 .38089 .56362 .37508 .55583 Mtetra
.562 .645 .89 r
.37508 .55583 .38089 .56362 .39056 .56207 .38473 .55515 Mtetra
.541 .664 .917 r
.38473 .55515 .39056 .56207 .4003 .55987 .39442 .55471 Mtetra
.57 .741 .957 r
.39442 .55471 .4003 .55987 .41013 .55621 .40419 .55328 Mtetra
.643 .858 .981 r
.40419 .55328 .41013 .55621 .42006 .55046 .41408 .54993 Mtetra
.743 .962 .938 r
.41408 .54993 .42006 .55046 .43005 .54305 .42408 .54371 Mtetra
.849 .983 .862 r
.42408 .54371 .43005 .54305 .44008 .53441 .43419 .53408 Mtetra
.864 .955 .867 r
.43419 .53408 .44008 .53441 .45007 .52801 .4443 .52428 Mtetra
.809 .845 .877 r
.4443 .52428 .45007 .52801 .45999 .5259 .45437 .51644 Mtetra
.629 .634 .837 r
.45437 .51644 .45999 .5259 .46989 .52803 .46435 .51401 Mtetra
.413 .439 .777 r
.46435 .51401 .46989 .52803 .4798 .53392 .47427 .51845 Mtetra
.367 .392 .754 r
.47427 .51845 .4798 .53392 .48982 .53788 .48425 .52466 Mtetra
.376 .43 .79 r
.48425 .52466 .48982 .53788 .49996 .53693 .49433 .5297 Mtetra
.505 .643 .918 r
.49433 .5297 .49996 .53693 .51017 .53077 .50453 .52994 Mtetra
.723 .959 .945 r
.50453 .52994 .51017 .53077 .52041 .51973 .5148 .52393 Mtetra
.558 .883 .616 r
.5148 .52393 .52041 .51973 .53064 .50766 .5251 .51476 Mtetra
0 0 0 r
.5251 .51476 .53064 .50766 .54085 .49658 .5354 .50425 Mtetra
.5354 .50425 .54085 .49658 .55107 .48771 .54569 .49506 Mtetra
.032 0 0 r
.54569 .49506 .55107 .48771 .56133 .48178 .55602 .48861 Mtetra
.24 0 0 r
.55602 .48861 .56133 .48178 .57165 .47855 .5664 .48537 Mtetra
.423 0 .058 r
.5664 .48537 .57165 .47855 .58205 .47801 .57687 .48533 Mtetra
.538 .095 .145 r
.57687 .48533 .58205 .47801 .59257 .48044 .58746 .48807 Mtetra
.579 .143 .177 r
.58746 .48807 .59257 .48044 .60322 .48511 .59815 .49215 Mtetra
.535 .084 .129 r
.59815 .49215 .60322 .48511 .61398 .49082 .6089 .4949 Mtetra
.308 0 0 r
.6089 .4949 .61398 .49082 .62482 .49551 .61963 .49448 Mtetra
.744 .967 .934 r
.61963 .49448 .62482 .49551 .63558 .49529 .63023 .48776 Mtetra
.825 .755 .786 r
.63023 .48776 .63558 .49529 .64621 .48981 .64067 .47615 Mtetra
.772 .644 .721 r
.64067 .47615 .64621 .48981 .65667 .47932 .65105 .46332 Mtetra
.735 .605 .713 r
.65105 .46332 .65667 .47932 .66704 .46685 .66149 .45226 Mtetra
.645 .571 .757 r
.66149 .45226 .66704 .46685 .67756 .45817 .67223 .44817 Mtetra
.489 .562 .857 r
.67223 .44817 .67756 .45817 .6883 .45381 .68327 .4496 Mtetra
.091 .528 .907 r
.68327 .4496 .6883 .45381 .69932 .45383 .6945 .45306 Mtetra
.265 0 0 r
.6945 .45306 .69932 .45383 .71053 .45615 .7058 .45636 Mtetra
.005 0 0 r
.7058 .45636 .71053 .45615 .72175 .45723 .71699 .45618 Mtetra
.464 .876 .945 r
.71699 .45618 .72175 .45723 .73293 .45662 .72806 .45306 Mtetra
.708 .879 .961 r
.72806 .45306 .73293 .45662 .74403 .45386 .73905 .44797 Mtetra
.744 .797 .895 r
.73905 .44797 .74403 .45386 .75507 .44959 .75 .44184 Mtetra
.724 .733 .859 r
.75 .44184 .75507 .44959 .76611 .44465 .761 .43596 Mtetra
.705 .703 .845 r
.761 .43596 .76611 .44465 .77716 .43947 .77205 .43052 Mtetra
.683 .688 .848 r
.77205 .43052 .77716 .43947 .78827 .43466 .78321 .42592 Mtetra
.667 .687 .859 r
.78321 .42592 .78827 .43466 .79944 .43022 .79445 .42195 Mtetra
.654 .694 .875 r
.79445 .42195 .79944 .43022 .8107 .42622 .80577 .41845 Mtetra
.646 .705 .89 r
.80577 .41845 .8107 .42622 .82202 .42254 .81717 .41523 Mtetra
.643 .719 .904 r
.81717 .41523 .82202 .42254 .83341 .41905 .82862 .41207 Mtetra
.641 .73 .913 r
.82862 .41207 .83341 .41905 .84486 .41569 .84012 .40892 Mtetra
.644 .739 .919 r
.84012 .40892 .84486 .41569 .85636 .41234 .85167 .40568 Mtetra
.645 .745 .922 r
.85167 .40568 .85636 .41234 .8679 .409 .86325 .40238 Mtetra
.647 .748 .923 r
.86325 .40238 .8679 .409 .8795 .40565 .87488 .39901 Mtetra
.649 .749 .922 r
.87488 .39901 .8795 .40565 .89113 .40224 .88655 .39556 Mtetra
.659 .752 .919 r
.2641 .58177 .27027 .58715 .27964 .58407 .27349 .57877 Mtetra
.66 .756 .921 r
.27349 .57877 .27964 .58407 .28905 .58092 .28291 .57571 Mtetra
.664 .761 .923 r
.28291 .57571 .28905 .58092 .2985 .57771 .29238 .57257 Mtetra
.668 .765 .923 r
.29238 .57257 .2985 .57771 .30799 .57445 .30188 .5693 Mtetra
.675 .767 .92 r
.30188 .5693 .30799 .57445 .31751 .57109 .31143 .56584 Mtetra
.68 .765 .916 r
.31143 .56584 .31751 .57109 .32706 .56775 .32102 .56226 Mtetra
.685 .758 .908 r
.32102 .56226 .32706 .56775 .33664 .56447 .33064 .55854 Mtetra
.68 .743 .898 r
.33064 .55854 .33664 .56447 .34624 .56146 .34029 .55489 Mtetra
.67 .72 .887 r
.34029 .55489 .34624 .56146 .35585 .55891 .34996 .55149 Mtetra
.647 .688 .875 r
.34996 .55149 .35585 .55891 .36546 .55696 .35964 .54869 Mtetra
.612 .653 .866 r
.35964 .54869 .36546 .55696 .37508 .55583 .3693 .54685 Mtetra
.574 .619 .859 r
.3693 .54685 .37508 .55583 .38473 .55515 .37896 .54603 Mtetra
.524 .593 .865 r
.37896 .54603 .38473 .55515 .39442 .55471 .38862 .54639 Mtetra
.51 .609 .887 r
.38862 .54639 .39442 .55471 .40419 .55328 .39834 .54683 Mtetra
.521 .675 .934 r
.39834 .54683 .40419 .55328 .41408 .54993 .40813 .54655 Mtetra
.634 .839 .979 r
.40813 .54655 .41408 .54993 .42408 .54371 .41807 .54347 Mtetra
.782 .971 .917 r
.41807 .54347 .42408 .54371 .43419 .53408 .42817 .53619 Mtetra
.825 1 .815 r
.42817 .53619 .43419 .53408 .4443 .52428 .43835 .52596 Mtetra
.89 .985 .805 r
.43835 .52596 .4443 .52428 .45437 .51644 .44857 .51388 Mtetra
.825 .89 .889 r
.44857 .51388 .45437 .51644 .46435 .51401 .45869 .50566 Mtetra
.593 .647 .873 r
.45869 .50566 .46435 .51401 .47427 .51845 .46871 .50423 Mtetra
.448 .458 .777 r
.46871 .50423 .47427 .51845 .48425 .52466 .47871 .50778 Mtetra
.354 .368 .736 r
.47871 .50778 .48425 .52466 .49433 .5297 .48874 .51491 Mtetra
.396 .42 .768 r
.48874 .51491 .49433 .5297 .50453 .52994 .4989 .52007 Mtetra
.521 .579 .854 r
.4989 .52007 .50453 .52994 .5148 .52393 .50916 .52062 Mtetra
.639 .852 .981 r
.50916 .52062 .5148 .52393 .5251 .51476 .51949 .51723 Mtetra
.516 .9 .735 r
.51949 .51723 .5251 .51476 .5354 .50425 .52986 .51058 Mtetra
0 0 0 r
.52986 .51058 .5354 .50425 .54569 .49506 .54024 .50369 Mtetra
.164 0 0 r
.54024 .50369 .54569 .49506 .55602 .48861 .55064 .49809 Mtetra
.327 0 .1 r
.55064 .49809 .55602 .48861 .5664 .48537 .5611 .49483 Mtetra
.429 .015 .151 r
.5611 .49483 .5664 .48537 .57687 .48533 .57163 .49393 Mtetra
.466 .038 .143 r
.57163 .49393 .57687 .48533 .58746 .48807 .58224 .49433 Mtetra
.416 0 .023 r
.58224 .49433 .58746 .48807 .59815 .49215 .59291 .49451 Mtetra
0 0 0 r
.59291 .49451 .59815 .49215 .6089 .4949 .60356 .49141 Mtetra
.786 .88 .915 r
.60356 .49141 .6089 .4949 .61963 .49448 .61415 .48432 Mtetra
.795 .697 .757 r
.61415 .48432 .61963 .49448 .63023 .48776 .62461 .47256 Mtetra
.768 .629 .707 r
.62461 .47256 .63023 .48776 .64067 .47615 .63499 .45877 Mtetra
.716 .585 .708 r
.63499 .45877 .64067 .47615 .65105 .46332 .64548 .44859 Mtetra
.663 .58 .751 r
.64548 .44859 .65105 .46332 .66149 .45226 .65617 .44344 Mtetra
.454 .574 .885 r
.65617 .44344 .66149 .45226 .67223 .44817 .66718 .4452 Mtetra
0 .282 .677 r
.66718 .4452 .67223 .44817 .68327 .4496 .67846 .45092 Mtetra
.456 0 0 r
.67846 .45092 .68327 .4496 .6945 .45306 .68975 .45478 Mtetra
.257 0 0 r
.68975 .45478 .6945 .45306 .7058 .45636 .70097 .45564 Mtetra
.463 .882 .928 r
.70097 .45564 .7058 .45636 .71699 .45618 .71202 .45221 Mtetra
.757 .872 .931 r
.71202 .45221 .71699 .45618 .72806 .45306 .72294 .44589 Mtetra
.756 .76 .855 r
.72294 .44589 .72806 .45306 .73905 .44797 .73383 .43882 Mtetra
.736 .704 .821 r
.73383 .43882 .73905 .44797 .75 .44184 .74475 .43182 Mtetra
.704 .673 .818 r
.74475 .43182 .75 .44184 .761 .43596 .75577 .42602 Mtetra
.681 .665 .828 r
.75577 .42602 .761 .43596 .77205 .43052 .7669 .42127 Mtetra
.659 .671 .851 r
.7669 .42127 .77205 .43052 .78321 .42592 .77815 .4175 Mtetra
.642 .686 .875 r
.77815 .4175 .78321 .42592 .79445 .42195 .78948 .41437 Mtetra
.634 .707 .899 r
.78948 .41437 .79445 .42195 .80577 .41845 .80089 .41148 Mtetra
.629 .725 .916 r
.80089 .41148 .80577 .41845 .81717 .41523 .81236 .40867 Mtetra
.632 .742 .927 r
.81236 .40867 .81717 .41523 .82862 .41207 .82386 .40572 Mtetra
.636 .752 .932 r
.82386 .40572 .82862 .41207 .84012 .40892 .8354 .40263 Mtetra
.642 .757 .932 r
.8354 .40263 .84012 .40892 .85167 .40568 .84698 .39935 Mtetra
.647 .759 .931 r
.84698 .39935 .85167 .40568 .86325 .40238 .85859 .39593 Mtetra
.651 .757 .927 r
.85859 .39593 .86325 .40238 .87488 .39901 .87024 .39242 Mtetra
.653 .754 .924 r
.87024 .39242 .87488 .39901 .88655 .39556 .88193 .38884 Mtetra
.65 .75 .923 r
.25789 .57635 .2641 .58177 .27349 .57877 .26729 .57353 Mtetra
.651 .757 .928 r
.26729 .57353 .27349 .57877 .28291 .57571 .27672 .57067 Mtetra
.653 .766 .932 r
.27672 .57067 .28291 .57571 .29238 .57257 .28619 .56773 Mtetra
.659 .776 .936 r
.28619 .56773 .29238 .57257 .30188 .5693 .2957 .56463 Mtetra
.668 .786 .937 r
.2957 .56463 .30188 .5693 .31143 .56584 .30526 .56131 Mtetra
.679 .794 .935 r
.30526 .56131 .31143 .56584 .32102 .56226 .31487 .55771 Mtetra
.694 .796 .929 r
.31487 .55771 .32102 .56226 .33064 .55854 .32454 .55375 Mtetra
.702 .79 .919 r
.32454 .55375 .33064 .55854 .34029 .55489 .33424 .54956 Mtetra
.707 .771 .902 r
.33424 .54956 .34029 .55489 .34996 .55149 .34399 .54516 Mtetra
.693 .736 .884 r
.34399 .54516 .34996 .55149 .35964 .54869 .35375 .54105 Mtetra
.667 .691 .863 r
.35375 .54105 .35964 .54869 .3693 .54685 .3635 .53758 Mtetra
.622 .634 .842 r
.3635 .53758 .3693 .54685 .37896 .54603 .37323 .53538 Mtetra
.561 .577 .828 r
.37323 .53538 .37896 .54603 .38862 .54639 .38292 .53503 Mtetra
.508 .537 .821 r
.38292 .53503 .38862 .54639 .39834 .54683 .39261 .53618 Mtetra
.441 .516 .839 r
.39261 .53618 .39834 .54683 .40813 .54655 .40231 .53862 Mtetra
.451 .594 .903 r
.40231 .53862 .40813 .54655 .41807 .54347 .41211 .53994 Mtetra
.528 .801 .996 r
.41211 .53994 .41807 .54347 .42817 .53619 .42207 .53837 Mtetra
.601 .947 .803 r
.42207 .53837 .42817 .53619 .43835 .52596 .43222 .53165 Mtetra
.725 .936 .611 r
.43222 .53165 .43835 .52596 .44857 .51388 .44253 .51885 Mtetra
.797 .968 .661 r
.44253 .51885 .44857 .51388 .45869 .50566 .45283 .50551 Mtetra
.877 .959 .852 r
.45283 .50551 .45869 .50566 .46871 .50423 .46305 .49493 Mtetra
.676 .66 .827 r
.46305 .49493 .46871 .50423 .47871 .50778 .47317 .49074 Mtetra
.469 .439 .742 r
.47317 .49074 .47871 .50778 .48874 .51491 .48322 .49435 Mtetra
.421 .379 .707 r
.48322 .49435 .48874 .51491 .4989 .52007 .49333 .50068 Mtetra
.41 .382 .717 r
.49333 .50068 .4989 .52007 .50916 .52062 .50353 .50706 Mtetra
.435 .463 .79 r
.50353 .50706 .50916 .52062 .51949 .51723 .51384 .51073 Mtetra
.511 .676 .939 r
.51384 .51073 .51949 .51723 .52986 .51058 .52424 .51052 Mtetra
.3 .794 .858 r
.52424 .51052 .52986 .51058 .54024 .50369 .53468 .50832 Mtetra
.084 0 0 r
.53468 .50832 .54024 .50369 .55064 .49809 .54516 .50494 Mtetra
.232 0 0 r
.54516 .50494 .55064 .49809 .5611 .49483 .55569 .50168 Mtetra
.24 0 0 r
.55569 .50168 .5611 .49483 .57163 .49393 .56626 .49852 Mtetra
0 0 0 r
.56626 .49852 .57163 .49393 .58224 .49433 .57685 .49419 Mtetra
.689 .973 .918 r
.57685 .49419 .58224 .49433 .59291 .49451 .58743 .48784 Mtetra
.817 .774 .812 r
.58743 .48784 .59291 .49451 .60356 .49141 .59795 .47758 Mtetra
.772 .643 .719 r
.59795 .47758 .60356 .49141 .61415 .48432 .6084 .46455 Mtetra
.729 .577 .685 r
.6084 .46455 .61415 .48432 .62461 .47256 .61882 .45153 Mtetra
.696 .552 .686 r
.61882 .45153 .62461 .47256 .63499 .45877 .62931 .44124 Mtetra
.605 .521 .733 r
.62931 .44124 .63499 .45877 .64548 .44859 .64007 .43885 Mtetra
.351 .492 .86 r
.64007 .43885 .64548 .44859 .65617 .44344 .65114 .44295 Mtetra
.555 0 0 r
.65114 .44295 .65617 .44344 .66718 .4452 .66241 .44989 Mtetra
.625 .136 .071 r
.66241 .44989 .66718 .4452 .67846 .45092 .67378 .45633 Mtetra
.392 0 0 r
.67378 .45633 .67846 .45092 .68975 .45478 .68495 .45657 Mtetra
.344 .806 .698 r
.68495 .45657 .68975 .45478 .70097 .45564 .69591 .45155 Mtetra
.804 .873 .897 r
.69591 .45155 .70097 .45564 .71202 .45221 .70675 .44356 Mtetra
.78 .73 .806 r
.70675 .44356 .71202 .45221 .72294 .44589 .71752 .43439 Mtetra
.729 .658 .779 r
.71752 .43439 .72294 .44589 .73383 .43882 .72839 .42654 Mtetra
.697 .632 .78 r
.72839 .42654 .73383 .43882 .74475 .43182 .73937 .42021 Mtetra
.664 .627 .802 r
.73937 .42021 .74475 .43182 .75577 .42602 .7505 .41578 Mtetra
.638 .64 .836 r
.7505 .41578 .75577 .42602 .7669 .42127 .76177 .41266 Mtetra
.62 .671 .877 r
.76177 .41266 .7669 .42127 .77815 .4175 .77314 .41021 Mtetra
.605 .704 .914 r
.77314 .41021 .77815 .4175 .78948 .41437 .78459 .40806 Mtetra
.606 .739 .939 r
.78459 .40806 .78948 .41437 .80089 .41148 .79608 .40569 Mtetra
.611 .763 .952 r
.79608 .40569 .80089 .41148 .81236 .40867 .8076 .40309 Mtetra
.625 .777 .954 r
.8076 .40309 .81236 .40867 .82386 .40572 .81914 .40011 Mtetra
.637 .782 .951 r
.81914 .40011 .82386 .40572 .8354 .40263 .8307 .39683 Mtetra
.648 .78 .944 r
.8307 .39683 .8354 .40263 .84698 .39935 .84229 .39333 Mtetra
.655 .775 .937 r
.84229 .39333 .84698 .39935 .85859 .39593 .85391 .38965 Mtetra
.659 .768 .93 r
.85391 .38965 .85859 .39593 .87024 .39242 .86557 .38588 Mtetra
.66 .76 .924 r
.86557 .38588 .87024 .39242 .88193 .38884 .87727 .38207 Mtetra
.642 .748 .926 r
.25164 .57089 .25789 .57635 .26729 .57353 .26104 .56823 Mtetra
.64 .754 .931 r
.26104 .56823 .26729 .57353 .27672 .57067 .27048 .56559 Mtetra
.641 .763 .937 r
.27048 .56559 .27672 .57067 .28619 .56773 .27995 .56289 Mtetra
.644 .774 .942 r
.27995 .56289 .28619 .56773 .2957 .56463 .28946 .56009 Mtetra
.649 .788 .948 r
.28946 .56009 .2957 .56463 .30526 .56131 .29902 .55712 Mtetra
.661 .805 .952 r
.29902 .55712 .30526 .56131 .31487 .55771 .30864 .55385 Mtetra
.679 .823 .952 r
.30864 .55385 .31487 .55771 .32454 .55375 .31831 .55014 Mtetra
.7 .837 .949 r
.31831 .55014 .32454 .55375 .33424 .54956 .32805 .54594 Mtetra
.724 .84 .936 r
.32805 .54594 .33424 .54956 .34399 .54516 .33785 .54112 Mtetra
.733 .825 .922 r
.33785 .54112 .34399 .54516 .35375 .54105 .34768 .53605 Mtetra
.731 .79 .899 r
.34768 .53605 .35375 .54105 .3635 .53758 .35754 .53089 Mtetra
.696 .729 .875 r
.35754 .53089 .3635 .53758 .37323 .53538 .36739 .52659 Mtetra
.639 .654 .849 r
.36739 .52659 .37323 .53538 .38292 .53503 .3772 .52386 Mtetra
.568 .572 .818 r
.3772 .52386 .38292 .53503 .39261 .53618 .38695 .52331 Mtetra
.479 .496 .798 r
.38695 .52331 .39261 .53618 .40231 .53862 .39665 .52549 Mtetra
.432 .465 .794 r
.39665 .52549 .40231 .53862 .41211 .53994 .40637 .5289 Mtetra
.393 .483 .833 r
.40637 .5289 .41211 .53994 .42207 .53837 .41617 .5324 Mtetra
.525 .699 .949 r
.41617 .5324 .42207 .53837 .43222 .53165 .42616 .53181 Mtetra
.755 .981 .913 r
.42616 .53181 .43222 .53165 .44253 .51885 .43638 .52471 Mtetra
.642 .898 .573 r
.43638 .52471 .44253 .51885 .45283 .50551 .44672 .51294 Mtetra
.692 .886 .51 r
.44672 .51294 .45283 .50551 .46305 .49493 .45711 .49807 Mtetra
.813 .994 .754 r
.45711 .49807 .46305 .49493 .47317 .49074 .46741 .48664 Mtetra
.718 .834 .937 r
.46741 .48664 .47317 .49074 .48322 .49435 .4776 .48182 Mtetra
.539 .537 .801 r
.4776 .48182 .48322 .49435 .49333 .50068 .48776 .48225 Mtetra
.445 .413 .728 r
.48776 .48225 .49333 .50068 .50353 .50706 .49795 .48698 Mtetra
.452 .404 .714 r
.49795 .48698 .50353 .50706 .51384 .51073 .50822 .49195 Mtetra
.489 .438 .727 r
.50822 .49195 .51384 .51073 .52424 .51052 .51859 .49514 Mtetra
.531 .497 .764 r
.51859 .49514 .52424 .51052 .53468 .50832 .52903 .49618 Mtetra
.593 .576 .804 r
.52903 .49618 .53468 .50832 .54516 .50494 .53953 .49472 Mtetra
.646 .637 .826 r
.53953 .49472 .54516 .50494 .55569 .50168 .55007 .49143 Mtetra
.69 .656 .811 r
.55007 .49143 .55569 .50168 .56626 .49852 .56062 .4863 Mtetra
.72 .638 .765 r
.56062 .4863 .56626 .49852 .57685 .49419 .57118 .47865 Mtetra
.724 .604 .722 r
.57118 .47865 .57685 .49419 .58743 .48784 .5817 .46883 Mtetra
.721 .577 .693 r
.5817 .46883 .58743 .48784 .59795 .47758 .59219 .45718 Mtetra
.711 .564 .686 r
.59219 .45718 .59795 .47758 .6084 .46455 .60267 .44574 Mtetra
.671 .55 .709 r
.60267 .44574 .6084 .46455 .61882 .45153 .61326 .43863 Mtetra
.6 .57 .791 r
.61326 .43863 .61882 .45153 .62931 .44124 .62402 .43683 Mtetra
0 .412 .833 r
.62402 .43683 .62931 .44124 .64007 .43885 .63507 .44173 Mtetra
.674 .167 .027 r
.63507 .44173 .64007 .43885 .65114 .44295 .64634 .45017 Mtetra
.6 .151 .156 r
.64634 .45017 .65114 .44295 .66241 .44989 .65761 .4555 Mtetra
.412 0 0 r
.65761 .4555 .66241 .44989 .67378 .45633 .66877 .45608 Mtetra
.645 .963 .911 r
.66877 .45608 .67378 .45633 .68495 .45657 .67969 .45002 Mtetra
.822 .791 .823 r
.67969 .45002 .68495 .45657 .69591 .45155 .69042 .43976 Mtetra
.761 .668 .759 r
.69042 .43976 .69591 .45155 .70675 .44356 .70116 .42956 Mtetra
.725 .624 .745 r
.70116 .42956 .70675 .44356 .71752 .43439 .71196 .42061 Mtetra
.684 .606 .762 r
.71196 .42061 .71752 .43439 .72839 .42654 .72294 .41444 Mtetra
.65 .613 .798 r
.72294 .41444 .72839 .42654 .73937 .42021 .73409 .41051 Mtetra
.615 .642 .854 r
.73409 .41051 .73937 .42021 .7505 .41578 .74539 .40821 Mtetra
.577 .682 .912 r
.74539 .40821 .7505 .41578 .76177 .41266 .75681 .40678 Mtetra
.559 .735 .958 r
.75681 .40678 .76177 .41266 .77314 .41021 .76829 .40529 Mtetra
.552 .772 .98 r
.76829 .40529 .77314 .41021 .78459 .40806 .77981 .40352 Mtetra
.578 .801 .984 r
.77981 .40352 .78459 .40806 .79608 .40569 .79133 .40113 Mtetra
.605 .812 .98 r
.79133 .40113 .79608 .40569 .8076 .40309 .80286 .39822 Mtetra
.633 .811 .969 r
.80286 .39822 .8076 .40309 .81914 .40011 .81441 .39485 Mtetra
.651 .803 .956 r
.81441 .39485 .81914 .40011 .8307 .39683 .82597 .39116 Mtetra
.66 .791 .945 r
.82597 .39116 .8307 .39683 .84229 .39333 .83757 .38729 Mtetra
.666 .781 .935 r
.83757 .38729 .84229 .39333 .85391 .38965 .8492 .38331 Mtetra
.668 .771 .927 r
.8492 .38331 .85391 .38965 .86557 .38588 .86087 .37927 Mtetra
.667 .763 .922 r
.86087 .37927 .86557 .38588 .87727 .38207 .87259 .37524 Mtetra
.638 .747 .927 r
.24535 .5654 .25164 .57089 .26104 .56823 .25476 .56281 Mtetra
.634 .749 .931 r
.25476 .56281 .26104 .56823 .27048 .56559 .26421 .5603 Mtetra
.631 .754 .936 r
.26421 .5603 .27048 .56559 .27995 .56289 .27368 .55781 Mtetra
.628 .762 .943 r
.27368 .55781 .27995 .56289 .28946 .56009 .28319 .55533 Mtetra
.625 .774 .952 r
.28319 .55533 .28946 .56009 .29902 .55712 .29274 .55286 Mtetra
.628 .796 .963 r
.29274 .55286 .29902 .55712 .30864 .55385 .30234 .5502 Mtetra
.637 .824 .972 r
.30234 .5502 .30864 .55385 .31831 .55014 .312 .54723 Mtetra
.657 .86 .977 r
.312 .54723 .31831 .55014 .32805 .54594 .32172 .54368 Mtetra
.692 .893 .97 r
.32172 .54368 .32805 .54594 .33785 .54112 .33153 .53929 Mtetra
.728 .913 .957 r
.33153 .53929 .33785 .54112 .34768 .53605 .34141 .53403 Mtetra
.771 .908 .934 r
.34141 .53403 .34768 .53605 .35754 .53089 .35136 .52777 Mtetra
.779 .865 .913 r
.35136 .52777 .35754 .53089 .36739 .52659 .36135 .52129 Mtetra
.756 .786 .877 r
.36135 .52129 .36739 .52659 .3772 .52386 .37133 .51511 Mtetra
.686 .674 .833 r
.37133 .51511 .3772 .52386 .38695 .52331 .38126 .5107 Mtetra
.595 .564 .789 r
.38126 .5107 .38695 .52331 .39665 .52549 .3911 .50921 Mtetra
.507 .469 .749 r
.3911 .50921 .39665 .52549 .40637 .5289 .40086 .51114 Mtetra
.403 .39 .731 r
.40086 .51114 .40637 .5289 .41617 .5324 .41056 .51679 Mtetra
.365 .391 .755 r
.41056 .51679 .41617 .5324 .42616 .53181 .42034 .52269 Mtetra
.33 .498 .873 r
.42034 .52269 .42616 .53181 .43638 .52471 .43027 .52631 Mtetra
.223 .736 .707 r
.43027 .52631 .43638 .52471 .44672 .51294 .44045 .52333 Mtetra
0 0 0 r
.44045 .52333 .44672 .51294 .45711 .49807 .45086 .51179 Mtetra
.45086 .51179 .45711 .49807 .46741 .48664 .46133 .49686 Mtetra
.46133 .49686 .46741 .48664 .4776 .48182 .47176 .48166 Mtetra
.878 .963 .849 r
.47176 .48166 .4776 .48182 .48776 .48225 .4821 .47085 Mtetra
.668 .622 .794 r
.4821 .47085 .48776 .48225 .49795 .48698 .49237 .46642 Mtetra
.57 .475 .708 r
.49237 .46642 .49795 .48698 .50822 .49195 .50265 .4658 Mtetra
.533 .424 .675 r
.50265 .4658 .50822 .49195 .51859 .49514 .51297 .46749 Mtetra
.542 .424 .668 r
.51297 .46749 .51859 .49514 .52903 .49618 .52337 .46869 Mtetra
.568 .442 .669 r
.52337 .46869 .52903 .49618 .53953 .49472 .53382 .46793 Mtetra
.601 .467 .67 r
.53382 .46793 .53953 .49472 .55007 .49143 .54432 .4646 Mtetra
.63 .486 .667 r
.54432 .4646 .55007 .49143 .56062 .4863 .55483 .45868 Mtetra
.647 .495 .662 r
.55483 .45868 .56062 .4863 .57118 .47865 .56535 .45078 Mtetra
.651 .496 .66 r
.56535 .45078 .57118 .47865 .5817 .46883 .57587 .44238 Mtetra
.632 .489 .669 r
.57587 .44238 .5817 .46883 .59219 .45718 .58643 .43629 Mtetra
.596 .492 .706 r
.58643 .43629 .59219 .45718 .60267 .44574 .59711 .43404 Mtetra
.385 .47 .824 r
.59711 .43404 .60267 .44574 .61326 .43863 .608 .43823 Mtetra
.645 .087 0 r
.608 .43823 .61326 .43863 .62402 .43683 .61911 .44691 Mtetra
.658 .252 .264 r
.61911 .44691 .62402 .43683 .63507 .44173 .63034 .45536 Mtetra
.591 .214 .296 r
.63034 .45536 .63507 .44173 .64634 .45017 .64157 .4604 Mtetra
.327 0 .113 r
.64157 .4604 .64634 .45017 .65761 .4555 .65256 .45675 Mtetra
.792 .998 .802 r
.65256 .45675 .65761 .4555 .66877 .45608 .66331 .44635 Mtetra
.814 .718 .759 r
.66331 .44635 .66877 .45608 .67969 .45002 .67395 .4336 Mtetra
.748 .613 .708 r
.67395 .4336 .67969 .45002 .69042 .43976 .68458 .42108 Mtetra
.691 .565 .708 r
.68458 .42108 .69042 .43976 .70116 .42956 .69539 .41233 Mtetra
.651 .554 .731 r
.69539 .41233 .70116 .42956 .71196 .42061 .7064 .40708 Mtetra
.608 .57 .786 r
.7064 .40708 .71196 .42061 .72294 .41444 .71762 .40483 Mtetra
.551 .612 .867 r
.71762 .40483 .72294 .41444 .73409 .41051 .72902 .4044 Mtetra
.485 .691 .958 r
.72902 .4044 .73409 .41051 .74539 .40821 .7405 .4043 Mtetra
.41 .747 .994 r
.7405 .4043 .74539 .40821 .75681 .40678 .75204 .40398 Mtetra
.425 .803 .992 r
.75204 .40398 .75681 .40678 .76829 .40529 .76357 .40264 Mtetra
.487 .842 .994 r
.76357 .40264 .76829 .40529 .77981 .40352 .77509 .40039 Mtetra
.574 .862 .996 r
.77509 .40039 .77981 .40352 .79133 .40113 .7866 .39727 Mtetra
.631 .855 .984 r
.7866 .39727 .79133 .40113 .80286 .39822 .79811 .39355 Mtetra
.66 .832 .966 r
.79811 .39355 .80286 .39822 .81441 .39485 .80964 .38949 Mtetra
.673 .81 .948 r
.80964 .38949 .81441 .39485 .82597 .39116 .82119 .38524 Mtetra
.675 .79 .935 r
.82119 .38524 .82597 .39116 .83757 .38729 .83279 .38099 Mtetra
.675 .777 .927 r
.83279 .38099 .83757 .38729 .8492 .38331 .84443 .37674 Mtetra
.674 .767 .921 r
.84443 .37674 .8492 .38331 .86087 .37927 .85612 .37252 Mtetra
.671 .761 .918 r
.85612 .37252 .86087 .37927 .87259 .37524 .86786 .36837 Mtetra
.643 .748 .926 r
.23902 .55988 .24535 .5654 .25476 .56281 .24846 .55716 Mtetra
.639 .743 .924 r
.24846 .55716 .25476 .56281 .26421 .5603 .25793 .55454 Mtetra
.634 .739 .924 r
.25793 .55454 .26421 .5603 .27368 .55781 .26742 .55202 Mtetra
.627 .736 .926 r
.26742 .55202 .27368 .55781 .28319 .55533 .27695 .54963 Mtetra
.617 .737 .932 r
.27695 .54963 .28319 .55533 .29274 .55286 .28649 .54743 Mtetra
.611 .747 .941 r
.28649 .54743 .29274 .55286 .30234 .5502 .29608 .54529 Mtetra
.605 .765 .956 r
.29608 .54529 .30234 .5502 .312 .54723 .3057 .54315 Mtetra
.612 .802 .973 r
.3057 .54315 .312 .54723 .32172 .54368 .31538 .54067 Mtetra
.629 .851 .984 r
.31538 .54067 .32172 .54368 .33153 .53929 .32514 .53756 Mtetra
.66 .909 .979 r
.32514 .53756 .33153 .53929 .34141 .53403 .335 .53343 Mtetra
.712 .953 .951 r
.335 .53343 .34141 .53403 .35136 .52777 .34496 .52786 Mtetra
.755 .975 .922 r
.34496 .52786 .35136 .52777 .36135 .52129 .355 .52108 Mtetra
.811 .966 .905 r
.355 .52108 .36135 .52129 .37133 .51511 .36512 .51311 Mtetra
.813 .908 .906 r
.36512 .51311 .37133 .51511 .38126 .5107 .37523 .50545 Mtetra
.758 .791 .879 r
.37523 .50545 .38126 .5107 .3911 .50921 .38529 .49918 Mtetra
.642 .632 .824 r
.38529 .49918 .3911 .50921 .40086 .51114 .39524 .49615 Mtetra
.51 .486 .766 r
.39524 .49615 .40086 .51114 .41056 .51679 .40506 .49772 Mtetra
.427 .394 .72 r
.40506 .49772 .41056 .51679 .42034 .52269 .41483 .50296 Mtetra
.349 .339 .707 r
.41483 .50296 .42034 .52269 .43027 .52631 .4246 .51094 Mtetra
.398 .417 .763 r
.4246 .51094 .43027 .52631 .44045 .52333 .43457 .51588 Mtetra
.585 .678 .904 r
.43457 .51588 .44045 .52333 .45086 .51179 .44477 .51443 Mtetra
.631 .953 .772 r
.44477 .51443 .45086 .51179 .46133 .49686 .45515 .50662 Mtetra
0 0 0 r
.45515 .50662 .46133 .49686 .47176 .48166 .46565 .49301 Mtetra
.46565 .49301 .47176 .48166 .4821 .47085 .47613 .47928 Mtetra
.47613 .47928 .4821 .47085 .49237 .46642 .48655 .46821 Mtetra
.672 .974 .822 r
.48655 .46821 .49237 .46642 .50265 .4658 .49693 .46058 Mtetra
.684 .79 .93 r
.49693 .46058 .50265 .4658 .51297 .46749 .5073 .45653 Mtetra
.629 .614 .816 r
.5073 .45653 .51297 .46749 .52337 .46869 .51771 .45377 Mtetra
.613 .55 .759 r
.51771 .45377 .52337 .46869 .53382 .46793 .52816 .45122 Mtetra
.624 .538 .737 r
.52816 .45122 .53382 .46793 .54432 .4646 .53865 .44786 Mtetra
.638 .546 .735 r
.53865 .44786 .54432 .4646 .55483 .45868 .54917 .44367 Mtetra
.641 .565 .754 r
.54917 .44367 .55483 .45868 .56535 .45078 .55973 .43969 Mtetra
.626 .612 .817 r
.55973 .43969 .56535 .45078 .57587 .44238 .57035 .437 Mtetra
.388 .666 .97 r
.57035 .437 .57587 .44238 .58643 .43629 .58107 .43793 Mtetra
.511 0 0 r
.58107 .43793 .58643 .43629 .59711 .43404 .59194 .44234 Mtetra
.641 .214 .215 r
.59194 .44234 .59711 .43404 .608 .43823 .60297 .44948 Mtetra
.63 .234 .273 r
.60297 .44948 .608 .43823 .61911 .44691 .6141 .45653 Mtetra
.492 .071 .169 r
.6141 .45653 .61911 .44691 .63034 .45536 .62517 .45774 Mtetra
.319 .781 .652 r
.62517 .45774 .63034 .45536 .64157 .4604 .6361 .45248 Mtetra
.824 .755 .787 r
.6361 .45248 .64157 .4604 .65256 .45675 .64681 .4407 Mtetra
.773 .628 .7 r
.64681 .4407 .65256 .45675 .66331 .44635 .65738 .42579 Mtetra
.717 .568 .686 r
.65738 .42579 .66331 .44635 .67395 .4336 .66804 .41365 Mtetra
.681 .551 .7 r
.66804 .41365 .67395 .4336 .68458 .42108 .67886 .40523 Mtetra
.631 .555 .751 r
.67886 .40523 .68458 .42108 .69539 .41233 .68994 .4015 Mtetra
.555 .587 .841 r
.68994 .4015 .69539 .41233 .7064 .40708 .70123 .40111 Mtetra
.405 .655 .96 r
.70123 .40111 .7064 .40708 .71762 .40483 .71268 .40216 Mtetra
.146 .635 .917 r
.71268 .40216 .71762 .40483 .72902 .4044 .72423 .40354 Mtetra
.079 .634 .81 r
.72423 .40354 .72902 .4044 .7405 .4043 .73578 .40372 Mtetra
.184 .715 .836 r
.73578 .40372 .7405 .4043 .75204 .40398 .74732 .40264 Mtetra
.414 .846 .946 r
.74732 .40264 .75204 .40398 .76357 .40264 .75881 .40008 Mtetra
.581 .888 .99 r
.75881 .40008 .76357 .40264 .77509 .40039 .77028 .39646 Mtetra
.66 .862 .976 r
.77028 .39646 .77509 .40039 .7866 .39727 .78174 .39219 Mtetra
.688 .825 .949 r
.78174 .39219 .7866 .39727 .79811 .39355 .79321 .38755 Mtetra
.689 .792 .928 r
.79321 .38755 .79811 .39355 .80964 .38949 .80473 .38291 Mtetra
.687 .771 .915 r
.80473 .38291 .80964 .38949 .82119 .38524 .81629 .37832 Mtetra
.679 .758 .91 r
.81629 .37832 .82119 .38524 .83279 .38099 .82791 .37393 Mtetra
.674 .752 .909 r
.82791 .37393 .83279 .38099 .84443 .37674 .83958 .36967 Mtetra
.67 .751 .911 r
.83958 .36967 .84443 .37674 .85612 .37252 .85131 .36551 Mtetra
.667 .752 .914 r
.85131 .36551 .85612 .37252 .86786 .36837 .8631 .36144 Mtetra
.656 .751 .92 r
.23264 .55431 .23902 .55988 .24846 .55716 .24213 .55128 Mtetra
.653 .74 .913 r
.24213 .55128 .24846 .55716 .25793 .55454 .25164 .5483 Mtetra
.648 .728 .907 r
.25164 .5483 .25793 .55454 .26742 .55202 .26118 .54546 Mtetra
.638 .715 .903 r
.26118 .54546 .26742 .55202 .27695 .54963 .27074 .54285 Mtetra
.624 .704 .903 r
.27074 .54285 .27695 .54963 .28649 .54743 .2803 .54056 Mtetra
.609 .697 .906 r
.2803 .54056 .28649 .54743 .29608 .54529 .28989 .53861 Mtetra
.588 .696 .917 r
.28989 .53861 .29608 .54529 .3057 .54315 .29949 .53708 Mtetra
.574 .713 .937 r
.29949 .53708 .3057 .54315 .31538 .54067 .30912 .5357 Mtetra
.554 .749 .968 r
.30912 .5357 .31538 .54067 .32514 .53756 .31879 .53434 Mtetra
.549 .822 .997 r
.31879 .53434 .32514 .53756 .335 .53343 .32855 .53237 Mtetra
.539 .895 .975 r
.32855 .53237 .335 .53343 .34496 .52786 .33841 .52926 Mtetra
.515 .915 .849 r
.33841 .52926 .34496 .52786 .355 .52108 .3484 .52441 Mtetra
.558 .917 .731 r
.3484 .52441 .355 .52108 .36512 .51311 .35854 .51724 Mtetra
.633 .937 .701 r
.35854 .51724 .36512 .51311 .37523 .50545 .36876 .50832 Mtetra
.803 .998 .795 r
.36876 .50832 .37523 .50545 .38529 .49918 .37906 .49799 Mtetra
.858 .928 .872 r
.37906 .49799 .38529 .49918 .39524 .49615 .38932 .48834 Mtetra
.756 .721 .819 r
.38932 .48834 .39524 .49615 .40506 .49772 .39949 .48097 Mtetra
.612 .528 .735 r
.39949 .48097 .40506 .49772 .41483 .50296 .40951 .47829 Mtetra
.495 .403 .68 r
.40951 .47829 .41483 .50296 .4246 .51094 .41937 .48182 Mtetra
.429 .339 .653 r
.41937 .48182 .4246 .51094 .43457 .51588 .42918 .48974 Mtetra
.348 .297 .659 r
.42918 .48974 .43457 .51588 .44477 .51443 .43903 .50039 Mtetra
.273 .359 .77 r
.43903 .50039 .44477 .51443 .45515 .50662 .44908 .50752 Mtetra
.124 0 0 r
.44908 .50752 .45515 .50662 .46565 .49301 .45938 .50772 Mtetra
.298 0 .186 r
.45938 .50772 .46565 .49301 .47613 .47928 .46984 .50158 Mtetra
.251 0 .26 r
.46984 .50158 .47613 .47928 .48655 .46821 .48039 .48991 Mtetra
.212 0 .24 r
.48039 .48991 .48655 .46821 .49693 .46058 .49094 .47723 Mtetra
.141 0 .151 r
.49094 .47723 .49693 .46058 .5073 .45653 .50147 .46586 Mtetra
0 0 0 r
.50147 .46586 .5073 .45653 .51771 .45377 .51197 .45685 Mtetra
.373 .807 .639 r
.51197 .45685 .51771 .45377 .52816 .45122 .52248 .45086 Mtetra
.463 .883 .922 r
.52248 .45086 .52816 .45122 .53865 .44786 .53301 .44747 Mtetra
.146 .688 .813 r
.53301 .44747 .53865 .44786 .54917 .44367 .5436 .4467 Mtetra
.434 0 0 r
.5436 .4467 .54917 .44367 .55973 .43969 .55428 .44897 Mtetra
.587 .167 .213 r
.55428 .44897 .55973 .43969 .57035 .437 .56506 .45362 Mtetra
.602 .246 .338 r
.56506 .45362 .57035 .437 .58107 .43793 .57596 .45964 Mtetra
.582 .251 .374 r
.57596 .45964 .58107 .43793 .59194 .44234 .58695 .46467 Mtetra
.502 .181 .354 r
.58695 .46467 .59194 .44234 .60297 .44948 .59791 .46413 Mtetra
.285 0 .188 r
.59791 .46413 .60297 .44948 .6141 .45653 .60877 .45717 Mtetra
.911 .978 .78 r
.60877 .45717 .6141 .45653 .62517 .45774 .61944 .44317 Mtetra
.807 .656 .695 r
.61944 .44317 .62517 .45774 .6361 .45248 .62997 .42554 Mtetra
.708 .536 .654 r
.62997 .42554 .6361 .45248 .64681 .4407 .64055 .41064 Mtetra
.661 .497 .651 r
.64055 .41064 .64681 .4407 .65738 .42579 .65126 .40019 Mtetra
.61 .479 .677 r
.65126 .40019 .65738 .42579 .66804 .41365 .66224 .39606 Mtetra
.541 .486 .744 r
.66224 .39606 .66804 .41365 .67886 .40523 .67349 .39673 Mtetra
.366 .544 .897 r
.67349 .39673 .67886 .40523 .68994 .4015 .68492 .39975 Mtetra
0 .381 .688 r
.68492 .39975 .68994 .4015 .70123 .40111 .69648 .40349 Mtetra
.389 0 0 r
.69648 .40349 .70123 .40111 .71268 .40216 .70806 .4058 Mtetra
.331 0 0 r
.70806 .4058 .71268 .40216 .72423 .40354 .71961 .40634 Mtetra
.094 0 0 r
.71961 .40634 .72423 .40354 .73578 .40372 .73109 .40448 Mtetra
.301 .793 .77 r
.73109 .40448 .73578 .40372 .74732 .40264 .74251 .40082 Mtetra
.626 .93 .969 r
.74251 .40082 .74732 .40264 .75881 .40008 .75389 .39598 Mtetra
.716 .872 .955 r
.75389 .39598 .75881 .40008 .77028 .39646 .76526 .3905 Mtetra
.718 .802 .917 r
.76526 .3905 .77028 .39646 .78174 .39219 .77667 .38503 Mtetra
.708 .759 .892 r
.77667 .38503 .78174 .39219 .79321 .38755 .78812 .37971 Mtetra
.692 .734 .883 r
.78812 .37971 .79321 .38755 .80473 .38291 .79965 .37482 Mtetra
.681 .722 .881 r
.79965 .37482 .80473 .38291 .81629 .37832 .81124 .37027 Mtetra
.67 .72 .886 r
.81124 .37027 .81629 .37832 .82791 .37393 .82291 .36606 Mtetra
.663 .723 .894 r
.82291 .36606 .82791 .37393 .83958 .36967 .83465 .36208 Mtetra
.658 .731 .903 r
.83465 .36208 .83958 .36967 .85131 .36551 .84645 .35824 Mtetra
.656 .741 .912 r
.84645 .35824 .85131 .36551 .8631 .36144 .85831 .35446 Mtetra
.671 .755 .914 r
.22623 .54871 .23264 .55431 .24213 .55128 .23576 .54529 Mtetra
.671 .742 .904 r
.23576 .54529 .24213 .55128 .25164 .5483 .24533 .54186 Mtetra
.666 .727 .895 r
.24533 .54186 .25164 .5483 .26118 .54546 .25493 .53852 Mtetra
.657 .71 .886 r
.25493 .53852 .26118 .54546 .27074 .54285 .26454 .53537 Mtetra
.646 .691 .878 r
.26454 .53537 .27074 .54285 .2803 .54056 .27416 .53252 Mtetra
.629 .67 .871 r
.27416 .53252 .2803 .54056 .28989 .53861 .28379 .53011 Mtetra
.605 .65 .868 r
.28379 .53011 .28989 .53861 .29949 .53708 .29341 .52831 Mtetra
.583 .634 .868 r
.29341 .52831 .29949 .53708 .30912 .5357 .30304 .52709 Mtetra
.553 .626 .879 r
.30304 .52709 .30912 .5357 .31879 .53434 .31268 .52653 Mtetra
.538 .643 .901 r
.31268 .52653 .31879 .53434 .32855 .53237 .32235 .52613 Mtetra
.524 .691 .944 r
.32235 .52613 .32855 .53237 .33841 .52926 .33209 .52557 Mtetra
.539 .801 .994 r
.33209 .52557 .33841 .52926 .3484 .52441 .34194 .52387 Mtetra
.55 .913 .957 r
.34194 .52387 .3484 .52441 .35854 .51724 .35193 .52022 Mtetra
.485 .884 .73 r
.35193 .52022 .35854 .51724 .36876 .50832 .36208 .51407 Mtetra
.49 .831 .549 r
.36208 .51407 .36876 .50832 .37906 .49799 .37239 .50491 Mtetra
.53 .828 .5 r
.37239 .50491 .37906 .49799 .38932 .48834 .38278 .49388 Mtetra
.714 .942 .637 r
.38278 .49388 .38932 .48834 .39949 .48097 .3932 .48188 Mtetra
.844 .988 .858 r
.3932 .48188 .39949 .48097 .40951 .47829 .40353 .47204 Mtetra
.73 .76 .877 r
.40353 .47204 .40951 .47829 .41937 .48182 .41371 .46653 Mtetra
.542 .504 .762 r
.41371 .46653 .41937 .48182 .42918 .48974 .42373 .46691 Mtetra
.412 .359 .688 r
.42373 .46691 .42918 .48974 .43903 .50039 .43363 .47371 Mtetra
.405 .334 .664 r
.43363 .47371 .43903 .50039 .44908 .50752 .44359 .48204 Mtetra
.429 .357 .674 r
.44359 .48204 .44908 .50752 .45938 .50772 .4537 .48896 Mtetra
.498 .445 .729 r
.4537 .48896 .45938 .50772 .46984 .50158 .46399 .49148 Mtetra
.642 .639 .832 r
.46399 .49148 .46984 .50158 .48039 .48991 .47444 .4883 Mtetra
.745 .941 .948 r
.47444 .4883 .48039 .48991 .49094 .47723 .48498 .48204 Mtetra
0 0 0 r
.48498 .48204 .49094 .47723 .50147 .46586 .49554 .4742 Mtetra
.49554 .4742 .50147 .46586 .51197 .45685 .50612 .46694 Mtetra
.207 0 .035 r
.50612 .46694 .51197 .45685 .52248 .45086 .51671 .46142 Mtetra
.328 0 .111 r
.51671 .46142 .52248 .45086 .53301 .44747 .52732 .45803 Mtetra
.415 .007 .154 r
.52732 .45803 .53301 .44747 .5436 .4467 .53799 .45676 Mtetra
.471 .055 .169 r
.53799 .45676 .5436 .4467 .55428 .44897 .54872 .45725 Mtetra
.474 .032 .117 r
.54872 .45725 .55428 .44897 .56506 .45362 .55953 .45834 Mtetra
.312 0 0 r
.55953 .45834 .56506 .45362 .57596 .45964 .57039 .45785 Mtetra
.568 .899 .982 r
.57039 .45785 .57596 .45964 .58695 .46467 .58126 .45426 Mtetra
.762 .689 .781 r
.58126 .45426 .58695 .46467 .59791 .46413 .59205 .4449 Mtetra
.74 .589 .688 r
.59205 .4449 .59791 .46413 .60877 .45717 .60273 .43106 Mtetra
.715 .543 .656 r
.60273 .43106 .60877 .45717 .61944 .44317 .61335 .41575 Mtetra
.698 .528 .654 r
.61335 .41575 .61944 .44317 .62997 .42554 .62398 .40197 Mtetra
.652 .514 .682 r
.62398 .40197 .62997 .42554 .64055 .41064 .63481 .39467 Mtetra
.582 .526 .757 r
.63481 .39467 .64055 .41064 .65126 .40019 .64588 .39338 Mtetra
.284 .554 .927 r
.64588 .39338 .65126 .40019 .66224 .39606 .65718 .39652 Mtetra
.495 0 0 r
.65718 .39652 .66224 .39606 .67349 .39673 .66868 .4019 Mtetra
.553 .054 .025 r
.66868 .4019 .67349 .39673 .68492 .39975 .68025 .4063 Mtetra
.499 .022 .054 r
.68025 .4063 .68492 .39975 .69648 .40349 .69181 .40882 Mtetra
.33 0 0 r
.69181 .40882 .69648 .40349 .70806 .4058 .7033 .40825 Mtetra
0 0 0 r
.7033 .40825 .70806 .4058 .71961 .40634 .7147 .40511 Mtetra
.617 .941 .951 r
.7147 .40511 .71961 .40634 .73109 .40448 .72602 .39996 Mtetra
.749 .863 .932 r
.72602 .39996 .73109 .40448 .74251 .40082 .7373 .39362 Mtetra
.741 .768 .875 r
.7373 .39362 .74251 .40082 .75389 .39598 .7486 .3871 Mtetra
.723 .717 .844 r
.7486 .3871 .75389 .39598 .76526 .3905 .75994 .38074 Mtetra
.701 .688 .835 r
.75994 .38074 .76526 .3905 .77667 .38503 .77135 .37505 Mtetra
.685 .677 .837 r
.77135 .37505 .77667 .38503 .78812 .37971 .78285 .36995 Mtetra
.67 .676 .847 r
.78285 .36995 .78812 .37971 .79965 .37482 .79444 .36549 Mtetra
.66 .682 .86 r
.79444 .36549 .79965 .37482 .81124 .37027 .80611 .36148 Mtetra
.652 .693 .876 r
.80611 .36148 .81124 .37027 .82291 .36606 .81786 .35777 Mtetra
.646 .705 .89 r
.81786 .35777 .82291 .36606 .83465 .36208 .82967 .35427 Mtetra
.643 .719 .903 r
.82967 .35427 .83465 .36208 .84645 .35824 .84155 .35086 Mtetra
.642 .733 .914 r
.84155 .35086 .84645 .35824 .85831 .35446 .85348 .34743 Mtetra
.682 .757 .908 r
.21976 .54307 .22623 .54871 .23576 .54529 .22935 .53933 Mtetra
.685 .748 .899 r
.22935 .53933 .23576 .54529 .24533 .54186 .23897 .53549 Mtetra
.684 .735 .89 r
.23897 .53549 .24533 .54186 .25493 .53852 .24863 .53162 Mtetra
.68 .719 .879 r
.24863 .53162 .25493 .53852 .26454 .53537 .25831 .5278 Mtetra
.674 .699 .865 r
.25831 .5278 .26454 .53537 .27416 .53252 .26801 .52407 Mtetra
.66 .672 .851 r
.26801 .52407 .27416 .53252 .28379 .53011 .27772 .52066 Mtetra
.641 .643 .836 r
.27772 .52066 .28379 .53011 .29341 .52831 .28744 .51775 Mtetra
.615 .609 .822 r
.28744 .51775 .29341 .52831 .30304 .52709 .29713 .5156 Mtetra
.581 .577 .813 r
.29713 .5156 .30304 .52709 .31268 .52653 .3068 .5145 Mtetra
.548 .551 .809 r
.3068 .5145 .31268 .52653 .32235 .52613 .31645 .5144 Mtetra
.505 .535 .82 r
.31645 .5144 .32235 .52613 .33209 .52557 .32609 .51541 Mtetra
.474 .552 .855 r
.32609 .51541 .33209 .52557 .34194 .52387 .33578 .51678 Mtetra
.42 .616 .932 r
.33578 .51678 .34194 .52387 .35193 .52022 .34553 .51798 Mtetra
.302 .749 .961 r
.34553 .51798 .35193 .52022 .36208 .51407 .35543 .51761 Mtetra
0 0 0 r
.35543 .51761 .36208 .51407 .37239 .50491 .36551 .51455 Mtetra
.095 0 0 r
.36551 .51455 .37239 .50491 .38278 .49388 .37577 .50819 Mtetra
.068 0 .053 r
.37577 .50819 .38278 .49388 .3932 .48188 .38622 .49798 Mtetra
0 0 .05 r
.38622 .49798 .3932 .48188 .40353 .47204 .39677 .48494 Mtetra
0 0 0 r
.39677 .48494 .40353 .47204 .41371 .46653 .40737 .46999 Mtetra
.883 .99 .743 r
.40737 .46999 .41371 .46653 .42373 .46691 .4179 .45616 Mtetra
.771 .675 .757 r
.4179 .45616 .42373 .46691 .43363 .47371 .4283 .4457 Mtetra
.608 .466 .662 r
.4283 .4457 .43363 .47371 .44359 .48204 .43854 .44138 Mtetra
.522 .375 .623 r
.43854 .44138 .44359 .48204 .4537 .48896 .44863 .44433 Mtetra
.483 .341 .612 r
.44863 .44433 .4537 .48896 .46399 .49148 .45872 .45145 Mtetra
.448 .325 .619 r
.45872 .45145 .46399 .49148 .47444 .4883 .46888 .46064 Mtetra
.424 .344 .663 r
.46888 .46064 .47444 .4883 .48498 .48204 .47918 .46836 Mtetra
.392 .442 .793 r
.47918 .46836 .48498 .48204 .49554 .4742 .48963 .47277 Mtetra
0 .539 .777 r
.48963 .47277 .49554 .4742 .50612 .46694 .50019 .47425 Mtetra
.341 0 .002 r
.50019 .47425 .50612 .46694 .51671 .46142 .51083 .47284 Mtetra
.342 0 .135 r
.51083 .47284 .51671 .46142 .52732 .45803 .52153 .46943 Mtetra
.254 0 .093 r
.52153 .46943 .52732 .45803 .53799 .45676 .53227 .46403 Mtetra
0 0 0 r
.53227 .46403 .53799 .45676 .54872 .45725 .54302 .45572 Mtetra
.881 .939 .85 r
.54302 .45572 .54872 .45725 .55953 .45834 .55376 .44444 Mtetra
.788 .653 .714 r
.55376 .44444 .55953 .45834 .57039 .45785 .56444 .4298 Mtetra
.712 .536 .648 r
.56444 .4298 .57039 .45785 .58126 .45426 .57507 .41363 Mtetra
.659 .473 .622 r
.57507 .41363 .58126 .45426 .59205 .4449 .58569 .39952 Mtetra
.624 .442 .616 r
.58569 .39952 .59205 .4449 .60273 .43106 .59638 .38958 Mtetra
.574 .413 .625 r
.59638 .38958 .60273 .43106 .61335 .41575 .60726 .38701 Mtetra
.503 .396 .665 r
.60726 .38701 .61335 .41575 .62398 .40197 .61837 .39068 Mtetra
.215 .38 .813 r
.61837 .39068 .62398 .40197 .63481 .39467 .62968 .3978 Mtetra
.662 .15 .014 r
.62968 .3978 .63481 .39467 .64588 .39338 .64115 .40611 Mtetra
.61 .218 .275 r
.64115 .40611 .64588 .39338 .65718 .39652 .65268 .4125 Mtetra
.557 .191 .302 r
.65268 .4125 .65718 .39652 .66868 .4019 .6642 .41604 Mtetra
.471 .096 .245 r
.6642 .41604 .66868 .4019 .68025 .4063 .67563 .41565 Mtetra
.29 0 .056 r
.67563 .41565 .68025 .4063 .69181 .40882 .68696 .41187 Mtetra
0 0 0 r
.68696 .41187 .69181 .40882 .7033 .40825 .69818 .40531 Mtetra
.804 .928 .916 r
.69818 .40531 .7033 .40825 .7147 .40511 .70934 .39713 Mtetra
.774 .755 .836 r
.70934 .39713 .7147 .40511 .72602 .39996 .7205 .38876 Mtetra
.735 .674 .791 r
.7205 .38876 .72602 .39996 .7373 .39362 .7317 .38073 Mtetra
.701 .633 .777 r
.7317 .38073 .7373 .39362 .7486 .3871 .74298 .37384 Mtetra
.68 .618 .779 r
.74298 .37384 .7486 .3871 .75994 .38074 .75437 .36798 Mtetra
.662 .616 .793 r
.75437 .36798 .75994 .38074 .77135 .37505 .76587 .36319 Mtetra
.649 .625 .812 r
.76587 .36319 .77135 .37505 .78285 .36995 .77747 .35919 Mtetra
.64 .642 .836 r
.77747 .35919 .78285 .36995 .79444 .36549 .78917 .35572 Mtetra
.633 .661 .859 r
.78917 .35572 .79444 .36549 .80611 .36148 .80094 .35258 Mtetra
.631 .682 .88 r
.80094 .35258 .80611 .36148 .81786 .35777 .81277 .34952 Mtetra
.629 .7 .897 r
.81277 .34952 .81786 .35777 .82967 .35427 .82467 .34652 Mtetra
.628 .716 .91 r
.82467 .34652 .82967 .35427 .84155 .35086 .83662 .34349 Mtetra
.631 .73 .919 r
.83662 .34349 .84155 .35086 .85348 .34743 .84861 .34035 Mtetra
.681 .757 .909 r
.21326 .53739 .21976 .54307 .22935 .53933 .22286 .53365 Mtetra
.687 .759 .907 r
.22286 .53365 .22935 .53933 .23897 .53549 .23251 .52976 Mtetra
.691 .759 .904 r
.23251 .52976 .23897 .53549 .24863 .53162 .2422 .52573 Mtetra
.695 .755 .898 r
.2422 .52573 .24863 .53162 .25831 .5278 .25193 .52155 Mtetra
.699 .745 .887 r
.25193 .52155 .25831 .5278 .26801 .52407 .2617 .51719 Mtetra
.695 .726 .874 r
.2617 .51719 .26801 .52407 .27772 .52066 .2715 .51285 Mtetra
.686 .699 .856 r
.2715 .51285 .27772 .52066 .28744 .51775 .28133 .50862 Mtetra
.665 .661 .836 r
.28133 .50862 .28744 .51775 .29713 .5156 .29114 .50489 Mtetra
.636 .617 .815 r
.29114 .50489 .29713 .5156 .3068 .5145 .30093 .50196 Mtetra
.599 .57 .793 r
.30093 .50196 .3068 .5145 .31645 .5144 .31069 .50019 Mtetra
.555 .523 .775 r
.31069 .50019 .31645 .5144 .32609 .51541 .3204 .49997 Mtetra
.517 .487 .762 r
.3204 .49997 .32609 .51541 .33578 .51678 .33007 .50114 Mtetra
.474 .46 .762 r
.33007 .50114 .33578 .51678 .34553 .51798 .33974 .5037 Mtetra
.455 .467 .782 r
.33974 .5037 .34553 .51798 .35543 .51761 .34946 .50649 Mtetra
.446 .518 .839 r
.34946 .50649 .35543 .51761 .36551 .51455 .35929 .50866 Mtetra
.466 .686 .962 r
.35929 .50866 .36551 .51455 .37577 .50819 .36928 .50871 Mtetra
.399 .854 .866 r
.36928 .50871 .37577 .50819 .38622 .49798 .37948 .50542 Mtetra
0 0 0 r
.37948 .50542 .38622 .49798 .39677 .48494 .38989 .49796 Mtetra
.38989 .49796 .39677 .48494 .40737 .46999 .40048 .48591 Mtetra
0 0 .005 r
.40048 .48591 .40737 .46999 .4179 .45616 .41115 .47136 Mtetra
0 0 0 r
.41115 .47136 .4179 .45616 .4283 .4457 .4218 .45609 Mtetra
.4218 .45609 .4283 .4457 .43854 .44138 .43233 .44434 Mtetra
.433 .851 .693 r
.43233 .44434 .43854 .44138 .44863 .44433 .44269 .43828 Mtetra
.554 .719 .949 r
.44269 .43828 .44863 .44433 .45872 .45145 .45297 .43703 Mtetra
.462 .471 .782 r
.45297 .43703 .45872 .45145 .46888 .46064 .46323 .43978 Mtetra
.479 .418 .71 r
.46323 .43978 .46888 .46064 .47918 .46836 .47356 .4433 Mtetra
.511 .415 .682 r
.47356 .4433 .47918 .46836 .48963 .47277 .48398 .44583 Mtetra
.541 .427 .672 r
.48398 .44583 .48963 .47277 .50019 .47425 .49449 .44663 Mtetra
.573 .445 .669 r
.49449 .44663 .50019 .47425 .51083 .47284 .50509 .44516 Mtetra
.597 .462 .667 r
.50509 .44516 .51083 .47284 .52153 .46943 .51575 .44171 Mtetra
.62 .476 .665 r
.51575 .44171 .52153 .46943 .53227 .46403 .52645 .43628 Mtetra
.643 .492 .662 r
.52645 .43628 .53227 .46403 .54302 .45572 .53717 .42857 Mtetra
.662 .506 .662 r
.53717 .42857 .54302 .45572 .55376 .44444 .54789 .41909 Mtetra
.678 .523 .668 r
.54789 .41909 .55376 .44444 .56444 .4298 .5586 .4086 Mtetra
.689 .548 .689 r
.5586 .4086 .56444 .4298 .57507 .41363 .56932 .39886 Mtetra
.67 .587 .754 r
.56932 .39886 .57507 .41363 .58569 .39952 .5801 .39315 Mtetra
.53 .704 .95 r
.5801 .39315 .58569 .39952 .59638 .38958 .59102 .39229 Mtetra
.549 .005 0 r
.59102 .39229 .59638 .38958 .60726 .38701 .60214 .39723 Mtetra
.654 .242 .251 r
.60214 .39723 .60726 .38701 .61837 .39068 .61345 .40577 Mtetra
.626 .253 .315 r
.61345 .40577 .61837 .39068 .62968 .3978 .62488 .41362 Mtetra
.587 .217 .309 r
.62488 .41362 .62968 .3978 .64115 .40611 .63634 .41896 Mtetra
.488 .098 .226 r
.63634 .41896 .64115 .40611 .65268 .4125 .64773 .41963 Mtetra
.217 0 0 r
.64773 .41963 .65268 .4125 .6642 .41604 .65902 .41605 Mtetra
.672 .975 .89 r
.65902 .41605 .6642 .41604 .67563 .41565 .6702 .40904 Mtetra
.804 .798 .846 r
.6702 .40904 .67563 .41565 .68696 .41187 .6813 .39984 Mtetra
.755 .669 .766 r
.6813 .39984 .68696 .41187 .69818 .40531 .69237 .38997 Mtetra
.724 .615 .735 r
.69237 .38997 .69818 .40531 .70934 .39713 .70346 .38033 Mtetra
.695 .586 .729 r
.70346 .38033 .70934 .39713 .7205 .38876 .71463 .37209 Mtetra
.676 .577 .736 r
.71463 .37209 .7205 .38876 .7317 .38073 .72591 .36527 Mtetra
.656 .579 .756 r
.72591 .36527 .7317 .38073 .74298 .37384 .73731 .36004 Mtetra
.641 .591 .783 r
.73731 .36004 .74298 .37384 .75437 .36798 .74884 .35602 Mtetra
.629 .614 .816 r
.74884 .35602 .75437 .36798 .76587 .36319 .76048 .35282 Mtetra
.618 .64 .85 r
.76048 .35282 .76587 .36319 .77747 .35919 .7722 .35014 Mtetra
.615 .67 .88 r
.7722 .35014 .77747 .35919 .78917 .35572 .784 .34759 Mtetra
.612 .696 .903 r
.784 .34759 .78917 .35572 .80094 .35258 .79586 .34504 Mtetra
.617 .717 .918 r
.79586 .34504 .80094 .35258 .81277 .34952 .80775 .34231 Mtetra
.62 .731 .925 r
.80775 .34231 .81277 .34952 .82467 .34652 .81969 .33943 Mtetra
.625 .738 .928 r
.81969 .33943 .82467 .34652 .83662 .34349 .83168 .3364 Mtetra
.63 .741 .927 r
.83168 .3364 .83662 .34349 .84861 .34035 .8437 .33321 Mtetra
.668 .754 .915 r
.20671 .53168 .21326 .53739 .22286 .53365 .2163 .52828 Mtetra
.673 .768 .922 r
.2163 .52828 .22286 .53365 .23251 .52976 .22594 .52473 Mtetra
.681 .783 .927 r
.22594 .52473 .23251 .52976 .2422 .52573 .23563 .52097 Mtetra
.693 .796 .929 r
.23563 .52097 .2422 .52573 .25193 .52155 .24537 .5169 Mtetra
.709 .803 .923 r
.24537 .5169 .25193 .52155 .2617 .51719 .25518 .51241 Mtetra
.721 .8 .914 r
.25518 .51241 .2617 .51719 .2715 .51285 .26505 .50755 Mtetra
.731 .784 .895 r
.26505 .50755 .2715 .51285 .28133 .50862 .27497 .50228 Mtetra
.726 .751 .872 r
.27497 .50228 .28133 .50862 .29114 .50489 .28493 .4969 Mtetra
.712 .704 .841 r
.28493 .4969 .29114 .50489 .30093 .50196 .2949 .49157 Mtetra
.681 .644 .806 r
.2949 .49157 .30093 .50196 .31069 .50019 .30486 .48686 Mtetra
.642 .581 .771 r
.30486 .48686 .31069 .50019 .3204 .49997 .31478 .4832 Mtetra
.598 .52 .738 r
.31478 .4832 .3204 .49997 .33007 .50114 .32463 .48111 Mtetra
.552 .467 .712 r
.32463 .48111 .33007 .50114 .33974 .5037 .33441 .48111 Mtetra
.512 .425 .694 r
.33441 .48111 .33974 .5037 .34946 .50649 .34413 .48316 Mtetra
.469 .393 .688 r
.34413 .48316 .34946 .50649 .35929 .50866 .35382 .48731 Mtetra
.436 .384 .702 r
.35382 .48731 .35929 .50866 .36928 .50871 .36354 .49239 Mtetra
.387 .401 .753 r
.36354 .49239 .36928 .50871 .37948 .50542 .37335 .49753 Mtetra
.238 .494 .897 r
.37335 .49753 .37948 .50542 .38989 .49796 .3833 .5013 Mtetra
.377 0 0 r
.3833 .5013 .38989 .49796 .40048 .48591 .39344 .5025 Mtetra
.439 .085 .266 r
.39344 .5025 .40048 .48591 .41115 .47136 .40376 .50046 Mtetra
.424 .129 .358 r
.40376 .50046 .41115 .47136 .4218 .45609 .41427 .49446 Mtetra
.393 .124 .382 r
.41427 .49446 .4218 .45609 .43233 .44434 .42494 .4837 Mtetra
.33 .073 .364 r
.42494 .4837 .43233 .44434 .44269 .43828 .43573 .46834 Mtetra
.204 0 .282 r
.43573 .46834 .44269 .43828 .45297 .43703 .44653 .45112 Mtetra
0 0 0 r
.44653 .45112 .45297 .43703 .46323 .43978 .45728 .43396 Mtetra
.871 .79 .769 r
.45728 .43396 .46323 .43978 .47356 .4433 .46793 .41944 Mtetra
.687 .533 .672 r
.46793 .41944 .47356 .4433 .48398 .44583 .4785 .40869 Mtetra
.622 .453 .632 r
.4785 .40869 .48398 .44583 .49449 .44663 .48903 .40091 Mtetra
.59 .416 .615 r
.48903 .40091 .49449 .44663 .50509 .44516 .49956 .39574 Mtetra
.575 .401 .609 r
.49956 .39574 .50509 .44516 .51575 .44171 .5101 .39223 Mtetra
.562 .392 .608 r
.5101 .39223 .51575 .44171 .52645 .43628 .52068 .39038 Mtetra
.542 .382 .614 r
.52068 .39038 .52645 .43628 .53717 .42857 .53132 .39117 Mtetra
.509 .374 .632 r
.53132 .39117 .53717 .42857 .54789 .41909 .54205 .39495 Mtetra
.405 .351 .684 r
.54205 .39495 .54789 .41909 .5586 .4086 .5529 .40256 Mtetra
0 .058 .568 r
.5529 .40256 .5586 .4086 .56932 .39886 .5639 .41288 Mtetra
.666 .288 .32 r
.5639 .41288 .56932 .39886 .5801 .39315 .57504 .4233 Mtetra
.603 .29 .412 r
.57504 .4233 .5801 .39315 .59102 .39229 .58628 .43188 Mtetra
.555 .265 .43 r
.58628 .43188 .59102 .39229 .60214 .39723 .59755 .43585 Mtetra
.513 .227 .418 r
.59755 .43585 .60214 .39723 .61345 .40577 .60879 .43501 Mtetra
.449 .152 .368 r
.60879 .43501 .61345 .40577 .62488 .41362 .61998 .43012 Mtetra
.27 0 .201 r
.61998 .43012 .62488 .41362 .63634 .41896 .63109 .42192 Mtetra
.689 .954 .694 r
.63109 .42192 .63634 .41896 .64773 .41963 .64212 .41108 Mtetra
.825 .752 .783 r
.64212 .41108 .64773 .41963 .65902 .41605 .65309 .39881 Mtetra
.74 .606 .708 r
.65309 .39881 .65902 .41605 .6702 .40904 .66405 .38656 Mtetra
.699 .55 .681 r
.66405 .38656 .6702 .40904 .6813 .39984 .67504 .37525 Mtetra
.667 .521 .676 r
.67504 .37525 .6813 .39984 .69237 .38997 .68612 .36607 Mtetra
.647 .512 .684 r
.68612 .36607 .69237 .38997 .70346 .38033 .69732 .35898 Mtetra
.629 .514 .704 r
.69732 .35898 .70346 .38033 .71463 .37209 .70867 .35403 Mtetra
.613 .529 .736 r
.70867 .35403 .71463 .37209 .72591 .36527 .72016 .35071 Mtetra
.6 .559 .78 r
.72016 .35071 .72591 .36527 .73731 .36004 .73177 .34848 Mtetra
.586 .599 .832 r
.73177 .34848 .73731 .36004 .74884 .35602 .74349 .34687 Mtetra
.579 .651 .885 r
.74349 .34687 .74884 .35602 .76048 .35282 .75527 .34534 Mtetra
.572 .698 .926 r
.75527 .34534 .76048 .35282 .7722 .35014 .76711 .34369 Mtetra
.58 .738 .951 r
.76711 .34369 .7722 .35014 .784 .34759 .77898 .34162 Mtetra
.591 .763 .961 r
.77898 .34162 .784 .34759 .79586 .34504 .79088 .33917 Mtetra
.61 .775 .96 r
.79088 .33917 .79586 .34504 .80775 .34231 .8028 .33628 Mtetra
.625 .777 .954 r
.8028 .33628 .80775 .34231 .81969 .33943 .81475 .33306 Mtetra
.636 .77 .944 r
.81475 .33306 .81969 .33943 .83168 .3364 .82674 .32962 Mtetra
.644 .759 .933 r
.82674 .32962 .83168 .3364 .8437 .33321 .83876 .32602 Mtetra
.642 .748 .926 r
.20012 .52592 .20671 .53168 .2163 .52828 .20967 .5231 Mtetra
.643 .77 .94 r
.20967 .5231 .2163 .52828 .22594 .52473 .21927 .5202 Mtetra
.648 .796 .954 r
.21927 .5202 .22594 .52473 .23563 .52097 .22893 .51711 Mtetra
.658 .825 .964 r
.22893 .51711 .23563 .52097 .24537 .5169 .23864 .5137 Mtetra
.673 .855 .969 r
.23864 .5137 .24537 .5169 .25518 .51241 .24843 .50984 Mtetra
.693 .883 .969 r
.24843 .50984 .25518 .51241 .26505 .50755 .25829 .50543 Mtetra
.72 .903 .96 r
.25829 .50543 .26505 .50755 .27497 .50228 .26824 .50033 Mtetra
.745 .911 .949 r
.26824 .50033 .27497 .50228 .28493 .4969 .27825 .49461 Mtetra
.771 .9 .932 r
.27825 .49461 .28493 .4969 .2949 .49157 .28833 .48827 Mtetra
.777 .862 .913 r
.28833 .48827 .2949 .49157 .30486 .48686 .29845 .48171 Mtetra
.763 .797 .881 r
.29845 .48171 .30486 .48686 .31478 .4832 .30857 .47523 Mtetra
.72 .71 .84 r
.30857 .47523 .31478 .4832 .32463 .48111 .31867 .46953 Mtetra
.664 .619 .794 r
.31867 .46953 .32463 .48111 .33441 .48111 .32871 .46522 Mtetra
.603 .533 .748 r
.32871 .46522 .33441 .48111 .34413 .48316 .33866 .46291 Mtetra
.545 .461 .712 r
.33866 .46291 .34413 .48316 .35382 .48731 .34851 .4632 Mtetra
.503 .412 .684 r
.34851 .4632 .35382 .48731 .36354 .49239 .35831 .46576 Mtetra
.468 .376 .668 r
.35831 .46576 .36354 .49239 .37335 .49753 .36808 .47047 Mtetra
.445 .359 .665 r
.36808 .47047 .37335 .49753 .3833 .5013 .37789 .47644 Mtetra
.425 .357 .677 r
.37789 .47644 .3833 .5013 .39344 .5025 .38777 .48281 Mtetra
.428 .394 .719 r
.38777 .48281 .39344 .5025 .40376 .50046 .3978 .48775 Mtetra
.471 .506 .813 r
.3978 .48775 .40376 .50046 .41427 .49446 .40804 .4897 Mtetra
.634 .801 .963 r
.40804 .4897 .41427 .49446 .42494 .4837 .41851 .48658 Mtetra
.687 .972 .774 r
.41851 .48658 .42494 .4837 .43573 .46834 .42919 .47765 Mtetra
0 0 0 r
.42919 .47765 .43573 .46834 .44653 .45112 .43995 .46559 Mtetra
.43995 .46559 .44653 .45112 .45728 .43396 .45073 .45219 Mtetra
.132 0 .15 r
.45073 .45219 .45728 .43396 .46793 .41944 .46146 .4402 Mtetra
.281 0 .246 r
.46146 .4402 .46793 .41944 .4785 .40869 .47214 .43093 Mtetra
.36 .047 .291 r
.47214 .43093 .4785 .40869 .48903 .40091 .48279 .4239 Mtetra
.414 .098 .318 r
.48279 .4239 .48903 .40091 .49956 .39574 .49343 .41898 Mtetra
.443 .125 .33 r
.49343 .41898 .49956 .39574 .5101 .39223 .5041 .41548 Mtetra
.469 .149 .339 r
.5041 .41548 .5101 .39223 .52068 .39038 .5148 .41337 Mtetra
.504 .179 .349 r
.5148 .41337 .52068 .39038 .53132 .39117 .52556 .4134 Mtetra
.538 .207 .354 r
.52556 .4134 .53132 .39117 .54205 .39495 .53639 .4157 Mtetra
.578 .237 .355 r
.53639 .4157 .54205 .39495 .5529 .40256 .54732 .42076 Mtetra
.601 .246 .34 r
.54732 .42076 .5529 .40256 .5639 .41288 .55837 .42727 Mtetra
.585 .206 .289 r
.55837 .42727 .5639 .41288 .57504 .4233 .56952 .43246 Mtetra
.503 .066 .142 r
.56952 .43246 .57504 .4233 .58628 .43188 .58071 .43452 Mtetra
0 0 0 r
.58071 .43452 .58628 .43188 .59755 .43585 .59187 .43069 Mtetra
.814 .839 .869 r
.59187 .43069 .59755 .43585 .60879 .43501 .60294 .4217 Mtetra
.77 .657 .738 r
.60294 .4217 .60879 .43501 .61998 .43012 .61394 .40964 Mtetra
.731 .579 .685 r
.61394 .40964 .61998 .43012 .63109 .42192 .62488 .39609 Mtetra
.699 .536 .663 r
.62488 .39609 .63109 .42192 .64212 .41108 .63581 .38292 Mtetra
.679 .515 .656 r
.63581 .38292 .64212 .41108 .65309 .39881 .64676 .37101 Mtetra
.661 .504 .661 r
.64676 .37101 .65309 .39881 .66405 .38656 .65779 .36126 Mtetra
.646 .504 .676 r
.65779 .36126 .66405 .38656 .67504 .37525 .66893 .35384 Mtetra
.626 .512 .704 r
.66893 .35384 .67504 .37525 .68612 .36607 .68022 .34906 Mtetra
.604 .533 .748 r
.68022 .34906 .68612 .36607 .69732 .35898 .69166 .34635 Mtetra
.577 .575 .814 r
.69166 .34635 .69732 .35898 .70867 .35403 .70323 .34507 Mtetra
.536 .633 .894 r
.70323 .34507 .70867 .35403 .72016 .35071 .71491 .34461 Mtetra
.484 .704 .966 r
.71491 .34461 .72016 .35071 .73177 .34848 .72668 .34423 Mtetra
.428 .753 .995 r
.72668 .34423 .73177 .34848 .74349 .34687 .7385 .34365 Mtetra
.422 .792 .994 r
.7385 .34365 .74349 .34687 .75527 .34534 .75035 .34241 Mtetra
.453 .821 .994 r
.75035 .34241 .75527 .34534 .76711 .34369 .76222 .34055 Mtetra
.518 .846 .998 r
.76222 .34055 .76711 .34369 .77898 .34162 .7741 .33796 Mtetra
.576 .852 .996 r
.7741 .33796 .77898 .34162 .79088 .33917 .78599 .3348 Mtetra
.62 .842 .985 r
.78599 .3348 .79088 .33917 .8028 .33628 .7979 .33117 Mtetra
.647 .824 .968 r
.7979 .33117 .8028 .33628 .81475 .33306 .80982 .3272 Mtetra
.662 .801 .949 r
.80982 .3272 .81475 .33306 .82674 .32962 .82178 .32302 Mtetra
.667 .777 .932 r
.82178 .32302 .82674 .32962 .83876 .32602 .83378 .31877 Mtetra
.612 .74 .936 r
.19348 .52013 .20012 .52592 .20967 .5231 .20299 .51791 Mtetra
.604 .761 .954 r
.20299 .51791 .20967 .5231 .21927 .5202 .21255 .51573 Mtetra
.598 .788 .971 r
.21255 .51573 .21927 .5202 .22893 .51711 .22215 .51347 Mtetra
.592 .82 .986 r
.22215 .51347 .22893 .51711 .23864 .5137 .2318 .51103 Mtetra
.583 .856 .995 r
.2318 .51103 .23864 .5137 .24843 .50984 .24152 .50833 Mtetra
.572 .893 .987 r
.24152 .50833 .24843 .50984 .25829 .50543 .25132 .50515 Mtetra
.56 .92 .952 r
.25132 .50515 .25829 .50543 .26824 .50033 .2612 .5013 Mtetra
.547 .929 .891 r
.2612 .5013 .26824 .50033 .27825 .49461 .27118 .49663 Mtetra
.561 .935 .834 r
.27118 .49663 .27825 .49461 .28833 .48827 .28127 .49091 Mtetra
.597 .946 .804 r
.28127 .49091 .28833 .48827 .29845 .48171 .29145 .48423 Mtetra
.686 .979 .826 r
.29145 .48423 .29845 .48171 .30857 .47523 .30171 .47654 Mtetra
.78 .993 .878 r
.30171 .47654 .30857 .47523 .31867 .46953 .31202 .46828 Mtetra
.831 .932 .897 r
.31202 .46828 .31867 .46953 .32871 .46522 .32235 .45975 Mtetra
.793 .793 .852 r
.32235 .45975 .32871 .46522 .33866 .46291 .33266 .45169 Mtetra
.718 .649 .779 r
.33266 .45169 .33866 .46291 .34851 .4632 .34292 .44467 Mtetra
.647 .536 .715 r
.34292 .44467 .34851 .4632 .35831 .46576 .35311 .43937 Mtetra
.593 .461 .67 r
.35311 .43937 .35831 .46576 .36808 .47047 .36321 .43636 Mtetra
.554 .41 .64 r
.36321 .43636 .36808 .47047 .37789 .47644 .37323 .43584 Mtetra
.525 .376 .621 r
.37323 .43584 .37789 .47644 .38777 .48281 .3832 .43793 Mtetra
.513 .36 .611 r
.3832 .43793 .38777 .48281 .3978 .48775 .39318 .44145 Mtetra
.505 .353 .608 r
.39318 .44145 .3978 .48775 .40804 .4897 .40321 .44586 Mtetra
.486 .343 .612 r
.40321 .44586 .40804 .4897 .41851 .48658 .41328 .45182 Mtetra
.446 .334 .633 r
.41328 .45182 .41851 .48658 .42919 .47765 .42339 .45938 Mtetra
.279 .314 .719 r
.42339 .45938 .42919 .47765 .43995 .46559 .43358 .46809 Mtetra
.701 .206 .065 r
.43358 .46809 .43995 .46559 .45073 .45219 .44389 .47719 Mtetra
.599 .274 .391 r
.44389 .47719 .45073 .45219 .46146 .4402 .45435 .48445 Mtetra
.556 .272 .439 r
.45435 .48445 .46146 .4402 .47214 .43093 .46498 .48878 Mtetra
.534 .266 .454 r
.46498 .48878 .47214 .43093 .48279 .4239 .47574 .49024 Mtetra
.519 .258 .46 r
.47574 .49024 .48279 .4239 .49343 .41898 .48661 .48886 Mtetra
.508 .251 .46 r
.48661 .48886 .49343 .41898 .5041 .41548 .49756 .4854 Mtetra
.496 .241 .458 r
.49756 .4854 .5041 .41548 .5148 .41337 .50856 .47984 Mtetra
.476 .222 .45 r
.50856 .47984 .5148 .41337 .52556 .4134 .5196 .47142 Mtetra
.444 .19 .433 r
.5196 .47142 .52556 .4134 .53639 .4157 .53064 .46009 Mtetra
.377 .12 .392 r
.53064 .46009 .53639 .4157 .54732 .42076 .54165 .44579 Mtetra
.169 0 .241 r
.54165 .44579 .54732 .42076 .55837 .42727 .55263 .42958 Mtetra
.91 .981 .726 r
.55263 .42958 .55837 .42727 .56952 .43246 .56356 .41373 Mtetra
.752 .601 .689 r
.56356 .41373 .56952 .43246 .58071 .43452 .57448 .39899 Mtetra
.665 .486 .633 r
.57448 .39899 .58071 .43452 .59187 .43069 .58539 .38584 Mtetra
.633 .448 .615 r
.58539 .38584 .59187 .43069 .60294 .4217 .59631 .37423 Mtetra
.623 .438 .611 r
.59631 .37423 .60294 .4217 .61394 .40964 .60725 .36351 Mtetra
.615 .434 .614 r
.60725 .36351 .61394 .40964 .62488 .39609 .61822 .35422 Mtetra
.603 .431 .622 r
.61822 .35422 .62488 .39609 .63581 .38292 .62929 .34757 Mtetra
.59 .435 .64 r
.62929 .34757 .63581 .38292 .64676 .37101 .64047 .34345 Mtetra
.573 .448 .672 r
.64047 .34345 .64676 .37101 .65779 .36126 .65179 .34169 Mtetra
.549 .478 .728 r
.65179 .34169 .65779 .36126 .66893 .35384 .66324 .34169 Mtetra
.5 .541 .83 r
.66324 .34169 .66893 .35384 .68022 .34906 .67483 .34278 Mtetra
.36 .63 .956 r
.67483 .34278 .68022 .34906 .69166 .34635 .68651 .34436 Mtetra
.067 .603 .858 r
.68651 .34436 .69166 .34635 .70323 .34507 .69828 .34568 Mtetra
.132 0 0 r
.69828 .34568 .70323 .34507 .71491 .34461 .71009 .34643 Mtetra
.141 0 0 r
.71009 .34643 .71491 .34461 .72668 .34423 .72192 .34615 Mtetra
.06 0 0 r
.72192 .34615 .72668 .34423 .7385 .34365 .73376 .34487 Mtetra
0 0 0 r
.73376 .34487 .7385 .34365 .75035 .34241 .7456 .34252 Mtetra
.312 .803 .823 r
.7456 .34252 .75035 .34241 .76222 .34055 .75743 .3393 Mtetra
.497 .894 .943 r
.75743 .3393 .76222 .34055 .7741 .33796 .76926 .33539 Mtetra
.608 .908 .983 r
.76926 .33539 .7741 .33796 .78599 .3348 .7811 .33098 Mtetra
.661 .881 .98 r
.7811 .33098 .78599 .3348 .7979 .33117 .79297 .32628 Mtetra
.684 .848 .961 r
.79297 .32628 .7979 .33117 .80982 .3272 .80486 .32139 Mtetra
.691 .816 .942 r
.80486 .32139 .80982 .3272 .82178 .32302 .81679 .31641 Mtetra
.69 .788 .925 r
.81679 .31641 .82178 .32302 .83378 .31877 .82876 .31146 Mtetra
.599 .736 .94 r
.18679 .51429 .19348 .52013 .20299 .51791 .1963 .51231 Mtetra
.589 .742 .949 r
.1963 .51231 .20299 .51791 .21255 .51573 .20584 .51044 Mtetra
.58 .752 .959 r
.20584 .51044 .21255 .51573 .22215 .51347 .21542 .50865 Mtetra
.57 .767 .972 r
.21542 .50865 .22215 .51347 .2318 .51103 .22503 .50688 Mtetra
.551 .789 .987 r
.22503 .50688 .2318 .51103 .24152 .50833 .23469 .50514 Mtetra
.533 .822 .999 r
.23469 .50514 .24152 .50833 .25132 .50515 .24441 .50322 Mtetra
.499 .855 .991 r
.24441 .50322 .25132 .50515 .2612 .5013 .2542 .50099 Mtetra
.445 .87 .933 r
.2542 .50099 .2612 .5013 .27118 .49663 .26407 .49816 Mtetra
.37 .836 .801 r
.26407 .49816 .27118 .49663 .28127 .49091 .27405 .49447 Mtetra
0 0 0 r
.27405 .49447 .28127 .49091 .29145 .48423 .28415 .48972 Mtetra
.28415 .48972 .29145 .48423 .30171 .47654 .29436 .48364 Mtetra
.29436 .48364 .30171 .47654 .31202 .46828 .30468 .47631 Mtetra
.30468 .47631 .31202 .46828 .32235 .45975 .31509 .46769 Mtetra
.31509 .46769 .32235 .45975 .33266 .45169 .32556 .45824 Mtetra
.504 .831 .531 r
.32556 .45824 .33266 .45169 .34292 .44467 .33606 .44829 Mtetra
.716 .977 .758 r
.33606 .44829 .34292 .44467 .35311 .43937 .34653 .43873 Mtetra
.822 .958 .901 r
.34653 .43873 .35311 .43937 .36321 .43636 .35695 .43026 Mtetra
.763 .777 .864 r
.35695 .43026 .36321 .43636 .37323 .43584 .3673 .42337 Mtetra
.668 .611 .782 r
.3673 .42337 .37323 .43584 .3832 .43793 .37758 .41855 Mtetra
.602 .504 .716 r
.37758 .41855 .3832 .43793 .39318 .44145 .38779 .41579 Mtetra
.555 .439 .676 r
.38779 .41579 .39318 .44145 .40321 .44586 .39796 .41534 Mtetra
.505 .387 .652 r
.39796 .41534 .40321 .44586 .41328 .45182 .40807 .41829 Mtetra
.457 .344 .638 r
.40807 .41829 .41328 .45182 .42339 .45938 .41813 .42478 Mtetra
.437 .328 .633 r
.41813 .42478 .42339 .45938 .43358 .46809 .42826 .43276 Mtetra
.44 .329 .631 r
.42826 .43276 .43358 .46809 .44389 .47719 .4385 .44073 Mtetra
.478 .353 .632 r
.4385 .44073 .44389 .47719 .45435 .48445 .44891 .44635 Mtetra
.522 .381 .63 r
.44891 .44635 .45435 .48445 .46498 .48878 .45949 .44859 Mtetra
.549 .396 .626 r
.45949 .44859 .46498 .48878 .47574 .49024 .47019 .44831 Mtetra
.568 .407 .623 r
.47019 .44831 .47574 .49024 .48661 .48886 .48098 .44593 Mtetra
.577 .412 .621 r
.48098 .44593 .48661 .48886 .49756 .4854 .49184 .4424 Mtetra
.586 .418 .621 r
.49184 .4424 .49756 .4854 .50856 .47984 .50274 .43774 Mtetra
.604 .432 .622 r
.50274 .43774 .50856 .47984 .5196 .47142 .51369 .43094 Mtetra
.626 .45 .625 r
.51369 .43094 .5196 .47142 .53064 .46009 .52466 .42161 Mtetra
.654 .473 .627 r
.52466 .42161 .53064 .46009 .54165 .44579 .53562 .40885 Mtetra
.674 .49 .628 r
.53562 .40885 .54165 .44579 .55263 .42958 .54655 .39368 Mtetra
.678 .494 .63 r
.54655 .39368 .55263 .42958 .56356 .41373 .55744 .37847 Mtetra
.669 .489 .632 r
.55744 .37847 .56356 .41373 .57448 .39899 .56832 .36472 Mtetra
.645 .475 .638 r
.56832 .36472 .57448 .39899 .58539 .38584 .57923 .35453 Mtetra
.622 .467 .65 r
.57923 .35453 .58539 .38584 .59631 .37423 .59022 .34777 Mtetra
.607 .474 .673 r
.59022 .34777 .59631 .37423 .60725 .36351 .60128 .34336 Mtetra
.59 .497 .718 r
.60128 .34336 .60725 .36351 .61822 .35422 .61244 .34104 Mtetra
.546 .547 .807 r
.61244 .34104 .61822 .35422 .62929 .34757 .62372 .34083 Mtetra
.385 .626 .949 r
.62372 .34083 .62929 .34757 .64047 .34345 .63512 .34226 Mtetra
0 .44 .692 r
.63512 .34226 .64047 .34345 .65179 .34169 .64666 .34481 Mtetra
.441 0 0 r
.64666 .34481 .65179 .34169 .66324 .34169 .6583 .34778 Mtetra
.478 0 .002 r
.6583 .34778 .66324 .34169 .67483 .34278 .67002 .35027 Mtetra
.464 0 .051 r
.67002 .35027 .67483 .34278 .68651 .34436 .68179 .35192 Mtetra
.414 0 .028 r
.68179 .35192 .68651 .34436 .69828 .34568 .69358 .35226 Mtetra
.333 0 0 r
.69358 .35226 .69828 .34568 .71009 .34643 .70537 .35131 Mtetra
.185 0 0 r
.70537 .35131 .71009 .34643 .72192 .34615 .71716 .349 Mtetra
0 0 0 r
.71716 .349 .72192 .34615 .73376 .34487 .72893 .34558 Mtetra
.354 .826 .787 r
.72893 .34558 .73376 .34487 .7456 .34252 .74069 .34127 Mtetra
.575 .929 .945 r
.74069 .34127 .7456 .34252 .75743 .3393 .75246 .33633 Mtetra
.671 .916 .976 r
.75246 .33633 .75743 .3393 .76926 .33539 .76424 .33106 Mtetra
.703 .875 .962 r
.76424 .33106 .76926 .33539 .7811 .33098 .77605 .32559 Mtetra
.708 .837 .944 r
.77605 .32559 .7811 .33098 .79297 .32628 .7879 .32014 Mtetra
.707 .81 .929 r
.7879 .32014 .79297 .32628 .80486 .32139 .79978 .31471 Mtetra
.703 .791 .919 r
.79978 .31471 .80486 .32139 .81679 .31641 .81172 .30935 Mtetra
.698 .777 .913 r
.81172 .30935 .81679 .31641 .82876 .31146 .82371 .3041 Mtetra
.609 .739 .937 r
.18006 .50842 .18679 .51429 .1963 .51231 .18961 .50621 Mtetra
.602 .73 .934 r
.18961 .50621 .1963 .51231 .20584 .51044 .19918 .50416 Mtetra
.593 .721 .933 r
.19918 .50416 .20584 .51044 .21542 .50865 .20878 .5023 Mtetra
.58 .715 .935 r
.20878 .5023 .21542 .50865 .22503 .50688 .2184 .50068 Mtetra
.559 .714 .944 r
.2184 .50068 .22503 .50688 .23469 .50514 .22803 .49939 Mtetra
.537 .723 .959 r
.22803 .49939 .23469 .50514 .24441 .50322 .23769 .49831 Mtetra
.501 .743 .981 r
.23769 .49831 .24441 .50322 .2542 .50099 .24739 .49744 Mtetra
.45 .777 .998 r
.24739 .49744 .2542 .50099 .26407 .49816 .25714 .49651 Mtetra
.342 .79 .955 r
.25714 .49651 .26407 .49816 .27405 .49447 .26695 .49537 Mtetra
.158 .698 .742 r
.26695 .49537 .27405 .49447 .28415 .48972 .27686 .49365 Mtetra
.031 0 0 r
.27686 .49365 .28415 .48972 .29436 .48364 .28688 .49107 Mtetra
.149 0 0 r
.28688 .49107 .29436 .48364 .30468 .47631 .29702 .48734 Mtetra
.2 0 .019 r
.29702 .48734 .30468 .47631 .31509 .46769 .30729 .48217 Mtetra
.224 0 .113 r
.30729 .48217 .31509 .46769 .32556 .45824 .31768 .47556 Mtetra
.225 0 .16 r
.31768 .47556 .32556 .45824 .33606 .44829 .32818 .46743 Mtetra
.222 0 .183 r
.32818 .46743 .33606 .44829 .34653 .43873 .33875 .45821 Mtetra
.2 0 .177 r
.33875 .45821 .34653 .43873 .35695 .43026 .34936 .44816 Mtetra
.136 0 .128 r
.34936 .44816 .35695 .43026 .3673 .42337 .36001 .43747 Mtetra
0 0 0 r
.36001 .43747 .3673 .42337 .37758 .41855 .37067 .42642 Mtetra
.37067 .42642 .37758 .41855 .38779 .41579 .38128 .41619 Mtetra
.811 .987 .884 r
.38128 .41619 .38779 .41579 .39796 .41534 .39184 .40736 Mtetra
.764 .732 .823 r
.39184 .40736 .39796 .41534 .40807 .41829 .40236 .39944 Mtetra
.674 .552 .708 r
.40236 .39944 .40807 .41829 .41813 .42478 .41288 .39198 Mtetra
.638 .472 .642 r
.41288 .39198 .41813 .42478 .42826 .43276 .42345 .38322 Mtetra
.619 .431 .606 r
.42345 .38322 .42826 .43276 .4385 .44073 .43408 .3727 Mtetra
.6 .403 .586 r
.43408 .3727 .4385 .44073 .44891 .44635 .44472 .36179 Mtetra
.587 .385 .574 r
.44472 .36179 .44891 .44635 .45949 .44859 .45533 .35136 Mtetra
.574 .37 .567 r
.45533 .35136 .45949 .44859 .47019 .44831 .46591 .34275 Mtetra
.562 .359 .563 r
.46591 .34275 .47019 .44831 .48098 .44593 .47646 .3366 Mtetra
.552 .351 .561 r
.47646 .3366 .48098 .44593 .49184 .4424 .487 .33297 Mtetra
.543 .344 .56 r
.487 .33297 .49184 .4424 .50274 .43774 .49756 .33184 Mtetra
.534 .338 .561 r
.49756 .33184 .50274 .43774 .51369 .43094 .50817 .3332 Mtetra
.526 .334 .563 r
.50817 .3332 .51369 .43094 .52466 .42161 .51884 .3364 Mtetra
.522 .336 .57 r
.51884 .3364 .52466 .42161 .53562 .40885 .52961 .34012 Mtetra
.521 .344 .582 r
.52961 .34012 .53562 .40885 .54655 .39368 .54047 .34346 Mtetra
.531 .367 .605 r
.54047 .34346 .54655 .39368 .55744 .37847 .5514 .34504 Mtetra
.543 .407 .646 r
.5514 .34504 .55744 .37847 .56832 .36472 .5624 .34532 Mtetra
.53 .466 .729 r
.5624 .34532 .56832 .36472 .57923 .35453 .57348 .34609 Mtetra
.415 .584 .91 r
.57348 .34609 .57923 .35453 .59022 .34777 .58465 .34779 Mtetra
.318 0 0 r
.58465 .34779 .59022 .34777 .60128 .34336 .59593 .35094 Mtetra
.547 .083 .106 r
.59593 .35094 .60128 .34336 .61244 .34104 .60734 .35494 Mtetra
.55 .16 .254 r
.60734 .35494 .61244 .34104 .62372 .34083 .61883 .35861 Mtetra
.54 .177 .301 r
.61883 .35861 .62372 .34083 .63512 .34226 .6304 .36163 Mtetra
.527 .174 .312 r
.6304 .36163 .63512 .34226 .64666 .34481 .64204 .36384 Mtetra
.507 .154 .302 r
.64204 .36384 .64666 .34481 .6583 .34778 .65372 .36495 Mtetra
.472 .11 .269 r
.65372 .36495 .6583 .34778 .67002 .35027 .66543 .3645 Mtetra
.418 .037 .206 r
.66543 .3645 .67002 .35027 .68179 .35192 .67713 .36258 Mtetra
.32 0 .087 r
.67713 .36258 .68179 .35192 .69358 .35226 .68882 .35917 Mtetra
.138 0 0 r
.68882 .35917 .69358 .35226 .70537 .35131 .70049 .35459 Mtetra
0 0 0 r
.70049 .35459 .70537 .35131 .71716 .349 .71216 .34909 Mtetra
.568 .939 .872 r
.71216 .34909 .71716 .349 .72893 .34558 .72382 .34299 Mtetra
.715 .939 .959 r
.72382 .34299 .72893 .34558 .74069 .34127 .73551 .33665 Mtetra
.741 .872 .941 r
.73551 .33665 .74069 .34127 .75246 .33633 .74722 .33024 Mtetra
.733 .818 .917 r
.74722 .33024 .75246 .33633 .76424 .33106 .75897 .32404 Mtetra
.722 .784 .902 r
.75897 .32404 .76424 .33106 .77605 .32559 .77078 .31805 Mtetra
.71 .765 .896 r
.77078 .31805 .77605 .32559 .7879 .32014 .78265 .31239 Mtetra
.701 .756 .895 r
.78265 .31239 .7879 .32014 .79978 .31471 .79458 .30697 Mtetra
.695 .755 .898 r
.79458 .30697 .79978 .31471 .81172 .30935 .80657 .30175 Mtetra
.69 .759 .904 r
.80657 .30175 .81172 .30935 .82371 .3041 .81861 .29669 Mtetra
.643 .748 .925 r
.17328 .5025 .18006 .50842 .18961 .50621 .18292 .49957 Mtetra
.639 .724 .91 r
.18292 .49957 .18961 .50621 .19918 .50416 .19258 .49676 Mtetra
.629 .698 .895 r
.19258 .49676 .19918 .50416 .20878 .5023 .20226 .49417 Mtetra
.616 .673 .882 r
.20226 .49417 .20878 .5023 .2184 .50068 .21195 .4919 Mtetra
.599 .65 .872 r
.21195 .4919 .2184 .50068 .22803 .49939 .22164 .49006 Mtetra
.581 .63 .865 r
.22164 .49006 .22803 .49939 .23769 .49831 .23134 .48869 Mtetra
.559 .614 .863 r
.23134 .48869 .23769 .49831 .24739 .49744 .24103 .48786 Mtetra
.541 .607 .868 r
.24103 .48786 .24739 .49744 .25714 .49651 .25075 .48744 Mtetra
.519 .61 .884 r
.25075 .48744 .25714 .49651 .26695 .49537 .26048 .48739 Mtetra
.5 .634 .913 r
.26048 .48739 .26695 .49537 .27686 .49365 .27027 .48743 Mtetra
.473 .684 .958 r
.27027 .48743 .27686 .49365 .28688 .49107 .28012 .48734 Mtetra
.416 .758 .995 r
.28012 .48734 .28688 .49107 .29702 .48734 .29007 .48678 Mtetra
.26 .763 .879 r
.29007 .48678 .29702 .48734 .30729 .48217 .30012 .4854 Mtetra
0 0 0 r
.30012 .4854 .30729 .48217 .31768 .47556 .3103 .48293 Mtetra
.137 0 0 r
.3103 .48293 .31768 .47556 .32818 .46743 .32061 .47907 Mtetra
.212 0 .041 r
.32061 .47907 .32818 .46743 .33875 .45821 .33104 .47377 Mtetra
.241 0 .138 r
.33104 .47377 .33875 .45821 .34936 .44816 .34158 .46693 Mtetra
.248 0 .188 r
.34158 .46693 .34936 .44816 .36001 .43747 .35222 .45862 Mtetra
.245 0 .214 r
.35222 .45862 .36001 .43747 .37067 .42642 .36293 .44897 Mtetra
.261 0 .235 r
.36293 .44897 .37067 .42642 .38128 .41619 .37366 .43907 Mtetra
.273 0 .245 r
.37366 .43907 .38128 .41619 .39184 .40736 .38437 .42936 Mtetra
.234 0 .221 r
.38437 .42936 .39184 .40736 .40236 .39944 .39513 .41876 Mtetra
.136 0 .149 r
.39513 .41876 .40236 .39944 .41288 .39198 .40592 .4069 Mtetra
0 0 0 r
.40592 .4069 .41288 .39198 .42345 .38322 .41675 .39383 Mtetra
.41675 .39383 .42345 .38322 .43408 .3727 .42757 .38008 Mtetra
.534 .817 .469 r
.42757 .38008 .43408 .3727 .44472 .36179 .43832 .36785 Mtetra
0 0 0 r
.43832 .36785 .44472 .36179 .45533 .35136 .449 .35807 Mtetra
.449 .35807 .45533 .35136 .46591 .34275 .45964 .35064 Mtetra
.099 0 0 r
.45964 .35064 .46591 .34275 .47646 .3366 .47025 .3455 Mtetra
.242 0 0 r
.47025 .3455 .47646 .3366 .487 .33297 .48087 .34185 Mtetra
.324 0 .034 r
.48087 .34185 .487 .33297 .49756 .33184 .49151 .33969 Mtetra
.413 0 .047 r
.49151 .33969 .49756 .33184 .50817 .3332 .50219 .33983 Mtetra
.497 .019 .051 r
.50219 .33983 .50817 .3332 .51884 .3364 .51293 .34235 Mtetra
.578 .098 .078 r
.51293 .34235 .51884 .3364 .52961 .34012 .52375 .34737 Mtetra
.621 .166 .15 r
.52375 .34737 .52961 .34012 .54047 .34346 .53468 .35394 Mtetra
.6 .181 .219 r
.53468 .35394 .54047 .34346 .5514 .34504 .54573 .35985 Mtetra
.571 .189 .279 r
.54573 .35985 .5514 .34504 .5624 .34532 .55687 .36458 Mtetra
.548 .194 .32 r
.55687 .36458 .5624 .34532 .57348 .34609 .56809 .36806 Mtetra
.535 .194 .337 r
.56809 .36806 .57348 .34609 .58465 .34779 .5794 .37065 Mtetra
.538 .2 .344 r
.5794 .37065 .58465 .34779 .59593 .35094 .5908 .37346 Mtetra
.534 .195 .339 r
.5908 .37346 .59593 .35094 .60734 .35494 .6023 .37604 Mtetra
.512 .168 .321 r
.6023 .37604 .60734 .35494 .61883 .35861 .61384 .37727 Mtetra
.479 .125 .286 r
.61384 .37727 .61883 .35861 .6304 .36163 .62542 .37701 Mtetra
.427 .053 .225 r
.62542 .37701 .6304 .36163 .64204 .36384 .63702 .37519 Mtetra
.332 0 .105 r
.63702 .37519 .64204 .36384 .65372 .36495 .64863 .37188 Mtetra
.119 0 0 r
.64863 .37188 .65372 .36495 .66543 .3645 .66023 .36714 Mtetra
0 0 0 r
.66023 .36714 .66543 .3645 .67713 .36258 .67182 .36127 Mtetra
.698 .966 .937 r
.67182 .36127 .67713 .36258 .68882 .35917 .68339 .35456 Mtetra
.769 .874 .924 r
.68339 .35456 .68882 .35917 .70049 .35459 .69497 .34733 Mtetra
.758 .784 .875 r
.69497 .34733 .70049 .35459 .71216 .34909 .70657 .33995 Mtetra
.739 .729 .842 r
.70657 .33995 .71216 .34909 .72382 .34299 .71819 .33266 Mtetra
.721 .696 .826 r
.71819 .33266 .72382 .34299 .73551 .33665 .72987 .32574 Mtetra
.707 .68 .821 r
.72987 .32574 .73551 .33665 .74722 .33024 .7416 .31923 Mtetra
.695 .673 .825 r
.7416 .31923 .74722 .33024 .75897 .32404 .7534 .31328 Mtetra
.685 .674 .833 r
.7534 .31328 .75897 .32404 .77078 .31805 .76527 .30779 Mtetra
.677 .682 .847 r
.76527 .30779 .77078 .31805 .78265 .31239 .77722 .30276 Mtetra
.671 .695 .863 r
.77722 .30276 .78265 .31239 .79458 .30697 .78924 .29805 Mtetra
.668 .712 .881 r
.78924 .29805 .79458 .30697 .80657 .30175 .80133 .29357 Mtetra
.665 .733 .9 r
.80133 .29357 .80657 .30175 .81861 .29669 .81347 .28921 Mtetra
.682 .757 .908 r
.16646 .49655 .17328 .5025 .18292 .49957 .17622 .49262 Mtetra
.677 .726 .887 r
.17622 .49262 .18292 .49957 .19258 .49676 .18601 .48875 Mtetra
.667 .694 .866 r
.18601 .48875 .19258 .49676 .20226 .49417 .19581 .48502 Mtetra
.654 .663 .846 r
.19581 .48502 .20226 .49417 .21195 .4919 .20562 .48157 Mtetra
.638 .632 .828 r
.20562 .48157 .21195 .4919 .22164 .49006 .21543 .47849 Mtetra
.619 .601 .81 r
.21543 .47849 .22164 .49006 .23134 .48869 .22524 .47591 Mtetra
.598 .572 .795 r
.22524 .47591 .23134 .48869 .24103 .48786 .23503 .47396 Mtetra
.578 .545 .782 r
.23503 .47396 .24103 .48786 .25075 .48744 .2448 .47267 Mtetra
.556 .522 .773 r
.2448 .47267 .25075 .48744 .26048 .48739 .25457 .47214 Mtetra
.537 .506 .769 r
.25457 .47214 .26048 .48739 .27027 .48743 .26434 .47226 Mtetra
.519 .497 .772 r
.26434 .47226 .27027 .48743 .28012 .48734 .27411 .47298 Mtetra
.503 .5 .786 r
.27411 .47298 .28012 .48734 .29007 .48678 .28393 .47408 Mtetra
.486 .518 .815 r
.28393 .47408 .29007 .48678 .30012 .4854 .2938 .47535 Mtetra
.465 .563 .871 r
.2938 .47535 .30012 .4854 .3103 .48293 .30374 .4765 Mtetra
.41 .651 .957 r
.30374 .4765 .3103 .48293 .32061 .47907 .31378 .47724 Mtetra
.196 .7 .907 r
.31378 .47724 .32061 .47907 .33104 .47377 .32392 .4772 Mtetra
.159 0 0 r
.32392 .4772 .33104 .47377 .34158 .46693 .3342 .4761 Mtetra
.326 0 .032 r
.3342 .4761 .34158 .46693 .35222 .45862 .34457 .4741 Mtetra
.389 .018 .208 r
.34457 .4741 .35222 .45862 .36293 .44897 .35504 .47126 Mtetra
.42 .09 .297 r
.35504 .47126 .36293 .44897 .37366 .43907 .36559 .46763 Mtetra
.433 .126 .343 r
.36559 .46763 .37366 .43907 .38437 .42936 .37621 .46317 Mtetra
.429 .136 .364 r
.37621 .46317 .38437 .42936 .39513 .41876 .38694 .45722 Mtetra
.425 .143 .379 r
.38694 .45722 .39513 .41876 .40592 .4069 .39774 .44995 Mtetra
.449 .172 .399 r
.39774 .44995 .40592 .4069 .41675 .39383 .40853 .44362 Mtetra
.48 .207 .422 r
.40853 .44362 .41675 .39383 .42757 .38008 .41927 .43932 Mtetra
.507 .239 .443 r
.41927 .43932 .42757 .38008 .43832 .36785 .42998 .43758 Mtetra
.524 .26 .457 r
.42998 .43758 .43832 .36785 .449 .35807 .44069 .4381 Mtetra
.524 .266 .465 r
.44069 .4381 .449 .35807 .45964 .35064 .45146 .43851 Mtetra
.519 .264 .468 r
.45146 .43851 .45964 .35064 .47025 .3455 .46233 .43754 Mtetra
.508 .257 .468 r
.46233 .43754 .47025 .3455 .48087 .34185 .47331 .43394 Mtetra
.497 .247 .466 r
.47331 .43394 .48087 .34185 .49151 .33969 .48436 .42772 Mtetra
.488 .239 .462 r
.48436 .42772 .49151 .33969 .50219 .33983 .49545 .4201 Mtetra
.483 .231 .456 r
.49545 .4201 .50219 .33983 .51293 .34235 .50656 .41236 Mtetra
.49 .231 .45 r
.50656 .41236 .51293 .34235 .52375 .34737 .51769 .40687 Mtetra
.5 .233 .441 r
.51769 .40687 .52375 .34737 .53468 .35394 .52884 .40397 Mtetra
.51 .232 .429 r
.52884 .40397 .53468 .35394 .54573 .35985 .54006 .40313 Mtetra
.514 .228 .417 r
.54006 .40313 .54573 .35985 .55687 .36458 .55135 .40324 Mtetra
.499 .207 .401 r
.55135 .40324 .55687 .36458 .56809 .36806 .5627 .40202 Mtetra
.476 .178 .38 r
.5627 .40202 .56809 .36806 .5794 .37065 .5741 .3993 Mtetra
.453 .144 .35 r
.5741 .3993 .5794 .37065 .5908 .37346 .58552 .39574 Mtetra
.412 .083 .295 r
.58552 .39574 .5908 .37346 .6023 .37604 .59698 .39137 Mtetra
.325 0 .181 r
.59698 .39137 .6023 .37604 .61384 .37727 .60847 .38612 Mtetra
.113 0 0 r
.60847 .38612 .61384 .37727 .62542 .37701 .61996 .37997 Mtetra
.428 .838 .651 r
.61996 .37997 .62542 .37701 .63702 .37519 .63144 .3727 Mtetra
.789 .946 .926 r
.63144 .3727 .63702 .37519 .64863 .37188 .64292 .36462 Mtetra
.782 .787 .857 r
.64292 .36462 .64863 .37188 .66023 .36714 .6544 .3561 Mtetra
.747 .691 .798 r
.6544 .3561 .66023 .36714 .67182 .36127 .66589 .34743 Mtetra
.72 .637 .765 r
.66589 .34743 .67182 .36127 .68339 .35456 .67739 .33893 Mtetra
.701 .607 .748 r
.67739 .33893 .68339 .35456 .69497 .34733 .68893 .3308 Mtetra
.686 .59 .742 r
.68893 .3308 .69497 .34733 .70657 .33995 .70053 .32328 Mtetra
.674 .582 .744 r
.70053 .32328 .70657 .33995 .71819 .33266 .71218 .31642 Mtetra
.664 .582 .752 r
.71218 .31642 .71819 .33266 .72987 .32574 .72392 .31033 Mtetra
.657 .587 .765 r
.72392 .31033 .72987 .32574 .7416 .31923 .73573 .30492 Mtetra
.649 .597 .783 r
.73573 .30492 .7416 .31923 .7534 .31328 .74763 .30016 Mtetra
.644 .613 .803 r
.74763 .30016 .7534 .31328 .76527 .30779 .75961 .29591 Mtetra
.639 .632 .827 r
.75961 .29591 .76527 .30779 .77722 .30276 .77167 .29205 Mtetra
.636 .655 .852 r
.77167 .29205 .77722 .30276 .78924 .29805 .78381 .28847 Mtetra
.633 .68 .877 r
.78381 .28847 .78924 .29805 .80133 .29357 .79602 .28505 Mtetra
.631 .71 .903 r
.79602 .28505 .80133 .29357 .81347 .28921 .8083 .28168 Mtetra
.709 .762 .894 r
.15958 .49055 .16646 .49655 .17622 .49262 .16945 .48582 Mtetra
.705 .738 .877 r
.16945 .48582 .17622 .49262 .18601 .48875 .17935 .48104 Mtetra
.698 .712 .859 r
.17935 .48104 .18601 .48875 .19581 .48502 .18927 .4763 Mtetra
.688 .685 .842 r
.18927 .4763 .19581 .48502 .20562 .48157 .19921 .47167 Mtetra
.676 .656 .823 r
.19921 .47167 .20562 .48157 .21543 .47849 .20917 .46723 Mtetra
.66 .625 .804 r
.20917 .46723 .21543 .47849 .22524 .47591 .21911 .46311 Mtetra
.641 .593 .785 r
.21911 .46311 .22524 .47591 .23503 .47396 .22906 .45944 Mtetra
.621 .561 .765 r
.22906 .45944 .23503 .47396 .2448 .47267 .23898 .45636 Mtetra
.599 .529 .747 r
.23898 .45636 .2448 .47267 .25457 .47214 .24888 .454 Mtetra
.579 .501 .731 r
.24888 .454 .25457 .47214 .26434 .47226 .25877 .45242 Mtetra
.559 .475 .717 r
.25877 .45242 .26434 .47226 .27411 .47298 .26863 .45168 Mtetra
.542 .455 .706 r
.26863 .45168 .27411 .47298 .28393 .47408 .27849 .45172 Mtetra
.528 .439 .698 r
.27849 .45172 .28393 .47408 .2938 .47535 .28836 .45248 Mtetra
.518 .43 .695 r
.28836 .45248 .2938 .47535 .30374 .4765 .29826 .45376 Mtetra
.51 .426 .697 r
.29826 .45376 .30374 .4765 .31378 .47724 .3082 .45539 Mtetra
.509 .431 .704 r
.3082 .45539 .31378 .47724 .32392 .4772 .31821 .45701 Mtetra
.512 .446 .719 r
.31821 .45701 .32392 .4772 .3342 .4761 .32831 .45835 Mtetra
.51 .467 .745 r
.32831 .45835 .3342 .4761 .34457 .4741 .33849 .45955 Mtetra
.505 .503 .788 r
.33849 .45955 .34457 .4741 .35504 .47126 .34874 .46057 Mtetra
.514 .578 .857 r
.34874 .46057 .35504 .47126 .36559 .46763 .35911 .46078 Mtetra
.528 .695 .945 r
.35911 .46078 .36559 .46763 .37621 .46317 .3696 .45991 Mtetra
.489 .816 1 r
.3696 .45991 .37621 .46317 .38694 .45722 .38018 .45814 Mtetra
.196 .724 .754 r
.38018 .45814 .38694 .45722 .39774 .44995 .39083 .45592 Mtetra
.322 0 0 r
.39083 .45592 .39774 .44995 .40853 .44362 .40147 .45536 Mtetra
.502 .092 .195 r
.40147 .45536 .40853 .44362 .41927 .43932 .41209 .45716 Mtetra
.541 .179 .302 r
.41209 .45716 .41927 .43932 .42998 .43758 .42275 .46021 Mtetra
.546 .207 .344 r
.42275 .46021 .42998 .43758 .44069 .4381 .43349 .46359 Mtetra
.523 .196 .354 r
.43349 .46359 .44069 .4381 .45146 .43851 .44436 .46541 Mtetra
.487 .167 .349 r
.44436 .46541 .45146 .43851 .46233 .43754 .45536 .46469 Mtetra
.442 .127 .334 r
.45536 .46469 .46233 .43754 .47331 .43394 .46648 .4611 Mtetra
.391 .082 .317 r
.46648 .4611 .47331 .43394 .48436 .42772 .47768 .45463 Mtetra
.339 .037 .297 r
.47768 .45463 .48436 .42772 .49545 .4201 .48894 .44561 Mtetra
.292 0 .271 r
.48894 .44561 .49545 .4201 .50656 .41236 .50022 .43498 Mtetra
.266 0 .239 r
.50022 .43498 .50656 .41236 .51769 .40687 .5115 .42468 Mtetra
.226 0 .17 r
.5115 .42468 .51769 .40687 .52884 .40397 .52277 .4156 Mtetra
.169 0 .025 r
.52277 .4156 .52884 .40397 .54006 .40313 .53406 .40889 Mtetra
0 0 0 r
.53406 .40889 .54006 .40313 .55135 .40324 .54539 .40385 Mtetra
.527 .921 .863 r
.54539 .40385 .55135 .40324 .5627 .40202 .55675 .39835 Mtetra
.744 .894 .946 r
.55675 .39835 .5627 .40202 .5741 .3993 .56813 .39193 Mtetra
.76 .774 .864 r
.56813 .39193 .5741 .3993 .58552 .39574 .57952 .3844 Mtetra
.739 .68 .794 r
.57952 .3844 .58552 .39574 .59698 .39137 .59092 .37602 Mtetra
.71 .613 .747 r
.59092 .37602 .59698 .39137 .60847 .38612 .60232 .36744 Mtetra
.69 .572 .717 r
.60232 .36744 .60847 .38612 .61996 .37997 .61374 .35871 Mtetra
.68 .548 .698 r
.61374 .35871 .61996 .37997 .63144 .3727 .62515 .34966 Mtetra
.671 .533 .688 r
.62515 .34966 .63144 .3727 .64292 .36462 .63658 .34058 Mtetra
.663 .523 .683 r
.63658 .34058 .64292 .36462 .6544 .3561 .64803 .33185 Mtetra
.656 .518 .683 r
.64803 .33185 .6544 .3561 .66589 .34743 .65951 .32364 Mtetra
.649 .516 .687 r
.65951 .32364 .66589 .34743 .67739 .33893 .67105 .31615 Mtetra
.643 .518 .695 r
.67105 .31615 .67739 .33893 .68893 .3308 .68264 .30944 Mtetra
.637 .523 .707 r
.68264 .30944 .68893 .3308 .70053 .32328 .69431 .30361 Mtetra
.632 .532 .723 r
.69431 .30361 .70053 .32328 .71218 .31642 .70607 .29857 Mtetra
.626 .544 .743 r
.70607 .29857 .71218 .31642 .72392 .31033 .71791 .29427 Mtetra
.621 .56 .765 r
.71791 .29427 .72392 .31033 .73573 .30492 .72984 .29058 Mtetra
.616 .58 .79 r
.72984 .29058 .73573 .30492 .74763 .30016 .74186 .28736 Mtetra
.612 .602 .817 r
.74186 .28736 .74763 .30016 .75961 .29591 .75396 .28447 Mtetra
.609 .626 .843 r
.75396 .28447 .75961 .29591 .77167 .29205 .76613 .28178 Mtetra
.605 .651 .869 r
.76613 .28178 .77167 .29205 .78381 .28847 .77838 .2792 Mtetra
.603 .676 .892 r
.77838 .2792 .78381 .28847 .79602 .28505 .7907 .27667 Mtetra
.601 .701 .914 r
.7907 .27667 .79602 .28505 .8083 .28168 .80308 .27409 Mtetra
.72 .764 .887 r
.15266 .48451 .15958 .49055 .16945 .48582 .1626 .47936 Mtetra
.721 .752 .877 r
.1626 .47936 .16945 .48582 .17935 .48104 .17257 .47408 Mtetra
.72 .738 .866 r
.17257 .47408 .17935 .48104 .18927 .4763 .18258 .4687 Mtetra
.717 .721 .853 r
.18258 .4687 .18927 .4763 .19921 .47167 .19262 .46325 Mtetra
.712 .701 .838 r
.19262 .46325 .19921 .47167 .20917 .46723 .2027 .45772 Mtetra
.703 .675 .82 r
.2027 .45772 .20917 .46723 .21911 .46311 .21279 .45222 Mtetra
.69 .645 .8 r
.21279 .45222 .21911 .46311 .22906 .45944 .22289 .44685 Mtetra
.673 .612 .779 r
.22289 .44685 .22906 .45944 .23898 .45636 .233 .44175 Mtetra
.653 .577 .757 r
.233 .44175 .23898 .45636 .24888 .454 .2431 .43706 Mtetra
.632 .543 .735 r
.2431 .43706 .24888 .454 .25877 .45242 .25318 .43291 Mtetra
.611 .51 .714 r
.25318 .43291 .25877 .45242 .26863 .45168 .26324 .42946 Mtetra
.592 .48 .695 r
.26324 .42946 .26863 .45168 .27849 .45172 .27328 .42673 Mtetra
.574 .455 .679 r
.27328 .42673 .27849 .45172 .28836 .45248 .28331 .4248 Mtetra
.56 .434 .665 r
.28331 .4248 .28836 .45248 .29826 .45376 .29332 .42362 Mtetra
.548 .417 .654 r
.29332 .42362 .29826 .45376 .3082 .45539 .30334 .42317 Mtetra
.539 .405 .646 r
.30334 .42317 .3082 .45539 .31821 .45701 .31339 .42328 Mtetra
.534 .396 .64 r
.31339 .42328 .31821 .45701 .32831 .45835 .32346 .42382 Mtetra
.528 .391 .638 r
.32346 .42382 .32831 .45835 .33849 .45955 .33358 .42478 Mtetra
.524 .388 .637 r
.33358 .42478 .33849 .45955 .34874 .46057 .34375 .42605 Mtetra
.53 .393 .639 r
.34375 .42605 .34874 .46057 .35911 .46078 .35401 .42686 Mtetra
.54 .402 .641 r
.35401 .42686 .35911 .46078 .3696 .45991 .36438 .42691 Mtetra
.537 .402 .645 r
.36438 .42691 .3696 .45991 .38018 .45814 .3748 .42721 Mtetra
.527 .402 .654 r
.3748 .42721 .38018 .45814 .39083 .45592 .38526 .42822 Mtetra
.51 .403 .669 r
.38526 .42822 .39083 .45592 .40147 .45536 .39575 .43018 Mtetra
.494 .405 .684 r
.39575 .43018 .40147 .45536 .41209 .45716 .4063 .4328 Mtetra
.519 .427 .691 r
.4063 .4328 .41209 .45716 .42275 .46021 .41698 .43404 Mtetra
.556 .442 .679 r
.41698 .43404 .42275 .46021 .43349 .46359 .42779 .43318 Mtetra
.574 .438 .658 r
.42779 .43318 .43349 .46359 .44436 .46541 .43871 .43073 Mtetra
.582 .431 .642 r
.43871 .43073 .44436 .46541 .45536 .46469 .44971 .42708 Mtetra
.578 .422 .633 r
.44971 .42708 .45536 .46469 .46648 .4611 .46075 .42343 Mtetra
.46075 .42343 .46648 .4611 .47768 .45463 .47184 .41979 Mtetra
.594 .439 .641 r
.47184 .41979 .47768 .45463 .48894 .44561 .48298 .41495 Mtetra
.618 .468 .655 r
.48298 .41495 .48894 .44561 .50022 .43498 .49418 .4085 Mtetra
.653 .505 .67 r
.49418 .4085 .50022 .43498 .5115 .42468 .50542 .39992 Mtetra
.674 .526 .676 r
.50542 .39992 .5115 .42468 .52277 .4156 .51668 .38993 Mtetra
.664 .515 .672 r
.51668 .38993 .52277 .4156 .53406 .40889 .52794 .38059 Mtetra
.644 .493 .662 r
.52794 .38059 .53406 .40889 .54539 .40385 .53921 .37219 Mtetra
.628 .471 .65 r
.53921 .37219 .54539 .40385 .55675 .39835 .55049 .36448 Mtetra
.62 .459 .643 r
.55049 .36448 .55675 .39835 .56813 .39193 .56181 .35703 Mtetra
.625 .46 .639 r
.56181 .35703 .56813 .39193 .57952 .3844 .57312 .34879 Mtetra
.627 .46 .636 r
.57312 .34879 .57952 .3844 .59092 .37602 .58445 .34005 Mtetra
.624 .457 .636 r
.58445 .34005 .59092 .37602 .60232 .36744 .59579 .33161 Mtetra
.62 .455 .636 r
.59579 .33161 .60232 .36744 .61374 .35871 .60716 .32359 Mtetra
.618 .455 .639 r
.60716 .32359 .61374 .35871 .62515 .34966 .61856 .316 Mtetra
.616 .457 .644 r
.61856 .316 .62515 .34966 .63658 .34058 .63 .30896 Mtetra
.613 .461 .652 r
.63 .30896 .63658 .34058 .64803 .33185 .64149 .30267 Mtetra
.61 .467 .663 r
.64149 .30267 .64803 .33185 .65951 .32364 .65304 .29713 Mtetra
.607 .476 .677 r
.65304 .29713 .65951 .32364 .67105 .31615 .66467 .29241 Mtetra
.603 .487 .694 r
.66467 .29241 .67105 .31615 .68264 .30944 .67637 .28844 Mtetra
.599 .502 .716 r
.67637 .28844 .68264 .30944 .69431 .30361 .68817 .28518 Mtetra
.594 .521 .741 r
.68817 .28518 .69431 .30361 .70607 .29857 .70005 .28248 Mtetra
.59 .543 .77 r
.70005 .28248 .70607 .29857 .71791 .29427 .71202 .28021 Mtetra
.586 .568 .8 r
.71202 .28021 .71791 .29427 .72984 .29058 .72407 .27823 Mtetra
.584 .595 .83 r
.72407 .27823 .72984 .29058 .74186 .28736 .73619 .27637 Mtetra
.581 .622 .858 r
.73619 .27637 .74186 .28736 .75396 .28447 .74839 .27455 Mtetra
.581 .648 .881 r
.74839 .27455 .75396 .28447 .76613 .28178 .76066 .27267 Mtetra
.581 .67 .9 r
.76066 .27267 .76613 .28178 .77838 .2792 .77298 .2707 Mtetra
.581 .689 .915 r
.77298 .2707 .77838 .2792 .7907 .27667 .78537 .26863 Mtetra
.583 .705 .926 r
.78537 .26863 .7907 .27667 .80308 .27409 .79782 .26643 Mtetra
.712 .763 .892 r
.14569 .47843 .15266 .48451 .1626 .47936 .15562 .47355 Mtetra
.718 .773 .896 r
.15562 .47355 .1626 .47936 .17257 .47408 .16559 .46851 Mtetra
.724 .782 .899 r
.16559 .46851 .17257 .47408 .18258 .4687 .17561 .46328 Mtetra
.731 .789 .898 r
.17561 .46328 .18258 .4687 .19262 .46325 .18568 .45784 Mtetra
.739 .791 .894 r
.18568 .45784 .19262 .46325 .2027 .45772 .1958 .45213 Mtetra
.743 .786 .888 r
.1958 .45213 .2027 .45772 .21279 .45222 .20596 .44621 Mtetra
.745 .774 .877 r
.20596 .44621 .21279 .45222 .22289 .44685 .21616 .4401 Mtetra
.74 .753 .863 r
.21616 .4401 .22289 .44685 .233 .44175 .22638 .43392 Mtetra
.73 .723 .844 r
.22638 .43392 .233 .44175 .2431 .43706 .23663 .42776 Mtetra
.714 .686 .822 r
.23663 .42776 .2431 .43706 .25318 .43291 .24688 .42179 Mtetra
.693 .645 .797 r
.24688 .42179 .25318 .43291 .26324 .42946 .25713 .41613 Mtetra
.67 .603 .771 r
.25713 .41613 .26324 .42946 .27328 .42673 .26737 .4109 Mtetra
.646 .562 .746 r
.26737 .4109 .27328 .42673 .28331 .4248 .27759 .40622 Mtetra
.624 .525 .722 r
.27759 .40622 .28331 .4248 .29332 .42362 .2878 .40214 Mtetra
.603 .493 .7 r
.2878 .40214 .29332 .42362 .30334 .42317 .298 .39874 Mtetra
.587 .466 .682 r
.298 .39874 .30334 .42317 .31339 .42328 .3082 .39599 Mtetra
.572 .444 .667 r
.3082 .39599 .31339 .42328 .32346 .42382 .31839 .39388 Mtetra
.562 .428 .655 r
.31839 .39388 .32346 .42382 .33358 .42478 .3286 .3923 Mtetra
.555 .415 .645 r
.3286 .3923 .33358 .42478 .34375 .42605 .33885 .3911 Mtetra
.555 .408 .637 r
.33885 .3911 .34375 .42605 .35401 .42686 .34915 .3898 Mtetra
.556 .405 .631 r
.34915 .3898 .35401 .42686 .36438 .42691 .35952 .38824 Mtetra
.548 .395 .626 r
.35952 .38824 .36438 .42691 .3748 .42721 .36991 .3874 Mtetra
.538 .386 .623 r
.36991 .3874 .3748 .42721 .38526 .42822 .38032 .38745 Mtetra
.541 .386 .621 r
.38032 .38745 .38526 .42822 .39575 .43018 .39081 .38722 Mtetra
.55 .39 .616 r
.39081 .38722 .39575 .43018 .4063 .4328 .4014 .38593 Mtetra
.569 .398 .609 r
.4014 .38593 .4063 .4328 .41698 .43404 .41213 .38221 Mtetra
.584 .402 .601 r
.41213 .38221 .41698 .43404 .42779 .43318 .42299 .37601 Mtetra
.582 .395 .594 r
.42299 .37601 .42779 .43318 .43871 .43073 .43388 .36934 Mtetra
.574 .386 .589 r
.43388 .36934 .43871 .43073 .44971 .42708 .44478 .36337 Mtetra
.559 .373 .585 r
.44478 .36337 .44971 .42708 .46075 .42343 .45566 .35965 Mtetra
.545 .362 .585 r
.45566 .35965 .46075 .42343 .47184 .41979 .46654 .35818 Mtetra
.541 .361 .587 r
.46654 .35818 .47184 .41979 .48298 .41495 .47747 .35742 Mtetra
.545 .368 .592 r
.47747 .35742 .48298 .41495 .49418 .4085 .48847 .3562 Mtetra
.565 .388 .601 r
.48847 .3562 .49418 .4085 .50542 .39992 .49955 .35249 Mtetra
.587 .41 .609 r
.49955 .35249 .50542 .39992 .51668 .38993 .51069 .34632 Mtetra
.6 .425 .616 r
.51069 .34632 .51668 .38993 .52794 .38059 .52186 .33908 Mtetra
.606 .432 .621 r
.52186 .33908 .52794 .38059 .53921 .37219 .53305 .33154 Mtetra
.6 .43 .623 r
.53305 .33154 .53921 .37219 .55049 .36448 .54426 .32489 Mtetra
.595 .428 .626 r
.54426 .32489 .55049 .36448 .56181 .35703 .55551 .31895 Mtetra
.6 .435 .63 r
.55551 .31895 .56181 .35703 .57312 .34879 .56678 .31275 Mtetra
.604 .442 .636 r
.56678 .31275 .57312 .34879 .58445 .34005 .57808 .30643 Mtetra
.605 .449 .644 r
.57808 .30643 .58445 .34005 .59579 .33161 .58942 .3005 Mtetra
.604 .456 .653 r
.58942 .3005 .59579 .33161 .60716 .32359 .6008 .29509 Mtetra
.602 .464 .665 r
.6008 .29509 .60716 .32359 .61856 .316 .61224 .29034 Mtetra
.6 .475 .681 r
.61224 .29034 .61856 .316 .63 .30896 .62374 .28625 Mtetra
.597 .489 .701 r
.62374 .28625 .63 .30896 .64149 .30267 .63532 .28285 Mtetra
.593 .507 .726 r
.63532 .28285 .64149 .30267 .65304 .29713 .64697 .28007 Mtetra
.587 .529 .757 r
.64697 .28007 .65304 .29713 .66467 .29241 .6587 .27786 Mtetra
.58 .556 .792 r
.6587 .27786 .66467 .29241 .67637 .28844 .67052 .27609 Mtetra
.571 .587 .83 r
.67052 .27609 .67637 .28844 .68817 .28518 .68242 .27465 Mtetra
.561 .621 .869 r
.68242 .27465 .68817 .28518 .70005 .28248 .6944 .27341 Mtetra
.552 .654 .903 r
.6944 .27341 .70005 .28248 .71202 .28021 .70646 .2722 Mtetra
.545 .684 .929 r
.70646 .2722 .71202 .28021 .72407 .27823 .71858 .27092 Mtetra
.545 .708 .946 r
.71858 .27092 .72407 .27823 .73619 .27637 .73077 .26946 Mtetra
.549 .725 .955 r
.73077 .26946 .73619 .27637 .74839 .27455 .74302 .26778 Mtetra
.56 .736 .958 r
.74302 .26778 .74839 .27455 .76066 .27267 .75531 .26582 Mtetra
.571 .739 .955 r
.75531 .26582 .76066 .27267 .77298 .2707 .76766 .26364 Mtetra
.581 .738 .95 r
.76766 .26364 .77298 .2707 .78537 .26863 .78007 .26126 Mtetra
.591 .732 .942 r
.78007 .26126 .78537 .26863 .79782 .26643 .79252 .25872 Mtetra
.684 .758 .907 r
.13868 .4723 .14569 .47843 .15562 .47355 .14853 .46823 Mtetra
.691 .787 .924 r
.14853 .46823 .15562 .47355 .16559 .46851 .15844 .46402 Mtetra
.699 .818 .939 r
.15844 .46402 .16559 .46851 .17561 .46328 .1684 .45958 Mtetra
.708 .849 .949 r
.1684 .45958 .17561 .46328 .18568 .45784 .17842 .45487 Mtetra
.72 .877 .954 r
.17842 .45487 .18568 .45784 .1958 .45213 .18851 .44978 Mtetra
.73 .9 .955 r
.18851 .44978 .1958 .45213 .20596 .44621 .19866 .44431 Mtetra
.743 .917 .951 r
.19866 .44431 .20596 .44621 .21616 .4401 .20888 .43843 Mtetra
.755 .925 .946 r
.20888 .43843 .21616 .4401 .22638 .43392 .21915 .43219 Mtetra
.767 .924 .939 r
.21915 .43219 .22638 .43392 .23663 .42776 .22947 .42563 Mtetra
.777 .912 .932 r
.22947 .42563 .23663 .42776 .24688 .42179 .23983 .41886 Mtetra
.781 .885 .921 r
.23983 .41886 .24688 .42179 .25713 .41613 .25022 .41198 Mtetra
.776 .843 .903 r
.25022 .41198 .25713 .41613 .26737 .4109 .26063 .40512 Mtetra
.76 .79 .877 r
.26063 .40512 .26737 .4109 .27759 .40622 .27104 .39838 Mtetra
.737 .73 .844 r
.27104 .39838 .27759 .40622 .2878 .40214 .28145 .3919 Mtetra
.709 .67 .81 r
.28145 .3919 .2878 .40214 .298 .39874 .29186 .38577 Mtetra
.68 .615 .775 r
.29186 .38577 .298 .39874 .3082 .39599 .30225 .38009 Mtetra
.654 .567 .745 r
.30225 .38009 .3082 .39599 .31839 .39388 .31264 .3749 Mtetra
.635 .529 .717 r
.31264 .3749 .31839 .39388 .3286 .3923 .32304 .37002 Mtetra
.62 .499 .694 r
.32304 .37002 .3286 .3923 .33885 .3911 .33346 .36536 Mtetra
.607 .474 .674 r
.33346 .36536 .33885 .3911 .34915 .3898 .3439 .36092 Mtetra
.597 .455 .659 r
.3439 .36092 .34915 .3898 .35952 .38824 .35436 .3567 Mtetra
.584 .438 .648 r
.35436 .3567 .35952 .38824 .36991 .3874 .36483 .35311 Mtetra
.575 .424 .639 r
.36483 .35311 .36991 .3874 .38032 .38745 .37532 .34997 Mtetra
.586 .424 .629 r
.37532 .34997 .38032 .38745 .39081 .38722 .38591 .34543 Mtetra
.599 .425 .618 r
.38591 .34543 .39081 .38722 .4014 .38593 .39662 .33875 Mtetra
.606 .423 .608 r
.39662 .33875 .4014 .38593 .41213 .38221 .40744 .33004 Mtetra
.608 .419 .6 r
.40744 .33004 .41213 .38221 .42299 .37601 .4183 .31997 Mtetra
.597 .407 .594 r
.4183 .31997 .42299 .37601 .43388 .36934 .42914 .31086 Mtetra
.581 .392 .59 r
.42914 .31086 .43388 .36934 .44478 .36337 .43992 .30393 Mtetra
.56 .376 .588 r
.43992 .30393 .44478 .36337 .45566 .35965 .45065 .30014 Mtetra
.539 .36 .587 r
.45065 .30014 .45566 .35965 .46654 .35818 .46136 .29949 Mtetra
.523 .349 .587 r
.46136 .29949 .46654 .35818 .47747 .35742 .47209 .30104 Mtetra
.515 .346 .59 r
.47209 .30104 .47747 .35742 .48847 .3562 .48289 .30358 Mtetra
.525 .358 .597 r
.48289 .30358 .48847 .3562 .49955 .35249 .4938 .30476 Mtetra
.543 .377 .606 r
.4938 .30476 .49955 .35249 .51069 .34632 .50479 .30391 Mtetra
.565 .401 .618 r
.50479 .30391 .51069 .34632 .52186 .33908 .51586 .3009 Mtetra
.582 .422 .629 r
.51586 .3009 .52186 .33908 .53305 .33154 .52697 .29649 Mtetra
.582 .429 .639 r
.52697 .29649 .53305 .33154 .54426 .32489 .53813 .29253 Mtetra
.579 .434 .649 r
.53813 .29253 .54426 .32489 .55551 .31895 .54934 .2892 Mtetra
.579 .443 .66 r
.54934 .2892 .55551 .31895 .56678 .31275 .56061 .2861 Mtetra
.581 .457 .676 r
.56061 .2861 .56678 .31275 .57808 .30643 .57193 .28322 Mtetra
.584 .476 .698 r
.57193 .28322 .57808 .30643 .58942 .3005 .5833 .28057 Mtetra
.584 .499 .725 r
.5833 .28057 .58942 .3005 .6008 .29509 .59474 .27823 Mtetra
.579 .525 .759 r
.59474 .27823 .6008 .29509 .61224 .29034 .60626 .27642 Mtetra
.57 .558 .802 r
.60626 .27642 .61224 .29034 .62374 .28625 .61785 .27505 Mtetra
.555 .6 .854 r
.61785 .27505 .62374 .28625 .63532 .28285 .62952 .27406 Mtetra
.53 .649 .91 r
.62952 .27406 .63532 .28285 .64697 .28007 .64128 .27333 Mtetra
.491 .698 .961 r
.64128 .27333 .64697 .28007 .6587 .27786 .65311 .27275 Mtetra
.44 .736 .99 r
.65311 .27275 .6587 .27786 .67052 .27609 .66502 .27219 Mtetra
.39 .758 .992 r
.66502 .27219 .67052 .27609 .68242 .27465 .677 .27153 Mtetra
.359 .77 .981 r
.677 .27153 .68242 .27465 .6944 .27341 .68905 .27066 Mtetra
.361 .784 .974 r
.68905 .27066 .6944 .27341 .70646 .2722 .70116 .26946 Mtetra
.39 .802 .979 r
.70116 .26946 .70646 .2722 .71858 .27092 .71332 .26789 Mtetra
.442 .821 .99 r
.71332 .26789 .71858 .27092 .73077 .26946 .72553 .2659 Mtetra
.496 .831 .999 r
.72553 .2659 .73077 .26946 .74302 .26778 .73777 .26352 Mtetra
.548 .829 .998 r
.73777 .26352 .74302 .26778 .75531 .26582 .75006 .26076 Mtetra
.585 .815 .987 r
.75006 .26076 .75531 .26582 .76766 .26364 .76239 .25769 Mtetra
.609 .793 .969 r
.76239 .25769 .76766 .26364 .78007 .26126 .77476 .2544 Mtetra
.624 .767 .948 r
.77476 .2544 .78007 .26126 .79252 .25872 .78718 .25095 Mtetra
.637 .747 .928 r
.13161 .46613 .13868 .4723 .14853 .46823 .14135 .4632 Mtetra
.636 .787 .955 r
.14135 .4632 .14853 .46823 .15844 .46402 .15115 .46018 Mtetra
.632 .832 .977 r
.15115 .46018 .15844 .46402 .1684 .45958 .161 .45697 Mtetra
.623 .875 .989 r
.161 .45697 .1684 .45958 .17842 .45487 .17092 .45351 Mtetra
.606 .91 .981 r
.17092 .45351 .17842 .45487 .18851 .44978 .18091 .44969 Mtetra
.573 .928 .946 r
.18091 .44969 .18851 .44978 .19866 .44431 .19097 .44548 Mtetra
.529 .921 .883 r
.19097 .44548 .19866 .44431 .20888 .43843 .20112 .4408 Mtetra
.475 .892 .799 r
.20112 .4408 .20888 .43843 .21915 .43219 .21134 .43565 Mtetra
.425 .851 .712 r
.21134 .43565 .21915 .43219 .22947 .42563 .22164 .43001 Mtetra
.379 .808 .634 r
.22164 .43001 .22947 .42563 .23983 .41886 .23199 .42394 Mtetra
0 0 0 r
.23199 .42394 .23983 .41886 .25022 .41198 .24241 .4175 Mtetra
.24241 .4175 .25022 .41198 .26063 .40512 .25286 .41079 Mtetra
.25286 .41079 .26063 .40512 .27104 .39838 .26335 .4039 Mtetra
.26335 .4039 .27104 .39838 .28145 .3919 .27387 .39696 Mtetra
.27387 .39696 .28145 .3919 .29186 .38577 .28439 .39007 Mtetra
.428 .836 .647 r
.28439 .39007 .29186 .38577 .30225 .38009 .29493 .38334 Mtetra
.492 .888 .733 r
.29493 .38334 .30225 .38009 .31264 .3749 .30546 .37689 Mtetra
.586 .945 .833 r
.30546 .37689 .31264 .3749 .32304 .37002 .31601 .37054 Mtetra
.672 .971 .912 r
.31601 .37054 .32304 .37002 .33346 .36536 .32658 .36427 Mtetra
.71 .95 .954 r
.32658 .36427 .33346 .36536 .3439 .36092 .33715 .35836 Mtetra
.715 .908 .963 r
.33715 .35836 .3439 .36092 .35436 .3567 .34772 .35293 Mtetra
.709 .865 .956 r
.34772 .35293 .35436 .3567 .36483 .35311 .35829 .34787 Mtetra
.709 .812 .929 r
.35829 .34787 .36483 .35311 .37532 .34997 .3689 .34286 Mtetra
.74 .76 .869 r
.3689 .34286 .37532 .34997 .38591 .34543 .3796 .33645 Mtetra
.759 .719 .815 r
.3796 .33645 .38591 .34543 .39662 .33875 .39041 .32827 Mtetra
.755 .689 .788 r
.39041 .32827 .39662 .33875 .40744 .33004 .40125 .31941 Mtetra
.752 .686 .787 r
.40125 .31941 .40744 .33004 .4183 .31997 .41209 .31064 Mtetra
.742 .708 .819 r
.41209 .31064 .4183 .31997 .42914 .31086 .4229 .30319 Mtetra
.714 .741 .873 r
.4229 .30319 .42914 .31086 .43992 .30393 .43368 .29762 Mtetra
.661 .768 .93 r
.43368 .29762 .43992 .30393 .45065 .30014 .44444 .2938 Mtetra
.579 .74 .952 r
.44444 .2938 .45065 .30014 .46136 .29949 .4552 .29174 Mtetra
.493 .654 .931 r
.4552 .29174 .46136 .29949 .47209 .30104 .46598 .29156 Mtetra
.446 .578 .892 r
.46598 .29156 .47209 .30104 .48289 .30358 .47681 .29273 Mtetra
.461 .552 .862 r
.47681 .29273 .48289 .30358 .4938 .30476 .48771 .294 Mtetra
.49 .57 .864 r
.48771 .294 .4938 .30476 .50479 .30391 .49871 .29461 Mtetra
.556 .641 .89 r
.49871 .29461 .50479 .30391 .51586 .3009 .50978 .29343 Mtetra
.607 .718 .924 r
.50978 .29343 .51586 .3009 .52697 .29649 .52093 .29085 Mtetra
.587 .776 .969 r
.52093 .29085 .52697 .29649 .53813 .29253 .53213 .28833 Mtetra
.53 .809 .997 r
.53213 .28833 .53813 .29253 .54934 .2892 .54338 .28618 Mtetra
.437 .811 .993 r
.54338 .28618 .54934 .2892 .56061 .2861 .5547 .28451 Mtetra
.293 .772 .925 r
.5547 .28451 .56061 .2861 .57193 .28322 .56609 .28323 Mtetra
.132 .68 .774 r
.56609 .28323 .57193 .28322 .5833 .28057 .57755 .28204 Mtetra
.018 0 0 r
.57755 .28204 .5833 .28057 .59474 .27823 .58908 .28095 Mtetra
.142 0 0 r
.58908 .28095 .59474 .27823 .60626 .27642 .60068 .28015 Mtetra
.217 0 0 r
.60068 .28015 .60626 .27642 .61785 .27505 .61237 .27954 Mtetra
.257 0 0 r
.61237 .27954 .61785 .27505 .62952 .27406 .62413 .27898 Mtetra
.272 0 0 r
.62413 .27898 .62952 .27406 .64128 .27333 .63596 .27837 Mtetra
.266 0 0 r
.63596 .27837 .64128 .27333 .65311 .27275 .64786 .2776 Mtetra
.241 0 0 r
.64786 .2776 .65311 .27275 .66502 .27219 .65983 .27655 Mtetra
.192 0 0 r
.65983 .27655 .66502 .27219 .677 .27153 .67185 .27512 Mtetra
.117 0 0 r
.67185 .27512 .677 .27153 .68905 .27066 .68393 .27326 Mtetra
.005 0 0 r
.68393 .27326 .68905 .27066 .70116 .26946 .69604 .27089 Mtetra
0 0 0 r
.69604 .27089 .70116 .26946 .71332 .26789 .70819 .26804 Mtetra
.307 .8 .818 r
.70819 .26804 .71332 .26789 .72553 .2659 .72038 .2647 Mtetra
.457 .877 .931 r
.72038 .2647 .72553 .2659 .73777 .26352 .73259 .26094 Mtetra
.566 .898 .983 r
.73259 .26094 .73777 .26352 .75006 .26076 .74484 .25682 Mtetra
.629 .878 .988 r
.74484 .25682 .75006 .26076 .76239 .25769 .75712 .25241 Mtetra
.659 .84 .97 r
.75712 .25241 .76239 .25769 .77476 .2544 .76944 .24782 Mtetra
.671 .798 .943 r
.76944 .24782 .77476 .2544 .78718 .25095 .7818 .24311 Mtetra
.576 .729 .946 r
.12449 .45992 .13161 .46613 .14135 .4632 .13411 .45815 Mtetra
.561 .767 .974 r
.13411 .45815 .14135 .4632 .15115 .46018 .14379 .45634 Mtetra
.538 .806 .995 r
.14379 .45634 .15115 .46018 .161 .45697 .15352 .45444 Mtetra
.5 .84 .997 r
.15352 .45444 .161 .45697 .17092 .45351 .16331 .45237 Mtetra
.439 .852 .962 r
.16331 .45237 .17092 .45351 .18091 .44969 .17318 .45007 Mtetra
.35 .825 .87 r
.17318 .45007 .18091 .44969 .19097 .44548 .18312 .44745 Mtetra
.243 .751 .724 r
.18312 .44745 .19097 .44548 .20112 .4408 .19314 .44445 Mtetra
0 0 0 r
.19314 .44445 .20112 .4408 .21134 .43565 .20325 .44102 Mtetra
.20325 .44102 .21134 .43565 .22164 .43001 .21344 .43709 Mtetra
.029 0 0 r
.21344 .43709 .22164 .43001 .23199 .42394 .22371 .43269 Mtetra
.082 0 0 r
.22371 .43269 .23199 .42394 .24241 .4175 .23406 .4278 Mtetra
.124 0 0 r
.23406 .4278 .24241 .4175 .25286 .41079 .24447 .4225 Mtetra
.155 0 0 r
.24447 .4225 .25286 .41079 .26335 .4039 .25494 .41685 Mtetra
.18 0 .028 r
.25494 .41685 .26335 .4039 .27387 .39696 .26547 .4109 Mtetra
.199 0 .061 r
.26547 .4109 .27387 .39696 .28439 .39007 .27603 .40475 Mtetra
.215 0 .085 r
.27603 .40475 .28439 .39007 .29493 .38334 .28662 .39851 Mtetra
.228 0 .101 r
.28662 .39851 .29493 .38334 .30546 .37689 .29724 .39226 Mtetra
.231 0 .107 r
.29724 .39226 .30546 .37689 .31601 .37054 .30789 .38595 Mtetra
.231 0 .109 r
.30789 .38595 .31601 .37054 .32658 .36427 .31856 .37959 Mtetra
.248 0 .117 r
.31856 .37959 .32658 .36427 .33715 .35836 .32923 .3736 Mtetra
.269 0 .127 r
.32923 .3736 .33715 .35836 .34772 .35293 .3399 .36812 Mtetra
.272 0 .128 r
.3399 .36812 .34772 .35293 .35829 .34787 .3506 .3627 Mtetra
.258 0 .115 r
.3506 .3627 .35829 .34787 .3689 .34286 .36134 .35707 Mtetra
.216 0 .083 r
.36134 .35707 .3689 .34286 .3796 .33645 .37213 .35078 Mtetra
.195 0 .076 r
.37213 .35078 .3796 .33645 .39041 .32827 .38298 .34395 Mtetra
.271 0 .139 r
.38298 .34395 .39041 .32827 .40125 .31941 .39381 .33814 Mtetra
.362 .008 .224 r
.39381 .33814 .40125 .31941 .41209 .31064 .40461 .3338 Mtetra
.417 .083 .289 r
.40461 .3338 .41209 .31064 .4229 .30319 .41541 .3304 Mtetra
.442 .122 .326 r
.41541 .3304 .4229 .30319 .43368 .29762 .42625 .32745 Mtetra
.436 .125 .337 r
.42625 .32745 .43368 .29762 .44444 .2938 .43716 .32363 Mtetra
.422 .112 .333 r
.43716 .32363 .44444 .2938 .4552 .29174 .44814 .31894 Mtetra
.42 .102 .318 r
.44814 .31894 .4552 .29174 .46598 .29156 .45914 .3147 Mtetra
.42 .086 .29 r
.45914 .3147 .46598 .29156 .47681 .29273 .47017 .3114 Mtetra
.43 .071 .252 r
.47017 .3114 .47681 .29273 .48771 .294 .48123 .30959 Mtetra
.439 .056 .215 r
.48123 .30959 .48771 .294 .49871 .29461 .49234 .30882 Mtetra
.413 .02 .181 r
.49234 .30882 .49871 .29461 .50978 .29343 .50352 .3075 Mtetra
.391 0 .168 r
.50352 .3075 .50978 .29343 .52093 .29085 .51476 .30552 Mtetra
.391 .003 .178 r
.51476 .30552 .52093 .29085 .53213 .28833 .52607 .30334 Mtetra
.396 .011 .186 r
.52607 .30334 .53213 .28833 .54338 .28618 .53743 .30121 Mtetra
.412 .025 .193 r
.53743 .30121 .54338 .28618 .5547 .28451 .54886 .29962 Mtetra
.423 .036 .198 r
.54886 .29962 .5547 .28451 .56609 .28323 .56036 .29841 Mtetra
.56036 .29841 .56609 .28323 .57755 .28204 .57193 .29716 Mtetra
.42 .033 .196 r
.57193 .29716 .57755 .28204 .58908 .28095 .58356 .29584 Mtetra
.419 .029 .191 r
.58356 .29584 .58908 .28095 .60068 .28015 .59527 .29453 Mtetra
.412 .018 .179 r
.59527 .29453 .60068 .28015 .61237 .27954 .60704 .29314 Mtetra
.399 0 .159 r
.60704 .29314 .61237 .27954 .62413 .27898 .61887 .29153 Mtetra
.379 0 .128 r
.61887 .29153 .62413 .27898 .63596 .27837 .63077 .28964 Mtetra
.349 0 .084 r
.63077 .28964 .63596 .27837 .64786 .2776 .64272 .28738 Mtetra
.305 0 .022 r
.64272 .28738 .64786 .2776 .65983 .27655 .65471 .2847 Mtetra
.238 0 0 r
.65471 .2847 .65983 .27655 .67185 .27512 .66675 .28152 Mtetra
.143 0 0 r
.66675 .28152 .67185 .27512 .68393 .27326 .67882 .27784 Mtetra
.003 0 0 r
.67882 .27784 .68393 .27326 .69604 .27089 .69092 .27365 Mtetra
0 0 0 r
.69092 .27365 .69604 .27089 .70819 .26804 .70305 .26901 Mtetra
.381 .84 .775 r
.70305 .26901 .70819 .26804 .72038 .2647 .7152 .26396 Mtetra
.546 .926 .912 r
.7152 .26396 .72038 .2647 .73259 .26094 .72737 .25858 Mtetra
.647 .936 .967 r
.72737 .25858 .73259 .26094 .74484 .25682 .73957 .25294 Mtetra
.694 .904 .97 r
.73957 .25294 .74484 .25682 .75712 .25241 .7518 .24712 Mtetra
.712 .859 .952 r
.7518 .24712 .75712 .25241 .76944 .24782 .76407 .24119 Mtetra
.714 .814 .927 r
.76407 .24119 .76944 .24782 .7818 .24311 .77637 .23521 Mtetra
.529 .712 .956 r
.11732 .45366 .12449 .45992 .13411 .45815 .12687 .45262 Mtetra
.511 .733 .974 r
.12687 .45262 .13411 .45815 .14379 .45634 .13647 .45161 Mtetra
.489 .756 .989 r
.13647 .45161 .14379 .45634 .15352 .45444 .14611 .45059 Mtetra
.46 .778 .998 r
.14611 .45059 .15352 .45444 .16331 .45237 .15582 .44951 Mtetra
.416 .795 .992 r
.15582 .44951 .16331 .45237 .17318 .45007 .16559 .44835 Mtetra
.354 .797 .958 r
.16559 .44835 .17318 .45007 .18312 .44745 .17542 .44704 Mtetra
.27 .771 .877 r
.17542 .44704 .18312 .44745 .19314 .44445 .18533 .4455 Mtetra
.166 .703 .742 r
.18533 .4455 .19314 .44445 .20325 .44102 .19531 .44367 Mtetra
0 0 0 r
.19531 .44367 .20325 .44102 .21344 .43709 .20538 .44148 Mtetra
.035 0 0 r
.20538 .44148 .21344 .43709 .22371 .43269 .21554 .4389 Mtetra
.109 0 0 r
.21554 .4389 .22371 .43269 .23406 .4278 .22578 .43589 Mtetra
.166 0 0 r
.22578 .43589 .23406 .4278 .24447 .4225 .2361 .43246 Mtetra
.208 0 0 r
.2361 .43246 .24447 .4225 .25494 .41685 .24649 .42862 Mtetra
.238 0 .028 r
.24649 .42862 .25494 .41685 .26547 .4109 .25696 .42438 Mtetra
.26 0 .08 r
.25696 .42438 .26547 .4109 .27603 .40475 .26749 .41976 Mtetra
.278 0 .119 r
.26749 .41976 .27603 .40475 .28662 .39851 .27808 .41484 Mtetra
.292 0 .148 r
.27808 .41484 .28662 .39851 .29724 .39226 .28872 .40968 Mtetra
.3 0 .169 r
.28872 .40968 .29724 .39226 .30789 .38595 .29941 .40428 Mtetra
.307 0 .185 r
.29941 .40428 .30789 .38595 .31856 .37959 .31014 .39869 Mtetra
.325 0 .203 r
.31014 .39869 .31856 .37959 .32923 .3736 .32089 .39331 Mtetra
.344 0 .22 r
.32089 .39331 .32923 .3736 .3399 .36812 .33164 .38832 Mtetra
.348 .001 .227 r
.33164 .38832 .3399 .36812 .3506 .3627 .34244 .38325 Mtetra
.348 .003 .23 r
.34244 .38325 .3506 .3627 .36134 .35707 .35327 .37804 Mtetra
.36 .017 .24 r
.35327 .37804 .36134 .35707 .37213 .35078 .36412 .37311 Mtetra
.39 .051 .266 r
.36412 .37311 .37213 .35078 .38298 .34395 .37497 .36893 Mtetra
.447 .116 .31 r
.37497 .36893 .38298 .34395 .39381 .33814 .38577 .36686 Mtetra
.49 .168 .347 r
.38577 .36686 .39381 .33814 .40461 .3338 .39655 .36691 Mtetra
.497 .186 .368 r
.39655 .36691 .40461 .3338 .41541 .3304 .40738 .36715 Mtetra
.488 .185 .378 r
.40738 .36715 .41541 .3304 .42625 .32745 .41832 .36634 Mtetra
.455 .16 .374 r
.41832 .36634 .42625 .32745 .43716 .32363 .42942 .36253 Mtetra
.418 .127 .362 r
.42942 .36253 .43716 .32363 .44814 .31894 .44064 .35571 Mtetra
.396 .105 .349 r
.44064 .35571 .44814 .31894 .45914 .3147 .45191 .34783 Mtetra
.384 .086 .331 r
.45191 .34783 .45914 .3147 .47017 .3114 .46319 .34013 Mtetra
.4 .087 .315 r
.46319 .34013 .47017 .3114 .48123 .30959 .47446 .33455 Mtetra
.423 .093 .3 r
.47446 .33455 .48123 .30959 .49234 .30882 .48574 .3311 Mtetra
.426 .083 .28 r
.48574 .3311 .49234 .30882 .50352 .3075 .49706 .32839 Mtetra
.425 .076 .267 r
.49706 .32839 .50352 .3075 .51476 .30552 .50843 .32599 Mtetra
.42 .069 .261 r
.50843 .32599 .51476 .30552 .52607 .30334 .51987 .32344 Mtetra
.417 .063 .255 r
.51987 .32344 .52607 .30334 .53743 .30121 .53136 .32081 Mtetra
.423 .066 .252 r
.53136 .32081 .53743 .30121 .54886 .29962 .54291 .31857 Mtetra
.425 .063 .245 r
.54291 .31857 .54886 .29962 .56036 .29841 .55453 .31656 Mtetra
.416 .05 .232 r
.55453 .31656 .56036 .29841 .57193 .29716 .5662 .31437 Mtetra
.403 .032 .215 r
.5662 .31437 .57193 .29716 .58356 .29584 .57794 .31193 Mtetra
.388 .009 .193 r
.57794 .31193 .58356 .29584 .59527 .29453 .58973 .30924 Mtetra
.366 0 .161 r
.58973 .30924 .59527 .29453 .60704 .29314 .60158 .30625 Mtetra
.333 0 .117 r
.60158 .30625 .60704 .29314 .61887 .29153 .61347 .30288 Mtetra
.287 0 .055 r
.61347 .30288 .61887 .29153 .63077 .28964 .62541 .29909 Mtetra
.221 0 0 r
.62541 .29909 .63077 .28964 .64272 .28738 .63738 .29487 Mtetra
.126 0 0 r
.63738 .29487 .64272 .28738 .65471 .2847 .64939 .29022 Mtetra
0 0 0 r
.64939 .29022 .65471 .2847 .66675 .28152 .66143 .28511 Mtetra
.66143 .28511 .66675 .28152 .67882 .27784 .67349 .27959 Mtetra
.389 .835 .722 r
.67349 .27959 .67882 .27784 .69092 .27365 .68558 .27369 Mtetra
.555 .933 .869 r
.68558 .27369 .69092 .27365 .70305 .26901 .69769 .26748 Mtetra
.66 .958 .941 r
.69769 .26748 .70305 .26901 .7152 .26396 .70982 .26103 Mtetra
.713 .939 .959 r
.70982 .26103 .7152 .26396 .72737 .25858 .72197 .2544 Mtetra
.735 .904 .954 r
.72197 .2544 .72737 .25858 .73957 .25294 .73416 .24767 Mtetra
.742 .869 .939 r
.73416 .24767 .73957 .25294 .7518 .24712 .74637 .24087 Mtetra
.741 .836 .923 r
.74637 .24087 .7518 .24712 .76407 .24119 .75862 .23405 Mtetra
.737 .807 .907 r
.75862 .23405 .76407 .24119 .77637 .23521 .7709 .22725 Mtetra
.513 .706 .958 r
.1101 .44736 .11732 .45366 .12687 .45262 .11964 .44653 Mtetra
.503 .71 .964 r
.11964 .44653 .12687 .45262 .13647 .45161 .12922 .44577 Mtetra
.491 .716 .971 r
.12922 .44577 .13647 .45161 .14611 .45059 .13884 .44507 Mtetra
.476 .723 .978 r
.13884 .44507 .14611 .45059 .15582 .44951 .14851 .44444 Mtetra
.456 .732 .986 r
.14851 .44444 .15582 .44951 .16559 .44835 .15823 .44387 Mtetra
.431 .744 .993 r
.15823 .44387 .16559 .44835 .17542 .44704 .168 .44331 Mtetra
.396 .757 .993 r
.168 .44331 .17542 .44704 .18533 .4455 .17783 .44273 Mtetra
.347 .765 .977 r
.17783 .44273 .18533 .4455 .19531 .44367 .18772 .44204 Mtetra
.277 .757 .929 r
.18772 .44204 .19531 .44367 .20538 .44148 .19769 .44119 Mtetra
.184 .715 .829 r
.19769 .44119 .20538 .44148 .21554 .4389 .20774 .44012 Mtetra
0 0 0 r
.20774 .44012 .21554 .4389 .22578 .43589 .21787 .43876 Mtetra
.026 0 0 r
.21787 .43876 .22578 .43589 .2361 .43246 .22808 .43708 Mtetra
.109 0 0 r
.22808 .43708 .2361 .43246 .24649 .42862 .23837 .43503 Mtetra
.17 0 0 r
.23837 .43503 .24649 .42862 .25696 .42438 .24875 .43259 Mtetra
.211 0 0 r
.24875 .43259 .25696 .42438 .26749 .41976 .25921 .42971 Mtetra
.242 0 0 r
.25921 .42971 .26749 .41976 .27808 .41484 .26975 .42643 Mtetra
.265 0 .035 r
.26975 .42643 .27808 .41484 .28872 .40968 .28036 .42279 Mtetra
.282 0 .08 r
.28036 .42279 .28872 .40968 .29941 .40428 .29104 .41882 Mtetra
.297 0 .117 r
.29104 .41882 .29941 .40428 .31014 .39869 .30177 .41458 Mtetra
.32 0 .152 r
.30177 .41458 .31014 .39869 .32089 .39331 .31255 .41036 Mtetra
.342 0 .18 r
.31255 .41036 .32089 .39331 .33164 .38832 .32335 .40633 Mtetra
.349 0 .197 r
.32335 .40633 .33164 .38832 .34244 .38325 .33419 .40218 Mtetra
.359 .001 .213 r
.33419 .40218 .34244 .38325 .35327 .37804 .34508 .39802 Mtetra
.398 .043 .242 r
.34508 .39802 .35327 .37804 .36412 .37311 .35595 .39494 Mtetra
.446 .098 .281 r
.35595 .39494 .36412 .37311 .37497 .36893 .36679 .39353 Mtetra
.499 .159 .323 r
.36679 .39353 .37497 .36893 .38577 .36686 .37758 .39458 Mtetra
.53 .2 .352 r
.37758 .39458 .38577 .36686 .39655 .36691 .38836 .39768 Mtetra
.523 .2 .363 r
.38836 .39768 .39655 .36691 .40738 .36715 .39925 .40019 Mtetra
.496 .182 .363 r
.39925 .40019 .40738 .36715 .41832 .36634 .41031 .40053 Mtetra
.443 .136 .349 r
.41031 .40053 .41832 .36634 .42942 .36253 .42157 .39673 Mtetra
.38 .082 .328 r
.42157 .39673 .42942 .36253 .44064 .35571 .43301 .38878 Mtetra
.338 .043 .309 r
.43301 .38878 .44064 .35571 .45191 .34783 .44451 .37862 Mtetra
.311 .014 .289 r
.44451 .37862 .45191 .34783 .46319 .34013 .45603 .36785 Mtetra
.33 .02 .279 r
.45603 .36785 .46319 .34013 .47446 .33455 .46751 .35913 Mtetra
.36 .033 .269 r
.46751 .35913 .47446 .33455 .48574 .3311 .47897 .35288 Mtetra
.379 .036 .253 r
.47897 .35288 .48574 .3311 .49706 .32839 .49045 .3483 Mtetra
.391 .037 .239 r
.49045 .3483 .49706 .32839 .50843 .32599 .50196 .34481 Mtetra
.384 .023 .223 r
.50196 .34481 .50843 .32599 .51987 .32344 .51352 .34131 Mtetra
.373 .007 .208 r
.51352 .34131 .51987 .32344 .53136 .32081 .52513 .3377 Mtetra
.37 0 .193 r
.52513 .3377 .53136 .32081 .54291 .31857 .53679 .33427 Mtetra
.359 0 .17 r
.53679 .33427 .54291 .31857 .55453 .31656 .54851 .33086 Mtetra
.333 0 .135 r
.54851 .33086 .55453 .31656 .5662 .31437 .56028 .32719 Mtetra
.298 0 .089 r
.56028 .32719 .5662 .31437 .57794 .31193 .5721 .32317 Mtetra
.251 0 .029 r
.5721 .32317 .57794 .31193 .58973 .30924 .58397 .31877 Mtetra
.184 0 0 r
.58397 .31877 .58973 .30924 .60158 .30625 .59587 .31396 Mtetra
.087 0 0 r
.59587 .31396 .60158 .30625 .61347 .30288 .6078 .3087 Mtetra
0 0 0 r
.6078 .3087 .61347 .30288 .62541 .29909 .61977 .30303 Mtetra
.61977 .30303 .62541 .29909 .63738 .29487 .63176 .29697 Mtetra
.414 .846 .713 r
.63176 .29697 .63738 .29487 .64939 .29022 .64378 .29056 Mtetra
.579 .943 .859 r
.64378 .29056 .64939 .29022 .66143 .28511 .65582 .28385 Mtetra
.682 .967 .93 r
.65582 .28385 .66143 .28511 .67349 .27959 .66788 .27689 Mtetra
.733 .947 .95 r
.66788 .27689 .67349 .27959 .68558 .27369 .67997 .26975 Mtetra
.753 .914 .945 r
.67997 .26975 .68558 .27369 .69769 .26748 .69208 .2625 Mtetra
.758 .88 .934 r
.69208 .2625 .69769 .26748 .70982 .26103 .70421 .2552 Mtetra
.757 .852 .921 r
.70421 .2552 .70982 .26103 .72197 .2544 .71638 .24789 Mtetra
.753 .83 .911 r
.71638 .24789 .72197 .2544 .73416 .24767 .72858 .24064 Mtetra
.748 .813 .904 r
.72858 .24064 .73416 .24767 .74637 .24087 .74081 .23344 Mtetra
.744 .801 .898 r
.74081 .23344 .74637 .24087 .75862 .23405 .75308 .2263 Mtetra
.74 .791 .893 r
.75308 .2263 .75862 .23405 .7709 .22725 .76539 .21923 Mtetra
.547 .718 .953 r
.10283 .44102 .1101 .44736 .11964 .44653 .11244 .43966 Mtetra
.547 .701 .941 r
.11244 .43966 .11964 .44653 .12922 .44577 .12209 .4384 Mtetra
.545 .685 .93 r
.12209 .4384 .12922 .44577 .13884 .44507 .13178 .43725 Mtetra
.542 .67 .921 r
.13178 .43725 .13884 .44507 .14851 .44444 .14151 .43623 Mtetra
.536 .656 .913 r
.14151 .43623 .14851 .44444 .15823 .44387 .15126 .43537 Mtetra
.531 .646 .908 r
.15126 .43537 .15823 .44387 .168 .44331 .16106 .43463 Mtetra
.526 .64 .905 r
.16106 .43463 .168 .44331 .17783 .44273 .1709 .43401 Mtetra
.523 .638 .905 r
.1709 .43401 .17783 .44273 .18772 .44204 .18079 .43345 Mtetra
.521 .642 .909 r
.18079 .43345 .18772 .44204 .19769 .44119 .19074 .43288 Mtetra
.522 .651 .916 r
.19074 .43288 .19769 .44119 .20774 .44012 .20075 .43225 Mtetra
.524 .666 .926 r
.20075 .43225 .20774 .44012 .21787 .43876 .21083 .43147 Mtetra
.528 .688 .94 r
.21083 .43147 .21787 .43876 .22808 .43708 .22099 .4305 Mtetra
.532 .714 .956 r
.22099 .4305 .22808 .43708 .23837 .43503 .23123 .42929 Mtetra
.535 .746 .973 r
.23123 .42929 .23837 .43503 .24875 .43259 .24155 .42778 Mtetra
.536 .782 .988 r
.24155 .42778 .24875 .43259 .25921 .42971 .25195 .42596 Mtetra
.523 .817 .999 r
.25195 .42596 .25921 .42971 .26975 .42643 .26243 .42388 Mtetra
.489 .844 .994 r
.26243 .42388 .26975 .42643 .28036 .42279 .27297 .42159 Mtetra
.416 .844 .951 r
.27297 .42159 .28036 .42279 .29104 .41882 .28357 .41919 Mtetra
.287 .787 .836 r
.28357 .41919 .29104 .41882 .30177 .41458 .29423 .41674 Mtetra
0 0 0 r
.29423 .41674 .30177 .41458 .31255 .41036 .30493 .41437 Mtetra
.057 0 0 r
.30493 .41437 .31255 .41036 .32335 .40633 .31567 .41212 Mtetra
.144 0 0 r
.31567 .41212 .32335 .40633 .33419 .40218 .32648 .40966 Mtetra
.207 0 0 r
.32648 .40966 .33419 .40218 .34508 .39802 .33736 .40704 Mtetra
.306 0 0 r
.33736 .40704 .34508 .39802 .35595 .39494 .34824 .40528 Mtetra
.393 0 .072 r
.34824 .40528 .35595 .39494 .36679 .39353 .3591 .40483 Mtetra
.463 .033 .136 r
.3591 .40483 .36679 .39353 .37758 .39458 .36996 .40603 Mtetra
.5 .073 .16 r
.36996 .40603 .37758 .39458 .38836 .39768 .38084 .40844 Mtetra
.469 .031 .125 r
.38084 .40844 .38836 .39768 .39925 .40019 .39185 .40997 Mtetra
.38 0 .045 r
.39185 .40997 .39925 .40019 .41031 .40053 .40302 .40943 Mtetra
.188 0 0 r
.40302 .40943 .41031 .40053 .42157 .39673 .41437 .40561 Mtetra
0 0 0 r
.41437 .40561 .42157 .39673 .43301 .38878 .42587 .39851 Mtetra
.42587 .39851 .43301 .38878 .44451 .37862 .43745 .38932 Mtetra
.43745 .38932 .44451 .37862 .45603 .36785 .44906 .37922 Mtetra
.44906 .37922 .45603 .36785 .46751 .35913 .46066 .37032 Mtetra
.082 0 0 r
.46066 .37032 .46751 .35913 .47897 .35288 .47223 .36306 Mtetra
.121 0 0 r
.47223 .36306 .47897 .35288 .49045 .3483 .48382 .35712 Mtetra
.48382 .35712 .49045 .3483 .50196 .34481 .49543 .35204 Mtetra
.036 0 0 r
.49543 .35204 .50196 .34481 .51352 .34131 .50709 .3468 Mtetra
0 0 0 r
.50709 .3468 .51352 .34131 .52513 .3377 .51878 .34132 Mtetra
.51878 .34132 .52513 .3377 .53679 .33427 .53051 .33598 Mtetra
.39 .842 .758 r
.53051 .33598 .53679 .33427 .54851 .33086 .54229 .3307 Mtetra
.542 .926 .903 r
.54229 .3307 .54851 .33086 .56028 .32719 .5541 .32537 Mtetra
.637 .937 .964 r
.5541 .32537 .56028 .32719 .5721 .32317 .56596 .31992 Mtetra
.689 .912 .972 r
.56596 .31992 .5721 .32317 .58397 .31877 .57785 .31424 Mtetra
.715 .876 .957 r
.57785 .31424 .58397 .31877 .59587 .31396 .58978 .3083 Mtetra
.729 .841 .933 r
.58978 .3083 .59587 .31396 .6078 .3087 .60173 .30201 Mtetra
.735 .81 .911 r
.60173 .30201 .6078 .3087 .61977 .30303 .61372 .29542 Mtetra
.737 .784 .89 r
.61372 .29542 .61977 .30303 .63176 .29697 .62572 .28856 Mtetra
.737 .762 .873 r
.62572 .28856 .63176 .29697 .64378 .29056 .63776 .28149 Mtetra
.735 .746 .86 r
.63776 .28149 .64378 .29056 .65582 .28385 .64981 .27426 Mtetra
.733 .733 .851 r
.64981 .27426 .65582 .28385 .66788 .27689 .66189 .26695 Mtetra
.73 .725 .846 r
.66189 .26695 .66788 .27689 .67997 .26975 .674 .25962 Mtetra
.727 .72 .844 r
.674 .25962 .67997 .26975 .69208 .2625 .68614 .25234 Mtetra
.725 .719 .845 r
.68614 .25234 .69208 .2625 .70421 .2552 .69832 .24516 Mtetra
.723 .722 .849 r
.69832 .24516 .70421 .2552 .71638 .24789 .71054 .2381 Mtetra
.721 .728 .856 r
.71054 .2381 .71638 .24789 .72858 .24064 .72279 .2312 Mtetra
.721 .737 .864 r
.72279 .2312 .72858 .24064 .74081 .23344 .7351 .22441 Mtetra
.721 .749 .874 r
.7351 .22441 .74081 .23344 .75308 .2263 .74744 .21773 Mtetra
.721 .763 .885 r
.74744 .21773 .75308 .2263 .76539 .21923 .75983 .21113 Mtetra
.605 .737 .939 r
.09551 .43462 .10283 .44102 .11244 .43966 .10526 .43225 Mtetra
.604 .705 .915 r
.10526 .43225 .11244 .43966 .12209 .4384 .11506 .42996 Mtetra
.6 .674 .893 r
.11506 .42996 .12209 .4384 .13178 .43725 .12488 .42779 Mtetra
.594 .646 .872 r
.12488 .42779 .13178 .43725 .14151 .43623 .13472 .42577 Mtetra
.586 .62 .853 r
.13472 .42577 .14151 .43623 .15126 .43537 .14459 .42397 Mtetra
.578 .598 .836 r
.14459 .42397 .15126 .43537 .16106 .43463 .15449 .42235 Mtetra
.571 .578 .821 r
.15449 .42235 .16106 .43463 .1709 .43401 .16441 .42094 Mtetra
.565 .562 .809 r
.16441 .42094 .1709 .43401 .18079 .43345 .17437 .41969 Mtetra
.561 .549 .799 r
.17437 .41969 .18079 .43345 .19074 .43288 .18437 .41857 Mtetra
.559 .54 .791 r
.18437 .41857 .19074 .43288 .20075 .43225 .19441 .41751 Mtetra
.558 .535 .785 r
.19441 .41751 .20075 .43225 .21083 .43147 .20451 .41644 Mtetra
.56 .532 .781 r
.20451 .41644 .21083 .43147 .22099 .4305 .21468 .41532 Mtetra
.562 .532 .779 r
.21468 .41532 .22099 .4305 .23123 .42929 .22491 .4141 Mtetra
.565 .534 .779 r
.22491 .4141 .23123 .42929 .24155 .42778 .2352 .41276 Mtetra
.569 .539 .782 r
.2352 .41276 .24155 .42778 .25195 .42596 .24556 .41131 Mtetra
.569 .545 .788 r
.24556 .41131 .25195 .42596 .26243 .42388 .25598 .40984 Mtetra
.568 .554 .798 r
.25598 .40984 .26243 .42388 .27297 .42159 .26645 .40843 Mtetra
.563 .566 .814 r
.26645 .40843 .27297 .42159 .28357 .41919 .27696 .40717 Mtetra
.554 .583 .837 r
.27696 .40717 .28357 .41919 .29423 .41674 .28752 .40613 Mtetra
.544 .609 .868 r
.28752 .40613 .29423 .41674 .30493 .41437 .29813 .40524 Mtetra
.533 .642 .903 r
.29813 .40524 .30493 .41437 .31567 .41212 .30879 .40439 Mtetra
.54 .688 .935 r
.30879 .40439 .31567 .41212 .32648 .40966 .31955 .40316 Mtetra
.553 .734 .96 r
.31955 .40316 .32648 .40966 .33736 .40704 .33039 .40141 Mtetra
.53 .757 .98 r
.33039 .40141 .33736 .40704 .34824 .40528 .34129 .39977 Mtetra
.503 .752 .985 r
.34129 .39977 .34824 .40528 .3591 .40483 .35223 .39848 Mtetra
.499 .72 .97 r
.35223 .39848 .3591 .40483 .36996 .40603 .36321 .39752 Mtetra
.524 .66 .922 r
.36321 .39752 .36996 .40603 .38084 .40844 .37425 .39668 Mtetra
.569 .602 .846 r
.37425 .39668 .38084 .40844 .39185 .40997 .38539 .39514 Mtetra
.598 .566 .789 r
.38539 .39514 .39185 .40997 .40302 .40943 .39664 .39249 Mtetra
.618 .552 .757 r
.39664 .39249 .40302 .40943 .41437 .40561 .40799 .38864 Mtetra
.641 .564 .753 r
.40799 .38864 .41437 .40561 .42587 .39851 .41942 .38357 Mtetra
.672 .604 .771 r
.41942 .38357 .42587 .39851 .43745 .38932 .43093 .37739 Mtetra
.707 .664 .806 r
.43093 .37739 .43745 .38932 .44906 .37922 .44248 .37049 Mtetra
.73 .739 .859 r
.44248 .37049 .44906 .37922 .46066 .37032 .45406 .3637 Mtetra
.736 .8 .903 r
.45406 .3637 .46066 .37032 .47223 .36306 .46567 .35724 Mtetra
.728 .825 .925 r
.46567 .35724 .47223 .36306 .48382 .35712 .4773 .35111 Mtetra
.724 .819 .924 r
.4773 .35111 .48382 .35712 .49543 .35204 .48896 .34509 Mtetra
.735 .793 .899 r
.48896 .34509 .49543 .35204 .50709 .3468 .50066 .33855 Mtetra
.737 .758 .87 r
.50066 .33855 .50709 .3468 .51878 .34132 .51239 .33159 Mtetra
.724 .718 .845 r
.51239 .33159 .51878 .34132 .53051 .33598 .52415 .32467 Mtetra
.708 .681 .821 r
.52415 .32467 .53051 .33598 .54229 .3307 .53594 .31789 Mtetra
.693 .648 .801 r
.53594 .31789 .54229 .3307 .5541 .32537 .54776 .31132 Mtetra
.681 .624 .785 r
.54776 .31132 .5541 .32537 .56596 .31992 .55962 .30489 Mtetra
.674 .608 .774 r
.55962 .30489 .56596 .31992 .57785 .31424 .57151 .29852 Mtetra
.67 .598 .766 r
.57151 .29852 .57785 .31424 .58978 .3083 .58344 .29212 Mtetra
.67 .593 .761 r
.58344 .29212 .58978 .3083 .60173 .30201 .59539 .28559 Mtetra
.67 .591 .758 r
.59539 .28559 .60173 .30201 .61372 .29542 .60738 .27893 Mtetra
.671 .591 .757 r
.60738 .27893 .61372 .29542 .62572 .28856 .6194 .27215 Mtetra
.673 .593 .758 r
.6194 .27215 .62572 .28856 .63776 .28149 .63144 .26531 Mtetra
.675 .597 .761 r
.63144 .26531 .63776 .28149 .64981 .27426 .64352 .25846 Mtetra
.676 .602 .765 r
.64352 .25846 .64981 .27426 .66189 .26695 .65564 .25165 Mtetra
.677 .609 .773 r
.65564 .25165 .66189 .26695 .674 .25962 .66779 .24496 Mtetra
.678 .619 .782 r
.66779 .24496 .674 .25962 .68614 .25234 .67998 .23842 Mtetra
.679 .63 .794 r
.67998 .23842 .68614 .25234 .69832 .24516 .69223 .23209 Mtetra
.68 .645 .808 r
.69223 .23209 .69832 .24516 .71054 .2381 .70452 .22595 Mtetra
.681 .662 .825 r
.70452 .22595 .71054 .2381 .72279 .2312 .71687 .22001 Mtetra
.684 .683 .843 r
.71687 .22001 .72279 .2312 .7351 .22441 .72927 .21423 Mtetra
.687 .708 .864 r
.72927 .21423 .7351 .22441 .74744 .21773 .74172 .20856 Mtetra
.689 .735 .886 r
.74172 .20856 .74744 .21773 .75983 .21113 .75422 .20298 Mtetra
.665 .753 .916 r
.08813 .42819 .09551 .43462 .10526 .43225 .09808 .42446 Mtetra
.659 .713 .888 r
.09808 .42446 .10526 .43225 .11506 .42996 .10806 .42079 Mtetra
.65 .675 .861 r
.10806 .42079 .11506 .42996 .12488 .42779 .11806 .41723 Mtetra
.639 .641 .836 r
.11806 .41723 .12488 .42779 .13472 .42577 .12808 .41381 Mtetra
.627 .61 .813 r
.12808 .41381 .13472 .42577 .14459 .42397 .13812 .4106 Mtetra
.616 .582 .793 r
.13812 .4106 .14459 .42397 .15449 .42235 .14817 .40759 Mtetra
.605 .558 .775 r
.14817 .40759 .15449 .42235 .16441 .42094 .15824 .40482 Mtetra
.596 .537 .759 r
.15824 .40482 .16441 .42094 .17437 .41969 .16833 .40225 Mtetra
.588 .519 .744 r
.16833 .40225 .17437 .41969 .18437 .41857 .17844 .39988 Mtetra
.582 .504 .732 r
.17844 .39988 .18437 .41857 .19441 .41751 .18859 .39765 Mtetra
.577 .491 .721 r
.18859 .39765 .19441 .41751 .20451 .41644 .19877 .39554 Mtetra
.573 .481 .713 r
.19877 .39554 .20451 .41644 .21468 .41532 .209 .39351 Mtetra
.57 .474 .706 r
.209 .39351 .21468 .41532 .22491 .4141 .21926 .39154 Mtetra
.567 .467 .7 r
.21926 .39154 .22491 .4141 .2352 .41276 .22958 .38964 Mtetra
.565 .463 .697 r
.22958 .38964 .2352 .41276 .24556 .41131 .23994 .38782 Mtetra
.562 .459 .694 r
.23994 .38782 .24556 .41131 .25598 .40984 .25034 .38614 Mtetra
.558 .456 .694 r
.25034 .38614 .25598 .40984 .26645 .40843 .26078 .38462 Mtetra
.556 .454 .693 r
.26078 .38462 .26645 .40843 .27696 .40717 .27127 .3832 Mtetra
.556 .453 .693 r
.27127 .3832 .27696 .40717 .28752 .40613 .28181 .38181 Mtetra
.56 .454 .69 r
.28181 .38181 .28752 .40613 .29813 .40524 .29244 .38016 Mtetra
.567 .455 .685 r
.29244 .38016 .29813 .40524 .30879 .40439 .30315 .37802 Mtetra
.579 .456 .677 r
.30315 .37802 .30879 .40439 .31955 .40316 .31397 .37501 Mtetra
.59 .456 .667 r
.31397 .37501 .31955 .40316 .33039 .40141 .32491 .37098 Mtetra
.592 .449 .656 r
.32491 .37098 .33039 .40141 .34129 .39977 .33593 .36643 Mtetra
.59 .438 .644 r
.33593 .36643 .34129 .39977 .35223 .39848 .347 .36157 Mtetra
.587 .427 .632 r
.347 .36157 .35223 .39848 .36321 .39752 .35812 .35636 Mtetra
.582 .415 .62 r
.35812 .35636 .36321 .39752 .37425 .39668 .36929 .35095 Mtetra
.576 .402 .609 r
.36929 .35095 .37425 .39668 .38539 .39514 .3805 .34559 Mtetra
.569 .391 .601 r
.3805 .34559 .38539 .39514 .39664 .39249 .39172 .34059 Mtetra
.558 .38 .597 r
.39172 .34059 .39664 .39249 .40799 .38864 .40294 .33667 Mtetra
.549 .374 .596 r
.40294 .33667 .40799 .38864 .41942 .38357 .41417 .33382 Mtetra
.547 .376 .601 r
.41417 .33382 .41942 .38357 .43093 .37739 .42544 .33134 Mtetra
.549 .383 .608 r
.42544 .33134 .43093 .37739 .44248 .37049 .43677 .32891 Mtetra
.554 .395 .62 r
.43677 .32891 .44248 .37049 .45406 .3637 .44817 .32628 Mtetra
.561 .409 .632 r
.44817 .32628 .45406 .3637 .46567 .35724 .45962 .32332 Mtetra
.569 .424 .645 r
.45962 .32332 .46567 .35724 .4773 .35111 .47114 .32003 Mtetra
.58 .441 .656 r
.47114 .32003 .4773 .35111 .48896 .34509 .48272 .31622 Mtetra
.597 .461 .666 r
.48272 .31622 .48896 .34509 .50066 .33855 .49436 .31137 Mtetra
.612 .478 .674 r
.49436 .31137 .50066 .33855 .51239 .33159 .50606 .30564 Mtetra
.622 .49 .681 r
.50606 .30564 .51239 .33159 .52415 .32467 .51778 .2994 Mtetra
.628 .497 .684 r
.51778 .2994 .52415 .32467 .53594 .31789 .52955 .29288 Mtetra
.628 .499 .686 r
.52955 .29288 .53594 .31789 .54776 .31132 .54134 .28639 Mtetra
.627 .499 .687 r
.54134 .28639 .54776 .31132 .55962 .30489 .55317 .27999 Mtetra
.625 .498 .687 r
.55317 .27999 .55962 .30489 .57151 .29852 .56504 .27374 Mtetra
.624 .498 .689 r
.56504 .27374 .57151 .29852 .58344 .29212 .57694 .26763 Mtetra
.624 .5 .691 r
.57694 .26763 .58344 .29212 .59539 .28559 .58888 .26159 Mtetra
.624 .503 .694 r
.58888 .26159 .59539 .28559 .60738 .27893 .60086 .25561 Mtetra
.626 .508 .699 r
.60086 .25561 .60738 .27893 .6194 .27215 .61288 .24969 Mtetra
.628 .515 .706 r
.61288 .24969 .6194 .27215 .63144 .26531 .62494 .24385 Mtetra
.63 .523 .714 r
.62494 .24385 .63144 .26531 .64352 .25846 .63705 .23811 Mtetra
.632 .533 .725 r
.63705 .23811 .64352 .25846 .65564 .25165 .6492 .23251 Mtetra
.633 .545 .737 r
.6492 .23251 .65564 .25165 .66779 .24496 .66141 .22711 Mtetra
.635 .559 .751 r
.66141 .22711 .66779 .24496 .67998 .23842 .67367 .22192 Mtetra
.637 .575 .768 r
.67367 .22192 .67998 .23842 .69223 .23209 .686 .21696 Mtetra
.639 .594 .787 r
.686 .21696 .69223 .23209 .70452 .22595 .69838 .21221 Mtetra
.64 .616 .81 r
.69838 .21221 .70452 .22595 .71687 .22001 .71083 .20767 Mtetra
.642 .642 .835 r
.71083 .20767 .71687 .22001 .72927 .21423 .72335 .20327 Mtetra
.645 .673 .862 r
.72335 .20327 .72927 .21423 .74172 .20856 .73593 .19898 Mtetra
.646 .708 .892 r
.73593 .19898 .74172 .20856 .75422 .20298 .74857 .19475 Mtetra
.711 .763 .892 r
.0807 .4217 .08813 .42819 .09808 .42446 .09086 .41658 Mtetra
.702 .723 .866 r
.09086 .41658 .09808 .42446 .10806 .42079 .10104 .4115 Mtetra
.69 .686 .841 r
.10104 .4115 .10806 .42079 .11806 .41723 .11123 .40648 Mtetra
.677 .653 .819 r
.11123 .40648 .11806 .41723 .12808 .41381 .12145 .40159 Mtetra
.664 .622 .798 r
.12145 .40159 .12808 .41381 .13812 .4106 .13167 .39685 Mtetra
.651 .594 .778 r
.13167 .39685 .13812 .4106 .14817 .40759 .1419 .39231 Mtetra
.638 .569 .761 r
.1419 .39231 .14817 .40759 .15824 .40482 .15214 .38798 Mtetra
.627 .546 .744 r
.15214 .38798 .15824 .40482 .16833 .40225 .16239 .38387 Mtetra
.616 .526 .73 r
.16239 .38387 .16833 .40225 .17844 .39988 .17265 .37998 Mtetra
.607 .509 .717 r
.17265 .37998 .17844 .39988 .18859 .39765 .18293 .37629 Mtetra
.599 .494 .706 r
.18293 .37629 .18859 .39765 .19877 .39554 .19323 .37279 Mtetra
.592 .481 .696 r
.19323 .37279 .19877 .39554 .209 .39351 .20355 .36949 Mtetra
.585 .469 .688 r
.20355 .36949 .209 .39351 .21926 .39154 .21389 .36638 Mtetra
.579 .46 .681 r
.21389 .36638 .21926 .39154 .22958 .38964 .22426 .36349 Mtetra
.573 .451 .675 r
.22426 .36349 .22958 .38964 .23994 .38782 .23465 .36083 Mtetra
.569 .445 .671 r
.23465 .36083 .23994 .38782 .25034 .38614 .24508 .35835 Mtetra
.565 .439 .667 r
.24508 .35835 .25034 .38614 .26078 .38462 .25554 .35602 Mtetra
.565 .436 .663 r
.25554 .35602 .26078 .38462 .27127 .3832 .26606 .3536 Mtetra
.568 .434 .658 r
.26606 .3536 .27127 .3832 .28181 .38181 .27665 .35089 Mtetra
.575 .434 .652 r
.27665 .35089 .28181 .38181 .29244 .38016 .28734 .3475 Mtetra
.584 .435 .645 r
.28734 .3475 .29244 .38016 .30315 .37802 .29815 .34315 Mtetra
.594 .435 .637 r
.29815 .34315 .30315 .37802 .31397 .37501 .30908 .3376 Mtetra
.601 .435 .628 r
.30908 .3376 .31397 .37501 .32491 .37098 .32012 .33079 Mtetra
.604 .431 .621 r
.32012 .33079 .32491 .37098 .33593 .36643 .33124 .32311 Mtetra
.604 .425 .613 r
.33124 .32311 .33593 .36643 .347 .36157 .34242 .31477 Mtetra
.603 .419 .606 r
.34242 .31477 .347 .36157 .35812 .35636 .35365 .30578 Mtetra
.599 .411 .598 r
.35365 .30578 .35812 .35636 .36929 .35095 .36489 .29654 Mtetra
.588 .398 .592 r
.36489 .29654 .36929 .35095 .3805 .34559 .37611 .28809 Mtetra
.573 .384 .587 r
.37611 .28809 .3805 .34559 .39172 .34059 .38727 .28124 Mtetra
.552 .367 .583 r
.38727 .28124 .39172 .34059 .40294 .33667 .39834 .27724 Mtetra
.531 .351 .582 r
.39834 .27724 .40294 .33667 .41417 .33382 .40935 .27611 Mtetra
.519 .344 .584 r
.40935 .27611 .41417 .33382 .42544 .33134 .42037 .27658 Mtetra
.512 .342 .588 r
.42037 .27658 .42544 .33134 .43677 .32891 .43144 .27786 Mtetra
.514 .349 .595 r
.43144 .27786 .43677 .32891 .44817 .32628 .44261 .27892 Mtetra
.52 .359 .603 r
.44261 .27892 .44817 .32628 .45962 .32332 .45387 .27932 Mtetra
.527 .37 .611 r
.45387 .27932 .45962 .32332 .47114 .32003 .46523 .27908 Mtetra
.537 .383 .62 r
.46523 .27908 .47114 .32003 .48272 .31622 .47667 .27797 Mtetra
.553 .401 .629 r
.47667 .27797 .48272 .31622 .49436 .31137 .48821 .27558 Mtetra
.569 .418 .637 r
.48821 .27558 .49436 .31137 .50606 .30564 .49981 .27199 Mtetra
.583 .434 .645 r
.49981 .27199 .50606 .30564 .51778 .2994 .51147 .26742 Mtetra
.594 .447 .651 r
.51147 .26742 .51778 .2994 .52955 .29288 .52318 .26215 Mtetra
.6 .455 .657 r
.52318 .26215 .52955 .29288 .54134 .28639 .53492 .25658 Mtetra
.603 .461 .661 r
.53492 .25658 .54134 .28639 .55317 .27999 .54671 .25091 Mtetra
.603 .464 .665 r
.54671 .25091 .55317 .27999 .56504 .27374 .55854 .24538 Mtetra
.602 .467 .669 r
.55854 .24538 .56504 .27374 .57694 .26763 .57041 .24004 Mtetra
.601 .47 .673 r
.57041 .24004 .57694 .26763 .58888 .26159 .58233 .23493 Mtetra
.601 .474 .679 r
.58233 .23493 .58888 .26159 .60086 .25561 .5943 .23003 Mtetra
.601 .479 .686 r
.5943 .23003 .60086 .25561 .61288 .24969 .60632 .22533 Mtetra
.601 .487 .695 r
.60632 .22533 .61288 .24969 .62494 .24385 .6184 .22082 Mtetra
.602 .495 .705 r
.6184 .22082 .62494 .24385 .63705 .23811 .63053 .21651 Mtetra
.602 .506 .718 r
.63053 .21651 .63705 .23811 .6492 .23251 .64273 .21241 Mtetra
.603 .519 .732 r
.64273 .21241 .6492 .23251 .66141 .22711 .65499 .20853 Mtetra
.603 .533 .749 r
.65499 .20853 .66141 .22711 .67367 .22192 .66733 .20487 Mtetra
.603 .55 .768 r
.66733 .20487 .67367 .22192 .686 .21696 .67973 .20143 Mtetra
.603 .57 .789 r
.67973 .20143 .686 .21696 .69838 .21221 .69221 .19819 Mtetra
.602 .592 .814 r
.69221 .19819 .69838 .21221 .71083 .20767 .70476 .19512 Mtetra
.602 .619 .841 r
.70476 .19512 .71083 .20767 .72335 .20327 .71739 .19217 Mtetra
.601 .649 .87 r
.71739 .19217 .72335 .20327 .73593 .19898 .7301 .1893 Mtetra
.598 .684 .902 r
.7301 .1893 .73593 .19898 .74857 .19475 .74288 .18646 Mtetra
.74 .766 .874 r
.07322 .41517 .0807 .4217 .09086 .41658 .08354 .40897 Mtetra
.731 .737 .856 r
.08354 .40897 .09086 .41658 .10104 .4115 .09389 .40278 Mtetra
.721 .709 .838 r
.09389 .40278 .10104 .4115 .11123 .40648 .10425 .39662 Mtetra
.71 .682 .821 r
.10425 .39662 .11123 .40648 .12145 .40159 .11463 .39054 Mtetra
.698 .657 .805 r
.11463 .39054 .12145 .40159 .13167 .39685 .12501 .38458 Mtetra
.686 .632 .79 r
.12501 .38458 .13167 .39685 .1419 .39231 .1354 .37877 Mtetra
.674 .609 .775 r
.1354 .37877 .1419 .39231 .15214 .38798 .1458 .37314 Mtetra
.662 .587 .761 r
.1458 .37314 .15214 .38798 .16239 .38387 .1562 .36771 Mtetra
.651 .567 .748 r
.1562 .36771 .16239 .38387 .17265 .37998 .1666 .36249 Mtetra
.64 .548 .735 r
.1666 .36249 .17265 .37998 .18293 .37629 .17701 .35749 Mtetra
.63 .531 .724 r
.17701 .35749 .18293 .37629 .19323 .37279 .18743 .35272 Mtetra
.62 .516 .714 r
.18743 .35272 .19323 .37279 .20355 .36949 .19785 .3482 Mtetra
.611 .502 .705 r
.19785 .3482 .20355 .36949 .21389 .36638 .20828 .34392 Mtetra
.604 .49 .697 r
.20828 .34392 .21389 .36638 .22426 .36349 .21873 .33987 Mtetra
.597 .479 .69 r
.21873 .33987 .22426 .36349 .23465 .36083 .2292 .33604 Mtetra
.592 .47 .682 r
.2292 .33604 .23465 .36083 .24508 .35835 .2397 .33232 Mtetra
.588 .462 .675 r
.2397 .33232 .24508 .35835 .25554 .35602 .25024 .32863 Mtetra
.588 .455 .668 r
.25024 .32863 .25554 .35602 .26606 .3536 .26083 .32475 Mtetra
.59 .451 .66 r
.26083 .32475 .26606 .3536 .27665 .35089 .2715 .32051 Mtetra
.593 .448 .653 r
.2715 .32051 .27665 .35089 .28734 .3475 .28224 .31575 Mtetra
.597 .446 .647 r
.28224 .31575 .28734 .3475 .29815 .34315 .29307 .31037 Mtetra
.602 .446 .643 r
.29307 .31037 .29815 .34315 .30908 .3376 .30397 .30436 Mtetra
.608 .449 .641 r
.30397 .30436 .30908 .3376 .32012 .33079 .31495 .29773 Mtetra
.615 .454 .641 r
.31495 .29773 .32012 .33079 .33124 .32311 .32599 .29047 Mtetra
.622 .461 .643 r
.32599 .29047 .33124 .32311 .34242 .31477 .33709 .28258 Mtetra
.634 .47 .643 r
.33709 .28258 .34242 .31477 .35365 .30578 .34826 .27367 Mtetra
.64 .475 .643 r
.34826 .27367 .35365 .30578 .36489 .29654 .35948 .26409 Mtetra
.633 .468 .642 r
.35948 .26409 .36489 .29654 .37611 .28809 .37067 .25519 Mtetra
.614 .454 .642 r
.37067 .25519 .37611 .28809 .38727 .28124 .3818 .24794 Mtetra
.577 .428 .642 r
.3818 .24794 .38727 .28124 .39834 .27724 .3928 .24389 Mtetra
.536 .4 .642 r
.3928 .24389 .39834 .27724 .40935 .27611 .40373 .24306 Mtetra
.513 .385 .643 r
.40373 .24306 .40935 .27611 .42037 .27658 .41466 .24389 Mtetra
.503 .379 .645 r
.41466 .24389 .42037 .27658 .43144 .27786 .42565 .24541 Mtetra
.512 .387 .647 r
.42565 .24541 .43144 .27786 .44261 .27892 .43675 .24627 Mtetra
.527 .397 .647 r
.43675 .24627 .44261 .27892 .45387 .27932 .44796 .24613 Mtetra
.536 .401 .645 r
.44796 .24613 .45387 .27932 .46523 .27908 .45925 .24535 Mtetra
.543 .405 .643 r
.45925 .24535 .46523 .27908 .47667 .27797 .47063 .24396 Mtetra
.551 .41 .642 r
.47063 .24396 .47667 .27797 .48821 .27558 .48208 .24193 Mtetra
.559 .417 .644 r
.48208 .24193 .48821 .27558 .49981 .27199 .49361 .23929 Mtetra
.568 .426 .648 r
.49361 .23929 .49981 .27199 .51147 .26742 .5052 .236 Mtetra
.576 .436 .654 r
.5052 .236 .51147 .26742 .52318 .26215 .51685 .23219 Mtetra
.584 .447 .661 r
.51685 .23219 .52318 .26215 .53492 .25658 .52855 .22801 Mtetra
.589 .456 .668 r
.52855 .22801 .53492 .25658 .54671 .25091 .5403 .22364 Mtetra
.591 .464 .675 r
.5403 .22364 .54671 .25091 .55854 .24538 .5521 .21929 Mtetra
.592 .47 .682 r
.5521 .21929 .55854 .24538 .57041 .24004 .56395 .21505 Mtetra
.592 .476 .69 r
.56395 .21505 .57041 .24004 .58233 .23493 .57586 .21104 Mtetra
.591 .482 .699 r
.57586 .21104 .58233 .23493 .5943 .23003 .58782 .20726 Mtetra
.589 .489 .708 r
.58782 .20726 .5943 .23003 .60632 .22533 .59985 .20373 Mtetra
.588 .496 .718 r
.59985 .20373 .60632 .22533 .6184 .22082 .61194 .20045 Mtetra
.586 .506 .731 r
.61194 .20045 .6184 .22082 .63053 .21651 .62411 .19741 Mtetra
.584 .517 .745 r
.62411 .19741 .63053 .21651 .64273 .21241 .63634 .19459 Mtetra
.582 .529 .76 r
.63634 .19459 .64273 .21241 .65499 .20853 .64866 .192 Mtetra
.58 .543 .778 r
.64866 .192 .65499 .20853 .66733 .20487 .66105 .18962 Mtetra
.577 .559 .798 r
.66105 .18962 .66733 .20487 .67973 .20143 .67352 .18743 Mtetra
.574 .578 .819 r
.67352 .18743 .67973 .20143 .69221 .19819 .68608 .18539 Mtetra
.57 .598 .841 r
.68608 .18539 .69221 .19819 .70476 .19512 .69871 .18348 Mtetra
.566 .62 .865 r
.69871 .18348 .70476 .19512 .71739 .19217 .71144 .18166 Mtetra
.561 .645 .89 r
.71144 .18166 .71739 .19217 .7301 .1893 .72424 .17988 Mtetra
.555 .671 .915 r
.72424 .17988 .7301 .1893 .74288 .18646 .73713 .1781 Mtetra
.754 .768 .864 r
.06568 .40859 .07322 .41517 .08354 .40897 .07612 .40174 Mtetra
.749 .751 .853 r
.07612 .40174 .08354 .40897 .09389 .40278 .08658 .39487 Mtetra
.743 .734 .843 r
.08658 .39487 .09389 .40278 .10425 .39662 .09706 .388 Mtetra
.736 .716 .833 r
.09706 .388 .10425 .39662 .11463 .39054 .10755 .38117 Mtetra
.728 .699 .823 r
.10755 .38117 .11463 .39054 .12501 .38458 .11806 .3744 Mtetra
.719 .681 .812 r
.11806 .3744 .12501 .38458 .1354 .37877 .12857 .36774 Mtetra
.71 .663 .802 r
.12857 .36774 .1354 .37877 .1458 .37314 .13909 .3612 Mtetra
.699 .644 .791 r
.13909 .3612 .1458 .37314 .1562 .36771 .1496 .35483 Mtetra
.689 .626 .781 r
.1496 .35483 .1562 .36771 .1666 .36249 .16012 .34865 Mtetra
.678 .609 .771 r
.16012 .34865 .1666 .36249 .17701 .35749 .17064 .34268 Mtetra
.667 .592 .761 r
.17064 .34268 .17701 .35749 .18743 .35272 .18116 .33693 Mtetra
.657 .576 .752 r
.18116 .33693 .18743 .35272 .19785 .3482 .19169 .33142 Mtetra
.647 .561 .743 r
.19169 .33142 .19785 .3482 .20828 .34392 .20221 .32615 Mtetra
.639 .547 .734 r
.20221 .32615 .20828 .34392 .21873 .33987 .21276 .32104 Mtetra
.632 .534 .725 r
.21276 .32104 .21873 .33987 .2292 .33604 .22332 .31606 Mtetra
.627 .522 .715 r
.22332 .31606 .2292 .33604 .2397 .33232 .23392 .31106 Mtetra
.624 .511 .705 r
.23392 .31106 .2397 .33232 .25024 .32863 .24456 .30592 Mtetra
.622 .501 .694 r
.24456 .30592 .25024 .32863 .26083 .32475 .25525 .30058 Mtetra
.621 .492 .684 r
.25525 .30058 .26083 .32475 .2715 .32051 .266 .29497 Mtetra
.617 .483 .676 r
.266 .29497 .2715 .32051 .28224 .31575 .27678 .28931 Mtetra
.613 .476 .671 r
.27678 .28931 .28224 .31575 .29307 .31037 .28759 .28372 Mtetra
.608 .472 .671 r
.28759 .28372 .29307 .31037 .30397 .30436 .2984 .27845 Mtetra
.605 .474 .675 r
.2984 .27845 .30397 .30436 .31495 .29773 .30923 .27353 Mtetra
.611 .487 .686 r
.30923 .27353 .31495 .29773 .32599 .29047 .32009 .26852 Mtetra
.626 .509 .701 r
.32009 .26852 .32599 .29047 .33709 .28258 .33102 .26307 Mtetra
.656 .545 .716 r
.33102 .26307 .33709 .28258 .34826 .27367 .34206 .25632 Mtetra
.687 .58 .73 r
.34206 .25632 .34826 .27367 .35948 .26409 .3532 .24833 Mtetra
.696 .601 .746 r
.3532 .24833 .35948 .26409 .37067 .25519 .36434 .24047 Mtetra
.685 .608 .764 r
.36434 .24047 .37067 .25519 .3818 .24794 .37545 .23368 Mtetra
.632 .588 .787 r
.37545 .23368 .3818 .24794 .3928 .24389 .38646 .2296 Mtetra
.56 .55 .8 r
.38646 .2296 .3928 .24389 .40373 .24306 .39741 .22822 Mtetra
.526 .524 .796 r
.39741 .22822 .40373 .24306 .41466 .24389 .40837 .22794 Mtetra
.524 .507 .78 r
.40837 .22794 .41466 .24389 .42565 .24541 .41941 .22779 Mtetra
.557 .507 .756 r
.41941 .22779 .42565 .24541 .43675 .24627 .43055 .2264 Mtetra
.582 .501 .729 r
.43055 .2264 .43675 .24627 .44796 .24613 .4418 .22372 Mtetra
.584 .483 .706 r
.4418 .22372 .44796 .24613 .45925 .24535 .45312 .22059 Mtetra
.58 .467 .689 r
.45312 .22059 .45925 .24535 .47063 .24396 .4645 .21737 Mtetra
.571 .452 .678 r
.4645 .21737 .47063 .24396 .48208 .24193 .47592 .21451 Mtetra
.565 .444 .673 r
.47592 .21451 .48208 .24193 .49361 .23929 .4874 .21197 Mtetra
.563 .444 .675 r
.4874 .21197 .49361 .23929 .5052 .236 .49894 .20951 Mtetra
.565 .449 .68 r
.49894 .20951 .5052 .236 .51685 .23219 .51054 .207 Mtetra
.572 .461 .689 r
.51054 .207 .51685 .23219 .52855 .22801 .52221 .20423 Mtetra
.578 .473 .699 r
.52221 .20423 .52855 .22801 .5403 .22364 .53393 .20124 Mtetra
.583 .486 .71 r
.53393 .20124 .5403 .22364 .5521 .21929 .54572 .19812 Mtetra
.586 .497 .721 r
.54572 .19812 .5521 .21929 .56395 .21505 .55756 .19498 Mtetra
.586 .507 .732 r
.55756 .19498 .56395 .21505 .57586 .21104 .56947 .19196 Mtetra
.585 .515 .743 r
.56947 .19196 .57586 .21104 .58782 .20726 .58144 .18913 Mtetra
.582 .523 .755 r
.58144 .18913 .58782 .20726 .59985 .20373 .59348 .18653 Mtetra
.578 .532 .767 r
.59348 .18653 .59985 .20373 .61194 .20045 .6056 .18418 Mtetra
.574 .542 .781 r
.6056 .18418 .61194 .20045 .62411 .19741 .61779 .18207 Mtetra
.569 .552 .796 r
.61779 .18207 .62411 .19741 .63634 .19459 .63006 .18017 Mtetra
.564 .564 .812 r
.63006 .18017 .63634 .19459 .64866 .192 .64242 .17848 Mtetra
.558 .577 .829 r
.64242 .17848 .64866 .192 .66105 .18962 .65486 .17696 Mtetra
.553 .591 .846 r
.65486 .17696 .66105 .18962 .67352 .18743 .66739 .17558 Mtetra
.547 .605 .863 r
.66739 .17558 .67352 .18743 .68608 .18539 .68 .17431 Mtetra
.541 .62 .88 r
.68 .17431 .68608 .18539 .69871 .18348 .69271 .17312 Mtetra
.535 .636 .897 r
.69271 .17312 .69871 .18348 .71144 .18166 .7055 .17197 Mtetra
.529 .652 .913 r
.7055 .17197 .71144 .18166 .72424 .17988 .71838 .17083 Mtetra
.523 .668 .928 r
.71838 .17083 .72424 .17988 .73713 .1781 .73134 .16968 Mtetra
.753 .768 .865 r
.05808 .40196 .06568 .40859 .07612 .40174 .06855 .39512 Mtetra
.754 .769 .865 r
.06855 .39512 .07612 .40174 .08658 .39487 .07904 .38823 Mtetra
.755 .769 .865 r
.07904 .38823 .08658 .39487 .09706 .388 .08955 .38133 Mtetra
.754 .769 .865 r
.08955 .38133 .09706 .388 .10755 .38117 .10008 .37443 Mtetra
.753 .768 .865 r
.10008 .37443 .10755 .38117 .11806 .3744 .11063 .36755 Mtetra
.751 .766 .865 r
.11063 .36755 .11806 .3744 .12857 .36774 .12119 .36073 Mtetra
.748 .762 .864 r
.12119 .36073 .12857 .36774 .13909 .3612 .13175 .35399 Mtetra
.743 .757 .863 r
.13175 .35399 .13909 .3612 .1496 .35483 .14233 .34737 Mtetra
.738 .75 .862 r
.14233 .34737 .1496 .35483 .16012 .34865 .15291 .34089 Mtetra
.731 .742 .86 r
.15291 .34089 .16012 .34865 .17064 .34268 .16349 .33459 Mtetra
.724 .733 .858 r
.16349 .33459 .17064 .34268 .18116 .33693 .17407 .32847 Mtetra
.717 .722 .854 r
.17407 .32847 .18116 .33693 .19169 .33142 .18466 .32251 Mtetra
.71 .711 .849 r
.18466 .32251 .19169 .33142 .20221 .32615 .19526 .31672 Mtetra
.704 .698 .841 r
.19526 .31672 .20221 .32615 .21276 .32104 .20589 .31098 Mtetra
.7 .683 .831 r
.20589 .31098 .21276 .32104 .22332 .31606 .21654 .30522 Mtetra
.697 .668 .817 r
.21654 .30522 .22332 .31606 .23392 .31106 .22724 .29931 Mtetra
.695 .651 .802 r
.22724 .29931 .23392 .31106 .24456 .30592 .23798 .29317 Mtetra
.69 .634 .787 r
.23798 .29317 .24456 .30592 .25525 .30058 .24877 .28689 Mtetra
.684 .618 .776 r
.24877 .28689 .25525 .30058 .266 .29497 .25958 .28058 Mtetra
.67 .602 .771 r
.25958 .28058 .266 .29497 .27678 .28931 .27038 .27478 Mtetra
.651 .591 .775 r
.27038 .27478 .27678 .28931 .28759 .28372 .28114 .26984 Mtetra
.626 .588 .792 r
.28114 .26984 .28759 .28372 .2984 .27845 .29184 .26612 Mtetra
.595 .599 .826 r
.29184 .26612 .2984 .27845 .30923 .27353 .30249 .26368 Mtetra
.579 .647 .881 r
.30249 .26368 .30923 .27353 .32009 .26852 .31317 .26172 Mtetra
.572 .735 .952 r
.31317 .26172 .32009 .26852 .33102 .26307 .32391 .25959 Mtetra
.604 .865 .992 r
.32391 .25959 .33102 .26307 .34206 .25632 .3348 .25601 Mtetra
.603 .943 .935 r
.3348 .25601 .34206 .25632 .3532 .24833 .34584 .25073 Mtetra
.465 .883 .77 r
.34584 .25073 .3532 .24833 .36434 .24047 .35695 .24483 Mtetra
0 0 0 r
.35695 .24483 .36434 .24047 .37545 .23368 .36808 .23908 Mtetra
.36808 .23908 .37545 .23368 .38646 .2296 .37916 .23497 Mtetra
.115 0 0 r
.37916 .23497 .38646 .2296 .39741 .22822 .39022 .23251 Mtetra
.069 0 0 r
.39022 .23251 .39741 .22822 .40837 .22794 .40133 .23021 Mtetra
0 0 0 r
.40133 .23021 .40837 .22794 .41941 .22779 .41252 .2273 Mtetra
.537 .918 .929 r
.41252 .2273 .41941 .22779 .43055 .2264 .42383 .22267 Mtetra
.725 .895 .957 r
.42383 .22267 .43055 .2264 .4418 .22372 .43522 .21658 Mtetra
.728 .785 .898 r
.43522 .21658 .4418 .22372 .45312 .22059 .44664 .21031 Mtetra
.694 .694 .845 r
.44664 .21031 .45312 .22059 .4645 .21737 .45809 .20451 Mtetra
.646 .624 .813 r
.45809 .20451 .4645 .21737 .47592 .21451 .46956 .20001 Mtetra
.608 .579 .795 r
.46956 .20001 .47592 .21451 .4874 .21197 .48105 .19675 Mtetra
.584 .556 .789 r
.48105 .19675 .4874 .21197 .49894 .20951 .49258 .19436 Mtetra
.57 .55 .793 r
.49258 .19436 .49894 .20951 .51054 .207 .50418 .19248 Mtetra
.571 .56 .803 r
.50418 .19248 .51054 .207 .52221 .20423 .51585 .19058 Mtetra
.575 .578 .818 r
.51585 .19058 .52221 .20423 .53393 .20124 .52758 .18855 Mtetra
.583 .599 .835 r
.52758 .18855 .53393 .20124 .54572 .19812 .53938 .18629 Mtetra
.588 .62 .851 r
.53938 .18629 .54572 .19812 .55756 .19498 .55125 .18387 Mtetra
.588 .636 .866 r
.55125 .18387 .55756 .19498 .56947 .19196 .56318 .18144 Mtetra
.585 .65 .88 r
.56318 .18144 .56947 .19196 .58144 .18913 .57519 .17907 Mtetra
.578 .659 .892 r
.57519 .17907 .58144 .18913 .59348 .18653 .58726 .17686 Mtetra
.569 .666 .903 r
.58726 .17686 .59348 .18653 .6056 .18418 .59941 .17483 Mtetra
.559 .67 .912 r
.59941 .17483 .6056 .18418 .61779 .18207 .61164 .17299 Mtetra
.549 .675 .921 r
.61164 .17299 .61779 .18207 .63006 .18017 .62395 .17134 Mtetra
.54 .678 .928 r
.62395 .17134 .63006 .18017 .64242 .17848 .63634 .16984 Mtetra
.531 .68 .933 r
.63634 .16984 .64242 .17848 .65486 .17696 .64882 .16846 Mtetra
.525 .683 .938 r
.64882 .16846 .65486 .17696 .66739 .17558 .66138 .16718 Mtetra
.52 .684 .941 r
.66138 .16718 .66739 .17558 .68 .17431 .67403 .16597 Mtetra
.517 .686 .943 r
.67403 .16597 .68 .17431 .69271 .17312 .68677 .16478 Mtetra
.516 .686 .944 r
.68677 .16478 .69271 .17312 .7055 .17197 .69959 .1636 Mtetra
.69959 .1636 .7055 .17197 .71838 .17083 .71251 .16241 Mtetra
.517 .686 .944 r
.71251 .16241 .71838 .17083 .73134 .16968 .7255 .16118 Mtetra
.74 .766 .874 r
.05043 .39529 .05808 .40196 .06855 .39512 .06085 .38898 Mtetra
.745 .783 .884 r
.06085 .38898 .06855 .39512 .07904 .38823 .07129 .38262 Mtetra
.75 .8 .893 r
.07129 .38262 .07904 .38823 .08955 .38133 .08176 .37623 Mtetra
.754 .817 .902 r
.08176 .37623 .08955 .38133 .10008 .37443 .09226 .36981 Mtetra
.756 .834 .911 r
.09226 .36981 .10008 .37443 .11063 .36755 .10278 .36338 Mtetra
.757 .849 .919 r
.10278 .36338 .11063 .36755 .12119 .36073 .11332 .35695 Mtetra
.757 .863 .927 r
.11332 .35695 .12119 .36073 .13175 .35399 .12388 .35056 Mtetra
.754 .876 .934 r
.12388 .35056 .13175 .35399 .14233 .34737 .13446 .34424 Mtetra
.75 .887 .941 r
.13446 .34424 .14233 .34737 .15291 .34089 .14504 .33802 Mtetra
.745 .896 .947 r
.14504 .33802 .15291 .34089 .16349 .33459 .15564 .3319 Mtetra
.738 .903 .952 r
.15564 .3319 .16349 .33459 .17407 .32847 .16625 .3259 Mtetra
.732 .908 .955 r
.16625 .3259 .17407 .32847 .18466 .32251 .17688 .31999 Mtetra
.728 .91 .957 r
.17688 .31999 .18466 .32251 .19526 .31672 .18753 .31413 Mtetra
.731 .909 .956 r
.18753 .31413 .19526 .31672 .20589 .31098 .19821 .30821 Mtetra
.738 .905 .952 r
.19821 .30821 .20589 .31098 .21654 .30522 .20894 .30214 Mtetra
.748 .896 .945 r
.20894 .30214 .21654 .30522 .22724 .29931 .21971 .29583 Mtetra
.758 .885 .935 r
.21971 .29583 .22724 .29931 .23798 .29317 .23054 .28925 Mtetra
.758 .872 .93 r
.23054 .28925 .23798 .29317 .24877 .28689 .2414 .28264 Mtetra
.75 .862 .931 r
.2414 .28264 .24877 .28689 .25958 .28058 .25225 .27627 Mtetra
.715 .857 .949 r
.25225 .27627 .25958 .28058 .27038 .27478 .26305 .27086 Mtetra
.641 .857 .982 r
.26305 .27086 .27038 .27478 .28114 .26984 .27377 .26692 Mtetra
.471 .831 .995 r
.27377 .26692 .28114 .26984 .29184 .26612 .28438 .26482 Mtetra
.136 .673 .849 r
.28438 .26482 .29184 .26612 .30249 .26368 .29491 .26463 Mtetra
.15 0 0 r
.29491 .26463 .30249 .26368 .31317 .26172 .30545 .26529 Mtetra
.288 0 0 r
.30545 .26529 .31317 .26172 .32391 .25959 .31606 .26599 Mtetra
.276 0 0 r
.31606 .26599 .32391 .25959 .3348 .25601 .32684 .26522 Mtetra
.232 0 0 r
.32684 .26522 .3348 .25601 .34584 .25073 .33781 .26246 Mtetra
.231 0 0 r
.33781 .26246 .34584 .25073 .35695 .24483 .34891 .25848 Mtetra
.241 0 .048 r
.34891 .25848 .35695 .24483 .36808 .23908 .36009 .25381 Mtetra
.285 0 .092 r
.36009 .25381 .36808 .23908 .37916 .23497 .37128 .24969 Mtetra
.307 0 .103 r
.37128 .24969 .37916 .23497 .39022 .23251 .38249 .24612 Mtetra
.262 0 .059 r
.38249 .24612 .39022 .23251 .40133 .23021 .39379 .24186 Mtetra
.158 0 0 r
.39379 .24186 .40133 .23021 .41252 .2273 .40518 .23637 Mtetra
0 0 0 r
.40518 .23637 .41252 .2273 .42383 .22267 .41667 .22888 Mtetra
.41667 .22888 .42383 .22267 .43522 .21658 .42824 .21989 Mtetra
.599 .932 .728 r
.42824 .21989 .43522 .21658 .44664 .21031 .43982 .21092 Mtetra
.705 .984 .875 r
.43982 .21092 .44664 .21031 .45809 .20451 .45139 .20281 Mtetra
.687 .95 .956 r
.45139 .20281 .45809 .20451 .46956 .20001 .46294 .19661 Mtetra
.624 .887 .988 r
.46294 .19661 .46956 .20001 .48105 .19675 .4745 .19228 Mtetra
.557 .826 .996 r
.4745 .19228 .48105 .19675 .49258 .19436 .48608 .18943 Mtetra
.502 .787 .996 r
.48608 .18943 .49258 .19436 .50418 .19248 .49772 .18756 Mtetra
.483 .779 .997 r
.49772 .18756 .50418 .19248 .51585 .19058 .50942 .18593 Mtetra
.473 .785 .998 r
.50942 .18593 .51585 .19058 .52758 .18855 .52119 .18429 Mtetra
.478 .802 1 r
.52119 .18429 .52758 .18855 .53938 .18629 .53304 .18237 Mtetra
.48 .816 .999 r
.53304 .18237 .53938 .18629 .55125 .18387 .54495 .18022 Mtetra
.479 .825 .998 r
.54495 .18022 .55125 .18387 .56318 .18144 .55694 .17792 Mtetra
.476 .829 .996 r
.55694 .17792 .56318 .18144 .57519 .17907 .56899 .17555 Mtetra
.469 .826 .996 r
.56899 .17555 .57519 .17907 .58726 .17686 .58111 .17325 Mtetra
.465 .822 .996 r
.58111 .17325 .58726 .17686 .59941 .17483 .59331 .17103 Mtetra
.461 .815 .997 r
.59331 .17103 .59941 .17483 .61164 .17299 .60558 .16894 Mtetra
.462 .807 .998 r
.60558 .16894 .61164 .17299 .62395 .17134 .61793 .16697 Mtetra
.465 .799 .999 r
.61793 .16697 .62395 .17134 .63634 .16984 .63035 .1651 Mtetra
.472 .79 .999 r
.63035 .1651 .63634 .16984 .64882 .16846 .64286 .1633 Mtetra
.482 .78 .997 r
.64286 .1633 .64882 .16846 .66138 .16718 .65545 .16155 Mtetra
.494 .769 .993 r
.65545 .16155 .66138 .16718 .67403 .16597 .66812 .15981 Mtetra
.506 .758 .986 r
.66812 .15981 .67403 .16597 .68677 .16478 .68087 .15806 Mtetra
.518 .744 .977 r
.68087 .15806 .68677 .16478 .69959 .1636 .69371 .15628 Mtetra
.529 .73 .966 r
.69371 .15628 .69959 .1636 .71251 .16241 .70662 .15447 Mtetra
.539 .715 .954 r
.70662 .15447 .71251 .16241 .7255 .16118 .71961 .15261 Mtetra
.711 .763 .893 r
.04273 .38856 .05043 .39529 .06085 .38898 .05301 .38332 Mtetra
.718 .796 .913 r
.05301 .38332 .06085 .38898 .07129 .38262 .06333 .37801 Mtetra
.722 .832 .933 r
.06333 .37801 .07129 .38262 .08176 .37623 .07369 .37266 Mtetra
.722 .867 .95 r
.07369 .37266 .08176 .37623 .09226 .36981 .08408 .36726 Mtetra
.717 .901 .961 r
.08408 .36726 .09226 .36981 .10278 .36338 .09451 .3618 Mtetra
.702 .929 .965 r
.09451 .3618 .10278 .36338 .11332 .35695 .10497 .35633 Mtetra
.677 .948 .958 r
.10497 .35633 .11332 .35695 .12388 .35056 .11545 .35085 Mtetra
.639 .954 .936 r
.11545 .35085 .12388 .35056 .13446 .34424 .12597 .34538 Mtetra
.588 .945 .9 r
.12597 .34538 .13446 .34424 .14504 .33802 .13651 .33995 Mtetra
.528 .921 .849 r
.13651 .33995 .14504 .33802 .15564 .3319 .14708 .33457 Mtetra
.462 .884 .789 r
.14708 .33457 .15564 .3319 .16625 .3259 .15766 .32925 Mtetra
.4 .842 .727 r
.15766 .32925 .16625 .3259 .17688 .31999 .16828 .32394 Mtetra
.346 .8 .667 r
.16828 .32394 .17688 .31999 .18753 .31413 .17893 .31863 Mtetra
0 0 0 r
.17893 .31863 .18753 .31413 .19821 .30821 .18963 .31321 Mtetra
.18963 .31321 .19821 .30821 .20894 .30214 .20037 .30762 Mtetra
.20037 .30762 .20894 .30214 .21971 .29583 .21116 .30183 Mtetra
.21116 .30183 .21971 .29583 .23054 .28925 .222 .29586 Mtetra
.222 .29586 .23054 .28925 .2414 .28264 .23286 .28999 Mtetra
.23286 .28999 .2414 .28264 .25225 .27627 .24372 .2845 Mtetra
.059 0 0 r
.24372 .2845 .25225 .27627 .26305 .27086 .25452 .28002 Mtetra
.202 0 0 r
.25452 .28002 .26305 .27086 .27377 .26692 .26524 .27697 Mtetra
.32 0 0 r
.26524 .27697 .27377 .26692 .28438 .26482 .27587 .27556 Mtetra
.403 0 .069 r
.27587 .27556 .28438 .26482 .29491 .26463 .28645 .27577 Mtetra
.429 0 .093 r
.28645 .27577 .29491 .26463 .30545 .26529 .29705 .27655 Mtetra
.422 0 .09 r
.29705 .27655 .30545 .26529 .31606 .26599 .30775 .27714 Mtetra
.363 0 .052 r
.30775 .27714 .31606 .26599 .32684 .26522 .31862 .27631 Mtetra
.276 0 0 r
.31862 .27631 .32684 .26522 .33781 .26246 .32968 .27361 Mtetra
.219 0 0 r
.32968 .27361 .33781 .26246 .34891 .25848 .34086 .26976 Mtetra
.187 0 0 r
.34086 .26976 .34891 .25848 .36009 .25381 .35212 .26525 Mtetra
.213 0 0 r
.35212 .26525 .36009 .25381 .37128 .24969 .36341 .26111 Mtetra
.234 0 0 r
.36341 .26111 .37128 .24969 .38249 .24612 .37473 .25735 Mtetra
.195 0 0 r
.37473 .25735 .38249 .24612 .39379 .24186 .38613 .25292 Mtetra
.128 0 0 r
.38613 .25292 .39379 .24186 .40518 .23637 .39762 .24733 Mtetra
.015 0 0 r
.39762 .24733 .40518 .23637 .41667 .22888 .40922 .23987 Mtetra
0 0 0 r
.40922 .23987 .41667 .22888 .42824 .21989 .4209 .23095 Mtetra
.4209 .23095 .42824 .21989 .43982 .21092 .43259 .22183 Mtetra
.43259 .22183 .43982 .21092 .45139 .20281 .44428 .21327 Mtetra
.04 0 0 r
.44428 .21327 .45139 .20281 .46294 .19661 .45596 .20633 Mtetra
.114 0 0 r
.45596 .20633 .46294 .19661 .4745 .19228 .46763 .20105 Mtetra
.167 0 0 r
.46763 .20105 .4745 .19228 .48608 .18943 .47932 .19722 Mtetra
.196 0 0 r
.47932 .19722 .48608 .18943 .49772 .18756 .49105 .19442 Mtetra
.188 0 0 r
.49105 .19442 .49772 .18756 .50942 .18593 .50284 .192 Mtetra
.165 0 0 r
.50284 .192 .50942 .18593 .52119 .18429 .5147 .18969 Mtetra
.123 0 0 r
.5147 .18969 .52119 .18429 .53304 .18237 .52663 .1872 Mtetra
.081 0 0 r
.52663 .1872 .53304 .18237 .54495 .18022 .53862 .18451 Mtetra
.038 0 0 r
.53862 .18451 .54495 .18022 .55694 .17792 .55068 .18164 Mtetra
0 0 0 r
.55068 .18164 .55694 .17792 .56899 .17555 .56281 .17868 Mtetra
.56281 .17868 .56899 .17555 .58111 .17325 .57499 .1757 Mtetra
.57499 .1757 .58111 .17325 .59331 .17103 .58725 .17274 Mtetra
.58725 .17274 .59331 .17103 .60558 .16894 .59957 .16984 Mtetra
.198 .725 .738 r
.59957 .16984 .60558 .16894 .61793 .16697 .61197 .16699 Mtetra
.263 .772 .817 r
.61197 .16699 .61793 .16697 .63035 .1651 .62443 .16418 Mtetra
.333 .812 .889 r
.62443 .16418 .63035 .1651 .64286 .1633 .63697 .16139 Mtetra
.401 .837 .946 r
.63697 .16139 .64286 .1633 .65545 .16155 .64958 .15859 Mtetra
.461 .846 .983 r
.64958 .15859 .65545 .16155 .66812 .15981 .66225 .15577 Mtetra
.51 .838 .999 r
.66225 .15577 .66812 .15981 .68087 .15806 .675 .1529 Mtetra
.546 .817 .996 r
.675 .1529 .68087 .15806 .69371 .15628 .68782 .14998 Mtetra
.571 .788 .981 r
.68782 .14998 .69371 .15628 .70662 .15447 .70072 .14701 Mtetra
.586 .756 .959 r
.70072 .14701 .70662 .15447 .71961 .15261 .71368 .14397 Mtetra
.664 .753 .917 r
.03496 .38178 .04273 .38856 .05301 .38332 .04507 .37788 Mtetra
.666 .798 .945 r
.04507 .37788 .05301 .38332 .06333 .37801 .05522 .3739 Mtetra
.662 .843 .969 r
.05522 .3739 .06333 .37801 .07369 .37266 .06542 .36987 Mtetra
.647 .884 .984 r
.06542 .36987 .07369 .37266 .08408 .36726 .07566 .36576 Mtetra
.615 .914 .98 r
.07566 .36576 .08408 .36726 .09451 .3618 .08595 .36159 Mtetra
.562 .922 .949 r
.08595 .36159 .09451 .3618 .10497 .35633 .09629 .35736 Mtetra
.486 .901 .886 r
.09629 .35736 .10497 .35633 .11545 .35085 .10667 .35308 Mtetra
.393 .849 .792 r
.10667 .35308 .11545 .35085 .12597 .34538 .11709 .34878 Mtetra
.294 .774 .682 r
.11709 .34878 .12597 .34538 .13651 .33995 .12754 .34446 Mtetra
0 0 0 r
.12754 .34446 .13651 .33995 .14708 .33457 .13804 .34013 Mtetra
.13804 .34013 .14708 .33457 .15766 .32925 .14858 .33579 Mtetra
.14858 .33579 .15766 .32925 .16828 .32394 .15915 .33142 Mtetra
.001 0 0 r
.15915 .33142 .16828 .32394 .17893 .31863 .16978 .32699 Mtetra
.04 0 0 r
.16978 .32699 .17893 .31863 .18963 .31321 .18045 .32245 Mtetra
.072 0 0 r
.18045 .32245 .18963 .31321 .20037 .30762 .19118 .31776 Mtetra
.103 0 0 r
.19118 .31776 .20037 .30762 .21116 .30183 .20195 .31296 Mtetra
.134 0 0 r
.20195 .31296 .21116 .30183 .222 .29586 .21277 .30808 Mtetra
.18 0 0 r
.21277 .30808 .222 .29586 .23286 .28999 .22361 .30339 Mtetra
.231 0 .023 r
.22361 .30339 .23286 .28999 .24372 .2845 .23445 .29908 Mtetra
.291 0 .081 r
.23445 .29908 .24372 .2845 .25452 .28002 .24526 .29558 Mtetra
.346 0 .127 r
.24526 .29558 .25452 .28002 .26524 .27697 .25603 .29313 Mtetra
.389 0 .159 r
.25603 .29313 .26524 .27697 .27587 .27556 .26676 .29175 Mtetra
.418 .02 .174 r
.26676 .29175 .27587 .27556 .28645 .27577 .27748 .29129 Mtetra
.417 .014 .164 r
.27748 .29129 .28645 .27577 .29705 .27655 .28827 .29095 Mtetra
.394 0 .132 r
.28827 .29095 .29705 .27655 .30775 .27714 .29916 .29014 Mtetra
.332 0 .071 r
.29916 .29014 .30775 .27714 .31862 .27631 .3102 .28808 Mtetra
.245 0 0 r
.3102 .28808 .31862 .27631 .32968 .27361 .3214 .28457 Mtetra
.184 0 0 r
.3214 .28457 .32968 .27361 .34086 .26976 .3327 .28028 Mtetra
.153 0 0 r
.3327 .28028 .34086 .26976 .35212 .26525 .34407 .27565 Mtetra
.179 0 0 r
.34407 .27565 .35212 .26525 .36341 .26111 .35545 .27149 Mtetra
.207 0 0 r
.35545 .27149 .36341 .26111 .37473 .25735 .36686 .26782 Mtetra
.191 0 0 r
.36686 .26782 .37473 .25735 .38613 .25292 .37833 .26379 Mtetra
.161 0 0 r
.37833 .26379 .38613 .25292 .39762 .24733 .38989 .25899 Mtetra
.106 0 0 r
.38989 .25899 .39762 .24733 .40922 .23987 .40155 .25271 Mtetra
.08 0 0 r
.40155 .25271 .40922 .23987 .4209 .23095 .41329 .24518 Mtetra
.102 0 0 r
.41329 .24518 .4209 .23095 .43259 .22183 .42508 .23716 Mtetra
.139 0 .027 r
.42508 .23716 .43259 .22183 .44428 .21327 .43688 .22924 Mtetra
.195 0 .065 r
.43688 .22924 .44428 .21327 .45596 .20633 .44868 .22225 Mtetra
.237 0 .084 r
.44868 .22225 .45596 .20633 .46763 .20105 .46049 .21633 Mtetra
.267 0 .087 r
.46049 .21633 .46763 .20105 .47932 .19722 .47232 .21148 Mtetra
.282 0 .074 r
.47232 .21148 .47932 .19722 .49105 .19442 .48418 .20743 Mtetra
.278 0 .046 r
.48418 .20743 .49105 .19442 .50284 .192 .4961 .20379 Mtetra
.264 0 .01 r
.4961 .20379 .50284 .192 .5147 .18969 .50807 .20033 Mtetra
.236 0 0 r
.50807 .20033 .5147 .18969 .52663 .1872 .52011 .19679 Mtetra
.204 0 0 r
.52011 .19679 .52663 .1872 .53862 .18451 .5322 .19313 Mtetra
.168 0 0 r
.5322 .19313 .53862 .18451 .55068 .18164 .54435 .18933 Mtetra
.129 0 0 r
.54435 .18933 .55068 .18164 .56281 .17868 .55656 .18541 Mtetra
.087 0 0 r
.55656 .18541 .56281 .17868 .57499 .1757 .56883 .18143 Mtetra
.036 0 0 r
.56883 .18143 .57499 .1757 .58725 .17274 .58116 .17741 Mtetra
0 0 0 r
.58116 .17741 .58725 .17274 .59957 .16984 .59354 .17338 Mtetra
.59354 .17338 .59957 .16984 .61197 .16699 .60599 .16933 Mtetra
.60599 .16933 .61197 .16699 .62443 .16418 .61849 .16527 Mtetra
.287 .783 .753 r
.61849 .16527 .62443 .16418 .63697 .16139 .63106 .16118 Mtetra
.391 .851 .862 r
.63106 .16118 .63697 .16139 .64958 .15859 .64369 .15703 Mtetra
.485 .889 .941 r
.64369 .15703 .64958 .15859 .66225 .15577 .65637 .15283 Mtetra
.557 .894 .983 r
.65637 .15283 .66225 .15577 .675 .1529 .66911 .14854 Mtetra
.605 .872 .992 r
.66911 .14854 .675 .1529 .68782 .14998 .68191 .14419 Mtetra
.632 .834 .978 r
.68191 .14419 .68782 .14998 .70072 .14701 .69477 .13976 Mtetra
.645 .791 .952 r
.69477 .13976 .70072 .14701 .71368 .14397 .70769 .13525 Mtetra
.6 .736 .94 r
.02714 .37496 .03496 .38178 .04507 .37788 .03705 .37246 Mtetra
.592 .782 .971 r
.03705 .37246 .04507 .37788 .05522 .3739 .04702 .36988 Mtetra
.573 .825 .993 r
.04702 .36988 .05522 .3739 .06542 .36987 .05704 .36722 Mtetra
.537 .859 .996 r
.05704 .36722 .06542 .36987 .07566 .36576 .06712 .36449 Mtetra
.479 .871 .969 r
.06712 .36449 .07566 .36576 .08595 .36159 .07726 .36167 Mtetra
.397 .849 .902 r
.07726 .36167 .08595 .36159 .09629 .35736 .08745 .35877 Mtetra
.298 .794 .797 r
.08745 .35877 .09629 .35736 .10667 .35308 .0977 .35579 Mtetra
0 0 0 r
.0977 .35579 .10667 .35308 .11709 .34878 .10801 .35275 Mtetra
.10801 .35275 .11709 .34878 .12754 .34446 .11837 .34964 Mtetra
.11837 .34964 .12754 .34446 .13804 .34013 .12878 .34647 Mtetra
.045 0 0 r
.12878 .34647 .13804 .34013 .14858 .33579 .13924 .34325 Mtetra
.095 0 0 r
.13924 .34325 .14858 .33579 .15915 .33142 .14976 .33994 Mtetra
.134 0 0 r
.14976 .33994 .15915 .33142 .16978 .32699 .16034 .33655 Mtetra
.166 0 0 r
.16034 .33655 .16978 .32699 .18045 .32245 .17097 .33305 Mtetra
.192 0 0 r
.17097 .33305 .18045 .32245 .19118 .31776 .18166 .32945 Mtetra
.218 0 0 r
.18166 .32945 .19118 .31776 .20195 .31296 .19241 .32578 Mtetra
.243 0 .011 r
.19241 .32578 .20195 .31296 .21277 .30808 .2032 .32209 Mtetra
.273 0 .053 r
.2032 .32209 .21277 .30808 .22361 .30339 .21402 .31853 Mtetra
.303 0 .091 r
.21402 .31853 .22361 .30339 .23445 .29908 .22486 .31523 Mtetra
.331 0 .123 r
.22486 .31523 .23445 .29908 .24526 .29558 .23572 .31233 Mtetra
.355 0 .145 r
.23572 .31233 .24526 .29558 .25603 .29313 .24659 .30992 Mtetra
.369 0 .152 r
.24659 .30992 .25603 .29313 .26676 .29175 .25747 .30789 Mtetra
.372 0 .144 r
.25747 .30789 .26676 .29175 .27748 .29129 .2684 .30611 Mtetra
.351 0 .111 r
.2684 .30611 .27748 .29129 .28827 .29095 .27941 .30409 Mtetra
.309 0 .056 r
.27941 .30409 .28827 .29095 .29916 .29014 .29052 .30155 Mtetra
.239 0 0 r
.29052 .30155 .29916 .29014 .3102 .28808 .30175 .29818 Mtetra
.156 0 0 r
.30175 .29818 .3102 .28808 .3214 .28457 .31308 .29397 Mtetra
.111 0 0 r
.31308 .29397 .3214 .28457 .3327 .28028 .32449 .2894 Mtetra
.099 0 0 r
.32449 .2894 .3327 .28028 .34407 .27565 .33594 .28478 Mtetra
.131 0 0 r
.33594 .28478 .34407 .27565 .35545 .27149 .34741 .28061 Mtetra
.16 0 0 r
.34741 .28061 .35545 .27149 .36686 .26782 .35891 .27687 Mtetra
.157 0 0 r
.35891 .27687 .36686 .26782 .37833 .26379 .37046 .27309 Mtetra
.145 0 0 r
.37046 .27309 .37833 .26379 .38989 .25899 .38209 .26896 Mtetra
.118 0 0 r
.38209 .26896 .38989 .25899 .40155 .25271 .39379 .26397 Mtetra
.115 0 0 r
.39379 .26397 .40155 .25271 .41329 .24518 .40558 .25814 Mtetra
.141 0 0 r
.40558 .25814 .41329 .24518 .42508 .23716 .41742 .25178 Mtetra
.174 0 .023 r
.41742 .25178 .42508 .23716 .43688 .22924 .42931 .24517 Mtetra
.213 0 .066 r
.42931 .24517 .43688 .22924 .44868 .22225 .44122 .2388 Mtetra
.24 0 .09 r
.44122 .2388 .44868 .22225 .46049 .21633 .45316 .23282 Mtetra
.258 0 .097 r
.45316 .23282 .46049 .21633 .47232 .21148 .46513 .22732 Mtetra
.264 0 .089 r
.46513 .22732 .47232 .21148 .48418 .20743 .47714 .22223 Mtetra
.258 0 .068 r
.47714 .22223 .48418 .20743 .4961 .20379 .48919 .21739 Mtetra
.242 0 .037 r
.48919 .21739 .4961 .20379 .50807 .20033 .50129 .21269 Mtetra
.217 0 0 r
.50129 .21269 .50807 .20033 .52011 .19679 .51345 .20795 Mtetra
.186 0 0 r
.51345 .20795 .52011 .19679 .5322 .19313 .52565 .20315 Mtetra
.149 0 0 r
.52565 .20315 .5322 .19313 .54435 .18933 .53791 .19823 Mtetra
.107 0 0 r
.53791 .19823 .54435 .18933 .55656 .18541 .55021 .19321 Mtetra
.058 0 0 r
.55021 .19321 .55656 .18541 .56883 .18143 .56257 .18809 Mtetra
0 0 0 r
.56257 .18809 .56883 .18143 .58116 .17741 .57497 .18288 Mtetra
.57497 .18288 .58116 .17741 .59354 .17338 .58743 .1776 Mtetra
.58743 .1776 .59354 .17338 .60599 .16933 .59993 .17226 Mtetra
.59993 .17226 .60599 .16933 .61849 .16527 .61248 .16684 Mtetra
.366 .827 .744 r
.61248 .16684 .61849 .16527 .63106 .16118 .62508 .16135 Mtetra
.476 .896 .853 r
.62508 .16135 .63106 .16118 .64369 .15703 .63773 .15576 Mtetra
.568 .931 .931 r
.63773 .15576 .64369 .15703 .65637 .15283 .65042 .15009 Mtetra
.635 .931 .97 r
.65042 .15009 .65637 .15283 .66911 .14854 .66316 .14432 Mtetra
.675 .903 .976 r
.66316 .14432 .66911 .14854 .68191 .14419 .67595 .13846 Mtetra
.695 .861 .962 r
.67595 .13846 .68191 .14419 .69477 .13976 .68878 .13251 Mtetra
.701 .815 .936 r
.68878 .13251 .69477 .13976 .70769 .13525 .70165 .12647 Mtetra
.522 .709 .957 r
.01926 .36808 .02714 .37496 .03705 .37246 .02899 .36685 Mtetra
.505 .748 .983 r
.02899 .36685 .03705 .37246 .04702 .36988 .03878 .36553 Mtetra
.476 .782 .998 r
.03878 .36553 .04702 .36988 .05704 .36722 .04864 .36412 Mtetra
.433 .805 .994 r
.04864 .36412 .05704 .36722 .06712 .36449 .05857 .36261 Mtetra
.373 .808 .962 r
.05857 .36261 .06712 .36449 .07726 .36167 .06856 .361 Mtetra
.297 .785 .897 r
.06856 .361 .07726 .36167 .08745 .35877 .07863 .3593 Mtetra
.212 .737 .803 r
.07863 .3593 .08745 .35877 .0977 .35579 .08876 .3575 Mtetra
0 0 0 r
.08876 .3575 .0977 .35579 .10801 .35275 .09895 .3556 Mtetra
.09895 .3556 .10801 .35275 .11837 .34964 .10922 .3536 Mtetra
.018 0 0 r
.10922 .3536 .11837 .34964 .12878 .34647 .11954 .3515 Mtetra
.072 0 0 r
.11954 .3515 .12878 .34647 .13924 .34325 .12994 .34931 Mtetra
.116 0 0 r
.12994 .34931 .13924 .34325 .14976 .33994 .1404 .34701 Mtetra
.152 0 0 r
.1404 .34701 .14976 .33994 .16034 .33655 .15092 .34461 Mtetra
.182 0 0 r
.15092 .34461 .16034 .33655 .17097 .33305 .16151 .34211 Mtetra
.208 0 0 r
.16151 .34211 .17097 .33305 .18166 .32945 .17217 .33951 Mtetra
.23 0 0 r
.17217 .33951 .18166 .32945 .19241 .32578 .18288 .3368 Mtetra
.247 0 0 r
.18288 .3368 .19241 .32578 .2032 .32209 .19367 .33399 Mtetra
.261 0 0 r
.19367 .33399 .2032 .32209 .21402 .31853 .20451 .33108 Mtetra
.269 0 .014 r
.20451 .33108 .21402 .31853 .22486 .31523 .21541 .32806 Mtetra
.27 0 .021 r
.21541 .32806 .22486 .31523 .23572 .31233 .22638 .32494 Mtetra
.261 0 .011 r
.22638 .32494 .23572 .31233 .24659 .30992 .23741 .32171 Mtetra
.24 0 0 r
.23741 .32171 .24659 .30992 .25747 .30789 .2485 .31838 Mtetra
.204 0 0 r
.2485 .31838 .25747 .30789 .2684 .30611 .25965 .31494 Mtetra
.147 0 0 r
.25965 .31494 .2684 .30611 .27941 .30409 .27086 .31139 Mtetra
.079 0 0 r
.27086 .31139 .27941 .30409 .29052 .30155 .28213 .30773 Mtetra
.016 0 0 r
.28213 .30773 .29052 .30155 .30175 .29818 .29346 .30397 Mtetra
0 0 0 r
.29346 .30397 .30175 .29818 .31308 .29397 .30485 .3001 Mtetra
.30485 .3001 .31308 .29397 .32449 .2894 .31629 .29612 Mtetra
.025 0 0 r
.31629 .29612 .32449 .2894 .33594 .28478 .32779 .29204 Mtetra
.045 0 0 r
.32779 .29204 .33594 .28478 .34741 .28061 .33935 .28784 Mtetra
.038 0 0 r
.33935 .28784 .34741 .28061 .35891 .27687 .35096 .28353 Mtetra
.003 0 0 r
.35096 .28353 .35891 .27687 .37046 .27309 .36263 .27912 Mtetra
0 0 0 r
.36263 .27912 .37046 .27309 .38209 .26896 .37435 .27459 Mtetra
.37435 .27459 .38209 .26896 .39379 .26397 .38612 .26995 Mtetra
.38612 .26995 .39379 .26397 .40558 .25814 .39795 .2652 Mtetra
.001 0 0 r
.39795 .2652 .40558 .25814 .41742 .25178 .40983 .26035 Mtetra
.067 0 0 r
.40983 .26035 .41742 .25178 .42931 .24517 .42176 .25538 Mtetra
.124 0 0 r
.42176 .25538 .42931 .24517 .44122 .2388 .43375 .25029 Mtetra
.16 0 0 r
.43375 .25029 .44122 .2388 .45316 .23282 .44578 .2451 Mtetra
.178 0 0 r
.44578 .2451 .45316 .23282 .46513 .22732 .45786 .23979 Mtetra
.179 0 0 r
.45786 .23979 .46513 .22732 .47714 .22223 .46999 .23438 Mtetra
.167 0 0 r
.46999 .23438 .47714 .22223 .48919 .21739 .48216 .22885 Mtetra
.144 0 0 r
.48216 .22885 .48919 .21739 .50129 .21269 .49439 .2232 Mtetra
.111 0 0 r
.49439 .2232 .50129 .21269 .51345 .20795 .50666 .21745 Mtetra
.071 0 0 r
.50666 .21745 .51345 .20795 .52565 .20315 .51897 .21158 Mtetra
.022 0 0 r
.51897 .21158 .52565 .20315 .53791 .19823 .53133 .2056 Mtetra
0 0 0 r
.53133 .2056 .53791 .19823 .55021 .19321 .54373 .19951 Mtetra
.54373 .19951 .55021 .19321 .56257 .18809 .55617 .1933 Mtetra
.55617 .1933 .56257 .18809 .57497 .18288 .56866 .18698 Mtetra
.56866 .18698 .57497 .18288 .58743 .1776 .58118 .18055 Mtetra
.35 .799 .654 r
.58118 .18055 .58743 .1776 .59993 .17226 .59375 .17401 Mtetra
.447 .871 .754 r
.59375 .17401 .59993 .17226 .61248 .16684 .60635 .16735 Mtetra
.54 .926 .842 r
.60635 .16735 .61248 .16684 .62508 .16135 .61899 .16058 Mtetra
.619 .956 .907 r
.61899 .16058 .62508 .16135 .63773 .15576 .63167 .1537 Mtetra
.677 .958 .945 r
.63167 .1537 .63773 .15576 .65042 .15009 .64438 .14671 Mtetra
.715 .939 .959 r
.64438 .14671 .65042 .15009 .66316 .14432 .65713 .1396 Mtetra
.735 .906 .954 r
.65713 .1396 .66316 .14432 .67595 .13846 .66991 .13238 Mtetra
.743 .866 .937 r
.66991 .13238 .67595 .13846 .68878 .13251 .68272 .12505 Mtetra
.743 .824 .915 r
.68272 .12505 .68878 .13251 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Sooooo`03okkBj_l0003ooooo01Gooooo00?o
0000ooooooooool0DOooool0063ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`0Mooooo`?o00000_ooool00ol0003oooooooooo`1Oooooo`?o_];Z00?o
0000okkBj_ooool05Oooool00ol0003oooooooooo`1@ooooo`00H?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol0000Looooo`;o0000IOooool2okkMk`?o_];Z00?o0000ok?@koooool05?oo
ool00ol0003oooooo`00001Aooooo`00H?ooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00006_ooool3o`0006Gooooo1OnngNl00onnd^[o/m3_o`000002ok?@kaKooooo
00?o0000ooooooooool0Coooool0063ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgM
gOmEEEGoooooo`0001Sooooo0_l0001Vooooo`;o_>Od1?nngNl01?nag?Ko/m3_ok?@kol00003ok?@
kaKooooo00?o0000ooooooooool0C_ooool0063ooooo00Go410@oooooooooooooooooa0@400<oooo
o`03ogMgMoo<c<co000001Gooooo0ol00002ooooo`03o`000?oooooooooo06;ooooo1?nlio@00onn
gNoo/Mcfok7LmP02ok7LmP05ok?@kol0003o/m3_ok?@konUb_<05_ooool00ol0003oooooooooo`1>
ooooo`00H?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000004oooool2
o`0006Wooooo1?nlio@2ojcWn@Go/Mcf00?o0000ojG:lonUb_<00_nUb_<Fooooo`03o`000?oooooo
oooo04gooooo001Pooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0?
ooooo`?o0000JOooool3okO`m@03okcWm?n/ioWo[>Oi00?o[>Oi0_nag?H2oj7EnP03o`000?nUb_?o
YL[c00?oYL[c5_ooool00ol0003oooooooooo`1<ooooo`00P_ooool2o`0006[ooooo1?ngl?D2oj;^
n0?o[>Oi0_nJgod4oj7EnP04o`000?nUb_?oYL[cojG:l`;oU/7e5_ooool00ol0003oooooooooo`1<
ooooo`00Ooooool3o`0000;ooooo00?o0000ooooooooool0IOooool3ojgel@04okO`mOnRk_SoX^kh
oj;^n0;oS^Ck1OnJgod2oj7EnP03oi;9nol0003oT/Wk00GoU/7e5?ooool3o`0004gooooo001loooo
o`?o0000Joooool4ojgel@;oTNk^00?oX^khohkTnon>i?/00on>i?/2oi[Oo@?oRm7n0_nBbO/00ol0
003oT/Wkoi;9n`04oiK1mAOooooo00?o0000ooooooooool0B_ooool007[ooooo0_l0001/ooooo`?o
W_CX00?o[OGaoi7^k_nAk^h01?mlho02ohkTn`CoP]Ko1?n;dOh2oi;9n`03o`000?n7^_OoRKOd00Co
RKOd5_ooool00ol0003oooooooooo`1:ooooo`00Moooool3o`0006cooooo0onNm>P00omiiM[oI=WL
ofCIg002ofCIg0;oO>?`1?mff?/2oh;Fo`;oPL;l1On4__X01?n7^_Oo0000ohNjmon7^_L5ohVgm1Ko
oooo00?o0000ooooooooool0BOooool007Gooooo0_l00002ooooo`03o`000?oooooooooo06Sooooo
00CoR^gGoegC__mMdkkoBLS01?mEcn<4ofKFlP;oM]Sk0omna?h4oh72o0GoQ;kj00Co0000ohNjmon7
^_OoQk[g0_n9]o@2ohB_lAOooooo00?o0000ooooooooool0B?ooool007;ooooo0ol00005ooooo`03
o`000?oooooooooo06Gooooo00?oR^gGoegC__mMdkh00om3aM42oeG?h`?oN<[o1Omkaol4ogk4oPCo
PL;l0_n4__X2ohB_l@03o`000?n4[o7oQ:oa00KoQ:oa5_ooool00ol0003oooooooooo`18ooooo`00
L?ooool2o`0006kooooo00?oL]k1o`000?mfc_l00_mfc_l5ogO<o`CoN<[o0_mkaol2ohJ^l0CoQJo`
2?n4[o400ol0003oQ:oaohB_l@07ohB_lAKooooo00?o0000ooooooooool0Aoooool003Sooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00023ooooo0ol0001/ooooo`;o0000
0_mbg/42ogK@o`CoM/ko0_mgc?l2ohZ]k@GoQjk^1?n6[_04ohF_l0OoQ:oa00Co0000ohB_lOn4[o7o
Q:oa0_n7Y^T4ohF[kAGooooo0ol00018ooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@07_ooool2o`0000?ooooo00?o0000oooo
ooooool0I?ooool2o`000003o`T00?l0003o000000;oFLbW0_mfd?l2ohn[j@GoS:c[1?n:[Nd5ohN^
kPCoQZk`1?n5[o02ohB_l@;oRYkQ0_n8X^D00ol0003oR:;UohNVj@04ohNVj@CoQJ_]5_ooool00ol0
003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l00000
0ol@413oooooooooo`0Yooooo`00>?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RH
ob4Q8Oo^k^h07?ooool3o`0006Sooooo0_l00002oaH000?o2@0000Co0000oeW<YonAZ^OoTJ[W1On?
ZnT5ohb/j`CoRZg]0_n7[^h2ohjCe0CoSIOH1?n<V]`5ohZNh@04ohRRiOl0003oR:;UohRRi@GoQjKY
1?n5ZndFooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1oooool00ol0003oooooooooo`0Zooooo`00>?ooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h06?ooool3o`0006?ooooo0_lD0003o`T00003o`000?lQ003o8@0000?o
5P0000Go2@00o`000?l0003o0000oi>Xi004oi6Zi`GoSj_Y0_n<[>/2oi6=b`CoT93?1On>Tm@4ohfG
f0CoS9[L1On:W^401?l0003oR:;UohRRiOn8X^D2ohNVj@;oSjGS1On>ZnXFooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000:oooool003Sooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo01Gooooo0ol0001Rooooo`05oal00?lD
003o5000oa@00?l900000_l[0003ob400003oaH00?l>003o3P0000?o00001?nCZ>@4oi6Zi`;oSj_Y
0_nBR/L5oi6=b`CoT93?1?n>Tm@4ohfGf0GoS9[L0_n:W^42oi6Ie`04o`000?n@W]goT9kMoi2Ng@Go
SjGS1On>ZnXEooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002cooooo000hooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`0Aooooo`?o00000oooool00ol0003oooooooooo`1Gooooo`;o<0000olZ0003
oal00003oa@00?ld003o=00000?o:`0000?o8@00oa/00?lK00000ol>0002o`0000?oUJKQ0_nCZ>@0
0onDQL7oThS4oi>8a002oi>8a0GoTX[71?nASL/4oi2@c`GoSY?D1?n=UmP2ohbJg0;oTY?A1?nAVML0
0ol0003oT9kMoi2Ng@02oi2Ng@GoSjGS0_n>ZnX2oiV_iQKooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo0000;?ooool003Sooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41004Oooool2o`0005Wo
oooo00?o:P00oc800?lb00000_lb0003oc000003obX00?m300;o?00000?o?0001?ld00000ol[003o
9P00oa/00003oa/00004o`h00?l0003o0000oiJRg@;oUJKQ0_nEPkh4oiB5`@CoThS41?nBR/L4oi6=
b`GoT93?0_n>Tm@2oiB;a`CoTho<1OnBTm43oi6Ie`03o`000?n@W]goT9kM00?oT9kM0_n?YN<2oiVV
gPGoVJoV5_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0omgMgOoc<c<o`00000/ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c00>ooooo`?o0000F?ooool01?lM003o:P00obX00?lZ0003oc800003oc00
0?m700_oA`0;00?o@`021?ll0003oc@000?o9P000olK0002o`000003oiJRgOnFPK_oUX6k00GoUH>n
0onDQL44oi>8a0CoTX[71OnASL/2oi2@c`;oU8O21OnDRlL4oi>?c0CoTY?A0onAVML01?l0003oTIWG
oi2NgOn@W]d2oiZNe`GoVJKN1OnI[nHDooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l00000;?ooool005Wooooo0ol0001Hooooo`?o7@000_lZ00000olb003o
B00BodP04P04odL02`;o@`021?ll00000old003o;`00obl00003obH00005oa/00?l0003o0000o`00
0?nFOkP01OnFPK/4oiF3_P?oU8G11?nCR<@5oi::a`;oTHg;0_nEQ;h5oiB7`PCoU8_71?nCSl`5oi:C
d@;oTIWG00?o0000oiZGd?nJW]L01?nJW]L5oiVVgP;oVJoV0_nU]N@Cooooo`04o`000?oooooooooo
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02_ooooo001F
ooooo`?o00000oooool00ol0003oooooooooo`1Cooooo`06o`X00?lM003o7@00oad00?lZ003oA00F
1?m80183odL02`?o@`0200?o?000ocL00?lg00001?l_00000olV003o1@00o`000002o`0000CoUWnh
1?nFPK/4oiF3_PCoU8G11?nCR<@2oi::a`;oUX6k1OnEQ;h4oiB7`PCoU8_71OnCSl`2oi:Cd@;oVY79
0_nJUm000ol0003oVYO@oiZGd004oiZNe`CoVJKN00?oYJcLojFei?nU]N@00onU]N@Fooooo`03o`00
0?oooooooooo043ooooo001Dooooo`;o0000F_ooool3o`X00003oad00?ll01GoA00F00;oA00F0om8
0184odL02`03od<00_lm00Wo=`0000?o=`000ol_0002o`D00003o`000?nEO;GoUGbe00GoUWnh1?nF
PK/5oiF3_P?oU8G10_nCR<@2oiIn]`GoUX6k1?nEQ;h4oiB7`PGoU8_70_nCSl`2oiZ<a0GoVY7900Co
VYO@o`000?nJUm3oVYO@1OnJW]L00onIY]koYJcLojF/g002ojF/g0CoYKGT5_ooool00ol0003ooooo
ooooo`10ooooo`00DOooool3o`0005[ooooo00Co0000o`X00?l:003o2P000oll01D2od@05PCoB00B
00?oA`0;od804Om201400olm00T3ocL00004obl00?lB003o4P00o`D000;oTgVb1?nEO;D4oiIo^0Go
UX6k1?nEPkh2oiB5`@03oiIm]OnFO[OoUWjg00?oUWjg1?nFPK/4oiF4_PGoU8O20_nDRlL2oiZ8_`Go
VXc41?nJTLT00onJUm3o0000oiZGd002oiZGd0;oVYkG0_nTY=D5ojF/g0;oYKGT0on`_>8Fooooo`03
o`000?oooooooooo03oooooo001>ooooo`Go0000F_ooool2o`000003o`X00?la013o?00E00;o?00E
0om401H00om801;o@`0Fod<05P04od804@;o?@090_lg00001?lL003o4P00oa800?lB0005oi=i/P?o
UGbe1OnFOkP4oiJ1^`;oUH>n0_nGNk84oiIm]@CoUWjg1?nFPK/5oiF4_P?oU8O200?oVXBkoiZ8_onJ
R;l00onJR;l4oiZ<a0CoVY7900GoVYO@o`000?nJUm3oVYO@oj>Mc`05ojBTe@?oYJcL00?o[kGMok2l
h_n`_>801?n`_>8Fooooo`03o`000?oooooooooo03kooooo001<ooooo`;o00001Oooool00ol0003o
ooooooooo`1Eooooo`?o00000ola0102oc`05@;oA00F00?o@P0Hod<05_m301H00_m301H3od804@?o
?@090olL00001?lB003oTWJ`oi9f/?nBM[04oi=i/P?oUGbe1OnFOkP2oiJ1^`;oUgV`1?nGNk84oiIm
]@CoUWjg1OnFPK/4oiF4_P03oiB7`_nJQ;_oVXBk00;oVXBk1?nJR;l4oiZ<a0GoVY7900?o0000oj>M
conSWLl00_nSWLl5ojBTe@04ojF/g?n_]Mgo[kGMojneg@Co/;cR00?o^<?Rooooooooool05?ooool0
0ol0003oooooooooo`0nooooo`00BOooool3o`0005kooooo0_l000001?lS00Ko<@0@oc404?la0103
oc`05@?o@P0H0om301H3od804@03ocd02OlT003o900000?o700000?oT7:^oi9f/?nBM[000_nBM[04
oi=i/PCoUGbe0onFOkP00onGN:koUgV`oiMi/002oiMi/0GoUg^b1?nFOKD4oiIn]`CoUX6k0_nEQ;h2
oiZ1]`GoVXBk1?nJR;l5oiZ<a0;oVY790_nSV<T00onSWLoo0000oj>Mc`02oj>Mc`CoY:CE00?o[jkG
ojnegOn_]Md00on_]Md00on`_>;o^<?RokS3hP02okS3hQCooooo0ol0000oooooo`008_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^023ooooo0_l0001Pooooo`;o00000_lS00H3oc404003oc`05Olm01Oo
@P0H00;o@P0H1?m301H00om2017o:P00ob@00003ob@00004oa`00?n@LZkoT7:^oi1b[PCoTWJ`1OnC
NK83oiEl]@04oiIo^?nGN:koUgR^oiMh[PGoUgV`1?nGNk84oiIm]@CoUWjg0_nFPK/2oiYn]0GoVX6g
1?nJQ;/5oiZ8_`?oVXc400?oXi?4oj>HbOnSV<T00onSV<T00ol0003oXig?oj>Mc`02oj>Mc`03ojBT
eOn_[]Oo[jkG00;o[jkG0on_]Md00onh_moo^<?RokS3hP04okS3hQGooooo00?o0000ooooooooool0
?Oooool002;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`?o00000_ooool00ol0003ooooo
ooooo`1Kooooo`?o00000_lS00H4oc4040;o?@0G0om201P4od<05P;o:P000olT00000on@LJcoT7:^
oi1b[P02oi1b[PCoTWJ`1OnCNK82oiEl]@03oiMf[?nGN:koUgR^00?oUgR^1?nGNK04oiMk/PCoUWfe
0onFO[L00onIO;7oVWjdoiYn]002oiYn]0GoVX6g1OnJQ;/4oiZ8_`03oiZ<a?nSTlCoXi?400;oXi?4
1?nSV<T01Ol0003oXig?oj>MconSWLoo[ZWC00Go[jkG00?o[kGMokRogonh_ml00_nh_ml4okS3hP;o
_L[T5Oooool00ol0003oooooooooo`0looooo`008_ooool01Ol@413ooooooooooooooooo410@01_o
oooo0_l0001Qooooo`Co00000olS00H2oc404003ocH04?lm01Oo?@0G00Co@P0H00?o@`0Fobd00?l]
00000_lZ0002ob@000?oT76/1?n@LZh5oi9f/0?oTgVb00CoUWB[oiMf[?nGMZcoUgJ/1OnGN:h4oiMi
/0GoUg^b1?nFOKD00onFO[OoVGbaoiUl/@05oiYn]0CoVX6g1OnJQ;/2oiZ8_`;oXXo01OnSTl@4oj>H
b@03o`000?nSWLoo[ZWC00;o[ZWC1?n_[]L00onh_=go^;oOokRog`04okRog`03okS3h_nmb^Co_L[T
00?o_L[T5Oooool00ol0003oooooooooo`0kooooo`008_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0ol0001Pooooo`03obP00?l0003o000000?o000000Co6P00ob<01_lS00Ko8`060olf0102
ocd05`;o@P0H1Ol]0002obX000GoT76/1On@LZh4oi9f/004oi=i/_nFM:_oUWB[oiIdZ`CoUgJ/1?nG
N:h4oiMi/0GoUg^b0_nFOKD2oiUj[`CoVGba1?nJO[@5oiZ1]`?oVXBk00?oXX^loj:?`?nRSl000onR
Sl04oj>Ca0CoXiS900?o0000ojjYdon^ZM<00on^ZM<2ojn^e`?o^;cM1?nh_ml00onncNGo_L[Tokg:
i003okg:i003okc>j?oooooooooo01?ooooo00?o0000ooooooooool0>oooool002;ooooo00Go0000
ooooooooooooooooo`00000Fooooo`?o0000FOooool2o`0000;o7@0000?o4@00od<03om300l00olX
00001Ol3003o0000o`000?l0003o6P0000;o8`0600Co;005ocH04?lf013o=P0@0olm01L6obd00003
obX00?n@LJcoT76/00KoT76/1?n@LZh2oi9f/0;oUG:Y1OnFM:/3oiMf[0CoUgR^1OnGNK03oiMk/P03
oiUi[OnINZooVGZ_00;oVGZ_1?nIO;44oiYn]0GoVX6g00?oVXBkoj:;_?nRRk`00_nRRk`4oj:?`0Go
Xi?400GoXiS9ojjUc_n^YLko0000ojjUcP04ojjYd`03ojn^eonh_=go^;cM00?o^;cM00?o^;oOokk=
iOnncND00_nncND3okg:i0?o_<kX5Oooool00ol0003oooooooooo`0jooooo`008_ooool01Ol@413o
oooooooooooooooo410@01?ooooo0ol00002ooooo`03o`000?oooooooooo05Gooooo0ol000000olM
003oCP0Jod<03`03od<03`;o:0000_l300001Ol0003o5000oaX00?lJ003o8`0600;o;0050_lf0102
ocd05`03obP00?l]003o;@0000Co;@000_nBLjd8oi1a[0;oT7:^0_nCKjL4oiEbZ@GoUWB[0onGMZ`5
oiMh[PCoUgV`00CoUg^boiUi[OnINJgoVGV]1OnINZl3oiUl/@GoVWjd0onJPKL00onQR;WoXX^loj:;
_003oj:;_0CoXXo01?nSTl@01_n]XL_o[ZG>ojjUc_n^YLko0000ojjUcP?o[ZWC00?o^;[KokRlgOnh
_=d00onh_=d00onod>Oo_/gUokk=i@04okk=i@03okg:i?nlc^So_<kX00;o_<kX5_ooool00ol0003o
ooooooooo`0iooooo`008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg013ooooo0ol0001Looooo`03
o`000?m801OoB00G00?oCP0J0om300l01?lX003o8000o`<00?l30003oa@000;o6P000_l/00D3ocH0
40?o:0000ol]0002oiAg/0CoTW>]1_n@LJ`00onAKJGoTfnWoi=_Y`02oi=_Y`GoUG:Y1?nFM:/3oiMf
[0GoUgR^0_nGNK02oiUh[0GoVGV]1?nINZl3oiUl/@GoVWjd00?oVX6goj68^OnQR;T00_nQR;T4oj:;
_0GoXXo000?oXi?4ojfQbon]XL/00_n]XL/2ojjUcP04o`000?n^YLko[ZG>ojjYd`?o^;[K0onh_=d3
oko@i`Co_/gU0_nme^`3okc>j0;o]]3]5?ooool2o`0003_ooooo000Rooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03_ooool2o`0005gooooo00?o?@0<odP05om801L00_m801L2odh06P?o@`0?0olP0000
1_lK003o5000oa@00?lD003o6P00ob@000;o;0050_lf01001OlO003o:000obP00?lX003o;@0000;o
UG^d1?nDMk03oi9c[@;oT76/0_n?JZ@3oi5]Y@GoTfnW1?nELZT4oiIdZ`CoUgJ/0onGN:h00onJMj_o
VGR/oiUh[002oiUh[0GoVGV]1?nINZl4oiUl/@?oVWjd00?oXHFfoj68^OnQR;T00onQR;T5oj:;_0?o
XXo000?o[Ik8ojfQbon]XL/00on]XL/2ojjUcP03o`000?n^YLko^KSI00Go^;[K00?o^;cMoko@iono
d>L00onod>L00onncNGo_MK/okgFk003okgFk003okc>j?nfd>go]]3]00;o]]3]5Oooool00ol0003o
ooooooooo`0hooooo`00<_ooool5o`0005_ooooo0olm00`3odP05`?oCP0J00?o@`0?oc400?lP0000
0_lP0002oa/000;o50000olT0002ob`01@?o7`000olX0003oiEk]0CoU7N`0_nBLjd00on=J:CoSfZT
ohmZY002ohmZY0CoTFfU1?nCKjL4oiEbZ@CoUWB[1?nGMZ`01?nGN:koVWN[oiYgZonJMj/5oiUh[0Co
VGV]1OnINZl3oiUl/@03oiYn]?nQQKKoXHFf00;oXHFf1?nQR;T5oj:;_003oj:?`?n]W/So[Ik800;o
[Ik81On]XL/2o`0000?o^KSI0onh^]/2ol3Dj@Co_m3W0_nmg_04okgFk003okKKlonfd>go]]3]00;o
]]3]00?oZlcaooooooooool05?ooool00ol0003oooooooooo`0gooooo`00<?ooool2o`0005kooooo
00Co>`00ocd03?lm00co?@0<0om801L00om>01[o>`00oc/00003oc4000;o80000_lK00000olD003o
7@00ob@00002ob@00003ob`01OlA003o7`0000;o7`000_lX00000on6IJGoRFJUohUVY@02ohUVY@Co
RfNT0on=J:@4ohmZY0CoTFfU1?nCKjL4oiEbZ@GoUWB[0_nGMZ`00onJMZ[oVWN[oiYgZ`03oiYgZ`Co
VGR/1?nINJd5oiUj[`;oVGba00?oX8>doj65]_nQQKH00onQQKH5oj68^@?oXX^l00?o[I_5ojfNb?n]
W/P00on]W/P2ojfQb`?o000000?o^KSIo`000?ni^=T00_ni^=T00onh^]_o`=CYol3Dj@03ol3Dj@03
oko@ionmg_3o_Mk`00?o_Mk`00?o_MK/okKKlonffo<00_nffo<00onfd>goZlcaoj_<l@02oj_<lAGo
oooo00?o0000ooooooooool0=oooool002gooooo0ol0001Oooooo`;o>`000_lm00`2odP05`03ocH0
0?lk003o>`0000;o>`000_la00000olP003o:@00oa/00002oa/000;o7@000olT0002oa4000?o7`00
0on6IJD4ohUVY@CoRfNT0on=J:@5ohmZY0?oTFfU1?nCKjL4oiEbZ@GoUWB[00?oUgJ/oiYfZ_nJMZX0
1OnJMj/4oiUh[0GoVGV]0onINZl00onPP[;oX8>doj23]002oj23]0CoXHFf1OnQR;T00onRRkco[I_5
ojfKa@02ojfKa@?o[Ik80ol00004okVhf003okVhfOl0003o^KSI00;o`M[[1?o0e>T2okcWm0Co_Mk`
0_naioP2okKKl`?oZ=Oh1On[c?4Eooooo`03o`000?oooooooooo03Kooooo000/ooooo`;o0000G_oo
ool4oc/000?o?@0<0olf0003oc/000?o<@000_lY00001?lK003o7P00oad00?lM0002ob@00004o`00
0?lA003o4@00oal000?oPf>U0on6IJD4ohUVY@CoRfNT1?n=J:@4ohmZY0?oTFfU1?nCKjL5oiEbZ@?o
UWB[00?oVWJYoiYfZ_nJMZX00_nJMZX4oiYgZ`CoVGR/1OnINJd01?nINZooX8:boj22/_nPP[84oj23
]0GoXHFf0onQR;T00on]V/?o[I_5ojfKa@03ojfKa@?o000000?o[Ik8okZhf?ni^=P01Oni^=P00oni
^=Wo0000ol7Jj`02ol7Jj`03ol3DjOnlioCo_>Od00?o_>Od00Co_Mk`ok7Wn?naioSo/NOh0_nQh?`5
ojSGn0;oZlca0onOa?8Eooooo`03o`000?oooooooooo03Gooooo000/ooooo`?o0000F_ooool00om6
003o>`00oc/00004oc/00003ocd03?l_003o=P0000;o=P000olk00000ola003o<000oc000002obT0
00?o7P000_lM0002o`000004oa400?n0HJGoP66Uoh1QY@CoPf>U0on6IJD4ohUVY@?oRfNT1?n=J:@4
ohmZY0?oTFfU1OnCKjL4oiEbZ@04oiIdZonJMZWoVWJYoiYfZ@CoVWJZ1?nJMj/5oiUh[0?oVGV]00?o
Wh2aoj22/_nPP[800onPP[84oj23]0CoXHFf00?oXHRiojfJ`on]V/<00_n]V/<01?n]VlGo0000o`00
0?l00003ojfNb0?o^[SH1?ni^=P01Oo2hNoo`M[[ol7Jjol0003o`M[[00?o]_3e0_nlio@3ojG_m`03
ok7Wn?nQh?coXN3l00?oXN3l0_nXeoP3oi_;n0GoWlCb5?ooool00ol0003oooooooooo`0eooooo`00
;?ooool01?l0003oooooo`000?l0001Hooooo`;oAP001?lk00001?lh003o;`00obl00?l_0003ocH0
0003oc/00?ld003o<00000;o<00000?o:@00obD00?lN00000_lN00001?lM003o0000o`000?l00002
oh=RY0?oP66U1?n3HjD3ohIUY@CoRFJU0on;Ij@4oheXY0CoSfZT1?nAKJD4oi=_Y`;oUG:Y0_nIM:P5
oiYfZ@?oVWJZ1?nJMj/5oiUh[004oiUi[OnOP;7oWh2aoin0/@GoX8:b1?nPPk@3oj65]P04ojbH`_n]
V/?o[I[3ojfJ``?o00001?n]VlD00on]W/So^[SHokZhf002okZhf0?o^KSH0oo2hNl00oo1f^_o0000
okK`m@02okK`m@?oRngY0_nUkoL3oi3Un`;oXN3l0onEd?`5oi_;n0;oWlCb0_nG^o4Cooooo`03o`00
0?oooooo000000Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko
<S8bo`000?l@413oc<c<01Wooooo000/ooooo`;o00000_ooool00ol0003oooooooooo`1?ooooo`04
obH00?m9003oB@00odT000?oAP000olk0003ocP000;o;`0000?o=P00obd00?l]00000old0002oc00
00?o9@000_lN0002o`000003ohUVY?n3HZCoPf:T00;oPf:T0on0HJD4oh=SY@?oQVFU1?n9IZD4oh]W
Y0?oSFRT1?n?JZ@4oi5]Y@?oTfnW00?oV7:VoiUdZ?nIM:P00_nIM:P5oiYfZ@?oVWJZ1OnJMj/3oiUh
[003oimo/?nOP;7oWh2a00?oWh2a1?nPP[85oj23]003oj65]_n/V<;o[9S200?o00000_n]V/<4ojfK
a@03okZif?nj^=So^[SH00Co^[SH00Co^KSHol;Qkoo2hNoo`^7_0onXmO001?l0003oRngYoh_]jOn;
kNT3ogCPkP;oT>Gk0on<e?l5oiG@o0;oVl_h0_nD_?<5oiNklAGooooo00?o0000ooooooooool01Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B406Oooool002_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`03oe40
0?mW017oI`0A00;oI`0A0om]01L3of`05`04odT00?m6003oG00=oe`03@?oAP000olh00000ol_003o
9`00obd00002obd000?o=00000?o<000obP00?lU00000_lU00000olN003o0000oi=]Y003ohUVY0Co
Pf:T0on0HJD4oh=SY@?oQVFU1?n9IZD4oh]WY0?oSFRT1On?JZ@3oi5]Y@04oi=_YonHLZKoV7:VoiQb
YPGoVGBX1?nJMZT3oiYfZPGoVWN[00CoVGR/oimo/?nOOk3oWgn`1OnOP;44oj22/PCoX8>d00Go[9O2
ojbH`_l0003o0000ojbH`P05ojfJ``03ojfKaOnj^MSo^[WH00;o^[WH1?nj^=P3ol3Yl@08ol;QkonX
mO3oZ?G`ojSel?mQelKoC/cAo`000?m>c=42ogCPkPCoO]Co1?n<e?l2oiG@o0;oT[gd1OnD_?<4oiNk
lAGooooo00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000Iooooo`00:oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo047ooooo00Co<`00oe400?mA003oD@001?mW0143ofd05`?oK00G1?mL00d3odH000;o>0000olW
0002obd00003oc@00?lX003o:00000?o:0000_lU0002o`0000?oTffT0on9IZ@4oh=RY0?oP66U0on3
HjD3ohIUY@CoRFJU1?n;Ij@4oheXY0CoSfZT0_nAKJD00onEKjGoV7:VoiQbYP03oiQbYPCoVGBX1?nJ
MZT4oiYfZP?oVWN[1_nOOk04oin0/@GoX8:b0_nPPk@3o`0000?o[9S21?n]V/<00onk^mWo^[WHokZi
f004okZif003okZhf?o0jO7o`>Wa00;o`>Wa0_n>k]h00onXmO3o0000of?=nP02of?=nP04o`000?ma
d_goLM;mog7Bo@;oO]Co0on<^O@3ohnlm@GoT[gd0_nD_?<2oiB`jPGoUKC]5Oooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q
01Wooooo000[ooooo`?o00001Oooool00ol0003oooooooooo`0mooooo`03o`l00?lc003o<`0000?o
D@001?mW0143ofd05`CoK00G0omL00d3odH00003ocP00?l_003o9`0000;o9`0000?o;@00ob400?lX
00001OlX00001?lU003o0000oiedY?nMM:@4oi=]Y0?oRFJT1?n3HZ@3oh1QY@CoPf>U0on6IJD4ohUV
Y@?oRfNT1?n=J:@4ohmZY003oi5]YOnEKjGoUFnU00GoV7:V1?nIM:P4oiYfZ@CoVWJZ00?oVWN[oimo
/?nOOk001_nOOk04oin0/@CoX8:b0ol00003ojbG`PCo[9S200?o[I[3ok^kfOnk^mT00_nk^mT4okZi
f0?o^o;c00?o`>Waohk^g_n>k]h00omLb?T2of?=nP;oRjo]00?oRkGbo`000?n;]O800_n;]O85ohbi
m0?oSkce0_nB_O@2oiB[iPGoU;3Z1OnE]>dEooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`06Oooool002_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0jooooo`;o3`000_lc0004oe4000?oI`0A0om]01L4
of`05`?oG00=00?oAP00och00?ln00000ol_0002obL000;o8@001?lX0002o`000003oj9gY?nMM:Co
WGBT00;oWGBT1?nCKJ@3ohUVY0CoPf:T0on0HJD4oh=SY@?oQVFU1?n9IZD3oh]WY0CoSFRT0_n?JZ@2
oi5[X`CoUFnU1?nHLZH4oiUdZ0GoVWJY0_nJMZX00onOOjooWgn`oimo/007oimo/0GoWh2a0ol00000
0on[Ul7o[9O2ojbG`P03ojbG`PCo[9S21_nk^mT00onj^MSo^o;cok_bl`02ok_bl`03of?E^?n?W]ko
SikN00GoSJOW1?n;[nd00on;]O;o0000oh^elP02oh^elP;oS;Wd0_nDWm/3oiBUh@GoU:_V1OnD/>X2
oiFdk@;oVK?Y5Oooool00ol0003oooooooooo`03ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool00omEEEGoQhN7ooooo`0Kooooo`00:oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo03Oooooo00Go0000o`l00?l?003o<`00oeP08004of<0:0?oJ`D/0omZ0bT4of@08@?oE00B1?ln
0002obl00005obL00?lI003o8@00ob400?lX00000_l90002o`0000?oXWNT1?nMM:@2oi=]Y0;oSEfE
0on7FI@4ohAHU@?oPeNF0on3FIP01?n3HjGoQVFUohIUYOn6IJD4ohUVY@;oRfNT00?oRF:NoheVXOn=
IZ400_n=IZ44oi5[X`CoUFnU1?nHLZH4oiUdZ0GoVWJY00CoVWJZoimo[onOOjooWgn_2?nOOk02oin0
/@?o000000?oX8:boj^G`On[Ul400_n[Ul45ojbG`P;o[9S20_nl_]`4ok^kf@?o[_O^00?o^o;coi:F
e?nBU]@01?n?W]h5ohfWi`CoRjo]00CoRkGbo`000?nEV=CoUISD1?nDWm/4oiBUh@GoU:_V0_nD/>X2
oiZ]i0GoVK?Y4oooool3o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@
413oV9RH01_ooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l0
00000ol@413oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=Ooo
ool2o`000004odX05?mH023oF00PoeP080CoH`0X0om[1B`3ofX3:@CoI00Q0omD0183och00003obl0
0?lL003o6@0000;o6@0000Ko2`00o`T00?l9003o2@00o`000?nSNJ@5oj9gY0?oWGBT1?n=GID3ohMI
U0CoQ5RE0on3EiH4oh=IV0?oQE^J1?n6GY`3ohURWPCoSFJQ1OnAJj<3oiE_Y@CoV7:V1OnIM:P3oiYf
Z@03oj1o[onOOjooWgn_00;oWgn_1onOOk03o`0000;oWh2a00?oZiO2oj^G`On[Ul400on[Ul45ojbG
`P03ojbH`_nl_]co_;kL00;o_;kL00?o^k_Iojkgk_n^mnh00_n^mnh00onDS/[oTYKDoi:Fe002oi:F
e0CoSikN0_n=YnL2oiN;a@CoUY7<00?oUISDo`000?nEV=@00_nEV=@4oiBOf`CoU:GQ0_nDZnH2oiZV
gPGoVZgT1OnI/nTEooooo`09o`000?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
00Coc<c<odA4A?l0003o410@6Oooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1oooool00ol0003oooooooooo`04ooooo`?o00002_ooool00ol0003oooooooooo`0booooo`?o
00000_m:01@2oeP080CoH`0X0om[1B`3ofX3:@CoI00Q0omD0183och000;o70000olI0002o`/00003
o`T00?nSNJCoXgVT00;oXgVT1OnRMj@2oiedY003oi9RU_n=GIGoSEfE00;oSEfE0on7FI@4ohAHU@?o
PeNF1?n3FIP3ohEKVPCoQUjL0on9HYh4oheVX@GoTF^S0onEKjD5oiQbYPCoVGBX00CoVWJYoj1o[onP
OjooX7n_1?nOOjl4oimo/0?o00000_nOOk000onOP;7oZiO2oj^G`P02oj^G`PCoZiO11?n/Ul800onl
`moo_;kLokbng002okbng0?oU?7K00Co[_O^oiB>b_nDS/[oU8k:1?nBU]@2ohnNgP;oV8Fm1OnGRlD4
oiJAc003oiFHe?l0003oUISD00;oUISD0onDWm/2oiBUh@;oVj3G1OnJY]h5oiZ]i0;oVK?Y0_nQ]NLE
ooooo`03o`000?oooooooooo02oooooo0008ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol00005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0;oooool2
o`0000;o>`050_m:01@2oeP080CoH`0X0om[1B`4ofX3:@?oI00Q1?mD01801_ln003o9`00oa`00?lL
003o6@00o`H000?o2`000_nRN:@5oj=iY0CoXWNT00?oWGBToi9RU_nBHYH01?n=GID3ohMIU0CoQ5RE
0on3EiH4oh=IV0?oQE^J1?n6GY`4ohURWPCoSFJQ1?nAJj<3oiE_Y@GoV7:V0onIM:P6oj1o[`CoWgn_
00?oWgn`o`000?l000001?nOOk06oj^G`PGoZiO100?o[9O2okc3gonl`ml00_nl`ml01?nl_]coU?7K
oiCafonDlM/2oiJ7`@GoU8k:0_nBU]@00onIP;OoV8FmoiR5_@03oiR5_@CoUh_51OnFTL`01?nEV=Co
0000oifDb_nMU<X3oibJd@GoVj3G1OnJY]h2oiZ]i0;oXZkP1OnQ]NLEooooo`03o`000?oooooooooo
02kooooo000@ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00006
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0;?ooool00ol0003o;P00oc/01@03
oc/01@04odX05?mH023oF00PoeP080CoH`0X0om[1B`4ofX3:@03of@08Om?00ko?@0000?o?@000olW
00001?l0003o1P00o`H00?l;0002oimfY0CoXWRT1?nSNJ@3oj9gY004oiIUUonBHYKoTV:Foi9RUPCo
SEfE1?n7FI@3ohAHU@CoPeNF0on3FIP4ohEKVPCoQUjL0on9HYh4oheVX@CoTF^S1?nEKjD4oiQbYP03
oiUdZ?nPOjooX7n_00KoX7n_0_nOOjl3o`0000CoWgn`2?n[Ul84oj^G`@;o_<SS0onl`ml2ofWH]P03
oiN1^OnFQl7oUXO100?oUXO10_nDS/X2oiYl/@CoVH2g1?nHQKd4oiN;a@CoUY7<00?oWXo3oifDb_l0
00000_nMU<X4oibJd@GoVj3G0_nJY]h2oj:WfPGoXZkP0_nQ]NL3ojZkiQGooooo00?o0000oooooooo
ool0;Oooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`00
00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Zooooo`03o`000?l^003o;P00
00?o>`050_m:01@00omH023oFP0Uoeh09P03oeh09P?oG`0T1?mI01`3odl03P?o?@000olW00000ol0
003o1P00oiedY004oimfY0CoXWRT1?nSNJ@01?nRMjCoUVFGoiIUUonFIIL3oi9RUPCoSEfE1?n7FI@3
ohAHU@CoPeNF0on3FIP4ohEKVPCoQUjL0on9HYh4oheVX@CoTF^S1?nEKjD3oiQbYPWoX7n_0ol00002
oimo[`?oWgn`00?oZiW4oj^G`_n[Ul802?n[Ul800on[Ul7o_<SSokc8h`03okc8h`03okc3gomYf;Ko
Uh6i00?oUh6i0onFQl400onKNJgoVWbaoiYl/@03oiYl/@?oVH2g1?nHQKd5oiN;a@03oiJAc?nNSl?o
WXo300;oWXo300CoWIC:o`000?nMU<[oWIC:1?nLV]42oi^Pe`;oXj7C1OnRYmX3oj:^h003oj^fhOnZ
^nKoZ[_V00CoZ[_V5?ooool00ol0003oooooooooo`0]ooooo`004?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oMgMgolc<c?l000001_ooool2o`0000oooooo0_l0000Xooooo`04o`000?lR
003o;P00obh000?o>`0500?oBP0Doe@07omJ02D00_mJ02D4oeh09P?oG`0T1?mI01`2odl03P?o?@00
00Co9`00o`000?nJNJcoW7b_0onMM:@4oimfY0CoXWRT0onSNJ@00onIJIWoUVFGoiIUU`02oiIUU`?o
TV:F1?n=GID4ohMIU0?oQ5RE1?n3EiH3oh=IV0CoQE^J1?n6GY`3ohURWPCoSFJQ1OnAJj<3oiE_Y@03
oiQbY_nPOjooX7n_00KoX7n_0ol000000onPOjooWgn_oimo[`03oimo[`04oimo/?n[VLCoZiW4oj^I
a0SoZiO20_nlcnT4okc8h`04o`000?nHOK?oV7fcoiQm/`?oUh6i00CoUXO1oi]i[OnKNJgoVgV]1OnJ
O;43oiV0]`GoV8Fm0_nGRlD2oj2;_PGoWXo30_nMU<X01?l0003oWIC:oibJdOnLV]42ojBLc@GoXj7C
1OnRYmX01?nR[^3oZkKQoj^fhOn[]^44ojZkiP03ok32iooooooooooo01?ooooo00?o0000oooooooo
ool0;?ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Ko
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Tooooo`?o8P0000Co;P00oc/01Olk
00GoC@0G0omD01l2oeX09@CoGP0V0omO02@4oeT070;oC`0>00Co?@00o`@00?l0003oVgR[0_nJNJ`0
0onKLZCoWGBToiedY002oiedY0CoWgJT1?nRN:@2oj=iY0;oVFVI1?nFIIL3oi9RUPCoSEfE1?n7FI@3
ohAHU@CoPeNF0on3FIP4ohEKVPCoQUjL0on9HYh4oheVX@GoTF^S0_nEKjD00onOOJkoX7n_oj1o[`04
oj1o[`?o00001OnPOjl3oimo[`03ojbKa_n[VLCoZiW400;oZiW41_n[Ul85okc?j@03okc8honINJko
V7fc00CoV7fc0_nGPKT00onLMjWoVgV]oi]i[@03oi]i[@CoVWba1?nIP;L3oiR5_@03oj68^OnPRkko
X8^n00?oX8^n1?nNSl<3oifDbP03o`000?nTW<goY9c=00?oY9c=1OnSXM<2oj:WfP;oZk7L1On[]^40
0onZ^nKo/<;Wok32i`02ok32ia?ooooo0_l0000^ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00gooooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo027ooooo00Co6P00ob800?lR003o8P000_l^0003odd05`;oE00O0omJ02D3oeh09P?oG`0T1?mI
01`01?m?00ko5000o`@00?l40003oi]hZ`03oiYi[?nKLZCoVg:T00CoWGBT1?nOMZ@4oj9hY004oj=i
Y?nIJIWoVFVIoiUYV@CoUVFG0onBHYH4oheMU@CoQeVD1?n4F9D3oh=GUPCoPeVH0on5FiX4ohINW0?o
RF:N1On=IZ44oi5[X`03oiE_YOnOOJkoWgf^00?oX7n_0ol00008oj1o[`03oimo[on/VlKo[9_600;o
[9_60on[VL@4oj^G`P;o^]O^1?nlcnT4oiUi[P?oV7fc00CoW7JVoiagZOnLMjWoW7NY1OnKNJd5oiYl
/@?oVH2g00?oV8Fmoj68^OnQR;T00_nQR;T4oj2;_PGoWXo300CoWIC:ojJHb?l0003oYYS81?nTW<d4
oj>Qd`03ojf^f?n[/McoZk7L00?oZk7L0on[]^42ok71i@Co/<;W5Oooool00ol0003oooooooooo`0[
ooooo`00:Oooool2o`0001Cooooo00?o0000ooooooooool07_ooool00ol0003o6P00oaX00002ob80
0003obh00?m500goC@0G00;oC@0G0_mD01l3oeX09@CoGP0V00?oG`0Toc@00?lU00000_lU0003oa@0
0003o`@00?nLNJ_oVgR[00;oVgR[00?oVW:Toi]bY?nKLZ@00_nKLZ@4oiedY0CoWgJT0onRN:@4oiUY
V@CoUVFG0onBHYH5oheMU@?oQeVD1?n4F9D3oh=GUPCoPeVH0on5FiX4ohINW0?oRF:N1On=IZ43oi5[
X`04oiaj[?nOOJkoWgf^oimm[P?o00002_nPOjl00on^WlSo[9_6ojbKaP03ojbKaPCoZiW400?oZiO2
ok[Gk_njenh00onjenh00onlcnWoVWJZoiUi[P04oiUi[P04oiQm/onLMZKoW7JVoiafYPCoW7NY1?nK
NJd5oiYl/@;oVH2g00?oXhFdoj68^OnQR;T00onQR;T4oj2;_PCoWXo300GoZ9K3ojJHb?nVV<SoYYS8
o`000005ojBLc@03oj>Qdon][]So[JkH00;o[JkH1?n[/M`00on[]^7o/L7Uok71i@03ok71i@;o/<;W
0_nba^TEooooo`03o`000?oooooooooo02[ooooo000Yooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool06oooool01_l0003o4P00oaX00?lJ003o8P00och00P?oA@0=0_m=01L3oe@07`?o
FP0U00?oGP0Vocd00?lm00000old0002obD00003oa@00?nMNjgoWG^]00?oW7V[00CoVgR[oiYbY?nJ
LZCoVW:T1?nKLZ@4oiedY0CoWgJT0_nRN:@00onJJi_oVFVIoiUYV@02oiUYV@CoUVFG1?nBHYH4oheM
U@?oQeVD1?n4F9D3oh=GUPCoPeVH0on5FiX4ohINW0CoRF:N1?n=IZ401OnAJj?oW7Z/oiaj[?nLNZco
Wgf^00;o000000?oWgf^oj1o[onPOjl02?nPOjl4ojjOb0Co[9_60on[VL@2okOPm0Co^]O^0onJMZX4
oiUi[P03oiedY?nLMZKoW7JV00?oW7JV0onLMjT4oi]i[@CoVWba00?oY8Baoj>5]?nSQK@00_nSQK@4
oj68^@GoX8^n00CoWXo3ojRF`onXU/?oZ9K31?nVV<P01Ol0003oY9c=ojBLcOnTW<go[jcE00Go[JkH
0_n[/M`3ok?1i@Co/L7U00?o/l[[ok;6jOnba^T00onba^TDooooo`03o`000?oooooooooo02[ooooo
000Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06Oooool2oa8000;o6P000oln
0082odD03@?oC@0G00?oE00OodD01Om200800_m20083ocd000?o=00000?o9@00oiim[onMNjd00onM
Njd2oiaiZ`03oiQbYOnJLZCoVW:T00;oVW:T1?nKLZ@4oiedY0CoWgJT00?oXWRToiY[VonJJi/01?nI
JIT4oiIUU`CoTV:F1?n=GID3ohMIU0CoQ5RE0on3EiH4oh=IV0CoQE^J1?n6GY`3ohURWP?oSFJQ00?o
V7JZoiaj[?nLNZ`00ol00003oimm[PSoX7n_00?o/JG=ojjOb?n^WlP00on^WlP5ojbKaP03oj^Ia?ng
h?Co]n3d00;o]n3d00?o^]O^oiYdYonJM:L01?nJMZX2oiUi[P;oWGBT1OnLMZH3oiagZ@GoVgV]0_nJ
O;42ojB4/@CoXhFd1OnQR;T3oj2;_P03ojVD`?nXU/?oZ9K300?oZ9K31?nVV<P00ol0003o[jcEojn/
e@02ojn/e@?o[JkH00?o]L?Uok?1iOnc`ND01?nc`ND00ona`NGo/l[[ok?:j`02ok?:j`?o//KY0_n`
bN`Dooooo`03o`000?oooooooooo02Wooooo000Yooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool05_ooool01Ol:003o4P00oa800?lJ003o=`0000?o?P020_m500d00om=01OoA003od@0
0`03odD01@?o@P020_lm00000old003oWh2aoiim[`03oiim[`?oWG^]00CoUg:WoiQbYOnHLZGoV7:U
1?nJLZ@4oi]bY0CoWGBT0onOMZ@01?nJK9coVV^KoiY[VonJJi/4oiUYV@CoUVFG1?nBHYH4oheMU@?o
QeVD1?n4F9D3oh=GUPCoPeVH1?n5FiX4ohINW0?oRF:N00?oSFJQoiQfZ_nHMZX00ol00003oiaj[0?o
Wgf^1_nPOjl4ok6Uc@Co[Yo81?n/VlH2ok3Yn0;o]n3d00?oVW:ToiYdYonJM:L00_nJM:L4oiYfZP03
oiUi[_nMM:CoWGBT00;oWGBT1?nLMZH3oiagZ@GoVgV]00?oVWbaojB4/OnTQ;400_nTQ;43oj>5]0Go
XHRi00?oX8^nojVD`?nYU<000_nYU<04ojRF``?oYYS800?o/JcCo`000?n_[=D01?n_[=D01?n][]So
]L?UokG3iOne`nD4ok?1i@;o]<o]1?ncb^/00onba^Wo/<W/ok39k003ok39k1Cooooo00?o0000oooo
ooooool0:?ooool002Wooooo0ol0000Gooooo`03o`000?oooooooooo01;ooooo00Go0000o`X00?l:
003o4P00oc400003ocL000;o?P0200?oA@0=od800?m400<00om400<2odD01@?o@P0200?o?@00oin2
]?nOP;400onOP;43oiim[`04oiek[OnGLZOoUg:WoiMbY`CoV7:U0onJLZ@4oi]bY0CoWGBT0_nOMZ@2
oiY/W0CoVV^K0onIJIT5oiIUU`?oTV:F1?n=GID4ohMIU0?oQ5RE1?n3EiH3oh=IV0CoQE^J1?n6GY`2
ohURWP04oiA`Yol0003o0000o`0000;oV7JZ1?nLNZ`4oimm[P?oX7n_00?o]JkBok6UcOnaYLd00ona
YLd5ojjOb005ojbKa_n`jOSo/>Whok3Yn?nJLJ800onJLZ@5oiYdY`;oVWJZ00?oWWBSoiedY?nMM:@0
0onMM:@4oiafYPCoW7NY0onKNJd00onVQ:ooY8BaojB4/@03ojB4/@CoXhFd0onQR;T00on/U;koZIC0
ojVD`003ojVD`0CoZ9K300?oYYS8ok6/dona[=<00_na[=<01Ol0003o[jcEojn/eOn_[=Go^<SV00Go
]L?U00?o/l7UokC?kOndcnd00ondcnd2ok?:j`;o/=3a1?n`bN`00onZa^koooooooooo`0Aooooo`;o
0000:_ooool002Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?l:003o2P0000?o<@000_lg00000oln00;o?`00od800002od8000?oA0030_m500D00om200;oX8Fg
oin2]003oin2]0CoWh2a0_nNOJl00onGLjSoUg:WoiMbY`02oiMbY`CoV7:U1?nJLZ@4oi]bY0?oWGBT
00CoWgJToiY/W?nJK9coVVbL1?nJJi/3oiUYV@GoUVFG0onBHYH4oheMU@CoQeVD0on4F9D4oh=GUP?o
PeVH1?n5FiX2ohINW0;oTFbU0ol00005oiQfZPCoW7Z/1?nOOJh00onPOjoo]JkBokF^dP02okF^dPGo
/JG=0_n^WlP4oj?_mP03ok3Yn?nJLJ;oVW6R00?oVW:T1OnJM:L00onJMZ[oWWBSoiidX`05oiedY0Co
W7JV1?nLMjT01?nKNJgoYXB_ojJ4[onVQ:l5ojB4/@CoXhFd00?oXHRiojbD__n/U;h00_n/U;h4ojVD
`0?oZ9K300?o]:kBok6/dona[=<01?na[=<00ol0003o^<SVokS8iP02okS8iP?o]L?U0_nee_44okC?
k@03ojoIm_n`d?7o/=3a00?o/=3a00?o/<W/oj[6k_nZa^h00_nZa^hDooooo`03o`000?oooooooooo
02Oooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00005oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03Oooool2o`000003o`X00?lZ003o<@00
00;o<@000_lg0003ocl000;o@P000om400<00om500GoXHRioj25]`02oj25]`GoWh:d0_nOP;401?nF
M:_oUg>XoiMcZ?nGLjP4oiMbY`CoV7:U1?nJLZ@4oi]bY0;oWGBT00?oVVjNoiY/W?nJK9`00_nJK9`4
oiY[V`CoVFVI1?nFIIL3oi9RUPCoSEfE1?n7FI@3ohAHU@CoPeNF0on3FIP2ohEKVP;oSfRQ00CoTFbU
o`000?l0003o00001?nDL:L4oiQfZPGoW7Z/0_nOOJh00oni]mSo]JkBokF^dP03okF^dPCo/JG=0on:
kNL2oj?_mP03oiU_XOnJLJ;oVW6R00;oVW6R1?nJLZ@3oiYdY`03oiidX_nNM:?oWWBS00;oWWBS1?nM
M:@5oiafYP?oW7NY1OnVQ:l5ojB4/@;oXhFd00?o[iNmojbD__n/U;h00on/U;h5ojVD`004ojRF`ond
[];o]:kBokB^dPCo/JcC00?o^m7Zo`000?nhb>H00onhb>H00one`nGo]MKaokGFl@03okGFl@03okC?
kOn_fOKo[mWf00;o[mWf0_n`d?42ojW=lPGoZ/K^5Oooool00ol0003oooooooooo`0Vooooo`003_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00[ooooo0_l000000olR003o
:P00obX00003oc400003ocL00?lj003o?`0000;o?`000_m200000om400?oXhbkoj><^`03oj68^@Co
X8Fg1?nOP[@00onOP;7oUWB[oiIdZ`04oiMcZ0?oUg:W1?nHLZD4oiYbY0CoVg:T00?oWGBToiY^W_nJ
KYh01?nJK9`4oiY[V`CoVFVI1?nFIIL3oi9RUPCoSEfE1?n7FI@3ohAHU@CoPeNF0_n3FIP00on=IIko
SfRQohmXX@03o`0000CoTFbU0onDL:L4oiQfZPGoW7Z/00CoWgf^okVgf?ni]mSo^KOH1One[]801Ona
YLgoR^gWoh[]ion:kNOoV6fP00CoVFnQ1?nJLJ84oiYbY004oiYdYonNM:;oWWBRoiidXPCoWWBS1?nM
M:@5oiafYP;oW7NY00?oYhB^ojJ4[onVQ:l00onVQ:l5ojB4/@04oj>5]?n_Ukgo[iNmojnG_@Co[9Bn
1?nYU<000onh/]?o]:kBokB^dP03okB^dP03ok6/donkdN[o^m7Z00;o^m7Z00?o0000okS8i_nhb>H0
0oncgoH2okGFl@?oZN7j0_n_fOH3ojGBm`CoZLgb0_nZa^h3ojC2kQCooooo00?o0000ooooooooool0
9_ooool000Kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Q
onk^kP06ooooo`;o00007Oooool00ol0003oooooooooo`07ooooo`04o`000?lH003o8P00ob8000;o
:P0000?o<@00ocD00?le00000_lj0003ocl00003od800?nUSkkoXhbk00?oXhbk1?nQR;T3oj25]`;o
Wh:d0_nFMZ`4oiIdZ`?oUg>X1?nGLZL3oiQbY@CoVW:T0onKLZ@01?nIKj3oVVjNoiY^W_nJKYh4oiY/
W0CoVV^K1?nIJIT4oiIUU`?oTV:F1?n=GID4ohMIU0;oQ5RE00?oS62IohaRVon<HY/00_n<HY/3oheU
WP;o00000_n?J:45oi5/Y@?oU72W1?nHMZX4oiaj[003okc2g_ni]mSo^KOH00?o^KOH0one[]800omS
el;oVFjOoiQ]X003oiQ]X0CoVFnQ1OnJLJ83oiYbY0CoWWBR1?nNM:<5oiedY0CoW7JV00CoW7NYojN4
[_nWQ:koYhB^1?nVQ:l4ojB4/@03ok>K_on_Ukgo[iNm00;o[iNm1On/U;h00onYU<3o^;;CokRbd`02
okRbd`?o]:kB0_nmgo04ok_AjP03oj_ZnOl0003o/mof00;o/mof0onKj?/2ojWQnP;oW]Ol1OnUd_L2
ojW=lP;oX/Ga1OnT`^hDooooo`03o`000?oooooooooo02Gooooo000>ooooo`05o`000?oooooooooo
ooooool000003Oooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool00oooool2o`0000;o60000_lR00000olZ003o;P00ocD00002ocD000;o>P0000?o?`00
ojRC`?nXTl000onUSkh5oj><^`?oXHRi0_nPQKL00onGN:koUWJ/oiIf[002oiIf[0CoUWB[0onGLjP4
oiMbY`CoV7:U0onJLZ@01?nKLZCoVFnPoiU_X?nIKj04oiY^WP?oVVbL1?nJJi/4oiUYV@CoUVFG0onB
HYH4oheMU@;oQeVD0_n<GiP3ohaPV@CoS6:K0ol00005ohmXX@CoTFbU0onDL:L5oiQfZP;oW7Z/0onl
`]h5okVgf003okF^d_nIKYooVFjO00;oVFjO0onHKJ04oiU_X@GoVW6R0_nJLZ@00onOM:;oWWBRoiid
XP03oiidXPCoWWBS1?nMM:@3oiafYP03ojV5[_nWQ:koYhB^00;oYhB^1OnVQ:l2ojB4/@?o/i^o0on_
Ukd4ojbD_P03okfjeonh/]?o^;;C00Co^;;C00?o]:kBokgOl?nmgo000_nmgo000onkdN[oZn[ioj_Z
n@02oj_Zn@04o`000?nKj?_oVnSkoi_Xn`;oTm[n1OnNeo`2ojGBm`;oWlKd1OnRaO42ojC2kP;oXKg]
5Oooool00ol0003oooooooooo`0Tooooo`003_ooool01Ol0003ooooooooooooooooo000000kooooo
00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`0Nooooo`;o00000_ooool01_l0003o6000
oaP00?lH003o8P00obH000;o;P000ole00000olj003oZYO2ojRC`003ojRC`0?oYHnn1OnSS;/2oj68
^@04oiQj/?nGN:koUgR^oiMh[PCoUWJ/1?nFM:/3oiMcZ0CoUg:W1?nHLZD2oiYbY003oiQ_XonIKj3o
VFnP00;oVFnP1?nJKYh4oiY/W0?oVV^K1?nIJIT4oiIUU`?oTV:F0_n=GID2ohiQV0CoS5nH0on<H9T0
1?n<HY_o0000o`000?l00004oheUWPCoSfRQ1?nAK:D3oiA`Y`GoV7JZ00?oW7Z/okc2g_nl`]h00_nl
`]h4okVgf003oi]^W_nIKYooVFjO00?oVFjO0onHKJ04oiU_X@GoVW6R00?oVW:ToimdX_nOM:801OnN
M:84oiidX`CoWGBT00CoW7JVojV5[_nYQJkoZHF^1?nWQ:h5ojJ4[`03ojB4/OncVkoo/i^o00;o/i^o
1?n_Ukd00on/U;ko_K[Gokfje`02okfje`Co^;;C00?o]o3eokgOl?nmgo000_nmgo02oi?]l@;oZn[i
0_moi?400ol0003oQ=Sooi?JoP04oi?JoP;oW]Ol0_nLa_D5oio6m0;oX/Ga0onO_>d4oj6mkA?ooooo
0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0
003o8B4Qolc<c009ooooo`003_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool00oooool2o`00027ooooo0_l;00000olH003o7@00obH00002obH000;o;P0000?o=@00ok^m
g?ni^m/01?nZUl83ojRC`0CoYHnn0_nSS;/2oiYm/P?oV7Z`1?nGN:h3oiIf[0CoUWB[0onGLjP4oiMb
Y`CoV7:U00?oVW:ToiQ_XonHKj<01?nIKj04oiY^WPCoVVbL0onJJi/4oiUYV@CoUVFG0_nBHYH00onA
I9WoSV6HohiQV002ohiQV0CoS5nH00CoS62Io`000?l0003o00001?n<HY/3oheUWPCoSfRQ1?nAK:D4
oiA`Y`?oV7JZ0_nlbnH5okc2gP03okVgf?nKKYkoVfjN00;oVfjN1?nIKYl3oiQ]X0GoVFnQ0onJLJ80
0onPMJ;oWgBRoimdXP02oimdXPCoWWBR1?nNM:<4oiedY0GoZHF^1?nWQ:h3ojJ4[`03okRS`oncVkoo
/i^o00?o/i^o0on_Ukd00oo2b=oo_K[Gokfje`04okfje`03okRbdongl?Go]o3e00;o]o3e00Go_Mo`
oi?]lOnCkO7oTngaodo=dP04og?BoP03ohCHool0003oQ=So00;oTm[n0onG`oH4oic6m@;oWlKd0onN
^n`5oinlk@;oXKg]0_nQ^^/Dooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Wooooo000>ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo0_l0000Poooo
o`03od_6[_l;003o7@0000;o7@000olV00001Ol^003o^kgLok^mg?nk_Mco[I_500GoZYO21?nXTl02
ojF?_P03oib0]?nJOK;oVWfb00;oVWfb1?nHN[03oiMh[PCoUWJ/0onFM:/4oiMcZ0?oUg:W0_nHLZD2
oiE_Y@?oV6nS1?nIKj04oiY^WPCoVVbL1?nJJi/3oiUYV@CoUVFG00?oTV:Foi5TVOnAI9T01?n>HIP2
ohaOV0?o00000on<H9T4ohaRV`?oSFFN1?n?J:45oi5/Y@?oU72W00?oV7JZokc;i_nlbnH00onlbnH2
okc2gP?oVFbM1?nKKYh4oiU^W`?oV6fP1OnIKj42oiYaXP;oX7FR1?nOM:84oiidXPGoWWBS0_nMM:@0
0on[R;3oZHF^ojV5[P03ojV5[PCoYhB^00?oYXB_okRS`onhXl<00_nhXl<5ok>K_`04ojnG_Oo2b=oo
`/SOol;8g`Co_K[G0_nAl=l2okO`m@;oF]?900?oKL3nofc:o_m/b_h00_m/b_h2og?BoP;oT[;]0_nD
_?<00ol0003oU;ccoiO3mP04oiO3mP;oW<Ke0_nM]n/5oijkk0;oWkc]0_nP]nP5oj6jjaCooooo00?o
0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooo
ooooo`000009ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`03o`000?oooooooooo01gooooo00Co0000oa800?lB003o7@000_o1h>l0
0onn`Mco_;oLokbog003okbog004ok^mg?n]VlGo[I_5ojfKa@CoZYO21?nXTl000onUSkkoW82doib0
]004oiYm/PCoV7Z`0onGN:h4oiIf[0CoUWB[0onGLjP2oiMbY`03oi=_Y_nEKjGoUFnU00;oUFnU1?nH
Kj<3oiU_X0CoVVjN1?nJK9`4oiY[V`?oVFVI0onFIIL01?nCIY_oTFBIoi5TVOnAI9T3ohiQV0?o0000
0_n<GiP4ohaPV@CoS6:K0on=IIh4ohmXX@GoTFbU0_nDL:L2okWAk0Co_<_V00?oRf2KoiIXVonIK9d0
0onIK9d4oi]^WPCoVFjO0onHKJ05oiU_X@04oiYaX_nPMJ;oX7FRoj1eXPCoWgBR1?nNM:85oiidX`04
oiedY?n[R;3oZhR`oj^8/0CoZHF^1?nWQ:h5okRS``Co/i^o00?oa=o/ol;8goo2b=l00oo2b=l01?nm
^]OoTO3Ooi7`gonAl=l2og^dm`;oKL3n0_nFVM@4oiBVhPGoT[;]0_nD_?<01?l0003oU;ccoiO3m_nG
`oH2oibbi`GoWKO[0_nN^n`2oj6ci@GoX;OX0onQ^^/00onT^nWoooooooooo`0Booooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S802Oooool002Oooooo00?o0000ooooooooool06_ooool01Ol0003o1000o`@00?lB003o`Mc]00?o
`N3_0onn`M`3okbog003ok2Paon]VlGo[I_500;o[I_51OnZUl82ojRC`003oij4]_nLP;CoW82d00;o
W82d0onJOK84oiQj/0?oUgR^1?nFMZ`4oiIdZ`?oUg>X00?oUg:Woi=_Y_nCKjH01?nEKjD4oiQ_X`Co
VFnP0onJKYh4oiY/W0CoVV^K0onIJIT01?nFIIOoTfJKoi=VVonCIY/3oi5TV@?o00000_n>HIP3ohaO
V0CoS62I1?n<HY/3oheUWPGoSfRQ1?nAK:D00onDL:Oo^M7/okWAk002okWAk003okc;i_n6FiSoRf2K
00;oUVRK1OnIK9d3oi]^WPCoVFjO1?nHKJ03oiU_X@03oimeXonPMJ;oX7FR00?oX7FR0onOM:85oiid
XP?oWWBS00?o[Xbboj^8/?n[R;000_n[R;05ojV5[P;oYhB^0_no/<`4okRS``?o/i^o0oo4gn`3ol;8
g`04o`000?n9X^CoRJ;TohVRi0;oNkCg00?oVHo7oiJIe?nFVM@00onFVM@4oiBVhP;oT[;]0_nNXmT2
oif[h@03o`000?nMZn7oWJ_Q00CoW;;W0_nM]n/2oj6^h@GoXK?U1?nP]nP00onQ^^_oY;_YojBkj@02
ojBkjACooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
c<c<o`000?l0003o0000olc<c009ooooo`009oooool2o`0001Sooooo00Co0000ogcVh_mli^;o[O;e
1Oo1g>d00oo1h>oo_/7Lokk1g003okk1g004okbog?n`X<Oo/:37ok2Pa`?o[I_51?nZUl800onQQkWo
WXBfoij4]P02oij4]P?oW82d1?nJOK83oiQj/0CoUgR^0onFMZ`2oiIdZ`;oT6nY0onAKjP3oi=_YPCo
UFnU1?nHKj<4oiU_X0?oVVjN1?nJK9`4oiY[V`;oVFVI00?oU6ZNoi=VVonCIY/00_nCIY/01?nAI9Wo
0000o`000?nAI9T4ohiQV0?oS5nH1?n<H9T4ohaRV`?oSFFN1On?J:43oi5/Y@;o^]?/0onidN`00on6
FiSoT6>Ioi1SV@03oiIXV`GoVFbM0onKKYh4oiU^W`CoV6fP0_nIKj42oimeX`GoX7FR0onOM:85oiid
XP;oWWBS0_n^S;84oj^8/0GoZHF^00CoYhB^okn`c?no/<co_k3<1OnhXl<00oncVkooa=o/olCOk002
olCOk003ol;8gonCTm3oTi?@00;oRJ;T0_nLQk`4oiV?a`GoUYWD0_nDY^800onQWM3oWZ?IoijSf@03
oijSf@;oWJ_Q00?o0000oif[hOnMZn400_nL/^L00onRZM_oXJkQoj6^h@03oj6^h@CoXK?U0_nP]nP3
ojBhi`CoY;_Y5Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol@413o^[Zjoooooonj^[[o410@00Wooooo000Wooooo`03o`000?oooooooooo01Cooooo0_m<
bl`01?mli^;o/nggok?]monckOL2ol7Ij`?o`Mc]0_no`md4okk1g003ok:Tb_n`X<Oo/:3700;o/:37
1?n]VlD01?nZUl;oXHNioj67^OnQQkT4oij4]P?oW82d1?nJOK84oiQj/0?oUgR^0_nFMZ`00on@L:[o
T6nYoi1_Z@02oi1_Z@?oTFnX1?nCKjH3oiE_Y@CoV6nS1?nIKj04oiY^WP?oVVbL0onJJi/01?nFKJ7o
U6ZNoiAZW_nDJYh2oi=VV`?o00000onAI9T4ohiQV0?oS5nH1?n<H9T4ohaRV`CoSFFN1?n?J:400onA
K:Go^]?/ok[Ck003ok[Ck003okWAk?n@HiWoT6>I00;oT6>I1?nFJ9/4oiU/W@?oVfjN1OnIKYl3oiQ]
X004oiU_XOnOMJ?oWgFSoimeX`GoX7FR0onOM:85oiidXP03oiidXon^S;;o[Xbb00;o[Xbb0on[R;04
ojV5[P03olS9fono/<co_k3<00;o_k3<1?nhXl<3ok;gk`;oa=o/0_nCTm02oj63]0CoW8Nl1OnISlL2
oiJIe0;oY9O81?nQWM05oijSf@;oWJ_Q00?o0000oj>Te_nRZM/00onRZM/5oj6^h@;oXK?U0_nU]><5
ojBhi`;oY;_Y0_nW_NTBooooo`?o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
0000okZj^_oooooo^[Zjo`000009ooooo`009oooool00ol0003oooooooooo`0>ooooo`?oC<SU0omU
fNH00on?k?;o/nggok?]m`02ok?]m`Co`MW[00?o`Mc]oko3gOno`md00_no`md00onn`Mco/ZC:ok:T
bP02ok:TbPCo/:370_n]VlD00onSS;coXHNioj67^@03oj67^@?oWXBf1?nLP;@3oiYm/PCoV7Z`0_nG
N:h01?nALJ_oT72Zoi1`Z_n@L:X4oi1_Z@CoTFnX0onCKjH4oiE_Y@?oV6nS1?nIKj04oiY^WP?oVVbL
00CoVV^KoiI]XOnFKJ7oUVfQ0_nDJYh3o`0000;oTfJK1?nAI9T4ohiQV0CoS5nH0on<H9T4ohaRV`Co
SFFN0on?J:43okc<i`;o^]?/0on;GYL4oi1SV@CoUVRK1?nIK9d3oi]^WPGoVFjO0_nHKJ000onNMJCo
WgFSoimeX`03oimeX`CoX7FR1?nOM:83oiidXP03ok2B]on^S;;o[Xbb00?o[Xbb1?n[R;02ojV5[P?o
b<WK1?no/<`01?nhXl?o/_O_ok;gkonbmnl3oiZ8_`03ojF3[onQPkCoXH>d00?oXH>d1?nLQk`3oiV?
a`03ojND`OnTUlSoY9O800;oY9O81OnQWM02oijSf@;oYYo?0_nSY=H00ol0003oXjCFoj>TeP04oj:Y
f`;oXJkQ0_nV/N05ojFdh`;oY;SW0_nX^nL5ojNmjACooooo00Wo0000ooooooooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Wooooo000Vooooo`?o0000
2Oooool4ofk>oP;oGlkf0_mjg_P3oigYnPCo]nKf00?o/nggol7Ijoo1fN/00_o1fN/2ol34g@?o_l?M
00?o]JW=ok:Tb_nbY<X00onbY<X3ok2Pa`03ojJA_onSS;coXhbl00;oXhbl1?nQQkT4oij4]P?oW82d
0onJOK82oiQj/0;oTW>/0onALJ/4oi1`ZP?oT6nY1?nAKjP3oi=_YPCoUFnU0onHKj<4oiU_X0CoVVjN
0_nJK9`01?nGL:CoUVfQoiI]XOnFKJ43o`0000;oU6ZN0onCIY/4oi5TV@CoSV6H1?n<GiP3ohaPV@Go
S6:K0on=IIh00on?J:7o_<cWokc<i`02okc<i`?oRUbF0on;GYL4oi1SV@CoUVRK1?nIK9d4oi]^WPCo
VFjO00?oV6fPoiieY?nNMJ@01OnOMJ<4oj1eXPCoWgBR0_nNM:82ok2B]`Go[Xbb1?n[R;000onYQJko
b<WKolS9f`02olS9f`?o_k3<00?o0000oj23]?nPPk@00onPPk@00onJR;ooYH>_ojF3[`05oj63]0Co
W8Nl00?oVHo7ojND`OnWU<400_nWU<44ojBGb0?oXIg@00?oZIg;ojJOconVWll00onVWll2oj>TeP04
o`000?nSY=KoXZWKoj:Yf`;oZ:kL1OnV/N02ojFdh`;oZKWT1OnX^nL2ojNmj@;oZ/3Y5Oooool00ol0
003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`02ooooo`?oPKok1?mib?l2ofk>oP?o
RM_n1?nUh_/00onMjO[o]nKfokOVmP02okOVmP?o`MGY00?o`MW[ol34gOo0a=d00oo0a=d01?no`mgo
]JW=okFYcOneZLd5ok:TbP04ok2PaonVTKooYY6oojJA_`?oXhbl1?nQQkT4oij4]P;oW82d00CoUGR`
oiAe[_nDMJkoU7F^1?nBLj`4oi5aZ`?oT72Z0on@KjT4oi5_Z0?oTfnV1?nEKjD4oiQ_X`?oVFnP1?nJ
KYh00onJK9coUg2ToiM`Y003o`000003oiI]XOnDJYkoU6ZN00;oU6ZN0onCIY/4oi5TV@CoSV6H1?n<
GiP4ohaPV@CoS6:K0_n=IIh2okZmf`?o_<cW1?n:G9H3oh]NU`GoT6>I0onFJ9/4oiU/W@CoVfjN0onI
KYl01?nPN:KoWWFToiieY?nNMJ@5oimeX`CoX7FR1?nOM:800onNM:;o/9:gok2B]`02ok2B]`Go[Xbb
0_n[R;02olWbk@Gob<WK00?o_k3<ojF1[OnUPJd01?nPPk@00onZQJgoYH>_ojF3[`02ojF3[`CoXH>d
0onLQk`00on]TkcoYiC1ojND`@03ojND`@CoY9O800?oXIg@ojVMbonYWL/00_nYWL/4ojJOc`?oXjCF
00?o0000ojR^g?nX[]`00onX[]`3ojJah003oj^hh_nY^NCoZKWT00?oZKWT0onX^nL2oj_0j@CoZ/3Y
5?ooool00ol0003oooooooooo`0Nooooo`006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
00?o0000oooooon5]O@00on5]O@3oh6on`;oNLSo1?nBdoh00on9fokoYN;kojGRn`02ojGRn`Co^=gc
00Co]nKfol7EjOo1eNWo`MGY1_o0a=d00onh[/oo]JW=okFYc@02okFYc@Co/ZC:00?oZIK2ojJA_onV
TKl00_nVTKl3oj><_0GoXHNi0_nNQ;H01?nGNk;oUGR`oiEh/?nEN;03oiAe[PCoTW>/1?nALJ/3oi1`
ZPCoT6nY0onAKjP3oi=_YPCoUFnU1?nHKj<3oiU_X0;oVVjN0_nGLZL3o`0000CoUVfQ1?nDJYh3oi=V
V`CoTFBI1?n>HIP4ohaOV0CoS62I1?n<HY/00on=IIko^[gKokZmf`02okZmf`03okc<ion;G9GoRUbF
00?oRUbF1?n;GYL4oi1SV@?oUVRK1?nIK9d4oi]^WP04oiU^WonPN:KoX7RVoj1hYPCoWWFT1?nOMJ<5
oj1eXP?oWgBR1On`T[L5ojj</P03oj^8/?o9l^gobO;]00;obO;]0_o8bM/2ojV1Z@CoYH6]0_nPPk@2
ojZ5[@CoYH>_1OnQPk@01?nLQkco[I>lojfC_?n]Tk`4ojND`@?oY9O800?o[Yk7ojVMbonYWL/00onY
WL/5ojJOc`04oj>Te_n[[MSoZjgHo`0000GoZ:kL00CoY[7Poj^hh_n[^>;oZkSR1OnY^N@00onX^nOo
Zl3Yoj_0j@02oj_0j@;oZ/3Y0_n[`^/Dooooo`03o`000?oooooooooo01gooooo000Kooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`02ohFem0?oVKc`1?nGb?P2oi;CoP?o
ZMOh0_nhe>h4okSMl`?o`M7V00?o`MGYol34gOo0a=d01?o0a=d3okR^c`Co]JW=00?o/ZC:ojVF`_nY
U/800_nYU/83ojJA_`CoXhbl1?nQQkT00onNQ;KoUg^boiMk/P04oiEh/0?oU7F^0onBLj`4oi5aZ`?o
T72Z1?n@KjT3oi5_Z0CoTfnV0onEKjD4oiQ_X`;oVFnP00?oUgBZoiMbYol000000_l00004oiM`Y0?o
UVfQ1?nDJYh4oi=VV`?oTFBI1?n>HIP4ohaOV0CoS62I0on<HY/00ondZLko^[gKokZmf`03okZmf`;o
RebE1?n:G9H4oh]NU`CoT6>I0onFJ9/5oiU/W@?oVfjN1?nPN:H4oiieY0CoWgFS1OnPMJ82oimdXP;o
]Ibo1?n`T[L4ojj</P;oKMJV0_o9l^d00onGKj?oZH6YojV1Z@03ojV1Z@CoYH6]00?oX8>dojZ5[OnZ
QJd00_nZQJd3ojF3[`CoXH>d00?o/IJjojfC_?n]Tk`00_n]Tk`5ojND`@04ojBGb?n^W/Oo[Yk7ojjN
a`GoZIg;0_nVWll2ojn]eP?oZjgH00Co0000oj^]f?nX[]coZ:kL0_n^^>45oj^hhP;oZKWT0_n/`>P4
oj_0j@03ojc4jon[`^_oZl;[00?oZl;[4oooool2o`0001kooooo000Kooooo`05oa0@4?oooooooooo
ooooool@41001_ooool2o`0000;ooooo1OnI_?02oiO8n0?oZ/ca00?oZMOhokSDk_nhe>h00onhe>h0
0onhgO?o`M7Vol7AiP02ol7AiP;o`LCM1?o0a=d00onj/];o^:k?okR^c`03okR^c`;o]JW=00?o[9_6
ojVF`_nYU/800onYU/84ojJA_`?oXhbl0_nQQkT2oiUn]0CoUg^b0onEN;03oiAe[PCoTW>/0onALJ/3
oi1`ZPCoT6nY1?nAKjP3oi=_YP?oUFnU0_nHKj<2oiAd[@04oiMdZ_l0003o0000o`0000?oUg:W1?nG
L:@4oiI]X@?oU6ZN1?nCIY/3oi5TV@CoSV6H1?n<GiP4ohaPV@03ohaRVondZLko]:W>00;o]:W>0onj
_M/4oh]LU@?oRUbF1?n;GYL4oi1SV@?oUVRK1OnIK9d2oi]^WP03ojAnZOnPN:KoX7RV00?oX7RV0onN
MJ@5oimeX`CoX7FR00CoWgBRokFL_oneW;oo]Ibo1On`T[L2ojj</P;oKMJV00CoVVjOoiM_XonGKj?o
UfnS1OnYPJT4ojF1[@GoZXF]1?nUPjl2oj63]0?o/IJj0on]Tk`4ojND`@03ok>Ra_n^W/Oo[Yk700;o
[Yk71?nYWL/00onc/=Go[jgFojn]eP03ojn]eP?oZjgH00?o0000ojjhhOn^^>400on^^>42oj^hhP;o
[L;X1On/`>P00on[`>Wo[<C[ojc4j`02ojc4j`?oZl;[00?oZ/?/ooooooooool04?ooool00ol0003o
ooooo`00000Nooooo`006oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool00_ooool2oiVll0?oZL3Z0onZc?43okO;j@?o^=C^1?noc>@00oo1dNKo`LCMol74g@02ol74g@03
ol34gOnj/];o^[;B00;o^[;B0onh[/l00on_XL[o[9_6ojbKaP02ojbKaPCoZIK21?nVTKl2oj><_003
oi^2]onIO[CoVGjd00;oVGjd1?nGNk83oiEh/0?oU7F^1?nBLj`3oi5aZ`CoT72Z0on@KjT4oi5_Z0?o
TfnV0_nEKjD01?nAM:ooU7B]oiAd[OnDM:d2o`0000?oUgBZ0onGLZL4oiM`Y0CoUVfQ0onDJYh4oi=V
V`?oTFBI1On>HIP3ohaOV0?oS62I00?o[9[5okBYc_ndZLh01?ndZLh00onj_M_oSenEoh]LU@03oh]L
U@?oRUbF1?n;GYL4oi1SV@CoUVRK1?nIK9d01?nKKYkoY7jYojAnZOnTOZT4oj1hYP?oWWFT1OnOMJ<3
oj1eXP03okf^boneW;oo]Ibo00;o]Ibo1On`T[L00on^S;;oVVjOoiY^W`02oiY^W`;oUfnS0_n]PjL4
ojV1Z@CoYH6]1OnZQJd4ojF3[`03oj63]?naU[[o/IJj00;o/IJj1?n]Tk`00onWU<7o/j;6ok>RaP02
ok>RaPCo[Yk700?oZIg;ok>`eOnc/=D00_nc/=D4ojn]eP05oj^]f?na^n;o/K_Rok6kh_l000000on^
^>42ojo5jPCo[L;X0_n/`>P3ojc6k@Co[<C[00?oZl;[oj[3k?nZ`n`00_nZ`n`Dooooo`03o`000?oo
oooooooo01_ooooo000Kooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`03ooooo`GoZL3Z00?oZ/caokO;jOngbnT00ongbnT00onhe>ko_lcToko<i002oko<i0Go`LCM0_nl
]mD5okZbdP04okR^con_XL[o[j7:ojnQbPCo[9_61?nYU/82ojJA_`03oif6^_nKP[OoVh:g00;oVh:g
0onIO[@4oiMk/P?oUGR`0onDMJh4oi9c[0CoTG6[0on@L:X3oi1_Z@;oTFnX0_n>Lk43ohmd/0?oTGB_
0ol00002oiAd[@?oUgBZ0onGLZL4oiM`Y0CoUVfQ0onDJYh4oi=VV`CoTFBI1?n>HIP3ohaOV003ohaP
VOn/V/Go[9[500;o[9[51?ndZLh3ohmOU@CoRebE0on:G9H4oh]NU`CoT6>I1?nFJ9/3oiU/W@03ojV3
[?nTOZWoY7jY00;oY7jY1?nPN:H3oiieY0GoWgFS00?oX7FRokf^bonm[//00_nm[//4okFL_`?o/9:g
00?oWFnMoiY^WonJKYl00onJKYl01?nGKj?o[H>Wojf3Yon]PjL5ojV1Z@;oYH6]0_nbS:h4ojZ5[@Co
YH>_1OnaU[X4ojfC_0Go/j;60on^W/L00oni]mSo/k3Eok>`e@04ok>`e@;o[jgF0_ne`^@3ok6khP03
o`000?n^^>7o[lGZ00Co[lGZ0_n]`^P2ojc:k`Go[<K]0_n/a>/2oj_5k@?oZ/?/00?oZ<;/oooooooo
ool04oooool00ol0003oooooooooo`0Jooooo`006oooool01Ol@413ooooooooooooooooo410@00Go
oooo00?o0000ooooooooool01Oooool3ojW0jP?o]/?T0ongbnT3okk8hP03oko<i?o1a=go`LCM00Co
`LCM1?nl]mD3okZbdP03ok:Xc_n_XL[o[j7:00;o[j7:1On/VlH2ojVF`P03oj2;__nMQ[[oWHJj00;o
WHJj0onKP[L4oiUn]0?oUg^b1?nEN;03oiAe[P?oTW>/1?nALJ/2oi1`ZPCoSWBa1?n>Lk43ohmd/0?o
000000?oTGB_oiAd[OnDM:d00_nDM:d3oiMdZPCoUg:W0onGL:@4oiI]X@CoU6ZN0onCIY/4oi5TV@Co
SV6H0_n<GiP00onTT<3o[9[5ojbJa@03ojbJa@?o]:W>00CoTV:FohmOUOn?GiGoSenE1?n;G9D3ohYL
UPCoRejG1?n@HiT4oiIXV`;oVFbM0_nYPj`4ojAnZ@CoX7RV1?nNMJ@3oimeX`03ol;6gOnm[/_o_Jk;
00?o_Jk;1?neW;l01?n`T[OoWFnMoie_WOnMKid5oiY^W`Co[H>W1OnYPJT01?nUPJgo/Xb^ok:<[_nb
S:h5ojZ5[@;oYH>_0_niWK`5ok6F^P;o[I>l0_nl[<X5ok>RaP04ojjNaoni]mSo^KOHokVgf0Co/k3E
00?o]lgZokG2i?ne`^@00one`^@2ok6khP03ok3:kOl0003o[lGZ00?o[lGZ00?o[<obojc:kon/b^l0
0on/b^l2ojc6k@;oZ/O_1On[aNd01?nZ`ncoZ<;/ojS2k?nX`^`Dooooo`03o`000?oooooooooo01[o
oooo000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000Oooooo00?oZL3ZokK3i?nf
`n@00onf`n@00ongbnWo_/SRokk8hP02okk8hPKo`LCM1_nl]mD01?nj/];o/ZS>ok:Xc_nbZ<h3ojnQ
bPCo[9_600?oXi72oj2;__nPRkh00_nPRkh3oif6^P?oVh:g1?nIO[@4oiMk/P?oUGR`0onDMJh2oi9c
[003oi1f/_n?MK7oSgFa00;oSgFa1_n>M;44ohic/@?o000000CoSgB`oi5d[onAM:ooTGB_1?nDM:d3
oiMdZPCoUg:W0onGL:@4oiI]X@CoU6ZN0onCIY/4oi5TV@CoSV6H00CoS5nHojB@`?nTT<3oY9301On/
V/D00ondZLkoTV:Foi9RUP03ohmOU@CoRebE1?n:G9H3oh]NU`GoT6>I0onFJ9/00onIK9goZH>/ojV3
[002ojV3[0?oY7jY1?nPN:H4oiieY0;oWgFS0oo2a]d5okf^b`;o]Ibo0_nOL9`4oie_W@?oVVjO00?o
/XVYojf3Yon]PjL00_n]PjL5ojV1Z@Co/Xb^1OnZQJd01?nUPjoo^IflokVM_?niWK`5ok6F^P04ojfC
_?nl[<[o_:c:okb/bPCo/j;600?o_LCOokVgf?ni]mP00oni]mP00onc/=Go]lgZokO=jP02okO=jP?o
]L;T00?o/=?bok3:kOn`b^d00_n`b^d00ol0003o[lGZojc?lP03ojc?lP;o[<[_0_nXb_45oj[7k`;o
ZlG]0_nXa>h5ojS2k1Cooooo00?o0000ooooooooool06Oooool001_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`03o`000?oooooooooo00Oooooo1?nf`n@2okg4g`?o_/SR1_o1a=d2okjke`Co
_;OE00?o]JkBok:Xc_nbZ<h00_nbZ<h4ojnQbP04ojbKa_nSTL;oXi72oj>A`PCoX8^n0onMQ[X4oi^2
]`?oVGjd1?nGNk82oiEh/004oi5i]?nAMk?oTGNcoi5g/`?oT7Jb1?n?MK47ohid/@?o00001?n?M;03
oi5d[`CoU7B]0onGM:X4oiMbY`CoUg2T0onFKJ44oiAZWP?oTfJK1?nAI9T2ohiQV0;oWXg11?nTT<04
ojbJa@CoTV:F1?n?GiD3oh]LU@CoRUbF0on;GYL5oi1SV@?oUVRK1OnYPj`3ojAnZ@GoX7RV0onNMJ@0
0onOMJ?o`/KMol;6g@02ol;6g@Co_Jk;00?oXW:Moim`W?nOL9`00_nOL9`4oie_W@;oVVjO0onbRJT3
ojf3Y`CoZH6Y00?o_I^eok:<[_nbS:h00_nbS:h4ojZ5[@03ol6[a?niWKco^Ifl00;o^Ifl1?naU[X0
0oo6`MKo_:c:okb/bP03okb/bP03ok>Ra_nma=oo_LCO00;o_LCO0oni]mP2okOOm0Co]lgZ00?o]L;T
ok3Cl_n`do800_n`do82ok3:k@;oZ=Cg00Co0000ojc?l_n/co;o[<ob0_nVcO@4ojS:l@;oZ/O_0onW
a^l4ojS4kP;oZ<;/0_nW`N`Dooooo`03o`000?oooooooooo01Wooooo000Uooooo`03o`000?oooooo
oooo00Sooooo00?o]/?Tokg4gonma=l00onma=l00onnb>;o`LCMol74g@04ol74g@Co_[_G00?o_;OE
okF^d_ne[]800_ne[]84ok:XcP;o[j7:00?oYYS7oj>A`_nSTL800_nSTL84oj2;_PCoWHJj0onKP[L3
oiUn]0;oUg^b0_nBNkH3oi5i]0?oTGNc1?n@M[83ohme/@CoSWBa0ol00004ohic/@?oSgB`0onAM:l4
oiAd[@CoUgBZ0onGLZL4oiM`Y0?oUVfQ1?nDJYh3oi=VV`;oTFBI0_nIT<T5oij=`@?oY9300on/V/D0
0onDIISoTV:Foi9RUP02oi9RUPCoSenE0on;G9D4ohYLUP?oRejG1On@HiT2oiIXV`03ojb6[OnYPjco
ZH>/00?oZH>/1?nTOZT4oj1hYP;oWWFT0_nni?85ol;6g@04okf^bonRLYgoXW:Moj9bW@CoWg2L1?nM
Kid00onJKYoo/XVYok:9Z@02ok:9Z@Co[H>W0_nYPJT3okfK]@Co/Xb^0_nZQJd3ol6[a0Co^Ifl00?o
/IJjolK1e_o6`MH00_o6`MH3okb/bP;o_mc^1?nma=l00oni]mSo]modokOOm003okOOm0;o]lgZ0onX
g?T2ok3ClP;oXM[k0onXe?L00ol0003oZ=Cgojc?lP04ojK=m0;oZ<[a0_nUao45ojO6k`;oZ<C^0_nV
`Nd4ojO1k1;ooooo00?o0000ooooool000006_ooool002Gooooo00?o0000ooooooooool02_ooool3
okg4g`;o`<CM1?o1a=d2oko0fP?o_[_G0_nh]MH4okF^dP?o/ZS>00?oZIo<ojJHaonVV<L00_nVV<L4
oj>A`PCoX8^n0onMQ[X2oi^2]`04oiB1^onCOKSoTgfhoi=m^0CoTW^f1?nANK@3oi5g/`?oT7Jb1?n?
MK43o`0000?oSWBa1?n>Lk43ohmd/0?oTGB_1OnDM:d3oiMdZP?oUg:W1?nGL:@2oiI]X@;oOkSh0on6
Z>`3oi6Jf0GoVI391?nNSL44ojB@`003ojbJaOnDIISoU6FH00CoTV:F1?n?GiD3oh]LU@CoRUbF1?n;
GYL4oi1SV@04oiIXVon/QZgo[8J]ojb6[@CoZH>/1?nTOZT4oj1hYP03oiieY?nni?;o_^Cb00;o_^Cb
0_o2a]d3ojYlXP?oXW:M1OnOL9`3oie_W@Go/XVY1?n]PjL00onYPJWo_I^eokfK]@02okfK]@Co/Xb^
00?oZXF]ol6[a?o1Zl@00_o1Zl@4okVM_0Koa/7F00?o_:c:okoLk_nog>h00_nog>h2okg4g`?oX>kh
0_nggo@3oiCSo@;oZ=ci0_nBg?h5oj7Jn`;oZ=Cg00?oX/oho`000?nRcoP00_nVcO@2oj?8l`GoYLOa
0_nWa^l2ojG2kPGoY/7]0_nW`N`2ojJok1Cooooo00?o0000ooooooooool05oooool002Gooooo0_l0
000<ooooo`03okg4goo0a=go`<CM00;o`<CM00?o`LCMoko0f_no`=X00ono`=X00onn^mOo^;GFokRe
eP02okReePCo]JkB00Co/ZS>ojVOc?nYWlcoZIo<0onVV<L4oj>A`PCoX8^n0_nMQ[X01?nFQ;koU86k
oiB1^onDPK/4oi=m^0?oTW^f1?nANK@3oi5g/`?oT7Jb0_n?MK42o`0000OoSWBa0on>Lk44ohmd/0?o
TGB_1?nDM:d3oiMdZP;oUg:W0on7`OX3oh30o0CoOkSh0on6Z>`3oi6Jf0CoVI391?nNSL43ojB@`003
oiEVVOnDIISoU6FH00;oU6FH0onBHYH4ohmOU@?oRebE1?n:G9H4oh]NU`?oT6>I00?oYh6[ojb6[On/
QZd00_n/QZd4ojV3[0CoY7jY0_nPN:H4ohK[g0;o_^Cb00?oZgfQojYlX_nZO:800onZO:83oj9bW@Go
Wg2L0onMKid5ok:9Z@Co[H>W1OnmVkD4ok:<[PGo`J_40oniWK`2olg]jPCoa/7F00?oWO3cokoLk_no
g>h00_nog>h2odg;a@;oX>kh0omYf?82oiCSo@CoO=On0onBg?h2oj7Jn`?oV/oj0_nRcoP00onOa_Co
0000oio6m004oj?8l`;oYLOa0_nT`Nh5ojG2kP;oY/7]0_nU_n`5ojJok1?ooooo00?o0000oooooooo
ool05oooool002Cooooo00?o0000ooooooooool03Oooool3ol34g@?o`LCM0ono`=X00onk_=_o^;GF
okReeP04okReeP;o]JkB00?o[JOAojVOc?nYWl`00_nYWl`3ojJHa`CoXi720_nPRkh2oiR9`PCoUXBn
0onDPK/3oi=m^0CoTW^f0onANK@3oi5g/`;oT7Jb0ol00002ohme/@OoSWBa0on>Lk44ohmd/0?oTGB_
0_nDM:d3ohZ`k`CoSK_e1?n7`OX3oh30o0CoOkSh0_n6Z>`4oi6Jf0?oVI391OnNSL400onTT<3oUFJI
oiEVV@04oiAUV0?oTV:F1?n?GiD4oh]LU@?oRUbF1?n;GYL2oi1SV@;oYh6[1?n/QZd5ojV3[0;oY7jY
0on/OJ03ojenX@CoZgfQ1OnZO:83oj9bW@GoWg2L0_nMKid2ok^D[`Co/XVY1?n]PjL00ooC`<So_I^e
okfK]@03okfK]@;o/Xb^0_o=c=P5ol6[a003okVM_?o=kN[ocNgZ00;ocNgZ00?oa/7Foig`lonMl?<0
0_nMl?<00onog>ko5:;?oaBRc`02obngeP?oJ;on1?m/cOd2ogcGoP;oSLGj1OnCcO/2oi[?nP;oW<?c
0onOa_@01?l0003oWlKdoj?8lonSb?<2oj;0kPCoY<7^0_nU`^h2ojFnk0GoYKo/0_nV_n`2ojJnjaCo
oooo00?o0000ooooooooool05_ooool002Cooooo00?o0000ooooooooool03_ooool00oo0a=go`LCM
ol74g@03ol74g@04oko0f_nk_=_o^kcKok^lf`Co^;GF00?o/:oGojfWdOn]Ym400_n]Ym43ojVOc0Co
YYS70_nSTL800onJS/KoV8W2oiR9`P03oiR9`P?oUXBn0onDPK/3oi=m^0CoTW^f0onANK@2oi5g/`?o
00000_n@M[83ohme/@KoSWBa00?oT93@ohfEe_n=UMH00_n=UMH3oh^KgPCoR:CW1On:/>l2ohfkm@?o
SVZU0on>J:<3ohiWX@CoS6FP0_n9HYl4oi6Jf0?oVI390_nNSL400onAII_oUFJIoiEVV@02oiEVV@Co
U6FH0onBHYH4ohmOU@CoRebE0on:G9H4oh]NU`04oi1SVOnWPJ_oYh6[ojN1Z`Co[8J]1OnYPj`00onT
OZWo[7fPojamX002ojamX0Co[GjQ0_n[OJ400oo0VK3oZWbRojYlXP03ojYlXP?oXW:M1OnOL9`01?nM
Kigo^iB_ok^D[onkU:l5ok:9Z@;o[H>W0_oC`<P5okfK]@04ok:<[_o=c=SocLcHolg<f0Co`J_40_l0
0002olg]jP?oVi791On=W=d4ogb`m@;oJ;on0_nC[^T4ohnlm@CoSLGj0_nCcO/2oi^ml0GoW<?c0_nO
a_@00ol0003oXKg]oj;0kP04oj;0kP;oY<7^0_nT_N/4ojFnk0;oYKo/0onU_N/4ojJnjaCooooo00?o
0000ooooooooool05Oooool002Cooooo0ol0000?ooooo`Co`LCM0_nma=l4ok^lf`03okRee_n`[mOo
/:oG00;o/:oG0on]Ym44ojVOc0;oYYS700?oWIC;oiZ>a_nJS/H00_nJS/H4oiR9`P?oUXBn0onDPK/4
oi=m^0?oTW^f0_nANK@3o`0000;oTGNc0on@M[82ohme/@03oi6;bOnASLcoTHg<00;oTHg<1?n@T=04
ohfEeP?oRi_N1?n8Y>L2ohZ`k`?oSffW1?n>JZD3ohiXX`?oSVNQ1?n<IJ03ohURW`?oRV:N1?n<Hid3
oi5UV`?oUFJI1?nDIIP3oi9RUPCoSenE1?n;G9D3ohYLUP?oRejG00?oWWNWojN1ZonWPJ/00_nWPJ/5
ojb6[@?oZH>/00?oQEJAojamX?n/OJ000on/OJ04ojenX@04oj]mXOo0VK3o`9V`ol2I/0CoZWbR1?nR
LYd4oim`W0Co^iB_1OnbRJT01?n]PjOodl38om?0b?oC`<P4okfK]@;o[?WS1?o=c=P01?o1ZlCoXHk0
oj6>`?n>U]L3ojJ=^`CoVi790on=W=d00onVW<coWJCJoifTfP02oifTfPGoTjkY0_n?_?D00onNZn3o
V[CYoiZdj@03oiZdj@CoVkg`0_nL`o<2oj6ijP?oXKg]00Co0000oj6mkOnR`>koX/3^0_nT^^T5ojBm
j`;oYKk/0_nU_>X5ojFmj`CoY[k[4_ooool2o`0000Wooooo1?l000000ol@413oooooooooo`07oooo
o`009?ooool00ol0003oooooooooo`0@ooooo`03ol74gOnma=oo_LCO00?o_LCO0_nk_=/2ok>ig@Co
/:oG1?n]Ym42ojVOc003oj2Ld?nMU<_oWIC;00;oWIC;0onJS/H4oiR9`PCoUXBn0onDPK/3oi=m^0;o
TW^f0ol00002oi5i]0;oTGNc00CoT8S7oi69b?nARLSoTHW81?nARlT4oi6=c0?oT93@1On=UMH3oh^K
gP;oR:CW0onBLJX3ohm]Y`CoSVZU0on>J:<3ohiWX@CoS6FP0on9HYl3ohYRWPCoS6>M0onAII/3oiEV
V@CoU6FH1?nBHYH3ohmOU@CoRebE0on:G9H01?n;GYOoWWNWoiigYonNMjL5ojN1Z`Co[8J]00CoZH>/
ohEFTOn5EY7oQEJA1On/OJ04ojenX@04oj]mXOo0VK3o`9V`ol2I/0CoZWbR1?nRLYd3oim`W003olFX
_?nkU:oo^iB_00;o^iB_1?nbRJT2ok3d/@Codl3800?o_I^eojcihon/nN<00on/nN<2olg<f0?oXHk0
00?o/92eojJ=^onVSK/00_nVSK/5oi^Ab@04ohfLgOnVW<coYYc<ojJLc0CoWJCJ0_nC[^T2oj>SePCo
WZ_P1OnJ]>T2oi^ml0;oX[CV1?nQ^NX2oj6mk@03ojBhiol0003oY;SW00CoY;[Y0_nT_N/2ojJkj0Go
YKcZ0_nU_N/2ojJmjPGoY[k[4oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wo
oooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03
o`000?oooooooooo01;ooooo0onma=l00onf`nCo/kWMok>ig@03ok>ig@Co/:oG0_n]Ym400onSY=Ko
X9c@oj2Ld002oj2Ld0?oWIC;0onJS/H5oiR9`P?oUXBn0onDPK/2oi=m^0?o00001On?R<L4oi28a`?o
THW80onARlT4oi6=c0CoT93@0_n=UMH3odW9eP04oiYn/onFMjkoUWN^oiIg[PCoTW6Z0on?KJL3ohiZ
Y@?oSVRS0on>Ij44ohaUX0?oRF:O0on:HYh4ohaSW@?oTFFK0onEIYT4oiAUV0CoTV:F0on?GiD4oh]L
U@;oRUbF00?oV72ToiigYonNMjL00onNMjL4ojN1Z`?o[8J]0_n6EI02ohEFT@03ojMiX?n/OJ3o[7fP
00?o[7fP1?n]OZ44ol2I/0CoZWbR1?nRLYd2oim`W0?oaJRl1?nkU:l2ok:9Z@Co/?Ba0_oC`<P4oiaj
[@Go[Xfc0_nQS/03ok2@]@?oYXfk1?nKTLT00on_Vl?oYYc<ojJLc002ojJLc0?oWJCJ00?oZJ3=oj>S
e_nSXmH00onSXmH4oij[h0;oV[CY0_nT[ml5oj:diP;oXKWZ0_nU]><2ojBhi`03o`000?nT^>OoY;SW
00;oY;[Y0_nV^NL4ojJkj0;oYKcZ0_nW_>T5ojJmjP;oY[k[0_nW_n/Dooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02Oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool04oooool0
1?nma=oo]/?TokK3i?nf`n@5ok>ig@;o/:oG00?oYZcLoj>Te_nSY=H00_nSY=H3oj2Ld0CoWIC;0onJ
S/H2oiR9`P;oT8o?0on?S<`2ohn:bP?o00000_n>R<P7ohn8a`?oT8S70onARLP3oi6;b@GoTHg<0_n@
T=02of[Hl`;oWhJh0onJO[<4oiIg[P?oTW6Z0on?KJL3ohiZY@CoSVRS0on>Ij43ohaUX0?oRF:O1?n:
HYh3ohaSW@?oTFFK1?nEIYT3oiAUV0CoTV:F0on?GiD3oh]LU@04oi=/X_nHL:CoV72ToiQ`Y0GoWWNW
1?nWPJ/2ojb6[@?oQUF@00CoQEJAojMiX?nWNJ3oYgVP1?n/OJ04ojenX@04onSk^Oo0VK3o`9V`ol2I
/0GoZWbR0onRLYd00onOL9coaJRlolFX_002olFX_0Co^iB_00Co/XVYojJ3[_neRJOo]HVW1OnYOjH2
oiaj[@;o]i6_1?n^SK<00onQS/3o/92eok2@]@02ok2@]@CoYXfk00CoVi79ojnK`on_Vl?o[i_31OnV
W<`01?nMY=[oZJ3=ojVPcOnYX<d4oj>SeP;oWZ_P0onXZmT4ojB_g`;oX[CV0_nW/Ml5ojFdh`;oY;SW
00?o0000ojNhiOnV^NL01?nV^NL2ojJkj0;oYk_W1?nW_>T2ojJmjP?oYkkZ1?nW_n/Cooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02Oooool000Wooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool05Oooool4okK3i0;o/kWM
0_nX]^<4ojJ/g0CoXjCF0onPW=02oifDb`04oi>Ie_nBTm;oTY?Boi:CdPGoT8o?0_n?S<`2o`0000;o
Sh[:0on>R<P7ohn8a`?oT8S71?nARLP3oi6;b@;oTHg<0ommf?h2ojF?_P?oWhJh0_nJO[<01On<JZOo
RFNUohUWYOn9IjGoUWN^00?oTW6Z0on?KJL3ohiZY@CoSVRS0on>Ij43ohaUX0?oRF:O1?n:HYh3ohaS
W@?oTFFK1?nEIYT3oiAUV0CoTV:F0on?GiD01?n;G9GoTfbRoi=/X_nCK:84oiQ`Y0CoWWNW1?nWPJ/0
1On/QZgoQUF@ohIET?n6EI3oX7>O00CoYgVP1On/OJ02ojenX@;oj?^i0oo0VK05ojYlXP?oXW:M1Oo5
Z;`4ok^D[`04ojJ3[_neRJOo]HVWokF9Y`GoZGnV00CoW7Z]okNA[ongTJoo]i6_1?n^SK<5ok2@]@Co
YXfk1On_Vl<3ojJLc003ok:QaonYX<goZJ3=00?oZJ3=0_nSXmH00on^Z]?oZ:_IojR[f@04ojR[f@;o
Y:oO00?oZZoKojNagonW/Ml00onW/Ml2ojFdh`;oZKKS0onW^>D01?l0003oYkSUojJiionV^NL2ojRj
iPGoYk_W0_nW_>T2ojRmj@GoYkkZ0_nW_n/2ojS0ja?ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`09ooooo`002Oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q
8Oo^k^h01Oooool3o`0001Kooooo0_nf`n@3oj[0jP?oZ;KS1?nV[=`2oj>TeP04oiRUgonFW][oUYkJ
oiJNfPCoTiWF0onBTm83oi2?c`?o000000CoShc<ohn:b_n?R/[oSh[:0on>R<P8ohn8a`?oT8S70_nA
RLP2ohW8o0GoQM7o00CoOMSnojF?__nUSkkoTWB]0on?KjX3ohaZY`CoRFNU0on8IJ<3ohMTX`?oQV>S
0on7I:<01?n>J:?oSVNQohiWXOn>Ij43ohaUX0?oRF:O1?n:HYh3ohaSW@?oTFFK1?nEIYT3oiAUV0Co
TV:F0_n?GiD5oi=/XPCoV72T1?nNMjL4ojN1Z`03ohQFSon6EI3oQUF@00;oX7>O1?nWNJ05ojamX004
ojenXOoXnkWoj?^ionSk^@Co`9V`1?nZO:82oj9bW@;od=KN1Oo5Z;`2ok^D[`03ok:7YoneRJOo]HVW
00;o]HVW1OnYOjH4okNA[`Co[Xfc00?o_ibeok2@]On`T;D00on`T;D2ojJ=^`;o^Inn1?n_Vl<00onV
W<co/Z77ok:Qa`02ok:Qa`?oZJ3=00?o]:cAojjZdon^Z]<00_n^Z]<4ojR[f@03ojj`fOnZ[m_oZZoK
00;oZZoK0onW/Ml00on[]^7oZKKSojVfh`03ojVfh`?oYkSU00?o0000ojRji_nX^^H00onX^^H3ojNk
i`03ojRmj?nX_NWoZ;gY00?oZ;gY0_nW_^X2ojRojPGoZ<3[4Oooool3o`0000Oooooo00?o0000oooo
ooooool02Oooool000Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00Cooooo00?o0000ooooooooool06?ooool4oj[0jP?oZ;KS0_nV[=`00onI[>CoV:GOoiRUg`02oiRU
g`?oUYkJ0onCVMH3oi:CdP?o000000CoT8o?ohn<c?n?S<coShc<1?n?R/X3ohj8b0GoShS70on8]_@4
ohRnn@?oRLSl0_n5dOl3oiMj/@?oTWB]0on?KjX3ohaZY`CoRFNU0on8IJ<3ohMTX`?oQV>S1?n7I:<3
ohYVY0?oRFJU0on6IZL3oh9WZ`04ohYRW_n<HigoS6>MohaSW@?oTFFK1?nEIYT3oiAUV0;oTV:F0_nD
KZ@8oi=/XP?oV72T1OnNMjL2ojN1Z`;oR5J?00CoQUF@oj1cWonPLiooX7>O1?nWNJ05ojamX005ojen
XOn]QJ_o[HF[ok2</?oXnkT00oo0VK04ojYlXP04oj9bWOo@e]kod=KNom3FgPGoaJRl00?o^iB_ok:7
YonbQjL01?neRJL5ojUoYPGo]i6_0_n^SK<2oknL]@Go/92e00CoYXfkokVO__niWkko^Inn0on_Vl<0
0onjZ<Oo/Z77ok:Qa`03ok:Qa`03ojVPcOnd[=7o]:cA00;o]:cA1?n^Z]<00onXZmWo[[3Iojj`f@02
ojj`f@CoZZoK00CoYk7Ooj^fhOn[]^7oZkKQ1?nY]^<01OnW^>GoZK[UojVjiOl0003oZK[U00CoZ;[V
00?oYk_WojRmj?nX_NP00_nX_NP3ojRmj@03ojVoj_nX_n[oZ;oZ00?oZ;oZ1?nX`>/>ooooo`Co0000
00?oooooo`000?ooool01_ooool00ol0003oooooooooo`09ooooo`002Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`;oZ/3Z
00?oV[c`oiZdj_nJ]>X00_nJ]>X3oiV/i0?oV:GO1?nFW]X2oi>IeP?o000000?oTY?Boi2?con@Sll0
0_n@Sll3ohn<c0;oSh[:00?oQJKZohJZkOn6Z^d00_n6Z^d4ohN`l0CoR;Kd0_n8__T3okJ_dP03ok6U
c?nLP[KoW8:f00?oUgZa1?nBM:d3ohm_ZP?oS6ZW0on9IjD3ohQUX`?oQfBS0on6Hj<4ohMTX`?oRVJT
0on9IZD3ohIVY`CoPVN[0omnIjl3oi5UV`CoUFJI0_nDIIP00onBL:SoU6jToiA^Y002oiA^Y0SoTfbR
0onHL:@5oiigY`04ojN1Zon8EXooR5J?oiY^W`GoX7>O0onWNJ05ojamX0?o[HF[1OnfRJD2ojYlXP;o
Z7VO00?o0000om3Fg_o@e]h00_o@e]h2olFX_004okN;YonbQjOo/XNWok:7Y`;ocZNa0oneRJL4ojUo
YP;oaJ2c1?ngTJl01?n^SK?o_ibeoknL]OnoW;D4ok2@]@03ol:[`_niWkko^Inn00?o^Inn00Co[i_3
okZXaonjZ<Oo^ZS70onbXLL00onl]=;o]:cAokB/d@03okB/d@?o[Z[C00?o];?Hojj`fOn^/=T00on^
/=T2ojZ_f`;o[kOO1On[]^42ojVfh`;oZk[T0onY^^D01?l0003oZK[UojRji_nX^^H2ojVmj0CoZ;gX
00?oZ;gYojVoj_nY_nX00_nY_nX2ojRojP;oZL7[1OnX`>/:ooooo`?o00001Oooool00ol0003ooooo
ooooo`03ooooo`03oeEEEOmVIVKo000000_ooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo0_l0000Kooooo`?oV[c`1?nJ]>X3oiV/i0?o
V:GO0_nFW]X3o`0000;oQjGX0on6XnL4ohFSi`?oQJCX0on5Y^X4ohJZk@CoQk3`0_n8]_@2okZif0;o
]ZoB0_nQRk`3oib2]PCoUgZa0onBM:d3ohm_ZP?oS6ZW0on9IjD3ohQUX`CoQfBS0on6Hj<3ohMTX`?o
RVJT1?n9IZD3ohIVY`?oPVN[0omnIjl3ohA]/0CoSW6]0onBL:P4oiA^Y0SoTfbR0onHL:@5oiigY`04
oh]HSon8EXooVVjOoiY^W`GoX7>O0onWNJ05ojamX0?o[HF[1OnfRJD4ojQiW`;oWg6M0_o@e]h4okN;
Y`?o/XNW0_o>Yk44okF9Y`;oZGnV0oo5X;<4okNA[`Go_ibe0_n`T;D2ol:[`PCo^Inn00?oak[>okZX
aonjZ<L00onjZ<L01?nbXLOo_;CBokbdd_nl]=85okB/d@04ojjZdond/mSo];?HokBcf0?o[[3I00?o
/[[Pojnggon_]ml00on_]ml2oj^fh@;o[K_T1On[^^@2ojVji@03oj^niol0003oZKgX00CoZKgX0_nX
_NP2ojVoj@?oZKoZ1_nY`N/2ojS0j`;oZ<7[1_ooool4o`0000Sooooo00?o0000ooooooooool04Ooo
ool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1Oooool00ol0003oooooooooo`0Kooooo`?oV[c`0_nJ]>X00on</o3oRjo^oh^_kP02oh^_kP04ohZ[
jol0003o0000o`0000;oRJOY1?n7YNP3ohJSi`CoQJ?W0on5Y>P3ohFVjP;oQZ[]00?o_^[col7/l_nm
`=`00onm`=`2okZif003ojNC`OnQRkcoXH^l00;oXH^l0onLP[H4oiMj/@?oTWB]0on?KjX3ohaZY`?o
RFNU0on8IJ<4ohMTX`?oQV>S0on7I:<3ohYVY0CoRFJU0on6IZL4oh9WZ`;oOVN_0on4KK04ohia[@?o
TW2X1OnDKZ@7oi=/XPCoV72T0onNMjL00on;F8ooUV^NoiY^W`02oiY^W`GoX7>O1?nWNJ03ojamX003
ojV1ZOn]QJ_o[HF[00;obJNf1?nfRJD4ojQiW`;oWg6M0_nmU[05okN;Y`04ok:7Yoo>Yk7ocZNaoljW
/@Co]HVW00?oZGnVolFP/oo5X;<00_o5X;<4okNA[`03om2g`_noW;Go_ibe00;o_ibe00?o/92eol:[
`_o2Zl800_o2Zl82okVO_P?oak[>1?njZ<L5okbddP;o]:cA0_ni^m/5okBcf004ojj`fOnb^^3o/[[P
ok:jh0?o[kOO0_n`_nD4ojfki0;oZk[T0_n/_nP3oj^ni`04o`000?n[_^OoZKgXojVmj0;oZ/3Z1OnY
_nT00onY_n[oZL7[ojW1j`06ojW1j`CoZ<7[0_ooool3o`0000cooooo00?o0000ooooooooool04Ooo
ool002;ooooo00?o0000ooooooooool07Oooool3ohbgl`?oS;?`00CoRjo^o`000?l0003o00000on:
Zn/3ohVWj@CoQjGX0on6XnL2ohFSi`?oF<?j0_m6`Nd4okkZl`;o_/KP0onm`=`00on/W<OoYi?1ojNC
`@02ojNC`@?oXH^l1?nLP[H3oiMj/@?oTWB]0on?KjX3ohaZY`CoRFNU0on8IJ<3ohMTX`?oQV>S0on7
I:<3ohYVY0CoRFJU0on6IZL4oh9WZ`?oOVN_0on4KK04ohia[@?oTW2X1?nDKZ@7oi=/XPCoV72T0_nN
MjL3oiI[WPCoVVjO1?nPLil4ojMiX0;o[7fP0_nYPJT01?n]QJ_obJNfolVW]_o9YkH4okJ9Y@CoZ7VO
00CoWg6MokfF/?nmU[3o_IJ`1OngRjL01?nbQjOocZNaoljW/Oo>Yk44okF9Y`KoaJ2c0_ngTJl2om2g
`PCo_ibe1Oo2Zl800oniWkkoak[>olNjcP02olNjcP?o^ZS70_o1`]X3okbddP03okk<iOni^m_o^K_K
00?o^K_K0_nd/mP2okK1h`Go/[[P00?o[kOOok2oiOn`_nD00_n`_nD2ojfki0;o[L;Y1?n/_nP2oj^n
i`03oj_1j_l0003oZl7Z00CoZ/3Z0_nY_nT6ojW1j`03ojW2k?nY`N_oZL7[00?oZL7[1?nX`N/00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo01ko
oooo0on<]o<00on</o3o0000o`000002oh^_kP?oOKOh0omi^OX4ogBko0?oK[kn0omU`Oh2oeS3nP03
ock0^Onji_Co^^Kd00;o^^Kd00?o_^[cokk6h?nna^000_nna^001?nm`=co[9c7ojbLaon/W<L3ojNC
`@CoXH^l0onLP[H3oiMj/@?oTWB]0on?KjX3ohaZY`CoRFNU0on8IJ<3ohMTX`?oQV>S1?n7I:<3ohYV
Y0?oRFJU0on6IZL4oh9WZ`?oOVN_0on4KK04ohia[@?oTW2X1?nDKZ@8oi=/XP?oV72T00?oWWNWoiI[
W_nFJih00_nFJih4oiY^W`CoX7>O1?nWNJ001?n/OJ3oZH6YojV1ZOnYPJT4olVW]PGo]XVU0onXNIl4
okfF/0Go]h^W1?o>Yk44okF9Y`03om;1bOo5X;?oaJ2c00?oaJ2c00Co]i6_om2g`_o@]l;od;O20ono
W;D2om;:dP?o`Z_200?ocMoUolNjc_o7^/h01?o7^/h00onjZ<Oo`L;Jol72fP02ol72fP04okbdd_nn
c>Go_/cUokk<i@?o^K_K0_nebn/4okK1h`;o/[[P0_naaNT4ok2oi@03ojg6k?n]`^Wo[L;Y00?o[L;Y
0_n/_nP2oj_4k0?oZl7Z00Co0000oj_1j_nZ`>[oZ/3Z0_nY`^`5ojW1j`CoZL;/0_nY`N/2ojS1k0Go
Z<7[4?ooool00ol0003oooooooooo`0@ooooo`008_ooool2o`00023ooooo0ol00004oh2emPCoOKOh
0omi^OX2ogBko0?oJ/_m0_mJc?D3oeWCgP03oi;]l_nji_Co^^Kd00;o^^Kd0_nnbN<3okk6h003ok2U
c?n/W<Oo[9c700;o[9c70onWTl44oj6;_0?oW8:f1?nGN[43oi9d[@?oSfnZ0on<JZL3ohUWY@?oR6FS
0on7I:<3ohISX`CoQfBS0on:IZ@3ohUVY@?oQVJW1?n2Ij/3ogiW[`?oQ6f`1?n>LJd3oi9`Z0CoU6jT
2?nCK:82oiQ`Y0;oTfVN1OnFJih3oiY^W`CoX7>O1?nWNJ03ojV1Z@;ohO3I0oo9YkH5okJ9Y@;oZ7VO
0_o3/<L3okfF/0Co]h^W0_oYn/L4oljW/@;o]HVW0_oB`LT4olFP/`03ol[ocOo@]l;od;O200?od;O2
00?o_ibeom;:d_oBb]800_oBb]801?o2Zl;ocMoUolgOiOo=gnD4olNjcP03ol7Ok_o1`][o`L;J00;o
`L;J00?o]N7fokk<iOnnc>D00onnc>D00oni^m_o]L_[okG;j`02okG;j`;o]/7S0_n`cNl4ok75j@03
ok2oiOn]a^co[LK/00;o[LK/0on]`^T00on[a^koZlC/oj_4k003oj_4k0;oZl7Z00?oZLC]o`000?nY
`^`01?nY`^`2ojW1j`GoZL;/0_nX`^`4ojS1k0CoZ<7[4?ooool00ol0003oooooooooo`0@ooooo`00
8_ooool00ol0003oooooooooo`0Looooo`?o000000Cooooooh>dmOn3]?GoPkCe1?n0]OH2ogfgn0?o
OL7m0omeaol2of[;o@;oL=[f0onKj?/3okSPm003ok[Vm?nnbN?o_/WS00?o_/WS00Co_/KPok2Uc?n`
YLco/:G<0on/W<L4ojNC`@?oXH^l0onLP[H4oiMj/@?oTWB]0on?KjX3ohaZY`?oRFNU0on8IJ<4ohMT
X`?oQV>S0on7I:<3ohYVY0CoRFJU0on6IZL4oh9WZ`?oOVN_0_n4KK04ohia[@?oTW2X1?nDKZ@8oi=/
XP04oiQ`Y?nCJIkoTfVNoi=YWPGoUV^N0onJKYl5oj1cW`?oYgVP0_nYPJT3on7`f@CobJNf1?nfRJD0
1?nXNIoo`k37ol>`aoo3/<L4okfF/0;o]h^W0ooYn/L4oljW/@04okF9YooB`LWod/79om;1b@?oaJ2c
0oo:old3om2g`P03ojGfjOoBb];od/[B00;od/[B0_mHc[84olgOi@03olNjc_o1gnko`Mo^00;o`Mo^
00?o`L;JokGQm_nehOH00_nehOH2okk<i@;o[MWg1?nebn/00onXeOOo/<g_ok3=k`03ok3=k`;o/LGY
0_n[b_04ojg6k003ojg2jOn[a^koZlK^00;oZlK^0_n[a>`2ojW5kP?oZLC]00Co0000ojW4kOnY`^co
ZL;/0_nX`nd6ojW2k0CoZ<;/1?nX`N`4ojS1j`oooooo00?o0000ooooooooool04?ooool002;ooooo
00?o0000ooooooooool06Oooool3o`0000Kooooo0on7]_@4oh:kn@;oOL7m0on9c_h2ogoGo`CoWmom
00CoVnSkokSPm?nhh?Co^>3d1?nmb^@2okk9h`03ok>/dOn`YLco/:G<00;o/:G<1?n/W<L2ojNC`@04
oiV7_onDP;_oU82koiB0^`?oSgVg1?n:M;@3ohM`/P?oQ6ja0on2KK83ohUWY@?oR6FS1?n7I:<3ohIS
X`?oQfBS0on:IZ@4ohUVY@?oQVJW1?n2Ij/3ogiW[`?oQ6f`0on>LJd3oi9`Z0CoU6jT1onCK:82oi5X
W`CoTfVN1?nFJih3oiY^W`GoX7>O0_nWNJ000onTOJWoZH6Yon7`f@03on7`f@CobJNf0_nfRJD2oi7V
n`Co`k371?nmU[000ongRjOojO[7onWja`03onWja`;ocZNa0_mAajH4om;1b@03olFP/oo:olgob_o=
00;ob_o=00?od;O2ojGfjOnUm^T00_nUm^T00ooBb];oF<jboeS>/P03oeS>/P;ocMoU0omfhNd2ol7O
kP?oM^3a0_nehOH2ohcLo`Co[MWg00?o]L_[ojSEmonXeOL00_nXeOL2ok3=k`;oY/of1On[b_02ojg6
k0?oZLWa0_n[a^h2ojO7l0CoZLG^0_nYa>d00onXa>ko0000ojS3k@04ojS3k@;oZL;/0_nX`^d4ojS2
k003ojO2k?nX`NcoZ<7/00?oZ<7/0_nX`N/00onW`>_oooooooooo`0=ooooo`03o`000?oooooooooo
013ooooo000Rooooo`03o`000?oooooooooo01Kooooo0ol0000:ooooo`?oQkKd0_n2^oT3oho4n@;o
RLkn1?nQe?X2oioOo@;o]MWb0_nkbND4okg:i003okJce_nc[=7o/jcA00;o/jcA1?n`YL`2ojbLa`03
oij?`onIQkooVHNo00;oVHNo0onDP;/3ohmi]`?oRWBd0on7L;83ohA^/@?oPVfb0on2K[@3oh=b^0Co
QfBS0on6Hj<3ohMTX`?oRVJT1?n9IZD2ohIVY`;oPebL1?n1FY/2ogaGW0?oLUFR1?n>LJd3oi9`Z0Co
U6jT1OnCK:84oi5XW`?oTfVN1?nFJih3oiY^W`GoX7>O00?oYgVPojAmZOnORK`01?nSRk`01?nTT<7o
hO3IolVW]_o9YkH3ojInZ0;oTNKk1Oo3/<L2okfF/0CoZhbe00?o^Y>_ok:=[onbSJl00onbSJl01?nJ
QK_oDLNVom;1bOoB`LT3ojVD`0;o_9Zf1?nUT/400ommSm_oZIc9ojVLb@02ojVLb@CoR9oS0om5Vo@4
obbWk@?oBl7b1?n<g?l2ojgIm`?oT]Sn0_nXeOL2oi[@nPCoY/of0_n[b_03ojG<m0;oZLWa0_nUb?85
ojO7l0;oZLG^0_nWaNl3ojS4kP03o`000?nX`ngoZ<?]00;oYl?]1OnX`^d00onX`^coYl;/ojO2k002
ojO2k0;oZ<7/0_nW`N`4ojO0j`kooooo00?o0000ooooooooool04?ooool002;ooooo0_l0000Doooo
o`?o00003_ooool4oi>jlP;oSlCi1?nRbO@2oj7DnP?o/]7`00?o]MWbok_9iOnkbND00_nkbND00onm
b^Co][?FokJceP02okJcePCo/jcA0_n`YL`00onTUlSoWXo3oij?``02oij?``?oVHNo0onDP;/3ohmi
]`?oRWBd0on7L;84ohA^/@;oPVfb0on2K[@3oh=b^0CoPWNn0on1P<T3oh>Cf`KoQk7a00?oOM3oohIP
W_n6H9h00_n3G9`4oh5JV`;oO5NL1?mbEJ800om7D;SoKe>Rohia[@03oi9`Z0CoU6jT1?nCK:800on<
IJ3oTFROoi5XW`02oi5XW`?oTfVN1?nFJih3oiY^W`GoX7>O00CoY7fYoin9_?nORKcoWhVl0_nSRk`0
0onQO:[oYGjYojEnZ@02ojEnZ@CoYWjX00?oXGf[oi7Vnoo3/<L00oo3/<L00onmU[3o]Y2_okJ@[`02
oj^<]@?o^Y>_1?nbSJl5okNE]@04ojVD`?nlV[Ko_9ZfokbJ]P?oYI;100?o^InnojVLbOnYW<T00onY
W<T2ohROh`;oYIk?1On:X><3og6_m`CoGK[m0omdc_l2oi;HoP?oR/_m1?nJd?X2ojK?mP?oW/ch0_nU
c?@2oj78m0CoYLSb0_nWao02ojG6l0GoYlG_0_nXa>h00onW`nko0000ojO3k@03ojO3k@;oZ<;]0onW
`^d2ojO2k0OoYl7/1?nW`>/=ooooo`03o`000?oooooooooo013ooooo000Qooooo`;o00004_ooool3
o`0001;ooooo0_nC^_82oj>ok@CoX/Wd0_n`bN`3ok;Al0;o^LSV0onkbND00ong^=[o][?FokJceP04
okJceP;o/jcA00?oZ9o=ojBGb?nTUlP00_nTUlP3oij?``?oVHNo0onDP;/3ohmi]`CoRWBd0on7L;83
ohA^/@?oPVfb0on2K[@3oh=b^0CoPWNn0on1P<T3oh>Cf`CoQk7a00CoSFRSohIPW_n6H9koQV2N0on3
G9`3oh5JV`?oO5NL0ombEJ82odM@^004ofmCX_m`E:7oL5BQogYJX@CoU6jT0_nCK:83ohaUX0CoTFRO
0onCJIh4oiI[WPCoVVjO0onPLil2oib<`P?oWhVl00?oXh^loj5lZ_nQO:X01OnUOZT4ojInZ004oj5m
Zoo3/<Oo`k37okRC/@Co]Y2_00?oZhbeokZC[onjTjl00_njTjl3ok:=[`03olBQ]?ngUKGo]iFe00?o
]iFe1OnlV[H01?nUT/7o^InnokVO__niWkh3ojVLb@03okVS`onUW/ooYIk?00?oYIk?0_n:X><2ojFV
e`CoU:cW1?n3]?D4oh;2o0;oR/_m0_n?`_P4oiK9n@;oW/ch0_nLaO@5oj78m0;oYLSb0_nSaO44ojG6
l0;oYlG_0_nV`nl3ojO3kP04o`000?nW`nkoYl?]ojO3k@GoYl;]2?nW`N`2ojO0k0GoYl3[3?ooool0
0ol0003oooooooooo`0@ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`;o000000?o410@ooooooooool00oooool00ol0003oooooooooo`0?ooooo`;o00005_ooool4
oj>ok@03oj;9m?n`bNco/<W/00?o/<W/00?o/]7`okW8i_nib>H00_nib>H01?nkbNGo]kSJokNhf_ng
^=X4okJceP03ojfWd_nXWlgoZ9o=00;oZ9o=0onTUlP3oij?``CoVHNo0onDP;/3ohmi]`?oRWBd0on7
L;83ohA^/@?oPVfb0on2K[@3oh=b^0CoPWNn0on1P<T4oh>Cf`04ohNalOn=J:?oSFRSoheXX`?oQV2N
0on3G9`3oh5JV`?oO5NL0ombEJ83odM@^0;oL5BQ1?mjFZ43ohEQX@?oS6FP1?nAJ9l3oi=YWPCoUV^N
1?nJKYl2oj1cW`?oW8c20_nORK`00onIMj_oXGbZoj5lZP02oj5lZPCoYGjY1?nVOZP01?nQOJ_o^9>a
okRC/OnhTk44okJ@[`Go^Y>_0_nbSJl3olBQ]0?o]iFe0_o5Y;P4okbJ]PGo^Inn00CoZIc9okVS`oni
Xl?o^J?30onUW/l00ondYlcoYJKGojFVe`03ojFVe`CoU:cW0_n3]?D2oiV_i`CoT[Wa1?n?`_P2oiK9
n@;oV/7c1?nLaO@2oj78m0;oXLCa1OnSaO42ojG6l0;oY<?_1?nV`nl2ojO3kP03ojK2kOl0003oYl;]
00?oYl;]00?oY/7/ojO1k?nW`N`01OnW`N`6ojO0k0;oYl3[0_nW_n/=ooooo`03o`000?oooooooooo
00oooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0<ooooo`?o00006Oooool2oj>ok@Co[l;X0_n`bN`2okO5
i@?o^LSV0_nh_=d4okNhfP03okJce_n]Ym;o[JOB00;o[JOB0onXWld3ojBGb0CoWXo30onIQkl3oiB0
^`?oSgVg0on:M;@3ohM`/PCoQ6ja0_n2KK83oh9^]0?oPg:h1?n2Mkh4oh60b@;oPi?K0_mgH:/2og5K
ZP04oheXXon6H9koQV2NohIPWP?oPebL0on1FY/3ogaGW0CoLUFR0om7D;P2og1DX@?oNUZQ0on5HJ43
ohaUX0CoTFRO0onCJIh5oiI[WP?oVVjO00?oX7>Ooi5aZonALJ/00_nALJ/3oiUgZ`CoXGbZ1?nUOZT3
ojInZ003okVJ^?nhTk7o^9>a00;o^9>a1?nfT:l00oo5Y;So^Y>_okZC[`02okZC[`03ok:=[oo4XKCo
a:6d00;oa:6d0_ngUKD3olFT^0Co_9Zf00?obJblokVO__niWkh00_niWkh5okVS``04ojFNcondYlco
]:O<okBWc0CoYJKG0_nD[>L2ojF[f`GoVJoW0_nB^O42oijej0?oVK__1OnJ`O<2oic5m0;oWl3`1?nQ
a?42oj?5l@;oXl;_1OnT`nl2ojK3k`;oYL;]0onV`^d00ol0003oYl;]ojK1k003ojK1k0;oYl7/2OnW
`>`6ojNoj`cooooo00?o0000ooooooooool03oooool000Oooooo00Go410@oooooooooooooooooa0@
400;ooooo`Go00001Oooool2o`0000[ooooo0ol0000Mooooo`Co[l;X0_nf`n@4okO5i@03okW8i_nh
_=go^;cM00;o^;cM0_ng^=X00on`[mOo[JOBojfWdP03ojfWdPCoZ9o=0onTUlP2oij?``04oi>;b?n>
QLGoSXG5ohj5a@?oRH740on4OlD3oh1ob@?oQg2b1?n4K[43oh9]/P?oPVjd0on3L[P4oh9g_P;oPH39
0on0JJl2ogMPZ`?oLE^Z0on6H9h3oh=LW0?oPEZK0omlEi`4og9EXP;oAe2h0_nKMjT01?m`E:7oNUZQ
ogYJXOmjFZ43ohEQX@?oS6FP1?nAJ9l3oi=YWPGoUV^N0_nJKYl2ohY/Z`CoTG6[1?nIMj/3oj5lZPCo
YGjY0_nVOZP3okVJ^0Co^9>a0_nfT:l2olFT^0Co^Y>_1Oo4XK@00ongUKGoaJBholFT^002olFT^0?o
_9Zf0_o9[;`4okVO_P03olB/`_niXl?o^J?300;o^J?31OndYl`2ojFVe`03ok:[dOnUZm_oYJ_K00?o
YJ_K0_nI[nL2ojJ`g`GoW[GX0onI^nl2oi[1l`;oWkc]1OnO`?02oj74l@;oX[o^1?nS`^l2ojC3k`;o
YL7]1OnU`^d2ojK2k@03o`000?nV`>coY/3/00;oY/7/0_nV_n`6ojO0k0_oYko[2oooool00ol0003o
ooooooooo`0?ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoo
oooo00001_ooool00ol0003oooooooooo`06ooooo`?o00008Oooool00on_`^So]/?TokK3i003okK3
i0;o]lGU0_nh`>03okRlg@03ok:ffon`[mOo/:oG00;o/:oG1On]Ym82ojROc@04oijIconIT/_oVI;;
oiVBb`CoTh_80on>QLD3ohV1a0?oQ7o50_n0OlT3ogb4d0GoMi3N0_mXY_@3oh9^]0;oPg:h00CoZIk;
oiZ8_onJR;ooVXRo0on;M[H3oh1Y[`?oMf2[0_maFjX2ofaK[@04ohIPW_n3G9coPebLoh=LW0?oPEZK
0omlEi`4og9EXP05odM@^?mYFk3oIeFYofMEZOnKMjT00omjFZ43ohEQX@?oS6FP1?nAJ9l4oi=YWPCo
UV^N00?oVVjOohQ/[?n:K:/00_n:K:/3oi5aZ`CoVGN[0onQO:X4ojEnZ@03ojInZ?niV[So^IZh00;o
^IZh1?nhTk401?nfT:ooaJBholFT^?o5Y;P4okZC[`03ol^b`Oo4XKCoa:6d00;oa:6d1_o5Y;P01?nl
V[KobJblolV/_?o9[;`3okVO_P;oa:c20oniXl<2olB`a`Co]:O<1?nbZm43ojF[f`03ojn`fOnV/=oo
Y[3O00?oY[3O0_nN]NP2ojJdhPGoXKOX0onO_>d2oio0l0;oX[c/1OnR_nh2oj?2k`;oY;o/1?nU`Nd2
ojG2k@?oY[o/0_nV`>`00ol0003oY[o[ojJok004ojJok0;oYl3/3onW_n/:ooooo`03o`000?oooooo
oooo00oooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0
0006ooooo`03o`000?oooooooooo00?ooooo0ol0000Vooooo`?o]/?T0_nh`n<4okS0h004okRlgOnb
]]_o/[KKok:ff`Co/:oG0_n]Ym82oj>Qd`CoWYW?0onIT//3oi>;b0?oSXG50on9PL@3ohAoa@?oP7o9
0omlQ=05ogN@gP;oJ:Kd0_nh]ML3ojVNb`?oVXRo0on;M[H3oh1Y[`?oMf2[0_maFjX3ofaK[@?oPebL
1?n1FY/3ogaGW0?oLUFR0_mYFk03ofMEZ@;oQEnO00?oNUZQohEQXOn5HJ400_n5HJ43ohaUX0CoTFRO
0onCJIh3oiI[WP?oR6b/0on:K:/3oi5aZ`CoVGN[0onQO:X4ojEnZ@Go^IZh1?nhTk45olFT^0;o^Y>_
0_o;//44olBQ]003om?1bOo5Y;SoaJBh00?oaJBh1Oo9[;`00oniWkkoa:c2olB/`P02olB/`P04okVS
`oo4/<Ooa;37olB`a`?o]:O<0_nl/<h4ok:[d@04ojF[fon_/=Wo[k3Iojn`f@?oY[3O00?o[K?LojJd
h_nV]>800onV]>83oj6gj003ojNgi?nT^^SoY;[X00;oY;[X1?nR_>`2oj:okP;oYKg[1OnT_n`2ojG1
k@?oY[o[0_nV_n`2ojJnj`;oY[o[00Co0000ojJojonV_ncoY[o/4onW_n/:ooooo`03o`000?oooooo
oooo00oooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000005
ooooo`04o`000?ooooooooooooooo`?o0000:_ooool00onf`nCo^<?SokS3h`02okS3h`;o^<3P0_nd
_>04ok:ff`;o/:oG00?oYjWHoj>QdonSXM<00onSXM<3oijIc`?oVI;;0onCRlP3ohj5a@?oRH740on4
OlD3oh1ob@CoO8C@0_mgT=h3ol?<h@;o^;GG00CoVHFloheg]_n=MkKoSGNf0on3K;43oh]f]P?oP6V_
0omgH:/3og5KZP;oK5^]0_m]I;P00on3G9coPEZKoh5JV`02oh5JV`?oO5NL0_mbEJ800on_n<KoJE^`
ofUK/003ofMEZ@;oKE^/00?oQEnOohEQXOn5HJ400_n5HJ43ohaUX0CoTFRO0onCJIh00onFJikoTGVe
oi5i]@03ohQ/[0?oRVb[1?nALJ/3oiUgZ`CoXGbZ0_nUOZT2okRS``Go^IZh0_nhTk42om76c`CoaJBh
00Co^Y>_ol^b`Oo;//7obk;10oo4XK@2om?1b@CoaJBh00?ocko;olV/_?o9[;`00_o9[;`00ooA`lgo
a:c2olB/`P02olB/`P03olVmcoo4/<Ooa;3700?oa;3700Co]:O<okb`c_nl/<ko_;3>0onbZm42okVd
e0Co[k3I00CoY[3Oojfcg?n]/mco[K?L1?nV]>800onQ]nSoYkOTojNgi002ojNgi0CoY;[X0_nR_>`2
ojJkj0CoYKg[0_nT_n`3ojJmjP;oY[o[0_nW_^X5ojJnj`;oY[o[00?o0000ojNojonW_n/05?nW_n/9
ooooo`03o`000?oooooooooo00oooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0oo^k^koA4A4o`000005ooooo`Co0000;_ooool3okS3h`03okG3i?nd_>3o];cP00?o];cP0_nb]]/0
0onZ/MgoYjWHojNYf002ojNYf0CoXj7C1?nNVLl3oiVBb`?oTh_80on>QLD3ohV1a0?oQ7o50on0OlT2
ogb4d003od;3hOo6g>Woa]cY00;o`lcQ00?oY9C5oiV5_?nIQK`00_nIQK`2oheg]P?oPfba0omhI;04
oh1Y[`;oMf2[0omaFjX2ofaK[@?oKFBh1?n1FY/3ogaGW003og9EX_nRcOKoRX7300;oJE^`0omWEJT3
ofeK[0?oNeNL00CoQF6QohaUX?n<IJ3oS6FP1?nAJ9l2oi=YWP04og5Y^_nANKGoTGVeoi5i]@?oR6b/
0on:K:/4oi5aZ`CoVGN[0onQO:X01?nUOZWo^:?3okRS`onhXl<5okVJ^004okRC/OoAa/oodLK?om76
c`?oaJBh00?obN7Zol^b`Oo;//400oo;//401?o4XKCodl79om?1bOoC`LT3olFT^0?ocko;0_o9[;`3
om73c@;oa:c20oo9_Ll3olB`a`03olRndOnl/<ko_;3>00?o_;3>00?o/Z_AokVde?ni]=@00_ni]=@2
ojn`f@03okBefOn]/mco[K?L00?o[K?L0_nV]>82ojbfh@CoYkOT0_nT^^P2ojRiiPGoY[_X0_nU_N/3
ojNlj@;oY[gZ0_nW_NT4ojNnjP;oY[k[1?nW_^X01?l0003oYkkZojNojonW_n/2ojNnjQ7oYko[2Ooo
ool00ol0003oooooooooo`0?ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?o
MgMgo`000?ooool01?ooool2o`00037ooooo00Co^<?SokG3i?ne`nCo]L?T0ond_>000on]^N?oZ[7M
ojZag@02ojZag@CoYjWH1?nSXM<2oijIc`04oiBQgOn?WMcoSigLohnMg0?oRY_N1?n4W>83ognRj@Co
NJoe0_mZ`_h01?o5i^koa]cYolKLjOn^Y<h4ojBDa@?oVHFl0on=MkH2oh=//@?oN6B`0om_H[<00on0
JJooMf2[ogMPZ`03og5KZP?oK5^]0_m]I;P3ogR1d003oh5JVomlEicoO5NL00;oX/gf0_m]EZL3ofUK
/0?oIeFY0_m]Fj`3ogma^P;oLU>N0_nTXm@2oi5XW`03okk`l_n9RLgoRHW=00;oLFVj0omcIkH4ohQ/
[0;oRVb[1?nALJ/4oiUgZ`;oXGbZ00?o/:O?okRS`onhXl<00_nhXl<4okVJ^003ok3ijooAa/oodLK?
00?odLK?00CoaJBholWQj_o9hN[obN7Z0oo;//42okkgk`Codl7900?oaJBholnoboo?_l/00_o?_l/0
0oo9[;codL?=om73c@02om73c@03olB/`_o9_LoobKg?00;obKg?00?oa;37olRndOo8_]400_o8_]43
okb`cP03oknke_ni]=Co^KCD00;o^KCD00?o_;cJokBefOnd]MT00_nd]MT2ojfcg0;o/KSN1On/]^42
ojNgi0;oZkWS1?nX^NH2ojJkj0;oZ;_W1?nW_>T00onX_>SoYkgYojNmj@03ojNmj@;oYkkZ00?oZ;kY
ojNnj_nW_^X01OnW_^X00ol0003oYkkZojNnjP03ojNnjQ7oYko[2?ooool00ol0003oooooooooo`0?
ooooo`008_ooool00ol0003oooooooooo`0_ooooo`Co]L?T00Co];cPojfihon]^N?o[KWS1?nZ/Md2
ojNYf0;oWJcQ0onIY]l4oiBQg@?oSigL0on:Vmh4ohBLhP?oOj;Y0_mi[oD3olGVkP03okJdeon^Y<ko
[ZC>00;o[ZC>0onTU<D3oiV5_0?oSGNf0on3K;42ogQT/0CoKf:c0_mSI/000omgH:_oLE^Zog5KZP03
ofaK[@?oKFBh1OmhPM001OnRcOKoOVN^ofeFYom]EZOoFDbX00;oJE^`0omWEJT3ofeK[0;oOg6j1OnT
Xm@01?mhL;go]mG_ohV9cOn9RLd3og5Y^P;oLfNf0ommL;X01?n8K:coRVb[ohY/Zon:K:/3oi5aZ`;o
VGN[0_nUXm<4ok2Wc`Co^:?300?o^IZhok3ijon`nN/00_n`nN/2om76c`?oVi;:1?o9hNX00oo;//7o
__O_okkgk`02okkgk`;odl790_nhj_H3olnob`;oa>O_0ooA`ld00oo6f>SobKg?olVmc`03olVmc`Go
b;kA00?o_;3>oknke_no^mH00_no^mH00oni]=Co_;cJokblfP02okblfP;o];GI00?o][cNok6hg_na
^=h00ona^=h2ojbfh@;o[kWQ1On[^N<2ojRiiP;oZk_U1?nX^nL00onW_>WoZ;cXojRlj002ojRlj0?o
YkgY00?oZ;gXojRnjOnX_^T00_nX_^T2ojNnjP;oZ;kY0onW_^X01?l0003oYkkZojNnj_nW_^X2ojNo
jPooYko[00?oYl3[ooooooooool01oooool00ol0003oooooooooo`0>ooooo`008oooool00ol0003o
ooooooooo`0_ooooo`;o]L?T0_n^`NP4ojfih`;oZ[7M00?oXK;Uoif/hOnM[>400onM[>43oiVVg`Co
U:7M0on?WM`3ohZKgP;oQ9cR0_mGb_@00omNe/goSnoEokkYlP02okkYlP04olGVk_nf]=Oo][CGokJd
e`?o[ZC>0onTU<D4oiV5_0;oSGNf0on3K;43ogQT/0?oKf:c0omSI/03og5KZP;oK5^]0om]I;P4ogR1
d0?oOVN^0_m]EZL2oeU<Z004ofUK/?mWEJWoIeFYofMEZ@?oKE^/0omoLKX3ojBSe0?oN72m0_m[HK@0
0on9RLgoLFVjog5Y^P03og=W]P?oOG2j0on7Ol<2oi5aZ`03oiNCcOnUXm?oYJ?C00?oYJ?C1?n`Yll2
okRS``CoXY;40onQT/@3oi^BbP03ojFA`?nRU<KoXYC600;oXYC61?n?U=<2ofNBi`Co^>[f00?ocko;
olCWkoo4inl00_o4inl01?oA`lgoa]SXolKHj?o6f>P3olVmc`;oaM7S0oo8_]42ol?:g`?o_k_F00?o
_LGQokblf_nl_=X00onl_=X01?nd]MWo][cNokJlg_nf_=h3ok6hgP;o/kgQ1?n_^N42oj^ih`;o[KcT
1On[^nD2ojRki`;oZ[cW1?nX_>P00onW_NWoZ;gXojRmj002ojRmj0SoZ;kY0_nW_^X00ol0003oZ;kZ
ojNojP04ojNojP;oYko[0_nW_nX8ojNoj`CoYl3[2?ooool00ol0003oooooooooo`0>ooooo`009?oo
ool00ol0003oooooooooo`0_ooooo`Co[/7X0_n]^N<2oj>ij0?oXK;U1OnM[>43oiVVg`;oU:7M0_n9
^OD4oh2nn`;oLlKo0_mag^h00on<kNCo_^WbokkYlP02okkYlP;o^L3O1?nf]=L3ojjTcP?oY9C50onI
QK`3oheg]P;oPfba0omhI;03ofmR/`?oHfK00ollO^D3ofaK[@?oKFBh00CoN87@ofeT^?m]I;SoW8Nl
0_mnIjh3ofeFY`;oFDbX0omWEJT3ofeK[0CoOg6j00?oY:?DojfXdomhL;d00_mhL;d3of]Q]0;oLFVj
0omcIkH4oge`^P;oQgo31?nGTld4ojFSd`;o/:O?1?nTUlP4oj:Ba0CoXI;400CoVi;:ojFA`?nUTL3o
YI700onRU<H4ohnDd`;oIi;W0_nBW=T3ofVIk0;oa>O_0_mcfOT5olKHj003olVmcoo5dN?oaM7S00;o
aM7S00?ob;kAol?:goo3b]l00_o3b]l01?no^mKo_LGQokg5hOnmaN43okblfP;o^/?Q1?nf_=h00ona
^=ko/kgQok>mh@02ok>mh@;o[kWQ0_n`_N@4ojfli0;oZk_U0_n/_NH5ojZli`;oZ;cX0onY_NP2ojRm
j003ojVnjOnX_^WoZ;kY00GoZ;kY1?nX_^X01?l0003oZ;kZojNoj_nW_nX2ojRojPGoYkoZ0_nW_n/0
0onX_n_oYko[ojNoj`03ojNoj`;oYl3[0_nX`>/7ooooo`03o`000?oooooooooo00kooooo000Uoooo
o`;o0000<?ooool2ojk1j0;oY;o/1?nS^NP3oj6bi@;oWJcQ0onD]nl4ohnfl@?oRKWe0_n0__/2ogoJ
o@;oSn_c0onhioD00onnjO;o^L3OokW0g`03okW0g`;o][CG00CoXYg@oiVAbonITL_oVI7;0on>QLH3
ohAl``?oNGG30on3K;42ogQT/0CoKf:c0omSI/03ocani@;oY:7B0_m]I;P2oh9la0?oKFBh0_mnIjh3
ofeFY`;oFDbX0_m5FlD2ofMEZ@?oKE^/0_moLKX00ooPmM[o[JSCojfXd`03ogQ`_@?oJf6d0_mXHKL0
0omaJK[oLfNfog=W]P04oge`^P?oQgo31?nGTld2ojFSd`Co[ZG>1?nTUlP4oj:Ba0;oXI;400?oYHnn
ojFA`?nUTL000_nUTL04oj:DaP;oSiCC00?oY9[;oi:LfOnBW=T00onBW=T3ofVIk004obf?k_mcfOWo
LmWiog?In@;oa]SX0onKgod2olGAh`;o/MOd1?o3b]l00ongd^ko_LGQokg5h@03okg5h@03okblf_nj
`n7o^/?Q00;o^/?Q0_nf_=h2okG1i0?o/kgQ00?o//7Uok2mi?n`_N@00on`_N@2ojfli0;o[[kV1?n/
_NH2ojZli`;oZkkX1?nY_NP00onZ_^WoZKkYojVnj@02ojVnj@;oZ;kY0_nX_nT7ojRnjP03o`000?nX
_n[oZ;oZ00?oZ;oZ0_nW_nX6ojRoj`;oYko[1onX`>/6ooooo`03o`000?oooooooooo00kooooo000W
ooooo`03o`000?oooooooooo02kooooo1?nT_n`2oj>ij0?oV[[_0onG^>h4oiBgk`;oSkKa0_n=bO`3
ohSBo`?oT^Cl00CoSn_cokSWmOnhioGo^>Oe0_nkb>D4okW0g`03ojZYe_nRWM3oXYg@00;oXYg@0onI
TL/3ohj5aP?oQ7c30_miML<3ogAgb0?oN6B`0om_H[<4of=V`003ocaniOo2b^7oY:7B00?oY:7B0_n2
O<@3ofeT^0;oFEJd00?oOVN^ofeFYom]EZL00omIC:P3odEKa@?oKE^/00?oOg6jon3ef_nGYMl00omb
MLH3ogQ`_@;oJf6d0omXHKL3og=W]P?oOG2j1?n7Ol<2oiNCc@04omWVg_nm^mOo_K_Gokfke`?o[ZG>
1?nTUlP2oj:Ba0;oXHfo1?nUSkh4ojFA`0;oXYC600?o[IW3ojBJbonTV//00_nTV//4oi:Lf@CoJIW/
0ol]Snh2oc2Tl@;oVmom0om^bOh3ok7Gm003ol?:gongd^ko]m;^00;o]m;^0_nmaN42okK;jPCo^/?Q
00?o]<SYokG1i?ne`N@00one`N@01?nc_N7o//7Uok;1iOnb`ND2ok2mi0;o[l7W1On^_^H2ojbmiP;o
[;oX1?n[_^P00onY_NSoZ[kYojZnj@02ojZnj@;oZKkY0_nY_nT4ojRoj@;oZ;kZ1OnX_nX01?l0003o
Z;oZojRoj_nX_nX8ojRoj`[oZ<3[1_ooool00ol0003oooooooooo`0>ooooo`00:?ooool00ol0003o
ooooooooo`0^ooooo`;oY;o/0onK_Nl4oiZjk`?oUkS^0_nD]nl3oi74n0?oSLWl00CoR=;ooi;To?nB
i?coT^Cl0_nah_P2okS<j@Co^lSU00Co^L3OojZYe_nZZMKoZZWF1?nRWM03oiVAb`?oSXG60on4O<<3
ogUe``;oM7O80ombQ=H3ofmR/`;oHfK00_o@j>L3ol;:h@?oY:7B0on2O<@3ofeT^0;oFEJd0_m]EZL3
oeU<Z0CoAE_500?oXO?5om?ShooChn<00onGYMl2og9eaP03oeYN_?mhL;goN72m00;oJf6d0omXHKL3
ofmfbPCoOG2j0_n7Ol<01?n4i[coiOOBonGgd_oDe]X4okfke`?o[ZG>0_nTUlP00onMS<;oXHfooj6=
_`02oj6=_`CoYHnn0onUTL000on]Ul3o[IW3ojfI``02ojfI``CoY9[;0_nBW=T2ojFQd@?oSZ7P1Om[
X?02oe>Yn@CoGk[m1?nHe?`2okOBkP;oYm3f1?nfbnX00onj`n7o]<SYokC8j@02okC8j@;o]L7T0_na
aNT3ok;1i@;o[lCY1?n_`NL2ojjniP;o[L7X1On/_nP2oj^nj0;oZkoY0onZ_^T00onY`>[oZKoYojVo
j@03ojVoj@;oZ;oY2?nX_nX00ol0003oZ;o[ojRoj`05ojRoj`ooZ<3[1Oooool00ol0003ooooooooo
o`0>ooooo`00:Oooool00ol0003oooooooooo`0_ooooo`CoVkg_0_nJ^^l2oiJmlPCoU<3e0_nAa?P3
oiOAo0;oUM_n0on/f_P00onah_So^<cYokS<j@02okS<j@;o^lSU0_n_/]/4ojZYePCoXYg@0onITL/2
ohj5aP?oQ7c30omiML<3ogAgb0CoLXCF00GoMjofom3Xioo@j>Ood>SWojn/e@03oiR@b@?oPGRo0_mW
Hk/01?n2O<CoKFBhofeT^?m]I;P2oeUF]0;oIF[300GoKEJWoeU<Z?mIC:SoFDbXodEKa@02oj7ca@Co
dn?S0_nGYMl3og9eaP03oeYN_?mhL;goJf6d00;oJf6d0omXHKL3ofmfbP?oPZg`0_n4i[`2onGgdP?o
e=KJ0_nm^mL01?nVWlooWY;7oijBaonNT/L4oif<`PCoXHfo1?nUSkh01?nUTL3o[IO0ojfG`?n]Ul04
ojfI``;oY9[;00?o[io8ojFQdOnUXM400onUXM43ohjQh0;oJj3`0_n<Z>P3ogJ^m@CoGk[m0_nHe?`3
oh_:o@?oYm3f0_nfbnX3ojc=l@;o]<SY0_n^bNh4ok75j@03ok;1iOn_a>Wo[lCY00;o[lCY0_n_`NL2
ojg3jPCo[L7X0_n/_nP2oj_1j@GoZkoY00CoZ[kYojW0j_nY`>[oZL3Z0_nY_nT2ojW0jPOoZ;oZ00Go
Z<3[ojRojonX_n_oZ;o[o`000003ojRoja?oZ<3[1?ooool00ol0003oooooooooo`0>ooooo`00:_oo
ool2o`00037ooooo0onI_?04oiJmlP;oU<3e0onIbOP2oiOAo0?oZ=?f0_n/f_P3okG=k0;o^<cY0_na
^Ml4ojnbf`?oZZWF0_nRWM02oiBCd0?oS8g?0on1R=43ohAl``;oNGG31?mdMlP2og:4eP04ohkZ^oo?
mnOocoOWom3Xi`?o[jcE0onHT<T3oh5h_`;oIf>k0om]I;P3oeUF]0;oIF[30_mIC:P3oiF]i`03on?l
c_oChn?odn?S00;oXJ;F0_mYL<H3og9eaP;oFUjl0om[HK@3ofQQ]`CoKgK:00?oPZg`ohCV_?n4i[`0
0_oUmm83omCFfP03ok^ge_nVWlooYYo?00;oYYo?0onNT/L3oif<`PCoXHfo0onUSkh00onYU<3o[IO0
ojfG`002ojfG`0?o[IW300?o]:33ojnOb?n_WlP00_n_WlP3ojFQd@03ok6XconQYm[oXJOJ00;oXJOJ
1?n<Z>P4ogJ^m@?oKKKk0_n;b_d2ohS3n`CoV/ci0_n/cO42ojC;m0Go[/W^0_naaNT3ojg7k@;o[lCY
00?o[<K]ojg3j_n]`nX00on]`nX2ojg1j0;o[<?[1?n[`NT2oj^oj@?oZ/7Z0_nY`>X2ojW1j`CoZL3Z
0_nX_nX6ojS0j`;oZ;o[00?oZ<3[o`000?nX`>/05OnX`>/3ooooo`03o`000?oooooooooo00kooooo
000/ooooo`03o`000?oooooooooo02oooooo0onI_?02oiJmlP?oV/;d0_nIbOP2ojG;m0?oZ=?f0_na
bnd3okG=k0;o/[kS1?na^Ml2ojnbf`04ojBTe_nMVm;oWI_BoifKdPCoU9?@0on<SLl3oh68d@CoNHgJ
0_m[WNh2ogAgb003odfom_n<jOCoS^Zk00;ocoOW0_o1bN03ojn/e@?oV9390on1N;l2ofMS^`;oGFC1
0_m]I;P2oeUF]0?oIF[30onE[NL2on?lcPCoXJ;F0omYL<H2og9eaP;oFUjl0omUJl@4ofQQ]`;oKgK:
0_nSf_/00ooIolkoi?c9onClb@02on?[eP03omCFf_nk]mKo^kOF00CoYYo?0onNT/L3oif<`PCoXHfo
00CoYHnnojVD`?nYU<3oZIC01On]Ul001?n]VL?o]:33okBP`ondX<<4ojnOb004ojFQdOnaZ<oo/JS?
ok6Xc`CoXJOJ0_n<Z>P2oij]hP?oS;3^1Omn]_L3ohS3n`;oV/ci0_nFa_P4ojC;m0;o[/W^0_nWbO44
ojg7k@03ojS7l?n/a^go[<K]00;o[<K]0_n]`nX2oj_5k@Go[<?[0_n[`NT3oj[2j`;oZ/7Z00?oZL;[
ojW1jonY`N/00onY`N/2ojW0jP;oZ<7[2onX`>/00ol0003oZ<3[ojS0j`0DojS0j`?ooooo00?o0000
ooooooooool03Oooool002gooooo00?o0000ooooooooool0;oooool4oibmk`;oV/;d0_nTaO04ojG;
m003ojSCm_nabngo/L_]00;o/L_]00?o]Lg/ok:nhonb_^<00_nb_^<2ok6ig`03ojR/fOnTY=KoY:CF
00;oY:CF0onMVm84oiBCd0?oS8g?0on1R=44ogV=fP;oJig^0_n<jO@00on>j[_ocoOWologi`04ol79
h0?o[jcE0_nHT<T3oh5h_`?oIf>k0omMI<42oeUF]0CoIF[300?oUJgWon?lc_oSo<h00_o?f>04oj6R
eP;oJG360_mMI<400ombMLKoFUjloeYN_002ofE[a0KoQICJ00?oXm[komWoc_oIolh00_oTo<T00ooS
jmKodM;Jok^geP03ok^gePCoYYo?0onNT/L3oif<`P;oXHfo00?oXY32ojVD`?nYU<000onYU<03ojfG
`003ok>N`ondX<?o]:3300;o]:330on_WlP00ongZ<Wo/JS?ok6Xc`03ok6Xc`;oXJOJ0_n][=L4oij]
hP?oS;3^0_mn]_L2ohjglPGoS[og0onFa_P2ojC;m0?oWlSe0onWbO400on]angoZ<O`ojS7l002ojS7
l0;o[<K]0_nYa^l4oj_5k@;o[<?[0_nYa>`4oj[2j`03ojW3k?nY`^_oZL;[00;oZL;[0_nY`N/2ojS1
k0GoZ<7[0_nX`>/00onX`N_oZ<3[ojS0j`05ojS0j`03o`000?nX`>_oZ<3[01CoZ<3[0oooool00ol0
003oooooooooo`0=ooooo`00;_ooool00ol0003oooooooooo`0_ooooo`;oW;g_0_nT_nd4ojC5l0;o
YL_d0on^b>d2ok7;k@;o/L7U0onb_^<00on//]goZ:cIojR/f@02ojR/f@?oY:CF1?nMVm83oiBCd0?o
S8g?1?n1R=42ogV=fP?oRLgn00?oS>Wdol7ik?o1nN`00oo7gNT2ol79h004oj>WfOnAT]7oTI;Aoi6B
d@?oNWk<0on1N;l2ofMS^`?oGFC10omDOml2ofEZ``03ocVl]?oSo<kohoc>00CocmSP0onQX]H2ofU`
aP?oGFC10_mJG[`3ofE[a0CoQICJ0_nimO401?oIolkoi?c9onClbOoSjmH3om7BfP?o^kOF0_nVWll2
oiJCcP?oU8g80onIS<D4oj:@`PCoZIC00_n]Ul02ok>N``Go]:3300Co[io8okNXbOngZ<Wo]jS90ona
Z<l00onh[/oo[JcGojf/e`03ojf/e`;oWZgR0_nY/]l4oi^cj@?oS[Ob0_n>_oL2oiFml`CoU/?f0_nO
b?D2oik5m0GoXlOb0_nXao02ojG7l@CoZLK_0_n[aNd2ojS5kPCoZLC/00?oZ/;[ojW3k?nY`n`00_nY
`n`2ojW2j`;oZ<;/1?nX`N`2ojS1j`;oZ<7/1?nX`N/7ojS0j`03o`000?nX`>_oZ<3[01CoZ<3[0_oo
ool00ol0003oooooooooo`0=ooooo`00;oooool00ol0003oooooooooo`0_ooooo`CoY;o]0_nTaO03
ojc4k0;o[/S]0_n``^L4ok71i@04ok:nhon//]go[;;Mojbbg@CoZ:cI0onTY=H2oifKdP04oiFRg_n=
X>7oSJ3QohfPh@CoRJCV1On6/?42ohW=oP03oh?ZfOo1nNco`OW/00?oamgY00?o/[[Ooj>WfOnSYmT0
0_nSYmT3oi6Bd@;oNWk<0om^Ml/2ofMS^`CoGFC10omDOml00oo1nnWodoo@om?od002omgdg@;ocmSP
00CoWZ_OogV3dOmiPm7oNH?A0omYL<H2oeeT`@?oH6k:0omUJl@01On5U=[o^OGaokWelOnimO7ofOo>
00;oi?c900?ohn_Fom7Bf_oAd]X00_oAd]X2ok^geP03ojJUeOnFTlkoUY?>00;oUY?>1?nDSLP3oiV<
a@?oXY321?nYU<000on]Ul3o/ik3ok>N``02ok>N``?o]:3300?o^jW7okNXbOngZ<T00_ngZ<T00ona
Z<oo^:k?okR^c`02okR^c`?o[JcG00?o];;GojVbgonY/]l00onY/]l2oi^cj@03ojBfiOnJ^>goV[S]
00;oV[S]1?nE_O<2oiK3mP;oV/7c1?nNaO@2oj?7lP;oXLGb1OnUao42ojW6k`03ojK5konXaNkoZ<G^
00?oZ<G^0_nYa>`3ojS4kP;oZL?/00?oYl?]ojS2k?nX`^`00onX`^`8ojS1k0;oZ<7[0_nX`N`7ojS0
j`03o`000?nX`>_oZ<3[01?oZ<3[0_ooool00ol0003oooooooooo`0=ooooo`00<?ooool2o`00033o
oooo0_nT_nd2oj_1jP?o[<C/0_n_`^P4ok32i`;o/L7U0_n^^>44ojbbg@;oZ:cI00CoXJ_NoiZVg_nJ
Y]koVZKN1?nEX]h3ohfPh@CoRJCV0_n6/?42ohWUn@?o]_?c0oo5j>l01?o7gNWo/[[Ook:jgonb^]l3
oj>Wf@?oTI;A0omjO/`2ofigb`?oI7_E0omMI<400omDOmoo`O_Yol7kj@02om?od0;ogOCM0_o4d><3
oij[g`;oNH?A0_mEIlT01?mYL<KoGFC1oeeT`OmMI<42of1^bPGoPJC[00?o^OGaol;Yl?oJo=T00_oS
l]L2omgTf@;odM;J00?o^[cKojJUeOnVYMD00_nVYMD4oiJCcP?oU8g80onIS<D4oj:@`P;oZIC000?o
[I_4ok>N`oncW/<00oncW/<00ondX<?o^jW7ok^Ya`02ok^Ya`;o]jS900?o_K3=okR^conh[/l00onh
[/l00on][=Oo];;GokBbe`02okBbe`?oZK;O00?o[kKNojBfiOnT]^D00_nT]^D4oiZhk@;oUKgc0onL
_Nl3oi[1l`;oW/Gd0_nO`o84oj75lP;oYLOa0onTaO43ojK5k`;oZ<G^0onWa>l2ojS4kP;oYl?^1?nW
`nd2ojS2k0;oYl;]1onX`N`00onW`NcoZ<7/ojS1k003ojS1k0;oZ<3[0_nX`N`2ojS0j`03o`000?nX
`>_oZ<3[01CoZ<3[00?oooooo`000?ooool03_ooool003;ooooo00?o0000ooooooooool0;_ooool4
oj_1jP03ojc4k?n_`^So[l;X00;o[l;X0_n``^L2ojnlh`Co[[SQ0_n//]d00onU/>3oXJ_Noj6[gP02
oj6[gP?oVZKN1?nEX]h3ohfPh@;oRJCV0_n<d_l4ojSXnP04okKcloo5j>ooaNS_olGXk`;o^l[V1?nb
^]l3oj>Wf@?oTI;A0_mjO/`3ofigb`?oI7_E0on6/_800onIl/godoo@om?od002omgdg@Coa=3S0_nN
Zml3ogV3d@;oEFO90omMI<43of1^bP?oPJC[0_o2jO000ooJo=Woho;Gon?be`03omgTf@Co^[cK1?nV
YMD3oiJCcPCoU8g80onIS<D2oj:@`P03oj>Faon]VlCo[I_400;o[I_40oncW/<00onhZ<Wo^jW7ok^Y
a`03ok^Ya`04okNXbOnm/<go_K3=okf`c@?o^:k?0_nm]M84okBbe`03ojVbgon_]]ko[kKN00;o[kKN
0_nT]^D2oj^ii0CoX[[Z0_nL_Nl2oj:mk0CoW[o`1?nO`o82oj75lP?oX/Ca0_nTaO400onTa?3oYLC`
ojG4l003ojG4l0;oYlC_0_nV`nh4ojO3kP;oYl?]1_nW`^d2ojS1k0KoYl7/0_nX`N`3ojO1k0CoZ<7/
0_nX`>/01?l0003oYl7/ojS0jonX`>/2ojO1k0ooZ<3[00?oYl3[ooooool000003oooool003?ooooo
00?o0000ooooooooool0;_ooool2oj_1jP?o[/7X0_n_`^P2ojnoiPCo[kcS0_n^^>42ojRehP?oYK3P
1?nQZmh3oiZVgP;oUJ;N0_nB]^l4ohfom`04ohcBoonXj?[oZ>SjojSXnP?o^^Wd00?o^m?/ok_:i_nk
b^H00onkb^H2ok:jg`04oinReon?Tm?oSi?CohnCd`?oPXWB0om`Q=H2ofigb`CoI7_E00CoQ[;bohO=
o_o8n>[ob?SZ0_oInm`2omKWhP;oa=3S00CoYZkMogf;e_mmRmKoOH_F0_miPm42oeEWb@?oHgSC00Go
GFC1of1^b_mPK/[oH6k:oh6Tj`02ol;Yl003om[lfOoSl]Ooho;G00?ogNCI0_o>d]`4okZlf`;oYZGE
00CoUYWEoh^=d?n;SM3oRhg@1?n>S<d3oiN@bPCoXiK71?n]Vl@01?ncW/?o^:S9okRXbOnhZ<T4ok^Y
a`Go_K3=00?o^:k?okfed_nm]M800_nm]M82okBbe`;o^;SI0on_]]h2ok>jgPCoZkWT0_nR^^X2ojNk
j0CoX[g/0_nN_o02oj:okPCoXL;`0_nRa?42oj;2l0CoY<C`0_nUa?02ojC3k`GoY/?^0_nW`nh00onV
`^koYl;]ojO2k@05ojO2k@;oYl7]4onW`N`00ol0003oYl7/ojO1k003ojO1k0;oZ<3[0_nW`>/6ojS0
j`KoYl3[00?o0000ooooooooool03Oooool003Cooooo00?o0000ooooooooool0;_ooool5ojk1j0Co
[koV0_n__><2ojZji@CoZ;GR0onU/>02oj6[gP;oVk;W0onF/^X4oi:fk`;oSKog0_nQfO/3ok7Tn003
ok[Ym?nkdnco^m?/00;o^m?/0_nkb^H2ojZ`g0CoWj;G0on?Tm<3oh:9dP;oL8CF0omcV>L2ofAke@;o
Qlgn0_o8n>X2omWkg0;oe^OR00?o`/cRojJ^gOnV[]d00_nV[]d2ogf;eP?oJGW@0_mEIlT3of=hd`Co
TJ[W0_o3i>l2om[^h0;ogncK00?ogNCIolkBg?o>d]`00_o>d]`2okZlf`03ojN/f_nFVMGoUYWE00;o
UYWE0on;SM03ohj<c@CoUi3:0onSU/L3ojfKa003ok6Uc?nhZ<Wo^:S900;o^:S90onkZLL2oknbc@?o
_K3=0_o1^=43okfedP03oknke_nh^=Wo^;SI00?o^;SI00?o[kKNok>jg_nc^]h00_nc^]h2oj^ii003
ojnkhonW^nSoYk_X00?oYk_X0_nR_N`2ojJnj`CoX[o^0_nQ`_02oj?1kPCoX/;`0_nTa?02ojC2k`Co
Y<?_0_nV`nh2ojG2kPCoY/;^0_nW`^d2ojK1k@GoYl7]1_nW`N`2ojO0k0_oYl7/00?o0000ojO1k?nW
`N`00_nW`N`5ojO0j`;oZ<3[2?nW`>/00ooooooo0000ooooo`0>ooooo`00=Oooool2o`0002oooooo
1On^`NP2ojnoiP;oZkgW1?nZ^^D2ojRehP03oj>gionO]>OoWkCW00;oWkCW1?nK/^L3oiJbjP;oT[K_
0onLcOT01?nQfO_o/NChok7Tn?nai?P3okWGk`;o^m?/0_na_>84ojZ`g0?oWj;G0on?Tm<3oh:9dP?o
L8CF1?mcV>L00on7cOkob?SZolShjP02omWkg003omKWh_o2c>;o`/cR00;o`/cR0onV[]d3ogf;eP;o
JGW@0omMNMH3of=hd`04oi6Zioo3i>oo`nC_ol?Tk`;of^kP0ooOk=/2omSPg0;oc];L00?o_L;MojN/
f_nW[=X00_nW[=X3oiJIe@?oRhg@1?n>S<d3oiN@bPCoXiK700Co[I_4ok6Uc?naYLco/JG<1?nhZ<T0
0onkZLOo_k;=oknbc@02oknbc@03okf`cOo1^=7o`KSA00;o`KSA00Co_KGBoknke_no^mKo_k_F0onh
^=T00onj_=_o/k[Nok>jgP02ok>jgP03okJmgon_^n?o[k_S00;o[k_S0_nW^nP2oj^mi`GoY[k[0_nR
_nh00onU_ncoXl7^oj?1kP03oj?1kP;oX/;`0_nT`Nh4ojC2k`;oY<?_1_nU`^h2ojK2kPKoY/7]0_nW
`Nd3ojK1k0;oYl7/1_nW`>`2ojO1k0;oYl3/1_nW`N`00ol0003oYl7/ojO1k003ojO1k0;oYl3[0_nW
`>`6ojO0j`Kooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0;_ooool2
ojk1j0;oZl7Y1?n[_NL2ojZji@;oYK[X0onS]nL4oindi`;oVk;W0_nL_o04oi[3m0;oW<gi0_nXg?X2
ok?FlP?o^MO_0_ndaNH4ok6lhP?oZ[3L0_nOX]L01OnBW]_oQYOMohJGgOn6UmgoSi?C00?oPXWB0om`
Q=H2og>Hi`;oX]Kj0_nnm_000oo>k^[ob]kXol[Nj004ol;<hPCoYZkM0ommRmH2ofUid0?oGGWF1?n3
Z>d00oo3i>oof^kPom[^h003omo/f`;of>3L00?ocMCOokg2gOnm`]d00_nm`]d4ojN/fP?oUYWE0on;
SM03ohj<c@CoUi3:0_nSU/L00onUX=7o/JG<ok6Uc002ok6Uc0?o^:S90_nl/]03oknbc@03ol:kdoo1
^=7o`KSA00?o`KSA1Ono^mH01Onh^=Wo^[cKokZlfonj_=_o/k[N00Co][gO0_n_^n<2ok6ni0CoZkgW
0_nV_^/2ojVnj@CoYKo/0_nS`Nh2ojG0k@GoY<7^0_nT`^l2ojG1kPKoYL;^0_nU`Nd2ojK1k@;oY/3]
1OnV`Nd2ojK1k003ojK0k?nW`>coYl3/00_oYl3/0_nW`N`01OnW`>coYl7/ojO1k?nW`Nco000000Go
Yl7/1?nW`>`2ojO0j`Wooooo00?o0000ooooooooool03?ooool003Sooooo00?o0000ooooooooool0
;_ooool4oj_1j@;oZkgW0_nW_NT4ojFjj0?oXkOW0_nO]>L2oiflkPCoW;o`0_nJ`o@3oj?Bn003ojSL
n_nce_;o/mKb00;o/mKb00?o^MO_okC5i_ndaNH00_ndaNH2ok6lhP04ojF`gonLYmgoW:OMoibWg@Co
TYkK0on6Umd3oh:Kh`GoQJc_00CoX]Kjokkfl?o>k^[oc^kZ1?o:g^P2ol;<hP;oZKGR0on?W=`3off4
f@?oK8SL0omMNMH2oh>Xk@?o/M?b0_o9i^`00ooOk=_of>3LomSPg003olgDg`;o_L;M00?o[KKOoiNS
gOnGXmd00_nGXmd3ohVFf@?oPhoG0on9TMD4oiJHe0CoYJ3A1?naYL`00onhZ<Wo_;;@okbbd002okbb
d004oknbcOo2^m?o`[_Col:kd`?o`KSA0_o2_mL3oknkeP04ol31f_nj_=_o^[cKokZlf`;o^l7N1?nf
_Ml00on_^n?o/KkTok6ni002ok6ni0;oZkgW0_n^_nH4ojVnj@;oYKo/0_nW_n/4ojG0k@;oY<7^0onU
`>d2ojG1kP;oYL3/1_nU`Nd2ojG0k0CoY/3]0_nV`Nd6ojK0k13oYl3/0_nW`N`00onW`>co0000ojO1
k004ojO1k0;oYl3/3?ooool00ol0003oooooooooo`0<ooooo`00>Oooool00ol0003oooooooooo`0^
ooooo`;oZl7Y0_nW`>/4ojNmj@;oYK[X0_nR_N`4oj2lk@?oWKc^0_nL_o03oj3;mP;oXm;h0on]d_<2
ok?FlP?o/l[[0_ndaNH00on[^>?oYK3OojF`g`02ojF`g`?oW:OM1?nBW]/3ohJGg@?oPY_S0_n5[>l2
ojCKn`;o`>Sa0oo8iN`2ol[Nj0;o^/SU1?nY]N83ohnLg0?oKHCI0_m/R=`4oh6Sj@?o/M?b0_o9i^`2
om3Si@04omSPg?o=e=oocMCOolgDg`;o_lSR0on]]]l4oiNSg@?oRIKI0on3SmL3ohVAe@CoUYSD1?nU
X=42ok6Uc003okBae_nl/]3o_;;@00;o_;;@00?o_[gIol:kdoo2^m<00oo2^m<01Oo1^=7o`[oGol:o
eoo2_mOo_k_F00Co`<7J00?o^[cKok_1g_nk`Mh00_nk`Mh2okJmg`?o]l7R0_na_^@2ok;0i@Co[[oV
0_nY_^T2oj^oj@CoYko[0_nU`>d3ojO0k0;oYL3]00?oY[o/ojG0k?nU`>`00onU`>`2ojG1k@03ojFo
k?nU`>coYL3/00?oYL3/0_nV`>d2ojJok0KoY/3/0_nV_n`CojO0k003o`000?nW`NcoYl7/013ooooo
00?o0000ooooooooool03?ooool003[ooooo0_l0000_ooooo`CoYl3[0_nW_NT2oj>nk0CoX[g/0_nP
_>d2oj33l@CoWlKc0_nPboH3ojW>l`;o[M;c0onabnd2ok?:j`;o[[kU0on[^><4ojF`g`?oW:OM0_nB
W]/00on?YN?oRZWZohZYjP02ohZYjPCoTKgd00?oY=_kol3XlOo0j?400oo8iN`2ol;Ej0Co^/SU0_nY
]N801?nFYMooPiKMoh>FgOn3U]d3off4f@?oK8SL1?n1XnT00onado;obNK/om3Si@02om3Si@?oc]gT
00?ocMCOoko8h_nob>800_nob>83ojffg`?oUj?M1?n9U]T3oh>?e`;oRI7E1?nFV=@2ojFPd@;oYjcK
1?nd/MH00onl/]3o_[gIokjmf@02okjmf@?o`[_C00Co`/?Kol:oeoo2_mOo`[oG0_o2aM`3ol31fP;o
_lGO0onk`Mh00onka>7o]l7RokO1hP02okO1hP03okO3i?nb`>Go//3U00?o//3U0_n^_nH00on_`NOo
ZkoYoj^oj@03oj^oj@;oYko[0_nY`>X2ojO0k0;oZ;o[1?nV_n`2ojG0k0;oY[o[1?nU_n`2ojG0k0;o
Y[o[1OnV_n`2ojK0k003ojJojonV_ncoY[o/00?oY[o/0_nW`>`00onW`>_oYl3/ojO0k00=ojO0k003
o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool003cooooo00?o0000ooooooooool0
;Oooool2ojO0j`;oY;o]1?nS_^`2oj:mk0;oXL7_1?nP`o42oio6l`?oY/Wb0_nYc_<2ojg;k`?o/L_]
0_n_`^P4ojjni@?oZkSS0_nU/=l2oifZh0?oUJGQ0on?YN<4ohZYjP;oTKgd0_n[eoL3ok[Ql`03olSU
k?o2eNSo`]GX00;o`]GX0_njb>D2ojZfhP?oUZGO0on3U]d2ofn=h0?oOZ?Z00CoK8SLoh6SjOn1XnWo
YLSb0onmf>d01?o@hnGoc]gTolkMi?o>gN@2olODi0?o_lSR00?o/[kSoj2^hOnP[^400_nP[^42ohbN
g`CoPIKN0omnTmh3ohNJgP;oUYSD00?oUZ?NojN/fonW[=/00onW[=/2okBaeP03okFlgonn_MWo_[gI
00?o_[gI00?o`[_Col;3foo2`m/00_o2`m/00oo2_mOo`/GLol;5g002ol;5g003ol31f_noaMoo_lGO
00;o_lGO00Go^l7Nok_4hOnka>7o^lCQokO1hP04okO3i0;o//3U0_nb`^H4ojo1i`;oZkoY0on/`>P2
ojW0jP;oZ/3Y1?nX_n/2ojJok0;oYko[1?nV_n/2ojFok0KoY[o[0_nV_n`6ojJoj`;oY[o/0_nW_n/4
ojO0j`;oYl3/0_nW`>/6ojO0k0Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<
ooooo`00?Oooool00ol0003oooooooooo`0]ooooo`CoY;o]0_nS_^`2oj:okPCoXL7_0_nP`o43ojC6
l@;oY/Wb0_n[bNl4ojg;k`03ok7;kOn_`^So[l;X00;o[l;X0_n^_^D00onX]N?oXk3Qoj>`h@02oj>`
h@CoWJ[P0onEYN43ohnUh`;oRZWZ0onL`o<01?n[eoOo^^7cok[QlonjhO<3okkIkP;o`]GX0_nfaNH4
ojZfhP?oUZGO0on3U]d2ofn=h0CoOZ?Z00CoYLSbokgHkOnmf>go_MS]0oo6gNX00oo>gNCoamCTolOD
i002olODi004oko8h_nb_^?o/[kSok:nh`CoX:kQ0_n<W]l4oh6FgP?oOY?N0on7V]h3oiJSgPCoYjcK
00Co];7FokFlgone_=oo]KcO0onn_MT2okk6h@?o`/?K0_o1bN43ol;5g003ol39h_noaMoo_lGO00;o
_lGO00Co_LSSok_4hOnka>7o^lCQ0_nia^@3okO3i0;o]/GV1?nb`^H2ojo1i`?o[l;W0_n/`>P00on/
`NWoZ/3Yoj[0j@03oj[0j@;oZ;o[0_nX_nX4ojNoj`;oY[o[0_nW_^/6ojJoj`;oY[k[1_nV_n/6ojNo
j`;oYl3[0onW_n/3ojO0j`;oYl3/2Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00cooooo000nooooo`03o`000?oooooooooo02gooooo0_nT_nd3oj>ok@?oX[o^0_nQ`Nl3ojC3k`;o
Y<Ka0_nXa^l4oj_9k`;o[L__0on^`nX2ojo2j0;oZk[U0onX]N<4oj>`h@;oWJ[P00?oVZoVoiJ`jOnF
/>T00_nF/>T4oiNgkP;oW<?c0on/e_D01?njhO?o_]W^okkIk_nnfNh2okW>jPCo]/GV0_nZ]^801?nM
[N?oS:7RohbQh_n<XN83oh>Mi0?oP:?Y0_mnXnX3oiVml@04okgHkOo6gN[oa]gZolKMjP?oa]WW0_o7
e>@2okg;i@Co/[kS0_nP[^401?nFZnCoQIkTohFNi?n5W^@3oh6FgP?oOY?N1?n7V]h3oiJSgP;oYjcK
0_nW^>D4okFlg`03okjmfOnna^7o_/KQ00;o_/KQ00?o`/?Kol79hOo1bN400_o1bN401Oo2aMco`<WR
ol39h_o0bN;o_lGO00Co_LSS00?o^lCQokW6i?nia^@00_nia^@00ong`nCo]/GVokK5iP02okK5iP;o
//;V0_nba>L3ojo2i`03ojo3j?n/`NWo[<7Y00;o[<7Y1?nZ`>T5ojRojP;oYko[00?oYkoZojNnjonW
_^/00onW_^/2ojJoj`03ojJnj_nV_^_oY[k[00?oY[k[0_nV_n/00onW_^_oYko[ojNoj`09ojNoja3o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`00?oooool2o`0002oooooo
0_nS_nd2ojBok@CoXl7^0_nT`nl2ojO4kPCoZ<K_0_n[bNl3ojc4j`;o[/?Z0_n[_NH4oj^ji@?oZ;GS
0_nS/>42oijai@?oVZoV1?nF/>T2oiNgkP?oX/Sd0_n/e_D3okOGl@03okkIk_nic^[o^LkZ00;o^LkZ
0_nfaNH2ojVii@?oWJgS0on<XN83oh>Mi0CoP:?Y0_nI_O43ojc>lP05olKMj_o6fNOoa]WWolKIioo2
dnL01OnmbnD2ok:nh`03ojJhiOnFZnCoUZ_T00;oUZ_T0on5W^@3ogbJi0?oO9_V0on6Y>P4oiJ_j0Co
YkSU0_ne_=l3okG6i`;o_/KQ0_nlc>L2ol79h@?o_/kV0_o0bN83okg<iP;o_LSS0onkbnH2okW6i0;o
]lSW0onfaNH00onda^So//CWok;4i`03ok;4i`04ojo2ion_`nSo[l?Xojo3j0Co[<7Y1?nZ`>T2ojRo
jP;oZKoZ1?nW_nX2ojNnj`;oYkkZ1?nV_^X2ojJnj`?oYkkZ0onW_^/7ojNojaCooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0;ooooo`00@Oooool00ol0003oooooooooo`0]ooooo`Co
Y;o]0_nS`Nh2ojK1k@CoYlC^0_nXa^l3oj_3k0;o[<C[0_n/_nP4oj^miP;oZk[U00?oY[OUoj>diOnS
]>D00_nS]>D4oijai@?oVZoV0_nF/>T3oibnl0;oX/Sd0on]d?<2okOGl@?o^=;]0_nic^X00ona`nOo
ZKWUojVii@03ojVii@?oWJgS0on<XN83oh>Mi0;oP:?Y0_nC]o03ojc>lP?o]m?_00Coa]WWol;Cioo2
dnOo`]?W0_nmbnD2okC4iPCoY[SU1?nFZn@3ohFNi0?oO9[T0omlVnH3ohJTj0CoUZoX0_nW^>D00onW
`^go]LKWokG6i`02okG6i`04ok?=kOnlc>Oo_<cWokc<i`;o^M7/0onnc^H2ok_@jP?o_LcV0_njc^T3
ok_;iP03okS<jOngb>Oo]lSW00?o]lSW00Co]/GVokC6j?nda^So]<KX0_nba>L3ok75j0;o[l?X0_n^
`nT4ojc1j@CoZ/3Y1?nY_nX2ojNojP?oZ;kZ0onW_^X2ojJnjP_oYkkZ0_nW_n/Hooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool02oooool004;ooooo00?o0000ooooooooool0;Oooool2
ojBok@;oY[o/1?nV`Nd2ojO4kP;oZL;/0on[`n`2oj_0j@Co[;oX0_n[_NH2ojRjiP?oY[OU1?nS]>D2
oijai@;oWKKY1?nL^>`2oibnl0;oYLSb0on]d?<2ok;Bl0?o^=;]00?o]<WZok73iona`nL00_na`nL2
ojVii@;oX;;T0onFZ^@3ohZTiPCoRZWZ1?nC]o001On/c_;o]m?_okOCkongdnoo^]C]00?o`]?W0_nk
cNP4okC4iP;oY[SU0_nN/nL3oi2Yi`?oPZ7X1?mkX>X3ogbUk@?oQZk_0onF^O04ojO2k@03okG6ionc
cNgo/lg]00;o/lg]00?o_<cWokWAk?nidN`00_nidN`00onnc^Ko^m3Zok_@jP02ok_@jP03okg<i_nj
c^Wo^/kY00;o^/kY00Co^l_VokS<jOnhc>Wo^<cY0_ngb>L3okG9j@;o]<KX0_nbanT3ok75j003ok35
j_n^`nWo[/?Y00?o[/?Y0_n/`NT00on/`^[oZ/3Yoj[0j@03oj[0j@CoZKoZ0_nX_^X2ojRnj@KoYkkZ
0_nW_^T6ojNnjQgooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`00@ooo
ool00ol0003oooooooooo`0]ooooo`CoY[o/0_nV`Nd2ojS1j`CoZL;/00?oZl?/oj_0jOn[`>T00_n[
`>T2ojboj0;oZKcW1?nX^^H3ojJgi@;oXkCU0_nQ]^P4oiffj@;oW;S/0_nR`_04ojG8lP03ojg@lonb
d_3o/];`00;o/];`00Co^=;]okC9j_ndbN[o]<WZ0_na`nL2ojVjiPCoX;;T0onFZ^@3ohZTiPCoRZWZ
0_nC]o02ojC5l@03okOCkonje>go^]C]00;o^]C]00?o`]?Wok_=j?nkcNP00_nkcNP2okC4iP;oZkkW
1?nN/nL3oi2Yi`?oPZ7X1?mkX>X3ogbUk@?oQZk_0onF^O02ojO2k@?oY/Wb0_nccNd3ok3Al@;o^M7/
0oned^l2ok_@jP;o]m7]0_njc^T3okO?k0;o^<cY0onec>/2okG9j@;o/l[[1?nbanT01?naaNSo/<GZ
ok35j_n`aNX2ojk3j@;o[L?Z1?n/`^X2oj[0j@?oZ/3Z0_nY_nX2ojRojPCoZ;kY0_nW_^X6ojNnj@;o
YkkZ8?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0014ooooo`03o`00
0?oooooooooo02gooooo0_nV_n`2ojS0j`CoZ<7[0_nY`^`3oj[1jP;oZl3Y0_nY_^P4ojVli`;oZ;[V
0_nU^NL3oj>gi`CoXKKX0_nM]^T2oj2mkPCoX/;`0_nUb?82ojc>l@;o/];`0onbc>d2okC9jP;o[/7X
1?nY^^H3oj2bi0;oUZ[T0_nE[NL3ohn^j`CoU[O^0_nTaO43ojk=l0;o^]C]0onid>/2ok_=j0;o]<OX
1?n[_^L2oijci`;oV;;Y0on<ZnX3oh6Vk0?oOJS_0on0[_84ohVgm0CoUl7d0_nVbO83ojC>mP;o/=7a
00?o[M;cokGBkoned^l00_ned^l01?nbdo7o]m7]okOAkOngdNd2ok?Ak`?o]lo/0_nccnh3okG<j`03
ok;<kOncb^_o/l[[00?o/l[[0_nbanT2ok77j`;o/<GZ0_n^aN/4ojg3jP;o[<;Z0on[`^X2oj[0jP03
ojW0j_nX_n[oZ;oZ00?oZ;oZ0onX_^T7ojNnjBCooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`00AOooool2o`0002oooooo0onX`>/2ojS1j`GoZ/7Z0_nZ_nT4ojVnj0;oZKcW
0_nW^nP4ojFii`?oXkOW0_nQ]^P00onQ_>coX;g^oj2mkP03oj2mkP;oX/;`0_nWbO42ojc>l@?o/<c^
0_nbc>d2ojo5jPCo[/7X0_nY^^H2oj:fiP?oVk3V1?nE[NL3ohn^j`;oU[O^0onP`_02ojk=l0?o/lk^
0_nid>/2okK<j`Co]<OX0_n[_^L2ojBkj@CoV;;Y0on<ZnX3oh6Vk0?oOJS_0on0[_84ohVgm0;oUl7d
0_nHaoP2ojC>mP;oY=3g1?n]d_<00oned^oo/]?aok;Cl@02ok;Cl@03okOAkOncdNoo/m7_00;o/m7_
00?o]lo/ok??k_nccnh00_nccnh01?nec>_o//c]ok;<kOnbc>d2ok?:j`?o/L[]0_naan/2ojo7k0Co
[/G[0_n]`nX3ojc3j`;oZl;Z00?oZ/7[ojW0j_nY`>X00_nY`>X4ojRojPCoZ;kY0_nW_^TYooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool004Oooooo00?o0000ooooooooool0
;Oooool4ojW0jP;oZ/7Z0_nZ`>X4ojZoj@;oZKkX0_nX_NP4ojNkj0;oYKWW00?oY;_Zoj:kjonR^n/0
0_nR^n/3oj6lk0;oX;g^0onTa?02ojO9l@?oZl[_0_n`c>h2ojo8k0Co[lGZ0_n^`NP2ojRki`CoX[KV
0onK/>H2oiF]i`;oUk?[1?nG]nh2oj32l0;oZ<S`0oncc^h2okC>k@Co]/c[0_ndanP2ojg3j@CoY;_Y
0_nH/^T01?nD/^_oRjk]oh^^kOn;[^d4ohB/k`?oPJob0on4]_D4ohbnm`;oV<Oh0_nJboP4ojC@m`;o
[M;c0on[doD2ok;Cl@?o[m;b0_ncdNl2ok3Al@;o/lo^0onac^l2ok;<k@;o/<c^0onab^d00on^b^ko
[lO/ojo7k003ojo7k0;o[/G[0_n/aN`2ojc3j`;oZ/?/1?nZ`N/2ojW0jP;oZ<3[1?nX_nX2ojRnjBco
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`00B?ooool00ol0003ooooo
ooooo`0]ooooo`CoZL3Z1?nZ`>X2ojZoj@;oZ;kY1?nX_NP2ojNkj003ojFlj_nT^n[oY;_Z00;oY;_Z
0_nR^n/2oj>ok@CoXl7^0_nTa?03ojS7k`;oZl[_0_n]b>h4ojo8k0;o[lGZ0_n[_nP4ojRki`;oX[KV
0_nO]>L3oiVbj0CoUk?[0_nG]nh2oinok`CoZ<S`00?o/lk^okC>kOndc^d00_ndc^d2okK<j`;o/LS[
0_n]`nT2ojRojP?oWkWZ1?nD/^/3oh^^k@CoQ:c_0on1[o83ohBfm@;oS;kg0on@`oP3oi[;n0;oY=3g
0onSdOL2oj_Cm@;oZM;e0_n_d_83ojgAl`;o/=7a0on^d?82ok7>k`;o[/k`1?n`c>h01?nab^go[/[^
ojk:k_n^b^h2ojo7k0?o[LO]0_n/aN`2oj_5k@CoZ/?/0_nZ`N/2ojS1j`CoZ<3[0_nX_nX`ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool004Wooooo00?o0000ooooooooool0
;Oooool4ojW0jP;oZ/3Z0_nY_nX4ojRnj@;oZ;gX00?oY[gZojFlj_nU_>X00_nU_>X2ojBkjP;oY;k/
1?nS_nd2oj?1kP;oY/C_0onXanl2oj_7kPCo[LS^0_n_b>`2ojg3jPCoZkoX0_nX^nL2ojBhi`CoWkCW
0onI/^P2oiNcj`;oW;[]1?nO_nl2ojS8l0;o[<__0_ndc^d3ok;;k0;o/LS[0_n]aN/4ojRojP?oWkWZ
0_nD/^/2oi>dk@?oSK;_0on7/_44ohNfm0CoR[cg0_n@`oP00onDaoWoW<gioic=n@03oic=n@;oXm7g
0_nTd?L2ojWBm@?oZ=7f0_n]dO<3oj_@m0;o[]3b00?o[<obojk>l?n^c_000on^c_02ok3<kP;o[Lc_
0_n^b^h3ojc9k`;o[LO]0_n[anh4oj_5k@;oZ/?/00?oZL?/ojS1jonX`N/00onX`N/2ojS0jcCooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00B_ooool2o`0002kooooo0_nY
`>X2ojW0j`CoZKoZ0_nX_^T2ojNnjP?oY[gZ0_nU_>X2ojBnj`CoY;k/0_nS_nd3ojG2kP?oY/C_00?o
Z<O_oj_7k_n[anh00_n[anh2ojg8kP;o[<C/1?n]`nX2oj^oj0;oYk_X1?nT^>L2oindi`03oijfjOnK
]^_oVkK[00?oVkK[0onL^^d2oinok`;oYLG`0_n/bnl2ojk:kP?o//_/0_n_b>`4ojg5j`;oZ;oZ0_nT
_N/4oibhk0?oTkC]0on=/^l3ohNbl@;oQkKd0_n<^oH4oho1n0?oU<Oi0_nLcOT3oig=n0GoY=3g0_nX
dOH2ojO@m@?oZm3d00?oZLodojc?l_n/co800_n/co82ojk>l0?o[<ga0_n]c>l3oj_;l0;o[<W_00?o
Z/W`oj_7k_n[anh00on[anh2oj_5k@03ojW5k_nY`ncoZL?/00;oZL?/0_nX`N/iooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02_ooool004cooooo00?o0000ooooooooool0;?ooool4
ojW0j`;oZKoZ0onW_n/3ojNnjP04ojJmj_nU_^_oYKk[ojFnj`?oY;k[0_nT_^`3ojG1k@;oYL;^0_nW
a>h4ojS6k`;oZlO^0_n[aN`4ojc4k0;o[L?Z0onY_nT3ojNkj0;oY;SW00?oXKSYoijfjOnN]^T00_nN
]^T2oi^fj`;oW[_]1?nQ_nl2ojG5l0;oZLO_1?n^b^h00onbbnco[lS/ojo8k002ojo8k0;o[LG[0_nY
`^`4ojBmj`;oW;S/00?oV[S]oiBfkonD]^l00_nD]^l4ohnel@?oS;Oc0on<^oH2oho1n0?oU<Cg0onH
bOP2oig=n0?oWlkh0_nTd?L2ojC?mPCoYm3e00CoZm3dojW?m?nYcoCoZLod0_n/co83oj[>l`;o[<ga
0onZc?82oj_;l003ojW;lOnZbO3oZ/W`00;oZ/W`0_n[anh3ojS6k`?oZLG^0_nY`n`looooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02_ooool004gooooo00?o0000ooooooooool0;?oo
ool2ojW0j`?oYl3[0_nW_n/00onV_n_oY[k[ojJnj`02ojJnj`;oYKk[0_nU_n`4ojG0k@;oYL7]0_nV
`nh4ojO4kP;oZ<K_0_nZaNd4oj_5k0;o[<C/0onZ`NX2ojVoj@03ojNljOnT^^SoY;[X00;oY;[X0onQ
^>T2oijfj@;oWkW[1?nN^nd2oj6ok`;oYL?_1?nYanl2ojk:kP?o[/W^0_n_b>`2ojc5k0CoZL;/0_nT
_N/00onQ_>coV[S]oiZhk@02oiZhk@CoU;K_0_n?]O401?nB^O;oT;_doi2km?n@^o@5oi6omP;oU<Cg
00?oV<Kgoi_:n?nKb_P00_nKb_P2oio>n0?oXLgg0_nTcoH2ojC>mPCoYloe0_nYco@3ojS>m0;oZ/kc
0_nYcO<2oj[<lP;oZ<cb1?nYbo42oj[9l0?oZ<S`0_nXa^m3ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02_ooool004kooooo00?o0000ooooooooool0;Oooool2ojO0j`03ojO0k?nV
_n_oY[o[00;oY[o[0_nV_^/2ojJok0CoYKo/0_nU`>d2ojK2k@CoY/?^0_nWa>h3ojS4k@?oZ/G]0_n[
aN`3oj_2j`;oZ/7Z00?oZ;kYojNljOnW_>T00_nW_>T2ojBjj0;oXk[Y0onP^NX4oinij`;oW[_]0_nR
_nh4ojG3k`;oZLO_0on[b>l2ojk9kP;o[LO]1?n/aN`2ojW2k0;oY[o/0onQ_>`2oiZhk@;oV[W^1?nE
^?03oi:ilP?oT;_d0_nA_oH3oiG2mP?oV<Kg0_nKb_P3oig;m`;oXLgg0_nRcOH4ojC>mP;oYloe0onV
c_D2ojS>m0;oYlkd0_nYcO<2ojO=l`CoZ<cb0_nYbo43ojS:lP;oZ<S`Aoooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00[ooooo001?ooooo`;o0000;_ooool3ojO0k0;oY[o[1_nV_n`2
ojFok0;oY/7]1?nV`^d2ojK3kP?oZ<?]0_nXa>d2ojW3k0CoZ/?/0_n[`^/00onY`>[oZ;kYojRnj@02
ojRnj@;oYkcY0_nU^nT4oj>jj@?oX;WZ0_nO^N/3oj6mk@?oX[o^0_nU`nl3ojS6k`;oZlS_00?o[<O^
ojg7kOn]and00on]and2ojc5k0;oZ/?/0_nV_n`2ojBnk0CoWkc]0onJ^Nh2oiFhl0;oUk_`0onE_?84
oiBnm0;oUL;f0_nIa?H4oi_8m`;oWL_g0onOboH3oj;=mP;oY<kf0_nTc_D2ojK>m@?oY/kd0_nWc_@2
ojK=m0CoYlgc0_nXc?82ojO;l`;oZ<[bC?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00[ooooo001Aooooo`03o`000?oooooooooo02cooooo00?oYl3/ojJok?nV_n`01_nV_n`2ojK0
k0CoY/7]0_nV`^d3ojO2k@;oZ<?]0_nX`n`4ojW3k0;oZ/?/00?oZL7[ojW0j_nY`>X00_nY`>X2ojRn
j@;oYkgY1?nU^nT2oj>jj@;oXk_[1?nQ^n`2oj6mk@;oXl3^1?nU`nh2ojS6k`03ojW6k_n/anko[<O^
00;o[<O^0_n]and3oj_5k@;oZ/?/0_nW`N`4ojBnk0;oWkc]0_nN_>d3oi^kk`CoUk_`0onE_?82oiBn
m0?oV<7d0onIa?H2oi_8m`;oW/Wf0_nOboH2oj7;mPCoXlgf0_nTc_D3ojG=m@;oY/kd1_nVcO@2ojO=
l`;oY/cc0_nWbo=?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool005;o
oooo00?o0000ooooooooool0:oooool6ojJok0KoY/3/0_nV`Nd3ojO1k@;oYl;]0_nX`^`4ojS3k0;o
ZL?/1OnY`N/2ojW0jP;oZ;kY1?nW_NT2ojFkj@;oY;cZ1?nS^n/2oj6kk0;oXkk]1?nS`>h2ojG3kP03
ojO4k_nYa^koZLK^00;oZLK^0_n/anh3oj_6k@;oZlG]0_nY`n`4ojO1k0;oY;k/0_nS_N`4oijlk@?o
Vk__0_nG^o000onI_O7oV;kboiRnlP03oiRnlP;oV<7d00?oVl?doic6mOnLa_D00_nLa_D2oik9mP;o
X<We1?nQboH2oj?=mP?oY<ce1?nUcOD8ojK=m0;oY/ccDoooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00[ooooo001Cooooo`03o`000?oooooooooo02_ooooo1OnV_n`4ojK0k0CoY/7/
0_nW`Nd2ojO1k0CoZ<;/0_nX`n`7ojW1j`?oZ;oZ0onX_^T2ojNmj@;oYKcZ1?nT_>X2oj>kj`;oXkg/
1?nS_^d2oj?0kP;oY/;^0onWa>h2ojW6kP?oZ/K^0_n[a^d2oj_4k@CoZL?/0_nW`N`00onV_ncoXkg/
oj>mk003oj>mk0;oW[c]00?oWkc^oiblkonL_>l00_nL_>l3oiVml@;oV;kb0onK`O83oi_3m0;oW<Ke
0onNao@3oj39m@;oXL_f0onRboD4ojC<m@;oYLge1_nUcO@2ojK=m5Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`09ooooo`00E?ooool2o`0002gooooo1?nV_n`4ojK0k0;oY/7/1_nW
`N`2ojS2k003ojS1k?nY`N_oZL7[00CoZL7[0onX`>X2ojRojP;oYkkZ1?nV_NX3ojFljP;oY;cZ0onT
_N/3oj>mk0;oXkk]0_nU`>d2ojK2kP;oYl?^1?nYaNh2oj[6kP;oZ/G]1?n[a>d2ojW3k0;oZ<7/0onV
_n`2oj>mk0?oX[g/0onO_>h2oiblk`;oWKg_1?nL_o42oi_1lP;oW/;b1?nNaO<2oik7m003oj78m?nR
b_CoX/[d00;oX/[d0_nRboD3ojC;m0;oY<ce0_nUc?@6ojG=m5[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`09ooooo`00E_ooool00ol0003oooooooooo`0[ooooo`CoY[o/0_nV`>`2
ojO0k0KoYl7/1OnX`N`2ojW1j`?oZ<3[0_nX`>X2ojRojPCoYkkZ1?nV_NX4ojFmjP;oY;g[00?oY;k/
ojBok?nT_n`00_nT_n`2ojG0k@;oY/;]1?nW`nh2ojW5kP;oZLC]1?nZaNd2oj_4k@;oZL?/0_nX`N`2
ojO0j`CoYKo/1?nR_N`4oinmkP?oWKg_0_nL_o42oik0l0CoW/;b0_nNaO<2oj36l`?oXLSd0_nRb_@3
oj?:m0GoY<_d0onUc?@2ojG=m5kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09
ooooo`00Eoooool00ol0003oooooooooo`0[ooooo`;oY[o/0onW`>/3ojO0k0;oYl7/1OnX`N`7ojS0
j`KoZ;oZ1?nW_^X4ojJmjP;oYKgZ00?oYKk[ojBnk?nT_^`00_nT_^`2ojBok0;oY/7]1?nV`^d2ojO3
kP?oZ<C]0onYa>d2oj[5k@;oZ/?/0_nY`n`2ojS1j`CoYl3[0_nU_n`2ojBnk0CoX[g/0_nO_Nh00onQ
_^koWko_oinok`02oinok`CoW/3`0_nN`_82oj34lP;oX<Kc0_nRa_84oj?8l`;oXl[d0_nTb_<2ojC;
m6Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`00F?ooool00ol0003o
ooooooooo`0/ooooo`SoYl3[0_nX`N`9ojS0j`KoZ;oZ1_nW_^X2ojJmjP03ojJnjonU_^_oYKk[00;o
YKk[0_nT_^`2ojFok0CoY/7]0_nV`^d3ojO3k@;oZ<C]00?oZL?]oj[4k?nZa>`00_nZa>`2oj[3k0;o
ZL;[1?nX`N/2ojO0j`;oY[o[1?nT_^`2oj:mk003oj>nk?nQ_^koXKk^00;oXKk^0_nO_nl2oj70k`Co
X<;`0_nPa?82oj;5l@CoX/Kb0_nSb?<2ojC9l`;oY<[cJ_ooool01Ol0003ooooooooooooooooo0000
00_ooooo001Iooooo`03o`000?oooooooooo02cooooo1_nW`>/=ojS0j`CoZ;oZ1_nW_^X00onV_^[o
Y[k[ojJnj`02ojJnj`;oYKk[0onV_n`3ojFok0;oY/7]0onW`^d2ojO3k@03ojS3kOnY`ngoZL?]00;o
ZL?]0_nZa>`2ojW2k0CoZL;[0_nX`N/3ojS0j`?oY[o[0_nT_^`2ojBnj`?oXkk/0_nQ_^h2oj:ok@Co
XL3_0_nP`_03oj?3l0?oX/Ga0_nRa_82ojC7lP;oY<WcKOooool01Ol0003ooooooooooooooooo0000
00_ooooo001Jooooo`;o0000;Oooool2ojO0j`ooZ<3[1_nX_nX4ojNnjP?oY[kZ1OnV_^/2ojJok0;o
Y/3/1?nV`N`2ojO2k@03ojS2k?nX`ngoZ<?]00;oZ<?]0_nY`nd6ojW2k0;oZL;[0onY`N/2ojS0j`03
ojNoj_nV_^_oY[k[00;oY[k[0_nT_^/2ojFnj`CoY;k/0onR_nd2oj70k`?oXl7^0_nS`o000onU`noo
YLG`ojG5l002ojG5l0;oY<ObLOooool01?l0003oooooooooool0000;ooooo`00G?ooool00ol0003o
ooooooooo`0[ooooo`goZ<3[0onX_n/2ojRojP;oYkoZ1OnW_^X2ojNnj`KoY[k[0_nV_n`4ojK0k0;o
Y/7/00?oYl7/ojS2k?nX`^`00_nX`^`2ojS3k@SoZL;/1OnY`N/00onX_n[oYkoZojNojP02ojNojP;o
Y[k[0_nV_^X4ojFnj`;oY;k/0_nU_^`4ojBok@;oXl7^00?oYL;^ojG3konU`nl00_nU`nl2ojG5l7Go
oooo00?o0000ooooool000002oooool005gooooo00?o0000ooooooooool0:oooool<ojS0j`CoZ;o[
1?nW_nX2ojNnjP03ojNojonW_^_oYkk[00;oYkk[0_nV_^/2ojJoj`CoY[o/0_nV`>`5ojO1k0GoZ<;/
0_nY`^`6ojW2j`;oZL7[00?oZL3ZojRoj_nX_nX00_nX_nX2ojNojP;oYkkZ1?nV_^X2ojFnj`03ojJn
jonU_^coYKk/00?oYKk/0_nT_nd00onV`>coYL;^ojG2kP02ojG2kP;oYL?_N?ooool01?l0003ooooo
ooooool0000:ooooo`00G_ooool00ol0003oooooooooo`0[ooooo`[oZ<3[1_nX_n/2ojNojPGoYko[
0_nW_^/2ojNoj`CoY[o[0_nV_n`2ojO0k0GoYl7/0onX`N`2ojS2k0;oZL;/1_nY`^/00onY`N_oZL3Z
ojW0jP02ojW0jPCoZ;oZ1?nW_^X4ojJnjP?oY[k[0_nU_^`3ojJoj`?oY/3/0_nU`^ilooooo`03o`00
0?oooooo000000[ooooo001Oooooo`;o0000;?ooool8ojS0j`KoZ;o[3OnW_n/2ojJoj`?oYl3[00?o
Yl3/ojO1k?nW`N`01?nW`N`4ojS1k0CoZL;/0_nY`^/5ojW1j`;oZL3Z1_nX_nX4ojNnjP;oY[kZ1_nW
_^X2ojJojh?ooooo0_l0000:ooooo`00HOooool00ol0003oooooooooo`0Zooooo`SoZ<3[0_nX_n/B
ojNoj`;oYl3[00?oYl3/ojO1k?nW`N`01?nW`N`6ojS1k0;oZL;/1onY`N/3ojW0jP;oZ;oZ0_nX_^X3
ojRnj@;oYkkZ0_nW_^T6ojNnjXGooooo0ol0000:ooooo`00H_ooool00ol0003oooooooooo`0[oooo
o`;oZ<3[1_nW`>/AojNoj`03ojO0jonW`>coYl3/00;oYl3/1?nW`N`6ojS1k0;oZ<7[0_nY`N/2ojS0
j`CoZL3[0_nY`>X2ojRojPCoZ;kZ0onX_^T4ojNnj@;oYkkZQ?ooool4o`0000gooooo001Sooooo`03
o`000?oooooooooo02_ooooo1onW`>/>ojNoj`GoYl3[1OnW`>`3ojO1k0;oZ<7/1_nX`N/4ojS0j`;o
ZL3[1_nX_nX3ojRnjPCoZ;kY0_nW_^V3ooooo`Co00004Oooool006Cooooo0_l0000/ooooo`OoYl3[
2_nW_n/7ojO0j`GoYl3/0_nW`N`4ojS1k0OoZ<7[1?nX`>/8ojRojP?oZ;kZ0_nX_^V3ooooo`?o0000
5Oooool006Kooooo00?o0000ooooooooool0:oooool7ojO0j`;oYko[2OnW`>/8ojO0k0CoYl7/0_nX
`N`7ojS1j`KoZ<3[1_nX_nZ5ooooo`Co00006?ooool006Oooooo00?o0000ooooooooool0:_oooolC
ojO0j`SoYl3/1?nW`N`5ojS1j`KoZ<3[1?nX_n/2ojRojXCooooo1?l0000Looooo`00J?ooool00ol0
003oooooooooo`0Zoooooa7oYl3[2?nW`>`6ojO1k0CoZ<7[1onX`>/2ojRojh?ooooo1?l0000Poooo
o`00JOooool2o`0002cooooo2onW`>/;ojO0k0SoYl7/0_nX`N/7ojS0jh;ooooo1?l0000Tooooo`00
Joooool00ol0003oooooooooo`0Zooooo`_oYl3[2onW`>`6ojO1k0?oYl3/1?nX`>^2ooooo`?o0000
:?ooool006cooooo00?o0000ooooooooool0:_ooool;ojO0j`_oYl3/1OnW`N`2ojO0k8?ooooo1?l0
000[ooooo`00KOooool00ol0003oooooooooo`0[ooooo`[oYl3[3?nW`>`2ojO1k8;ooooo1?l0000_
ooooo`00K_ooool00ol0003oooooooooo`0Zooooo`_oYl3[2_nW`>b1ooooo`Co0000<oooool006oo
oooo0_l0000[ooooo`coYl3[1OnW`>b0ooooo`Co0000=oooool0077ooooo00?o0000ooooooooool0
:_ooool9ojO0jh;ooooo1?l0000kooooo`00L_ooool00ol0003oooooooooo`0Zooooo`GoYl3[P_oo
ool3o`0003oooooo001cooooo`03o`000?oooooooooo02[ooooo00?oYl3[ooooooooool0Ooooool4
o`0004;ooooo001dooooo`;o0000:_ooool00ol0003oooooooooo`1kooooo`Co0000A_ooool007Ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1hooooo`Co0000B_ooool007Oooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1dooooo`Co0000C_ooool007Sooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`1aooooo`?o0000D_ooool007Wooooo0_l0000T
ooooo`03o`000?oooooooooo06gooooo1?l0001Eooooo`00Noooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo06Wooooo1?l0001Iooooo`00O?ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo06Gooooo1?l0001Mooooo`00OOooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo067ooooo1?l0001Qooooo`00O_ooool2o`0001oooooo00?o0000ooooooooool0GOoo
ool4o`0006Gooooo0020ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0F_ooool3
o`0006Wooooo0021ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0E_ooool4o`00
06cooooo0022ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0D_ooool4o`00073o
oooo0023ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0C_ooool4o`0007Cooooo
0024ooooo`;o00006Oooool00ol0003oooooooooo`1:ooooo`Co0000N?ooool008Kooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`16ooooo`Co0000O?ooool008Oooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`13ooooo`?o0000P?ooool008Sooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0oooooo`Co0000Poooool008Wooooo0_l0000Dooooo`03o`00
0?oooooooooo03_ooooo1?l00027ooooo`00Roooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo03Oooooo1?l0002;ooooo`00S?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo03?ooooo1?l0002?ooooo`00SOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
033ooooo0ol0002Cooooo`00S_ooool2o`0000oooooo00?o0000ooooooooool0;?ooool4o`0009Ko
oooo002@ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:?ooool4o`0009[ooooo
002Aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09?ooool4o`0009kooooo002B
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool4o`000:;ooooo002Coooo
o`;o00002Oooool00ol0003oooooooooo`0Mooooo`Co0000Y_ooool009Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Jooooo`?o0000Z_ooool009Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Fooooo`Co0000[Oooool009Oooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Booooo`Co0000/Oooool009Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0>ooooo`Co0000]Oooool009Wooooo0_l00003ooooo`03o`000?oooooooooo
00[ooooo1?l0002iooooo`00Voooool01?l0003oooooooooool00009ooooo`?o0000_Oooool009co
oooo00?o0000ooooool000001Oooool4o`000<3ooooo002Mooooo`;o000000?oooooo`000?l00000
0_l00034ooooo`00W_ooool2o`000<Sooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Zooooo`05
oiRHV?l0003o0000odA4A?nj^[X02_ooool4o`000007oa0@4?oooooooooooa0@4?l0003oA4A4olc<
c006ooooo`;o8B4Q1?ooool5o`0009?ooooo002Zooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_oo
ool6o`0000Cooooo00?o0000ooooooooool01?ooool00onHV9So410@omgMg@05ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A409?ooooo002Zooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool01Oooool00on7QhOoEEEEooooo`0;ooooo`03oiRHV?lQ8B7ok^k^09Cooooo002Z
ooooo`03o`000?oooooooooo00Cooooo1_l00004ooooo`03o`000?oooooooooo00;ooooo00Goc<c<
ob4Q8Ol0003oEEEEo`00000=ooooo`03oiRHV?lQ8B7ok^k^09?ooooo002Zooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool00_ooool01OlQ8B7oQhN7oooooonHV9So000000kooooo00?o
MgMgofIVI_ooool0T_ooool00:Sooooo00?o410@o`000?l000000ol0000=ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo097ooooo002Z
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool01OlQ8B7oV9RHoooooomg
MgOoEEEE00_ooooo00Go0000okZj^_ooooooV9RHoa0@402Cooooo`00Z_ooool00ol0003ooooooooo
o`0<ooooo`03oeEEEOmVIVKo000000Cooooo00Goc<c<oa0@4?l0003o<S8bonk^kP0;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`0Toooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -17 0 ]
[.5 .82364 17 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20.) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.655 .751 .921 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69468 Mtetra
.655 .752 .921 r
.4053 .69468 .41061 .69934 .41957 .69681 .41427 .69216 Mtetra
.655 .752 .922 r
.41427 .69216 .41957 .69681 .42855 .69428 .42327 .68963 Mtetra
.655 .753 .922 r
.42327 .68963 .42855 .69428 .43756 .69174 .4323 .68709 Mtetra
.655 .754 .923 r
.4323 .68709 .43756 .69174 .4466 .68919 .44136 .68455 Mtetra
.654 .755 .924 r
.44136 .68455 .4466 .68919 .45567 .68663 .45046 .682 Mtetra
.654 .756 .924 r
.45046 .682 .45567 .68663 .46478 .68407 .45958 .67945 Mtetra
.654 .757 .925 r
.45958 .67945 .46478 .68407 .47391 .68149 .46873 .67688 Mtetra
.654 .758 .926 r
.46873 .67688 .47391 .68149 .48307 .67891 .47791 .67431 Mtetra
.654 .759 .927 r
.47791 .67431 .48307 .67891 .49227 .67632 .48713 .67172 Mtetra
.654 .76 .927 r
.48713 .67172 .49227 .67632 .50149 .67371 .49637 .66912 Mtetra
.655 .761 .928 r
.49637 .66912 .50149 .67371 .51075 .6711 .50565 .6665 Mtetra
.655 .761 .927 r
.50565 .6665 .51075 .6711 .52004 .66849 .51496 .66385 Mtetra
.656 .761 .927 r
.51496 .66385 .52004 .66849 .52936 .66586 .5243 .66118 Mtetra
.657 .76 .926 r
.5243 .66118 .52936 .66586 .53871 .66322 .53367 .65848 Mtetra
.657 .758 .924 r
.53367 .65848 .53871 .66322 .54809 .66058 .54308 .65577 Mtetra
.658 .756 .922 r
.54308 .65577 .54809 .66058 .55751 .65792 .55251 .65304 Mtetra
.658 .754 .921 r
.55251 .65304 .55751 .65792 .56695 .65526 .56198 .65031 Mtetra
.657 .751 .92 r
.56198 .65031 .56695 .65526 .57643 .65259 .57148 .64759 Mtetra
.655 .75 .92 r
.57148 .64759 .57643 .65259 .58595 .6499 .58102 .64491 Mtetra
.653 .75 .921 r
.58102 .64491 .58595 .6499 .59549 .64721 .59059 .64227 Mtetra
.65 .752 .924 r
.59059 .64227 .59549 .64721 .60507 .64451 .60019 .63968 Mtetra
.647 .756 .929 r
.60019 .63968 .60507 .64451 .61468 .6418 .60983 .63715 Mtetra
.643 .763 .936 r
.60983 .63715 .61468 .6418 .62432 .63908 .6195 .63465 Mtetra
.64 .772 .943 r
.6195 .63465 .62432 .63908 .634 .63636 .62921 .63217 Mtetra
.637 .783 .952 r
.62921 .63217 .634 .63636 .64371 .63362 .63895 .62968 Mtetra
.634 .795 .959 r
.63895 .62968 .64371 .63362 .65345 .63087 .64873 .62715 Mtetra
.634 .806 .965 r
.64873 .62715 .65345 .63087 .66323 .62811 .65854 .62455 Mtetra
.635 .815 .969 r
.65854 .62455 .66323 .62811 .67304 .62535 .66839 .62186 Mtetra
.639 .82 .97 r
.66839 .62186 .67304 .62535 .68289 .62257 .67826 .61907 Mtetra
.644 .822 .969 r
.67826 .61907 .68289 .62257 .69277 .61979 .68817 .61617 Mtetra
.65 .819 .965 r
.68817 .61617 .69277 .61979 .70269 .61699 .6981 .61319 Mtetra
.655 .812 .959 r
.6981 .61319 .70269 .61699 .71264 .61418 .70807 .61013 Mtetra
.66 .802 .951 r
.70807 .61013 .71264 .61418 .72262 .61137 .71807 .60703 Mtetra
.662 .791 .943 r
.71807 .60703 .72262 .61137 .73264 .60854 .7281 .60392 Mtetra
.663 .779 .936 r
.7281 .60392 .73264 .60854 .7427 .60571 .73817 .60082 Mtetra
.662 .769 .929 r
.73817 .60082 .7427 .60571 .75279 .60286 .74827 .59777 Mtetra
.66 .76 .924 r
.74827 .59777 .75279 .60286 .76291 .60001 .75841 .59476 Mtetra
.658 .754 .921 r
.75841 .59476 .76291 .60001 .77308 .59714 .7686 .59181 Mtetra
.656 .751 .92 r
.7686 .59181 .77308 .59714 .78328 .59427 .77882 .5889 Mtetra
.655 .75 .92 r
.77882 .5889 .78328 .59427 .79351 .59138 .78908 .58602 Mtetra
.654 .75 .921 r
.78908 .58602 .79351 .59138 .80378 .58849 .79938 .58316 Mtetra
.653 .752 .922 r
.79938 .58316 .80378 .58849 .81409 .58558 .80972 .58029 Mtetra
.653 .754 .924 r
.80972 .58029 .81409 .58558 .82443 .58267 .8201 .57741 Mtetra
.653 .757 .926 r
.8201 .57741 .82443 .58267 .83482 .57974 .83051 .57451 Mtetra
.654 .759 .927 r
.83051 .57451 .83482 .57974 .84523 .5768 .84096 .57158 Mtetra
.654 .76 .927 r
.84096 .57158 .84523 .5768 .85569 .57385 .85144 .56862 Mtetra
.655 .761 .928 r
.85144 .56862 .85569 .57385 .86618 .57089 .86197 .56564 Mtetra
.655 .761 .927 r
.86197 .56564 .86618 .57089 .87672 .56792 .87253 .56264 Mtetra
.656 .76 .927 r
.87253 .56264 .87672 .56792 .88729 .56494 .88312 .55962 Mtetra
.656 .76 .926 r
.88312 .55962 .88729 .56494 .89789 .56195 .89376 .55658 Mtetra
.656 .759 .925 r
.89376 .55658 .89789 .56195 .90854 .55895 .90443 .55353 Mtetra
.656 .757 .924 r
.90443 .55353 .90854 .55895 .91923 .55594 .91514 .55047 Mtetra
.656 .756 .924 r
.91514 .55047 .91923 .55594 .92995 .55292 .92589 .5474 Mtetra
.656 .755 .923 r
.92589 .5474 .92995 .55292 .94071 .54988 .93668 .54432 Mtetra
.656 .754 .922 r
.93668 .54432 .94071 .54988 .95152 .54684 .94751 .54123 Mtetra
.94751 .54123 .95152 .54684 .96236 .54378 .95838 .53814 Mtetra
.656 .753 .921 r
.95838 .53814 .96236 .54378 .97324 .54071 .96929 .53503 Mtetra
.656 .752 .921 r
.96929 .53503 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.655 .751 .921 r
.391 .69252 .39636 .6972 .4053 .69468 .39996 .69 Mtetra
.655 .752 .921 r
.39996 .69 .4053 .69468 .41427 .69216 .40895 .68747 Mtetra
.654 .752 .922 r
.40895 .68747 .41427 .69216 .42327 .68963 .41797 .68494 Mtetra
.41797 .68494 .42327 .68963 .4323 .68709 .42702 .6824 Mtetra
.654 .753 .923 r
.42702 .6824 .4323 .68709 .44136 .68455 .4361 .67986 Mtetra
.653 .754 .923 r
.4361 .67986 .44136 .68455 .45046 .682 .44521 .67732 Mtetra
.653 .754 .924 r
.44521 .67732 .45046 .682 .45958 .67945 .45435 .67477 Mtetra
.653 .755 .925 r
.45435 .67477 .45958 .67945 .46873 .67688 .46352 .67222 Mtetra
.653 .756 .926 r
.46352 .67222 .46873 .67688 .47791 .67431 .47272 .66966 Mtetra
.653 .758 .926 r
.47272 .66966 .47791 .67431 .48713 .67172 .48196 .66708 Mtetra
.653 .759 .927 r
.48196 .66708 .48713 .67172 .49637 .66912 .49122 .66448 Mtetra
.654 .76 .927 r
.49122 .66448 .49637 .66912 .50565 .6665 .50052 .66185 Mtetra
.655 .761 .927 r
.50052 .66185 .50565 .6665 .51496 .66385 .50985 .65918 Mtetra
.657 .761 .926 r
.50985 .65918 .51496 .66385 .5243 .66118 .51922 .65648 Mtetra
.658 .76 .925 r
.51922 .65648 .5243 .66118 .53367 .65848 .52861 .65373 Mtetra
.66 .759 .924 r
.52861 .65373 .53367 .65848 .54308 .65577 .53803 .65095 Mtetra
.66 .757 .922 r
.53803 .65095 .54308 .65577 .55251 .65304 .54749 .64814 Mtetra
.66 .755 .921 r
.54749 .64814 .55251 .65304 .56198 .65031 .55698 .64535 Mtetra
.658 .752 .92 r
.55698 .64535 .56198 .65031 .57148 .64759 .5665 .64258 Mtetra
.655 .75 .92 r
.5665 .64258 .57148 .64759 .58102 .64491 .57606 .63989 Mtetra
.65 .749 .922 r
.57606 .63989 .58102 .64491 .59059 .64227 .58565 .6373 Mtetra
.645 .75 .926 r
.58565 .6373 .59059 .64227 .60019 .63968 .59528 .63481 Mtetra
.638 .753 .932 r
.59528 .63481 .60019 .63968 .60983 .63715 .60494 .63245 Mtetra
.632 .759 .939 r
.60494 .63245 .60983 .63715 .6195 .63465 .61464 .63017 Mtetra
.626 .767 .947 r
.61464 .63017 .6195 .63465 .62921 .63217 .62439 .62795 Mtetra
.623 .779 .956 r
.62439 .62795 .62921 .63217 .63895 .62968 .63416 .62571 Mtetra
.621 .791 .963 r
.63416 .62571 .63895 .62968 .64873 .62715 .64398 .62341 Mtetra
.624 .803 .968 r
.64398 .62341 .64873 .62715 .65854 .62455 .65382 .62098 Mtetra
.629 .814 .971 r
.65382 .62098 .65854 .62455 .66839 .62186 .6637 .61837 Mtetra
.638 .821 .971 r
.6637 .61837 .66839 .62186 .67826 .61907 .6736 .61556 Mtetra
.649 .824 .967 r
.6736 .61556 .67826 .61907 .68817 .61617 .68353 .61255 Mtetra
.659 .822 .962 r
.68353 .61255 .68817 .61617 .6981 .61319 .69349 .60936 Mtetra
.667 .816 .955 r
.69349 .60936 .6981 .61319 .70807 .61013 .70347 .60604 Mtetra
.672 .806 .947 r
.70347 .60604 .70807 .61013 .71807 .60703 .71348 .60265 Mtetra
.674 .794 .939 r
.71348 .60265 .71807 .60703 .7281 .60392 .72352 .59925 Mtetra
.673 .782 .932 r
.72352 .59925 .7281 .60392 .73817 .60082 .7336 .59589 Mtetra
.67 .771 .926 r
.7336 .59589 .73817 .60082 .74827 .59777 .74372 .59263 Mtetra
.665 .762 .922 r
.74372 .59263 .74827 .59777 .75841 .59476 .75388 .58948 Mtetra
.661 .755 .92 r
.75388 .58948 .75841 .59476 .7686 .59181 .76409 .58645 Mtetra
.657 .751 .92 r
.76409 .58645 .7686 .59181 .77882 .5889 .77433 .58351 Mtetra
.654 .75 .92 r
.77433 .58351 .77882 .5889 .78908 .58602 .78462 .58064 Mtetra
.652 .75 .922 r
.78462 .58064 .78908 .58602 .79938 .58316 .79496 .57781 Mtetra
.651 .752 .924 r
.79496 .57781 .79938 .58316 .80972 .58029 .80533 .57498 Mtetra
.651 .754 .925 r
.80533 .57498 .80972 .58029 .8201 .57741 .81573 .57213 Mtetra
.652 .757 .926 r
.81573 .57213 .8201 .57741 .83051 .57451 .82618 .56925 Mtetra
.653 .759 .927 r
.82618 .56925 .83051 .57451 .84096 .57158 .83666 .56632 Mtetra
.654 .76 .927 r
.83666 .56632 .84096 .57158 .85144 .56862 .84717 .56335 Mtetra
.655 .761 .927 r
.84717 .56335 .85144 .56862 .86197 .56564 .85772 .56034 Mtetra
.656 .76 .927 r
.85772 .56034 .86197 .56564 .87253 .56264 .8683 .55729 Mtetra
.657 .76 .926 r
.8683 .55729 .87253 .56264 .88312 .55962 .87892 .55423 Mtetra
.657 .759 .925 r
.87892 .55423 .88312 .55962 .89376 .55658 .88958 .55114 Mtetra
.657 .758 .924 r
.88958 .55114 .89376 .55658 .90443 .55353 .90028 .54804 Mtetra
.657 .757 .923 r
.90028 .54804 .90443 .55353 .91514 .55047 .91102 .54493 Mtetra
.657 .756 .923 r
.91102 .54493 .91514 .55047 .92589 .5474 .9218 .54182 Mtetra
.657 .755 .922 r
.9218 .54182 .92589 .5474 .93668 .54432 .93261 .5387 Mtetra
.657 .754 .921 r
.93261 .5387 .93668 .54432 .94751 .54123 .94347 .53558 Mtetra
.657 .753 .921 r
.94347 .53558 .94751 .54123 .95838 .53814 .95437 .53245 Mtetra
.95437 .53245 .95838 .53814 .96929 .53503 .9653 .52931 Mtetra
.657 .752 .92 r
.9653 .52931 .96929 .53503 .98024 .53192 .97628 .52616 Mtetra
.654 .751 .921 r
.38561 .68781 .391 .69252 .39996 .69 .39458 .68528 Mtetra
.39458 .68528 .39996 .69 .40895 .68747 .40359 .68274 Mtetra
.40359 .68274 .40895 .68747 .41797 .68494 .41263 .6802 Mtetra
.654 .752 .922 r
.41263 .6802 .41797 .68494 .42702 .6824 .4217 .67766 Mtetra
.653 .752 .922 r
.4217 .67766 .42702 .6824 .4361 .67986 .43079 .67512 Mtetra
.653 .752 .923 r
.43079 .67512 .4361 .67986 .44521 .67732 .43992 .67257 Mtetra
.652 .753 .923 r
.43992 .67257 .44521 .67732 .45435 .67477 .44908 .67003 Mtetra
.652 .754 .924 r
.44908 .67003 .45435 .67477 .46352 .67222 .45828 .66748 Mtetra
.652 .754 .925 r
.45828 .66748 .46352 .67222 .47272 .66966 .4675 .66493 Mtetra
.652 .756 .926 r
.4675 .66493 .47272 .66966 .48196 .66708 .47675 .66236 Mtetra
.653 .757 .926 r
.47675 .66236 .48196 .66708 .49122 .66448 .48604 .65977 Mtetra
.654 .758 .926 r
.48604 .65977 .49122 .66448 .50052 .66185 .49536 .65714 Mtetra
.655 .759 .926 r
.49536 .65714 .50052 .66185 .50985 .65918 .50471 .65447 Mtetra
.657 .76 .926 r
.50471 .65447 .50985 .65918 .51922 .65648 .5141 .65174 Mtetra
.659 .761 .925 r
.5141 .65174 .51922 .65648 .52861 .65373 .52351 .64895 Mtetra
.661 .76 .924 r
.52351 .64895 .52861 .65373 .53803 .65095 .53296 .64612 Mtetra
.662 .759 .922 r
.53296 .64612 .53803 .65095 .54749 .64814 .54244 .64325 Mtetra
.662 .757 .921 r
.54244 .64325 .54749 .64814 .55698 .64535 .55195 .64039 Mtetra
.659 .754 .92 r
.55195 .64039 .55698 .64535 .5665 .64258 .56149 .63758 Mtetra
.655 .752 .921 r
.56149 .63758 .5665 .64258 .57606 .63989 .57107 .63486 Mtetra
.648 .75 .923 r
.57107 .63486 .57606 .63989 .58565 .6373 .58068 .63229 Mtetra
.64 .749 .928 r
.58068 .63229 .58565 .6373 .59528 .63481 .59033 .6299 Mtetra
.63 .75 .934 r
.59033 .6299 .59528 .63481 .60494 .63245 .60002 .62769 Mtetra
.621 .754 .942 r
.60002 .62769 .60494 .63245 .61464 .63017 .60976 .62563 Mtetra
.613 .761 .95 r
.60976 .62563 .61464 .63017 .62439 .62795 .61953 .62366 Mtetra
.608 .772 .959 r
.61953 .62366 .62439 .62795 .63416 .62571 .62934 .62168 Mtetra
.608 .785 .966 r
.62934 .62168 .63416 .62571 .64398 .62341 .63919 .61962 Mtetra
.613 .799 .971 r
.63919 .61962 .64398 .62341 .65382 .62098 .64907 .61736 Mtetra
.624 .811 .972 r
.64907 .61736 .65382 .62098 .6637 .61837 .65898 .61484 Mtetra
.638 .82 .97 r
.65898 .61484 .6637 .61837 .6736 .61556 .66891 .61201 Mtetra
.654 .825 .965 r
.66891 .61201 .6736 .61556 .68353 .61255 .67886 .60888 Mtetra
.668 .824 .958 r
.67886 .60888 .68353 .61255 .69349 .60936 .68884 .60549 Mtetra
.679 .818 .95 r
.68884 .60549 .69349 .60936 .70347 .60604 .69883 .60189 Mtetra
.685 .808 .941 r
.69883 .60189 .70347 .60604 .71348 .60265 .70886 .59821 Mtetra
.686 .796 .933 r
.70886 .59821 .71348 .60265 .72352 .59925 .71891 .59451 Mtetra
.682 .783 .927 r
.71891 .59451 .72352 .59925 .7336 .59589 .72901 .5909 Mtetra
.677 .772 .922 r
.72901 .5909 .7336 .59589 .74372 .59263 .73914 .58744 Mtetra
.67 .763 .92 r
.73914 .58744 .74372 .59263 .75388 .58948 .74932 .58417 Mtetra
.663 .756 .92 r
.74932 .58417 .75388 .58948 .76409 .58645 .75955 .58107 Mtetra
.657 .752 .92 r
.75955 .58107 .76409 .58645 .77433 .58351 .76982 .57812 Mtetra
.652 .751 .922 r
.76982 .57812 .77433 .58351 .78462 .58064 .78014 .57527 Mtetra
.65 .751 .924 r
.78014 .57527 .78462 .58064 .79496 .57781 .7905 .57246 Mtetra
.649 .753 .925 r
.7905 .57246 .79496 .57781 .80533 .57498 .8009 .56967 Mtetra
.649 .755 .927 r
.8009 .56967 .80533 .57498 .81573 .57213 .81134 .56683 Mtetra
.651 .757 .927 r
.81134 .56683 .81573 .57213 .82618 .56925 .82181 .56395 Mtetra
.653 .759 .927 r
.82181 .56395 .82618 .56925 .83666 .56632 .83232 .56101 Mtetra
.655 .759 .927 r
.83232 .56101 .83666 .56632 .84717 .56335 .84286 .55801 Mtetra
.656 .76 .926 r
.84286 .55801 .84717 .56335 .85772 .56034 .85344 .55496 Mtetra
.657 .759 .925 r
.85344 .55496 .85772 .56034 .8683 .55729 .86405 .55187 Mtetra
.658 .759 .924 r
.86405 .55187 .8683 .55729 .87892 .55423 .8747 .54875 Mtetra
.658 .758 .923 r
.8747 .54875 .87892 .55423 .88958 .55114 .88538 .54562 Mtetra
.658 .757 .922 r
.88538 .54562 .88958 .55114 .90028 .54804 .8961 .54248 Mtetra
.658 .756 .922 r
.8961 .54248 .90028 .54804 .91102 .54493 .90687 .53933 Mtetra
.658 .755 .921 r
.90687 .53933 .91102 .54493 .9218 .54182 .91767 .53618 Mtetra
.658 .754 .921 r
.91767 .53618 .9218 .54182 .93261 .5387 .92852 .53303 Mtetra
.657 .753 .921 r
.92852 .53303 .93261 .5387 .94347 .53558 .9394 .52987 Mtetra
.657 .753 .92 r
.9394 .52987 .94347 .53558 .95437 .53245 .95033 .52671 Mtetra
.657 .752 .92 r
.95033 .52671 .95437 .53245 .9653 .52931 .96129 .52355 Mtetra
.96129 .52355 .9653 .52931 .97628 .52616 .9723 .52037 Mtetra
.654 .751 .921 r
.38018 .68308 .38561 .68781 .39458 .68528 .38918 .68053 Mtetra
.38918 .68053 .39458 .68528 .40359 .68274 .3982 .67798 Mtetra
.3982 .67798 .40359 .68274 .41263 .6802 .40726 .67542 Mtetra
.40726 .67542 .41263 .6802 .4217 .67766 .41634 .67286 Mtetra
.653 .751 .921 r
.41634 .67286 .4217 .67766 .43079 .67512 .42546 .67031 Mtetra
.653 .751 .922 r
.42546 .67031 .43079 .67512 .43992 .67257 .43461 .66776 Mtetra
.652 .751 .922 r
.43461 .66776 .43992 .67257 .44908 .67003 .44379 .66521 Mtetra
.652 .751 .923 r
.44379 .66521 .44908 .67003 .45828 .66748 .453 .66266 Mtetra
.651 .752 .923 r
.453 .66266 .45828 .66748 .4675 .66493 .46224 .66012 Mtetra
.651 .753 .924 r
.46224 .66012 .4675 .66493 .47675 .66236 .47152 .65756 Mtetra
.651 .754 .925 r
.47152 .65756 .47675 .66236 .48604 .65977 .48083 .65498 Mtetra
.653 .756 .925 r
.48083 .65498 .48604 .65977 .49536 .65714 .49017 .65236 Mtetra
.654 .757 .925 r
.49017 .65236 .49536 .65714 .50471 .65447 .49954 .6497 Mtetra
.656 .759 .925 r
.49954 .6497 .50471 .65447 .5141 .65174 .50894 .64697 Mtetra
.659 .76 .925 r
.50894 .64697 .5141 .65174 .52351 .64895 .51838 .64417 Mtetra
.661 .761 .924 r
.51838 .64417 .52351 .64895 .53296 .64612 .52785 .6413 Mtetra
.663 .761 .923 r
.52785 .6413 .53296 .64612 .54244 .64325 .53735 .63839 Mtetra
.663 .76 .922 r
.53735 .63839 .54244 .64325 .55195 .64039 .54688 .63547 Mtetra
.661 .757 .921 r
.54688 .63547 .55195 .64039 .56149 .63758 .55645 .63259 Mtetra
.656 .754 .922 r
.55645 .63259 .56149 .63758 .57107 .63486 .56605 .62984 Mtetra
.647 .751 .925 r
.56605 .62984 .57107 .63486 .58068 .63229 .57568 .62728 Mtetra
.636 .748 .929 r
.57568 .62728 .58068 .63229 .59033 .6299 .58536 .62494 Mtetra
.623 .747 .936 r
.58536 .62494 .59033 .6299 .60002 .62769 .59507 .62286 Mtetra
.611 .749 .943 r
.59507 .62286 .60002 .62769 .60976 .62563 .60483 .621 Mtetra
.599 .754 .952 r
.60483 .621 .60976 .62563 .61953 .62366 .61464 .61928 Mtetra
.593 .764 .961 r
.61464 .61928 .61953 .62366 .62934 .62168 .62448 .61757 Mtetra
.594 .777 .968 r
.62448 .61757 .62934 .62168 .63919 .61962 .63436 .61575 Mtetra
.603 .792 .972 r
.63436 .61575 .63919 .61962 .64907 .61736 .64427 .61367 Mtetra
.618 .807 .972 r
.64427 .61367 .64907 .61736 .65898 .61484 .65421 .61124 Mtetra
.639 .819 .969 r
.65421 .61124 .65898 .61484 .66891 .61201 .66417 .6084 Mtetra
.661 .825 .962 r
.66417 .6084 .66891 .61201 .67886 .60888 .67415 .60514 Mtetra
.678 .825 .954 r
.67415 .60514 .67886 .60888 .68884 .60549 .68415 .60153 Mtetra
.691 .819 .944 r
.68415 .60153 .68884 .60549 .69883 .60189 .69416 .59765 Mtetra
.696 .808 .934 r
.69416 .59765 .69883 .60189 .70886 .59821 .7042 .59366 Mtetra
.696 .796 .927 r
.7042 .59366 .70886 .59821 .71891 .59451 .71427 .58968 Mtetra
.691 .783 .922 r
.71427 .58968 .71891 .59451 .72901 .5909 .72438 .58584 Mtetra
.683 .772 .919 r
.72438 .58584 .72901 .5909 .73914 .58744 .73453 .58221 Mtetra
.673 .763 .919 r
.73453 .58221 .73914 .58744 .74932 .58417 .74473 .57884 Mtetra
.663 .757 .92 r
.74473 .57884 .74932 .58417 .75955 .58107 .75498 .5757 Mtetra
.656 .753 .922 r
.75498 .5757 .75955 .58107 .76982 .57812 .76528 .57275 Mtetra
.65 .752 .924 r
.76528 .57275 .76982 .57812 .78014 .57527 .77563 .56992 Mtetra
.648 .753 .926 r
.77563 .56992 .78014 .57527 .7905 .57246 .78602 .56714 Mtetra
.647 .754 .928 r
.78602 .56714 .7905 .57246 .8009 .56967 .79645 .56435 Mtetra
.649 .756 .928 r
.79645 .56435 .8009 .56967 .81134 .56683 .80692 .56152 Mtetra
.651 .758 .928 r
.80692 .56152 .81134 .56683 .82181 .56395 .81742 .55861 Mtetra
.654 .759 .927 r
.81742 .55861 .82181 .56395 .83232 .56101 .82795 .55563 Mtetra
.656 .759 .926 r
.82795 .55563 .83232 .56101 .84286 .55801 .83852 .55258 Mtetra
.658 .758 .924 r
.83852 .55258 .84286 .55801 .85344 .55496 .84912 .54948 Mtetra
.659 .758 .923 r
.84912 .54948 .85344 .55496 .86405 .55187 .85976 .54634 Mtetra
.659 .757 .922 r
.85976 .54634 .86405 .55187 .8747 .54875 .87043 .54318 Mtetra
.66 .756 .921 r
.87043 .54318 .8747 .54875 .88538 .54562 .88114 .54 Mtetra
.659 .755 .921 r
.88114 .54 .88538 .54562 .8961 .54248 .89189 .53682 Mtetra
.659 .754 .92 r
.89189 .53682 .8961 .54248 .90687 .53933 .90268 .53364 Mtetra
.658 .753 .92 r
.90268 .53364 .90687 .53933 .91767 .53618 .91352 .53046 Mtetra
.91352 .53046 .91767 .53618 .92852 .53303 .92439 .52728 Mtetra
.658 .752 .92 r
.92439 .52728 .92852 .53303 .9394 .52987 .9353 .5241 Mtetra
.657 .752 .92 r
.9353 .5241 .9394 .52987 .95033 .52671 .94626 .52092 Mtetra
.94626 .52092 .95033 .52671 .96129 .52355 .95726 .51773 Mtetra
.95726 .51773 .96129 .52355 .9723 .52037 .96829 .51454 Mtetra
.655 .751 .921 r
.37472 .67831 .38018 .68308 .38918 .68053 .38373 .67574 Mtetra
.655 .751 .92 r
.38373 .67574 .38918 .68053 .3982 .67798 .39278 .67316 Mtetra
.654 .75 .92 r
.39278 .67316 .3982 .67798 .40726 .67542 .40185 .67058 Mtetra
.40185 .67058 .40726 .67542 .41634 .67286 .41096 .668 Mtetra
.41096 .668 .41634 .67286 .42546 .67031 .4201 .66542 Mtetra
.653 .749 .92 r
.4201 .66542 .42546 .67031 .43461 .66776 .42926 .66285 Mtetra
.652 .749 .921 r
.42926 .66285 .43461 .66776 .44379 .66521 .43846 .66029 Mtetra
.651 .749 .921 r
.43846 .66029 .44379 .66521 .453 .66266 .44769 .65773 Mtetra
.44769 .65773 .453 .66266 .46224 .66012 .45696 .65519 Mtetra
.65 .749 .922 r
.45696 .65519 .46224 .66012 .47152 .65756 .46625 .65264 Mtetra
.65 .75 .923 r
.46625 .65264 .47152 .65756 .48083 .65498 .47558 .65008 Mtetra
.651 .752 .924 r
.47558 .65008 .48083 .65498 .49017 .65236 .48494 .64749 Mtetra
.652 .754 .924 r
.48494 .64749 .49017 .65236 .49954 .6497 .49433 .64485 Mtetra
.655 .757 .925 r
.49433 .64485 .49954 .6497 .50894 .64697 .50376 .64216 Mtetra
.658 .759 .925 r
.50376 .64216 .50894 .64697 .51838 .64417 .51322 .63937 Mtetra
.661 .762 .925 r
.51322 .63937 .51838 .64417 .52785 .6413 .52271 .63651 Mtetra
.664 .763 .924 r
.52271 .63651 .52785 .6413 .53735 .63839 .53223 .63357 Mtetra
.53223 .63357 .53735 .63839 .54688 .63547 .54179 .6306 Mtetra
.663 .761 .923 r
.54179 .6306 .54688 .63547 .55645 .63259 .55137 .62766 Mtetra
.657 .758 .924 r
.55137 .62766 .55645 .63259 .56605 .62984 .56099 .62485 Mtetra
.648 .753 .926 r
.56099 .62485 .56605 .62984 .57568 .62728 .57065 .62225 Mtetra
.634 .748 .93 r
.57065 .62225 .57568 .62728 .58536 .62494 .58035 .61993 Mtetra
.618 .744 .937 r
.58035 .61993 .58536 .62494 .59507 .62286 .59009 .61795 Mtetra
.602 .744 .944 r
.59009 .61795 .59507 .62286 .60483 .621 .59988 .61626 Mtetra
.586 .746 .953 r
.59988 .61626 .60483 .621 .61464 .61928 .60971 .61478 Mtetra
.579 .755 .961 r
.60971 .61478 .61464 .61928 .62448 .61757 .61958 .61333 Mtetra
.579 .768 .968 r
.61958 .61333 .62448 .61757 .63436 .61575 .6295 .61177 Mtetra
.592 .785 .972 r
.6295 .61177 .63436 .61575 .64427 .61367 .63944 .60989 Mtetra
.613 .802 .972 r
.63944 .60989 .64427 .61367 .65421 .61124 .64941 .60756 Mtetra
.64 .816 .968 r
.64941 .60756 .65421 .61124 .66417 .6084 .6594 .6047 Mtetra
.667 .824 .959 r
.6594 .6047 .66417 .6084 .67415 .60514 .66941 .6013 Mtetra
.689 .824 .948 r
.66941 .6013 .67415 .60514 .68415 .60153 .67942 .59746 Mtetra
.703 .818 .937 r
.67942 .59746 .68415 .60153 .69416 .59765 .68945 .59329 Mtetra
.708 .807 .927 r
.68945 .59329 .69416 .59765 .7042 .59366 .69951 .589 Mtetra
.706 .795 .92 r
.69951 .589 .7042 .59366 .71427 .58968 .70959 .58474 Mtetra
.698 .782 .916 r
.70959 .58474 .71427 .58968 .72438 .58584 .71971 .58069 Mtetra
.687 .771 .916 r
.71971 .58069 .72438 .58584 .73453 .58221 .72989 .57692 Mtetra
.674 .763 .917 r
.72989 .57692 .73453 .58221 .74473 .57884 .74011 .57349 Mtetra
.663 .757 .921 r
.74011 .57349 .74473 .57884 .75498 .5757 .75039 .57035 Mtetra
.654 .755 .924 r
.75039 .57035 .75498 .5757 .76528 .57275 .76072 .56742 Mtetra
.648 .755 .927 r
.76072 .56742 .76528 .57275 .77563 .56992 .7711 .56463 Mtetra
.646 .756 .929 r
.7711 .56463 .77563 .56992 .78602 .56714 .78152 .56186 Mtetra
.646 .757 .93 r
.78152 .56186 .78602 .56714 .79645 .56435 .79198 .55906 Mtetra
.649 .759 .929 r
.79198 .55906 .79645 .56435 .80692 .56152 .80247 .55618 Mtetra
.652 .759 .928 r
.80247 .55618 .80692 .56152 .81742 .55861 .813 .55322 Mtetra
.655 .759 .926 r
.813 .55322 .81742 .55861 .82795 .55563 .82355 .55018 Mtetra
.658 .758 .924 r
.82355 .55018 .82795 .55563 .83852 .55258 .83414 .54706 Mtetra
.66 .757 .922 r
.83414 .54706 .83852 .55258 .84912 .54948 .84477 .54389 Mtetra
.66 .755 .92 r
.84477 .54389 .84912 .54948 .85976 .54634 .85543 .54069 Mtetra
.661 .754 .919 r
.85543 .54069 .85976 .54634 .87043 .54318 .86613 .53748 Mtetra
.66 .753 .918 r
.86613 .53748 .87043 .54318 .88114 .54 .87687 .53427 Mtetra
.66 .752 .918 r
.87687 .53427 .88114 .54 .89189 .53682 .88764 .53106 Mtetra
.659 .751 .918 r
.88764 .53106 .89189 .53682 .90268 .53364 .89846 .52786 Mtetra
.89846 .52786 .90268 .53364 .91352 .53046 .90933 .52466 Mtetra
.658 .751 .919 r
.90933 .52466 .91352 .53046 .92439 .52728 .92023 .52146 Mtetra
.657 .751 .919 r
.92023 .52146 .92439 .52728 .9353 .5241 .93117 .51827 Mtetra
.93117 .51827 .9353 .5241 .94626 .52092 .94216 .51507 Mtetra
.94216 .51507 .94626 .52092 .95726 .51773 .95319 .51187 Mtetra
.657 .751 .92 r
.95319 .51187 .95726 .51773 .96829 .51454 .96426 .50866 Mtetra
.655 .751 .92 r
.36922 .67351 .37472 .67831 .38373 .67574 .37826 .67091 Mtetra
.37826 .67091 .38373 .67574 .39278 .67316 .38732 .66831 Mtetra
.655 .75 .92 r
.38732 .66831 .39278 .67316 .40185 .67058 .39642 .66569 Mtetra
.39642 .66569 .40185 .67058 .41096 .668 .40554 .66308 Mtetra
.654 .749 .919 r
.40554 .66308 .41096 .668 .4201 .66542 .4147 .66047 Mtetra
.654 .748 .919 r
.4147 .66047 .4201 .66542 .42926 .66285 .42389 .65787 Mtetra
.653 .747 .919 r
.42389 .65787 .42926 .66285 .43846 .66029 .43311 .65528 Mtetra
.652 .747 .919 r
.43311 .65528 .43846 .66029 .44769 .65773 .44236 .65271 Mtetra
.651 .746 .919 r
.44236 .65271 .44769 .65773 .45696 .65519 .45164 .65015 Mtetra
.65 .746 .92 r
.45164 .65015 .45696 .65519 .46625 .65264 .46095 .6476 Mtetra
.649 .747 .921 r
.46095 .6476 .46625 .65264 .47558 .65008 .4703 .64506 Mtetra
.649 .748 .922 r
.4703 .64506 .47558 .65008 .48494 .64749 .47968 .6425 Mtetra
.65 .75 .923 r
.47968 .6425 .48494 .64749 .49433 .64485 .48909 .63991 Mtetra
.652 .753 .924 r
.48909 .63991 .49433 .64485 .50376 .64216 .49854 .63727 Mtetra
.655 .757 .925 r
.49854 .63727 .50376 .64216 .51322 .63937 .50802 .63454 Mtetra
.658 .761 .926 r
.50802 .63454 .51322 .63937 .52271 .63651 .51753 .63172 Mtetra
.662 .764 .926 r
.51753 .63172 .52271 .63651 .53223 .63357 .52708 .62879 Mtetra
.664 .766 .926 r
.52708 .62879 .53223 .63357 .54179 .6306 .53666 .62579 Mtetra
.664 .766 .925 r
.53666 .62579 .54179 .6306 .55137 .62766 .54627 .62279 Mtetra
.659 .762 .926 r
.54627 .62279 .55137 .62766 .56099 .62485 .55591 .6199 Mtetra
.65 .757 .928 r
.55591 .6199 .56099 .62485 .57065 .62225 .56559 .61722 Mtetra
.635 .75 .931 r
.56559 .61722 .57065 .62225 .58035 .61993 .57531 .61487 Mtetra
.615 .743 .937 r
.57531 .61487 .58035 .61993 .59009 .61795 .58507 .61293 Mtetra
.595 .738 .944 r
.58507 .61293 .59009 .61795 .59988 .61626 .59488 .61136 Mtetra
.576 .737 .952 r
.59488 .61136 .59988 .61626 .60971 .61478 .60474 .61009 Mtetra
.566 .743 .96 r
.60474 .61009 .60971 .61478 .61958 .61333 .61465 .6089 Mtetra
.566 .755 .967 r
.61465 .6089 .61958 .61333 .6295 .61177 .62459 .6076 Mtetra
.582 .774 .971 r
.62459 .6076 .6295 .61177 .63944 .60989 .63457 .60593 Mtetra
.609 .794 .97 r
.63457 .60593 .63944 .60989 .64941 .60756 .64457 .60371 Mtetra
.643 .81 .964 r
.64457 .60371 .64941 .60756 .6594 .6047 .65459 .60083 Mtetra
.675 .82 .953 r
.65459 .60083 .6594 .6047 .66941 .6013 .66462 .59729 Mtetra
.699 .82 .94 r
.66462 .59729 .66941 .6013 .67942 .59746 .67466 .59321 Mtetra
.714 .814 .927 r
.67466 .59321 .67942 .59746 .68945 .59329 .6847 .58874 Mtetra
.717 .803 .918 r
.6847 .58874 .68945 .59329 .69951 .589 .69477 .58415 Mtetra
.714 .791 .912 r
.69477 .58415 .69951 .589 .70959 .58474 .70487 .57964 Mtetra
.703 .779 .911 r
.70487 .57964 .70959 .58474 .71971 .58069 .71502 .57542 Mtetra
.689 .769 .913 r
.71502 .57542 .71971 .58069 .72989 .57692 .72521 .57158 Mtetra
.674 .762 .917 r
.72521 .57158 .72989 .57692 .74011 .57349 .73546 .56815 Mtetra
.66 .758 .923 r
.73546 .56815 .74011 .57349 .75039 .57035 .74577 .56505 Mtetra
.651 .757 .927 r
.74577 .56505 .75039 .57035 .76072 .56742 .75614 .56216 Mtetra
.645 .758 .931 r
.75614 .56216 .76072 .56742 .7711 .56463 .76654 .5594 Mtetra
.645 .76 .932 r
.76654 .5594 .7711 .56463 .78152 .56186 .77699 .55661 Mtetra
.647 .761 .932 r
.77699 .55661 .78152 .56186 .79198 .55906 .78748 .55377 Mtetra
.651 .761 .93 r
.78748 .55377 .79198 .55906 .80247 .55618 .79799 .55081 Mtetra
.655 .76 .927 r
.79799 .55081 .80247 .55618 .813 .55322 .80854 .54776 Mtetra
.659 .758 .924 r
.80854 .54776 .813 .55322 .82355 .55018 .81912 .54462 Mtetra
.661 .756 .921 r
.81912 .54462 .82355 .55018 .83414 .54706 .82973 .54141 Mtetra
.662 .754 .919 r
.82973 .54141 .83414 .54706 .84477 .54389 .84038 .53817 Mtetra
.662 .752 .917 r
.84038 .53817 .84477 .54389 .85543 .54069 .85106 .53492 Mtetra
.662 .751 .916 r
.85106 .53492 .85543 .54069 .86613 .53748 .86179 .53167 Mtetra
.661 .75 .916 r
.86179 .53167 .86613 .53748 .87687 .53427 .87255 .52843 Mtetra
.66 .749 .916 r
.87255 .52843 .87687 .53427 .88764 .53106 .88336 .5252 Mtetra
.659 .749 .917 r
.88336 .5252 .88764 .53106 .89846 .52786 .89421 .52199 Mtetra
.658 .749 .917 r
.89421 .52199 .89846 .52786 .90933 .52466 .9051 .51878 Mtetra
.657 .749 .918 r
.9051 .51878 .90933 .52466 .92023 .52146 .91604 .51558 Mtetra
.657 .75 .918 r
.91604 .51558 .92023 .52146 .93117 .51827 .92702 .51238 Mtetra
.657 .75 .919 r
.92702 .51238 .93117 .51827 .94216 .51507 .93803 .50918 Mtetra
.656 .751 .919 r
.93803 .50918 .94216 .51507 .95319 .51187 .94909 .50597 Mtetra
.656 .751 .92 r
.94909 .50597 .95319 .51187 .96426 .50866 .9602 .50275 Mtetra
.36369 .66869 .36922 .67351 .37826 .67091 .37275 .66606 Mtetra
.37275 .66606 .37826 .67091 .38732 .66831 .38183 .66341 Mtetra
.656 .75 .919 r
.38183 .66341 .38732 .66831 .39642 .66569 .39095 .66077 Mtetra
.656 .749 .919 r
.39095 .66077 .39642 .66569 .40554 .66308 .40009 .65812 Mtetra
.655 .748 .918 r
.40009 .65812 .40554 .66308 .4147 .66047 .40927 .65547 Mtetra
.655 .747 .918 r
.40927 .65547 .4147 .66047 .42389 .65787 .41848 .65282 Mtetra
.654 .746 .917 r
.41848 .65282 .42389 .65787 .43311 .65528 .42771 .65019 Mtetra
.653 .745 .917 r
.42771 .65019 .43311 .65528 .44236 .65271 .43699 .64758 Mtetra
.652 .744 .917 r
.43699 .64758 .44236 .65271 .45164 .65015 .44629 .64499 Mtetra
.65 .743 .917 r
.44629 .64499 .45164 .65015 .46095 .6476 .45562 .64243 Mtetra
.648 .742 .918 r
.45562 .64243 .46095 .6476 .4703 .64506 .46499 .6399 Mtetra
.647 .743 .919 r
.46499 .6399 .4703 .64506 .47968 .6425 .47439 .63738 Mtetra
.647 .745 .921 r
.47439 .63738 .47968 .6425 .48909 .63991 .48382 .63486 Mtetra
.648 .749 .923 r
.48382 .63486 .48909 .63991 .49854 .63727 .49328 .6323 Mtetra
.65 .753 .925 r
.49328 .6323 .49854 .63727 .50802 .63454 .50279 .62967 Mtetra
.654 .759 .927 r
.50279 .62967 .50802 .63454 .51753 .63172 .51232 .62693 Mtetra
.659 .765 .928 r
.51232 .62693 .51753 .63172 .52708 .62879 .52189 .62406 Mtetra
.663 .769 .929 r
.52189 .62406 .52708 .62879 .53666 .62579 .53149 .62107 Mtetra
.666 .771 .928 r
.53149 .62107 .53666 .62579 .54627 .62279 .54112 .61801 Mtetra
.662 .768 .928 r
.54112 .61801 .54627 .62279 .55591 .6199 .55079 .61502 Mtetra
.654 .763 .929 r
.55079 .61502 .55591 .6199 .56559 .61722 .56049 .61221 Mtetra
.638 .753 .931 r
.56049 .61221 .56559 .61722 .57531 .61487 .57023 .60976 Mtetra
.617 .742 .936 r
.57023 .60976 .57531 .61487 .58507 .61293 .58002 .60778 Mtetra
.592 .733 .942 r
.58002 .60778 .58507 .61293 .59488 .61136 .58985 .60627 Mtetra
.568 .727 .949 r
.58985 .60627 .59488 .61136 .60474 .61009 .59974 .60518 Mtetra
.555 .73 .956 r
.59974 .60518 .60474 .61009 .61465 .6089 .60967 .60423 Mtetra
.554 .741 .963 r
.60967 .60423 .61465 .6089 .62459 .6076 .61965 .6032 Mtetra
.573 .761 .967 r
.61965 .6032 .62459 .6076 .63457 .60593 .62966 .60174 Mtetra
.605 .783 .966 r
.62966 .60174 .63457 .60593 .64457 .60371 .63969 .59963 Mtetra
.645 .802 .958 r
.63969 .59963 .64457 .60371 .65459 .60083 .64974 .59674 Mtetra
.682 .813 .945 r
.64974 .59674 .65459 .60083 .66462 .59729 .65979 .59305 Mtetra
.708 .813 .93 r
.65979 .59305 .66462 .59729 .67466 .59321 .66984 .58871 Mtetra
.723 .807 .916 r
.66984 .58871 .67466 .59321 .6847 .58874 .67991 .58393 Mtetra
.725 .796 .908 r
.67991 .58393 .6847 .58874 .69477 .58415 .68999 .57907 Mtetra
.719 .784 .903 r
.68999 .57907 .69477 .58415 .70487 .57964 .70011 .57434 Mtetra
.705 .773 .905 r
.70011 .57434 .70487 .57964 .71502 .57542 .71028 .57003 Mtetra
.688 .765 .91 r
.71028 .57003 .71502 .57542 .72521 .57158 .7205 .56618 Mtetra
.67 .76 .918 r
.7205 .56618 .72521 .57158 .73546 .56815 .73079 .56282 Mtetra
.655 .758 .926 r
.73079 .56282 .73546 .56815 .74577 .56505 .74113 .55981 Mtetra
.646 .76 .932 r
.74113 .55981 .74577 .56505 .75614 .56216 .75153 .557 Mtetra
.643 .762 .935 r
.75153 .557 .75614 .56216 .76654 .5594 .76197 .55425 Mtetra
.645 .765 .936 r
.76197 .55425 .76654 .5594 .77699 .55661 .77244 .55142 Mtetra
.65 .765 .933 r
.77244 .55142 .77699 .55661 .78748 .55377 .78294 .54848 Mtetra
.655 .764 .929 r
.78294 .54848 .78748 .55377 .79799 .55081 .79348 .54539 Mtetra
.66 .761 .925 r
.79348 .54539 .79799 .55081 .80854 .54776 .80404 .5422 Mtetra
.663 .758 .921 r
.80404 .5422 .80854 .54776 .81912 .54462 .81464 .53893 Mtetra
.664 .754 .917 r
.81464 .53893 .81912 .54462 .82973 .54141 .82527 .53562 Mtetra
.664 .751 .915 r
.82527 .53562 .82973 .54141 .84038 .53817 .83594 .5323 Mtetra
.663 .749 .914 r
.83594 .5323 .84038 .53817 .85106 .53492 .84665 .529 Mtetra
.662 .747 .913 r
.84665 .529 .85106 .53492 .86179 .53167 .85741 .52572 Mtetra
.661 .746 .913 r
.85741 .52572 .86179 .53167 .87255 .52843 .8682 .52247 Mtetra
.659 .746 .914 r
.8682 .52247 .87255 .52843 .88336 .5252 .87904 .51924 Mtetra
.658 .746 .915 r
.87904 .51924 .88336 .5252 .89421 .52199 .88992 .51603 Mtetra
.657 .747 .916 r
.88992 .51603 .89421 .52199 .9051 .51878 .90085 .51283 Mtetra
.657 .748 .917 r
.90085 .51283 .9051 .51878 .91604 .51558 .91182 .50964 Mtetra
.656 .749 .918 r
.91182 .50964 .91604 .51558 .92702 .51238 .92283 .50644 Mtetra
.656 .749 .919 r
.92283 .50644 .92702 .51238 .93803 .50918 .93388 .50323 Mtetra
.656 .75 .919 r
.93388 .50323 .93803 .50918 .94909 .50597 .94497 .50002 Mtetra
.656 .751 .92 r
.94497 .50002 .94909 .50597 .9602 .50275 .9561 .4968 Mtetra
.657 .752 .92 r
.35813 .66383 .36369 .66869 .37275 .66606 .3672 .66117 Mtetra
.657 .751 .92 r
.3672 .66117 .37275 .66606 .38183 .66341 .37631 .6585 Mtetra
.657 .751 .919 r
.37631 .6585 .38183 .66341 .39095 .66077 .38544 .65581 Mtetra
.657 .75 .919 r
.38544 .65581 .39095 .66077 .40009 .65812 .39461 .65313 Mtetra
.657 .749 .918 r
.39461 .65313 .40009 .65812 .40927 .65547 .4038 .65043 Mtetra
.656 .748 .917 r
.4038 .65043 .40927 .65547 .41848 .65282 .41303 .64774 Mtetra
.656 .746 .917 r
.41303 .64774 .41848 .65282 .42771 .65019 .42229 .64505 Mtetra
.655 .745 .916 r
.42229 .64505 .42771 .65019 .43699 .64758 .43158 .64239 Mtetra
.653 .743 .916 r
.43158 .64239 .43699 .64758 .44629 .64499 .4409 .63975 Mtetra
.651 .741 .916 r
.4409 .63975 .44629 .64499 .45562 .64243 .45026 .63715 Mtetra
.648 .74 .916 r
.45026 .63715 .45562 .64243 .46499 .6399 .45964 .63461 Mtetra
.646 .739 .917 r
.45964 .63461 .46499 .6399 .47439 .63738 .46906 .63211 Mtetra
.644 .74 .919 r
.46906 .63211 .47439 .63738 .48382 .63486 .47851 .62966 Mtetra
.643 .743 .922 r
.47851 .62966 .48382 .63486 .49328 .6323 .488 .6272 Mtetra
.644 .748 .925 r
.488 .6272 .49328 .6323 .50279 .62967 .49752 .6247 Mtetra
.647 .755 .928 r
.49752 .6247 .50279 .62967 .51232 .62693 .50708 .6221 Mtetra
.653 .762 .93 r
.50708 .6221 .51232 .62693 .52189 .62406 .51667 .61934 Mtetra
.659 .77 .931 r
.51667 .61934 .52189 .62406 .53149 .62107 .52629 .61642 Mtetra
.665 .775 .931 r
.52629 .61642 .53149 .62107 .54112 .61801 .53595 .61333 Mtetra
.666 .774 .931 r
.53595 .61333 .54112 .61801 .55079 .61502 .54564 .61023 Mtetra
.661 .769 .93 r
.54564 .61023 .55079 .61502 .56049 .61221 .55536 .60724 Mtetra
.646 .758 .931 r
.55536 .60724 .56049 .61221 .57023 .60976 .56512 .6046 Mtetra
.623 .744 .934 r
.56512 .6046 .57023 .60976 .58002 .60778 .57493 .60248 Mtetra
.595 .729 .938 r
.57493 .60248 .58002 .60778 .58985 .60627 .58478 .60094 Mtetra
.566 .717 .944 r
.58478 .60094 .58985 .60627 .59974 .60518 .59469 .59994 Mtetra
.549 .715 .95 r
.59469 .59994 .59974 .60518 .60967 .60423 .60465 .59918 Mtetra
.546 .723 .956 r
.60465 .59918 .60967 .60423 .61965 .6032 .61466 .5984 Mtetra
.567 .743 .959 r
.61466 .5984 .61965 .6032 .62966 .60174 .6247 .59716 Mtetra
.604 .767 .957 r
.6247 .59716 .62966 .60174 .63969 .59963 .63476 .59518 Mtetra
.649 .788 .948 r
.63476 .59518 .63969 .59963 .64974 .59674 .64484 .59226 Mtetra
.69 .799 .933 r
.64484 .59226 .64974 .59674 .65979 .59305 .65491 .58841 Mtetra
.717 .8 .917 r
.65491 .58841 .65979 .59305 .66984 .58871 .66498 .58382 Mtetra
.731 .794 .903 r
.66498 .58382 .66984 .58871 .67991 .58393 .67507 .57876 Mtetra
.73 .784 .895 r
.67507 .57876 .67991 .58393 .68999 .57907 .68517 .57366 Mtetra
.721 .774 .894 r
.68517 .57366 .68999 .57907 .70011 .57434 .69531 .5688 Mtetra
.704 .765 .9 r
.69531 .5688 .70011 .57434 .71028 .57003 .7055 .56448 Mtetra
.684 .759 .909 r
.7055 .56448 .71028 .57003 .7205 .56618 .71576 .56074 Mtetra
.664 .757 .92 r
.71576 .56074 .7205 .56618 .73079 .56282 .72608 .55752 Mtetra
.648 .759 .93 r
.72608 .55752 .73079 .56282 .74113 .55981 .73646 .55466 Mtetra
.642 .763 .937 r
.73646 .55466 .74113 .55981 .75153 .557 .74689 .55192 Mtetra
.641 .767 .939 r
.74689 .55192 .75153 .557 .76197 .55425 .75736 .54916 Mtetra
.648 .769 .937 r
.75736 .54916 .76197 .55425 .77244 .55142 .76786 .54623 Mtetra
.655 .769 .933 r
.76786 .54623 .77244 .55142 .78294 .54848 .77838 .54313 Mtetra
.662 .766 .927 r
.77838 .54313 .78294 .54848 .79348 .54539 .78893 .53987 Mtetra
.666 .761 .921 r
.78893 .53987 .79348 .54539 .80404 .5422 .79951 .5365 Mtetra
.668 .756 .916 r
.79951 .5365 .80404 .5422 .81464 .53893 .81013 .53309 Mtetra
.667 .751 .913 r
.81013 .53309 .81464 .53893 .82527 .53562 .82078 .52967 Mtetra
.666 .747 .911 r
.82078 .52967 .82527 .53562 .83594 .5323 .83147 .5263 Mtetra
.664 .745 .911 r
.83147 .5263 .83594 .5323 .84665 .529 .84221 .52296 Mtetra
.661 .744 .911 r
.84221 .52296 .84665 .529 .85741 .52572 .85299 .51968 Mtetra
.659 .744 .912 r
.85299 .51968 .85741 .52572 .8682 .52247 .86382 .51644 Mtetra
.658 .744 .914 r
.86382 .51644 .8682 .52247 .87904 .51924 .87469 .51323 Mtetra
.657 .745 .915 r
.87469 .51323 .87904 .51924 .88992 .51603 .88561 .51004 Mtetra
.656 .746 .916 r
.88561 .51004 .88992 .51603 .90085 .51283 .89657 .50685 Mtetra
.655 .747 .918 r
.89657 .50685 .90085 .51283 .91182 .50964 .90757 .50366 Mtetra
.655 .748 .918 r
.90757 .50366 .91182 .50964 .92283 .50644 .91861 .50046 Mtetra
.655 .749 .919 r
.91861 .50046 .92283 .50644 .93388 .50323 .92969 .49725 Mtetra
.655 .75 .92 r
.92969 .49725 .93388 .50323 .94497 .50002 .94082 .49403 Mtetra
.655 .751 .92 r
.94082 .49403 .94497 .50002 .9561 .4968 .95198 .4908 Mtetra
.657 .752 .92 r
.35253 .65894 .35813 .66383 .3672 .66117 .36162 .65626 Mtetra
.657 .751 .92 r
.36162 .65626 .3672 .66117 .37631 .6585 .37074 .65356 Mtetra
.657 .751 .919 r
.37074 .65356 .37631 .6585 .38544 .65581 .3799 .65085 Mtetra
.3799 .65085 .38544 .65581 .39461 .65313 .38909 .64813 Mtetra
.658 .75 .918 r
.38909 .64813 .39461 .65313 .4038 .65043 .3983 .64539 Mtetra
.658 .749 .917 r
.3983 .64539 .4038 .65043 .41303 .64774 .40755 .64264 Mtetra
.658 .748 .916 r
.40755 .64264 .41303 .64774 .42229 .64505 .41683 .63989 Mtetra
.657 .746 .915 r
.41683 .63989 .42229 .64505 .43158 .64239 .42615 .63716 Mtetra
.655 .743 .915 r
.42615 .63716 .43158 .64239 .4409 .63975 .43549 .63445 Mtetra
.653 .741 .914 r
.43549 .63445 .4409 .63975 .45026 .63715 .44486 .63179 Mtetra
.65 .738 .914 r
.44486 .63179 .45026 .63715 .45964 .63461 .45427 .62921 Mtetra
.646 .736 .915 r
.45427 .62921 .45964 .63461 .46906 .63211 .46371 .6267 Mtetra
.641 .735 .917 r
.46371 .6267 .46906 .63211 .47851 .62966 .47318 .62429 Mtetra
.638 .736 .919 r
.47318 .62429 .47851 .62966 .488 .6272 .48268 .62193 Mtetra
.636 .74 .923 r
.48268 .62193 .488 .6272 .49752 .6247 .49222 .61959 Mtetra
.639 .748 .928 r
.49222 .61959 .49752 .6247 .50708 .6221 .5018 .61718 Mtetra
.644 .758 .932 r
.5018 .61718 .50708 .6221 .51667 .61934 .51141 .61461 Mtetra
.653 .769 .934 r
.51141 .61461 .51667 .61934 .52629 .61642 .52106 .61181 Mtetra
.663 .778 .934 r
.52106 .61181 .52629 .61642 .53595 .61333 .53074 .60875 Mtetra
.669 .781 .933 r
.53074 .60875 .53595 .61333 .54564 .61023 .54045 .60555 Mtetra
.67 .778 .93 r
.54045 .60555 .54564 .61023 .55536 .60724 .5502 .60232 Mtetra
.657 .765 .929 r
.5502 .60232 .55536 .60724 .56512 .6046 .55998 .5994 Mtetra
.635 .748 .93 r
.55998 .5994 .56512 .6046 .57493 .60248 .56981 .59701 Mtetra
.604 .727 .932 r
.56981 .59701 .57493 .60248 .58478 .60094 .57968 .5953 Mtetra
.569 .708 .935 r
.57968 .5953 .58478 .60094 .59469 .59994 .58961 .5943 Mtetra
.548 .7 .94 r
.58961 .5943 .59469 .59994 .60465 .59918 .59959 .59367 Mtetra
.541 .703 .945 r
.59959 .59367 .60465 .59918 .61466 .5984 .60962 .59311 Mtetra
.564 .722 .947 r
.60962 .59311 .61466 .5984 .6247 .59716 .61969 .59207 Mtetra
.604 .746 .945 r
.61969 .59207 .6247 .59716 .63476 .59518 .62978 .59022 Mtetra
.653 .769 .934 r
.62978 .59022 .63476 .59518 .64484 .59226 .63988 .58729 Mtetra
.695 .781 .917 r
.63988 .58729 .64484 .59226 .65491 .58841 .64998 .58327 Mtetra
.722 .783 .9 r
.64998 .58327 .65491 .58841 .66498 .58382 .66007 .57844 Mtetra
.735 .778 .887 r
.66007 .57844 .66498 .58382 .67507 .57876 .67017 .57311 Mtetra
.731 .768 .882 r
.67017 .57311 .67507 .57876 .68517 .57366 .68029 .56784 Mtetra
.72 .76 .885 r
.68029 .56784 .68517 .57366 .69531 .5688 .69046 .56294 Mtetra
.698 .753 .895 r
.69046 .56294 .69531 .5688 .7055 .56448 .70069 .55875 Mtetra
.674 .751 .909 r
.70069 .55875 .7055 .56448 .71576 .56074 .71099 .55525 Mtetra
.653 .753 .923 r
.71099 .55525 .71576 .56074 .72608 .55752 .72135 .55228 Mtetra
.638 .759 .936 r
.72135 .55228 .72608 .55752 .73646 .55466 .73177 .54962 Mtetra
.637 .767 .942 r
.73177 .54962 .73646 .55466 .74689 .55192 .74224 .54694 Mtetra
.642 .773 .943 r
.74224 .54694 .74689 .55192 .75736 .54916 .75273 .54412 Mtetra
.654 .775 .938 r
.75273 .54412 .75736 .54916 .76786 .54623 .76324 .54102 Mtetra
.664 .773 .931 r
.76324 .54102 .76786 .54623 .77838 .54313 .77378 .53769 Mtetra
.67 .766 .922 r
.77378 .53769 .77838 .54313 .78893 .53987 .78434 .5342 Mtetra
.673 .759 .916 r
.78434 .5342 .78893 .53987 .79951 .5365 .79494 .53063 Mtetra
.672 .752 .911 r
.79494 .53063 .79951 .5365 .81013 .53309 .80557 .52707 Mtetra
.67 .747 .908 r
.80557 .52707 .81013 .53309 .82078 .52967 .81624 .52357 Mtetra
.666 .743 .908 r
.81624 .52357 .82078 .52967 .83147 .5263 .82697 .52016 Mtetra
.663 .741 .908 r
.82697 .52016 .83147 .5263 .84221 .52296 .83773 .51683 Mtetra
.66 .741 .91 r
.83773 .51683 .84221 .52296 .85299 .51968 .84855 .51357 Mtetra
.657 .742 .912 r
.84855 .51357 .85299 .51968 .86382 .51644 .85941 .51037 Mtetra
.656 .743 .914 r
.85941 .51037 .86382 .51644 .87469 .51323 .87032 .50719 Mtetra
.655 .745 .916 r
.87032 .50719 .87469 .51323 .88561 .51004 .88126 .50402 Mtetra
.655 .747 .917 r
.88126 .50402 .88561 .51004 .89657 .50685 .89226 .50085 Mtetra
.654 .748 .919 r
.89226 .50085 .89657 .50685 .90757 .50366 .90329 .49766 Mtetra
.654 .749 .919 r
.90329 .49766 .90757 .50366 .91861 .50046 .91436 .49446 Mtetra
.655 .75 .92 r
.91436 .49446 .91861 .50046 .92969 .49725 .92548 .49125 Mtetra
.92548 .49125 .92969 .49725 .94082 .49403 .93664 .48801 Mtetra
.655 .751 .92 r
.93664 .48801 .94082 .49403 .95198 .4908 .94784 .48476 Mtetra
.657 .752 .92 r
.34689 .65403 .35253 .65894 .36162 .65626 .356 .65133 Mtetra
.356 .65133 .36162 .65626 .37074 .65356 .36515 .64862 Mtetra
.36515 .64862 .37074 .65356 .3799 .65085 .37432 .64589 Mtetra
.658 .752 .92 r
.37432 .64589 .3799 .65085 .38909 .64813 .38353 .64314 Mtetra
.658 .752 .919 r
.38353 .64314 .38909 .64813 .3983 .64539 .39277 .64036 Mtetra
.659 .751 .918 r
.39277 .64036 .3983 .64539 .40755 .64264 .40204 .63757 Mtetra
.659 .75 .917 r
.40204 .63757 .40755 .64264 .41683 .63989 .41134 .63476 Mtetra
.659 .749 .916 r
.41134 .63476 .41683 .63989 .42615 .63716 .42067 .63195 Mtetra
.658 .746 .915 r
.42067 .63195 .42615 .63716 .43549 .63445 .43004 .62915 Mtetra
.656 .743 .914 r
.43004 .62915 .43549 .63445 .44486 .63179 .43943 .62641 Mtetra
.652 .739 .913 r
.43943 .62641 .44486 .63179 .45427 .62921 .44886 .62374 Mtetra
.647 .735 .913 r
.44886 .62374 .45427 .62921 .46371 .6267 .45832 .62118 Mtetra
.641 .732 .915 r
.45832 .62118 .46371 .6267 .47318 .62429 .46781 .61877 Mtetra
.635 .731 .917 r
.46781 .61877 .47318 .62429 .48268 .62193 .47733 .61647 Mtetra
.63 .732 .921 r
.47733 .61647 .48268 .62193 .49222 .61959 .48689 .61429 Mtetra
.629 .739 .926 r
.48689 .61429 .49222 .61959 .5018 .61718 .49648 .61208 Mtetra
.632 .749 .932 r
.49648 .61208 .5018 .61718 .51141 .61461 .50612 .60977 Mtetra
.642 .763 .936 r
.50612 .60977 .51141 .61461 .52106 .61181 .51579 .60719 Mtetra
.657 .776 .937 r
.51579 .60719 .52106 .61181 .53074 .60875 .52549 .60424 Mtetra
.67 .785 .935 r
.52549 .60424 .53074 .60875 .54045 .60555 .53523 .60098 Mtetra
.679 .786 .93 r
.53523 .60098 .54045 .60555 .5502 .60232 .545 .59749 Mtetra
.671 .774 .927 r
.545 .59749 .5502 .60232 .55998 .5994 .55481 .5942 Mtetra
.652 .755 .925 r
.55481 .5942 .55998 .5994 .56981 .59701 .56465 .59138 Mtetra
.62 .728 .924 r
.56465 .59138 .56981 .59701 .57968 .5953 .57454 .58934 Mtetra
.581 .702 .925 r
.57454 .58934 .57968 .5953 .58961 .5943 .58448 .58817 Mtetra
.555 .685 .926 r
.58448 .58817 .58961 .5943 .59959 .59367 .59448 .58754 Mtetra
.544 .681 .928 r
.59448 .58754 .59959 .59367 .60962 .59311 .60454 .58713 Mtetra
.565 .696 .929 r
.60454 .58713 .60962 .59311 .61969 .59207 .61463 .58625 Mtetra
.605 .719 .925 r
.61463 .58625 .61969 .59207 .62978 .59022 .62475 .58451 Mtetra
.656 .742 .913 r
.62475 .58451 .62978 .59022 .63988 .58729 .63487 .58155 Mtetra
.698 .755 .896 r
.63487 .58155 .63988 .58729 .64998 .58327 .64499 .57739 Mtetra
.723 .758 .88 r
.64499 .57739 .64998 .58327 .66007 .57844 .6551 .57235 Mtetra
.734 .755 .869 r
.6551 .57235 .66007 .57844 .67017 .57311 .66522 .56684 Mtetra
.728 .748 .868 r
.66522 .56684 .67017 .57311 .68029 .56784 .67537 .56153 Mtetra
.712 .743 .876 r
.67537 .56153 .68029 .56784 .69046 .56294 .68557 .55676 Mtetra
.687 .74 .891 r
.68557 .55676 .69046 .56294 .70069 .55875 .69584 .55287 Mtetra
.659 .741 .911 r
.69584 .55287 .70069 .55875 .71099 .55525 .70618 .54976 Mtetra
.638 .749 .929 r
.70618 .54976 .71099 .55525 .72135 .55228 .7166 .54713 Mtetra
.626 .759 .942 r
.7166 .54713 .72135 .55228 .73177 .54962 .72706 .54469 Mtetra
.634 .772 .947 r
.72706 .54469 .73177 .54962 .74224 .54694 .73755 .54203 Mtetra
.647 .779 .944 r
.73755 .54203 .74224 .54694 .75273 .54412 .74807 .53906 Mtetra
.664 .779 .935 r
.74807 .53906 .75273 .54412 .76324 .54102 .75859 .5357 Mtetra
.675 .773 .924 r
.75859 .5357 .76324 .54102 .77378 .53769 .76914 .53207 Mtetra
.679 .764 .915 r
.76914 .53207 .77378 .53769 .78434 .5342 .77971 .52832 Mtetra
.679 .755 .909 r
.77971 .52832 .78434 .5342 .79494 .53063 .79032 .52455 Mtetra
.675 .747 .905 r
.79032 .52455 .79494 .53063 .80557 .52707 .80097 .52089 Mtetra
.67 .743 .905 r
.80097 .52089 .80557 .52707 .81624 .52357 .81167 .51735 Mtetra
.665 .74 .906 r
.81167 .51735 .81624 .52357 .82697 .52016 .82242 .51395 Mtetra
.66 .74 .908 r
.82242 .51395 .82697 .52016 .83773 .51683 .83323 .51067 Mtetra
.657 .741 .911 r
.83323 .51067 .83773 .51683 .84855 .51357 .84408 .50746 Mtetra
.655 .742 .914 r
.84408 .50746 .84855 .51357 .85941 .51037 .85497 .50431 Mtetra
.654 .745 .917 r
.85497 .50431 .85941 .51037 .87032 .50719 .86591 .50117 Mtetra
.653 .747 .918 r
.86591 .50117 .87032 .50719 .88126 .50402 .8769 .49802 Mtetra
.653 .748 .92 r
.8769 .49802 .88126 .50402 .89226 .50085 .88792 .49486 Mtetra
.653 .75 .92 r
.88792 .49486 .89226 .50085 .90329 .49766 .89899 .49167 Mtetra
.654 .751 .921 r
.89899 .49167 .90329 .49766 .91436 .49446 .91009 .48846 Mtetra
.91009 .48846 .91436 .49446 .92548 .49125 .92124 .48522 Mtetra
.655 .751 .921 r
.92124 .48522 .92548 .49125 .93664 .48801 .93243 .48196 Mtetra
.93243 .48196 .93664 .48801 .94784 .48476 .94366 .47868 Mtetra
.656 .751 .92 r
.34122 .64908 .34689 .65403 .356 .65133 .35035 .64638 Mtetra
.656 .752 .921 r
.35035 .64638 .356 .65133 .36515 .64862 .35951 .64367 Mtetra
.657 .753 .921 r
.35951 .64367 .36515 .64862 .37432 .64589 .36871 .64094 Mtetra
.657 .754 .921 r
.36871 .64094 .37432 .64589 .38353 .64314 .37793 .63818 Mtetra
.658 .754 .921 r
.37793 .63818 .38353 .64314 .39277 .64036 .38719 .63539 Mtetra
.659 .755 .921 r
.38719 .63539 .39277 .64036 .40204 .63757 .39648 .63257 Mtetra
.66 .754 .92 r
.39648 .63257 .40204 .63757 .41134 .63476 .40581 .6297 Mtetra
.661 .753 .918 r
.40581 .6297 .41134 .63476 .42067 .63195 .41516 .62682 Mtetra
.661 .751 .917 r
.41516 .62682 .42067 .63195 .43004 .62915 .42455 .62392 Mtetra
.66 .748 .915 r
.42455 .62392 .43004 .62915 .43943 .62641 .43397 .62106 Mtetra
.657 .743 .913 r
.43397 .62106 .43943 .62641 .44886 .62374 .44342 .61825 Mtetra
.651 .737 .912 r
.44342 .61825 .44886 .62374 .45832 .62118 .4529 .61558 Mtetra
.644 .731 .912 r
.4529 .61558 .45832 .62118 .46781 .61877 .46241 .61309 Mtetra
.635 .726 .914 r
.46241 .61309 .46781 .61877 .47733 .61647 .47195 .6108 Mtetra
.625 .724 .918 r
.47195 .6108 .47733 .61647 .48689 .61429 .48153 .60872 Mtetra
.62 .727 .923 r
.48153 .60872 .48689 .61429 .49648 .61208 .49114 .60674 Mtetra
.618 .735 .93 r
.49114 .60674 .49648 .61208 .50612 .60977 .50079 .60474 Mtetra
.628 .752 .937 r
.50079 .60474 .50612 .60977 .51579 .60719 .51048 .60248 Mtetra
.646 .771 .939 r
.51048 .60248 .51579 .60719 .52549 .60424 .52021 .59976 Mtetra
.668 .788 .938 r
.52021 .59976 .52549 .60424 .53523 .60098 .52998 .59653 Mtetra
.688 .795 .931 r
.52998 .59653 .53523 .60098 .545 .59749 .53977 .59279 Mtetra
.689 .785 .924 r
.53977 .59279 .545 .59749 .55481 .5942 .5496 .58904 Mtetra
.676 .764 .917 r
.5496 .58904 .55481 .5942 .56465 .59138 .55946 .58561 Mtetra
.644 .732 .913 r
.55946 .58561 .56465 .59138 .57454 .58934 .56936 .58302 Mtetra
.602 .698 .911 r
.56936 .58302 .57454 .58934 .58448 .58817 .57931 .58146 Mtetra
.57 .672 .908 r
.57931 .58146 .58448 .58817 .59448 .58754 .58933 .58066 Mtetra
.552 .659 .907 r
.58933 .58066 .59448 .58754 .60454 .58713 .5994 .58028 Mtetra
.57 .669 .905 r
.5994 .58028 .60454 .58713 .61463 .58625 .60952 .5795 Mtetra
.607 .688 .9 r
.60952 .5795 .61463 .58625 .62475 .58451 .61965 .57783 Mtetra
.656 .71 .888 r
.61965 .57783 .62475 .58451 .63487 .58155 .6298 .57486 Mtetra
.697 .725 .871 r
.6298 .57486 .63487 .58155 .64499 .57739 .63993 .57057 Mtetra
.72 .729 .858 r
.63993 .57057 .64499 .57739 .6551 .57235 .65007 .56539 Mtetra
.729 .728 .85 r
.65007 .56539 .6551 .57235 .66522 .56684 .66021 .55981 Mtetra
.718 .723 .854 r
.66021 .55981 .66522 .56684 .67537 .56153 .67039 .55463 Mtetra
.699 .722 .867 r
.67039 .55463 .67537 .56153 .68557 .55676 .68063 .55021 Mtetra
.668 .722 .89 r
.68063 .55021 .68557 .55676 .69584 .55287 .69095 .54683 Mtetra
.636 .729 .915 r
.69095 .54683 .69584 .55287 .70618 .54976 .70135 .5443 Mtetra
.617 .745 .937 r
.70135 .5443 .70618 .54976 .7166 .54713 .71181 .5421 Mtetra
.613 .761 .95 r
.71181 .5421 .7166 .54713 .72706 .54469 .72232 .53988 Mtetra
.634 .779 .951 r
.72232 .53988 .72706 .54469 .73755 .54203 .73284 .53716 Mtetra
.658 .786 .942 r
.73284 .53716 .73755 .54203 .74807 .53906 .74336 .5339 Mtetra
.677 .781 .928 r
.74336 .5339 .74807 .53906 .75859 .5357 .7539 .53019 Mtetra
.688 .772 .915 r
.7539 .53019 .75859 .5357 .76914 .53207 .76445 .52619 Mtetra
.687 .759 .906 r
.76445 .52619 .76914 .53207 .77971 .52832 .77503 .52217 Mtetra
.684 .749 .901 r
.77503 .52217 .77971 .52832 .79032 .52455 .78566 .51825 Mtetra
.676 .741 .9 r
.78566 .51825 .79032 .52455 .80097 .52089 .79633 .51454 Mtetra
.668 .737 .902 r
.79633 .51454 .80097 .52089 .81167 .51735 .80707 .51104 Mtetra
.661 .737 .906 r
.80707 .51104 .81167 .51735 .82242 .51395 .81785 .50772 Mtetra
.656 .738 .91 r
.81785 .50772 .82242 .51395 .83323 .51067 .82869 .50454 Mtetra
.653 .742 .915 r
.82869 .50454 .83323 .51067 .84408 .50746 .83958 .50141 Mtetra
.651 .745 .918 r
.83958 .50141 .84408 .50746 .85497 .50431 .85052 .49832 Mtetra
.651 .748 .92 r
.85052 .49832 .85497 .50431 .86591 .50117 .86149 .49522 Mtetra
.651 .75 .922 r
.86149 .49522 .86591 .50117 .8769 .49802 .87251 .49208 Mtetra
.652 .752 .923 r
.87251 .49208 .8769 .49802 .88792 .49486 .88357 .48891 Mtetra
.653 .753 .923 r
.88357 .48891 .88792 .49486 .89899 .49167 .89466 .4857 Mtetra
.654 .753 .922 r
.89466 .4857 .89899 .49167 .91009 .48846 .9058 .48246 Mtetra
.655 .753 .922 r
.9058 .48246 .91009 .48846 .92124 .48522 .91697 .47918 Mtetra
.655 .753 .921 r
.91697 .47918 .92124 .48522 .93243 .48196 .92819 .47588 Mtetra
.656 .752 .921 r
.92819 .47588 .93243 .48196 .94366 .47868 .93945 .47256 Mtetra
.655 .751 .921 r
.33552 .6441 .34122 .64908 .35035 .64638 .34466 .64141 Mtetra
.655 .752 .921 r
.34466 .64141 .35035 .64638 .35951 .64367 .35384 .63871 Mtetra
.655 .753 .922 r
.35384 .63871 .35951 .64367 .36871 .64094 .36305 .63599 Mtetra
.656 .755 .922 r
.36305 .63599 .36871 .64094 .37793 .63818 .3723 .63324 Mtetra
.657 .756 .923 r
.3723 .63324 .37793 .63818 .38719 .63539 .38158 .63045 Mtetra
.659 .757 .923 r
.38158 .63045 .38719 .63539 .39648 .63257 .39089 .62762 Mtetra
.661 .758 .922 r
.39089 .62762 .39648 .63257 .40581 .6297 .40023 .62473 Mtetra
.662 .758 .921 r
.40023 .62473 .40581 .6297 .41516 .62682 .40961 .6218 Mtetra
.664 .757 .92 r
.40961 .6218 .41516 .62682 .42455 .62392 .41902 .61881 Mtetra
.664 .755 .918 r
.41902 .61881 .42455 .62392 .43397 .62106 .42847 .61582 Mtetra
.663 .75 .915 r
.42847 .61582 .43397 .62106 .44342 .61825 .43794 .61286 Mtetra
.658 .744 .913 r
.43794 .61286 .44342 .61825 .4529 .61558 .44744 .61001 Mtetra
.65 .735 .912 r
.44744 .61001 .4529 .61558 .46241 .61309 .45698 .60735 Mtetra
.639 .727 .912 r
.45698 .60735 .46241 .61309 .47195 .6108 .46654 .60496 Mtetra
.624 .719 .914 r
.46654 .60496 .47195 .6108 .48153 .60872 .47613 .60289 Mtetra
.613 .716 .919 r
.47613 .60289 .48153 .60872 .49114 .60674 .48576 .60107 Mtetra
.604 .719 .926 r
.48576 .60107 .49114 .60674 .50079 .60474 .49543 .5994 Mtetra
.61 .735 .934 r
.49543 .5994 .50079 .60474 .51048 .60248 .50514 .59753 Mtetra
.628 .757 .94 r
.50514 .59753 .51048 .60248 .52021 .59976 .51489 .5952 Mtetra
.659 .783 .94 r
.51489 .5952 .52021 .59976 .52998 .59653 .52468 .59215 Mtetra
.693 .8 .931 r
.52468 .59215 .52998 .59653 .53977 .59279 .5345 .58826 Mtetra
.706 .797 .921 r
.5345 .58826 .53977 .59279 .5496 .58904 .54435 .58402 Mtetra
.704 .778 .91 r
.54435 .58402 .5496 .58904 .55946 .58561 .55423 .57982 Mtetra
.674 .742 .902 r
.55423 .57982 .55946 .58561 .56936 .58302 .56415 .57642 Mtetra
.63 .701 .896 r
.56415 .57642 .56936 .58302 .57931 .58146 .57411 .57418 Mtetra
.593 .665 .889 r
.57411 .57418 .57931 .58146 .58933 .58066 .58413 .57293 Mtetra
.567 .641 .883 r
.58413 .57293 .58933 .58066 .5994 .58028 .59422 .57237 Mtetra
.579 .642 .877 r
.59422 .57237 .5994 .58028 .60952 .5795 .60434 .57155 Mtetra
.61 .655 .869 r
.60434 .57155 .60952 .5795 .61965 .57783 .6145 .5699 Mtetra
.654 .675 .857 r
.6145 .5699 .61965 .57783 .6298 .57486 .62466 .56691 Mtetra
.691 .689 .843 r
.62466 .56691 .6298 .57486 .63993 .57057 .63481 .56256 Mtetra
.71 .695 .834 r
.63481 .56256 .63993 .57057 .65007 .56539 .64497 .55738 Mtetra
.716 .698 .831 r
.64497 .55738 .65007 .56539 .66021 .55981 .65514 .55192 Mtetra
.701 .696 .842 r
.65514 .55192 .66021 .55981 .67039 .55463 .66536 .54715 Mtetra
.677 .698 .863 r
.66536 .54715 .67039 .55463 .68063 .55021 .67565 .54338 Mtetra
.64 .704 .893 r
.67565 .54338 .68063 .55021 .69095 .54683 .68603 .54077 Mtetra
.603 .717 .924 r
.68603 .54077 .69095 .54683 .70135 .5443 .69649 .53899 Mtetra
.593 .742 .948 r
.69649 .53899 .70135 .5443 .71181 .5421 .70701 .53724 Mtetra
.603 .766 .958 r
.70701 .53724 .71181 .5421 .72232 .53988 .71755 .53514 Mtetra
.642 .787 .951 r
.71755 .53514 .72232 .53988 .73284 .53716 .72809 .53219 Mtetra
.676 .789 .935 r
.72809 .53219 .73284 .53716 .74336 .5339 .73862 .5285 Mtetra
.693 .778 .916 r
.73862 .5285 .74336 .5339 .7539 .53019 .74915 .52434 Mtetra
.699 .764 .902 r
.74915 .52434 .7539 .53019 .76445 .52619 .7597 .51997 Mtetra
.693 .75 .895 r
.7597 .51997 .76445 .52619 .77503 .52217 .7703 .51575 Mtetra
.684 .741 .894 r
.7703 .51575 .77503 .52217 .78566 .51825 .78095 .51177 Mtetra
.672 .735 .897 r
.78095 .51177 .78566 .51825 .79633 .51454 .79166 .50813 Mtetra
.663 .735 .903 r
.79166 .50813 .79633 .51454 .80707 .51104 .80244 .50476 Mtetra
.655 .737 .91 r
.80244 .50476 .80707 .51104 .81785 .50772 .81326 .50158 Mtetra
.65 .741 .916 r
.81326 .50158 .81785 .50772 .82869 .50454 .82415 .49852 Mtetra
.648 .746 .92 r
.82415 .49852 .82869 .50454 .83958 .50141 .83507 .49548 Mtetra
.648 .749 .923 r
.83507 .49548 .83958 .50141 .85052 .49832 .84605 .49244 Mtetra
.649 .753 .925 r
.84605 .49244 .85052 .49832 .86149 .49522 .85706 .48935 Mtetra
.651 .755 .926 r
.85706 .48935 .86149 .49522 .87251 .49208 .8681 .4862 Mtetra
.652 .756 .925 r
.8681 .4862 .87251 .49208 .88357 .48891 .87919 .483 Mtetra
.654 .756 .925 r
.87919 .483 .88357 .48891 .89466 .4857 .89031 .47974 Mtetra
.655 .755 .924 r
.89031 .47974 .89466 .4857 .9058 .48246 .90148 .47644 Mtetra
.656 .755 .923 r
.90148 .47644 .9058 .48246 .91697 .47918 .91268 .47312 Mtetra
.656 .754 .922 r
.91268 .47312 .91697 .47918 .92819 .47588 .92393 .46976 Mtetra
.657 .753 .921 r
.92393 .46976 .92819 .47588 .93945 .47256 .93521 .46639 Mtetra
.653 .751 .921 r
.32977 .63908 .33552 .6441 .34466 .64141 .33894 .63641 Mtetra
.653 .752 .922 r
.33894 .63641 .34466 .64141 .35384 .63871 .34814 .63373 Mtetra
.653 .753 .923 r
.34814 .63373 .35384 .63871 .36305 .63599 .35737 .63103 Mtetra
.654 .755 .924 r
.35737 .63103 .36305 .63599 .3723 .63324 .36663 .62831 Mtetra
.655 .757 .925 r
.36663 .62831 .3723 .63324 .38158 .63045 .37592 .62555 Mtetra
.656 .759 .926 r
.37592 .62555 .38158 .63045 .39089 .62762 .38525 .62274 Mtetra
.659 .762 .926 r
.38525 .62274 .39089 .62762 .40023 .62473 .39462 .61987 Mtetra
.661 .764 .926 r
.39462 .61987 .40023 .62473 .40961 .6218 .40402 .61693 Mtetra
.665 .765 .924 r
.40402 .61693 .40961 .6218 .41902 .61881 .41345 .61389 Mtetra
.667 .764 .922 r
.41345 .61389 .41902 .61881 .42847 .61582 .42292 .61079 Mtetra
.669 .761 .919 r
.42292 .61079 .42847 .61582 .43794 .61286 .43242 .60765 Mtetra
.666 .754 .916 r
.43242 .60765 .43794 .61286 .44744 .61001 .44195 .60456 Mtetra
.66 .744 .912 r
.44195 .60456 .44744 .61001 .45698 .60735 .45151 .60162 Mtetra
.648 .731 .91 r
.45151 .60162 .45698 .60735 .46654 .60496 .46109 .59898 Mtetra
.63 .717 .91 r
.46109 .59898 .46654 .60496 .47613 .60289 .47071 .59678 Mtetra
.612 .707 .912 r
.47071 .59678 .47613 .60289 .48576 .60107 .48036 .59499 Mtetra
.592 .701 .919 r
.48036 .59499 .48576 .60107 .49543 .5994 .49004 .59361 Mtetra
.59 .712 .928 r
.49004 .59361 .49543 .5994 .50514 .59753 .49977 .59221 Mtetra
.602 .735 .938 r
.49977 .59221 .50514 .59753 .51489 .5952 .50954 .59046 Mtetra
.641 .772 .943 r
.50954 .59046 .51489 .5952 .52468 .59215 .51935 .5878 Mtetra
.692 .802 .933 r
.51935 .5878 .52468 .59215 .5345 .58826 .5292 .58393 Mtetra
.722 .809 .919 r
.5292 .58393 .5345 .58826 .54435 .58402 .53908 .57923 Mtetra
.735 .795 .9 r
.53908 .57923 .54435 .58402 .55423 .57982 .54897 .57409 Mtetra
.71 .756 .888 r
.54897 .57409 .55423 .57982 .56415 .57642 .5589 .5696 Mtetra
.667 .708 .879 r
.5589 .5696 .56415 .57642 .57411 .57418 .56887 .56631 Mtetra
.624 .662 .867 r
.56887 .56631 .57411 .57418 .58413 .57293 .57889 .56426 Mtetra
.589 .627 .857 r
.57889 .56426 .58413 .57293 .59422 .57237 .58898 .56324 Mtetra
.592 .618 .846 r
.58898 .56324 .59422 .57237 .60434 .57155 .59911 .56218 Mtetra
.613 .623 .837 r
.59911 .56218 .60434 .57155 .6145 .5699 .60928 .56046 Mtetra
.649 .638 .826 r
.60928 .56046 .6145 .5699 .62466 .56691 .61945 .55744 Mtetra
.681 .652 .815 r
.61945 .55744 .62466 .56691 .63481 .56256 .62962 .55312 Mtetra
.695 .659 .81 r
.62962 .55312 .63481 .56256 .64497 .55738 .6398 .54813 Mtetra
.698 .665 .814 r
.6398 .54813 .64497 .55738 .65514 .55192 .65 .54309 Mtetra
.676 .665 .831 r
.65 .54309 .65514 .55192 .66536 .54715 .66027 .53908 Mtetra
.644 .67 .86 r
.66027 .53908 .66536 .54715 .67565 .54338 .67063 .53632 Mtetra
.599 .681 .899 r
.67063 .53632 .67565 .54338 .68603 .54077 .68108 .53478 Mtetra
.557 .701 .936 r
.68108 .53478 .68603 .54077 .69649 .53899 .69162 .5339 Mtetra
.564 .742 .96 r
.69162 .5339 .69649 .53899 .70701 .53724 .70218 .53258 Mtetra
.601 .776 .964 r
.70218 .53258 .70701 .53724 .71755 .53514 .71275 .53043 Mtetra
.661 .795 .947 r
.71275 .53043 .71755 .53514 .72809 .53219 .72329 .52704 Mtetra
.699 .79 .921 r
.72329 .52704 .72809 .53219 .73862 .5285 .73381 .52272 Mtetra
.709 .77 .9 r
.73381 .52272 .73862 .5285 .74915 .52434 .74434 .51803 Mtetra
.707 .752 .887 r
.74434 .51803 .74915 .52434 .7597 .51997 .7549 .51332 Mtetra
.693 .737 .885 r
.7549 .51332 .7597 .51997 .7703 .51575 .76552 .50902 Mtetra
.679 .73 .889 r
.76552 .50902 .7703 .51575 .78095 .51177 .77621 .50515 Mtetra
.665 .729 .897 r
.77621 .50515 .78095 .51177 .79166 .50813 .78696 .50172 Mtetra
.653 .732 .907 r
.78696 .50172 .79166 .50813 .80244 .50476 .79779 .49859 Mtetra
.647 .739 .917 r
.79779 .49859 .80244 .50476 .81326 .50158 .80866 .49562 Mtetra
.643 .746 .924 r
.80866 .49562 .81326 .50158 .82415 .49852 .81959 .4927 Mtetra
.644 .753 .928 r
.81959 .4927 .82415 .49852 .83507 .49548 .83056 .48974 Mtetra
.645 .757 .93 r
.83056 .48974 .83507 .49548 .84605 .49244 .84156 .48671 Mtetra
.649 .76 .93 r
.84156 .48671 .84605 .49244 .85706 .48935 .8526 .48359 Mtetra
.651 .761 .929 r
.8526 .48359 .85706 .48935 .8681 .4862 .86368 .48038 Mtetra
.654 .76 .928 r
.86368 .48038 .8681 .4862 .87919 .483 .87479 .47711 Mtetra
.656 .759 .926 r
.87479 .47711 .87919 .483 .89031 .47974 .88594 .47378 Mtetra
.657 .758 .924 r
.88594 .47378 .89031 .47974 .90148 .47644 .89713 .47042 Mtetra
.657 .756 .923 r
.89713 .47042 .90148 .47644 .91268 .47312 .90836 .46702 Mtetra
.658 .755 .922 r
.90836 .46702 .91268 .47312 .92393 .46976 .91963 .46361 Mtetra
.658 .753 .921 r
.91963 .46361 .92393 .46976 .93521 .46639 .93095 .46018 Mtetra
.652 .751 .922 r
.32399 .63404 .32977 .63908 .33894 .63641 .33318 .63137 Mtetra
.33318 .63137 .33894 .63641 .34814 .63373 .34239 .6287 Mtetra
.652 .752 .923 r
.34239 .6287 .34814 .63373 .35737 .63103 .35164 .62602 Mtetra
.652 .754 .924 r
.35164 .62602 .35737 .63103 .36663 .62831 .36092 .62333 Mtetra
.652 .756 .926 r
.36092 .62333 .36663 .62831 .37592 .62555 .37023 .62061 Mtetra
.653 .758 .927 r
.37023 .62061 .37592 .62555 .38525 .62274 .37958 .61786 Mtetra
.655 .762 .928 r
.37958 .61786 .38525 .62274 .39462 .61987 .38896 .61504 Mtetra
.659 .765 .929 r
.38896 .61504 .39462 .61987 .40402 .61693 .39838 .61214 Mtetra
.663 .769 .928 r
.39838 .61214 .40402 .61693 .41345 .61389 .40784 .60912 Mtetra
.668 .771 .927 r
.40784 .60912 .41345 .61389 .42292 .61079 .41733 .60597 Mtetra
.673 .771 .924 r
.41733 .60597 .42292 .61079 .43242 .60765 .42685 .60269 Mtetra
.674 .767 .92 r
.42685 .60269 .43242 .60765 .44195 .60456 .43641 .59937 Mtetra
.673 .759 .915 r
.43641 .59937 .44195 .60456 .45151 .60162 .446 .5961 Mtetra
.662 .744 .911 r
.446 .5961 .45151 .60162 .46109 .59898 .45562 .59309 Mtetra
.644 .726 .908 r
.45562 .59309 .46109 .59898 .47071 .59678 .46525 .59053 Mtetra
.619 .706 .907 r
.46525 .59053 .47071 .59678 .48036 .59499 .47492 .58857 Mtetra
.589 .689 .911 r
.47492 .58857 .48036 .59499 .49004 .59361 .48462 .5873 Mtetra
.573 .688 .918 r
.48462 .5873 .49004 .59361 .49977 .59221 .49436 .58631 Mtetra
.57 .702 .931 r
.49436 .58631 .49977 .59221 .50954 .59046 .50414 .58528 Mtetra
.612 .746 .941 r
.50414 .58528 .50954 .59046 .51935 .5878 .51398 .58327 Mtetra
.677 .793 .936 r
.51398 .58327 .51935 .5878 .5292 .58393 .52386 .57974 Mtetra
.73 .818 .919 r
.52386 .57974 .5292 .58393 .53908 .57923 .53376 .57479 Mtetra
.763 .813 .892 r
.53376 .57479 .53908 .57923 .54897 .57409 .54368 .5687 Mtetra
.748 .777 .877 r
.54368 .5687 .54897 .57409 .5589 .5696 .55363 .5629 Mtetra
.71 .727 .863 r
.55363 .5629 .5589 .5696 .56887 .56631 .5636 .55815 Mtetra
.662 .671 .849 r
.5636 .55815 .56887 .56631 .57889 .56426 .57362 .55486 Mtetra
.618 .624 .835 r
.57362 .55486 .57889 .56426 .58898 .56324 .5837 .55297 Mtetra
.609 .603 .82 r
.5837 .55297 .58898 .56324 .59911 .56218 .59383 .55137 Mtetra
.617 .598 .808 r
.59383 .55137 .59911 .56218 .60928 .56046 .604 .54942 Mtetra
.644 .607 .798 r
.604 .54942 .60928 .56046 .61945 .55744 .61418 .54637 Mtetra
.668 .619 .791 r
.61418 .54637 .61945 .55744 .62962 .55312 .62437 .54223 Mtetra
.676 .626 .792 r
.62437 .54223 .62962 .55312 .6398 .54813 .63457 .53774 Mtetra
.672 .633 .802 r
.63457 .53774 .6398 .54813 .65 .54309 .64482 .53352 Mtetra
.642 .635 .828 r
.64482 .53352 .65 .54309 .66027 .53908 .65515 .53072 Mtetra
.596 .643 .867 r
.65515 .53072 .66027 .53908 .67063 .53632 .66559 .52939 Mtetra
.54 .66 .914 r
.66559 .52939 .67063 .53632 .68108 .53478 .67612 .52913 Mtetra
.496 .688 .953 r
.67612 .52913 .68108 .53478 .69162 .5339 .68672 .52917 Mtetra
.541 .749 .972 r
.68672 .52917 .69162 .5339 .70218 .53258 .69733 .52806 Mtetra
.617 .79 .964 r
.69733 .52806 .70218 .53258 .71275 .53043 .70791 .52553 Mtetra
.69 .798 .932 r
.70791 .52553 .71275 .53043 .72329 .52704 .71844 .52144 Mtetra
.722 .781 .899 r
.71844 .52144 .72329 .52704 .73381 .52272 .72894 .51634 Mtetra
.719 .755 .88 r
.72894 .51634 .73381 .52272 .74434 .51803 .73947 .51119 Mtetra
.708 .737 .874 r
.73947 .51119 .74434 .51803 .7549 .51332 .75005 .50632 Mtetra
.687 .725 .879 r
.75005 .50632 .7549 .51332 .76552 .50902 .76071 .50216 Mtetra
.668 .723 .89 r
.76071 .50216 .76552 .50902 .77621 .50515 .77144 .4986 Mtetra
.652 .728 .905 r
.77144 .4986 .77621 .50515 .78696 .50172 .78225 .49551 Mtetra
.64 .736 .918 r
.78225 .49551 .78696 .50172 .79779 .49859 .79313 .49269 Mtetra
.637 .747 .928 r
.79313 .49269 .79779 .49859 .80866 .49562 .80406 .48991 Mtetra
.636 .755 .934 r
.80406 .48991 .80866 .49562 .81959 .4927 .81502 .4871 Mtetra
.641 .762 .936 r
.81502 .4871 .81959 .4927 .83056 .48974 .82602 .48414 Mtetra
.646 .765 .935 r
.82602 .48414 .83056 .48974 .84156 .48671 .83705 .48106 Mtetra
.65 .765 .933 r
.83705 .48106 .84156 .48671 .8526 .48359 .84812 .47785 Mtetra
.654 .764 .93 r
.84812 .47785 .8526 .48359 .86368 .48038 .85922 .47455 Mtetra
.656 .762 .928 r
.85922 .47455 .86368 .48038 .87479 .47711 .87035 .47118 Mtetra
.658 .76 .925 r
.87035 .47118 .87479 .47711 .88594 .47378 .88153 .46776 Mtetra
.658 .758 .923 r
.88153 .46776 .88594 .47378 .89713 .47042 .89275 .46433 Mtetra
.659 .756 .922 r
.89275 .46433 .89713 .47042 .90836 .46702 .904 .46087 Mtetra
.659 .755 .921 r
.904 .46087 .90836 .46702 .91963 .46361 .9153 .4574 Mtetra
.659 .754 .92 r
.9153 .4574 .91963 .46361 .93095 .46018 .92665 .45393 Mtetra
.652 .751 .922 r
.31818 .62896 .32399 .63404 .33318 .63137 .32738 .62628 Mtetra
.32738 .62628 .33318 .63137 .34239 .6287 .33661 .6236 Mtetra
.651 .751 .923 r
.33661 .6236 .34239 .6287 .35164 .62602 .34588 .62093 Mtetra
.65 .752 .924 r
.34588 .62093 .35164 .62602 .36092 .62333 .35518 .61826 Mtetra
.649 .753 .925 r
.35518 .61826 .36092 .62333 .37023 .62061 .36451 .61559 Mtetra
.65 .755 .927 r
.36451 .61559 .37023 .62061 .37958 .61786 .37387 .61291 Mtetra
.65 .759 .929 r
.37387 .61291 .37958 .61786 .38896 .61504 .38327 .61019 Mtetra
.653 .764 .931 r
.38327 .61019 .38896 .61504 .39838 .61214 .39271 .6074 Mtetra
.658 .77 .933 r
.39271 .6074 .39838 .61214 .40784 .60912 .40218 .60447 Mtetra
.664 .777 .933 r
.40218 .60447 .40784 .60912 .41733 .60597 .41169 .60138 Mtetra
.674 .782 .931 r
.41169 .60138 .41733 .60597 .42685 .60269 .42124 .59806 Mtetra
.68 .783 .927 r
.42124 .59806 .42685 .60269 .43641 .59937 .43083 .59456 Mtetra
.686 .777 .921 r
.43083 .59456 .43641 .59937 .446 .5961 .44045 .59092 Mtetra
.68 .763 .914 r
.44045 .59092 .446 .5961 .45562 .59309 .4501 .58742 Mtetra
.666 .742 .907 r
.4501 .58742 .45562 .59309 .46525 .59053 .45977 .58428 Mtetra
.638 .713 .902 r
.45977 .58428 .46525 .59053 .47492 .58857 .46946 .58185 Mtetra
.599 .684 .902 r
.46946 .58185 .47492 .58857 .48462 .5873 .47917 .58039 Mtetra
.565 .665 .905 r
.47917 .58039 .48462 .5873 .49436 .58631 .48893 .57967 Mtetra
.536 .662 .918 r
.48893 .57967 .49436 .58631 .50414 .58528 .49872 .57945 Mtetra
.569 .706 .934 r
.49872 .57945 .50414 .58528 .51398 .58327 .50857 .57838 Mtetra
.643 .77 .94 r
.50857 .57838 .51398 .58327 .52386 .57974 .51847 .57564 Mtetra
.726 .822 .924 r
.51847 .57564 .52386 .57974 .53376 .57479 .52841 .57079 Mtetra
.788 .833 .887 r
.52841 .57079 .53376 .57479 .54368 .5687 .53836 .56386 Mtetra
.787 .803 .865 r
.53836 .56386 .54368 .5687 .55363 .5629 .54832 .55659 Mtetra
.758 .752 .847 r
.54832 .55659 .55363 .5629 .5636 .55815 .5583 .54995 Mtetra
.707 .688 .83 r
.5583 .54995 .5636 .55815 .57362 .55486 .56832 .54489 Mtetra
.653 .63 .814 r
.56832 .54489 .57362 .55486 .5837 .55297 .57839 .54163 Mtetra
.631 .596 .796 r
.57839 .54163 .5837 .55297 .59383 .55137 .5885 .53909 Mtetra
.624 .579 .783 r
.5885 .53909 .59383 .55137 .604 .54942 .59866 .53671 Mtetra
.638 .581 .774 r
.59866 .53671 .604 .54942 .61418 .54637 .60885 .53364 Mtetra
.652 .588 .77 r
.60885 .53364 .61418 .54637 .62437 .54223 .61905 .52988 Mtetra
.65 .592 .776 r
.61905 .52988 .62437 .54223 .63457 .53774 .62929 .52626 Mtetra
.638 .599 .794 r
.62929 .52626 .63457 .53774 .64482 .53352 .6396 .52338 Mtetra
.591 .6 .83 r
.6396 .52338 .64482 .53352 .65515 .53072 .65001 .52231 Mtetra
.522 .607 .879 r
.65001 .52231 .65515 .53072 .66559 .52939 .66053 .52284 Mtetra
.449 .631 .932 r
.66053 .52284 .66559 .52939 .67612 .52913 .67115 .52403 Mtetra
.417 .674 .968 r
.67115 .52403 .67612 .52913 .68672 .52917 .68181 .52488 Mtetra
.535 .768 .983 r
.68181 .52488 .68672 .52917 .69733 .52806 .69244 .52363 Mtetra
.656 .808 .956 r
.69244 .52363 .69733 .52806 .70791 .52553 .70301 .52025 Mtetra
.723 .794 .908 r
.70301 .52025 .70791 .52553 .71844 .52144 .71351 .51516 Mtetra
.741 .765 .872 r
.71351 .51516 .71844 .52144 .72894 .51634 .724 .5092 Mtetra
.722 .733 .86 r
.724 .5092 .72894 .51634 .73947 .51119 .73454 .50373 Mtetra
.7 .717 .863 r
.73454 .50373 .73947 .51119 .75005 .50632 .74515 .49901 Mtetra
.672 .711 .878 r
.74515 .49901 .75005 .50632 .76071 .50216 .75586 .49528 Mtetra
.648 .716 .898 r
.75586 .49528 .76071 .50216 .77144 .4986 .76667 .49229 Mtetra
.633 .73 .918 r
.76667 .49229 .77144 .4986 .78225 .49551 .77754 .48966 Mtetra
.623 .744 .933 r
.77754 .48966 .78225 .49551 .79313 .49269 .78848 .48718 Mtetra
.627 .759 .942 r
.78848 .48718 .79313 .49269 .80406 .48991 .79944 .48454 Mtetra
.633 .768 .945 r
.79944 .48454 .80406 .48991 .81502 .4871 .81044 .48173 Mtetra
.642 .773 .943 r
.81044 .48173 .81502 .4871 .82602 .48414 .82147 .47868 Mtetra
.65 .773 .939 r
.82147 .47868 .82602 .48414 .83705 .48106 .83252 .47545 Mtetra
.655 .77 .934 r
.83252 .47545 .83705 .48106 .84812 .47785 .84361 .47209 Mtetra
.659 .766 .929 r
.84361 .47209 .84812 .47785 .85922 .47455 .85473 .46864 Mtetra
.66 .762 .926 r
.85473 .46864 .85922 .47455 .87035 .47118 .86588 .46515 Mtetra
.661 .759 .923 r
.86588 .46515 .87035 .47118 .88153 .46776 .87708 .46164 Mtetra
.66 .756 .921 r
.87708 .46164 .88153 .46776 .89275 .46433 .88833 .45814 Mtetra
.66 .755 .92 r
.88833 .45814 .89275 .46433 .904 .46087 .89961 .45464 Mtetra
.659 .754 .92 r
.89961 .45464 .904 .46087 .9153 .4574 .91094 .45113 Mtetra
.659 .753 .919 r
.91094 .45113 .9153 .4574 .92665 .45393 .92232 .44763 Mtetra
.653 .751 .921 r
.31232 .62385 .31818 .62896 .32738 .62628 .32155 .62113 Mtetra
.652 .75 .921 r
.32155 .62113 .32738 .62628 .33661 .6236 .3308 .61842 Mtetra
.651 .749 .921 r
.3308 .61842 .33661 .6236 .34588 .62093 .34009 .61572 Mtetra
.65 .748 .921 r
.34009 .61572 .34588 .62093 .35518 .61826 .3494 .61304 Mtetra
.648 .748 .922 r
.3494 .61304 .35518 .61826 .36451 .61559 .35875 .6104 Mtetra
.647 .749 .924 r
.35875 .6104 .36451 .61559 .37387 .61291 .36813 .60777 Mtetra
.645 .752 .927 r
.36813 .60777 .37387 .61291 .38327 .61019 .37755 .60516 Mtetra
.646 .757 .93 r
.37755 .60516 .38327 .61019 .39271 .6074 .387 .6025 Mtetra
.649 .764 .933 r
.387 .6025 .39271 .6074 .40218 .60447 .39649 .59976 Mtetra
.656 .774 .935 r
.39649 .59976 .40218 .60447 .41169 .60138 .40601 .59684 Mtetra
.667 .784 .936 r
.40601 .59684 .41169 .60138 .42124 .59806 .41558 .59363 Mtetra
.68 .792 .934 r
.41558 .59363 .42124 .59806 .43083 .59456 .42519 .59012 Mtetra
.694 .795 .927 r
.42519 .59012 .43083 .59456 .44045 .59092 .43485 .58624 Mtetra
.697 .787 .92 r
.43485 .58624 .44045 .59092 .4501 .58742 .44453 .58227 Mtetra
.692 .769 .91 r
.44453 .58227 .4501 .58742 .45977 .58428 .45424 .5784 Mtetra
.666 .737 .902 r
.45424 .5784 .45977 .58428 .46946 .58185 .46396 .57521 Mtetra
.624 .698 .898 r
.46396 .57521 .46946 .58185 .47917 .58039 .4737 .57312 Mtetra
.573 .658 .895 r
.4737 .57312 .47917 .58039 .48893 .57967 .48347 .57228 Mtetra
.514 .629 .902 r
.48347 .57228 .48893 .57967 .49872 .57945 .49327 .57266 Mtetra
.524 .654 .917 r
.49327 .57266 .49872 .57945 .50857 .57838 .50313 .57267 Mtetra
.585 .719 .936 r
.50313 .57267 .50857 .57838 .51847 .57564 .51305 .57123 Mtetra
.699 .806 .931 r
.51305 .57123 .51847 .57564 .52841 .57079 .52302 .56709 Mtetra
.798 .846 .887 r
.52302 .56709 .52841 .57079 .53836 .56386 .533 .55981 Mtetra
.821 .832 .857 r
.533 .55981 .53836 .56386 .54832 .55659 .54299 .55124 Mtetra
.809 .789 .834 r
.54299 .55124 .54832 .55659 .5583 .54995 .55299 .54251 Mtetra
.759 .723 .82 r
.55299 .54251 .5583 .54995 .56832 .54489 .563 .53525 Mtetra
.698 .656 .805 r
.563 .53525 .56832 .54489 .57839 .54163 .57305 .53007 Mtetra
.66 .607 .785 r
.57305 .53007 .57839 .54163 .5885 .53909 .58315 .52615 Mtetra
.637 .577 .771 r
.58315 .52615 .5885 .53909 .59866 .53671 .5933 .52308 Mtetra
.635 .568 .762 r
.5933 .52308 .59866 .53671 .60885 .53364 .60348 .51998 Mtetra
.60348 .51998 .60885 .53364 .61905 .52988 .61371 .51685 Mtetra
.619 .568 .775 r
.61371 .51685 .61905 .52988 .62929 .52626 .62399 .51457 Mtetra
.59 .572 .801 r
.62399 .51457 .62929 .52626 .6396 .52338 .63436 .51357 Mtetra
.512 .567 .848 r
.63436 .51357 .6396 .52338 .65001 .52231 .64486 .51467 Mtetra
.395 .564 .902 r
.64486 .51467 .65001 .52231 .66053 .52284 .65548 .51727 Mtetra
.31 .596 .946 r
.65548 .51727 .66053 .52284 .67115 .52403 .66618 .51973 Mtetra
.342 .672 .976 r
.66618 .51973 .67115 .52403 .68181 .52488 .67688 .5209 Mtetra
.572 .799 .985 r
.67688 .5209 .68181 .52488 .69244 .52363 .6875 .51889 Mtetra
.713 .813 .927 r
.6875 .51889 .69244 .52363 .70301 .52025 .69803 .51414 Mtetra
.749 .773 .872 r
.69803 .51414 .70301 .52025 .71351 .51516 .70851 .50791 Mtetra
.748 .739 .844 r
.70851 .50791 .71351 .51516 .724 .5092 .71898 .50128 Mtetra
.714 .71 .846 r
.71898 .50128 .724 .5092 .73454 .50373 .72955 .4959 Mtetra
.681 .701 .862 r
.72955 .4959 .73454 .50373 .74515 .49901 .74023 .49179 Mtetra
.648 .706 .889 r
.74023 .49179 .74515 .49901 .75586 .49528 .75102 .48879 Mtetra
.62 .719 .917 r
.75102 .48879 .75586 .49528 .76667 .49229 .7619 .48649 Mtetra
.609 .741 .939 r
.7619 .48649 .76667 .49229 .77754 .48966 .77284 .48431 Mtetra
.608 .759 .951 r
.77284 .48431 .77754 .48966 .78848 .48718 .78382 .48203 Mtetra
.622 .774 .953 r
.78382 .48203 .78848 .48718 .79944 .48454 .79482 .47937 Mtetra
.637 .78 .95 r
.79482 .47937 .79944 .48454 .81044 .48173 .80584 .4764 Mtetra
.65 .779 .943 r
.80584 .4764 .81044 .48173 .82147 .47868 .81688 .47313 Mtetra
.658 .775 .935 r
.81688 .47313 .82147 .47868 .83252 .47545 .82795 .46967 Mtetra
.662 .768 .928 r
.82795 .46967 .83252 .47545 .84361 .47209 .83905 .46612 Mtetra
.664 .763 .923 r
.83905 .46612 .84361 .47209 .85473 .46864 .85018 .46252 Mtetra
.663 .758 .92 r
.85018 .46252 .85473 .46864 .86588 .46515 .86137 .45893 Mtetra
.662 .754 .918 r
.86137 .45893 .86588 .46515 .87708 .46164 .87259 .45536 Mtetra
.661 .752 .918 r
.87259 .45536 .87708 .46164 .88833 .45814 .88386 .45182 Mtetra
.66 .751 .918 r
.88386 .45182 .88833 .45814 .89961 .45464 .89518 .4483 Mtetra
.659 .751 .918 r
.89518 .4483 .89961 .45464 .91094 .45113 .90655 .44479 Mtetra
.658 .752 .919 r
.90655 .44479 .91094 .45113 .92232 .44763 .91796 .44128 Mtetra
.655 .751 .92 r
.30643 .61871 .31232 .62385 .32155 .62113 .31568 .61592 Mtetra
.655 .749 .919 r
.31568 .61592 .32155 .62113 .3308 .61842 .32495 .61314 Mtetra
.654 .747 .918 r
.32495 .61314 .3308 .61842 .34009 .61572 .33426 .61037 Mtetra
.652 .745 .918 r
.33426 .61037 .34009 .61572 .3494 .61304 .3436 .60765 Mtetra
.649 .743 .918 r
.3436 .60765 .3494 .61304 .35875 .6104 .35297 .60497 Mtetra
.646 .742 .919 r
.35297 .60497 .35875 .6104 .36813 .60777 .36237 .60236 Mtetra
.642 .742 .921 r
.36237 .60236 .36813 .60777 .37755 .60516 .3718 .59983 Mtetra
.64 .745 .925 r
.3718 .59983 .37755 .60516 .387 .6025 .38126 .59732 Mtetra
.638 .751 .93 r
.38126 .59732 .387 .6025 .39649 .59976 .39076 .59483 Mtetra
.643 .762 .935 r
.39076 .59483 .39649 .59976 .40601 .59684 .4003 .59219 Mtetra
.652 .777 .94 r
.4003 .59219 .40601 .59684 .41558 .59363 .40988 .58931 Mtetra
.669 .795 .942 r
.40988 .58931 .41558 .59363 .42519 .59012 .41951 .586 Mtetra
.692 .81 .938 r
.41951 .586 .42519 .59012 .43485 .58624 .42919 .58213 Mtetra
.709 .814 .93 r
.42919 .58213 .43485 .58624 .44453 .58227 .4389 .57784 Mtetra
.72 .803 .916 r
.4389 .57784 .44453 .58227 .45424 .5784 .44866 .5732 Mtetra
.704 .772 .905 r
.44866 .5732 .45424 .5784 .46396 .57521 .45842 .56898 Mtetra
.668 .727 .893 r
.45842 .56898 .46396 .57521 .4737 .57312 .4682 .5657 Mtetra
.603 .667 .885 r
.4682 .5657 .4737 .57312 .48347 .57228 .47799 .56416 Mtetra
.515 .608 .884 r
.47799 .56416 .48347 .57228 .49327 .57266 .4878 .5647 Mtetra
.485 .599 .892 r
.4878 .5647 .49327 .57266 .50313 .57267 .49767 .56577 Mtetra
.5 .641 .918 r
.49767 .56577 .50313 .57267 .51305 .57123 .50759 .56619 Mtetra
.637 .765 .94 r
.50759 .56619 .51305 .57123 .52302 .56709 .51758 .56352 Mtetra
.787 .852 .9 r
.51758 .56352 .52302 .56709 .533 .55981 .5276 .5567 Mtetra
.846 .865 .857 r
.5276 .5567 .533 .55981 .54299 .55124 .53763 .5473 Mtetra
.857 .833 .822 r
.53763 .5473 .54299 .55124 .55299 .54251 .54765 .53646 Mtetra
.816 .77 .81 r
.54765 .53646 .55299 .54251 .563 .53525 .55766 .52666 Mtetra
.753 .698 .799 r
.55766 .52666 .563 .53525 .57305 .53007 .56771 .51903 Mtetra
.699 .634 .78 r
.56771 .51903 .57305 .53007 .58315 .52615 .57778 .51325 Mtetra
.656 .588 .767 r
.57778 .51325 .58315 .52615 .5933 .52308 .58792 .5092 Mtetra
.634 .565 .759 r
.58792 .5092 .5933 .52308 .60348 .51998 .5981 .50607 Mtetra
.615 .555 .763 r
.5981 .50607 .60348 .51998 .61371 .51685 .60835 .50387 Mtetra
.576 .545 .783 r
.60835 .50387 .61371 .51685 .62399 .51457 .61869 .50341 Mtetra
.511 .539 .821 r
.61869 .50341 .62399 .51457 .63436 .51357 .62914 .50482 Mtetra
.367 .515 .874 r
.62914 .50482 .63436 .51357 .64486 .51467 .63974 .50843 Mtetra
.157 .476 .896 r
.63974 .50843 .64486 .51467 .65548 .51727 .65045 .51311 Mtetra
.112 .539 .915 r
.65045 .51311 .65548 .51727 .66618 .51973 .6612 .51637 Mtetra
.314 .703 .979 r
.6612 .51637 .66618 .51973 .67688 .5209 .67192 .51704 Mtetra
.655 .835 .969 r
.67192 .51704 .67688 .5209 .6875 .51889 .6825 .5135 Mtetra
.766 .801 .881 r
.6825 .5135 .6875 .51889 .69803 .51414 .69296 .50682 Mtetra
.762 .741 .834 r
.69296 .50682 .69803 .51414 .70851 .50791 .70341 .49946 Mtetra
.74 .708 .821 r
.70341 .49946 .70851 .50791 .71898 .50128 .71389 .49262 Mtetra
.692 .685 .839 r
.71389 .49262 .71898 .50128 .72955 .4959 .72452 .48791 Mtetra
.645 .683 .871 r
.72452 .48791 .72955 .4959 .74023 .49179 .7353 .48496 Mtetra
.608 .703 .912 r
.7353 .48496 .74023 .49179 .75102 .48879 .74619 .48299 Mtetra
.578 .729 .945 r
.74619 .48299 .75102 .48879 .7619 .48649 .75715 .48144 Mtetra
.583 .762 .964 r
.75715 .48144 .7619 .48649 .77284 .48431 .76814 .47955 Mtetra
.6 .783 .968 r
.76814 .47955 .77284 .48431 .78382 .48203 .77916 .47722 Mtetra
.629 .793 .961 r
.77916 .47722 .78382 .48203 .79482 .47937 .79017 .4743 Mtetra
.651 .791 .949 r
.79017 .4743 .79482 .47937 .80584 .4764 .8012 .47095 Mtetra
.663 .781 .936 r
.8012 .47095 .80584 .4764 .81688 .47313 .81224 .46735 Mtetra
.67 .771 .926 r
.81224 .46735 .81688 .47313 .82795 .46967 .82331 .46359 Mtetra
.669 .761 .919 r
.82331 .46359 .82795 .46967 .83905 .46612 .83443 .45984 Mtetra
.668 .754 .915 r
.83443 .45984 .83905 .46612 .85018 .46252 .84559 .45611 Mtetra
.665 .749 .913 r
.84559 .45611 .85018 .46252 .86137 .45893 .85679 .45247 Mtetra
.662 .747 .913 r
.85679 .45247 .86137 .45893 .87259 .45536 .86805 .44888 Mtetra
.66 .746 .914 r
.86805 .44888 .87259 .45536 .88386 .45182 .87936 .44535 Mtetra
.658 .747 .915 r
.87936 .44535 .88386 .45182 .89518 .4483 .89072 .44185 Mtetra
.657 .748 .917 r
.89072 .44185 .89518 .4483 .90655 .44479 .90212 .43837 Mtetra
.656 .75 .919 r
.90212 .43837 .90655 .44479 .91796 .44128 .91357 .43489 Mtetra
.658 .752 .919 r
.3005 .61354 .30643 .61871 .31568 .61592 .30977 .61067 Mtetra
.658 .75 .918 r
.30977 .61067 .31568 .61592 .32495 .61314 .31907 .60779 Mtetra
.657 .747 .916 r
.31907 .60779 .32495 .61314 .33426 .61037 .3284 .60493 Mtetra
.655 .743 .915 r
.3284 .60493 .33426 .61037 .3436 .60765 .33776 .60211 Mtetra
.652 .74 .914 r
.33776 .60211 .3436 .60765 .35297 .60497 .34715 .59935 Mtetra
.648 .736 .914 r
.34715 .59935 .35297 .60497 .36237 .60236 .35658 .59668 Mtetra
.643 .733 .915 r
.35658 .59668 .36237 .60236 .3718 .59983 .36602 .59413 Mtetra
.637 .732 .917 r
.36602 .59413 .3718 .59983 .38126 .59732 .3755 .5917 Mtetra
.63 .733 .922 r
.3755 .5917 .38126 .59732 .39076 .59483 .38501 .5894 Mtetra
.63 .741 .928 r
.38501 .5894 .39076 .59483 .4003 .59219 .39456 .58708 Mtetra
.633 .755 .936 r
.39456 .58708 .4003 .59219 .40988 .58931 .40415 .58465 Mtetra
.648 .778 .942 r
.40415 .58465 .40988 .58931 .41951 .586 .41378 .5818 Mtetra
.675 .804 .944 r
.41378 .5818 .41951 .586 .42919 .58213 .42348 .57832 Mtetra
.705 .826 .94 r
.42348 .57832 .42919 .58213 .4389 .57784 .43322 .57408 Mtetra
.737 .834 .924 r
.43322 .57408 .4389 .57784 .44866 .5732 .44301 .569 Mtetra
.74 .817 .912 r
.44301 .569 .44866 .5732 .45842 .56898 .45283 .56377 Mtetra
.722 .777 .896 r
.45283 .56377 .45842 .56898 .4682 .5657 .46266 .55895 Mtetra
.655 .708 .886 r
.46266 .55895 .4682 .5657 .47799 .56416 .47249 .556 Mtetra
.55 .625 .879 r
.47249 .556 .47799 .56416 .4878 .5647 .48232 .55576 Mtetra
.476 .568 .869 r
.48232 .55576 .4878 .5647 .49767 .56577 .49218 .55729 Mtetra
.421 .553 .882 r
.49218 .55729 .49767 .56577 .50759 .56619 .5021 .55963 Mtetra
.543 .675 .924 r
.5021 .55963 .50759 .56619 .51758 .56352 .5121 .55915 Mtetra
.733 .817 .917 r
.5121 .55915 .51758 .56352 .5276 .5567 .52216 .55403 Mtetra
.844 .884 .869 r
.52216 .55403 .5276 .5567 .53763 .5473 .53223 .54494 Mtetra
.892 .879 .815 r
.53223 .54494 .53763 .5473 .54765 .53646 .54229 .53273 Mtetra
.874 .838 .807 r
.54229 .53273 .54765 .53646 .55766 .52666 .55233 .52068 Mtetra
.823 .775 .807 r
.55233 .52068 .55766 .52666 .56771 .51903 .56237 .51045 Mtetra
.758 .7 .798 r
.56237 .51045 .56771 .51903 .57778 .51325 .57244 .50255 Mtetra
.691 .637 .79 r
.57244 .50255 .57778 .51325 .58792 .5092 .58256 .49731 Mtetra
.641 .595 .787 r
.58256 .49731 .58792 .5092 .5981 .50607 .59275 .49416 Mtetra
.59 .569 .798 r
.59275 .49416 .5981 .50607 .60835 .50387 .60303 .49309 Mtetra
.499 .54 .83 r
.60303 .49309 .60835 .50387 .61869 .50341 .61343 .4947 Mtetra
.339 .501 .873 r
.61343 .4947 .61869 .50341 .62914 .50482 .62397 .49868 Mtetra
.033 .399 .854 r
.62397 .49868 .62914 .50482 .63974 .50843 .63466 .50452 Mtetra
0 .295 .731 r
.63466 .50452 .63974 .50843 .65045 .51311 .64545 .51055 Mtetra
0 .501 .831 r
.64545 .51055 .65045 .51311 .6612 .51637 .65621 .51346 Mtetra
.449 .796 .998 r
.65621 .51346 .6612 .51637 .67192 .51704 .66688 .51237 Mtetra
.747 .825 .912 r
.66688 .51237 .67192 .51704 .6825 .5135 .67739 .50657 Mtetra
.791 .759 .825 r
.67739 .50657 .6825 .5135 .69296 .50682 .68779 .49788 Mtetra
.754 .702 .803 r
.68779 .49788 .69296 .50682 .70341 .49946 .69823 .49001 Mtetra
.716 .678 .812 r
.69823 .49001 .70341 .49946 .71389 .49262 .70878 .48392 Mtetra
.655 .669 .852 r
.70878 .48392 .71389 .49262 .72452 .48791 .71952 .48059 Mtetra
.587 .679 .904 r
.71952 .48059 .72452 .48791 .7353 .48496 .73041 .47919 Mtetra
.548 .717 .951 r
.73041 .47919 .7353 .48496 .74619 .48299 .74139 .4782 Mtetra
.531 .752 .977 r
.74139 .4782 .74619 .48299 .75715 .48144 .75242 .47707 Mtetra
.571 .789 .981 r
.75242 .47707 .75715 .48144 .76814 .47955 .76344 .47508 Mtetra
.615 .803 .972 r
.76344 .47508 .76814 .47955 .77916 .47722 .77445 .47231 Mtetra
.653 .799 .953 r
.77445 .47231 .77916 .47722 .79017 .4743 .78546 .46888 Mtetra
.673 .786 .934 r
.78546 .46888 .79017 .4743 .8012 .47095 .79648 .46502 Mtetra
.678 .769 .92 r
.79648 .46502 .8012 .47095 .81224 .46735 .80752 .46104 Mtetra
.678 .757 .911 r
.80752 .46104 .81224 .46735 .82331 .46359 .81861 .45704 Mtetra
.673 .747 .907 r
.81861 .45704 .82331 .46359 .83443 .45984 .82974 .45317 Mtetra
.668 .742 .906 r
.82974 .45317 .83443 .45984 .84559 .45611 .84093 .44941 Mtetra
.664 .74 .907 r
.84093 .44941 .84559 .45611 .85679 .45247 .85217 .44578 Mtetra
.66 .74 .909 r
.85217 .44578 .85679 .45247 .86805 .44888 .86347 .44224 Mtetra
.657 .741 .912 r
.86347 .44224 .86805 .44888 .87936 .44535 .87482 .43876 Mtetra
.655 .743 .915 r
.87482 .43876 .87936 .44535 .89072 .44185 .88621 .43532 Mtetra
.654 .746 .917 r
.88621 .43532 .89072 .44185 .90212 .43837 .89766 .43189 Mtetra
.654 .748 .919 r
.89766 .43189 .90212 .43837 .91357 .43489 .90915 .42846 Mtetra
.661 .753 .918 r
.29453 .60833 .3005 .61354 .30977 .61067 .30382 .60538 Mtetra
.661 .75 .916 r
.30382 .60538 .30977 .61067 .31907 .60779 .31315 .60241 Mtetra
.661 .748 .914 r
.31315 .60241 .31907 .60779 .3284 .60493 .32251 .59944 Mtetra
.66 .744 .912 r
.32251 .59944 .3284 .60493 .33776 .60211 .33189 .59649 Mtetra
.658 .74 .91 r
.33189 .59649 .33776 .60211 .34715 .59935 .34131 .59357 Mtetra
.654 .734 .908 r
.34131 .59357 .34715 .59935 .35658 .59668 .35076 .59074 Mtetra
.648 .727 .906 r
.35076 .59074 .35658 .59668 .36602 .59413 .36023 .58806 Mtetra
.64 .72 .906 r
.36023 .58806 .36602 .59413 .3755 .5917 .36973 .58556 Mtetra
.629 .715 .909 r
.36973 .58556 .3755 .5917 .38501 .5894 .37925 .58333 Mtetra
.621 .716 .914 r
.37925 .58333 .38501 .5894 .39456 .58708 .38881 .58126 Mtetra
.612 .723 .924 r
.38881 .58126 .39456 .58708 .40415 .58465 .3984 .57933 Mtetra
.619 .745 .936 r
.3984 .57933 .40415 .58465 .41378 .5818 .40803 .57718 Mtetra
.638 .778 .948 r
.40803 .57718 .41378 .5818 .42348 .57832 .41772 .57451 Mtetra
.677 .823 .953 r
.41772 .57451 .42348 .57832 .43322 .57408 .42748 .57089 Mtetra
.731 .858 .941 r
.42748 .57089 .43322 .57408 .44301 .569 .4373 .56593 Mtetra
.765 .866 .923 r
.4373 .56593 .44301 .569 .45283 .56377 .44716 .56002 Mtetra
.78 .839 .897 r
.44716 .56002 .45283 .56377 .46266 .55895 .45706 .55347 Mtetra
.727 .77 .887 r
.45706 .55347 .46266 .55895 .47249 .556 .46695 .54841 Mtetra
.628 .675 .876 r
.46695 .54841 .47249 .556 .48232 .55576 .47682 .54615 Mtetra
.51 .57 .852 r
.47682 .54615 .48232 .55576 .49218 .55729 .48669 .54711 Mtetra
.374 .483 .842 r
.48669 .54711 .49218 .55729 .5021 .55963 .4966 .551 Mtetra
.43 .555 .88 r
.4966 .551 .5021 .55963 .5121 .55915 .5066 .55322 Mtetra
.609 .726 .928 r
.5066 .55322 .5121 .55915 .52216 .55403 .51667 .55124 Mtetra
.799 .887 .909 r
.51667 .55124 .52216 .55403 .53223 .54494 .52678 .54407 Mtetra
.904 .927 .82 r
.52678 .54407 .53223 .54494 .54229 .53273 .53689 .53182 Mtetra
.918 .917 .799 r
.53689 .53182 .54229 .53273 .55233 .52068 .54698 .51834 Mtetra
.898 .881 .809 r
.54698 .51834 .55233 .52068 .56237 .51045 .55704 .50573 Mtetra
.838 .815 .828 r
.55704 .50573 .56237 .51045 .57244 .50255 .56712 .4957 Mtetra
.75 .742 .844 r
.56712 .4957 .57244 .50255 .58256 .49731 .57725 .48918 Mtetra
.655 .676 .858 r
.57725 .48918 .58256 .49731 .59275 .49416 .58746 .486 Mtetra
.529 .62 .886 r
.58746 .486 .59275 .49416 .60303 .49309 .59778 .48617 Mtetra
.271 .522 .909 r
.59778 .48617 .60303 .49309 .61343 .4947 .60825 .48988 Mtetra
0 .309 .77 r
.60825 .48988 .61343 .4947 .62397 .49868 .61887 .49621 Mtetra
.484 0 0 r
.61887 .49621 .62397 .49868 .63466 .50452 .62963 .50345 Mtetra
.496 0 0 r
.62963 .50345 .63466 .50452 .64545 .51055 .64044 .50949 Mtetra
.018 .583 .794 r
.64044 .50949 .64545 .51055 .65621 .51346 .65117 .51042 Mtetra
.678 .879 .973 r
.65117 .51042 .65621 .51346 .66688 .51237 .66174 .50611 Mtetra
.797 .78 .837 r
.66174 .50611 .66688 .51237 .67739 .50657 .67216 .49753 Mtetra
.79 .712 .779 r
.67216 .49753 .67739 .50657 .68779 .49788 .6825 .48721 Mtetra
.728 .661 .784 r
.6825 .48721 .68779 .49788 .69823 .49001 .69299 .47987 Mtetra
.668 .644 .818 r
.69299 .47987 .69823 .49001 .70878 .48392 .70367 .47579 Mtetra
.584 .653 .884 r
.70367 .47579 .70878 .48392 .71952 .48059 .71455 .47458 Mtetra
.477 .675 .951 r
.71455 .47458 .71952 .48059 .73041 .47919 .72558 .4749 Mtetra
.456 .739 .989 r
.72558 .4749 .73041 .47919 .74139 .4782 .73664 .47458 Mtetra
.496 .791 .998 r
.73664 .47458 .74139 .4782 .75242 .47707 .74769 .47328 Mtetra
.593 .826 .988 r
.74769 .47328 .75242 .47707 .76344 .47508 .7587 .47061 Mtetra
.658 .82 .962 r
.7587 .47061 .76344 .47508 .77445 .47231 .76968 .46696 Mtetra
.685 .794 .932 r
.76968 .46696 .77445 .47231 .78546 .46888 .78067 .46277 Mtetra
.693 .769 .91 r
.78067 .46277 .78546 .46888 .79648 .46502 .79167 .45835 Mtetra
.686 .748 .898 r
.79167 .45835 .79648 .46502 .80752 .46104 .80272 .45406 Mtetra
.68 .736 .893 r
.80272 .45406 .80752 .46104 .81861 .45704 .81383 .44994 Mtetra
.671 .73 .894 r
.81383 .44994 .81861 .45704 .82974 .45317 .82499 .44609 Mtetra
.664 .728 .898 r
.82499 .44609 .82974 .45317 .84093 .44941 .83622 .44243 Mtetra
.659 .73 .902 r
.83622 .44243 .84093 .44941 .85217 .44578 .84751 .43892 Mtetra
.655 .734 .907 r
.84751 .43892 .85217 .44578 .86347 .44224 .85885 .4355 Mtetra
.653 .738 .912 r
.85885 .4355 .86347 .44224 .87482 .43876 .87024 .43212 Mtetra
.652 .741 .915 r
.87024 .43212 .87482 .43876 .88621 .43532 .88168 .42875 Mtetra
.651 .744 .918 r
.88168 .42875 .88621 .43532 .89766 .43189 .89316 .42537 Mtetra
.652 .747 .92 r
.89316 .42537 .89766 .43189 .90915 .42846 .90469 .42197 Mtetra
.661 .753 .918 r
.28853 .60308 .29453 .60833 .30382 .60538 .29784 .6001 Mtetra
.663 .752 .917 r
.29784 .6001 .30382 .60538 .31315 .60241 .30719 .59707 Mtetra
.663 .751 .916 r
.30719 .59707 .31315 .60241 .32251 .59944 .31657 .59402 Mtetra
.664 .749 .914 r
.31657 .59402 .32251 .59944 .33189 .59649 .32598 .59095 Mtetra
.664 .746 .911 r
.32598 .59095 .33189 .59649 .34131 .59357 .33543 .58786 Mtetra
.662 .74 .908 r
.33543 .58786 .34131 .59357 .35076 .59074 .3449 .58482 Mtetra
.658 .732 .904 r
.3449 .58482 .35076 .59074 .36023 .58806 .35441 .58188 Mtetra
.649 .721 .901 r
.35441 .58188 .36023 .58806 .36973 .58556 .36393 .57914 Mtetra
.636 .71 .9 r
.36393 .57914 .36973 .58556 .37925 .58333 .37348 .57672 Mtetra
.622 .7 .9 r
.37348 .57672 .37925 .58333 .38881 .58126 .38305 .57465 Mtetra
.603 .693 .906 r
.38305 .57465 .38881 .58126 .3984 .57933 .39264 .573 Mtetra
.596 .701 .916 r
.39264 .573 .3984 .57933 .40803 .57718 .40227 .57145 Mtetra
.595 .723 .933 r
.40227 .57145 .40803 .57718 .41772 .57451 .41195 .5698 Mtetra
.629 .775 .95 r
.41195 .5698 .41772 .57451 .42748 .57089 .4217 .56729 Mtetra
.689 .836 .954 r
.4217 .56729 .42748 .57089 .4373 .56593 .43152 .56333 Mtetra
.755 .886 .938 r
.43152 .56333 .4373 .56593 .44716 .56002 .44142 .55764 Mtetra
.812 .893 .901 r
.44142 .55764 .44716 .56002 .45706 .55347 .45137 .5501 Mtetra
.798 .856 .893 r
.45137 .5501 .45706 .55347 .46695 .54841 .46133 .54291 Mtetra
.735 .773 .884 r
.46133 .54291 .46695 .54841 .47682 .54615 .47127 .53753 Mtetra
.59 .634 .862 r
.47127 .53753 .47682 .54615 .48669 .54711 .48118 .53632 Mtetra
.394 .482 .831 r
.48118 .53632 .48669 .54711 .4966 .551 .49109 .54007 Mtetra
.374 .468 .828 r
.49109 .54007 .4966 .551 .5066 .55322 .50107 .54428 Mtetra
.45 .559 .874 r
.50107 .54428 .5066 .55322 .51667 .55124 .51114 .54624 Mtetra
.67 .783 .934 r
.51114 .54624 .51667 .55124 .52678 .54407 .52129 .54273 Mtetra
.867 .932 .864 r
.52129 .54273 .52678 .54407 .53689 .53182 .53145 .53274 Mtetra
.909 .972 .796 r
.53145 .53274 .53689 .53182 .54698 .51834 .5416 .51985 Mtetra
.913 .978 .773 r
.5416 .51985 .54698 .51834 .55704 .50573 .55172 .50626 Mtetra
.884 .98 .826 r
.55172 .50626 .55704 .50573 .56712 .4957 .56184 .49493 Mtetra
.791 .969 .915 r
.56184 .49493 .56712 .4957 .57725 .48918 .572 .48746 Mtetra
.57 .893 .987 r
.572 .48746 .57725 .48918 .58746 .486 .58225 .48426 Mtetra
.079 .613 .861 r
.58225 .48426 .58746 .486 .59778 .48617 .59262 .48536 Mtetra
.45 0 0 r
.59262 .48536 .59778 .48617 .60825 .48988 .60315 .49033 Mtetra
.633 .079 0 r
.60315 .49033 .60825 .48988 .61887 .49621 .61383 .49762 Mtetra
.622 .079 0 r
.61383 .49762 .61887 .49621 .62963 .50345 .6246 .50424 Mtetra
.444 0 0 r
.6246 .50424 .62963 .50345 .64044 .50949 .63538 .50796 Mtetra
.505 .877 .977 r
.63538 .50796 .64044 .50949 .65117 .51042 .646 .50515 Mtetra
.804 .812 .858 r
.646 .50515 .65117 .51042 .66174 .50611 .65645 .4968 Mtetra
.791 .708 .773 r
.65645 .4968 .66174 .50611 .67216 .49753 .6668 .48614 Mtetra
.763 .666 .754 r
.6668 .48614 .67216 .49753 .6825 .48721 .67717 .47592 Mtetra
.684 .632 .791 r
.67717 .47592 .6825 .48721 .69299 .47987 .68778 .47074 Mtetra
.578 .625 .862 r
.68778 .47074 .69299 .47987 .70367 .47579 .69865 .46979 Mtetra
.436 .655 .952 r
.69865 .46979 .70367 .47579 .71455 .47458 .70968 .47072 Mtetra
.287 .668 .972 r
.70968 .47072 .71455 .47458 .72558 .4749 .7208 .47201 Mtetra
.388 .771 .991 r
.7208 .47201 .72558 .4749 .73664 .47458 .73187 .47142 Mtetra
.549 .838 .998 r
.73187 .47142 .73664 .47458 .74769 .47328 .74289 .46906 Mtetra
.663 .834 .965 r
.74289 .46906 .74769 .47328 .7587 .47061 .75385 .46521 Mtetra
.705 .799 .923 r
.75385 .46521 .7587 .47061 .76968 .46696 .76479 .46046 Mtetra
.705 .76 .895 r
.76479 .46046 .76968 .46696 .78067 .46277 .77576 .4556 Mtetra
.698 .737 .881 r
.77576 .4556 .78067 .46277 .79167 .45835 .78677 .45084 Mtetra
.684 .723 .879 r
.78677 .45084 .79167 .45835 .80272 .45406 .79784 .44652 Mtetra
.673 .718 .883 r
.79784 .44652 .80272 .45406 .81383 .44994 .80899 .44254 Mtetra
.663 .719 .89 r
.80899 .44254 .81383 .44994 .82499 .44609 .82021 .4389 Mtetra
.655 .723 .898 r
.82021 .4389 .82499 .44609 .83622 .44243 .83149 .43547 Mtetra
.652 .729 .906 r
.83149 .43547 .83622 .44243 .84751 .43892 .84282 .43213 Mtetra
.649 .735 .912 r
.84282 .43213 .84751 .43892 .85885 .4355 .85421 .42885 Mtetra
.649 .741 .916 r
.85421 .42885 .85885 .4355 .87024 .43212 .86564 .42554 Mtetra
.649 .744 .919 r
.86564 .42554 .87024 .43212 .88168 .42875 .87712 .42221 Mtetra
.65 .747 .92 r
.87712 .42221 .88168 .42875 .89316 .42537 .88864 .41885 Mtetra
.651 .748 .921 r
.88864 .41885 .89316 .42537 .90469 .42197 .90021 .41544 Mtetra
.66 .752 .919 r
.28248 .59781 .28853 .60308 .29784 .6001 .29181 .59484 Mtetra
.661 .754 .919 r
.29181 .59484 .29784 .6001 .30719 .59707 .30117 .59183 Mtetra
.663 .756 .919 r
.30117 .59183 .30719 .59707 .31657 .59402 .31058 .58876 Mtetra
.665 .756 .918 r
.31058 .58876 .31657 .59402 .32598 .59095 .32001 .58563 Mtetra
.669 .755 .915 r
.32001 .58563 .32598 .59095 .33543 .58786 .32949 .58239 Mtetra
.67 .751 .911 r
.32949 .58239 .33543 .58786 .3449 .58482 .339 .57912 Mtetra
.67 .744 .906 r
.339 .57912 .3449 .58482 .35441 .58188 .34854 .57583 Mtetra
.665 .731 .899 r
.34854 .57583 .35441 .58188 .36393 .57914 .3581 .57267 Mtetra
.654 .715 .893 r
.3581 .57267 .36393 .57914 .37348 .57672 .36769 .56976 Mtetra
.637 .695 .887 r
.36769 .56976 .37348 .57672 .38305 .57465 .37729 .56731 Mtetra
.611 .675 .886 r
.37729 .56731 .38305 .57465 .39264 .573 .3869 .56552 Mtetra
.588 .662 .889 r
.3869 .56552 .39264 .573 .40227 .57145 .39653 .56428 Mtetra
.559 .66 .904 r
.39653 .56428 .40227 .57145 .41195 .5698 .40619 .5636 Mtetra
.566 .697 .929 r
.40619 .5636 .41195 .5698 .4217 .56729 .41591 .56257 Mtetra
.602 .768 .959 r
.41591 .56257 .4217 .56729 .43152 .56333 .4257 .56051 Mtetra
.692 .872 .966 r
.4257 .56051 .43152 .56333 .44142 .55764 .43559 .55628 Mtetra
.799 .935 .92 r
.43559 .55628 .44142 .55764 .45137 .5501 .44558 .5491 Mtetra
.843 .94 .887 r
.44558 .5491 .45137 .5501 .46133 .54291 .45562 .54034 Mtetra
.846 .881 .866 r
.45562 .54034 .46133 .54291 .47127 .53753 .46566 .53115 Mtetra
.72 .743 .87 r
.46566 .53115 .47127 .53753 .48118 .53632 .47565 .52607 Mtetra
.504 .555 .841 r
.47565 .52607 .48118 .53632 .49109 .54007 .48558 .52725 Mtetra
.394 .444 .794 r
.48558 .52725 .49109 .54007 .50107 .54428 .49555 .53183 Mtetra
.324 .409 .795 r
.49555 .53183 .50107 .54428 .51114 .54624 .50559 .53773 Mtetra
.459 .577 .886 r
.50559 .53773 .51114 .54624 .52129 .54273 .51574 .53933 Mtetra
.727 .862 .945 r
.51574 .53933 .52129 .54273 .53145 .53274 .52595 .53424 Mtetra
.805 1 .827 r
.52595 .53424 .53145 .53274 .5416 .51985 .53617 .52462 Mtetra
.72 .936 .615 r
.53617 .52462 .5416 .51985 .55172 .50626 .54638 .51219 Mtetra
0 0 0 r
.54638 .51219 .55172 .50626 .56184 .49493 .55657 .50104 Mtetra
.55657 .50104 .56184 .49493 .572 .48746 .5668 .49326 Mtetra
.196 0 0 r
.5668 .49326 .572 .48746 .58225 .48426 .57711 .49005 Mtetra
.473 0 .049 r
.57711 .49005 .58225 .48426 .59262 .48536 .58754 .49143 Mtetra
.599 .143 .142 r
.58754 .49143 .59262 .48536 .60315 .49033 .59812 .49621 Mtetra
.632 .178 .155 r
.59812 .49621 .60315 .49033 .61383 .49762 .60882 .5023 Mtetra
.535 .041 .029 r
.60882 .5023 .61383 .49762 .6246 .50424 .61954 .5056 Mtetra
.01 0 0 r
.61954 .5056 .6246 .50424 .63538 .50796 .6302 .50434 Mtetra
.812 .874 .892 r
.6302 .50434 .63538 .50796 .646 .50515 .64067 .49633 Mtetra
.817 .724 .763 r
.64067 .49633 .646 .50515 .65645 .4968 .65099 .48393 Mtetra
.76 .646 .735 r
.65099 .48393 .65645 .4968 .6668 .48614 .66135 .47284 Mtetra
.712 .619 .751 r
.66135 .47284 .6668 .48614 .67717 .47592 .67185 .46518 Mtetra
.592 .598 .827 r
.67185 .46518 .67717 .47592 .68778 .47074 .68266 .46388 Mtetra
.333 .566 .924 r
.68266 .46388 .68778 .47074 .69865 .46979 .69375 .46679 Mtetra
.074 .565 .895 r
.69375 .46679 .69865 .46979 .70968 .47072 .70489 .46928 Mtetra
.075 .619 .845 r
.70489 .46928 .70968 .47072 .7208 .47201 .71603 .47016 Mtetra
.447 .843 .978 r
.71603 .47016 .7208 .47201 .73187 .47142 .72705 .46804 Mtetra
.675 .874 .974 r
.72705 .46804 .73187 .47142 .74289 .46906 .73798 .46368 Mtetra
.727 .806 .914 r
.73798 .46368 .74289 .46906 .75385 .46521 .74887 .45826 Mtetra
.728 .754 .873 r
.74887 .45826 .75385 .46521 .76479 .46046 .75977 .45247 Mtetra
.706 .717 .858 r
.75977 .45247 .76479 .46046 .77576 .4556 .77073 .44724 Mtetra
.689 .701 .857 r
.77073 .44724 .77576 .4556 .78677 .45084 .78178 .44259 Mtetra
.671 .697 .866 r
.78178 .44259 .78677 .45084 .79784 .44652 .79291 .4386 Mtetra
.657 .702 .88 r
.79291 .4386 .79784 .44652 .80899 .44254 .80412 .43509 Mtetra
.649 .712 .894 r
.80412 .43509 .80899 .44254 .82021 .4389 .8154 .43183 Mtetra
.643 .723 .906 r
.8154 .43183 .82021 .4389 .83149 .43547 .82674 .42872 Mtetra
.643 .735 .915 r
.82674 .42872 .83149 .43547 .84282 .43213 .83813 .42558 Mtetra
.644 .743 .921 r
.83813 .42558 .84282 .43213 .85421 .42885 .84956 .4224 Mtetra
.647 .748 .924 r
.84956 .4224 .85421 .42885 .86564 .42554 .86103 .41912 Mtetra
.649 .751 .924 r
.86103 .41912 .86564 .42554 .87712 .42221 .87254 .41576 Mtetra
.651 .752 .924 r
.87254 .41576 .87712 .42221 .88864 .41885 .88409 .41234 Mtetra
.652 .751 .922 r
.88409 .41234 .88864 .41885 .90021 .41544 .89569 .40886 Mtetra
.655 .751 .92 r
.27639 .59249 .28248 .59781 .29181 .59484 .28574 .58961 Mtetra
.656 .755 .923 r
.28574 .58961 .29181 .59484 .30117 .59183 .29511 .58669 Mtetra
.659 .76 .925 r
.29511 .58669 .30117 .59183 .31058 .58876 .30453 .58369 Mtetra
.663 .764 .925 r
.30453 .58369 .31058 .58876 .32001 .58563 .31399 .58059 Mtetra
.668 .768 .924 r
.31399 .58059 .32001 .58563 .32949 .58239 .32348 .57735 Mtetra
.674 .769 .922 r
.32348 .57735 .32949 .58239 .339 .57912 .33302 .57396 Mtetra
.68 .767 .916 r
.33302 .57396 .339 .57912 .34854 .57583 .34259 .5704 Mtetra
.681 .758 .91 r
.34259 .5704 .34854 .57583 .3581 .57267 .3522 .56681 Mtetra
.678 .743 .9 r
.3522 .56681 .3581 .57267 .36769 .56976 .36184 .56327 Mtetra
.663 .719 .89 r
.36184 .56327 .36769 .56976 .37729 .56731 .37149 .56011 Mtetra
.638 .69 .882 r
.37149 .56011 .37729 .56731 .3869 .56552 .38115 .55759 Mtetra
.605 .657 .875 r
.38115 .55759 .3869 .56552 .39653 .56428 .3908 .55596 Mtetra
.558 .627 .876 r
.3908 .55596 .39653 .56428 .40619 .5636 .40046 .55548 Mtetra
.534 .623 .886 r
.40046 .55548 .40619 .5636 .41591 .56257 .41016 .55547 Mtetra
.52 .649 .915 r
.41016 .55547 .41591 .56257 .4257 .56051 .4199 .55546 Mtetra
.589 .752 .955 r
.4199 .55546 .4257 .56051 .43559 .55628 .42975 .55367 Mtetra
.715 .886 .959 r
.42975 .55367 .43559 .55628 .44558 .5491 .43972 .54887 Mtetra
.82 .969 .898 r
.43972 .54887 .44558 .5491 .45562 .54034 .44979 .54063 Mtetra
.894 .959 .832 r
.44979 .54063 .45562 .54034 .46566 .53115 .45993 .52914 Mtetra
.85 .904 .873 r
.45993 .52914 .46566 .53115 .47565 .52607 .47002 .51993 Mtetra
.688 .745 .895 r
.47002 .51993 .47565 .52607 .48558 .52725 .48004 .51595 Mtetra
.491 .528 .822 r
.48004 .51595 .48558 .52725 .49555 .53183 .49003 .51767 Mtetra
.314 .375 .766 r
.49003 .51767 .49555 .53183 .50559 .53773 .50005 .52461 Mtetra
.354 .418 .789 r
.50005 .52461 .50559 .53773 .51574 .53933 .51017 .53018 Mtetra
.496 .581 .87 r
.51017 .53018 .51574 .53933 .52595 .53424 .5204 .53121 Mtetra
.667 .869 .976 r
.5204 .53121 .52595 .53424 .53617 .52462 .53067 .52728 Mtetra
.644 .953 .747 r
.53067 .52728 .53617 .52462 .54638 .51219 .54096 .51891 Mtetra
0 0 0 r
.54096 .51891 .54638 .51219 .55657 .50104 .55125 .51026 Mtetra
.122 0 0 r
.55125 .51026 .55657 .50104 .5668 .49326 .56157 .50342 Mtetra
.352 0 .14 r
.56157 .50342 .5668 .49326 .57711 .49005 .57195 .5002 Mtetra
.487 .086 .205 r
.57195 .5002 .57711 .49005 .58754 .49143 .58244 .50062 Mtetra
.535 .121 .203 r
.58244 .50062 .58754 .49143 .59812 .49621 .59303 .50288 Mtetra
.506 .049 .101 r
.59303 .50288 .59812 .49621 .60882 .5023 .60368 .50486 Mtetra
.003 0 0 r
.60368 .50486 .60882 .5023 .61954 .5056 .61429 .50239 Mtetra
.8 .89 .909 r
.61429 .50239 .61954 .5056 .6302 .50434 .6248 .49491 Mtetra
.806 .711 .76 r
.6248 .49491 .6302 .50434 .64067 .49633 .63516 .48283 Mtetra
.779 .648 .717 r
.63516 .48283 .64067 .49633 .65099 .48393 .64546 .46932 Mtetra
.711 .604 .736 r
.64546 .46932 .65099 .48393 .66135 .47284 .65594 .46108 Mtetra
.621 .595 .803 r
.65594 .46108 .66135 .47284 .67185 .46518 .66668 .45861 Mtetra
.318 .57 .93 r
.66668 .45861 .67185 .46518 .68266 .46388 .67771 .46148 Mtetra
0 .289 .654 r
.67771 .46148 .68266 .46388 .69375 .46679 .68895 .46669 Mtetra
.2 0 0 r
.68895 .46669 .69375 .46679 .70489 .46928 .70011 .46861 Mtetra
.268 .769 .878 r
.70011 .46861 .70489 .46928 .71603 .47016 .71114 .46703 Mtetra
.685 .888 .972 r
.71114 .46703 .71603 .47016 .72705 .46804 .72205 .46236 Mtetra
.757 .803 .89 r
.72205 .46236 .72705 .46804 .73798 .46368 .73288 .45585 Mtetra
.738 .733 .846 r
.73288 .45585 .73798 .46368 .74887 .45826 .74373 .44933 Mtetra
.718 .699 .831 r
.74373 .44933 .74887 .45826 .75977 .45247 .75463 .44328 Mtetra
.689 .682 .838 r
.75463 .44328 .75977 .45247 .77073 .44724 .76565 .43841 Mtetra
.667 .682 .855 r
.76565 .43841 .77073 .44724 .78178 .44259 .77677 .43446 Mtetra
.65 .693 .877 r
.77677 .43446 .78178 .44259 .79291 .4386 .78798 .43117 Mtetra
.636 .708 .899 r
.78798 .43117 .79291 .4386 .80412 .43509 .79928 .42826 Mtetra
.633 .728 .916 r
.79928 .42826 .80412 .43509 .8154 .43183 .81063 .42541 Mtetra
.632 .742 .927 r
.81063 .42541 .8154 .43183 .82674 .42872 .82202 .42252 Mtetra
.637 .754 .933 r
.82202 .42252 .82674 .42872 .83813 .42558 .83345 .41946 Mtetra
.642 .759 .934 r
.83345 .41946 .83813 .42558 .84956 .4224 .84492 .41625 Mtetra
.648 .762 .932 r
.84492 .41625 .84956 .4224 .86103 .41912 .85641 .41288 Mtetra
.652 .761 .93 r
.85641 .41288 .86103 .41912 .87254 .41576 .86795 .4094 Mtetra
.654 .759 .926 r
.86795 .4094 .87254 .41576 .88409 .41234 .87952 .40584 Mtetra
.656 .755 .923 r
.87952 .40584 .88409 .41234 .89569 .40886 .89113 .40224 Mtetra
.649 .75 .923 r
.27027 .58715 .27639 .59249 .28574 .58961 .27962 .58439 Mtetra
.649 .755 .927 r
.27962 .58439 .28574 .58961 .29511 .58669 .28901 .58162 Mtetra
.65 .762 .931 r
.28901 .58162 .29511 .58669 .30453 .58369 .29843 .57879 Mtetra
.654 .77 .934 r
.29843 .57879 .30453 .58369 .31399 .58059 .3079 .57585 Mtetra
.66 .778 .936 r
.3079 .57585 .31399 .58059 .32348 .57735 .31741 .57275 Mtetra
.669 .787 .937 r
.31741 .57275 .32348 .57735 .33302 .57396 .32696 .56943 Mtetra
.681 .793 .933 r
.32696 .56943 .33302 .57396 .34259 .5704 .33656 .56581 Mtetra
.692 .793 .928 r
.33656 .56581 .34259 .5704 .3522 .56681 .34621 .56192 Mtetra
.702 .784 .915 r
.34621 .56192 .3522 .56681 .36184 .56327 .3559 .55776 Mtetra
.697 .761 .901 r
.3559 .55776 .36184 .56327 .37149 .56011 .36562 .55366 Mtetra
.683 .728 .884 r
.36562 .55366 .37149 .56011 .38115 .55759 .37535 .54988 Mtetra
.648 .681 .867 r
.37535 .54988 .38115 .55759 .3908 .55596 .38507 .54704 Mtetra
.596 .629 .855 r
.38507 .54704 .3908 .55596 .40046 .55548 .39477 .54565 Mtetra
.545 .585 .846 r
.39477 .54565 .40046 .55548 .41016 .55547 .40447 .54569 Mtetra
.48 .554 .854 r
.40447 .54569 .41016 .55547 .4199 .55546 .41417 .54718 Mtetra
.473 .591 .891 r
.41417 .54718 .4199 .55546 .42975 .55367 .42394 .54834 Mtetra
.514 .715 .963 r
.42394 .54834 .42975 .55367 .43972 .54887 .43382 .5478 Mtetra
.69 .941 .962 r
.43382 .5478 .43972 .54887 .44979 .54063 .44386 .54274 Mtetra
.847 .998 .806 r
.44386 .54274 .44979 .54063 .45993 .52914 .45405 .53182 Mtetra
.87 .995 .771 r
.45405 .53182 .45993 .52914 .47002 .51993 .46425 .51947 Mtetra
.885 .946 .845 r
.46425 .51947 .47002 .51993 .48004 .51595 .47442 .50852 Mtetra
.697 .711 .859 r
.47442 .50852 .48004 .51595 .49003 .51767 .4845 .50399 Mtetra
.436 .458 .784 r
.4845 .50399 .49003 .51767 .50005 .52461 .49453 .50777 Mtetra
.373 .38 .738 r
.49453 .50777 .50005 .52461 .51017 .53018 .50462 .51448 Mtetra
.354 .382 .752 r
.50462 .51448 .51017 .53018 .5204 .53121 .51481 .52121 Mtetra
.405 .512 .854 r
.51481 .52121 .5204 .53121 .53067 .52728 .5251 .52432 Mtetra
.51 .822 1 r
.5251 .52432 .53067 .52728 .54096 .51891 .53545 .52256 Mtetra
0 0 0 r
.53545 .52256 .54096 .51891 .55125 .51026 .54584 .51874 Mtetra
.229 0 .016 r
.54584 .51874 .55125 .51026 .56157 .50342 .55626 .51422 Mtetra
.362 0 .157 r
.55626 .51422 .56157 .50342 .57195 .5002 .56672 .511 Mtetra
.412 .019 .181 r
.56672 .511 .57195 .5002 .58244 .50062 .57724 .50908 Mtetra
.335 0 .072 r
.57724 .50908 .58244 .50062 .59303 .50288 .5878 .50646 Mtetra
0 0 0 r
.5878 .50646 .59303 .50288 .60368 .50486 .59836 .50176 Mtetra
.848 .889 .868 r
.59836 .50176 .60368 .50486 .61429 .50239 .60883 .49215 Mtetra
.809 .699 .743 r
.60883 .49215 .61429 .50239 .6248 .49491 .61919 .47887 Mtetra
.756 .615 .703 r
.61919 .47887 .6248 .49491 .63516 .48283 .62952 .46557 Mtetra
.718 .586 .707 r
.62952 .46557 .63516 .48283 .64546 .46932 .63994 .4552 Mtetra
.605 .554 .771 r
.63994 .4552 .64546 .46932 .65594 .46108 .65067 .45324 Mtetra
.253 .487 .888 r
.65067 .45324 .65594 .46108 .66668 .45861 .66172 .45782 Mtetra
.489 0 0 r
.66172 .45782 .66668 .45861 .67771 .46148 .67294 .46385 Mtetra
.535 0 0 r
.67294 .46385 .67771 .46148 .68895 .46669 .68419 .46845 Mtetra
.049 0 0 r
.68419 .46845 .68895 .46669 .70011 .46861 .69522 .46709 Mtetra
.709 .953 .952 r
.69522 .46709 .70011 .46861 .71114 .46703 .70606 .4611 Mtetra
.784 .801 .866 r
.70606 .4611 .71114 .46703 .72205 .46236 .71683 .45336 Mtetra
.758 .712 .81 r
.71683 .45336 .72205 .46236 .73288 .45585 .72758 .44526 Mtetra
.716 .665 .799 r
.72758 .44526 .73288 .45585 .74373 .44933 .73844 .43864 Mtetra
.686 .651 .809 r
.73844 .43864 .74373 .44933 .75463 .44328 .74943 .43347 Mtetra
.655 .654 .837 r
.74943 .43347 .75463 .44328 .76565 .43841 .76055 .42981 Mtetra
.63 .672 .872 r
.76055 .42981 .76565 .43841 .77677 .43446 .77179 .42711 Mtetra
.616 .703 .907 r
.77179 .42711 .77677 .43446 .78798 .43117 .78311 .42473 Mtetra
.607 .731 .933 r
.78311 .42473 .78798 .43117 .79928 .42826 .79449 .42243 Mtetra
.614 .758 .947 r
.79449 .42243 .79928 .42826 .81063 .42541 .8059 .41984 Mtetra
.623 .773 .952 r
.8059 .41984 .81063 .42541 .82202 .42252 .81733 .41698 Mtetra
.636 .78 .95 r
.81733 .41698 .82202 .42252 .83345 .41946 .82879 .4138 Mtetra
.646 .781 .945 r
.82879 .4138 .83345 .41946 .84492 .41625 .84027 .41039 Mtetra
.653 .777 .939 r
.84027 .41039 .84492 .41625 .85641 .41288 .85178 .40681 Mtetra
.658 .771 .933 r
.85178 .40681 .85641 .41288 .86795 .4094 .86333 .40311 Mtetra
.661 .765 .927 r
.86333 .40311 .86795 .4094 .87952 .40584 .87492 .39934 Mtetra
.661 .759 .923 r
.87492 .39934 .87952 .40584 .89113 .40224 .88655 .39556 Mtetra
.644 .749 .925 r
.2641 .58177 .27027 .58715 .27962 .58439 .27346 .5791 Mtetra
.642 .752 .929 r
.27346 .5791 .27962 .58439 .28901 .58162 .28286 .57645 Mtetra
.642 .757 .932 r
.28286 .57645 .28901 .58162 .29843 .57879 .29229 .57379 Mtetra
.644 .765 .937 r
.29229 .57379 .29843 .57879 .3079 .57585 .30177 .57106 Mtetra
.646 .775 .942 r
.30177 .57106 .3079 .57585 .31741 .57275 .31128 .56824 Mtetra
.654 .788 .946 r
.31128 .56824 .31741 .57275 .32696 .56943 .32084 .56521 Mtetra
.667 .803 .948 r
.32084 .56521 .32696 .56943 .33656 .56581 .33045 .56185 Mtetra
.684 .818 .947 r
.33045 .56185 .33656 .56581 .34621 .56192 .34012 .55808 Mtetra
.707 .827 .939 r
.34012 .55808 .34621 .56192 .3559 .55776 .34985 .55374 Mtetra
.72 .823 .929 r
.34985 .55374 .3559 .55776 .36562 .55366 .35962 .54906 Mtetra
.728 .802 .91 r
.35962 .54906 .36562 .55366 .37535 .54988 .36943 .54412 Mtetra
.706 .757 .892 r
.36943 .54412 .37535 .54988 .38507 .54704 .37924 .53968 Mtetra
.664 .698 .871 r
.37924 .53968 .38507 .54704 .39477 .54565 .38903 .53634 Mtetra
.6 .623 .847 r
.38903 .53634 .39477 .54565 .40447 .54569 .39879 .53483 Mtetra
.514 .549 .83 r
.39879 .53483 .40447 .54569 .41417 .54718 .40851 .53578 Mtetra
.456 .508 .823 r
.40851 .53578 .41417 .54718 .42394 .54834 .41824 .53821 Mtetra
.398 .504 .85 r
.41824 .53821 .42394 .54834 .43382 .5478 .42802 .54135 Mtetra
.517 .675 .936 r
.42802 .54135 .43382 .5478 .44386 .54274 .43796 .54111 Mtetra
.753 .93 .946 r
.43796 .54111 .44386 .54274 .45405 .53182 .44808 .53508 Mtetra
.793 .991 .753 r
.44808 .53508 .45405 .53182 .46425 .51947 .45833 .5241 Mtetra
.859 .978 .678 r
.45833 .5241 .46425 .51947 .47442 .50852 .46863 .50939 Mtetra
.873 .984 .835 r
.46863 .50939 .47442 .50852 .4845 .50399 .47884 .49848 Mtetra
.673 .767 .921 r
.47884 .49848 .4845 .50399 .49453 .50777 .48896 .49488 Mtetra
.482 .498 .797 r
.48896 .49488 .49453 .50777 .50462 .51448 .49908 .49714 Mtetra
.37 .374 .733 r
.49908 .49714 .50462 .51448 .51481 .52121 .50924 .50407 Mtetra
.386 .387 .738 r
.50924 .50407 .51481 .52121 .5251 .52432 .5195 .51049 Mtetra
.447 .465 .786 r
.5195 .51049 .5251 .52432 .53545 .52256 .52986 .51401 Mtetra
.493 .6 .888 r
.52986 .51401 .53545 .52256 .54584 .51874 .54029 .51485 Mtetra
.553 .801 .991 r
.54029 .51485 .54584 .51874 .55626 .51422 .55076 .51298 Mtetra
.528 .894 .971 r
.55076 .51298 .55626 .51422 .56672 .511 .56126 .50974 Mtetra
.638 .933 .968 r
.56126 .50974 .56672 .511 .57724 .50908 .57179 .50512 Mtetra
.792 .858 .899 r
.57179 .50512 .57724 .50908 .5878 .50646 .5823 .49778 Mtetra
.79 .72 .787 r
.5823 .49778 .5878 .50646 .59836 .50176 .59277 .48772 Mtetra
.769 .639 .717 r
.59277 .48772 .59836 .50176 .60883 .49215 .60316 .47472 Mtetra
.748 .602 .694 r
.60316 .47472 .60883 .49215 .61919 .47887 .61352 .46117 Mtetra
.699 .573 .71 r
.61352 .46117 .61919 .47887 .62952 .46557 .624 .4523 Mtetra
.628 .577 .778 r
.624 .4523 .62952 .46557 .63994 .4552 .63468 .44935 Mtetra
.124 .482 .899 r
.63468 .44935 .63994 .4552 .65067 .45324 .64567 .45383 Mtetra
.652 .103 0 r
.64567 .45383 .65067 .45324 .66172 .45782 .65692 .46219 Mtetra
.568 .065 .019 r
.65692 .46219 .66172 .45782 .67294 .46385 .66812 .4668 Mtetra
.239 0 0 r
.66812 .4668 .67294 .46385 .68419 .46845 .67919 .46639 Mtetra
.742 .941 .949 r
.67919 .46639 .68419 .46845 .69522 .46709 .69002 .46006 Mtetra
.809 .773 .82 r
.69002 .46006 .69522 .46709 .70606 .4611 .70068 .45026 Mtetra
.755 .677 .776 r
.70068 .45026 .70606 .4611 .71683 .45336 .71139 .44115 Mtetra
.719 .642 .77 r
.71139 .44115 .71683 .45336 .72758 .44526 .72219 .43355 Mtetra
.678 .63 .794 r
.72219 .43355 .72758 .44526 .73844 .43864 .73317 .42847 Mtetra
.641 .641 .834 r
.73317 .42847 .73844 .43864 .74943 .43347 .74431 .42526 Mtetra
.608 .673 .887 r
.74431 .42526 .74943 .43347 .76055 .42981 .75557 .42319 Mtetra
.575 .711 .934 r
.75557 .42319 .76055 .42981 .77179 .42711 .76693 .42165 Mtetra
.571 .754 .964 r
.76693 .42165 .77179 .42711 .78311 .42473 .77833 .41984 Mtetra
.578 .782 .976 r
.77833 .41984 .78311 .42473 .79449 .42243 .78975 .41768 Mtetra
.605 .8 .975 r
.78975 .41768 .79449 .42243 .8059 .41984 .80119 .41493 Mtetra
.628 .804 .967 r
.80119 .41493 .8059 .41984 .81733 .41698 .81263 .41175 Mtetra
.647 .799 .956 r
.81263 .41175 .81733 .41698 .82879 .4138 .82409 .40823 Mtetra
.658 .79 .945 r
.82409 .40823 .82879 .4138 .84027 .41039 .83558 .40448 Mtetra
.663 .78 .936 r
.83558 .40448 .84027 .41039 .85178 .40681 .84711 .40063 Mtetra
.666 .772 .929 r
.84711 .40063 .85178 .40681 .86333 .40311 .85867 .39671 Mtetra
.667 .765 .924 r
.85867 .39671 .86333 .40311 .87492 .39934 .87027 .39276 Mtetra
.665 .759 .92 r
.87027 .39276 .87492 .39934 .88655 .39556 .88193 .38884 Mtetra
.643 .748 .925 r
.25789 .57635 .2641 .58177 .27346 .5791 .26727 .57368 Mtetra
.64 .748 .927 r
.26727 .57368 .27346 .5791 .28286 .57645 .27669 .57108 Mtetra
.637 .75 .93 r
.27669 .57108 .28286 .57645 .29229 .57379 .28613 .56852 Mtetra
.635 .754 .934 r
.28613 .56852 .29229 .57379 .30177 .57106 .29561 .56599 Mtetra
.63 .761 .941 r
.29561 .56599 .30177 .57106 .31128 .56824 .30512 .5635 Mtetra
.632 .775 .949 r
.30512 .5635 .31128 .56824 .32084 .56521 .31467 .56092 Mtetra
.636 .795 .959 r
.31467 .56092 .32084 .56521 .33045 .56185 .32428 .55816 Mtetra
.652 .824 .966 r
.32428 .55816 .33045 .56185 .34012 .55808 .33394 .55497 Mtetra
.679 .855 .966 r
.33394 .55497 .34012 .55808 .34985 .55374 .34367 .55111 Mtetra
.711 .879 .96 r
.34367 .55111 .34985 .55374 .35962 .54906 .35347 .54649 Mtetra
.75 .885 .94 r
.35347 .54649 .35962 .54906 .36943 .54412 .36334 .54091 Mtetra
.763 .861 .922 r
.36334 .54091 .36943 .54412 .37924 .53968 .37325 .53497 Mtetra
.755 .804 .892 r
.37325 .53497 .37924 .53968 .38903 .53634 .38318 .52904 Mtetra
.698 .712 .859 r
.38318 .52904 .38903 .53634 .39879 .53483 .39307 .52455 Mtetra
.614 .611 .824 r
.39307 .52455 .39879 .53483 .40851 .53578 .4029 .52256 Mtetra
.52 .513 .789 r
.4029 .52256 .40851 .53578 .41824 .53821 .41266 .5237 Mtetra
.404 .427 .771 r
.41266 .5237 .41824 .53821 .42802 .54135 .42238 .52833 Mtetra
.376 .434 .793 r
.42238 .52833 .42802 .54135 .43796 .54111 .43218 .53305 Mtetra
.386 .558 .901 r
.43218 .53305 .43796 .54111 .44808 .53508 .44212 .53544 Mtetra
.537 .923 .905 r
.44212 .53544 .44808 .53508 .45833 .5241 .45227 .53104 Mtetra
.612 .857 .498 r
.45227 .53104 .45833 .5241 .46863 .50939 .46262 .5181 Mtetra
0 0 0 r
.46262 .5181 .46863 .50939 .47884 .49848 .47298 .50311 Mtetra
.804 .971 .667 r
.47298 .50311 .47884 .49848 .48896 .49488 .48328 .48975 Mtetra
.781 .803 .87 r
.48328 .48975 .48896 .49488 .49908 .49714 .4935 .48254 Mtetra
.543 .51 .769 r
.4935 .48254 .49908 .49714 .50924 .50407 .50369 .48308 Mtetra
.481 .415 .706 r
.50369 .48308 .50924 .50407 .5195 .51049 .51392 .48712 Mtetra
.466 .393 .69 r
.51392 .48712 .5195 .51049 .52986 .51401 .52424 .49235 Mtetra
.496 .422 .703 r
.52424 .49235 .52986 .51401 .54029 .51485 .53464 .49584 Mtetra
.557 .479 .723 r
.53464 .49584 .54029 .51485 .55076 .51298 .54511 .49601 Mtetra
.623 .535 .734 r
.54511 .49601 .55076 .51298 .56126 .50974 .55561 .49274 Mtetra
.676 .565 .722 r
.55561 .49274 .56126 .50974 .57179 .50512 .5661 .48601 Mtetra
.704 .567 .697 r
.5661 .48601 .57179 .50512 .5823 .49778 .57656 .47593 Mtetra
.707 .554 .678 r
.57656 .47593 .5823 .49778 .59277 .48772 .58698 .46408 Mtetra
.688 .535 .673 r
.58698 .46408 .59277 .48772 .60316 .47472 .59742 .4534 Mtetra
.662 .529 .692 r
.59742 .4534 .60316 .47472 .61352 .46117 .60793 .44623 Mtetra
.541 .509 .769 r
.60793 .44623 .61352 .46117 .624 .4523 .61869 .44689 Mtetra
0 .297 .771 r
.61869 .44689 .624 .4523 .63468 .44935 .62971 .45378 Mtetra
.682 .205 .112 r
.62971 .45378 .63468 .44935 .64567 .45383 .6409 .46238 Mtetra
.629 .204 .217 r
.6409 .46238 .64567 .45383 .65692 .46219 .65214 .46892 Mtetra
.307 0 0 r
.65214 .46892 .65692 .46219 .66812 .4668 .66312 .4668 Mtetra
.796 .995 .869 r
.66312 .4668 .66812 .4668 .67919 .46639 .67384 .45776 Mtetra
.812 .736 .781 r
.67384 .45776 .67919 .46639 .69002 .46006 .68445 .4463 Mtetra
.757 .64 .732 r
.68445 .4463 .69002 .46006 .70068 .45026 .69504 .43491 Mtetra
.7 .596 .736 r
.69504 .43491 .70068 .45026 .71139 .44115 .70583 .42707 Mtetra
.656 .587 .765 r
.70583 .42707 .71139 .44115 .72219 .43355 .71682 .42243 Mtetra
.608 .606 .824 r
.71682 .42243 .72219 .43355 .73317 .42847 .728 .42037 Mtetra
.548 .649 .901 r
.728 .42037 .73317 .42847 .74431 .42526 .73934 .41979 Mtetra
.5 .72 .971 r
.73934 .41979 .74431 .42526 .75557 .42319 .75074 .41922 Mtetra
.467 .771 .996 r
.75074 .41922 .75557 .42319 .76693 .42165 .76219 .4183 Mtetra
.508 .819 1 r
.76219 .4183 .76693 .42165 .77833 .41984 .77362 .41639 Mtetra
.566 .842 .997 r
.77362 .41639 .77833 .41984 .78975 .41768 .78504 .41368 Mtetra
.622 .842 .984 r
.78504 .41368 .78975 .41768 .80119 .41493 .79646 .41029 Mtetra
.655 .827 .966 r
.79646 .41029 .80119 .41493 .81263 .41175 .80789 .40644 Mtetra
.668 .805 .949 r
.80789 .40644 .81263 .41175 .82409 .40823 .81935 .4024 Mtetra
.674 .788 .935 r
.81935 .4024 .82409 .40823 .83558 .40448 .83084 .39825 Mtetra
.672 .774 .926 r
.83084 .39825 .83558 .40448 .84711 .40063 .84237 .39415 Mtetra
.671 .765 .921 r
.84237 .39415 .84711 .40063 .85867 .39671 .85396 .39008 Mtetra
.669 .76 .919 r
.85396 .39008 .85867 .39671 .87027 .39276 .86559 .38604 Mtetra
.666 .757 .918 r
.86559 .38604 .87027 .39276 .88193 .38884 .87727 .38207 Mtetra
.648 .75 .923 r
.25164 .57089 .25789 .57635 .26727 .57368 .26105 .56809 Mtetra
.646 .745 .921 r
.26105 .56809 .26727 .57368 .27669 .57108 .27049 .56536 Mtetra
.641 .739 .92 r
.27049 .56536 .27669 .57108 .28613 .56852 .27996 .56271 Mtetra
.636 .735 .92 r
.27996 .56271 .28613 .56852 .29561 .56599 .28946 .56018 Mtetra
.627 .734 .924 r
.28946 .56018 .29561 .56599 .30512 .5635 .29898 .55784 Mtetra
.621 .738 .93 r
.29898 .55784 .30512 .5635 .31467 .56092 .30853 .5556 Mtetra
.613 .749 .942 r
.30853 .5556 .31467 .56092 .32428 .55816 .31811 .55344 Mtetra
.618 .775 .956 r
.31811 .55344 .32428 .55816 .33394 .55497 .32775 .55106 Mtetra
.631 .812 .97 r
.32775 .55106 .33394 .55497 .34367 .55111 .33745 .54826 Mtetra
.661 .864 .976 r
.33745 .54826 .34367 .55111 .35347 .54649 .34723 .54461 Mtetra
.71 .911 .965 r
.34723 .54461 .35347 .54649 .36334 .54091 .3571 .53972 Mtetra
.754 .939 .945 r
.3571 .53972 .36334 .54091 .37325 .53497 .36706 .53367 Mtetra
.802 .933 .919 r
.36706 .53367 .37325 .53497 .38318 .52904 .37708 .5264 Mtetra
.797 .884 .908 r
.37708 .5264 .38318 .52904 .39307 .52455 .38712 .5193 Mtetra
.75 .787 .883 r
.38712 .5193 .39307 .52455 .4029 .52256 .39711 .51338 Mtetra
.641 .647 .841 r
.39711 .51338 .4029 .52256 .41266 .5237 .40702 .51052 Mtetra
.506 .507 .791 r
.40702 .51052 .41266 .5237 .42238 .52833 .41683 .51203 Mtetra
.416 .413 .748 r
.41683 .51203 .42238 .52833 .43218 .53305 .4266 .51692 Mtetra
.324 .358 .742 r
.4266 .51692 .43218 .53305 .44212 .53544 .4364 .52415 Mtetra
.416 .492 .83 r
.4364 .52415 .44212 .53544 .45227 .53104 .44638 .52733 Mtetra
.695 .846 .955 r
.44638 .52733 .45227 .53104 .46262 .5181 .4566 .52299 Mtetra
.637 .914 .621 r
.4566 .52299 .46262 .5181 .47298 .50311 .46696 .51236 Mtetra
0 0 0 r
.46696 .51236 .47298 .50311 .48328 .48975 .47739 .49684 Mtetra
.608 .848 .479 r
.47739 .49684 .48328 .48975 .4935 .48254 .48775 .48346 Mtetra
.761 .994 .87 r
.48775 .48346 .4935 .48254 .50369 .48308 .49804 .47536 Mtetra
.661 .697 .873 r
.49804 .47536 .50369 .48308 .51392 .48712 .50832 .47191 Mtetra
.544 .505 .763 r
.50832 .47191 .51392 .48712 .52424 .49235 .51863 .47241 Mtetra
.544 .463 .715 r
.51863 .47241 .52424 .49235 .53464 .49584 .529 .47324 Mtetra
.57 .464 .695 r
.529 .47324 .53464 .49584 .54511 .49601 .53943 .47261 Mtetra
.608 .485 .687 r
.53943 .47261 .54511 .49601 .55561 .49274 .5499 .4693 Mtetra
.641 .506 .683 r
.5499 .4693 .55561 .49274 .5661 .48601 .56038 .4633 Mtetra
.66 .521 .684 r
.56038 .4633 .5661 .48601 .57656 .47593 .57086 .45582 Mtetra
.666 .538 .699 r
.57086 .45582 .57656 .47593 .58698 .46408 .58136 .44866 Mtetra
.625 .551 .751 r
.58136 .44866 .58698 .46408 .59742 .4534 .59195 .44546 Mtetra
.442 .595 .908 r
.59195 .44546 .59742 .4534 .60793 .44623 .6027 .44697 Mtetra
.605 .045 0 r
.6027 .44697 .60793 .44623 .61869 .44689 .61367 .45383 Mtetra
.683 .246 .204 r
.61367 .45383 .61869 .44689 .62971 .45378 .62482 .46289 Mtetra
.575 .152 .202 r
.62482 .46289 .62971 .45378 .6409 .46238 .63592 .46704 Mtetra
.198 0 0 r
.63592 .46704 .6409 .46238 .65214 .46892 .64688 .46482 Mtetra
.844 .866 .859 r
.64688 .46482 .65214 .46892 .66312 .4668 .65759 .45492 Mtetra
.803 .681 .73 r
.65759 .45492 .66312 .4668 .67384 .45776 .6681 .44087 Mtetra
.736 .602 .708 r
.6681 .44087 .67384 .45776 .68445 .4463 .67871 .42918 Mtetra
.694 .578 .72 r
.67871 .42918 .68445 .4463 .69504 .43491 .68947 .42093 Mtetra
.64 .579 .771 r
.68947 .42093 .69504 .43491 .70583 .42707 .70048 .41714 Mtetra
.562 .608 .857 r
.70048 .41714 .70583 .42707 .71682 .42243 .71172 .41648 Mtetra
.442 .672 .961 r
.71172 .41648 .71682 .42243 .728 .42037 .7231 .41705 Mtetra
.276 .693 .969 r
.7231 .41705 .728 .42037 .73934 .41979 .73456 .41782 Mtetra
.277 .746 .943 r
.73456 .41782 .73934 .41979 .75074 .41922 .74602 .41733 Mtetra
.388 .815 .966 r
.74602 .41733 .75074 .41922 .76219 .4183 .75745 .41565 Mtetra
.546 .867 .995 r
.75745 .41565 .76219 .4183 .77362 .41639 .76885 .41269 Mtetra
.638 .861 .983 r
.76885 .41269 .77362 .41639 .78504 .41368 .78023 .40885 Mtetra
.675 .827 .956 r
.78023 .40885 .78504 .41368 .79646 .41029 .79161 .40456 Mtetra
.688 .796 .932 r
.79161 .40456 .79646 .41029 .80789 .40644 .80302 .40004 Mtetra
.684 .772 .918 r
.80302 .40004 .80789 .40644 .81935 .4024 .81448 .3956 Mtetra
.68 .757 .91 r
.81448 .3956 .81935 .4024 .83084 .39825 .82598 .39126 Mtetra
.673 .749 .908 r
.82598 .39126 .83084 .39825 .84237 .39415 .83755 .3871 Mtetra
.668 .746 .909 r
.83755 .3871 .84237 .39415 .85396 .39008 .84917 .38307 Mtetra
.665 .747 .911 r
.84917 .38307 .85396 .39008 .86559 .38604 .86085 .37912 Mtetra
.662 .75 .915 r
.86085 .37912 .86559 .38604 .87727 .38207 .87259 .37524 Mtetra
.659 .752 .919 r
.24535 .5654 .25164 .57089 .26105 .56809 .2548 .56233 Mtetra
.658 .743 .913 r
.2548 .56233 .26105 .56809 .27049 .56536 .26428 .55929 Mtetra
.653 .732 .907 r
.26428 .55929 .27049 .56536 .27996 .56271 .27379 .55635 Mtetra
.646 .721 .903 r
.27379 .55635 .27996 .56271 .28946 .56018 .28332 .55359 Mtetra
.635 .711 .901 r
.28332 .55359 .28946 .56018 .29898 .55784 .29286 .55109 Mtetra
.622 .702 .902 r
.29286 .55109 .29898 .55784 .30853 .5556 .30243 .5489 Mtetra
.604 .698 .91 r
.30243 .5489 .30853 .5556 .31811 .55344 .312 .54711 Mtetra
.591 .707 .924 r
.312 .54711 .31811 .55344 .32775 .55106 .32161 .54551 Mtetra
.575 .731 .948 r
.32161 .54551 .32775 .55106 .33745 .54826 .33125 .54404 Mtetra
.58 .787 .978 r
.33125 .54404 .33745 .54826 .34723 .54461 .34097 .5421 Mtetra
.596 .864 .993 r
.34097 .5421 .34723 .54461 .3571 .53972 .35077 .53923 Mtetra
.627 .939 .959 r
.35077 .53923 .3571 .53972 .36706 .53367 .36069 .53479 Mtetra
.695 .981 .889 r
.36069 .53479 .36706 .53367 .37708 .5264 .37073 .52817 Mtetra
.757 .995 .852 r
.37073 .52817 .37708 .5264 .38712 .5193 .38086 .51995 Mtetra
.845 .982 .868 r
.38086 .51995 .38712 .5193 .39711 .51338 .39105 .51047 Mtetra
.826 .873 .879 r
.39105 .51047 .39711 .51338 .40702 .51052 .4012 .50203 Mtetra
.716 .692 .826 r
.4012 .50203 .40702 .51052 .41683 .51203 .41126 .49636 Mtetra
.57 .513 .752 r
.41126 .49636 .41683 .51203 .4266 .51692 .42118 .49582 Mtetra
.429 .38 .702 r
.42118 .49582 .4266 .51692 .4364 .52415 .43097 .50169 Mtetra
.373 .334 .686 r
.43097 .50169 .4364 .52415 .44638 .52733 .44079 .51013 Mtetra
.306 .336 .728 r
.44079 .51013 .44638 .52733 .4566 .52299 .45072 .5183 Mtetra
.282 .637 .965 r
.45072 .5183 .4566 .52299 .46696 .51236 .46089 .5199 Mtetra
0 0 0 r
.46089 .5199 .46696 .51236 .47739 .49684 .47127 .51209 Mtetra
.015 0 .071 r
.47127 .51209 .47739 .49684 .48775 .48346 .48173 .49917 Mtetra
0 0 .033 r
.48173 .49917 .48775 .48346 .49804 .47536 .4922 .48373 Mtetra
0 0 0 r
.4922 .48373 .49804 .47536 .50832 .47191 .50262 .47049 Mtetra
.844 .941 .887 r
.50262 .47049 .50832 .47191 .51863 .47241 .51299 .46139 Mtetra
.708 .647 .787 r
.51299 .46139 .51863 .47241 .529 .47324 .52337 .45507 Mtetra
.632 .53 .721 r
.52337 .45507 .529 .47324 .53943 .47261 .53378 .45097 Mtetra
.611 .496 .697 r
.53378 .45097 .53943 .47261 .5499 .4693 .54422 .44763 Mtetra
.6 .489 .698 r
.54422 .44763 .5499 .4693 .56038 .4633 .55471 .44502 Mtetra
.565 .49 .73 r
.55471 .44502 .56038 .4633 .57086 .45582 .56527 .44466 Mtetra
.452 .518 .836 r
.56527 .44466 .57086 .45582 .58136 .44866 .57594 .4471 Mtetra
.508 0 0 r
.57594 .4471 .58136 .44866 .59195 .44546 .58676 .45374 Mtetra
.675 .255 .238 r
.58676 .45374 .59195 .44546 .6027 .44697 .59775 .46263 Mtetra
.611 .25 .333 r
.59775 .46263 .6027 .44697 .61367 .45383 .60879 .46902 Mtetra
.521 .159 .294 r
.60879 .46902 .61367 .45383 .62482 .46289 .61979 .47027 Mtetra
0 0 0 r
.61979 .47027 .62482 .46289 .63592 .46704 .63055 .46198 Mtetra
.893 .825 .773 r
.63055 .46198 .63592 .46704 .64688 .46482 .64109 .44697 Mtetra
.762 .609 .688 r
.64109 .44697 .64688 .46482 .65759 .45492 .65159 .43166 Mtetra
.708 .549 .671 r
.65159 .43166 .65759 .45492 .6681 .44087 .66215 .41893 Mtetra
.647 .518 .693 r
.66215 .41893 .6681 .44087 .67871 .42918 .67299 .41271 Mtetra
.577 .517 .751 r
.67299 .41271 .67871 .42918 .68947 .42093 .68412 .41174 Mtetra
.449 .567 .882 r
.68412 .41174 .68947 .42093 .70048 .41714 .69545 .41362 Mtetra
.065 .544 .895 r
.69545 .41362 .70048 .41714 .71172 .41648 .70693 .41659 Mtetra
.187 0 0 r
.70693 .41659 .71172 .41648 .7231 .41705 .71843 .41828 Mtetra
.134 0 0 r
.71843 .41828 .7231 .41705 .73456 .41782 .7299 .41833 Mtetra
.178 .712 .747 r
.7299 .41833 .73456 .41782 .74602 .41733 .74129 .41615 Mtetra
.516 .901 .951 r
.74129 .41615 .74602 .41733 .75745 .41565 .75263 .41234 Mtetra
.678 .89 .975 r
.75263 .41234 .75745 .41565 .76885 .41269 .76393 .40757 Mtetra
.714 .828 .935 r
.76393 .40757 .76885 .41269 .78023 .40885 .77524 .40229 Mtetra
.707 .774 .904 r
.77524 .40229 .78023 .40885 .79161 .40456 .78659 .39714 Mtetra
.697 .744 .888 r
.78659 .39714 .79161 .40456 .80302 .40004 .798 .39219 Mtetra
.683 .727 .883 r
.798 .39219 .80302 .40004 .81448 .3956 .80948 .38765 Mtetra
.673 .72 .884 r
.80948 .38765 .81448 .3956 .82598 .39126 .82102 .38342 Mtetra
.664 .721 .891 r
.82102 .38342 .82598 .39126 .83755 .3871 .83264 .37946 Mtetra
.658 .725 .898 r
.83264 .37946 .83755 .3871 .84917 .38307 .84433 .37568 Mtetra
.655 .732 .906 r
.84433 .37568 .84917 .38307 .86085 .37912 .85607 .37201 Mtetra
.653 .741 .914 r
.85607 .37201 .86085 .37912 .87259 .37524 .86786 .36837 Mtetra
.67 .755 .914 r
.23902 .55988 .24535 .5654 .2548 .56233 .24851 .55653 Mtetra
.67 .746 .907 r
.24851 .55653 .2548 .56233 .26428 .55929 .25804 .55314 Mtetra
.668 .734 .9 r
.25804 .55314 .26428 .55929 .27379 .55635 .26759 .54981 Mtetra
.662 .721 .893 r
.26759 .54981 .27379 .55635 .28332 .55359 .27717 .54661 Mtetra
.653 .706 .886 r
.27717 .54661 .28332 .55359 .29286 .55109 .28676 .54363 Mtetra
.638 .687 .879 r
.28676 .54363 .29286 .55109 .30243 .5489 .29637 .54101 Mtetra
.618 .669 .876 r
.29637 .54101 .30243 .5489 .312 .54711 .30598 .53891 Mtetra
.597 .653 .875 r
.30598 .53891 .312 .54711 .32161 .54551 .31559 .53735 Mtetra
.569 .642 .884 r
.31559 .53735 .32161 .54551 .33125 .54404 .32521 .53644 Mtetra
.554 .654 .901 r
.32521 .53644 .33125 .54404 .34097 .5421 .33487 .53575 Mtetra
.542 .691 .936 r
.33487 .53575 .34097 .5421 .35077 .53923 .34457 .535 Mtetra
.567 .785 .981 r
.34457 .535 .35077 .53923 .36069 .53479 .35439 .53319 Mtetra
.616 .905 .985 r
.35439 .53319 .36069 .53479 .37073 .52817 .36433 .52952 Mtetra
.634 .964 .872 r
.36433 .52952 .37073 .52817 .38086 .51995 .37442 .52343 Mtetra
.692 .969 .751 r
.37442 .52343 .38086 .51995 .39105 .51047 .38465 .51438 Mtetra
.747 .978 .731 r
.38465 .51438 .39105 .51047 .4012 .50203 .39494 .50389 Mtetra
.855 .995 .823 r
.39494 .50389 .4012 .50203 .41126 .49636 .40523 .49307 Mtetra
.805 .865 .893 r
.40523 .49307 .41126 .49636 .42118 .49582 .41541 .48547 Mtetra
.613 .614 .828 r
.41541 .48547 .42118 .49582 .43097 .50169 .42543 .48339 Mtetra
.464 .424 .729 r
.42543 .48339 .43097 .50169 .44079 .51013 .43534 .48721 Mtetra
.351 .317 .68 r
.43534 .48721 .44079 .51013 .45072 .5183 .4452 .49652 Mtetra
.378 .344 .694 r
.4452 .49652 .45072 .5183 .46089 .5199 .4552 .50447 Mtetra
.476 .464 .765 r
.4552 .50447 .46089 .5199 .47127 .51209 .4654 .50726 Mtetra
.665 .799 .947 r
.4654 .50726 .47127 .51209 .48173 .49917 .47577 .50364 Mtetra
.619 .913 .637 r
.47577 .50364 .48173 .49917 .4922 .48373 .48625 .49355 Mtetra
0 0 0 r
.48625 .49355 .4922 .48373 .50262 .47049 .49675 .48174 Mtetra
.49675 .48174 .50262 .47049 .51299 .46139 .50723 .47063 Mtetra
.50723 .47063 .51299 .46139 .52337 .45507 .51769 .46167 Mtetra
.51769 .46167 .52337 .45507 .53378 .45097 .52816 .45572 Mtetra
.086 0 0 r
.52816 .45572 .53378 .45097 .54422 .44763 .53867 .45236 Mtetra
.3 0 0 r
.53867 .45236 .54422 .44763 .55471 .44502 .54923 .45158 Mtetra
.505 .039 .082 r
.54923 .45158 .55471 .44502 .56527 .44466 .55988 .45384 Mtetra
.583 .163 .211 r
.55988 .45384 .56527 .44466 .57594 .4471 .57065 .4583 Mtetra
.598 .201 .261 r
.57065 .4583 .57594 .4471 .58676 .45374 .58151 .46347 Mtetra
.558 .142 .208 r
.58151 .46347 .58676 .45374 .59775 .46263 .59245 .46695 Mtetra
.094 0 0 r
.59245 .46695 .59775 .46263 .60879 .46902 .60331 .4639 Mtetra
.826 .829 .851 r
.60331 .4639 .60879 .46902 .61979 .47027 .61404 .45435 Mtetra
.772 .628 .701 r
.61404 .45435 .61979 .47027 .63055 .46198 .62462 .43955 Mtetra
.74 .573 .666 r
.62462 .43955 .63055 .46198 .64109 .44697 .63511 .42331 Mtetra
.687 .535 .674 r
.63511 .42331 .64109 .44697 .65159 .43166 .64576 .41263 Mtetra
.636 .53 .717 r
.64576 .41263 .65159 .43166 .66215 .41893 .65665 .40794 Mtetra
.509 .558 .841 r
.65665 .40794 .66215 .41893 .67299 .41271 .66783 .40889 Mtetra
0 .45 .842 r
.66783 .40889 .67299 .41271 .68412 .41174 .67924 .41315 Mtetra
.453 0 0 r
.67924 .41315 .68412 .41174 .69545 .41362 .69074 .41711 Mtetra
.444 0 0 r
.69074 .41711 .69545 .41362 .70693 .41659 .70225 .4196 Mtetra
.223 0 0 r
.70225 .4196 .70693 .41659 .71843 .41828 .71367 .41907 Mtetra
.239 .753 .749 r
.71367 .41907 .71843 .41828 .7299 .41833 .725 .41604 Mtetra
.66 .923 .975 r
.725 .41604 .7299 .41833 .74129 .41615 .73626 .41109 Mtetra
.741 .837 .923 r
.73626 .41109 .74129 .41615 .75263 .41234 .74748 .40505 Mtetra
.73 .758 .875 r
.74748 .40505 .75263 .41234 .76393 .40757 .75872 .39893 Mtetra
.715 .717 .85 r
.75872 .39893 .76393 .40757 .77524 .40229 .77001 .39301 Mtetra
.694 .694 .845 r
.77001 .39301 .77524 .40229 .78659 .39714 .78138 .38777 Mtetra
.679 .686 .849 r
.78138 .38777 .78659 .39714 .798 .39219 .79284 .38309 Mtetra
.666 .687 .86 r
.79284 .38309 .798 .39219 .80948 .38765 .80438 .37894 Mtetra
.656 .693 .873 r
.80438 .37894 .80948 .38765 .82102 .38342 .816 .37517 Mtetra
.65 .704 .886 r
.816 .37517 .82102 .38342 .83264 .37946 .82769 .37162 Mtetra
.645 .715 .898 r
.82769 .37162 .83264 .37946 .84433 .37568 .83944 .3682 Mtetra
.643 .726 .908 r
.83944 .3682 .84433 .37568 .85607 .37201 .85125 .36484 Mtetra
.643 .737 .917 r
.85125 .36484 .85607 .37201 .86786 .36837 .8631 .36144 Mtetra
.677 .756 .911 r
.23264 .55431 .23902 .55988 .24851 .55653 .24217 .55077 Mtetra
.68 .751 .905 r
.24217 .55077 .24851 .55653 .25804 .55314 .25174 .54712 Mtetra
.68 .743 .898 r
.25174 .54712 .25804 .55314 .26759 .54981 .26134 .54342 Mtetra
.679 .731 .89 r
.26134 .54342 .26759 .54981 .27717 .54661 .27097 .53972 Mtetra
.676 .716 .879 r
.27097 .53972 .27717 .54661 .28676 .54363 .28063 .53603 Mtetra
.666 .694 .867 r
.28063 .53603 .28676 .54363 .29637 .54101 .29031 .53258 Mtetra
.65 .668 .854 r
.29031 .53258 .29637 .54101 .30598 .53891 .29999 .52952 Mtetra
.626 .636 .841 r
.29999 .52952 .30598 .53891 .31559 .53735 .30967 .52712 Mtetra
.594 .605 .832 r
.30967 .52712 .31559 .53735 .32521 .53644 .31932 .52568 Mtetra
.561 .579 .829 r
.31932 .52568 .32521 .53644 .33487 .53575 .32897 .52519 Mtetra
.517 .562 .84 r
.32897 .52519 .33487 .53575 .34457 .535 .3386 .5258 Mtetra
.49 .581 .873 r
.3386 .5258 .34457 .535 .35439 .53319 .34828 .52668 Mtetra
.452 .649 .943 r
.34828 .52668 .35439 .53319 .36433 .52952 .35804 .52728 Mtetra
.415 .807 .987 r
.35804 .52728 .36433 .52952 .37442 .52343 .36793 .52605 Mtetra
.296 .773 .671 r
.36793 .52605 .37442 .52343 .38465 .51438 .37801 .52175 Mtetra
0 0 0 r
.37801 .52175 .38465 .51438 .39494 .50389 .38827 .51397 Mtetra
.38827 .51397 .39494 .50389 .40523 .49307 .39867 .50238 Mtetra
.39867 .50238 .40523 .49307 .41541 .48547 .40913 .48901 Mtetra
.873 .991 .743 r
.40913 .48901 .41541 .48547 .42543 .48339 .41957 .47558 Mtetra
.783 .729 .803 r
.41957 .47558 .42543 .48339 .43534 .48721 .42985 .46659 Mtetra
.59 .487 .705 r
.42985 .46659 .43534 .48721 .4452 .49652 .43995 .46468 Mtetra
.491 .374 .647 r
.43995 .46468 .4452 .49652 .4552 .50447 .44995 .46951 Mtetra
.412 .31 .629 r
.44995 .46951 .4552 .50447 .4654 .50726 .45992 .48017 Mtetra
.376 .313 .659 r
.45992 .48017 .4654 .50726 .47577 .50364 .47002 .49016 Mtetra
.324 .401 .788 r
.47002 .49016 .47577 .50364 .48625 .49355 .48031 .49608 Mtetra
.322 0 0 r
.48031 .49608 .48625 .49355 .49675 .48174 .49074 .49703 Mtetra
.384 .03 .236 r
.49074 .49703 .49675 .48174 .50723 .47063 .50127 .49304 Mtetra
.411 .1 .324 r
.50127 .49304 .50723 .47063 .51769 .46167 .51185 .4876 Mtetra
.437 .137 .357 r
.51185 .4876 .51769 .46167 .52816 .45572 .52245 .48243 Mtetra
.47 .169 .372 r
.52245 .48243 .52816 .45572 .53867 .45236 .53309 .47907 Mtetra
.497 .192 .38 r
.53309 .47907 .53867 .45236 .54923 .45158 .54378 .47753 Mtetra
.499 .192 .376 r
.54378 .47753 .54923 .45158 .55988 .45384 .55452 .47627 Mtetra
.466 .149 .343 r
.55452 .47627 .55988 .45384 .57065 .4583 .56531 .47356 Mtetra
.266 0 .188 r
.56531 .47356 .57065 .4583 .58151 .46347 .57606 .46586 Mtetra
.842 .994 .748 r
.57606 .46586 .58151 .46347 .59245 .46695 .58673 .45314 Mtetra
.807 .661 .702 r
.58673 .45314 .59245 .46695 .60331 .4639 .59729 .43626 Mtetra
.724 .544 .647 r
.59729 .43626 .60331 .4639 .61404 .45435 .60778 .41865 Mtetra
.656 .48 .634 r
.60778 .41865 .61404 .45435 .62462 .43955 .61839 .40691 Mtetra
.606 .453 .648 r
.61839 .40691 .62462 .43955 .63511 .42331 .62921 .402 Mtetra
.515 .44 .71 r
.62921 .402 .63511 .42331 .64576 .41263 .64032 .40429 Mtetra
.096 .379 .84 r
.64032 .40429 .64576 .41263 .65665 .40794 .65169 .41113 Mtetra
.62 .098 0 r
.65169 .41113 .65665 .40794 .66783 .40889 .66318 .41794 Mtetra
.588 .158 .192 r
.66318 .41794 .66783 .40889 .67924 .41315 .6747 .42297 Mtetra
.488 .066 .165 r
.6747 .42297 .67924 .41315 .69074 .41711 .68613 .42413 Mtetra
.292 0 0 r
.68613 .42413 .69074 .41711 .70225 .4196 .69745 .42172 Mtetra
.345 .799 .667 r
.69745 .42172 .70225 .4196 .71367 .41907 .70864 .41615 Mtetra
.784 .925 .929 r
.70864 .41615 .71367 .41907 .725 .41604 .71975 .40867 Mtetra
.768 .767 .852 r
.71975 .40867 .725 .41604 .73626 .41109 .73086 .40089 Mtetra
.735 .69 .808 r
.73086 .40089 .73626 .41109 .74748 .40505 .74201 .39339 Mtetra
.702 .65 .795 r
.74201 .39339 .74748 .40505 .75872 .39893 .75325 .38699 Mtetra
.681 .636 .798 r
.75325 .38699 .75872 .39893 .77001 .39301 .7646 .38158 Mtetra
.662 .636 .813 r
.7646 .38158 .77001 .39301 .78138 .38777 .77605 .37716 Mtetra
.649 .646 .833 r
.77605 .37716 .78138 .38777 .79284 .38309 .78761 .37342 Mtetra
.641 .663 .856 r
.78761 .37342 .79284 .38309 .80438 .37894 .79924 .37009 Mtetra
.634 .681 .877 r
.79924 .37009 .80438 .37894 .816 .37517 .81095 .367 Mtetra
.634 .7 .894 r
.81095 .367 .816 .37517 .82769 .37162 .82272 .36392 Mtetra
.633 .715 .906 r
.82272 .36392 .82769 .37162 .83944 .3682 .83453 .36084 Mtetra
.633 .727 .915 r
.83453 .36084 .83944 .3682 .85125 .36484 .8464 .35771 Mtetra
.636 .737 .921 r
.8464 .35771 .85125 .36484 .8631 .36144 .85831 .35446 Mtetra
.673 .755 .913 r
.22623 .54871 .23264 .55431 .24217 .55077 .23577 .54523 Mtetra
.678 .759 .913 r
.23577 .54523 .24217 .55077 .25174 .54712 .24535 .54162 Mtetra
.683 .763 .912 r
.24535 .54162 .25174 .54712 .26134 .54342 .25498 .53787 Mtetra
.688 .763 .908 r
.25498 .53787 .26134 .54342 .27097 .53972 .26465 .53396 Mtetra
.695 .757 .9 r
.26465 .53396 .27097 .53972 .28063 .53603 .27436 .52982 Mtetra
.694 .743 .889 r
.27436 .52982 .28063 .53603 .29031 .53258 .28411 .52564 Mtetra
.69 .721 .873 r
.28411 .52564 .29031 .53258 .29999 .52952 .29389 .52148 Mtetra
.672 .687 .855 r
.29389 .52148 .29999 .52952 .30967 .52712 .30366 .51773 Mtetra
.645 .646 .836 r
.30366 .51773 .30967 .52712 .31932 .52568 .31343 .51468 Mtetra
.608 .598 .815 r
.31343 .51468 .31932 .52568 .32897 .52519 .32316 .51274 Mtetra
.561 .55 .799 r
.32316 .51274 .32897 .52519 .3386 .5258 .33285 .51233 Mtetra
.52 .513 .788 r
.33285 .51233 .3386 .5258 .34828 .52668 .34252 .51327 Mtetra
.472 .487 .793 r
.34252 .51327 .34828 .52668 .35804 .52728 .35217 .51553 Mtetra
.458 .509 .823 r
.35217 .51553 .35804 .52728 .36793 .52605 .36191 .51771 Mtetra
.465 .596 .899 r
.36191 .51771 .36793 .52605 .37801 .52175 .37176 .51875 Mtetra
.515 .823 1 r
.37176 .51875 .37801 .52175 .38827 .51397 .3818 .51694 Mtetra
.452 .864 .711 r
.3818 .51694 .38827 .51397 .39867 .50238 .39205 .51094 Mtetra
0 0 0 r
.39205 .51094 .39867 .50238 .40913 .48901 .40248 .50066 Mtetra
.40248 .50066 .40913 .48901 .41957 .47558 .41304 .48635 Mtetra
.41304 .48635 .41957 .47558 .42985 .46659 .42357 .47208 Mtetra
.659 .916 .606 r
.42357 .47208 .42985 .46659 .43995 .46468 .43399 .46061 Mtetra
.731 .841 .932 r
.43399 .46061 .43995 .46468 .44995 .46951 .44425 .45536 Mtetra
.478 .481 .783 r
.44425 .45536 .44995 .46951 .45992 .48017 .45437 .4577 Mtetra
.435 .377 .694 r
.45437 .4577 .45992 .48017 .47002 .49016 .4645 .46354 Mtetra
.435 .356 .668 r
.4645 .46354 .47002 .49016 .48031 .49608 .47472 .47053 Mtetra
.473 .387 .678 r
.47472 .47053 .48031 .49608 .49074 .49703 .48506 .47538 Mtetra
.533 .447 .705 r
.48506 .47538 .49074 .49703 .50127 .49304 .49552 .47662 Mtetra
.577 .516 .75 r
.49552 .47662 .50127 .49304 .51185 .4876 .50607 .47555 Mtetra
.626 .598 .803 r
.50607 .47555 .51185 .4876 .52245 .48243 .51668 .47274 Mtetra
.648 .653 .842 r
.51668 .47274 .52245 .48243 .53309 .47907 .52733 .46935 Mtetra
.663 .66 .837 r
.52733 .46935 .53309 .47907 .54378 .47753 .53802 .4654 Mtetra
.687 .628 .784 r
.53802 .4654 .54378 .47753 .55452 .47627 .54874 .45968 Mtetra
.695 .582 .725 r
.54874 .45968 .55452 .47627 .56531 .47356 .55946 .45164 Mtetra
.705 .554 .68 r
.55946 .45164 .56531 .47356 .57606 .46586 .57014 .43994 Mtetra
.705 .538 .659 r
.57014 .43994 .57606 .46586 .58673 .45314 .58077 .42605 Mtetra
.691 .525 .657 r
.58077 .42605 .58673 .45314 .59729 .43626 .5914 .41328 Mtetra
.676 .531 .68 r
.5914 .41328 .59729 .43626 .60778 .41865 .60209 .40403 Mtetra
.589 .544 .772 r
.60209 .40403 .60778 .41865 .61839 .40691 .61299 .40246 Mtetra
0 .421 .837 r
.61299 .40246 .61839 .40691 .62921 .402 .62414 .40723 Mtetra
.651 .174 .106 r
.62414 .40723 .62921 .402 .64032 .40429 .6355 .41487 Mtetra
.639 .23 .252 r
.6355 .41487 .64032 .40429 .65169 .41113 .64697 .42259 Mtetra
.558 .154 .233 r
.64697 .42259 .65169 .41113 .66318 .41794 .65841 .42624 Mtetra
.401 0 .073 r
.65841 .42624 .66318 .41794 .6747 .42297 .66974 .42552 Mtetra
0 0 0 r
.66974 .42552 .6747 .42297 .68613 .42413 .68093 .42051 Mtetra
.801 .898 .912 r
.68093 .42051 .68613 .42413 .69745 .42172 .692 .41256 Mtetra
.774 .724 .806 r
.692 .41256 .69745 .42172 .70864 .41615 .70303 .40342 Mtetra
.74 .651 .761 r
.70303 .40342 .70864 .41615 .71975 .40867 .71405 .39417 Mtetra
.706 .613 .751 r
.71405 .39417 .71975 .40867 .73086 .40089 .72517 .38628 Mtetra
.684 .601 .757 r
.72517 .38628 .73086 .40089 .74201 .39339 .73639 .37976 Mtetra
.661 .602 .777 r
.73639 .37976 .74201 .39339 .75325 .38699 .74775 .37481 Mtetra
.644 .615 .805 r
.74775 .37481 .75325 .38699 .7646 .38158 .75922 .37101 Mtetra
.631 .638 .839 r
.75922 .37101 .7646 .38158 .77605 .37716 .77081 .36794 Mtetra
.62 .665 .872 r
.77081 .36794 .77605 .37716 .78761 .37342 .78247 .36529 Mtetra
.618 .694 .899 r
.78247 .36529 .78761 .37342 .79924 .37009 .7942 .36267 Mtetra
.617 .717 .917 r
.7942 .36267 .79924 .37009 .81095 .367 .80598 .36 Mtetra
.623 .734 .927 r
.80598 .36 .81095 .367 .82272 .36392 .81779 .35709 Mtetra
.629 .744 .93 r
.81779 .35709 .82272 .36392 .83453 .36084 .82965 .35402 Mtetra
.634 .747 .93 r
.82965 .35402 .83453 .36084 .8464 .35771 .84154 .3508 Mtetra
.639 .747 .927 r
.84154 .3508 .8464 .35771 .85831 .35446 .85348 .34743 Mtetra
.659 .752 .919 r
.21976 .54307 .22623 .54871 .23577 .54523 .2293 .53993 Mtetra
.663 .766 .926 r
.2293 .53993 .23577 .54523 .24535 .54162 .23887 .53667 Mtetra
.67 .781 .933 r
.23887 .53667 .24535 .54162 .25498 .53787 .24849 .53322 Mtetra
.681 .795 .936 r
.24849 .53322 .25498 .53787 .26465 .53396 .25817 .52949 Mtetra
.697 .806 .933 r
.25817 .52949 .26465 .53396 .27436 .52982 .26791 .52535 Mtetra
.711 .808 .926 r
.26791 .52535 .27436 .52982 .28411 .52564 .27771 .52083 Mtetra
.725 .798 .909 r
.27771 .52083 .28411 .52564 .29389 .52148 .28757 .51585 Mtetra
.726 .771 .889 r
.28757 .51585 .29389 .52148 .30366 .51773 .29746 .5107 Mtetra
.716 .728 .859 r
.29746 .5107 .30366 .51773 .31343 .51468 .30738 .50553 Mtetra
.686 .668 .827 r
.30738 .50553 .31343 .51468 .32316 .51274 .31729 .50097 Mtetra
.645 .604 .793 r
.31729 .50097 .32316 .51274 .33285 .51233 .32716 .4975 Mtetra
.596 .538 .76 r
.32716 .4975 .33285 .51233 .34252 .51327 .33697 .49573 Mtetra
.541 .479 .735 r
.33697 .49573 .34252 .51327 .35217 .51553 .3467 .49625 Mtetra
.494 .436 .72 r
.3467 .49625 .35217 .51553 .36191 .51771 .35638 .49883 Mtetra
.437 .403 .723 r
.35638 .49883 .36191 .51771 .37176 .51875 .36604 .50338 Mtetra
.396 .416 .764 r
.36604 .50338 .37176 .51875 .3818 .51694 .37578 .50809 Mtetra
.314 .503 .883 r
.37578 .50809 .3818 .51694 .39205 .51094 .38565 .51155 Mtetra
.124 0 0 r
.38565 .51155 .39205 .51094 .40248 .50066 .39572 .51198 Mtetra
.299 0 .107 r
.39572 .51198 .40248 .50066 .41304 .48635 .40602 .50789 Mtetra
.289 0 .259 r
.40602 .50789 .41304 .48635 .42357 .47208 .41652 .4985 Mtetra
.212 0 .266 r
.41652 .4985 .42357 .47208 .43399 .46061 .42718 .48369 Mtetra
.065 0 .179 r
.42718 .48369 .43399 .46061 .44425 .45536 .43787 .46641 Mtetra
0 0 0 r
.43787 .46641 .44425 .45536 .45437 .4577 .44852 .44902 Mtetra
.822 .724 .757 r
.44852 .44902 .45437 .4577 .4645 .46354 .45904 .43596 Mtetra
.636 .486 .662 r
.45904 .43596 .4645 .46354 .47472 .47053 .46942 .42916 Mtetra
.57 .409 .624 r
.46942 .42916 .47472 .47053 .48506 .47538 .47976 .42713 Mtetra
.539 .377 .61 r
.47976 .42713 .48506 .47538 .49552 .47662 .4901 .42857 Mtetra
.539 .378 .611 r
.4901 .42857 .49552 .47662 .50607 .47555 .50052 .43001 Mtetra
.555 .392 .616 r
.50052 .43001 .50607 .47555 .51668 .47274 .51102 .4296 Mtetra
.581 .414 .621 r
.51102 .4296 .51668 .47274 .52733 .46935 .52158 .42616 Mtetra
.604 .431 .62 r
.52158 .42616 .52733 .46935 .53802 .4654 .53217 .41968 Mtetra
.613 .434 .616 r
.53217 .41968 .53802 .4654 .54874 .45968 .54278 .41133 Mtetra
.61 .428 .611 r
.54278 .41133 .54874 .45968 .55946 .45164 .55339 .40295 Mtetra
.586 .411 .611 r
.55339 .40295 .55946 .45164 .57014 .43994 .56406 .39807 Mtetra
.552 .397 .624 r
.56406 .39807 .57014 .43994 .58077 .42605 .57483 .39799 Mtetra
.459 .368 .666 r
.57483 .39799 .58077 .42605 .5914 .41328 .58578 .40426 Mtetra
0 .169 .706 r
.58578 .40426 .5914 .41328 .60209 .40403 .59695 .41494 Mtetra
.683 .283 .282 r
.59695 .41494 .60209 .40403 .61299 .40246 .60825 .42557 Mtetra
.612 .28 .384 r
.60825 .42557 .61299 .40246 .62414 .40723 .61962 .43373 Mtetra
.547 .232 .385 r
.61962 .43373 .62414 .40723 .6355 .41487 .63094 .43642 Mtetra
.459 .135 .329 r
.63094 .43642 .6355 .41487 .64697 .42259 .64215 .43372 Mtetra
.175 0 .06 r
.64215 .43372 .64697 .42259 .65841 .42624 .65323 .42639 Mtetra
.828 .997 .843 r
.65323 .42639 .65841 .42624 .66974 .42552 .66419 .41593 Mtetra
.806 .725 .775 r
.66419 .41593 .66974 .42552 .68093 .42051 .67509 .40418 Mtetra
.74 .612 .716 r
.67509 .40418 .68093 .42051 .692 .41256 .68599 .39256 Mtetra
.694 .56 .699 r
.68599 .39256 .692 .41256 .70303 .40342 .69698 .38294 Mtetra
.667 .541 .703 r
.69698 .38294 .70303 .40342 .71405 .39417 .7081 .37542 Mtetra
.642 .539 .722 r
.7081 .37542 .71405 .39417 .72517 .38628 .71937 .37025 Mtetra
.622 .552 .755 r
.71937 .37025 .72517 .38628 .73639 .37976 .7308 .36683 Mtetra
.606 .583 .802 r
.7308 .36683 .73639 .37976 .74775 .37481 .74235 .36455 Mtetra
.589 .625 .855 r
.74235 .36455 .74775 .37481 .75922 .37101 .754 .36289 Mtetra
.582 .678 .906 r
.754 .36289 .75922 .37101 .77081 .36794 .76572 .36122 Mtetra
.577 .722 .942 r
.76572 .36122 .77081 .36794 .78247 .36529 .77749 .35937 Mtetra
.588 .759 .96 r
.77749 .35937 .78247 .36529 .7942 .36267 .78928 .35706 Mtetra
.602 .778 .964 r
.78928 .35706 .7942 .36267 .80598 .36 .80109 .35434 Mtetra
.622 .785 .96 r
.80109 .35434 .80598 .36 .81779 .35709 .81292 .3512 Mtetra
.636 .783 .952 r
.81292 .3512 .81779 .35709 .82965 .35402 .82478 .34776 Mtetra
.647 .775 .941 r
.82478 .34776 .82965 .35402 .84154 .3508 .83668 .34411 Mtetra
.652 .763 .93 r
.83668 .34411 .84154 .3508 .85348 .34743 .84861 .34035 Mtetra
.638 .747 .927 r
.21326 .53739 .21976 .54307 .2293 .53993 .22277 .53471 Mtetra
.637 .764 .94 r
.22277 .53471 .2293 .53993 .23887 .53667 .23232 .53199 Mtetra
.64 .786 .952 r
.23232 .53199 .23887 .53667 .24849 .53322 .24191 .52911 Mtetra
.648 .811 .962 r
.24191 .52911 .24849 .53322 .25817 .52949 .25157 .52597 Mtetra
.661 .839 .968 r
.25157 .52597 .25817 .52949 .26791 .52535 .26129 .52245 Mtetra
.681 .867 .97 r
.26129 .52245 .26791 .52535 .27771 .52083 .27108 .5184 Mtetra
.709 .89 .963 r
.27108 .5184 .27771 .52083 .28757 .51585 .28096 .51366 Mtetra
.735 .901 .953 r
.28096 .51366 .28757 .51585 .29746 .5107 .2909 .50828 Mtetra
.764 .894 .935 r
.2909 .50828 .29746 .5107 .30738 .50553 .30092 .50221 Mtetra
.77 .86 .916 r
.30092 .50221 .30738 .50553 .31729 .50097 .31097 .49591 Mtetra
.758 .798 .885 r
.31097 .49591 .31729 .50097 .32716 .4975 .32103 .48968 Mtetra
.712 .709 .845 r
.32103 .48968 .32716 .4975 .33697 .49573 .33105 .4844 Mtetra
.65 .614 .801 r
.33105 .4844 .33697 .49573 .3467 .49625 .34101 .4808 Mtetra
.582 .524 .756 r
.34101 .4808 .3467 .49625 .35638 .49883 .35088 .47956 Mtetra
.513 .448 .721 r
.35088 .47956 .35638 .49883 .36604 .50338 .36065 .4813 Mtetra
.469 .401 .697 r
.36065 .4813 .36604 .50338 .37578 .50809 .37037 .4853 Mtetra
.43 .371 .69 r
.37037 .4853 .37578 .50809 .38565 .51155 .38011 .49108 Mtetra
.415 .378 .709 r
.38011 .49108 .38565 .51155 .39572 .51198 .38994 .4968 Mtetra
.417 .434 .77 r
.38994 .4968 .39572 .51198 .40602 .50789 .39992 .50088 Mtetra
.516 .669 .932 r
.39992 .50088 .40602 .50789 .41652 .4985 .41014 .50055 Mtetra
.567 .934 .807 r
.41014 .50055 .41652 .4985 .42718 .48369 .42061 .49415 Mtetra
0 0 0 r
.42061 .49415 .42718 .48369 .43787 .46641 .43124 .48258 Mtetra
0 0 .005 r
.43124 .48258 .43787 .46641 .44852 .44902 .44197 .46708 Mtetra
.02 0 .101 r
.44197 .46708 .44852 .44902 .45904 .43596 .45263 .45255 Mtetra
.129 0 .132 r
.45263 .45255 .45904 .43596 .46942 .42916 .4632 .44146 Mtetra
.176 0 .073 r
.4632 .44146 .46942 .42916 .47976 .42713 .4737 .4342 Mtetra
.192 0 0 r
.4737 .4342 .47976 .42713 .4901 .42857 .48417 .43064 Mtetra
0 0 0 r
.48417 .43064 .4901 .42857 .50052 .43001 .49466 .42828 Mtetra
.47 .856 .979 r
.49466 .42828 .50052 .43001 .51102 .4296 .50521 .4259 Mtetra
.636 .846 .981 r
.50521 .4259 .51102 .4296 .52158 .42616 .5158 .42244 Mtetra
.691 .86 .963 r
.5158 .42244 .52158 .42616 .53217 .41968 .52644 .41789 Mtetra
.647 .923 .976 r
.52644 .41789 .53217 .41968 .54278 .41133 .53711 .41331 Mtetra
0 0 0 r
.53711 .41331 .54278 .41133 .55339 .40295 .54782 .40994 Mtetra
.421 0 .034 r
.54782 .40994 .55339 .40295 .56406 .39807 .55862 .41029 Mtetra
.573 .179 .258 r
.55862 .41029 .56406 .39807 .57483 .39799 .56953 .41453 Mtetra
.623 .261 .336 r
.56953 .41453 .57483 .39799 .58578 .40426 .5806 .42227 Mtetra
.632 .277 .351 r
.5806 .42227 .58578 .40426 .59695 .41494 .59182 .43105 Mtetra
.579 .213 .312 r
.59182 .43105 .59695 .41494 .60825 .42557 .60306 .43586 Mtetra
.436 .019 .147 r
.60306 .43586 .60825 .42557 .61962 .43373 .61427 .43545 Mtetra
.516 .906 .77 r
.61427 .43545 .61962 .43373 .63094 .43642 .62535 .42888 Mtetra
.821 .77 .805 r
.62535 .42888 .63094 .43642 .64215 .43372 .6363 .41777 Mtetra
.755 .623 .713 r
.6363 .41777 .64215 .43372 .65323 .42639 .64717 .40497 Mtetra
.719 .567 .682 r
.64717 .40497 .65323 .42639 .66419 .41593 .65803 .39207 Mtetra
.69 .537 .675 r
.65803 .39207 .66419 .41593 .67509 .40418 .66894 .38097 Mtetra
.669 .528 .683 r
.66894 .38097 .67509 .40418 .68599 .39256 .67996 .37216 Mtetra
.644 .528 .708 r
.67996 .37216 .68599 .39256 .69698 .38294 .69114 .3664 Mtetra
.619 .545 .749 r
.69114 .3664 .69698 .38294 .7081 .37542 .7025 .36306 Mtetra
.588 .583 .814 r
.7025 .36306 .7081 .37542 .71937 .37025 .714 .36145 Mtetra
.544 .639 .895 r
.714 .36145 .71937 .37025 .7308 .36683 .72563 .36084 Mtetra
.495 .71 .966 r
.72563 .36084 .7308 .36683 .74235 .36455 .73733 .3603 Mtetra
.447 .76 .995 r
.73733 .3603 .74235 .36455 .754 .36289 .74909 .35954 Mtetra
.454 .802 .998 r
.74909 .35954 .754 .36289 .76572 .36122 .76087 .35806 Mtetra
.492 .83 .998 r
.76087 .35806 .76572 .36122 .77749 .35937 .77266 .35593 Mtetra
.554 .848 .998 r
.77266 .35593 .77749 .35937 .78928 .35706 .78445 .35307 Mtetra
.604 .848 .99 r
.78445 .35307 .78928 .35706 .80109 .35434 .79625 .34967 Mtetra
.639 .834 .976 r
.79625 .34967 .80109 .35434 .81292 .3512 .80807 .34586 Mtetra
.658 .815 .959 r
.80807 .34586 .81292 .3512 .82478 .34776 .81991 .34176 Mtetra
.668 .795 .942 r
.81991 .34176 .82478 .34776 .83668 .34411 .83179 .33751 Mtetra
.67 .775 .928 r
.83179 .33751 .83668 .34411 .84861 .34035 .8437 .33321 Mtetra
.617 .741 .935 r
.20671 .53168 .21326 .53739 .22277 .53471 .2162 .52941 Mtetra
.609 .755 .948 r
.2162 .52941 .22277 .53471 .23232 .53199 .22572 .52721 Mtetra
.604 .774 .962 r
.22572 .52721 .23232 .53199 .24191 .52911 .23528 .52498 Mtetra
.6 .8 .976 r
.23528 .52498 .24191 .52911 .25157 .52597 .24489 .52265 Mtetra
.592 .831 .99 r
.24489 .52265 .25157 .52597 .26129 .52245 .25456 .52014 Mtetra
.589 .87 .994 r
.25456 .52014 .26129 .52245 .27108 .5184 .2643 .51722 Mtetra
.587 .908 .98 r
.2643 .51722 .27108 .5184 .28096 .51366 .27411 .51371 Mtetra
.587 .935 .941 r
.27411 .51371 .28096 .51366 .2909 .50828 .28403 .50936 Mtetra
.612 .955 .895 r
.28403 .50936 .2909 .50828 .30092 .50221 .29404 .50392 Mtetra
.653 .971 .865 r
.29404 .50392 .30092 .50221 .31097 .49591 .30416 .49743 Mtetra
.74 .991 .875 r
.30416 .49743 .31097 .49591 .32103 .48968 .31436 .48981 Mtetra
.81 .974 .901 r
.31436 .48981 .32103 .48968 .33105 .4844 .3246 .48164 Mtetra
.823 .879 .886 r
.3246 .48164 .33105 .4844 .34101 .4808 .33486 .47332 Mtetra
.76 .732 .826 r
.33486 .47332 .34101 .4808 .35088 .47956 .34508 .46588 Mtetra
.679 .597 .757 r
.34508 .46588 .35088 .47956 .36065 .4813 .35522 .46016 Mtetra
.605 .493 .7 r
.35522 .46016 .36065 .4813 .37037 .4853 .36526 .45711 Mtetra
.545 .422 .663 r
.36526 .45711 .37037 .4853 .38011 .49108 .37517 .45753 Mtetra
.507 .379 .641 r
.37517 .45753 .38011 .49108 .38994 .4968 .38502 .46092 Mtetra
.473 .35 .631 r
.38502 .46092 .38994 .4968 .39992 .50088 .39484 .46699 Mtetra
.444 .334 .635 r
.39484 .46699 .39992 .50088 .41014 .50055 .4047 .4747 Mtetra
.388 .327 .668 r
.4047 .4747 .41014 .50055 .42061 .49415 .41465 .48309 Mtetra
.089 .307 .787 r
.41465 .48309 .42061 .49415 .43124 .48258 .42472 .49089 Mtetra
.616 .189 .208 r
.42472 .49089 .43124 .48258 .44197 .46708 .43496 .49673 Mtetra
.53 .226 .396 r
.43496 .49673 .44197 .46708 .45263 .45255 .44541 .49798 Mtetra
.486 .215 .428 r
.44541 .49798 .45263 .45255 .4632 .44146 .45604 .49365 Mtetra
.46 .2 .432 r
.45604 .49365 .4632 .44146 .4737 .4342 .46678 .48526 Mtetra
.435 .178 .424 r
.46678 .48526 .4737 .4342 .48417 .43064 .47756 .47436 Mtetra
.425 .161 .408 r
.47756 .47436 .48417 .43064 .49466 .42828 .48833 .46432 Mtetra
.434 .156 .39 r
.48833 .46432 .49466 .42828 .50521 .4259 .49907 .45699 Mtetra
.472 .177 .384 r
.49907 .45699 .50521 .4259 .5158 .42244 .50982 .45353 Mtetra
.521 .22 .398 r
.50982 .45353 .5158 .42244 .52644 .41789 .5206 .45396 Mtetra
.55 .256 .422 r
.5206 .45396 .52644 .41789 .53711 .41331 .53146 .45712 Mtetra
.556 .272 .441 r
.53146 .45712 .53711 .41331 .54782 .40994 .5424 .46119 Mtetra
.537 .264 .449 r
.5424 .46119 .54782 .40994 .55862 .41029 .55342 .46274 Mtetra
.508 .241 .445 r
.55342 .46274 .55862 .41029 .56953 .41453 .56447 .4602 Mtetra
.453 .188 .42 r
.56447 .4602 .56953 .41453 .5806 .42227 .57548 .45203 Mtetra
.319 .045 .331 r
.57548 .45203 .5806 .42227 .59182 .43105 .58642 .43918 Mtetra
0 0 0 r
.58642 .43918 .59182 .43105 .60306 .43586 .59729 .4243 Mtetra
.821 .696 .727 r
.59729 .4243 .60306 .43586 .61427 .43545 .60811 .40879 Mtetra
.709 .539 .656 r
.60811 .40879 .61427 .43545 .62535 .42888 .61892 .39394 Mtetra
.667 .489 .634 r
.61892 .39394 .62535 .42888 .6363 .41777 .62974 .3807 Mtetra
.642 .467 .632 r
.62974 .3807 .6363 .41777 .64717 .40497 .64064 .3702 Mtetra
.623 .459 .64 r
.64064 .3702 .64717 .40497 .65803 .39207 .65166 .36269 Mtetra
.598 .458 .661 r
.65166 .36269 .65803 .39207 .66894 .38097 .66284 .35872 Mtetra
.572 .473 .703 r
.66284 .35872 .66894 .38097 .67996 .37216 .6742 .3575 Mtetra
.532 .517 .785 r
.6742 .3575 .67996 .37216 .69114 .3664 .68571 .35806 Mtetra
.438 .597 .911 r
.68571 .35806 .69114 .3664 .7025 .36306 .69735 .35953 Mtetra
.217 .655 .953 r
.69735 .35953 .7025 .36306 .714 .36145 .70907 .36087 Mtetra
0 .559 .739 r
.70907 .36087 .714 .36145 .72563 .36084 .72084 .36165 Mtetra
.045 0 0 r
.72084 .36165 .72563 .36084 .73733 .3603 .73261 .36127 Mtetra
0 0 0 r
.73261 .36127 .73733 .3603 .74909 .35954 .74438 .35981 Mtetra
.236 .753 .787 r
.74438 .35981 .74909 .35954 .76087 .35806 .75613 .35723 Mtetra
.431 .867 .916 r
.75613 .35723 .76087 .35806 .77266 .35593 .76788 .35377 Mtetra
.574 .905 .979 r
.76788 .35377 .77266 .35593 .78445 .35307 .77963 .34969 Mtetra
.647 .89 .984 r
.77963 .34969 .78445 .35307 .79625 .34967 .79139 .34518 Mtetra
.675 .856 .968 r
.79139 .34518 .79625 .34967 .80807 .34586 .80317 .34048 Mtetra
.687 .826 .95 r
.80317 .34048 .80807 .34586 .81991 .34176 .81499 .33566 Mtetra
.689 .801 .934 r
.81499 .33566 .81991 .34176 .83179 .33751 .82685 .33081 Mtetra
.687 .78 .922 r
.82685 .33081 .83179 .33751 .8437 .33321 .83876 .32602 Mtetra
.613 .74 .936 r
.20012 .52592 .20671 .53168 .2162 .52941 .20962 .5237 Mtetra
.605 .74 .94 r
.20962 .5237 .2162 .52941 .22572 .52721 .21914 .52161 Mtetra
.598 .742 .945 r
.21914 .52161 .22572 .52721 .23528 .52498 .2287 .51963 Mtetra
.589 .75 .954 r
.2287 .51963 .23528 .52498 .24489 .52265 .23829 .51774 Mtetra
.574 .763 .968 r
.23829 .51774 .24489 .52265 .25456 .52014 .24792 .51598 Mtetra
.562 .79 .985 r
.24792 .51598 .25456 .52014 .2643 .51722 .25759 .51413 Mtetra
.543 .828 .998 r
.25759 .51413 .2643 .51722 .27411 .51371 .26733 .51209 Mtetra
.52 .873 .987 r
.26733 .51209 .27411 .51371 .28403 .50936 .27715 .50948 Mtetra
.48 .893 .919 r
.27715 .50948 .28403 .50936 .29404 .50392 .28706 .50604 Mtetra
.421 .862 .778 r
.28706 .50604 .29404 .50392 .30416 .49743 .2971 .50143 Mtetra
.391 .815 .636 r
.2971 .50143 .30416 .49743 .31436 .48981 .30726 .49533 Mtetra
0 0 0 r
.30726 .49533 .31436 .48981 .3246 .48164 .31752 .48782 Mtetra
.31752 .48782 .3246 .48164 .33486 .47332 .32789 .47886 Mtetra
.577 .889 .612 r
.32789 .47886 .33486 .47332 .34508 .46588 .3383 .46918 Mtetra
.757 .99 .78 r
.3383 .46918 .34508 .46588 .35522 .46016 .34872 .45934 Mtetra
.832 .949 .896 r
.34872 .45934 .35522 .46016 .36526 .45711 .35908 .45068 Mtetra
.75 .761 .862 r
.35908 .45068 .36526 .45711 .37517 .45753 .36933 .44423 Mtetra
.642 .584 .775 r
.36933 .44423 .37517 .45753 .38502 .46092 .37949 .44052 Mtetra
.558 .47 .711 r
.37949 .44052 .38502 .46092 .39484 .46699 .38954 .44012 Mtetra
.497 .395 .669 r
.38954 .44012 .39484 .46699 .4047 .4747 .39951 .44335 Mtetra
.448 .345 .645 r
.39951 .44335 .4047 .4747 .41465 .48309 .40943 .45015 Mtetra
.425 .325 .637 r
.40943 .45015 .41465 .48309 .42472 .49089 .4194 .45866 Mtetra
.422 .326 .64 r
.4194 .45866 .42472 .49089 .43496 .49673 .42949 .46719 Mtetra
.475 .372 .658 r
.42949 .46719 .43496 .49673 .44541 .49798 .43978 .47212 Mtetra
.555 .441 .678 r
.43978 .47212 .44541 .49798 .45604 .49365 .45029 .4718 Mtetra
.62 .503 .698 r
.45029 .4718 .45604 .49365 .46678 .48526 .46093 .4675 Mtetra
.677 .564 .72 r
.46093 .4675 .46678 .48526 .47756 .47436 .47166 .46031 Mtetra
.699 .611 .754 r
.47166 .46031 .47756 .47436 .48833 .46432 .48241 .45309 Mtetra
.694 .648 .799 r
.48241 .45309 .48833 .46432 .49907 .45699 .49316 .44731 Mtetra
.648 .659 .847 r
.49316 .44731 .49907 .45699 .50982 .45353 .50392 .44383 Mtetra
.573 .625 .866 r
.50392 .44383 .50982 .45353 .5206 .45396 .51471 .44264 Mtetra
.526 .567 .839 r
.51471 .44264 .5206 .45396 .53146 .45712 .52557 .44291 Mtetra
.538 .525 .789 r
.52557 .44291 .53146 .45712 .5424 .46119 .53649 .44317 Mtetra
.602 .521 .735 r
.53649 .44317 .5424 .46119 .55342 .46274 .54746 .44053 Mtetra
.649 .521 .694 r
.54746 .44053 .55342 .46274 .56447 .4602 .55844 .43387 Mtetra
.687 .526 .663 r
.55844 .43387 .56447 .4602 .57548 .45203 .56937 .42188 Mtetra
.7 .523 .644 r
.56937 .42188 .57548 .45203 .58642 .43918 .58023 .40622 Mtetra
.69 .509 .637 r
.58023 .40622 .58642 .43918 .59729 .4243 .59104 .39053 Mtetra
.676 .497 .636 r
.59104 .39053 .59729 .4243 .60811 .40879 .60186 .37655 Mtetra
.653 .485 .644 r
.60186 .37655 .60811 .40879 .61892 .39394 .61274 .36616 Mtetra
.631 .484 .664 r
.61274 .36616 .61892 .39394 .62974 .3807 .62374 .35945 Mtetra
.606 .499 .706 r
.62374 .35945 .62974 .3807 .64064 .3702 .63488 .35611 Mtetra
.559 .54 .79 r
.63488 .35611 .64064 .3702 .65166 .36269 .64617 .35557 Mtetra
.384 .608 .938 r
.64617 .35557 .65166 .36269 .66284 .35872 .65763 .35731 Mtetra
0 .422 .694 r
.65763 .35731 .66284 .35872 .6742 .3575 .66923 .36028 Mtetra
.424 0 0 r
.66923 .36028 .6742 .3575 .68571 .35806 .68091 .3631 Mtetra
.448 0 0 r
.68091 .3631 .68571 .35806 .69735 .35953 .69265 .3652 Mtetra
.392 0 0 r
.69265 .3652 .69735 .35953 .70907 .36087 .7044 .36583 Mtetra
.29 0 0 r
.7044 .36583 .70907 .36087 .72084 .36165 .71614 .36501 Mtetra
.088 0 0 r
.71614 .36501 .72084 .36165 .73261 .36127 .72785 .36265 Mtetra
.213 .727 .685 r
.72785 .36265 .73261 .36127 .74438 .35981 .73954 .35909 Mtetra
.507 .906 .918 r
.73954 .35909 .74438 .35981 .75613 .35723 .75122 .35465 Mtetra
.652 .92 .977 r
.75122 .35465 .75613 .35723 .76788 .35377 .7629 .34962 Mtetra
.696 .875 .965 r
.7629 .34962 .76788 .35377 .77963 .34969 .77461 .34437 Mtetra
.707 .834 .943 r
.77461 .34437 .77963 .34969 .79139 .34518 .78634 .33903 Mtetra
.703 .803 .928 r
.78634 .33903 .79139 .34518 .80317 .34048 .79812 .33381 Mtetra
.698 .785 .918 r
.79812 .33381 .80317 .34048 .81499 .33566 .80996 .32868 Mtetra
.694 .773 .913 r
.80996 .32868 .81499 .33566 .82685 .33081 .82184 .32366 Mtetra
.688 .767 .912 r
.82184 .32366 .82685 .33081 .83876 .32602 .83378 .31877 Mtetra
.63 .745 .93 r
.19348 .52013 .20012 .52592 .20962 .5237 .20303 .51754 Mtetra
.625 .731 .923 r
.20303 .51754 .20962 .5237 .21914 .52161 .2126 .51509 Mtetra
.616 .717 .918 r
.2126 .51509 .21914 .52161 .2287 .51963 .2222 .51285 Mtetra
.603 .705 .916 r
.2222 .51285 .2287 .51963 .23829 .51774 .23181 .5109 Mtetra
.584 .697 .92 r
.23181 .5109 .23829 .51774 .24792 .51598 .24144 .50934 Mtetra
.564 .697 .93 r
.24144 .50934 .24792 .51598 .25759 .51413 .25108 .50809 Mtetra
.535 .708 .951 r
.25108 .50809 .25759 .51413 .26733 .51209 .26074 .50719 Mtetra
.502 .741 .98 r
.26074 .50719 .26733 .51209 .27715 .50948 .27044 .50635 Mtetra
.434 .785 .997 r
.27044 .50635 .27715 .50948 .28706 .50604 .2802 .5054 Mtetra
.298 .785 .9 r
.2802 .5054 .28706 .50604 .2971 .50143 .29006 .50389 Mtetra
0 0 0 r
.29006 .50389 .2971 .50143 .30726 .49533 .30002 .50142 Mtetra
.068 0 0 r
.30002 .50142 .30726 .49533 .31752 .48782 .31012 .49757 Mtetra
.126 0 0 r
.31012 .49757 .31752 .48782 .32789 .47886 .32036 .49194 Mtetra
.148 0 .05 r
.32036 .49194 .32789 .47886 .3383 .46918 .33073 .4845 Mtetra
.124 0 .084 r
.33073 .4845 .3383 .46918 .34872 .45934 .34123 .47516 Mtetra
.071 0 .067 r
.34123 .47516 .34872 .45934 .35908 .45068 .35179 .46441 Mtetra
0 0 0 r
.35179 .46441 .35908 .45068 .36933 .44423 .3624 .45263 Mtetra
.3624 .45263 .36933 .44423 .37949 .44052 .373 .44082 Mtetra
.878 .967 .847 r
.373 .44082 .37949 .44052 .38954 .44012 .38355 .42974 Mtetra
.764 .681 .771 r
.38355 .42974 .38954 .44012 .39951 .44335 .39404 .42022 Mtetra
.657 .517 .681 r
.39404 .42022 .39951 .44335 .40943 .45015 .40444 .41271 Mtetra
.61 .443 .631 r
.40444 .41271 .40943 .45015 .4194 .45866 .41483 .40619 Mtetra
.586 .405 .603 r
.41483 .40619 .4194 .45866 .42949 .46719 .42521 .40049 Mtetra
.565 .378 .587 r
.42521 .40049 .42949 .46719 .43978 .47212 .43556 .39692 Mtetra
.548 .361 .579 r
.43556 .39692 .43978 .47212 .45029 .4718 .44588 .39595 Mtetra
.534 .35 .577 r
.44588 .39595 .45029 .4718 .46093 .4675 .4562 .39767 Mtetra
.522 .344 .581 r
.4562 .39767 .46093 .4675 .47166 .46031 .46656 .40132 Mtetra
.525 .355 .592 r
.46656 .40132 .47166 .46031 .48241 .45309 .47702 .40413 Mtetra
.543 .378 .608 r
.47702 .40413 .48241 .45309 .49316 .44731 .48759 .40451 Mtetra
.578 .412 .62 r
.48759 .40451 .49316 .44731 .50392 .44383 .49826 .40096 Mtetra
.609 .434 .62 r
.49826 .40096 .50392 .44383 .51471 .44264 .50899 .39349 Mtetra
.616 .431 .608 r
.50899 .39349 .51471 .44264 .52557 .44291 .51974 .38357 Mtetra
.609 .416 .595 r
.51974 .38357 .52557 .44291 .53649 .44317 .53048 .37277 Mtetra
.59 .394 .585 r
.53048 .37277 .53649 .44317 .54746 .44053 .54123 .36391 Mtetra
.573 .379 .58 r
.54123 .36391 .54746 .44053 .55844 .43387 .55202 .35773 Mtetra
.561 .37 .58 r
.55202 .35773 .55844 .43387 .56937 .42188 .56285 .35417 Mtetra
.552 .368 .586 r
.56285 .35417 .56937 .42188 .58023 .40622 .57377 .35277 Mtetra
.549 .378 .602 r
.57377 .35277 .58023 .40622 .59104 .39053 .58475 .35221 Mtetra
.543 .396 .632 r
.58475 .35221 .59104 .39053 .60186 .37655 .59583 .35266 Mtetra
.506 .421 .693 r
.59583 .35266 .60186 .37655 .61274 .36616 .60703 .35517 Mtetra
.353 .478 .847 r
.60703 .35517 .61274 .36616 .62374 .35945 .61837 .35929 Mtetra
.434 0 0 r
.61837 .35929 .62374 .35945 .63488 .35611 .62983 .36419 Mtetra
.574 .122 .139 r
.62983 .36419 .63488 .35611 .64617 .35557 .6414 .36908 Mtetra
.556 .164 .254 r
.6414 .36908 .64617 .35557 .65763 .35731 .65304 .37295 Mtetra
.53 .156 .275 r
.65304 .37295 .65763 .35731 .66923 .36028 .66472 .3754 Mtetra
.488 .112 .253 r
.66472 .3754 .66923 .36028 .68091 .3631 .6764 .37591 Mtetra
.426 .034 .189 r
.6764 .37591 .68091 .3631 .69265 .3652 .68806 .37456 Mtetra
.306 0 .049 r
.68806 .37456 .69265 .3652 .7044 .36583 .69968 .37138 Mtetra
.065 0 0 r
.69968 .37138 .7044 .36583 .71614 .36501 .71128 .36678 Mtetra
.37 .822 .705 r
.71128 .36678 .71614 .36501 .72785 .36265 .72286 .36117 Mtetra
.677 .958 .945 r
.72286 .36117 .72785 .36265 .73954 .35909 .73443 .35497 Mtetra
.739 .887 .947 r
.73443 .35497 .73954 .35909 .75122 .35465 .74602 .34864 Mtetra
.737 .818 .914 r
.74602 .34864 .75122 .35465 .7629 .34962 .75765 .34237 Mtetra
.721 .772 .893 r
.75765 .34237 .7629 .34962 .77461 .34437 .76934 .33644 Mtetra
.708 .748 .883 r
.76934 .33644 .77461 .34437 .78634 .33903 .78109 .33084 Mtetra
.695 .736 .883 r
.78109 .33084 .78634 .33903 .79812 .33381 .79291 .32564 Mtetra
.686 .734 .888 r
.79291 .32564 .79812 .33381 .80996 .32868 .8048 .32072 Mtetra
.68 .739 .896 r
.8048 .32072 .80996 .32868 .82184 .32366 .81675 .31602 Mtetra
.676 .748 .905 r
.81675 .31602 .82184 .32366 .83378 .31877 .82876 .31146 Mtetra
.661 .753 .918 r
.18679 .51429 .19348 .52013 .20303 .51754 .19643 .51099 Mtetra
.657 .729 .902 r
.19643 .51099 .20303 .51754 .2126 .51509 .2061 .50776 Mtetra
.648 .703 .887 r
.2061 .50776 .2126 .51509 .2222 .51285 .21578 .50474 Mtetra
.635 .678 .874 r
.21578 .50474 .2222 .51285 .23181 .5109 .22547 .50204 Mtetra
.617 .652 .862 r
.22547 .50204 .23181 .5109 .24144 .50934 .23516 .49979 Mtetra
.597 .629 .853 r
.23516 .49979 .24144 .50934 .25108 .50809 .24484 .49806 Mtetra
.574 .608 .849 r
.24484 .49806 .25108 .50809 .26074 .50719 .25452 .49697 Mtetra
.552 .594 .85 r
.25452 .49697 .26074 .50719 .27044 .50635 .26421 .49644 Mtetra
.526 .59 .861 r
.26421 .49644 .27044 .50635 .2802 .5054 .2739 .49645 Mtetra
.507 .606 .886 r
.2739 .49645 .2802 .5054 .29006 .50389 .28364 .49666 Mtetra
.482 .648 .931 r
.28364 .49666 .29006 .50389 .30002 .50142 .29344 .49684 Mtetra
.447 .735 .989 r
.29344 .49684 .30002 .50142 .31012 .49757 .30333 .49645 Mtetra
.327 .794 .931 r
.30333 .49645 .31012 .49757 .32036 .49194 .31335 .49502 Mtetra
0 0 0 r
.31335 .49502 .32036 .49194 .33073 .4845 .3235 .49209 Mtetra
.073 0 0 r
.3235 .49209 .33073 .4845 .34123 .47516 .33381 .48722 Mtetra
.134 0 .016 r
.33381 .48722 .34123 .47516 .35179 .46441 .34427 .48019 Mtetra
.139 0 .097 r
.34427 .48019 .35179 .46441 .3624 .45263 .35486 .47083 Mtetra
.142 0 .137 r
.35486 .47083 .3624 .45263 .373 .44082 .36553 .45996 Mtetra
.128 0 .145 r
.36553 .45996 .373 .44082 .38355 .42974 .37624 .44808 Mtetra
.086 0 .116 r
.37624 .44808 .38355 .42974 .39404 .42022 .38695 .43568 Mtetra
0 0 .022 r
.38695 .43568 .39404 .42022 .40444 .41271 .39765 .42328 Mtetra
0 0 0 r
.39765 .42328 .40444 .41271 .41483 .40619 .40832 .41127 Mtetra
.646 .921 .634 r
.40832 .41127 .41483 .40619 .42521 .40049 .41893 .40048 Mtetra
.743 .98 .915 r
.41893 .40048 .42521 .40049 .43556 .39692 .42943 .39336 Mtetra
.578 .833 .993 r
.42943 .39336 .43556 .39692 .44588 .39595 .43982 .39078 Mtetra
.364 .672 .975 r
.43982 .39078 .44588 .39595 .4562 .39767 .45018 .39158 Mtetra
.209 .547 .93 r
.45018 .39158 .4562 .39767 .46656 .40132 .46057 .39456 Mtetra
.319 .585 .939 r
.46057 .39456 .46656 .40132 .47702 .40413 .47105 .39677 Mtetra
.504 .659 .93 r
.47105 .39677 .47702 .40413 .48759 .40451 .48164 .39659 Mtetra
.656 .707 .885 r
.48164 .39659 .48759 .40451 .49826 .40096 .49233 .39302 Mtetra
.746 .736 .843 r
.49233 .39302 .49826 .40096 .50899 .39349 .50309 .38605 Mtetra
.796 .76 .821 r
.50309 .38605 .50899 .39349 .51974 .38357 .51387 .37668 Mtetra
.815 .778 .819 r
.51387 .37668 .51974 .38357 .53048 .37277 .52466 .36651 Mtetra
.784 .793 .86 r
.52466 .36651 .53048 .37277 .54123 .36391 .53545 .35851 Mtetra
.694 .805 .933 r
.53545 .35851 .54123 .36391 .55202 .35773 .54628 .35392 Mtetra
.362 .73 .988 r
.54628 .35392 .55202 .35773 .56285 .35417 .55719 .3539 Mtetra
.357 0 0 r
.55719 .3539 .56285 .35417 .57377 .35277 .56823 .35761 Mtetra
.568 .066 .02 r
.56823 .35761 .57377 .35277 .58475 .35221 .57937 .36258 Mtetra
.59 .169 .213 r
.57937 .36258 .58475 .35221 .59583 .35266 .59063 .36799 Mtetra
.584 .207 .293 r
.59063 .36799 .59583 .35266 .60703 .35517 .602 .37342 Mtetra
.573 .213 .321 r
.602 .37342 .60703 .35517 .61837 .35929 .61347 .37835 Mtetra
.557 .202 .322 r
.61347 .37835 .61837 .35929 .62983 .36419 .62501 .38229 Mtetra
.531 .172 .303 r
.62501 .38229 .62983 .36419 .6414 .36908 .6366 .3847 Mtetra
.478 .106 .254 r
.6366 .3847 .6414 .36908 .65304 .37295 .64819 .38474 Mtetra
.386 0 .147 r
.64819 .38474 .65304 .37295 .66472 .3754 .65977 .38258 Mtetra
.174 0 0 r
.65977 .38258 .66472 .3754 .6764 .37591 .67131 .37841 Mtetra
.317 .776 .636 r
.67131 .37841 .6764 .37591 .68806 .37456 .68282 .3727 Mtetra
.726 .958 .945 r
.68282 .3727 .68806 .37456 .69968 .37138 .6943 .3659 Mtetra
.773 .841 .904 r
.6943 .3659 .69968 .37138 .71128 .36678 .70578 .3585 Mtetra
.751 .751 .852 r
.70578 .3585 .71128 .36678 .72286 .36117 .71728 .35105 Mtetra
.73 .701 .823 r
.71728 .35105 .72286 .36117 .73443 .35497 .72881 .34379 Mtetra
.71 .672 .811 r
.72881 .34379 .73443 .35497 .74602 .34864 .74041 .33709 Mtetra
.695 .66 .81 r
.74041 .33709 .74602 .34864 .75765 .34237 .75207 .33096 Mtetra
.682 .656 .818 r
.75207 .33096 .75765 .34237 .76934 .33644 .76382 .32548 Mtetra
.672 .661 .831 r
.76382 .32548 .76934 .33644 .78109 .33084 .77564 .32053 Mtetra
.664 .671 .847 r
.77564 .32053 .78109 .33084 .79291 .32564 .78755 .31605 Mtetra
.658 .686 .865 r
.78755 .31605 .79291 .32564 .8048 .32072 .79954 .3119 Mtetra
.653 .705 .885 r
.79954 .3119 .8048 .32072 .81675 .31602 .81159 .30796 Mtetra
.651 .726 .904 r
.81159 .30796 .81675 .31602 .82876 .31146 .82371 .3041 Mtetra
.692 .759 .903 r
.18006 .50842 .18679 .51429 .19643 .51099 .1898 .50428 Mtetra
.688 .733 .885 r
.1898 .50428 .19643 .51099 .2061 .50776 .19958 .50012 Mtetra
.68 .705 .866 r
.19958 .50012 .2061 .50776 .21578 .50474 .20937 .49607 Mtetra
.669 .676 .848 r
.20937 .49607 .21578 .50474 .22547 .50204 .21918 .49222 Mtetra
.654 .646 .83 r
.21918 .49222 .22547 .50204 .23516 .49979 .22899 .48868 Mtetra
.635 .614 .812 r
.22899 .48868 .23516 .49979 .24484 .49806 .23879 .48563 Mtetra
.613 .582 .795 r
.23879 .48563 .24484 .49806 .25452 .49697 .24858 .48322 Mtetra
.59 .552 .78 r
.24858 .48322 .25452 .49697 .26421 .49644 .25834 .48156 Mtetra
.564 .524 .769 r
.25834 .48156 .26421 .49644 .2739 .49645 .26808 .48082 Mtetra
.541 .502 .762 r
.26808 .48082 .2739 .49645 .28364 .49666 .27781 .48093 Mtetra
.516 .487 .763 r
.27781 .48093 .28364 .49666 .29344 .49684 .28754 .48191 Mtetra
.495 .485 .775 r
.28754 .48191 .29344 .49684 .30333 .49645 .29729 .48343 Mtetra
.47 .5 .808 r
.29729 .48343 .30333 .49645 .31335 .49502 .30709 .48527 Mtetra
.436 .553 .875 r
.30709 .48527 .31335 .49502 .3235 .49209 .31697 .48695 Mtetra
.325 .655 .971 r
.31697 .48695 .3235 .49209 .33381 .48722 .32695 .48804 Mtetra
.088 0 0 r
.32695 .48804 .33381 .48722 .34427 .48019 .33705 .48808 Mtetra
.333 0 0 r
.33705 .48808 .34427 .48019 .35486 .47083 .3473 .48665 Mtetra
.4 .035 .225 r
.3473 .48665 .35486 .47083 .36553 .45996 .35766 .48387 Mtetra
.422 .103 .316 r
.35766 .48387 .36553 .45996 .37624 .44808 .36814 .47971 Mtetra
.425 .13 .359 r
.36814 .47971 .37624 .44808 .38695 .43568 .37873 .47376 Mtetra
.423 .144 .382 r
.37873 .47376 .38695 .43568 .39765 .42328 .38941 .46611 Mtetra
.439 .165 .4 r
.38941 .46611 .39765 .42328 .40832 .41127 .40011 .45856 Mtetra
.459 .189 .416 r
.40011 .45856 .40832 .41127 .41893 .40048 .41079 .45201 Mtetra
.476 .209 .428 r
.41079 .45201 .41893 .40048 .42943 .39336 .42145 .44659 Mtetra
.487 .219 .434 r
.42145 .44659 .42943 .39336 .43982 .39078 .43211 .44215 Mtetra
.477 .209 .428 r
.43211 .44215 .43982 .39078 .45018 .39158 .44283 .43678 Mtetra
.455 .183 .411 r
.44283 .43678 .45018 .39158 .46057 .39456 .45361 .4301 Mtetra
.431 .146 .378 r
.45361 .4301 .46057 .39456 .47105 .39677 .46441 .42342 Mtetra
.408 .102 .331 r
.46441 .42342 .47105 .39677 .48164 .39659 .47522 .41755 Mtetra
.423 .09 .295 r
.47522 .41755 .48164 .39659 .49233 .39302 .48603 .41398 Mtetra
.47 .134 .313 r
.48603 .41398 .49233 .39302 .50309 .38605 .49686 .41271 Mtetra
.498 .181 .361 r
.49686 .41271 .50309 .38605 .51387 .37668 .50775 .41227 Mtetra
.508 .213 .401 r
.50775 .41227 .51387 .37668 .52466 .36651 .5187 .41184 Mtetra
.503 .224 .424 r
.5187 .41184 .52466 .36651 .53545 .35851 .52971 .4101 Mtetra
.5 .229 .434 r
.52971 .4101 .53545 .35851 .54628 .35392 .54078 .40743 Mtetra
.509 .238 .439 r
.54078 .40743 .54628 .35392 .55719 .3539 .55191 .40574 Mtetra
.516 .242 .438 r
.55191 .40574 .55719 .3539 .56823 .35761 .56311 .40521 Mtetra
.522 .243 .432 r
.56311 .40521 .56823 .35761 .57937 .36258 .57439 .40571 Mtetra
.522 .236 .422 r
.57439 .40571 .57937 .36258 .59063 .36799 .58575 .40633 Mtetra
.503 .213 .406 r
.58575 .40633 .59063 .36799 .602 .37342 .59715 .40522 Mtetra
.474 .174 .376 r
.59715 .40522 .602 .37342 .61347 .37835 .60856 .4023 Mtetra
.427 .108 .319 r
.60856 .4023 .61347 .37835 .62501 .38229 .61999 .39795 Mtetra
.323 0 .194 r
.61999 .39795 .62501 .38229 .6366 .3847 .63142 .39223 Mtetra
0 0 0 r
.63142 .39223 .6366 .3847 .64819 .38474 .64282 .38499 Mtetra
.721 .988 .867 r
.64282 .38499 .64819 .38474 .65977 .38258 .6542 .37665 Mtetra
.805 .828 .869 r
.6542 .37665 .65977 .38258 .67131 .37841 .66557 .36769 Mtetra
.758 .698 .795 r
.66557 .36769 .67131 .37841 .68282 .3727 .67694 .35855 Mtetra
.722 .632 .757 r
.67694 .35855 .68282 .3727 .6943 .3659 .68833 .34971 Mtetra
.7 .598 .74 r
.68833 .34971 .6943 .3659 .70578 .3585 .69976 .34142 Mtetra
.681 .58 .735 r
.69976 .34142 .70578 .3585 .71728 .35105 .71127 .334 Mtetra
.668 .573 .74 r
.71127 .334 .71728 .35105 .72881 .34379 .72285 .32746 Mtetra
.656 .574 .751 r
.72285 .32746 .72881 .34379 .74041 .33709 .73452 .32185 Mtetra
.648 .582 .767 r
.73452 .32185 .74041 .33709 .75207 .33096 .74629 .31703 Mtetra
.64 .596 .788 r
.74629 .31703 .75207 .33096 .76382 .32548 .75814 .31287 Mtetra
.634 .613 .812 r
.75814 .31287 .76382 .32548 .77564 .32053 .77009 .3092 Mtetra
.629 .635 .837 r
.77009 .3092 .77564 .32053 .78755 .31605 .78211 .30586 Mtetra
.625 .658 .862 r
.78211 .30586 .78755 .31605 .79954 .3119 .79421 .30274 Mtetra
.623 .683 .886 r
.79421 .30274 .79954 .3119 .81159 .30796 .80638 .29972 Mtetra
.622 .709 .909 r
.80638 .29972 .81159 .30796 .82371 .3041 .81861 .29669 Mtetra
.707 .762 .895 r
.17328 .5025 .18006 .50842 .1898 .50428 .1831 .49787 Mtetra
.708 .747 .883 r
.1831 .49787 .1898 .50428 .19958 .50012 .19295 .49312 Mtetra
.705 .73 .87 r
.19295 .49312 .19958 .50012 .20937 .49607 .20283 .48833 Mtetra
.699 .71 .856 r
.20283 .48833 .20937 .49607 .21918 .49222 .21274 .48356 Mtetra
.692 .686 .84 r
.21274 .48356 .21918 .49222 .22899 .48868 .22267 .47884 Mtetra
.678 .656 .821 r
.22267 .47884 .22899 .48868 .23879 .48563 .23261 .47435 Mtetra
.661 .624 .802 r
.23261 .47435 .23879 .48563 .24858 .48322 .24255 .47022 Mtetra
.639 .588 .781 r
.24255 .47022 .24858 .48322 .25834 .48156 .25247 .46666 Mtetra
.614 .551 .76 r
.25247 .46666 .25834 .48156 .26808 .48082 .26236 .46387 Mtetra
.589 .516 .74 r
.26236 .46387 .26808 .48082 .27781 .48093 .27223 .46199 Mtetra
.563 .483 .724 r
.27223 .46199 .27781 .48093 .28754 .48191 .28206 .4612 Mtetra
.541 .457 .71 r
.28206 .4612 .28754 .48191 .29729 .48343 .29187 .46144 Mtetra
.52 .435 .7 r
.29187 .46144 .29729 .48343 .30709 .48527 .30167 .46272 Mtetra
.504 .422 .697 r
.30167 .46272 .30709 .48527 .31697 .48695 .31148 .46474 Mtetra
.492 .417 .7 r
.31148 .46474 .31697 .48695 .32695 .48804 .32134 .4673 Mtetra
.484 .422 .712 r
.32134 .4673 .32695 .48804 .33705 .48808 .33126 .47 Mtetra
.478 .442 .739 r
.33126 .47 .33705 .48808 .3473 .48665 .34127 .47252 Mtetra
.474 .489 .793 r
.34127 .47252 .3473 .48665 .35766 .48387 .35138 .47444 Mtetra
.469 .582 .885 r
.35138 .47444 .35766 .48387 .36814 .47971 .36162 .4754 Mtetra
.429 .745 .993 r
.36162 .4754 .36814 .47971 .37873 .47376 .37199 .47494 Mtetra
.148 .688 .711 r
.37199 .47494 .37873 .47376 .38941 .46611 .38249 .4729 Mtetra
.244 0 0 r
.38249 .4729 .38941 .46611 .40011 .45856 .39305 .47067 Mtetra
.379 0 .144 r
.39305 .47067 .40011 .45856 .41079 .45201 .40365 .46855 Mtetra
.382 .021 .223 r
.40365 .46855 .41079 .45201 .42145 .44659 .41435 .46497 Mtetra
.338 0 .227 r
.41435 .46497 .42145 .44659 .43211 .44215 .42516 .45925 Mtetra
.223 0 .159 r
.42516 .45925 .43211 .44215 .44283 .43678 .43607 .45076 Mtetra
.03 0 .014 r
.43607 .45076 .44283 .43678 .45361 .4301 .44705 .4401 Mtetra
0 0 0 r
.44705 .4401 .45361 .4301 .46441 .42342 .458 .43018 Mtetra
.458 .43018 .46441 .42342 .47522 .41755 .46892 .42263 Mtetra
.054 0 0 r
.46892 .42263 .47522 .41755 .48603 .41398 .47979 .41904 Mtetra
.359 0 0 r
.47979 .41904 .48603 .41398 .49686 .41271 .49067 .41943 Mtetra
.504 .027 .055 r
.49067 .41943 .49686 .41271 .50775 .41227 .5016 .42221 Mtetra
.545 .116 .177 r
.5016 .42221 .50775 .41227 .5187 .41184 .51262 .42577 Mtetra
.5 .111 .235 r
.51262 .42577 .5187 .41184 .52971 .4101 .52373 .42715 Mtetra
.448 .086 .257 r
.52373 .42715 .52971 .4101 .54078 .40743 .53491 .42577 Mtetra
.404 .055 .256 r
.53491 .42577 .54078 .40743 .55191 .40574 .54613 .42222 Mtetra
.346 0 .209 r
.54613 .42222 .55191 .40574 .56311 .40521 .55739 .41718 Mtetra
.273 0 .092 r
.55739 .41718 .56311 .40521 .57439 .40571 .56869 .41226 Mtetra
.05 0 0 r
.56869 .41226 .57439 .40571 .58575 .40633 .58002 .40713 Mtetra
.604 .953 .854 r
.58002 .40713 .58575 .40633 .59715 .40522 .59136 .40039 Mtetra
.797 .859 .896 r
.59136 .40039 .59715 .40522 .60856 .4023 .60269 .39219 Mtetra
.765 .71 .801 r
.60269 .39219 .60856 .4023 .61999 .39795 .614 .38298 Mtetra
.73 .625 .742 r
.614 .38298 .61999 .39795 .63142 .39223 .6253 .37315 Mtetra
.704 .576 .708 r
.6253 .37315 .63142 .39223 .64282 .38499 .6366 .3631 Mtetra
.687 .548 .691 r
.6366 .3631 .64282 .38499 .6542 .37665 .64791 .35318 Mtetra
.673 .531 .684 r
.64791 .35318 .6542 .37665 .66557 .36769 .65924 .34379 Mtetra
.663 .523 .683 r
.65924 .34379 .66557 .36769 .67694 .35855 .67061 .33515 Mtetra
.653 .519 .688 r
.67061 .33515 .67694 .35855 .68833 .34971 .68205 .32755 Mtetra
.645 .521 .699 r
.68205 .32755 .68833 .34971 .69976 .34142 .69356 .32101 Mtetra
.636 .528 .714 r
.69356 .32101 .69976 .34142 .71127 .334 .70517 .31558 Mtetra
.628 .539 .734 r
.70517 .31558 .71127 .334 .72285 .32746 .71687 .31109 Mtetra
.621 .555 .759 r
.71687 .31109 .72285 .32746 .73452 .32185 .72867 .3074 Mtetra
.615 .575 .786 r
.72867 .3074 .73452 .32185 .74629 .31703 .74057 .3043 Mtetra
.61 .599 .815 r
.74057 .3043 .74629 .31703 .75814 .31287 .75255 .30157 Mtetra
.605 .624 .843 r
.75255 .30157 .75814 .31287 .77009 .3092 .7646 .29908 Mtetra
.604 .649 .868 r
.7646 .29908 .77009 .3092 .78211 .30586 .77673 .29665 Mtetra
.601 .672 .89 r
.77673 .29665 .78211 .30586 .79421 .30274 .78892 .29424 Mtetra
.601 .692 .907 r
.78892 .29424 .79421 .30274 .80638 .29972 .80117 .29178 Mtetra
.602 .711 .921 r
.80117 .29178 .80638 .29972 .81861 .29669 .81347 .28921 Mtetra
.708 .762 .895 r
.16646 .49655 .17328 .5025 .1831 .49787 .1763 .49187 Mtetra
.712 .762 .892 r
.1763 .49187 .1831 .49787 .19295 .49312 .18618 .48704 Mtetra
.717 .761 .887 r
.18618 .48704 .19295 .49312 .20283 .48833 .19611 .48202 Mtetra
.721 .755 .88 r
.19611 .48202 .20283 .48833 .21274 .48356 .20608 .47681 Mtetra
.724 .744 .868 r
.20608 .47681 .21274 .48356 .22267 .47884 .2161 .47136 Mtetra
.721 .724 .853 r
.2161 .47136 .22267 .47884 .23261 .47435 .22616 .46578 Mtetra
.714 .697 .833 r
.22616 .46578 .23261 .47435 .24255 .47022 .23624 .46014 Mtetra
.699 .661 .809 r
.23624 .46014 .24255 .47022 .25247 .46666 .24634 .45462 Mtetra
.68 .621 .783 r
.24634 .45462 .25247 .46666 .26236 .46387 .25644 .44937 Mtetra
.655 .578 .756 r
.25644 .44937 .26236 .46387 .27223 .46199 .26652 .44464 Mtetra
.629 .536 .73 r
.26652 .44464 .27223 .46199 .28206 .4612 .27658 .44065 Mtetra
.604 .497 .706 r
.27658 .44065 .28206 .4612 .29187 .46144 .2866 .43753 Mtetra
.58 .463 .685 r
.2866 .43753 .29187 .46144 .30167 .46272 .29659 .43548 Mtetra
.56 .435 .667 r
.29659 .43548 .30167 .46272 .31148 .46474 .30656 .43445 Mtetra
.543 .413 .653 r
.30656 .43445 .31148 .46474 .32134 .4673 .31651 .43449 Mtetra
.53 .396 .643 r
.31651 .43449 .32134 .4673 .33126 .47 .32647 .43547 Mtetra
.519 .384 .637 r
.32647 .43547 .33126 .47 .34127 .47252 .33644 .43731 Mtetra
.517 .381 .635 r
.33644 .43731 .34127 .47252 .35138 .47444 .34647 .43938 Mtetra
.519 .384 .636 r
.34647 .43938 .35138 .47444 .36162 .4754 .35658 .44127 Mtetra
.519 .387 .64 r
.35658 .44127 .36162 .4754 .37199 .47494 .36677 .44311 Mtetra
.52 .394 .649 r
.36677 .44311 .37199 .47494 .38249 .4729 .37705 .44481 Mtetra
.524 .411 .666 r
.37705 .44481 .38249 .4729 .39305 .47067 .38741 .44609 Mtetra
.538 .437 .687 r
.38741 .44609 .39305 .47067 .40365 .46855 .39788 .44645 Mtetra
.589 .483 .701 r
.39788 .44645 .40365 .46855 .41435 .46497 .40852 .44394 Mtetra
.642 .523 .703 r
.40852 .44394 .41435 .46497 .42516 .45925 .41931 .43807 Mtetra
.664 .535 .698 r
.41931 .43807 .42516 .45925 .43607 .45076 .43019 .43053 Mtetra
.675 .548 .702 r
.43019 .43053 .43607 .45076 .44705 .4401 .44109 .42243 Mtetra
.674 .566 .725 r
.44109 .42243 .44705 .4401 .458 .43018 .45198 .41538 Mtetra
.661 .587 .761 r
.45198 .41538 .458 .43018 .46892 .42263 .46286 .41013 Mtetra
.637 .607 .802 r
.46286 .41013 .46892 .42263 .47979 .41904 .47374 .40651 Mtetra
.594 .585 .812 r
.47374 .40651 .47979 .41904 .49067 .41943 .48465 .40453 Mtetra
.544 .523 .783 r
.48465 .40453 .49067 .41943 .5016 .42221 .4956 .40436 Mtetra
.521 .477 .748 r
.4956 .40436 .5016 .42221 .51262 .42577 .5066 .40527 Mtetra
.537 .464 .721 r
.5066 .40527 .51262 .42577 .52373 .42715 .51769 .40561 Mtetra
.568 .477 .711 r
.51769 .40561 .52373 .42715 .53491 .42577 .52884 .40429 Mtetra
.623 .511 .706 r
.52884 .40429 .53491 .42577 .54613 .42222 .54005 .39958 Mtetra
.657 .525 .692 r
.54005 .39958 .54613 .42222 .55739 .41718 .55126 .39196 Mtetra
.658 .513 .676 r
.55126 .39196 .55739 .41718 .56869 .41226 .56249 .38338 Mtetra
.649 .494 .659 r
.56249 .38338 .56869 .41226 .58002 .40713 .57371 .37436 Mtetra
.639 .475 .645 r
.57371 .37436 .58002 .40713 .59136 .40039 .58495 .36518 Mtetra
.633 .465 .637 r
.58495 .36518 .59136 .40039 .60269 .39219 .59619 .35592 Mtetra
.632 .462 .634 r
.59619 .35592 .60269 .39219 .614 .38298 .60743 .34647 Mtetra
.63 .46 .634 r
.60743 .34647 .614 .38298 .6253 .37315 .61869 .33723 Mtetra
.624 .457 .636 r
.61869 .33723 .6253 .37315 .6366 .3631 .62998 .32885 Mtetra
.619 .458 .642 r
.62998 .32885 .6366 .3631 .64791 .35318 .64132 .32142 Mtetra
.614 .461 .651 r
.64132 .32142 .64791 .35318 .65924 .34379 .65273 .31507 Mtetra
.61 .469 .664 r
.65273 .31507 .65924 .34379 .67061 .33515 .66421 .30977 Mtetra
.604 .479 .683 r
.66421 .30977 .67061 .33515 .68205 .32755 .67578 .30556 Mtetra
.599 .494 .707 r
.67578 .30556 .68205 .32755 .69356 .32101 .68745 .30225 Mtetra
.593 .515 .736 r
.68745 .30225 .69356 .32101 .70517 .31558 .69921 .2997 Mtetra
.587 .541 .77 r
.69921 .2997 .70517 .31558 .71687 .31109 .71107 .29769 Mtetra
.583 .573 .808 r
.71107 .29769 .71687 .31109 .72867 .3074 .723 .29597 Mtetra
.578 .607 .845 r
.723 .29597 .72867 .3074 .74057 .3043 .73502 .29438 Mtetra
.577 .641 .877 r
.73502 .29438 .74057 .3043 .75255 .30157 .7471 .29272 Mtetra
.577 .67 .903 r
.7471 .29272 .75255 .30157 .7646 .29908 .75924 .29094 Mtetra
.582 .694 .919 r
.75924 .29094 .7646 .29908 .77673 .29665 .77142 .28891 Mtetra
.587 .71 .928 r
.77142 .28891 .77673 .29665 .78892 .29424 .78366 .28668 Mtetra
.593 .72 .933 r
.78366 .28668 .78892 .29424 .80117 .29178 .79596 .28427 Mtetra
.599 .725 .933 r
.79596 .28427 .80117 .29178 .81347 .28921 .8083 .28168 Mtetra
.687 .758 .906 r
.15958 .49055 .16646 .49655 .1763 .49187 .16938 .48647 Mtetra
.694 .78 .917 r
.16938 .48647 .1763 .49187 .18618 .48704 .17923 .48222 Mtetra
.703 .803 .927 r
.17923 .48222 .18618 .48704 .19611 .48202 .18913 .47773 Mtetra
.715 .824 .933 r
.18913 .47773 .19611 .48202 .20608 .47681 .19909 .47294 Mtetra
.729 .842 .934 r
.19909 .47294 .20608 .47681 .2161 .47136 .20911 .46775 Mtetra
.742 .853 .931 r
.20911 .46775 .2161 .47136 .22616 .46578 .2192 .46218 Mtetra
.755 .854 .924 r
.2192 .46218 .22616 .46578 .23624 .46014 .22935 .45621 Mtetra
.763 .844 .913 r
.22935 .45621 .23624 .46014 .24634 .45462 .23954 .44996 Mtetra
.764 .819 .896 r
.23954 .44996 .24634 .45462 .25644 .44937 .24977 .4435 Mtetra
.755 .78 .874 r
.24977 .4435 .25644 .44937 .26652 .44464 .26002 .43704 Mtetra
.736 .729 .845 r
.26002 .43704 .26652 .44464 .27658 .44065 .27027 .43075 Mtetra
.708 .671 .812 r
.27027 .43075 .27658 .44065 .2866 .43753 .28051 .42487 Mtetra
.675 .613 .778 r
.28051 .42487 .2866 .43753 .29659 .43548 .29074 .41962 Mtetra
.644 .559 .745 r
.29074 .41962 .29659 .43548 .30656 .43445 .30093 .41511 Mtetra
.614 .513 .715 r
.30093 .41511 .30656 .43445 .31651 .43449 .3111 .41149 Mtetra
.589 .475 .691 r
.3111 .41149 .31651 .43449 .32647 .43547 .32124 .40885 Mtetra
.568 .444 .67 r
.32124 .40885 .32647 .43547 .33644 .43731 .33137 .40724 Mtetra
.557 .424 .655 r
.33137 .40724 .33644 .43731 .34647 .43938 .34152 .4062 Mtetra
.551 .41 .643 r
.34152 .4062 .34647 .43938 .35658 .44127 .3517 .4055 Mtetra
.541 .397 .634 r
.3517 .4055 .35658 .44127 .36677 .44311 .3619 .40557 Mtetra
.532 .386 .629 r
.3619 .40557 .36677 .44311 .37705 .44481 .37213 .40639 Mtetra
.536 .388 .627 r
.37213 .40639 .37705 .44481 .38741 .44609 .38244 .40685 Mtetra
.547 .394 .625 r
.38244 .40685 .38741 .44609 .39788 .44645 .39286 .4063 Mtetra
.563 .404 .624 r
.39286 .4063 .39788 .44645 .40852 .44394 .4034 .40408 Mtetra
.579 .416 .625 r
.4034 .40408 .40852 .44394 .41931 .43807 .41405 .40023 Mtetra
.576 .418 .63 r
.41405 .40023 .41931 .43807 .43019 .43053 .42472 .39687 Mtetra
.569 .423 .644 r
.42472 .39687 .43019 .43053 .44109 .42243 .43541 .39462 Mtetra
.57 .443 .668 r
.43541 .39462 .44109 .42243 .45198 .41538 .44614 .39277 Mtetra
.579 .474 .699 r
.44614 .39277 .45198 .41538 .46286 .41013 .45693 .39075 Mtetra
.613 .517 .722 r
.45693 .39075 .46286 .41013 .47374 .40651 .4678 .3871 Mtetra
.639 .533 .717 r
.4678 .3871 .47374 .40651 .48465 .40453 .47873 .3818 Mtetra
.63 .506 .693 r
.47873 .3818 .48465 .40453 .4956 .40436 .4897 .37633 Mtetra
.61 .47 .666 r
.4897 .37633 .4956 .40436 .5066 .40527 .5007 .37125 Mtetra
.587 .435 .643 r
.5007 .37125 .5066 .40527 .51769 .40561 .51173 .36728 Mtetra
.576 .418 .63 r
.51173 .36728 .51769 .40561 .52884 .40429 .52281 .36381 Mtetra
.589 .423 .625 r
.52281 .36381 .52884 .40429 .54005 .39958 .53392 .3587 Mtetra
.602 .432 .623 r
.53392 .3587 .54005 .39958 .55126 .39196 .54506 .35188 Mtetra
.612 .44 .625 r
.54506 .35188 .55126 .39196 .56249 .38338 .55621 .34403 Mtetra
.616 .444 .626 r
.55621 .34403 .56249 .38338 .57371 .37436 .56738 .3358 Mtetra
.611 .442 .629 r
.56738 .3358 .57371 .37436 .58495 .36518 .57857 .32831 Mtetra
.608 .443 .634 r
.57857 .32831 .58495 .36518 .59619 .35592 .58979 .3216 Mtetra
.609 .45 .641 r
.58979 .3216 .59619 .35592 .60743 .34647 .60106 .31523 Mtetra
.609 .459 .653 r
.60106 .31523 .60743 .34647 .61869 .33723 .61236 .30943 Mtetra
.605 .468 .668 r
.61236 .30943 .61869 .33723 .62998 .32885 .62373 .30467 Mtetra
.6 .482 .69 r
.62373 .30467 .62998 .32885 .64132 .32142 .63518 .30091 Mtetra
.594 .501 .718 r
.63518 .30091 .64132 .32142 .65273 .31507 .64671 .29806 Mtetra
.586 .527 .755 r
.64671 .29806 .65273 .31507 .66421 .30977 .65833 .29599 Mtetra
.574 .561 .802 r
.65833 .29599 .66421 .30977 .67578 .30556 .67004 .29456 Mtetra
.558 .604 .855 r
.67004 .29456 .67578 .30556 .68745 .30225 .68184 .29356 Mtetra
.537 .652 .909 r
.68184 .29356 .68745 .30225 .69921 .2997 .69373 .29274 Mtetra
.513 .698 .953 r
.69373 .29274 .69921 .2997 .71107 .29769 .70568 .29194 Mtetra
.497 .736 .979 r
.70568 .29194 .71107 .29769 .723 .29597 .7177 .29092 Mtetra
.493 .763 .991 r
.7177 .29092 .723 .29597 .73502 .29438 .72978 .28962 Mtetra
.509 .784 .995 r
.72978 .28962 .73502 .29438 .7471 .29272 .7419 .2879 Mtetra
.533 .794 .993 r
.7419 .2879 .7471 .29272 .75924 .29094 .75406 .2858 Mtetra
.565 .797 .986 r
.75406 .2858 .75924 .29094 .77142 .28891 .76625 .28328 Mtetra
.59 .79 .975 r
.76625 .28328 .77142 .28891 .78366 .28668 .77848 .28044 Mtetra
.609 .776 .96 r
.77848 .28044 .78366 .28668 .79596 .28427 .79076 .27735 Mtetra
.621 .758 .944 r
.79076 .27735 .79596 .28427 .8083 .28168 .80308 .27409 Mtetra
.648 .749 .924 r
.15266 .48451 .15958 .49055 .16938 .48647 .16237 .48141 Mtetra
.649 .785 .947 r
.16237 .48141 .16938 .48647 .17923 .48222 .17213 .4782 Mtetra
.651 .825 .967 r
.17213 .4782 .17923 .48222 .18913 .47773 .18195 .47478 Mtetra
.653 .867 .98 r
.18195 .47478 .18913 .47773 .19909 .47294 .19184 .47104 Mtetra
.655 .905 .981 r
.19184 .47104 .19909 .47294 .20911 .46775 .2018 .46689 Mtetra
.653 .935 .968 r
.2018 .46689 .20911 .46775 .2192 .46218 .21183 .46225 Mtetra
.652 .955 .943 r
.21183 .46225 .2192 .46218 .22935 .45621 .22195 .45703 Mtetra
.653 .965 .915 r
.22195 .45703 .22935 .45621 .23954 .44996 .23215 .45127 Mtetra
.666 .973 .893 r
.23215 .45127 .23954 .44996 .24977 .4435 .24242 .44493 Mtetra
.69 .98 .887 r
.24242 .44493 .24977 .4435 .26002 .43704 .25275 .43812 Mtetra
.73 .985 .898 r
.25275 .43812 .26002 .43704 .27027 .43075 .26312 .43092 Mtetra
.769 .976 .917 r
.26312 .43092 .27027 .43075 .28051 .42487 .27353 .42353 Mtetra
.793 .938 .924 r
.27353 .42353 .28051 .42487 .29074 .41962 .28395 .41613 Mtetra
.79 .866 .905 r
.28395 .41613 .29074 .41962 .30093 .41511 .29437 .40887 Mtetra
.762 .776 .865 r
.29437 .40887 .30093 .41511 .3111 .41149 .30479 .40194 Mtetra
.722 .686 .815 r
.30479 .40194 .3111 .41149 .32124 .40885 .3152 .39548 Mtetra
.682 .608 .767 r
.3152 .39548 .32124 .40885 .33137 .40724 .32559 .38961 Mtetra
.649 .547 .726 r
.32559 .38961 .33137 .40724 .34152 .4062 .33597 .38426 Mtetra
.624 .503 .695 r
.33597 .38426 .34152 .4062 .3517 .4055 .34635 .37948 Mtetra
.599 .467 .672 r
.34635 .37948 .3517 .4055 .3619 .40557 .35671 .37564 Mtetra
.58 .44 .655 r
.35671 .37564 .3619 .40557 .37213 .40639 .36705 .37279 Mtetra
.577 .427 .641 r
.36705 .37279 .37213 .40639 .38244 .40685 .37746 .3698 Mtetra
.577 .419 .631 r
.37746 .3698 .38244 .40685 .39286 .4063 .38792 .36637 Mtetra
.567 .406 .623 r
.38792 .36637 .39286 .4063 .4034 .40408 .39839 .36372 Mtetra
.552 .395 .622 r
.39839 .36372 .4034 .40408 .41405 .40023 .40886 .36251 Mtetra
.525 .382 .628 r
.40886 .36251 .41405 .40023 .42472 .39687 .4193 .36379 Mtetra
.493 .372 .643 r
.4193 .36379 .42472 .39687 .43541 .39462 .42976 .36725 Mtetra
.495 .394 .67 r
.42976 .36725 .43541 .39462 .44614 .39277 .44032 .37005 Mtetra
.532 .444 .7 r
.44032 .37005 .44614 .39277 .45693 .39075 .45101 .37056 Mtetra
.611 .51 .715 r
.45101 .37056 .45693 .39075 .4678 .3871 .46187 .36687 Mtetra
.672 .546 .703 r
.46187 .36687 .4678 .3871 .47873 .3818 .47283 .35896 Mtetra
.686 .54 .682 r
.47283 .35896 .47873 .3818 .4897 .37633 .48384 .34873 Mtetra
.672 .511 .659 r
.48384 .34873 .4897 .37633 .5007 .37125 .49485 .33783 Mtetra
.633 .468 .641 r
.49485 .33783 .5007 .37125 .51173 .36728 .50585 .32909 Mtetra
.601 .435 .629 r
.50585 .32909 .51173 .36728 .52281 .36381 .51685 .32285 Mtetra
.584 .418 .622 r
.51685 .32285 .52281 .36381 .53392 .3587 .52788 .31805 Mtetra
.578 .414 .623 r
.52788 .31805 .53392 .3587 .54506 .35188 .53895 .31404 Mtetra
.585 .425 .631 r
.53895 .31404 .54506 .35188 .55621 .34403 .55005 .30959 Mtetra
.591 .437 .641 r
.55005 .30959 .55621 .34403 .56738 .3358 .5612 .30498 Mtetra
.586 .444 .655 r
.5612 .30498 .56738 .3358 .57857 .32831 .5724 .30139 Mtetra
.579 .454 .674 r
.5724 .30139 .57857 .32831 .58979 .3216 .58367 .29875 Mtetra
.577 .474 .7 r
.58367 .29875 .58979 .3216 .60106 .31523 .59501 .29668 Mtetra
.573 .503 .738 r
.59501 .29668 .60106 .31523 .61236 .30943 .60642 .29516 Mtetra
.56 .545 .795 r
.60642 .29516 .61236 .30943 .62373 .30467 .61791 .29426 Mtetra
.534 .603 .869 r
.61791 .29426 .62373 .30467 .63518 .30091 .62949 .29384 Mtetra
.475 .673 .951 r
.62949 .29384 .63518 .30091 .64671 .29806 .64116 .29375 Mtetra
.359 .72 .987 r
.64116 .29375 .64671 .29806 .65833 .29599 .65291 .29384 Mtetra
.198 .697 .914 r
.65291 .29384 .65833 .29599 .67004 .29456 .66474 .29392 Mtetra
.072 .632 .786 r
.66474 .29392 .67004 .29456 .68184 .29356 .67664 .29382 Mtetra
0 0 0 r
.67664 .29382 .68184 .29356 .69373 .29274 .6886 .29332 Mtetra
.6886 .29332 .69373 .29274 .70568 .29194 .7006 .29235 Mtetra
.115 .666 .731 r
.7006 .29235 .70568 .29194 .7177 .29092 .71265 .29079 Mtetra
.224 .746 .813 r
.71265 .29079 .7177 .29092 .72978 .28962 .72474 .28865 Mtetra
.358 .825 .904 r
.72474 .28865 .72978 .28962 .7419 .2879 .73684 .28593 Mtetra
.477 .871 .968 r
.73684 .28593 .7419 .2879 .75406 .2858 .74898 .2827 Mtetra
.567 .879 .993 r
.74898 .2827 .75406 .2858 .76625 .28328 .76114 .27902 Mtetra
.621 .859 .988 r
.76114 .27902 .76625 .28328 .77848 .28044 .77333 .27502 Mtetra
.65 .826 .968 r
.77333 .27502 .77848 .28044 .79076 .27735 .78556 .27079 Mtetra
.661 .789 .943 r
.78556 .27079 .79076 .27735 .80308 .27409 .79782 .26643 Mtetra
.597 .735 .941 r
.14569 .47843 .15266 .48451 .16237 .48141 .15531 .47635 Mtetra
.587 .77 .966 r
.15531 .47635 .16237 .48141 .17213 .4782 .16497 .47423 Mtetra
.574 .809 .988 r
.16497 .47423 .17213 .4782 .18195 .47478 .17469 .47199 Mtetra
.554 .848 .998 r
.17469 .47199 .18195 .47478 .19184 .47104 .18447 .46954 Mtetra
.519 .877 .984 r
.18447 .46954 .19184 .47104 .2018 .46689 .19432 .46678 Mtetra
.464 .882 .929 r
.19432 .46678 .2018 .46689 .21183 .46225 .20426 .46362 Mtetra
.391 .85 .826 r
.20426 .46362 .21183 .46225 .22195 .45703 .21428 .45996 Mtetra
.304 .782 .688 r
.21428 .45996 .22195 .45703 .23215 .45127 .22439 .45572 Mtetra
0 0 0 r
.22439 .45572 .23215 .45127 .24242 .44493 .23458 .45084 Mtetra
.23458 .45084 .24242 .44493 .25275 .43812 .24487 .44532 Mtetra
.24487 .44532 .25275 .43812 .26312 .43092 .25523 .43915 Mtetra
.25523 .43915 .26312 .43092 .27353 .42353 .26565 .43244 Mtetra
.26565 .43244 .27353 .42353 .28395 .41613 .27613 .4253 Mtetra
.27613 .4253 .28395 .41613 .29437 .40887 .28665 .41787 Mtetra
.28665 .41787 .29437 .40887 .30479 .40194 .29719 .41028 Mtetra
.29719 .41028 .30479 .40194 .3152 .39548 .30775 .40267 Mtetra
.30775 .40267 .3152 .39548 .32559 .38961 .31831 .39517 Mtetra
.31831 .39517 .32559 .38961 .33597 .38426 .32887 .38799 Mtetra
.463 .863 .684 r
.32887 .38799 .33597 .38426 .34635 .37948 .33942 .38126 Mtetra
.575 .941 .837 r
.33942 .38126 .34635 .37948 .35671 .37564 .34995 .37512 Mtetra
.666 .955 .948 r
.34995 .37512 .35671 .37564 .36705 .37279 .36048 .3696 Mtetra
.729 .887 .953 r
.36048 .3696 .36705 .37279 .37746 .3698 .37104 .36403 Mtetra
.728 .795 .905 r
.37104 .36403 .37746 .3698 .38792 .36637 .38163 .35845 Mtetra
.66 .711 .886 r
.38163 .35845 .38792 .36637 .39839 .36372 .39216 .3547 Mtetra
.563 .643 .887 r
.39216 .3547 .39839 .36372 .40886 .36251 .40265 .35349 Mtetra
.446 .587 .899 r
.40265 .35349 .40886 .36251 .4193 .36379 .4131 .35459 Mtetra
.351 .531 .892 r
.4131 .35459 .4193 .36379 .42976 .36725 .42358 .35728 Mtetra
.428 .552 .879 r
.42358 .35728 .42976 .36725 .44032 .37005 .43418 .35902 Mtetra
.543 .588 .85 r
.43418 .35902 .44032 .37005 .45101 .37056 .4449 .35848 Mtetra
.64 .616 .81 r
.4449 .35848 .45101 .37056 .46187 .36687 .45577 .35475 Mtetra
.708 .647 .787 r
.45577 .35475 .46187 .36687 .47283 .35896 .46673 .34783 Mtetra
.755 .682 .781 r
.46673 .34783 .47283 .35896 .48384 .34873 .47775 .33861 Mtetra
.779 .708 .785 r
.47775 .33861 .48384 .34873 .49485 .33783 .48879 .32842 Mtetra
.762 .717 .81 r
.48879 .32842 .49485 .33783 .50585 .32909 .49981 .3198 Mtetra
.718 .706 .838 r
.49981 .3198 .50585 .32909 .51685 .32285 .51084 .31351 Mtetra
.651 .679 .864 r
.51084 .31351 .51685 .32285 .52788 .31805 .52189 .30976 Mtetra
.583 .68 .907 r
.52189 .30976 .52788 .31805 .53895 .31404 .53299 .30788 Mtetra
.564 .743 .961 r
.53299 .30788 .53895 .31404 .55005 .30959 .54414 .30599 Mtetra
.497 .816 1 r
.54414 .30599 .55005 .30959 .5612 .30498 .55536 .30404 Mtetra
.243 .75 .879 r
.55536 .30404 .5612 .30498 .5724 .30139 .56665 .30273 Mtetra
.049 0 0 r
.56665 .30273 .5724 .30139 .58367 .29875 .57801 .30204 Mtetra
.229 0 0 r
.57801 .30204 .58367 .29875 .59501 .29668 .58945 .30182 Mtetra
.33 0 0 r
.58945 .30182 .59501 .29668 .60642 .29516 .60097 .30192 Mtetra
.379 0 0 r
.60097 .30192 .60642 .29516 .61791 .29426 .61257 .30215 Mtetra
.4 0 .016 r
.61257 .30215 .61791 .29426 .62949 .29384 .62426 .30238 Mtetra
.404 0 .041 r
.62426 .30238 .62949 .29384 .64116 .29375 .63601 .30246 Mtetra
.395 0 .041 r
.63601 .30246 .64116 .29375 .65291 .29384 .64784 .30225 Mtetra
.372 0 .018 r
.64784 .30225 .65291 .29384 .66474 .29392 .65973 .30159 Mtetra
.332 0 0 r
.65973 .30159 .66474 .29392 .67664 .29382 .67166 .3004 Mtetra
.267 0 0 r
.67166 .3004 .67664 .29382 .6886 .29332 .68363 .29854 Mtetra
.17 0 0 r
.68363 .29854 .6886 .29332 .7006 .29235 .69564 .29602 Mtetra
.025 0 0 r
.69564 .29602 .7006 .29235 .71265 .29079 .70767 .29283 Mtetra
0 0 0 r
.70767 .29283 .71265 .29079 .72474 .28865 .71972 .28905 Mtetra
.374 .84 .816 r
.71972 .28905 .72474 .28865 .73684 .28593 .73179 .28473 Mtetra
.538 .916 .937 r
.73179 .28473 .73684 .28593 .74898 .2827 .74388 .27999 Mtetra
.634 .919 .978 r
.74388 .27999 .74898 .2827 .76114 .27902 .75599 .27493 Mtetra
.68 .887 .974 r
.75599 .27493 .76114 .27902 .77333 .27502 .76813 .26963 Mtetra
.698 .846 .954 r
.76813 .26963 .77333 .27502 .78556 .27079 .78031 .2642 Mtetra
.701 .805 .93 r
.78031 .2642 .78556 .27079 .79782 .26643 .79252 .25872 Mtetra
.55 .72 .952 r
.13868 .4723 .14569 .47843 .15531 .47635 .14822 .47099 Mtetra
.533 .743 .972 r
.14822 .47099 .15531 .47635 .16497 .47423 .1578 .46973 Mtetra
.51 .768 .99 r
.1578 .46973 .16497 .47423 .17469 .47199 .16743 .46847 Mtetra
.477 .794 .999 r
.16743 .46847 .17469 .47199 .18447 .46954 .17712 .46715 Mtetra
.424 .811 .989 r
.17712 .46715 .18447 .46954 .19432 .46678 .18687 .46573 Mtetra
.345 .806 .934 r
.18687 .46573 .19432 .46678 .20426 .46362 .19668 .46412 Mtetra
.235 .753 .811 r
.19668 .46412 .20426 .46362 .21428 .45996 .20657 .46222 Mtetra
0 0 0 r
.20657 .46222 .21428 .45996 .22439 .45572 .21654 .45994 Mtetra
.007 0 0 r
.21654 .45994 .22439 .45572 .23458 .45084 .22661 .45716 Mtetra
.096 0 0 r
.22661 .45716 .23458 .45084 .24487 .44532 .23676 .45384 Mtetra
.155 0 0 r
.23676 .45384 .24487 .44532 .25523 .43915 .247 .44988 Mtetra
.199 0 0 r
.247 .44988 .25523 .43915 .26565 .43244 .25734 .44532 Mtetra
.227 0 .059 r
.25734 .44532 .26565 .43244 .27613 .4253 .26775 .44013 Mtetra
.249 0 .111 r
.26775 .44013 .27613 .4253 .28665 .41787 .27823 .43442 Mtetra
.265 0 .148 r
.27823 .43442 .28665 .41787 .29719 .41028 .28877 .42825 Mtetra
.275 0 .174 r
.28877 .42825 .29719 .41028 .30775 .40267 .29936 .42168 Mtetra
.282 0 .191 r
.29936 .42168 .30775 .40267 .31831 .39517 .30999 .41482 Mtetra
.293 0 .204 r
.30999 .41482 .31831 .39517 .32887 .38799 .32065 .40796 Mtetra
.304 0 .214 r
.32065 .40796 .32887 .38799 .33942 .38126 .33131 .40126 Mtetra
.305 0 .215 r
.33131 .40126 .33942 .38126 .34995 .37512 .34199 .39454 Mtetra
.296 0 .205 r
.34199 .39454 .34995 .37512 .36048 .3696 .3527 .38774 Mtetra
.276 0 .181 r
.3527 .38774 .36048 .3696 .37104 .36403 .36343 .38088 Mtetra
.263 0 .158 r
.36343 .38088 .37104 .36403 .38163 .35845 .37417 .37423 Mtetra
.309 0 .165 r
.37417 .37423 .38163 .35845 .39216 .3547 .38487 .36925 Mtetra
.365 0 .172 r
.38487 .36925 .39216 .3547 .40265 .35349 .39551 .36627 Mtetra
.366 0 .139 r
.39551 .36627 .40265 .35349 .4131 .35459 .40617 .36392 Mtetra
.303 0 .014 r
.40617 .36392 .4131 .35459 .42358 .35728 .41689 .36155 Mtetra
.026 0 0 r
.41689 .36155 .42358 .35728 .43418 .35902 .42768 .35852 Mtetra
.495 .897 .932 r
.42768 .35852 .43418 .35902 .4449 .35848 .43854 .35472 Mtetra
.634 .856 .984 r
.43854 .35472 .4449 .35848 .45577 .35475 .44944 .35097 Mtetra
.63 .855 .985 r
.44944 .35097 .45577 .35475 .46673 .34783 .46039 .34727 Mtetra
.553 .922 .938 r
.46039 .34727 .46673 .34783 .47775 .33861 .47139 .34279 Mtetra
0 0 0 r
.47139 .34279 .47775 .33861 .48879 .32842 .48244 .33765 Mtetra
.149 0 0 r
.48244 .33765 .48879 .32842 .49981 .3198 .49352 .33248 Mtetra
.283 0 .097 r
.49352 .33248 .49981 .3198 .51084 .31351 .50464 .32794 Mtetra
.384 0 .179 r
.50464 .32794 .51084 .31351 .52189 .30976 .51579 .32543 Mtetra
.442 .063 .223 r
.51579 .32543 .52189 .30976 .53299 .30788 .52699 .3246 Mtetra
.454 .081 .242 r
.52699 .3246 .53299 .30788 .54414 .30599 .53827 .324 Mtetra
.458 .094 .259 r
.53827 .324 .54414 .30599 .55536 .30404 .54961 .32334 Mtetra
.462 .106 .274 r
.54961 .32334 .55536 .30404 .56665 .30273 .56103 .32262 Mtetra
.464 .11 .28 r
.56103 .32262 .56665 .30273 .57801 .30204 .57251 .32188 Mtetra
.467 .113 .28 r
.57251 .32188 .57801 .30204 .58945 .30182 .58407 .32132 Mtetra
.466 .109 .276 r
.58407 .32132 .58945 .30182 .60097 .30192 .5957 .32077 Mtetra
.457 .097 .266 r
.5957 .32077 .60097 .30192 .61257 .30215 .6074 .31992 Mtetra
.444 .078 .248 r
.6074 .31992 .61257 .30215 .62426 .30238 .61916 .31869 Mtetra
.424 .049 .221 r
.61916 .31869 .62426 .30238 .63601 .30246 .63097 .31698 Mtetra
.395 .008 .181 r
.63097 .31698 .63601 .30246 .64784 .30225 .64283 .31473 Mtetra
.352 0 .123 r
.64283 .31473 .64784 .30225 .65973 .30159 .65473 .31185 Mtetra
.287 0 .037 r
.65473 .31185 .65973 .30159 .67166 .3004 .66666 .30834 Mtetra
.187 0 0 r
.66666 .30834 .67166 .3004 .68363 .29854 .67861 .30417 Mtetra
.037 0 0 r
.67861 .30417 .68363 .29854 .69564 .29602 .69058 .29943 Mtetra
0 0 0 r
.69058 .29943 .69564 .29602 .70767 .29283 .70257 .29418 Mtetra
.403 .848 .751 r
.70257 .29418 .70767 .29283 .71972 .28905 .71458 .28851 Mtetra
.581 .942 .903 r
.71458 .28851 .71972 .28905 .73179 .28473 .72661 .28254 Mtetra
.677 .948 .958 r
.72661 .28254 .73179 .28473 .74388 .27999 .73866 .27635 Mtetra
.716 .915 .962 r
.73866 .27635 .74388 .27999 .75599 .27493 .75074 .27005 Mtetra
.73 .875 .949 r
.75074 .27005 .75599 .27493 .76813 .26963 .76285 .26368 Mtetra
.731 .838 .931 r
.76285 .26368 .76813 .26963 .78031 .2642 .775 .2573 Mtetra
.727 .806 .913 r
.775 .2573 .78031 .2642 .79252 .25872 .78718 .25095 Mtetra
.541 .716 .954 r
.13161 .46613 .13868 .4723 .14822 .47099 .14115 .46495 Mtetra
.531 .718 .959 r
.14115 .46495 .14822 .47099 .1578 .46973 .15073 .46387 Mtetra
.521 .721 .964 r
.15073 .46387 .1578 .46973 .16743 .46847 .16034 .46288 Mtetra
.507 .727 .972 r
.16034 .46288 .16743 .46847 .17712 .46715 .17 .46198 Mtetra
.488 .736 .982 r
.17 .46198 .17712 .46715 .18687 .46573 .1797 .46118 Mtetra
.464 .751 .992 r
.1797 .46118 .18687 .46573 .19668 .46412 .18945 .46039 Mtetra
.429 .769 .997 r
.18945 .46039 .19668 .46412 .20657 .46222 .19926 .45959 Mtetra
.376 .783 .983 r
.19926 .45959 .20657 .46222 .21654 .45994 .20913 .45865 Mtetra
.295 .773 .924 r
.20913 .45865 .21654 .45994 .22661 .45716 .21907 .4575 Mtetra
.181 .716 .793 r
.21907 .4575 .22661 .45716 .23676 .45384 .2291 .45603 Mtetra
0 0 0 r
.2291 .45603 .23676 .45384 .247 .44988 .23921 .45413 Mtetra
.058 0 0 r
.23921 .45413 .247 .44988 .25734 .44532 .24942 .45176 Mtetra
.14 0 0 r
.24942 .45176 .25734 .44532 .26775 .44013 .25971 .44882 Mtetra
.198 0 0 r
.25971 .44882 .26775 .44013 .27823 .43442 .27009 .44535 Mtetra
.238 0 .014 r
.27009 .44535 .27823 .43442 .28877 .42825 .28056 .44135 Mtetra
.265 0 .082 r
.28056 .44135 .28877 .42825 .29936 .42168 .29109 .43681 Mtetra
.285 0 .132 r
.29109 .43681 .29936 .42168 .30999 .41482 .3017 .43178 Mtetra
.307 0 .172 r
.3017 .43178 .30999 .41482 .32065 .40796 .31235 .42653 Mtetra
.326 0 .203 r
.31235 .42653 .32065 .40796 .33131 .40126 .32304 .4212 Mtetra
.33 0 .221 r
.32304 .4212 .33131 .40126 .34199 .39454 .33378 .41544 Mtetra
.327 0 .23 r
.33378 .41544 .34199 .39454 .3527 .38774 .34458 .40919 Mtetra
.332 0 .238 r
.34458 .40919 .3527 .38774 .36343 .38088 .3554 .40289 Mtetra
.344 .012 .249 r
.3554 .40289 .36343 .38088 .37417 .37423 .36624 .39681 Mtetra
.369 .037 .265 r
.36624 .39681 .37417 .37423 .38487 .36925 .37707 .39146 Mtetra
.382 .047 .268 r
.37707 .39146 .38487 .36925 .39551 .36627 .38791 .38674 Mtetra
.339 0 .233 r
.38791 .38674 .39551 .36627 .40617 .36392 .39883 .3809 Mtetra
.244 0 .148 r
.39883 .3809 .40617 .36392 .41689 .36155 .40983 .37365 Mtetra
.11 0 0 r
.40983 .37365 .41689 .36155 .42768 .35852 .42085 .36627 Mtetra
0 0 0 r
.42085 .36627 .42768 .35852 .43854 .35472 .43186 .35971 Mtetra
.009 0 0 r
.43186 .35971 .43854 .35472 .44944 .35097 .44283 .35594 Mtetra
.246 0 0 r
.44283 .35594 .44944 .35097 .46039 .34727 .45378 .35497 Mtetra
.378 0 0 r
.45378 .35497 .46039 .34727 .47139 .34279 .46478 .35483 Mtetra
.43 .015 .148 r
.46478 .35483 .47139 .34279 .48244 .33765 .47585 .35457 Mtetra
.425 .055 .229 r
.47585 .35457 .48244 .33765 .49352 .33248 .48701 .35291 Mtetra
.419 .072 .267 r
.48701 .35291 .49352 .33248 .50464 .32794 .49824 .35011 Mtetra
.442 .101 .291 r
.49824 .35011 .50464 .32794 .51579 .32543 .50952 .34796 Mtetra
.457 .116 .299 r
.50952 .34796 .51579 .32543 .52699 .3246 .52086 .34656 Mtetra
.46 .115 .294 r
.52086 .34656 .52699 .3246 .53827 .324 .53226 .34538 Mtetra
.457 .11 .288 r
.53226 .34538 .53827 .324 .54961 .32334 .54373 .34416 Mtetra
.445 .096 .278 r
.54373 .34416 .54961 .32334 .56103 .32262 .55526 .34245 Mtetra
.432 .078 .264 r
.55526 .34245 .56103 .32262 .57251 .32188 .56685 .34031 Mtetra
.422 .061 .244 r
.56685 .34031 .57251 .32188 .58407 .32132 .5785 .33809 Mtetra
.405 .034 .216 r
.5785 .33809 .58407 .32132 .5957 .32077 .59021 .33565 Mtetra
.375 0 .175 r
.59021 .33565 .5957 .32077 .6074 .31992 .60197 .33271 Mtetra
.33 0 .116 r
.60197 .33271 .6074 .31992 .61916 .31869 .61377 .32922 Mtetra
.264 0 .029 r
.61377 .32922 .61916 .31869 .63097 .31698 .6256 .32518 Mtetra
.163 0 0 r
.6256 .32518 .63097 .31698 .64283 .31473 .63747 .32058 Mtetra
.007 0 0 r
.63747 .32058 .64283 .31473 .65473 .31185 .64936 .31541 Mtetra
0 0 0 r
.64936 .31541 .65473 .31185 .66666 .30834 .66127 .30973 Mtetra
.452 .876 .768 r
.66127 .30973 .66666 .30834 .67861 .30417 .6732 .3036 Mtetra
.625 .958 .909 r
.6732 .3036 .67861 .30417 .69058 .29943 .68515 .29713 Mtetra
.71 .951 .953 r
.68515 .29713 .69058 .29943 .70257 .29418 .69712 .29042 Mtetra
.742 .914 .951 r
.69712 .29042 .70257 .29418 .71458 .28851 .70911 .28356 Mtetra
.749 .875 .937 r
.70911 .28356 .71458 .28851 .72661 .28254 .72114 .27667 Mtetra
.747 .843 .923 r
.72114 .27667 .72661 .28254 .73866 .27635 .73319 .26979 Mtetra
.742 .82 .912 r
.73319 .26979 .73866 .27635 .75074 .27005 .74528 .26299 Mtetra
.737 .803 .905 r
.74528 .26299 .75074 .27005 .76285 .26368 .75741 .25628 Mtetra
.732 .792 .9 r
.75741 .25628 .76285 .26368 .775 .2573 .76958 .24965 Mtetra
.728 .784 .897 r
.76958 .24965 .775 .2573 .78718 .25095 .7818 .24311 Mtetra
.569 .726 .948 r
.12449 .45992 .13161 .46613 .14115 .46495 .1341 .45827 Mtetra
.566 .71 .938 r
.1341 .45827 .14115 .46495 .15073 .46387 .14374 .45673 Mtetra
.561 .694 .929 r
.14374 .45673 .15073 .46387 .16034 .46288 .15341 .45535 Mtetra
.554 .679 .922 r
.15341 .45535 .16034 .46288 .17 .46198 .16311 .45416 Mtetra
.543 .666 .917 r
.16311 .45416 .17 .46198 .1797 .46118 .17284 .45322 Mtetra
.532 .658 .916 r
.17284 .45322 .1797 .46118 .18945 .46039 .18259 .45247 Mtetra
.519 .655 .92 r
.18259 .45247 .18945 .46039 .19926 .45959 .19238 .45194 Mtetra
.508 .659 .928 r
.19238 .45194 .19926 .45959 .20913 .45865 .20221 .45152 Mtetra
.494 .671 .943 r
.20221 .45152 .20913 .45865 .21907 .4575 .21209 .45119 Mtetra
.479 .694 .963 r
.21209 .45119 .21907 .4575 .2291 .45603 .22203 .45081 Mtetra
.456 .727 .984 r
.22203 .45081 .2291 .45603 .23921 .45413 .23204 .45031 Mtetra
.418 .764 .996 r
.23204 .45031 .23921 .45413 .24942 .45176 .24213 .44957 Mtetra
.351 .785 .967 r
.24213 .44957 .24942 .45176 .25971 .44882 .25231 .44849 Mtetra
.235 .75 .855 r
.25231 .44849 .25971 .44882 .27009 .44535 .26257 .44705 Mtetra
0 0 0 r
.26257 .44705 .27009 .44535 .28056 .44135 .27291 .44519 Mtetra
.04 0 0 r
.27291 .44519 .28056 .44135 .29109 .43681 .28334 .44289 Mtetra
.135 0 0 r
.28334 .44289 .29109 .43681 .3017 .43178 .29386 .4401 Mtetra
.213 0 0 r
.29386 .4401 .3017 .43178 .31235 .42653 .30443 .43702 Mtetra
.267 0 .015 r
.30443 .43702 .31235 .42653 .32304 .4212 .31507 .43373 Mtetra
.287 0 .078 r
.31507 .43373 .32304 .4212 .33378 .41544 .32579 .4299 Mtetra
.297 0 .123 r
.32579 .4299 .33378 .41544 .34458 .40919 .33658 .42544 Mtetra
.325 0 .167 r
.33658 .42544 .34458 .40919 .3554 .40289 .34741 .42098 Mtetra
.352 0 .206 r
.34741 .42098 .3554 .40289 .36624 .39681 .35827 .41663 Mtetra
.356 .007 .228 r
.35827 .41663 .36624 .39681 .37707 .39146 .3692 .41182 Mtetra
.334 0 .224 r
.3692 .41182 .37707 .39146 .38791 .38674 .3802 .40603 Mtetra
.242 0 .171 r
.3802 .40603 .38791 .38674 .39883 .3809 .39134 .39775 Mtetra
.096 0 .071 r
.39134 .39775 .39883 .3809 .40983 .37365 .40258 .38715 Mtetra
0 0 0 r
.40258 .38715 .40983 .37365 .42085 .36627 .4138 .37693 Mtetra
.4138 .37693 .42085 .36627 .43186 .35971 .42496 .36873 Mtetra
.209 0 0 r
.42496 .36873 .43186 .35971 .44283 .35594 .43601 .36495 Mtetra
.429 0 .066 r
.43601 .36495 .44283 .35594 .45378 .35497 .447 .36558 Mtetra
.51 .078 .155 r
.447 .36558 .45378 .35497 .46478 .35483 .45802 .36828 Mtetra
.527 .123 .218 r
.45802 .36828 .46478 .35483 .47585 .35457 .46913 .37136 Mtetra
.481 .103 .246 r
.46913 .37136 .47585 .35457 .48701 .35291 .48036 .37215 Mtetra
.434 .075 .255 r
.48036 .37215 .48701 .35291 .49824 .35011 .4917 .37042 Mtetra
.418 .067 .26 r
.4917 .37042 .49824 .35011 .50952 .34796 .50311 .36772 Mtetra
.404 .051 .249 r
.50311 .36772 .50952 .34796 .52086 .34656 .51457 .36455 Mtetra
.395 .031 .224 r
.51457 .36455 .52086 .34656 .53226 .34538 .52609 .3615 Mtetra
.378 .002 .192 r
.52609 .3615 .53226 .34538 .54373 .34416 .53766 .35844 Mtetra
.338 0 .144 r
.53766 .35844 .54373 .34416 .55526 .34245 .54929 .35475 Mtetra
.285 0 .078 r
.54929 .35475 .55526 .34245 .56685 .34031 .56095 .3505 Mtetra
.225 0 0 r
.56095 .3505 .56685 .34031 .5785 .33809 .57267 .34603 Mtetra
.129 0 0 r
.57267 .34603 .5785 .33809 .59021 .33565 .58442 .34126 Mtetra
0 0 0 r
.58442 .34126 .59021 .33565 .60197 .33271 .5962 .336 Mtetra
.5962 .336 .60197 .33271 .61377 .32922 .60802 .33026 Mtetra
.505 .908 .815 r
.60802 .33026 .61377 .32922 .6256 .32518 .61986 .32409 Mtetra
.668 .963 .934 r
.61986 .32409 .6256 .32518 .63747 .32058 .63172 .31753 Mtetra
.74 .931 .952 r
.63172 .31753 .63747 .32058 .64936 .31541 .6436 .31061 Mtetra
.76 .877 .931 r
.6436 .31061 .64936 .31541 .66127 .30973 .6555 .30344 Mtetra
.759 .827 .905 r
.6555 .30344 .66127 .30973 .6732 .3036 .66742 .29612 Mtetra
.752 .79 .883 r
.66742 .29612 .6732 .3036 .68515 .29713 .67936 .28874 Mtetra
.744 .763 .868 r
.67936 .28874 .68515 .29713 .69712 .29042 .69134 .28143 Mtetra
.736 .745 .86 r
.69134 .28143 .69712 .29042 .70911 .28356 .70335 .27424 Mtetra
.728 .735 .856 r
.70335 .27424 .70911 .28356 .72114 .27667 .7154 .26724 Mtetra
.723 .731 .858 r
.7154 .26724 .72114 .27667 .73319 .26979 .72749 .26045 Mtetra
.717 .732 .863 r
.72749 .26045 .73319 .26979 .74528 .26299 .73964 .2539 Mtetra
.714 .738 .87 r
.73964 .2539 .74528 .26299 .75741 .25628 .75183 .24753 Mtetra
.712 .748 .88 r
.75183 .24753 .75741 .25628 .76958 .24965 .76408 .24132 Mtetra
.711 .76 .89 r
.76408 .24132 .76958 .24965 .7818 .24311 .77637 .23521 Mtetra
.624 .743 .932 r
.11732 .45366 .12449 .45992 .1341 .45827 .12707 .45097 Mtetra
.621 .71 .909 r
.12707 .45097 .1341 .45827 .14374 .45673 .13685 .44837 Mtetra
.615 .677 .886 r
.13685 .44837 .14374 .45673 .15341 .45535 .14665 .44592 Mtetra
.606 .647 .865 r
.14665 .44592 .15341 .45535 .16311 .45416 .15648 .4437 Mtetra
.594 .619 .846 r
.15648 .4437 .16311 .45416 .17284 .45322 .16631 .44175 Mtetra
.583 .595 .83 r
.16631 .44175 .17284 .45322 .18259 .45247 .17616 .4401 Mtetra
.572 .573 .816 r
.17616 .4401 .18259 .45247 .19238 .45194 .18603 .43875 Mtetra
.563 .556 .804 r
.18603 .43875 .19238 .45194 .20221 .45152 .19592 .43768 Mtetra
.555 .542 .795 r
.19592 .43768 .20221 .45152 .21209 .45119 .20584 .43685 Mtetra
.55 .532 .788 r
.20584 .43685 .21209 .45119 .22203 .45081 .2158 .43618 Mtetra
.547 .527 .785 r
.2158 .43618 .22203 .45081 .23204 .45031 .2258 .43561 Mtetra
.547 .527 .784 r
.2258 .43561 .23204 .45031 .24213 .44957 .23587 .43504 Mtetra
.55 .531 .787 r
.23587 .43504 .24213 .44957 .25231 .44849 .246 .43439 Mtetra
.552 .539 .794 r
.246 .43439 .25231 .44849 .26257 .44705 .2562 .43363 Mtetra
.556 .552 .805 r
.2562 .43363 .26257 .44705 .27291 .44519 .26646 .43274 Mtetra
.56 .572 .822 r
.26646 .43274 .27291 .44519 .28334 .44289 .2768 .43168 Mtetra
.565 .599 .846 r
.2768 .43168 .28334 .44289 .29386 .4401 .28721 .43044 Mtetra
.564 .634 .88 r
.28721 .43044 .29386 .4401 .30443 .43702 .29767 .42913 Mtetra
.555 .681 .923 r
.29767 .42913 .30443 .43702 .31507 .43373 .3082 .42778 Mtetra
.548 .745 .968 r
.3082 .42778 .31507 .43373 .32579 .4299 .31881 .42612 Mtetra
.52 .816 .999 r
.31881 .42612 .32579 .4299 .33658 .42544 .32949 .42406 Mtetra
.376 .821 .946 r
.32949 .42406 .33658 .42544 .34741 .42098 .34023 .42209 Mtetra
.141 .684 .717 r
.34023 .42209 .34741 .42098 .35827 .41663 .35101 .42016 Mtetra
0 0 0 r
.35101 .42016 .35827 .41663 .3692 .41182 .36191 .4171 Mtetra
.36191 .4171 .3692 .41182 .3802 .40603 .37294 .41221 Mtetra
.37294 .41221 .3802 .40603 .39134 .39775 .38413 .40454 Mtetra
.38413 .40454 .39134 .39775 .40258 .38715 .39544 .39446 Mtetra
.39544 .39446 .40258 .38715 .4138 .37693 .40673 .38478 Mtetra
.40673 .38478 .4138 .37693 .42496 .36873 .41796 .3771 Mtetra
.179 0 0 r
.41796 .3771 .42496 .36873 .43601 .36495 .42909 .3733 Mtetra
.393 0 .019 r
.42909 .3733 .43601 .36495 .447 .36558 .44017 .37339 Mtetra
.47 0 .047 r
.44017 .37339 .447 .36558 .45802 .36828 .45127 .3755 Mtetra
.48 0 .031 r
.45127 .3755 .45802 .36828 .46913 .37136 .46245 .37804 Mtetra
.361 0 0 r
.46245 .37804 .46913 .37136 .48036 .37215 .47376 .37817 Mtetra
.163 0 0 r
.47376 .37817 .48036 .37215 .4917 .37042 .48519 .3755 Mtetra
0 0 0 r
.48519 .3755 .4917 .37042 .50311 .36772 .49668 .371 Mtetra
.49668 .371 .50311 .36772 .51457 .36455 .50823 .36534 Mtetra
.516 .916 .853 r
.50823 .36534 .51457 .36455 .52609 .3615 .51981 .35971 Mtetra
.656 .939 .965 r
.51981 .35971 .52609 .3615 .53766 .35844 .53143 .35417 Mtetra
.722 .877 .953 r
.53143 .35417 .53766 .35844 .54929 .35475 .54308 .3482 Mtetra
.731 .803 .909 r
.54308 .3482 .54929 .35475 .56095 .3505 .55476 .34191 Mtetra
.72 .742 .869 r
.55476 .34191 .56095 .3505 .57267 .34603 .56648 .33558 Mtetra
.707 .694 .835 r
.56648 .33558 .57267 .34603 .58442 .34126 .57823 .32917 Mtetra
.699 .66 .808 r
.57823 .32917 .58442 .34126 .5962 .336 .59001 .32255 Mtetra
.693 .636 .788 r
.59001 .32255 .5962 .336 .60802 .33026 .60181 .31576 Mtetra
.688 .62 .774 r
.60181 .31576 .60802 .33026 .61986 .32409 .61364 .30881 Mtetra
.685 .609 .765 r
.61364 .30881 .61986 .32409 .63172 .31753 .62549 .30175 Mtetra
.683 .602 .759 r
.62549 .30175 .63172 .31753 .6436 .31061 .63737 .29458 Mtetra
.682 .599 .757 r
.63737 .29458 .6436 .31061 .6555 .30344 .64928 .2874 Mtetra
.68 .598 .757 r
.64928 .2874 .6555 .30344 .66742 .29612 .66122 .28031 Mtetra
.679 .601 .761 r
.66122 .28031 .66742 .29612 .67936 .28874 .67319 .27338 Mtetra
.677 .605 .768 r
.67319 .27338 .67936 .28874 .69134 .28143 .68521 .26669 Mtetra
.676 .613 .777 r
.68521 .26669 .69134 .28143 .70335 .27424 .69728 .26026 Mtetra
.675 .624 .79 r
.69728 .26026 .70335 .27424 .7154 .26724 .70941 .25415 Mtetra
.675 .638 .805 r
.70941 .25415 .7154 .26724 .72749 .26045 .72158 .24833 Mtetra
.674 .655 .823 r
.72158 .24833 .72749 .26045 .73964 .2539 .73383 .24279 Mtetra
.674 .676 .843 r
.73383 .24279 .73964 .2539 .75183 .24753 .74613 .23748 Mtetra
.676 .701 .866 r
.74613 .23748 .75183 .24753 .76408 .24132 .75849 .23232 Mtetra
.677 .729 .889 r
.75849 .23232 .76408 .24132 .77637 .23521 .7709 .22725 Mtetra
.679 .757 .91 r
.1101 .44736 .11732 .45366 .12707 .45097 .12003 .44335 Mtetra
.672 .716 .882 r
.12003 .44335 .12707 .45097 .13685 .44837 .12999 .43939 Mtetra
.661 .679 .856 r
.12999 .43939 .13685 .44837 .14665 .44592 .13997 .43555 Mtetra
.649 .645 .832 r
.13997 .43555 .14665 .44592 .15648 .4437 .14996 .43189 Mtetra
.635 .613 .81 r
.14996 .43189 .15648 .4437 .16631 .44175 .15995 .42849 Mtetra
.622 .584 .79 r
.15995 .42849 .16631 .44175 .17616 .4401 .16996 .42537 Mtetra
.608 .557 .772 r
.16996 .42537 .17616 .4401 .18603 .43875 .17997 .42258 Mtetra
.597 .534 .755 r
.17997 .42258 .18603 .43875 .19592 .43768 .18999 .42009 Mtetra
.586 .514 .741 r
.18999 .42009 .19592 .43768 .20584 .43685 .20003 .41793 Mtetra
.577 .497 .728 r
.20003 .41793 .20584 .43685 .2158 .43618 .21008 .41605 Mtetra
.569 .483 .718 r
.21008 .41605 .2158 .43618 .2258 .43561 .22016 .41441 Mtetra
.564 .472 .709 r
.22016 .41441 .2258 .43561 .23587 .43504 .23027 .41298 Mtetra
.56 .464 .703 r
.23027 .41298 .23587 .43504 .246 .43439 .24043 .41168 Mtetra
.556 .458 .699 r
.24043 .41168 .246 .43439 .2562 .43363 .25062 .41055 Mtetra
.553 .454 .696 r
.25062 .41055 .2562 .43363 .26646 .43274 .26086 .40958 Mtetra
.55 .452 .696 r
.26086 .40958 .26646 .43274 .2768 .43168 .27114 .40876 Mtetra
.547 .452 .699 r
.27114 .40876 .2768 .43168 .28721 .43044 .28147 .40808 Mtetra
.544 .454 .704 r
.28147 .40808 .28721 .43044 .29767 .42913 .29185 .40758 Mtetra
.54 .457 .711 r
.29185 .40758 .29767 .42913 .3082 .42778 .30228 .40728 Mtetra
.54 .466 .721 r
.30228 .40728 .3082 .42778 .31881 .42612 .31277 .40697 Mtetra
.542 .479 .735 r
.31277 .40697 .31881 .42612 .32949 .42406 .32333 .40656 Mtetra
.536 .492 .754 r
.32333 .40656 .32949 .42406 .34023 .42209 .33395 .40635 Mtetra
.533 .511 .778 r
.33395 .40635 .34023 .42209 .35101 .42016 .34462 .40622 Mtetra
.567 .556 .802 r
.34462 .40622 .35101 .42016 .36191 .4171 .35543 .40489 Mtetra
.621 .613 .821 r
.35543 .40489 .36191 .4171 .37294 .41221 .36639 .40175 Mtetra
.684 .674 .834 r
.36639 .40175 .37294 .41221 .38413 .40454 .37749 .39647 Mtetra
.743 .748 .856 r
.37749 .39647 .38413 .40454 .39544 .39446 .38871 .38942 Mtetra
.761 .842 .913 r
.38871 .38942 .39544 .39446 .40673 .38478 .39994 .38253 Mtetra
.701 .928 .966 r
.39994 .38253 .40673 .38478 .41796 .3771 .41115 .37678 Mtetra
.468 .887 .917 r
.41115 .37678 .41796 .3771 .42909 .3733 .42234 .37295 Mtetra
.257 .765 .855 r
.42234 .37295 .42909 .3733 .44017 .37339 .43351 .37107 Mtetra
.292 .754 .949 r
.43351 .37107 .44017 .37339 .45127 .3755 .44472 .37033 Mtetra
.438 .735 .99 r
.44472 .37033 .45127 .3755 .46245 .37804 .45599 .36976 Mtetra
.593 .698 .915 r
.45599 .36976 .46245 .37804 .47376 .37817 .46737 .36742 Mtetra
.661 .665 .843 r
.46737 .36742 .47376 .37817 .48519 .3755 .47883 .36292 Mtetra
.691 .645 .799 r
.47883 .36292 .48519 .3755 .49668 .371 .49036 .35659 Mtetra
.7 .624 .768 r
.49036 .35659 .49668 .371 .50823 .36534 .50193 .34904 Mtetra
.686 .595 .748 r
.50193 .34904 .50823 .36534 .51981 .35971 .51352 .34154 Mtetra
.672 .57 .732 r
.51352 .34154 .51981 .35971 .53143 .35417 .52513 .33424 Mtetra
.664 .551 .717 r
.52513 .33424 .53143 .35417 .54308 .3482 .53677 .32683 Mtetra
.657 .537 .706 r
.53677 .32683 .54308 .3482 .55476 .34191 .54843 .3194 Mtetra
.65 .525 .699 r
.54843 .3194 .55476 .34191 .56648 .33558 .56012 .31215 Mtetra
.643 .516 .693 r
.56012 .31215 .56648 .33558 .57823 .32917 .57183 .30508 Mtetra
.639 .51 .69 r
.57183 .30508 .57823 .32917 .59001 .32255 .58358 .29814 Mtetra
.636 .506 .688 r
.58358 .29814 .59001 .32255 .60181 .31576 .59536 .29133 Mtetra
.634 .505 .689 r
.59536 .29133 .60181 .31576 .61364 .30881 .60717 .28468 Mtetra
.633 .506 .691 r
.60717 .28468 .61364 .30881 .62549 .30175 .61902 .27819 Mtetra
.633 .51 .695 r
.61902 .27819 .62549 .30175 .63737 .29458 .6309 .27184 Mtetra
.633 .515 .701 r
.6309 .27184 .63737 .29458 .64928 .2874 .64283 .26567 Mtetra
.633 .522 .71 r
.64283 .26567 .64928 .2874 .66122 .28031 .65481 .25976 Mtetra
.633 .531 .72 r
.65481 .25976 .66122 .28031 .67319 .27338 .66683 .25413 Mtetra
.633 .541 .733 r
.66683 .25413 .67319 .27338 .68521 .26669 .67892 .24882 Mtetra
.633 .555 .748 r
.67892 .24882 .68521 .26669 .69728 .26026 .69107 .24383 Mtetra
.633 .57 .766 r
.69107 .24383 .69728 .26026 .70941 .25415 .70328 .23918 Mtetra
.633 .589 .787 r
.70328 .23918 .70941 .25415 .72158 .24833 .71556 .2348 Mtetra
.633 .611 .81 r
.71556 .2348 .72158 .24833 .73383 .24279 .72792 .23069 Mtetra
.634 .637 .836 r
.72792 .23069 .73383 .24279 .74613 .23748 .74034 .22677 Mtetra
.634 .668 .865 r
.74034 .22677 .74613 .23748 .75849 .23232 .75283 .22297 Mtetra
.634 .703 .895 r
.75283 .22297 .75849 .23232 .7709 .22725 .76539 .21923 Mtetra
.718 .764 .889 r
.10283 .44102 .1101 .44736 .12003 .44335 .11294 .43577 Mtetra
.709 .728 .865 r
.11294 .43577 .12003 .44335 .12999 .43939 .12307 .43054 Mtetra
.698 .695 .843 r
.12307 .43054 .12999 .43939 .13997 .43555 .13322 .42537 Mtetra
.686 .663 .822 r
.13322 .42537 .13997 .43555 .14996 .43189 .14338 .42031 Mtetra
.672 .633 .802 r
.14338 .42031 .14996 .43189 .15995 .42849 .15355 .41543 Mtetra
.659 .605 .783 r
.15355 .41543 .15995 .42849 .16996 .42537 .16373 .41077 Mtetra
.645 .578 .765 r
.16373 .41077 .16996 .42537 .17997 .42258 .17391 .40637 Mtetra
.631 .553 .748 r
.17391 .40637 .17997 .42258 .18999 .42009 .18409 .40226 Mtetra
.618 .531 .733 r
.18409 .40226 .18999 .42009 .20003 .41793 .19427 .39847 Mtetra
.606 .51 .719 r
.19427 .39847 .20003 .41793 .21008 .41605 .20446 .39501 Mtetra
.595 .493 .707 r
.20446 .39501 .21008 .41605 .22016 .41441 .21465 .39189 Mtetra
.586 .477 .697 r
.21465 .39189 .22016 .41441 .23027 .41298 .22486 .38909 Mtetra
.578 .465 .688 r
.22486 .38909 .23027 .41298 .24043 .41168 .23509 .3866 Mtetra
.571 .454 .681 r
.23509 .3866 .24043 .41168 .25062 .41055 .24533 .38442 Mtetra
.564 .445 .675 r
.24533 .38442 .25062 .41055 .26086 .40958 .2556 .38252 Mtetra
.56 .438 .67 r
.2556 .38252 .26086 .40958 .27114 .40876 .26591 .38081 Mtetra
.558 .433 .666 r
.26591 .38081 .27114 .40876 .28147 .40808 .27626 .37918 Mtetra
.557 .429 .661 r
.27626 .37918 .28147 .40808 .29185 .40758 .28667 .37754 Mtetra
.557 .425 .656 r
.28667 .37754 .29185 .40758 .30228 .40728 .29714 .37581 Mtetra
.559 .421 .65 r
.29714 .37581 .30228 .40728 .31277 .40697 .30768 .37387 Mtetra
.56 .417 .644 r
.30768 .37387 .31277 .40697 .32333 .40656 .31829 .37171 Mtetra
.555 .409 .638 r
.31829 .37171 .32333 .40656 .33395 .40635 .32893 .36977 Mtetra
.55 .401 .632 r
.32893 .36977 .33395 .40635 .34462 .40622 .33962 .36813 Mtetra
.554 .4 .628 r
.33962 .36813 .34462 .40622 .35543 .40489 .35038 .36609 Mtetra
.56 .404 .626 r
.35038 .36609 .35543 .40489 .36639 .40175 .36123 .3634 Mtetra
.566 .409 .627 r
.36123 .3634 .36639 .40175 .37749 .39647 .37216 .36018 Mtetra
.573 .419 .634 r
.37216 .36018 .37749 .39647 .38871 .38942 .38316 .35655 Mtetra
.577 .431 .646 r
.38316 .35655 .38871 .38942 .39994 .38253 .3942 .35295 Mtetra
.581 .445 .661 r
.3942 .35295 .39994 .38253 .41115 .37678 .40528 .34946 Mtetra
.59 .461 .672 r
.40528 .34946 .41115 .37678 .42234 .37295 .41643 .34559 Mtetra
.595 .464 .672 r
.41643 .34559 .42234 .37295 .43351 .37107 .42763 .34134 Mtetra
.589 .45 .66 r
.42763 .34134 .43351 .37107 .44472 .37033 .43887 .33719 Mtetra
.582 .435 .646 r
.43887 .33719 .44472 .37033 .45599 .36976 .45016 .33309 Mtetra
.581 .425 .634 r
.45016 .33309 .45599 .36976 .46737 .36742 .4615 .32856 Mtetra
.583 .421 .627 r
.4615 .32856 .46737 .36742 .47883 .36292 .47289 .3235 Mtetra
.589 .424 .626 r
.47289 .3235 .47883 .36292 .49036 .35659 .48433 .31777 Mtetra
.593 .428 .627 r
.48433 .31777 .49036 .35659 .50193 .34904 .49581 .31163 Mtetra
.593 .431 .632 r
.49581 .31163 .50193 .34904 .51352 .34154 .50732 .30578 Mtetra
.593 .436 .637 r
.50732 .30578 .51352 .34154 .52513 .33424 .51886 .30016 Mtetra
.599 .444 .643 r
.51886 .30016 .52513 .33424 .53677 .32683 .53044 .2943 Mtetra
.604 .452 .649 r
.53044 .2943 .53677 .32683 .54843 .3194 .54205 .28823 Mtetra
.608 .459 .654 r
.54205 .28823 .54843 .3194 .56012 .31215 .5537 .28204 Mtetra
.611 .465 .659 r
.5537 .28204 .56012 .31215 .57183 .30508 .56538 .27584 Mtetra
.612 .469 .663 r
.56538 .27584 .57183 .30508 .58358 .29814 .5771 .26972 Mtetra
.612 .472 .667 r
.5771 .26972 .58358 .29814 .59536 .29133 .58886 .26378 Mtetra
.611 .475 .672 r
.58886 .26378 .59536 .29133 .60717 .28468 .60065 .25812 Mtetra
.609 .479 .678 r
.60065 .25812 .60717 .28468 .61902 .27819 .6125 .25277 Mtetra
.608 .484 .685 r
.6125 .25277 .61902 .27819 .6309 .27184 .6244 .24773 Mtetra
.607 .491 .695 r
.6244 .24773 .6309 .27184 .64283 .26567 .63636 .24302 Mtetra
.606 .499 .706 r
.63636 .24302 .64283 .26567 .65481 .25976 .64837 .23866 Mtetra
.605 .51 .719 r
.64837 .23866 .65481 .25976 .66683 .25413 .66046 .23463 Mtetra
.604 .522 .735 r
.66046 .23463 .66683 .25413 .67892 .24882 .67261 .23093 Mtetra
.603 .537 .754 r
.67261 .23093 .67892 .24882 .69107 .24383 .68484 .22752 Mtetra
.601 .555 .774 r
.68484 .22752 .69107 .24383 .70328 .23918 .69715 .2244 Mtetra
.6 .575 .797 r
.69715 .2244 .70328 .23918 .71556 .2348 .70953 .2215 Mtetra
.598 .598 .822 r
.70953 .2215 .71556 .2348 .72792 .23069 .72199 .21878 Mtetra
.596 .623 .849 r
.72199 .21878 .72792 .23069 .74034 .22677 .73453 .21618 Mtetra
.593 .652 .877 r
.73453 .21618 .74034 .22677 .75283 .22297 .74714 .21365 Mtetra
.59 .684 .907 r
.74714 .21365 .75283 .22297 .76539 .21923 .75983 .21113 Mtetra
.741 .767 .873 r
.09551 .43462 .10283 .44102 .11294 .43577 .10575 .42846 Mtetra
.735 .741 .857 r
.10575 .42846 .11294 .43577 .12307 .43054 .11602 .42226 Mtetra
.726 .717 .841 r
.11602 .42226 .12307 .43054 .13322 .42537 .12632 .41607 Mtetra
.717 .692 .825 r
.12632 .41607 .13322 .42537 .14338 .42031 .13663 .40991 Mtetra
.707 .668 .809 r
.13663 .40991 .14338 .42031 .15355 .41543 .14695 .40382 Mtetra
.695 .643 .794 r
.14695 .40382 .15355 .41543 .16373 .41077 .15728 .39785 Mtetra
.682 .618 .778 r
.15728 .39785 .16373 .41077 .17391 .40637 .16762 .39206 Mtetra
.669 .594 .763 r
.16762 .39206 .17391 .40637 .18409 .40226 .17796 .38648 Mtetra
.655 .571 .748 r
.17796 .38648 .18409 .40226 .19427 .39847 .18829 .38118 Mtetra
.642 .549 .735 r
.18829 .38118 .19427 .39847 .20446 .39501 .19863 .37619 Mtetra
.629 .529 .722 r
.19863 .37619 .20446 .39501 .21465 .39189 .20895 .37156 Mtetra
.617 .511 .711 r
.20895 .37156 .21465 .39189 .22486 .38909 .21928 .3673 Mtetra
.606 .494 .7 r
.21928 .3673 .22486 .38909 .23509 .3866 .2296 .36341 Mtetra
.596 .48 .691 r
.2296 .36341 .23509 .3866 .24533 .38442 .23994 .35985 Mtetra
.588 .468 .683 r
.23994 .35985 .24533 .38442 .2556 .38252 .25029 .35656 Mtetra
.585 .459 .675 r
.25029 .35656 .2556 .38252 .26591 .38081 .26068 .35333 Mtetra
.583 .451 .667 r
.26068 .35333 .26591 .38081 .27626 .37918 .27112 .34997 Mtetra
.584 .446 .658 r
.27112 .34997 .27626 .37918 .28667 .37754 .28164 .34629 Mtetra
.587 .44 .649 r
.28164 .34629 .28667 .37754 .29714 .37581 .29223 .34211 Mtetra
.588 .434 .64 r
.29223 .34211 .29714 .37581 .30768 .37387 .30289 .33745 Mtetra
.587 .427 .631 r
.30289 .33745 .30768 .37387 .31829 .37171 .31361 .33241 Mtetra
.58 .415 .623 r
.31361 .33241 .31829 .37171 .32893 .36977 .32435 .32764 Mtetra
.57 .403 .615 r
.32435 .32764 .32893 .36977 .33962 .36813 .33509 .3235 Mtetra
.562 .392 .609 r
.33509 .3235 .33962 .36813 .35038 .36609 .34583 .32 Mtetra
.553 .384 .606 r
.34583 .32 .35038 .36609 .36123 .3634 .35658 .31728 Mtetra
.542 .376 .606 r
.35658 .31728 .36123 .3634 .37216 .36018 .36732 .31573 Mtetra
.533 .372 .609 r
.36732 .31573 .37216 .36018 .38316 .35655 .37807 .31517 Mtetra
.534 .379 .617 r
.37807 .31517 .38316 .35655 .3942 .35295 .38889 .31458 Mtetra
.546 .394 .626 r
.38889 .31458 .3942 .35295 .40528 .34946 .39981 .31311 Mtetra
.575 .419 .633 r
.39981 .31311 .40528 .34946 .41643 .34559 .41088 .30919 Mtetra
.6 .437 .633 r
.41088 .30919 .41643 .34559 .42763 .34134 .42208 .3028 Mtetra
.604 .435 .626 r
.42208 .3028 .42763 .34134 .43887 .33719 .43333 .29553 Mtetra
.598 .425 .618 r
.43333 .29553 .43887 .33719 .45016 .33309 .44461 .28822 Mtetra
.585 .41 .611 r
.44461 .28822 .45016 .33309 .4615 .32856 .45588 .28189 Mtetra
.573 .399 .607 r
.45588 .28189 .4615 .32856 .47289 .3235 .46717 .27673 Mtetra
.566 .394 .607 r
.46717 .27673 .47289 .3235 .48433 .31777 .47848 .27235 Mtetra
.562 .393 .61 r
.47848 .27235 .48433 .31777 .49581 .31163 .48982 .26863 Mtetra
.558 .394 .615 r
.48982 .26863 .49581 .31163 .50732 .30578 .50122 .26554 Mtetra
.558 .4 .623 r
.50122 .26554 .50732 .30578 .51886 .30016 .51266 .26272 Mtetra
.565 .411 .631 r
.51266 .26272 .51886 .30016 .53044 .2943 .52417 .25951 Mtetra
.573 .424 .64 r
.52417 .25951 .53044 .2943 .54205 .28823 .53572 .25583 Mtetra
.582 .437 .649 r
.53572 .25583 .54205 .28823 .5537 .28204 .54733 .25164 Mtetra
.59 .449 .658 r
.54733 .25164 .5537 .28204 .56538 .27584 .55898 .24711 Mtetra
.595 .459 .666 r
.55898 .24711 .56538 .27584 .5771 .26972 .57067 .24245 Mtetra
.597 .467 .674 r
.57067 .24245 .5771 .26972 .58886 .26378 .58242 .23784 Mtetra
.597 .473 .682 r
.58242 .23784 .58886 .26378 .60065 .25812 .59421 .23351 Mtetra
.595 .479 .691 r
.59421 .23351 .60065 .25812 .6125 .25277 .60606 .22951 Mtetra
.592 .486 .702 r
.60606 .22951 .6125 .25277 .6244 .24773 .61798 .22589 Mtetra
.589 .494 .714 r
.61798 .22589 .6244 .24773 .63636 .24302 .62997 .22265 Mtetra
.586 .504 .728 r
.62997 .22265 .63636 .24302 .64837 .23866 .64203 .21978 Mtetra
.583 .515 .745 r
.64203 .21978 .64837 .23866 .66046 .23463 .65417 .21724 Mtetra
.579 .529 .763 r
.65417 .21724 .66046 .23463 .67261 .23093 .66639 .21499 Mtetra
.576 .545 .783 r
.66639 .21499 .67261 .23093 .68484 .22752 .67869 .21296 Mtetra
.573 .563 .805 r
.67869 .21296 .68484 .22752 .69715 .2244 .69108 .21112 Mtetra
.569 .583 .828 r
.69108 .21112 .69715 .2244 .70953 .2215 .70354 .2094 Mtetra
.565 .604 .851 r
.70354 .2094 .70953 .2215 .72199 .21878 .71609 .20777 Mtetra
.561 .626 .874 r
.71609 .20777 .72199 .21878 .73453 .21618 .72872 .20618 Mtetra
.557 .65 .897 r
.72872 .20618 .73453 .21618 .74714 .21365 .74143 .20459 Mtetra
.552 .674 .919 r
.74143 .20459 .74714 .21365 .75983 .21113 .75422 .20298 Mtetra
.747 .767 .869 r
.08813 .42819 .09551 .43462 .10575 .42846 .09844 .42174 Mtetra
.746 .76 .864 r
.09844 .42174 .10575 .42846 .11602 .42226 .10877 .41524 Mtetra
.745 .752 .859 r
.10877 .41524 .11602 .42226 .12632 .41607 .11914 .40868 Mtetra
.742 .743 .853 r
.11914 .40868 .12632 .41607 .13663 .40991 .12952 .40209 Mtetra
.739 .733 .846 r
.12952 .40209 .13663 .40991 .14695 .40382 .13993 .39549 Mtetra
.734 .72 .838 r
.13993 .39549 .14695 .40382 .15728 .39785 .15035 .38892 Mtetra
.727 .705 .83 r
.15035 .38892 .15728 .39785 .16762 .39206 .16079 .38242 Mtetra
.718 .689 .821 r
.16079 .38242 .16762 .39206 .17796 .38648 .17123 .37605 Mtetra
.708 .671 .812 r
.17123 .37605 .17796 .38648 .18829 .38118 .18167 .36988 Mtetra
.696 .651 .801 r
.18167 .36988 .18829 .38118 .19863 .37619 .19211 .36395 Mtetra
.683 .631 .791 r
.19211 .36395 .19863 .37619 .20895 .37156 .20254 .3583 Mtetra
.671 .611 .78 r
.20254 .3583 .20895 .37156 .21928 .3673 .21298 .35293 Mtetra
.658 .591 .768 r
.21298 .35293 .21928 .3673 .2296 .36341 .22342 .34783 Mtetra
.648 .572 .755 r
.22342 .34783 .2296 .36341 .23994 .35985 .23387 .34289 Mtetra
.64 .553 .741 r
.23387 .34289 .23994 .35985 .25029 .35656 .24435 .33804 Mtetra
.635 .536 .726 r
.24435 .33804 .25029 .35656 .26068 .35333 .25488 .33309 Mtetra
.631 .521 .711 r
.25488 .33309 .26068 .35333 .27112 .34997 .26545 .32788 Mtetra
.629 .508 .696 r
.26545 .32788 .27112 .34997 .28164 .34629 .27608 .32236 Mtetra
.627 .497 .684 r
.27608 .32236 .28164 .34629 .29223 .34211 .28677 .3165 Mtetra
.623 .486 .674 r
.28677 .3165 .29223 .34211 .30289 .33745 .29749 .31052 Mtetra
.617 .476 .668 r
.29749 .31052 .30289 .33745 .31361 .33241 .30823 .30465 Mtetra
.606 .466 .664 r
.30823 .30465 .31361 .33241 .32435 .32764 .31896 .29942 Mtetra
.592 .454 .663 r
.31896 .29942 .32435 .32764 .33509 .3235 .32966 .29522 Mtetra
.575 .443 .664 r
.32966 .29522 .33509 .3235 .34583 .32 .34032 .29221 Mtetra
.555 .432 .667 r
.34032 .29221 .34583 .32 .35658 .31728 .35096 .29059 Mtetra
.525 .417 .674 r
.35096 .29059 .35658 .31728 .36732 .31573 .36156 .29079 Mtetra
.497 .408 .686 r
.36156 .29079 .36732 .31573 .37807 .31517 .37216 .29244 Mtetra
.5 .425 .703 r
.37216 .29244 .37807 .31517 .38889 .31458 .38286 .2938 Mtetra
.534 .461 .72 r
.38286 .2938 .38889 .31458 .39981 .31311 .3937 .29355 Mtetra
.611 .519 .725 r
.3937 .29355 .39981 .31311 .41088 .30919 .40476 .28959 Mtetra
.67 .553 .714 r
.40476 .28959 .41088 .30919 .42208 .3028 .41599 .2819 Mtetra
.684 .552 .699 r
.41599 .2819 .42208 .3028 .43333 .29553 .4273 .27259 Mtetra
.677 .536 .686 r
.4273 .27259 .43333 .29553 .44461 .28822 .43862 .26297 Mtetra
.65 .507 .676 r
.43862 .26297 .44461 .28822 .45588 .28189 .44991 .25478 Mtetra
.621 .48 .669 r
.44991 .25478 .45588 .28189 .46717 .27673 .46118 .24843 Mtetra
.6 .462 .665 r
.46118 .24843 .46717 .27673 .47848 .27235 .47245 .24347 Mtetra
.583 .448 .663 r
.47245 .24347 .47848 .27235 .48982 .26863 .48375 .23971 Mtetra
.569 .439 .664 r
.48375 .23971 .48982 .26863 .50122 .26554 .49509 .23698 Mtetra
.56 .435 .667 r
.49509 .23698 .50122 .26554 .51266 .26272 .50648 .23492 Mtetra
.559 .438 .671 r
.50648 .23492 .51266 .26272 .52417 .25951 .51794 .23297 Mtetra
.562 .446 .679 r
.51794 .23297 .52417 .25951 .53572 .25583 .52945 .2309 Mtetra
.57 .46 .689 r
.52945 .2309 .53572 .25583 .54733 .25164 .54104 .22849 Mtetra
.578 .476 .702 r
.54104 .22849 .54733 .25164 .55898 .24711 .55268 .22577 Mtetra
.586 .494 .717 r
.55268 .22577 .55898 .24711 .57067 .24245 .56437 .22279 Mtetra
.592 .511 .732 r
.56437 .22279 .57067 .24245 .58242 .23784 .57613 .2197 Mtetra
.594 .527 .749 r
.57613 .2197 .58242 .23784 .59421 .23351 .58795 .2167 Mtetra
.593 .541 .766 r
.58795 .2167 .59421 .23351 .60606 .22951 .59983 .21388 Mtetra
.589 .554 .783 r
.59983 .21388 .60606 .22951 .61798 .22589 .61178 .21133 Mtetra
.584 .567 .801 r
.61178 .21133 .61798 .22589 .62997 .22265 .62381 .20907 Mtetra
.576 .579 .819 r
.62381 .20907 .62997 .22265 .64203 .21978 .63591 .20711 Mtetra
.569 .592 .837 r
.63591 .20711 .64203 .21978 .65417 .21724 .6481 .20539 Mtetra
.561 .605 .854 r
.6481 .20539 .65417 .21724 .66639 .21499 .66037 .20389 Mtetra
.554 .618 .871 r
.66037 .20389 .66639 .21499 .67869 .21296 .67273 .20252 Mtetra
.548 .632 .887 r
.67273 .20252 .67869 .21296 .69108 .21112 .68516 .20124 Mtetra
.542 .645 .9 r
.68516 .20124 .69108 .21112 .70354 .2094 .69769 .2 Mtetra
.539 .657 .912 r
.69769 .2 .70354 .2094 .71609 .20777 .71029 .19875 Mtetra
.537 .668 .921 r
.71029 .19875 .71609 .20777 .72872 .20618 .72297 .19747 Mtetra
.535 .677 .929 r
.72297 .19747 .72872 .20618 .74143 .20459 .73573 .19614 Mtetra
.534 .686 .936 r
.73573 .19614 .74143 .20459 .75422 .20298 .74857 .19475 Mtetra
.739 .766 .875 r
.0807 .4217 .08813 .42819 .09844 .42174 .09099 .41556 Mtetra
.744 .776 .879 r
.09099 .41556 .09844 .42174 .10877 .41524 .10132 .40933 Mtetra
.748 .786 .884 r
.10132 .40933 .10877 .41524 .11914 .40868 .11168 .40301 Mtetra
.751 .794 .888 r
.11168 .40301 .11914 .40868 .12952 .40209 .12207 .39662 Mtetra
.755 .801 .89 r
.12207 .39662 .12952 .40209 .13993 .39549 .13249 .39013 Mtetra
.757 .806 .892 r
.13249 .39013 .13993 .39549 .15035 .38892 .14294 .38359 Mtetra
.757 .808 .893 r
.14294 .38359 .15035 .38892 .16079 .38242 .15341 .37704 Mtetra
.756 .807 .894 r
.15341 .37704 .16079 .38242 .17123 .37605 .1639 .37053 Mtetra
.752 .803 .894 r
.1639 .37053 .17123 .37605 .18167 .36988 .1744 .36411 Mtetra
.747 .796 .892 r
.1744 .36411 .18167 .36988 .19211 .36395 .18491 .35781 Mtetra
.74 .785 .889 r
.18491 .35781 .19211 .36395 .20254 .3583 .19542 .35168 Mtetra
.733 .771 .883 r
.19542 .35168 .20254 .3583 .21298 .35293 .20595 .34566 Mtetra
.726 .752 .873 r
.20595 .34566 .21298 .35293 .22342 .34783 .21649 .33973 Mtetra
.721 .73 .858 r
.21649 .33973 .22342 .34783 .23387 .34289 .22707 .33375 Mtetra
.716 .704 .838 r
.22707 .33375 .23387 .34289 .24435 .33804 .23768 .32764 Mtetra
.71 .677 .816 r
.23768 .32764 .24435 .33804 .25488 .33309 .24833 .32131 Mtetra
.705 .651 .794 r
.24833 .32131 .25488 .33309 .26545 .32788 .25904 .31471 Mtetra
.696 .627 .776 r
.25904 .31471 .26545 .32788 .27608 .32236 .26977 .30803 Mtetra
.686 .608 .762 r
.26977 .30803 .27608 .32236 .28677 .3165 .28052 .3014 Mtetra
.674 .593 .756 r
.28052 .3014 .28677 .3165 .29749 .31052 .29126 .29517 Mtetra
.66 .583 .758 r
.29126 .29517 .29749 .31052 .30823 .30465 .30198 .28961 Mtetra
.643 .578 .767 r
.30198 .28961 .30823 .30465 .31896 .29942 .31267 .28498 Mtetra
.62 .574 .781 r
.31267 .28498 .31896 .29942 .32966 .29522 .32332 .2815 Mtetra
.589 .569 .8 r
.32332 .2815 .32966 .29522 .34032 .29221 .33394 .27928 Mtetra
.545 .56 .821 r
.33394 .27928 .34032 .29221 .35096 .29059 .34453 .27846 Mtetra
.466 .534 .843 r
.34453 .27846 .35096 .29059 .36156 .29079 .35508 .27951 Mtetra
.381 .507 .86 r
.35508 .27951 .36156 .29079 .37216 .29244 .36564 .28201 Mtetra
.392 .535 .88 r
.36564 .28201 .37216 .29244 .38286 .2938 .37631 .28404 Mtetra
.486 .604 .895 r
.37631 .28404 .38286 .2938 .3937 .29355 .38714 .28418 Mtetra
.653 .69 .872 r
.38714 .28418 .3937 .29355 .40476 .28959 .39822 .28018 Mtetra
.754 .724 .825 r
.39822 .28018 .40476 .28959 .41599 .2819 .4095 .27204 Mtetra
.781 .723 .799 r
.4095 .27204 .41599 .2819 .4273 .27259 .42086 .26199 Mtetra
.78 .71 .785 r
.42086 .26199 .4273 .27259 .43862 .26297 .43224 .25145 Mtetra
.75 .684 .788 r
.43224 .25145 .43862 .26297 .44991 .25478 .44358 .24235 Mtetra
.71 .654 .792 r
.44358 .24235 .44991 .25478 .46118 .24843 .45488 .23512 Mtetra
.676 .625 .791 r
.45488 .23512 .46118 .24843 .47245 .24347 .46619 .22929 Mtetra
.643 .597 .787 r
.46619 .22929 .47245 .24347 .48375 .23971 .4775 .22473 Mtetra
.613 .57 .783 r
.4775 .22473 .48375 .23971 .49509 .23698 .48885 .22133 Mtetra
.588 .548 .778 r
.48885 .22133 .49509 .23698 .50648 .23492 .50024 .21887 Mtetra
.57 .534 .775 r
.50024 .21887 .50648 .23492 .51794 .23297 .51169 .2171 Mtetra
.559 .531 .78 r
.51169 .2171 .51794 .23297 .52945 .2309 .5232 .21575 Mtetra
.558 .54 .791 r
.5232 .21575 .52945 .2309 .54104 .22849 .53479 .21445 Mtetra
.56 .559 .809 r
.53479 .21445 .54104 .22849 .55268 .22577 .54644 .21308 Mtetra
.568 .587 .833 r
.54644 .21308 .55268 .22577 .56437 .22279 .55817 .21143 Mtetra
.573 .618 .859 r
.55817 .21143 .56437 .22279 .57613 .2197 .56996 .20957 Mtetra
.576 .649 .885 r
.56996 .20957 .57613 .2197 .58795 .2167 .58182 .20758 Mtetra
.574 .675 .908 r
.58182 .20758 .58795 .2167 .59983 .21388 .59374 .20554 Mtetra
.565 .695 .928 r
.59374 .20554 .59983 .21388 .61178 .21133 .60574 .20359 Mtetra
.553 .71 .944 r
.60574 .20359 .61178 .21133 .62381 .20907 .61781 .20177 Mtetra
.538 .718 .956 r
.61781 .20177 .62381 .20907 .63591 .20711 .62996 .20012 Mtetra
.526 .724 .964 r
.62996 .20012 .63591 .20711 .6481 .20539 .6422 .1986 Mtetra
.516 .727 .969 r
.6422 .1986 .6481 .20539 .66037 .20389 .65451 .19718 Mtetra
.51 .729 .972 r
.65451 .19718 .66037 .20389 .67273 .20252 .6669 .19581 Mtetra
.51 .73 .972 r
.6669 .19581 .67273 .20252 .68516 .20124 .67937 .19444 Mtetra
.513 .729 .971 r
.67937 .19444 .68516 .20124 .69769 .2 .69192 .19301 Mtetra
.521 .727 .967 r
.69192 .19301 .69769 .2 .71029 .19875 .70455 .1915 Mtetra
.528 .723 .962 r
.70455 .1915 .71029 .19875 .72297 .19747 .71725 .18991 Mtetra
.536 .717 .956 r
.71725 .18991 .72297 .19747 .73573 .19614 .73002 .18823 Mtetra
.544 .71 .948 r
.73002 .18823 .73573 .19614 .74857 .19475 .74288 .18646 Mtetra
.714 .763 .891 r
.07322 .41517 .0807 .4217 .09099 .41556 .08341 .40994 Mtetra
.721 .793 .908 r
.08341 .40994 .09099 .41556 .10132 .40933 .09364 .40462 Mtetra
.727 .824 .925 r
.09364 .40462 .10132 .40933 .11168 .40301 .10392 .39919 Mtetra
.732 .855 .939 r
.10392 .39919 .11168 .40301 .12207 .39662 .11423 .39366 Mtetra
.734 .886 .95 r
.11423 .39366 .12207 .39662 .13249 .39013 .12459 .38798 Mtetra
.731 .913 .956 r
.12459 .38798 .13249 .39013 .14294 .38359 .13499 .38221 Mtetra
.723 .935 .957 r
.13499 .38221 .14294 .38359 .15341 .37704 .14542 .37635 Mtetra
.709 .952 .953 r
.14542 .37635 .15341 .37704 .1639 .37053 .15588 .37044 Mtetra
.688 .961 .943 r
.15588 .37044 .1639 .37053 .1744 .36411 .16637 .36453 Mtetra
.665 .964 .929 r
.16637 .36453 .1744 .36411 .18491 .35781 .17689 .35862 Mtetra
.642 .962 .914 r
.17689 .35862 .18491 .35781 .19542 .35168 .18742 .35274 Mtetra
.628 .96 .902 r
.18742 .35274 .19542 .35168 .20595 .34566 .19799 .34682 Mtetra
.626 .96 .896 r
.19799 .34682 .20595 .34566 .21649 .33973 .20859 .34083 Mtetra
.637 .963 .898 r
.20859 .34083 .21649 .33973 .22707 .33375 .21924 .33469 Mtetra
.657 .969 .904 r
.21924 .33469 .22707 .33375 .23768 .32764 .22992 .32835 Mtetra
.674 .971 .911 r
.22992 .32835 .23768 .32764 .24833 .32131 .24064 .3219 Mtetra
.681 .972 .914 r
.24064 .3219 .24833 .32131 .25904 .31471 .25139 .31537 Mtetra
.661 .968 .91 r
.25139 .31537 .25904 .31471 .26977 .30803 .26215 .30905 Mtetra
.608 .954 .89 r
.26215 .30905 .26977 .30803 .28052 .3014 .2729 .30312 Mtetra
.51 .912 .834 r
.2729 .30312 .28052 .3014 .29126 .29517 .28364 .2977 Mtetra
.376 .832 .74 r
.28364 .2977 .29126 .29517 .30198 .28961 .29437 .29286 Mtetra
0 0 0 r
.29437 .29286 .30198 .28961 .31267 .28498 .3051 .28844 Mtetra
.3051 .28844 .31267 .28498 .32332 .2815 .31584 .28444 Mtetra
.31584 .28444 .32332 .2815 .33394 .27928 .32659 .28107 Mtetra
.32659 .28107 .33394 .27928 .34453 .27846 .33733 .27855 Mtetra
.094 .651 .755 r
.33733 .27855 .34453 .27846 .35508 .27951 .34803 .27774 Mtetra
.064 .613 .834 r
.34803 .27774 .35508 .27951 .36564 .28201 .35871 .27846 Mtetra
.221 .676 .949 r
.35871 .27846 .36564 .28201 .37631 .28404 .36947 .2791 Mtetra
.429 .742 .992 r
.36947 .2791 .37631 .28404 .38714 .28418 .38037 .27844 Mtetra
.655 .802 .953 r
.38037 .27844 .38714 .28418 .39822 .28018 .39149 .27441 Mtetra
.769 .826 .897 r
.39149 .27441 .39822 .28018 .4095 .27204 .40278 .26702 Mtetra
.805 .853 .886 r
.40278 .26702 .4095 .27204 .42086 .26199 .41414 .25831 Mtetra
.814 .898 .901 r
.41414 .25831 .42086 .26199 .43224 .25145 .42552 .2495 Mtetra
.756 .951 .94 r
.42552 .2495 .43224 .25145 .44358 .24235 .43687 .24222 Mtetra
.59 .944 .916 r
.43687 .24222 .44358 .24235 .45488 .23512 .44819 .23665 Mtetra
.385 .843 .78 r
.44819 .23665 .45488 .23512 .46619 .22929 .45954 .23194 Mtetra
0 0 0 r
.45954 .23194 .46619 .22929 .4775 .22473 .47091 .22785 Mtetra
.47091 .22785 .4775 .22473 .48885 .22133 .48233 .22419 Mtetra
.48233 .22419 .48885 .22133 .50024 .21887 .4938 .22096 Mtetra
.4938 .22096 .50024 .21887 .51169 .2171 .50531 .21833 Mtetra
.50531 .21833 .51169 .2171 .5232 .21575 .51689 .21621 Mtetra
.144 .688 .75 r
.51689 .21621 .5232 .21575 .53479 .21445 .52853 .2145 Mtetra
.157 .698 .782 r
.52853 .2145 .53479 .21445 .54644 .21308 .54024 .21299 Mtetra
.173 .709 .797 r
.54024 .21299 .54644 .21308 .55817 .21143 .55203 .21143 Mtetra
.176 .712 .792 r
.55203 .21143 .55817 .21143 .56996 .20957 .56388 .20974 Mtetra
.179 .714 .781 r
.56388 .20974 .56996 .20957 .58182 .20758 .5758 .20787 Mtetra
.181 .715 .774 r
.5758 .20787 .58182 .20758 .59374 .20554 .58779 .20584 Mtetra
.185 .718 .774 r
.58779 .20584 .59374 .20554 .60574 .20359 .59985 .20375 Mtetra
.199 .728 .788 r
.59985 .20375 .60574 .20359 .61781 .20177 .61198 .20162 Mtetra
.22 .742 .815 r
.61198 .20162 .61781 .20177 .62996 .20012 .62418 .19952 Mtetra
.255 .764 .853 r
.62418 .19952 .62996 .20012 .6422 .1986 .63645 .19742 Mtetra
.301 .788 .897 r
.63645 .19742 .6422 .1986 .65451 .19718 .64879 .19533 Mtetra
.354 .809 .939 r
.64879 .19533 .65451 .19718 .6669 .19581 .66121 .19319 Mtetra
.41 .824 .973 r
.66121 .19319 .6669 .19581 .67937 .19444 .67369 .19096 Mtetra
.463 .827 .994 r
.67369 .19096 .67937 .19444 .69192 .19301 .68625 .18863 Mtetra
.508 .819 1 r
.68625 .18863 .69192 .19301 .70455 .1915 .69887 .18617 Mtetra
.542 .801 .993 r
.69887 .18617 .70455 .1915 .71725 .18991 .71156 .18358 Mtetra
.566 .777 .978 r
.71156 .18358 .71725 .18991 .73002 .18823 .72431 .18089 Mtetra
.582 .75 .957 r
.72431 .18089 .73002 .18823 .74288 .18646 .73713 .1781 Mtetra
.671 .755 .914 r
.06568 .40859 .07322 .41517 .08341 .40994 .07572 .40462 Mtetra
.674 .798 .941 r
.07572 .40462 .08341 .40994 .09364 .40462 .0858 .40058 Mtetra
.673 .842 .964 r
.0858 .40058 .09364 .40462 .10392 .39919 .09594 .39642 Mtetra
.664 .885 .979 r
.09594 .39642 .10392 .39919 .11423 .39366 .10612 .39215 Mtetra
.642 .918 .978 r
.10612 .39215 .11423 .39366 .12459 .38798 .11636 .38771 Mtetra
.602 .935 .954 r
.11636 .38771 .12459 .38798 .13499 .38221 .12666 .38314 Mtetra
.543 .926 .902 r
.12666 .38314 .13499 .38221 .14542 .37635 .137 .37843 Mtetra
.466 .89 .823 r
.137 .37843 .14542 .37635 .15588 .37044 .14739 .3736 Mtetra
.381 .832 .729 r
.14739 .3736 .15588 .37044 .16637 .36453 .15782 .36868 Mtetra
0 0 0 r
.15782 .36868 .16637 .36453 .17689 .35862 .1683 .36365 Mtetra
.1683 .36365 .17689 .35862 .18742 .35274 .17882 .35852 Mtetra
.17882 .35852 .18742 .35274 .19799 .34682 .18938 .35323 Mtetra
.18938 .35323 .19799 .34682 .20859 .34083 .2 .34775 Mtetra
.2 .34775 .20859 .34083 .21924 .33469 .21067 .3421 Mtetra
.21067 .3421 .21924 .33469 .22992 .32835 .22137 .33631 Mtetra
.22137 .33631 .22992 .32835 .24064 .3219 .2321 .33059 Mtetra
.008 0 0 r
.2321 .33059 .24064 .3219 .25139 .31537 .24284 .32512 Mtetra
.098 0 0 r
.24284 .32512 .25139 .31537 .26215 .30905 .25356 .32013 Mtetra
.188 0 0 r
.25356 .32013 .26215 .30905 .2729 .30312 .26427 .31576 Mtetra
.248 0 .033 r
.26427 .31576 .2729 .30312 .28364 .2977 .27499 .31173 Mtetra
.282 0 .082 r
.27499 .31173 .28364 .2977 .29437 .29286 .28575 .30783 Mtetra
.278 0 .097 r
.28575 .30783 .29437 .29286 .3051 .28844 .29658 .30343 Mtetra
.248 0 .083 r
.29658 .30343 .3051 .28844 .31584 .28444 .3075 .2983 Mtetra
.209 0 .04 r
.3075 .2983 .31584 .28444 .32659 .28107 .31848 .2928 Mtetra
.155 0 0 r
.31848 .2928 .32659 .28107 .33733 .27855 .3295 .28734 Mtetra
.141 0 0 r
.3295 .28734 .33733 .27855 .34803 .27774 .34046 .28326 Mtetra
.12 0 0 r
.34046 .28326 .34803 .27774 .35871 .27846 .35138 .28081 Mtetra
0 0 0 r
.35138 .28081 .35871 .27846 .36947 .2791 .36233 .27892 Mtetra
.273 .776 .853 r
.36233 .27892 .36947 .2791 .38037 .27844 .37334 .2768 Mtetra
.564 .907 .973 r
.37334 .2768 .38037 .27844 .39149 .27441 .38451 .27275 Mtetra
.691 .945 .96 r
.38451 .27275 .39149 .27441 .40278 .26702 .3958 .26676 Mtetra
.65 .961 .925 r
.3958 .26676 .40278 .26702 .41414 .25831 .40713 .26053 Mtetra
.429 .863 .758 r
.40713 .26053 .41414 .25831 .42552 .2495 .41847 .25487 Mtetra
0 0 0 r
.41847 .25487 .42552 .2495 .43687 .24222 .4298 .25084 Mtetra
.238 0 0 r
.4298 .25084 .43687 .24222 .44819 .23665 .44114 .2482 Mtetra
.307 0 .043 r
.44114 .2482 .44819 .23665 .45954 .23194 .45253 .2456 Mtetra
.326 0 .1 r
.45253 .2456 .45954 .23194 .47091 .22785 .464 .24264 Mtetra
.316 0 .117 r
.464 .24264 .47091 .22785 .48233 .22419 .47553 .23893 Mtetra
.298 0 .108 r
.47553 .23893 .48233 .22419 .4938 .22096 .48712 .23472 Mtetra
.288 0 .085 r
.48712 .23472 .4938 .22096 .50531 .21833 .49876 .23064 Mtetra
.277 0 .047 r
.49876 .23064 .50531 .21833 .51689 .21621 .51045 .2269 Mtetra
.272 0 .002 r
.51045 .2269 .51689 .21621 .52853 .2145 .52219 .22379 Mtetra
.264 0 0 r
.52219 .22379 .52853 .2145 .54024 .21299 .53399 .22118 Mtetra
.248 0 0 r
.53399 .22118 .54024 .21299 .55203 .21143 .54586 .21882 Mtetra
.229 0 0 r
.54586 .21882 .55203 .21143 .56388 .20974 .55779 .21655 Mtetra
.2 0 0 r
.55779 .21655 .56388 .20974 .5758 .20787 .5698 .21412 Mtetra
.17 0 0 r
.5698 .21412 .5758 .20787 .58779 .20584 .58186 .21153 Mtetra
.133 0 0 r
.58186 .21153 .58779 .20584 .59985 .20375 .59399 .20875 Mtetra
.088 0 0 r
.59399 .20875 .59985 .20375 .61198 .20162 .60618 .2058 Mtetra
.034 0 0 r
.60618 .2058 .61198 .20162 .62418 .19952 .61843 .20275 Mtetra
0 0 0 r
.61843 .20275 .62418 .19952 .63645 .19742 .63074 .19958 Mtetra
.63074 .19958 .63645 .19742 .64879 .19533 .64312 .19632 Mtetra
.232 .747 .738 r
.64312 .19632 .64879 .19533 .66121 .19319 .65555 .19294 Mtetra
.347 .825 .854 r
.65555 .19294 .66121 .19319 .67369 .19096 .66805 .18941 Mtetra
.453 .872 .94 r
.66805 .18941 .67369 .19096 .68625 .18863 .6806 .18574 Mtetra
.537 .883 .985 r
.6806 .18574 .68625 .18863 .69887 .18617 .6932 .18191 Mtetra
.591 .864 .994 r
.6932 .18191 .69887 .18617 .71156 .18358 .70586 .17793 Mtetra
.623 .828 .979 r
.70586 .17793 .71156 .18358 .72431 .18089 .71857 .17385 Mtetra
.638 .787 .953 r
.71857 .17385 .72431 .18089 .73713 .1781 .73134 .16968 Mtetra
.609 .739 .937 r
.05808 .40196 .06568 .40859 .07572 .40462 .06794 .39939 Mtetra
.601 .785 .969 r
.06794 .39939 .07572 .40462 .0858 .40058 .07786 .39674 Mtetra
.583 .83 .992 r
.07786 .39674 .0858 .40058 .09594 .39642 .08783 .394 Mtetra
.55 .867 .995 r
.08783 .394 .09594 .39642 .10612 .39215 .09786 .39113 Mtetra
.494 .881 .965 r
.09786 .39113 .10612 .39215 .11636 .38771 .10796 .38811 Mtetra
.413 .86 .892 r
.10796 .38811 .11636 .38771 .12666 .38314 .11812 .38492 Mtetra
.314 .802 .78 r
.11812 .38492 .12666 .38314 .137 .37843 .12834 .38157 Mtetra
0 0 0 r
.12834 .38157 .137 .37843 .14739 .3736 .13862 .37806 Mtetra
.13862 .37806 .14739 .3736 .15782 .36868 .14897 .37439 Mtetra
.14897 .37439 .15782 .36868 .1683 .36365 .15937 .37054 Mtetra
.014 0 0 r
.15937 .37054 .1683 .36365 .17882 .35852 .16984 .3665 Mtetra
.058 0 0 r
.16984 .3665 .17882 .35852 .18938 .35323 .18036 .36227 Mtetra
.093 0 0 r
.18036 .36227 .18938 .35323 .2 .34775 .19095 .35783 Mtetra
.131 0 0 r
.19095 .35783 .2 .34775 .21067 .3421 .20158 .35331 Mtetra
.172 0 0 r
.20158 .35331 .21067 .3421 .22137 .33631 .21224 .34882 Mtetra
.228 0 .011 r
.21224 .34882 .22137 .33631 .2321 .33059 .22291 .34464 Mtetra
.287 0 .078 r
.22291 .34464 .2321 .33059 .24284 .32512 .23358 .34101 Mtetra
.339 0 .139 r
.23358 .34101 .24284 .32512 .25356 .32013 .24423 .33801 Mtetra
.38 .001 .188 r
.24423 .33801 .25356 .32013 .26427 .31576 .25487 .33564 Mtetra
.392 .025 .217 r
.25487 .33564 .26427 .31576 .27499 .31173 .26558 .33319 Mtetra
.386 .028 .23 r
.26558 .33319 .27499 .31173 .28575 .30783 .27638 .33014 Mtetra
.35 0 .221 r
.27638 .33014 .28575 .30783 .29658 .30343 .28736 .32551 Mtetra
.291 0 .192 r
.28736 .32551 .29658 .30343 .3075 .2983 .29852 .31889 Mtetra
.226 0 .146 r
.29852 .31889 .3075 .2983 .31848 .2928 .3098 .31082 Mtetra
.146 0 .076 r
.3098 .31082 .31848 .2928 .3295 .28734 .32115 .30191 Mtetra
.104 0 0 r
.32115 .30191 .3295 .28734 .34046 .28326 .33246 .29398 Mtetra
.071 0 0 r
.33246 .29398 .34046 .28326 .35138 .28081 .34368 .28775 Mtetra
0 0 0 r
.34368 .28775 .35138 .28081 .36233 .27892 .35486 .28286 Mtetra
.35486 .28286 .36233 .27892 .37334 .2768 .36603 .27898 Mtetra
.283 .774 .714 r
.36603 .27898 .37334 .2768 .38451 .27275 .37726 .2749 Mtetra
.303 .787 .722 r
.37726 .2749 .38451 .27275 .3958 .26676 .38854 .27063 Mtetra
0 0 0 r
.38854 .27063 .3958 .26676 .40713 .26053 .39983 .26738 Mtetra
.22 0 0 r
.39983 .26738 .40713 .26053 .41847 .25487 .41112 .26547 Mtetra
.389 0 .056 r
.41112 .26547 .41847 .25487 .4298 .25084 .42241 .26528 Mtetra
.451 .041 .169 r
.42241 .26528 .4298 .25084 .44114 .2482 .43376 .26609 Mtetra
.445 .06 .215 r
.43376 .26609 .44114 .2482 .45253 .2456 .44521 .26607 Mtetra
.422 .055 .234 r
.44521 .26607 .45253 .2456 .464 .24264 .45677 .2646 Mtetra
.384 .029 .234 r
.45677 .2646 .464 .24264 .47553 .23893 .46844 .2611 Mtetra
.348 0 .222 r
.46844 .2611 .47553 .23893 .48712 .23472 .48019 .25602 Mtetra
.326 0 .205 r
.48019 .25602 .48712 .23472 .49876 .23064 .49199 .2503 Mtetra
.308 0 .18 r
.49199 .2503 .49876 .23064 .51045 .2269 .50383 .24451 Mtetra
.304 0 .152 r
.50383 .24451 .51045 .2269 .52219 .22379 .5157 .23935 Mtetra
.298 0 .118 r
.5157 .23935 .52219 .22379 .53399 .22118 .52762 .23484 Mtetra
.29 0 .078 r
.52762 .23484 .53399 .22118 .54586 .21882 .5396 .23087 Mtetra
.275 0 .034 r
.5396 .23087 .54586 .21882 .55779 .21655 .55163 .22723 Mtetra
.248 0 0 r
.55163 .22723 .55779 .21655 .5698 .21412 .56372 .22362 Mtetra
.214 0 0 r
.56372 .22362 .5698 .21412 .58186 .21153 .57587 .21992 Mtetra
.17 0 0 r
.57587 .21992 .58186 .21153 .59399 .20875 .58808 .21601 Mtetra
.116 0 0 r
.58808 .21601 .59399 .20875 .60618 .2058 .60033 .21189 Mtetra
.049 0 0 r
.60033 .21189 .60618 .2058 .61843 .20275 .61264 .20758 Mtetra
0 0 0 r
.61264 .20758 .61843 .20275 .63074 .19958 .625 .20308 Mtetra
.625 .20308 .63074 .19958 .64312 .19632 .63741 .19841 Mtetra
.267 .757 .672 r
.63741 .19841 .64312 .19632 .65555 .19294 .64986 .19357 Mtetra
.401 .855 .81 r
.64986 .19357 .65555 .19294 .66805 .18941 .66236 .18855 Mtetra
.521 .914 .913 r
.66236 .18855 .66805 .18941 .6806 .18574 .6749 .18336 Mtetra
.61 .927 .968 r
.6749 .18336 .6806 .18574 .6932 .18191 .68749 .17799 Mtetra
.661 .903 .98 r
.68749 .17799 .6932 .18191 .70586 .17793 .70011 .17249 Mtetra
.686 .861 .965 r
.70011 .17249 .70586 .17793 .71857 .17385 .71279 .16687 Mtetra
.694 .813 .939 r
.71279 .16687 .71857 .17385 .73134 .16968 .7255 .16118 Mtetra
.533 .713 .955 r
.05043 .39529 .05808 .40196 .06794 .39939 .06012 .39399 Mtetra
.512 .752 .982 r
.06012 .39399 .06794 .39939 .07786 .39674 .06987 .39264 Mtetra
.48 .787 .998 r
.06987 .39264 .07786 .39674 .08783 .394 .07969 .39121 Mtetra
.433 .811 .992 r
.07969 .39121 .08783 .394 .09786 .39113 .08957 .38966 Mtetra
.367 .812 .951 r
.08957 .38966 .09786 .39113 .10796 .38811 .09952 .38796 Mtetra
.282 .781 .869 r
.09952 .38796 .10796 .38811 .11812 .38492 .10955 .3861 Mtetra
.189 .72 .754 r
.10955 .3861 .11812 .38492 .12834 .38157 .11965 .38406 Mtetra
0 0 0 r
.11965 .38406 .12834 .38157 .13862 .37806 .12982 .38184 Mtetra
.12982 .38184 .13862 .37806 .14897 .37439 .14007 .37941 Mtetra
.039 0 0 r
.14007 .37941 .14897 .37439 .15937 .37054 .15039 .37678 Mtetra
.087 0 0 r
.15039 .37678 .15937 .37054 .16984 .3665 .16078 .37391 Mtetra
.127 0 0 r
.16078 .37391 .16984 .3665 .18036 .36227 .17125 .37085 Mtetra
.162 0 0 r
.17125 .37085 .18036 .36227 .19095 .35783 .18178 .36762 Mtetra
.206 0 0 r
.18178 .36762 .19095 .35783 .20158 .35331 .19235 .36441 Mtetra
.253 0 0 r
.19235 .36441 .20158 .35331 .21224 .34882 .20295 .36139 Mtetra
.309 0 .055 r
.20295 .36139 .21224 .34882 .22291 .34464 .21354 .35888 Mtetra
.363 0 .119 r
.21354 .35888 .22291 .34464 .23358 .34101 .22412 .35711 Mtetra
.402 .007 .171 r
.22412 .35711 .23358 .34101 .24423 .33801 .2347 .35599 Mtetra
.429 .046 .21 r
.2347 .35599 .24423 .33801 .25487 .33564 .24529 .3554 Mtetra
.424 .052 .227 r
.24529 .3554 .25487 .33564 .26558 .33319 .25599 .35433 Mtetra
.399 .035 .228 r
.25599 .35433 .26558 .33319 .27638 .33014 .26685 .35199 Mtetra
.339 0 .206 r
.26685 .35199 .27638 .33014 .28736 .32551 .27796 .34726 Mtetra
.25 0 .164 r
.27796 .34726 .28736 .32551 .29852 .31889 .28933 .3396 Mtetra
.155 0 .108 r
.28933 .3396 .29852 .31889 .3098 .31082 .30087 .3297 Mtetra
.053 0 .037 r
.30087 .3297 .3098 .31082 .32115 .30191 .31252 .31831 Mtetra
.008 0 0 r
.31252 .31831 .32115 .30191 .33246 .29398 .32413 .30751 Mtetra
0 0 0 r
.32413 .30751 .33246 .29398 .34368 .28775 .33564 .29834 Mtetra
.33564 .29834 .34368 .28775 .35486 .28286 .34705 .29105 Mtetra
.022 0 0 r
.34705 .29105 .35486 .28286 .36603 .27898 .35838 .28574 Mtetra
.046 0 0 r
.35838 .28574 .36603 .27898 .37726 .2749 .36968 .28165 Mtetra
.142 0 0 r
.36968 .28165 .37726 .2749 .38854 .27063 .38098 .27877 Mtetra
.312 0 0 r
.38098 .27877 .38854 .27063 .39983 .26738 .39225 .27788 Mtetra
.43 0 .072 r
.39225 .27788 .39983 .26738 .41112 .26547 .40351 .27889 Mtetra
.495 .073 .169 r
.40351 .27889 .41112 .26547 .42241 .26528 .4148 .28157 Mtetra
.513 .114 .22 r
.4148 .28157 .42241 .26528 .43376 .26609 .42618 .28486 Mtetra
.485 .101 .237 r
.42618 .28486 .43376 .26609 .44521 .26607 .4377 .28667 Mtetra
.442 .071 .238 r
.4377 .28667 .44521 .26607 .45677 .2646 .44936 .28622 Mtetra
.38 .02 .223 r
.44936 .28622 .45677 .2646 .46844 .2611 .46117 .28282 Mtetra
.321 0 .201 r
.46117 .28282 .46844 .2611 .48019 .25602 .47308 .27699 Mtetra
.28 0 .178 r
.47308 .27699 .48019 .25602 .49199 .2503 .48504 .26987 Mtetra
.248 0 .149 r
.48504 .26987 .49199 .2503 .50383 .24451 .49704 .26224 Mtetra
.238 0 .121 r
.49704 .26224 .50383 .24451 .5157 .23935 .50906 .25513 Mtetra
.23 0 .087 r
.50906 .25513 .5157 .23935 .52762 .23484 .52111 .24869 Mtetra
.222 0 .047 r
.52111 .24869 .52762 .23484 .5396 .23087 .5332 .24299 Mtetra
.206 0 0 r
.5332 .24299 .5396 .23087 .55163 .22723 .54534 .23781 Mtetra
.175 0 0 r
.54534 .23781 .55163 .22723 .56372 .22362 .55752 .23281 Mtetra
.133 0 0 r
.55752 .23281 .56372 .22362 .57587 .21992 .56976 .22784 Mtetra
.074 0 0 r
.56976 .22784 .57587 .21992 .58808 .21601 .58204 .22268 Mtetra
.002 0 0 r
.58204 .22268 .58808 .21601 .60033 .21189 .59436 .21731 Mtetra
0 0 0 r
.59436 .21731 .60033 .21189 .61264 .20758 .60673 .2117 Mtetra
.60673 .2117 .61264 .20758 .625 .20308 .61914 .20586 Mtetra
.315 .777 .642 r
.61914 .20586 .625 .20308 .63741 .19841 .63158 .19981 Mtetra
.441 .871 .768 r
.63158 .19981 .63741 .19841 .64986 .19357 .64406 .19355 Mtetra
.555 .934 .87 r
.64406 .19355 .64986 .19357 .66236 .18855 .65657 .1871 Mtetra
.643 .956 .933 r
.65657 .1871 .66236 .18855 .6749 .18336 .66912 .18047 Mtetra
.699 .945 .959 r
.66912 .18047 .6749 .18336 .68749 .17799 .68169 .17368 Mtetra
.728 .911 .958 r
.68169 .17368 .68749 .17799 .70011 .17249 .6943 .16674 Mtetra
.738 .868 .941 r
.6943 .16674 .70011 .17249 .71279 .16687 .70694 .15971 Mtetra
.738 .824 .918 r
.70694 .15971 .71279 .16687 .7255 .16118 .71961 .15261 Mtetra
.467 .687 .962 r
.04273 .38856 .05043 .39529 .06012 .39399 .0523 .38814 Mtetra
.448 .711 .979 r
.0523 .38814 .06012 .39399 .06987 .39264 .06194 .38768 Mtetra
.424 .734 .991 r
.06194 .38768 .06987 .39264 .07969 .39121 .07164 .38714 Mtetra
.395 .753 .993 r
.07164 .38714 .07969 .39121 .08957 .38966 .08142 .38649 Mtetra
.361 .766 .983 r
.08142 .38649 .08957 .38966 .09952 .38796 .09128 .38571 Mtetra
.32 .77 .957 r
.09128 .38571 .09952 .38796 .10955 .3861 .10121 .38477 Mtetra
.272 .761 .913 r
.10121 .38477 .10955 .3861 .11965 .38406 .11122 .38366 Mtetra
.221 .739 .852 r
.11122 .38366 .11965 .38406 .12982 .38184 .12131 .38236 Mtetra
.168 .706 .779 r
.12131 .38236 .12982 .38184 .14007 .37941 .13149 .38085 Mtetra
.118 .665 .698 r
.13149 .38085 .14007 .37941 .15039 .37678 .14174 .37913 Mtetra
0 0 0 r
.14174 .37913 .15039 .37678 .16078 .37391 .15208 .37717 Mtetra
.15208 .37717 .16078 .37391 .17125 .37085 .16249 .37503 Mtetra
.021 0 0 r
.16249 .37503 .17125 .37085 .18178 .36762 .17298 .37271 Mtetra
.081 0 0 r
.17298 .37271 .18178 .36762 .19235 .36441 .18351 .37041 Mtetra
.144 0 0 r
.18351 .37041 .19235 .36441 .20295 .36139 .19408 .36828 Mtetra
.216 0 0 r
.19408 .36828 .20295 .36139 .21354 .35888 .20466 .36659 Mtetra
.285 0 0 r
.20466 .36659 .21354 .35888 .22412 .35711 .21524 .36553 Mtetra
.333 0 0 r
.21524 .36553 .22412 .35711 .2347 .35599 .22582 .365 Mtetra
.364 0 0 r
.22582 .365 .2347 .35599 .24529 .3554 .23645 .36485 Mtetra
.345 0 0 r
.23645 .36485 .24529 .3554 .25599 .35433 .24718 .36419 Mtetra
.289 0 0 r
.24718 .36419 .25599 .35433 .26685 .35199 .25808 .36234 Mtetra
.176 0 0 r
.25808 .36234 .26685 .35199 .27796 .34726 .26922 .35832 Mtetra
.033 0 0 r
.26922 .35832 .27796 .34726 .28933 .3396 .28061 .35166 Mtetra
0 0 0 r
.28061 .35166 .28933 .3396 .30087 .3297 .29217 .34295 Mtetra
.29217 .34295 .30087 .3297 .31252 .31831 .30385 .33282 Mtetra
.30385 .33282 .31252 .31831 .32413 .30751 .31551 .32301 Mtetra
.091 0 0 r
.31551 .32301 .32413 .30751 .33564 .29834 .3271 .31444 Mtetra
.181 0 .054 r
.3271 .31444 .33564 .29834 .34705 .29105 .33861 .30742 Mtetra
.258 0 .098 r
.33861 .30742 .34705 .29105 .35838 .28574 .35006 .30212 Mtetra
.304 0 .12 r
.35006 .30212 .35838 .28574 .36968 .28165 .36148 .29801 Mtetra
.346 0 .14 r
.36148 .29801 .36968 .28165 .38098 .27877 .37289 .2951 Mtetra
.399 .002 .165 r
.37289 .2951 .38098 .27877 .39225 .27788 .38428 .29391 Mtetra
.441 .04 .18 r
.38428 .29391 .39225 .27788 .40351 .27889 .39567 .2943 Mtetra
.471 .063 .184 r
.39567 .2943 .40351 .27889 .4148 .28157 .4071 .29595 Mtetra
.476 .059 .169 r
.4071 .29595 .4148 .28157 .42618 .28486 .41861 .29794 Mtetra
.429 0 .12 r
.41861 .29794 .42618 .28486 .4377 .28667 .43027 .29852 Mtetra
.345 0 .049 r
.43027 .29852 .4377 .28667 .44936 .28622 .44206 .29703 Mtetra
.206 0 0 r
.44206 .29703 .44936 .28622 .46117 .28282 .45399 .29288 Mtetra
.061 0 0 r
.45399 .29288 .46117 .28282 .47308 .27699 .46601 .28652 Mtetra
0 0 0 r
.46601 .28652 .47308 .27699 .48504 .26987 .47808 .27894 Mtetra
.47808 .27894 .48504 .26987 .49704 .26224 .49019 .27082 Mtetra
.49019 .27082 .49704 .26224 .50906 .25513 .50232 .26308 Mtetra
.50232 .26308 .50906 .25513 .52111 .24869 .51448 .25587 Mtetra
.51448 .25587 .52111 .24869 .5332 .24299 .52667 .24929 Mtetra
.52667 .24929 .5332 .24299 .54534 .23781 .53889 .24315 Mtetra
.53889 .24315 .54534 .23781 .55752 .23281 .55116 .23717 Mtetra
.55116 .23717 .55752 .23281 .56976 .22784 .56347 .2312 Mtetra
.56347 .2312 .56976 .22784 .58204 .22268 .57582 .22506 Mtetra
.389 .831 .703 r
.57582 .22506 .58204 .22268 .59436 .21731 .58821 .2187 Mtetra
.482 .894 .787 r
.58821 .2187 .59436 .21731 .60673 .2117 .60063 .21209 Mtetra
.566 .938 .855 r
.60063 .21209 .60673 .2117 .61914 .20586 .61308 .20525 Mtetra
.635 .961 .904 r
.61308 .20525 .61914 .20586 .63158 .19981 .62557 .19819 Mtetra
.687 .966 .934 r
.62557 .19819 .63158 .19981 .64406 .19355 .63808 .19091 Mtetra
.724 .956 .947 r
.63808 .19091 .64406 .19355 .65657 .1871 .65061 .18345 Mtetra
.747 .934 .948 r
.65061 .18345 .65657 .1871 .66912 .18047 .66318 .1758 Mtetra
.761 .907 .941 r
.66318 .1758 .66912 .18047 .68169 .17368 .67577 .168 Mtetra
.766 .878 .928 r
.67577 .168 .68169 .17368 .6943 .16674 .68838 .16008 Mtetra
.765 .847 .913 r
.68838 .16008 .6943 .16674 .70694 .15971 .70101 .15205 Mtetra
.761 .818 .897 r
.70101 .15205 .70694 .15971 .71961 .15261 .71368 .14397 Mtetra
.43 .671 .963 r
.03496 .38178 .04273 .38856 .0523 .38814 .04448 .38179 Mtetra
.421 .683 .972 r
.04448 .38179 .0523 .38814 .06194 .38768 .05407 .38176 Mtetra
.414 .696 .979 r
.05407 .38176 .06194 .38768 .07164 .38714 .06372 .38164 Mtetra
.407 .709 .985 r
.06372 .38164 .07164 .38714 .08142 .38649 .07345 .38143 Mtetra
.402 .723 .989 r
.07345 .38143 .08142 .38649 .09128 .38571 .08326 .38109 Mtetra
.397 .737 .992 r
.08326 .38109 .09128 .38571 .10121 .38477 .09315 .38061 Mtetra
.391 .751 .993 r
.09315 .38061 .10121 .38477 .11122 .38366 .10313 .37998 Mtetra
.385 .765 .991 r
.10313 .37998 .11122 .38366 .12131 .38236 .11318 .37916 Mtetra
.379 .777 .986 r
.11318 .37916 .12131 .38236 .13149 .38085 .12332 .37816 Mtetra
.37 .787 .977 r
.12332 .37816 .13149 .38085 .14174 .37913 .13354 .37697 Mtetra
.36 .796 .964 r
.13354 .37697 .14174 .37913 .15208 .37717 .14384 .37557 Mtetra
.342 .798 .944 r
.14384 .37557 .15208 .37717 .16249 .37503 .15422 .37398 Mtetra
.319 .794 .917 r
.15422 .37398 .16249 .37503 .17298 .37271 .16468 .37224 Mtetra
.276 .775 .877 r
.16468 .37224 .17298 .37271 .18351 .37041 .17519 .37046 Mtetra
.223 .744 .828 r
.17519 .37046 .18351 .37041 .19408 .36828 .18576 .36875 Mtetra
.153 .696 .771 r
.18576 .36875 .19408 .36828 .20466 .36659 .19636 .36729 Mtetra
.084 .643 .719 r
.19636 .36729 .20466 .36659 .21524 .36553 .20698 .36621 Mtetra
0 0 0 r
.20698 .36621 .21524 .36553 .22582 .365 .21763 .36544 Mtetra
.21763 .36544 .22582 .365 .23645 .36485 .22833 .3649 Mtetra
.112 .665 .77 r
.22833 .3649 .23645 .36485 .24718 .36419 .23913 .36398 Mtetra
.235 .751 .843 r
.23913 .36398 .24718 .36419 .25808 .36234 .25007 .36224 Mtetra
.394 .849 .896 r
.25007 .36224 .25808 .36234 .26922 .35832 .26119 .35903 Mtetra
.512 .913 .887 r
.26119 .35903 .26922 .35832 .28061 .35166 .2725 .35404 Mtetra
.518 .913 .803 r
.2725 .35404 .28061 .35166 .29217 .34295 .28396 .34765 Mtetra
.425 .834 .644 r
.28396 .34765 .29217 .34295 .30385 .33282 .29552 .34027 Mtetra
0 0 0 r
.29552 .34027 .30385 .33282 .31551 .32301 .3071 .33301 Mtetra
.003 0 0 r
.3071 .33301 .31551 .32301 .3271 .31444 .31866 .32647 Mtetra
.137 0 0 r
.31866 .32647 .3271 .31444 .33861 .30742 .33019 .3208 Mtetra
.223 0 .017 r
.33019 .3208 .33861 .30742 .35006 .30212 .34171 .31608 Mtetra
.262 0 .05 r
.34171 .31608 .35006 .30212 .36148 .29801 .35323 .31196 Mtetra
.288 0 .063 r
.35323 .31196 .36148 .29801 .37289 .2951 .36478 .30843 Mtetra
.317 0 .065 r
.36478 .30843 .37289 .2951 .38428 .29391 .37633 .30586 Mtetra
.334 0 .043 r
.37633 .30586 .38428 .29391 .39567 .2943 .38791 .30418 Mtetra
.333 0 0 r
.38791 .30418 .39567 .2943 .4071 .29595 .39953 .30322 Mtetra
.286 0 0 r
.39953 .30322 .4071 .29595 .41861 .29794 .41121 .3024 Mtetra
.114 0 0 r
.41121 .3024 .41861 .29794 .43027 .29852 .42301 .30059 Mtetra
0 0 0 r
.42301 .30059 .43027 .29852 .44206 .29703 .43491 .29736 Mtetra
.482 .899 .877 r
.43491 .29736 .44206 .29703 .45399 .29288 .44693 .29233 Mtetra
.64 .958 .925 r
.44693 .29233 .45399 .29288 .46601 .28652 .45902 .2858 Mtetra
.693 .972 .923 r
.45902 .2858 .46601 .28652 .47808 .27894 .47116 .27843 Mtetra
.702 .977 .913 r
.47116 .27843 .47808 .27894 .49019 .27082 .48334 .27066 Mtetra
.673 .973 .901 r
.48334 .27066 .49019 .27082 .50232 .26308 .49554 .26311 Mtetra
.643 .966 .894 r
.49554 .26311 .50232 .26308 .51448 .25587 .50777 .25586 Mtetra
.618 .957 .894 r
.50777 .25586 .51448 .25587 .52667 .24929 .52002 .24899 Mtetra
.614 .954 .905 r
.52002 .24899 .52667 .24929 .53889 .24315 .53232 .24236 Mtetra
.631 .956 .923 r
.53232 .24236 .53889 .24315 .55116 .23717 .54465 .2358 Mtetra
.656 .957 .94 r
.54465 .2358 .55116 .23717 .56347 .2312 .55702 .22919 Mtetra
.686 .955 .951 r
.55702 .22919 .56347 .2312 .57582 .22506 .56943 .2224 Mtetra
.71 .947 .956 r
.56943 .2224 .57582 .22506 .58821 .2187 .58187 .21542 Mtetra
.73 .936 .955 r
.58187 .21542 .58821 .2187 .60063 .21209 .59434 .20821 Mtetra
.745 .923 .95 r
.59434 .20821 .60063 .21209 .61308 .20525 .60684 .20078 Mtetra
.756 .908 .943 r
.60684 .20078 .61308 .20525 .62557 .19819 .61937 .19315 Mtetra
.763 .893 .935 r
.61937 .19315 .62557 .19819 .63808 .19091 .63192 .18532 Mtetra
.768 .878 .926 r
.63192 .18532 .63808 .19091 .65061 .18345 .64449 .17731 Mtetra
.771 .863 .917 r
.64449 .17731 .65061 .18345 .66318 .1758 .65709 .16914 Mtetra
.773 .848 .908 r
.65709 .16914 .66318 .1758 .67577 .168 .66971 .16082 Mtetra
.773 .834 .899 r
.66971 .16082 .67577 .168 .68838 .16008 .68235 .15239 Mtetra
.772 .82 .891 r
.68235 .15239 .68838 .16008 .70101 .15205 .69501 .14386 Mtetra
.77 .806 .882 r
.69501 .14386 .70101 .15205 .71368 .14397 .70769 .13525 Mtetra
.437 .674 .963 r
.02714 .37496 .03496 .38178 .04448 .38179 .03668 .37486 Mtetra
.445 .675 .961 r
.03668 .37486 .04448 .38179 .05407 .38176 .04629 .3747 Mtetra
.454 .675 .959 r
.04629 .3747 .05407 .38176 .06372 .38164 .05598 .37445 Mtetra
.464 .676 .956 r
.05598 .37445 .06372 .38164 .07345 .38143 .06574 .3741 Mtetra
.475 .677 .953 r
.06574 .3741 .07345 .38143 .08326 .38109 .07557 .37364 Mtetra
.485 .678 .95 r
.07557 .37364 .08326 .38109 .09315 .38061 .08549 .37305 Mtetra
.496 .679 .948 r
.08549 .37305 .09315 .38061 .10313 .37998 .09548 .37233 Mtetra
.506 .682 .945 r
.09548 .37233 .10313 .37998 .11318 .37916 .10555 .37146 Mtetra
.516 .685 .943 r
.10555 .37146 .11318 .37916 .12332 .37816 .1157 .37043 Mtetra
.525 .689 .942 r
.1157 .37043 .12332 .37816 .13354 .37697 .12593 .36925 Mtetra
.534 .693 .941 r
.12593 .36925 .13354 .37697 .14384 .37557 .13624 .3679 Mtetra
.542 .699 .942 r
.13624 .3679 .14384 .37557 .15422 .37398 .14663 .36639 Mtetra
.549 .705 .943 r
.14663 .36639 .15422 .37398 .16468 .37224 .15709 .36474 Mtetra
.552 .71 .945 r
.15709 .36474 .16468 .37224 .17519 .37046 .16761 .36301 Mtetra
.553 .713 .946 r
.16761 .36301 .17519 .37046 .18576 .36875 .1782 .36122 Mtetra
.551 .711 .946 r
.1782 .36122 .18576 .36875 .19636 .36729 .18885 .35948 Mtetra
.548 .701 .941 r
.18885 .35948 .19636 .36729 .20698 .36621 .19954 .35782 Mtetra
.548 .684 .929 r
.19954 .35782 .20698 .36621 .21763 .36544 .21029 .35625 Mtetra
.55 .663 .911 r
.21029 .35625 .21763 .36544 .22833 .3649 .22109 .35471 Mtetra
.562 .643 .888 r
.22109 .35471 .22833 .3649 .23913 .36398 .23197 .35298 Mtetra
.579 .632 .868 r
.23197 .35298 .23913 .36398 .25007 .36224 .24295 .35087 Mtetra
.602 .635 .856 r
.24295 .35087 .25007 .36224 .26119 .35903 .25404 .34808 Mtetra
.629 .656 .858 r
.25404 .34808 .26119 .35903 .2725 .35404 .26526 .34449 Mtetra
.653 .699 .88 r
.26526 .34449 .2725 .35404 .28396 .34765 .27657 .34026 Mtetra
.675 .765 .919 r
.27657 .34026 .28396 .34765 .29552 .34027 .28797 .33555 Mtetra
.669 .85 .969 r
.28797 .33555 .29552 .34027 .3071 .33301 .29941 .33084 Mtetra
.605 .91 .981 r
.29941 .33084 .3071 .33301 .31866 .32647 .31088 .32633 Mtetra
.486 .897 .913 r
.31088 .32633 .31866 .32647 .33019 .3208 .32239 .32203 Mtetra
.366 .835 .811 r
.32239 .32203 .33019 .3208 .34171 .31608 .33393 .31791 Mtetra
.317 .801 .758 r
.33393 .31791 .34171 .31608 .35323 .31196 .34552 .31376 Mtetra
.318 .802 .758 r
.34552 .31376 .35323 .31196 .36478 .30843 .35716 .30958 Mtetra
.347 .824 .805 r
.35716 .30958 .36478 .30843 .37633 .30586 .36884 .30559 Mtetra
.429 .868 .901 r
.36884 .30559 .37633 .30586 .38791 .30418 .38057 .30181 Mtetra
.528 .881 .983 r
.38057 .30181 .38791 .30418 .39953 .30322 .39234 .29823 Mtetra
.603 .831 .987 r
.39234 .29823 .39953 .30322 .41121 .3024 .40417 .29464 Mtetra
.644 .756 .93 r
.40417 .29464 .41121 .3024 .42301 .30059 .41607 .29058 Mtetra
.66 .702 .877 r
.41607 .29058 .42301 .30059 .43491 .29736 .42804 .28586 Mtetra
.675 .676 .843 r
.42804 .28586 .43491 .29736 .44693 .29233 .44009 .28033 Mtetra
.688 .672 .829 r
.44009 .28033 .44693 .29233 .45902 .2858 .4522 .27411 Mtetra
.699 .683 .831 r
.4522 .27411 .45902 .2858 .47116 .27843 .46435 .26749 Mtetra
.709 .703 .842 r
.46435 .26749 .47116 .27843 .48334 .27066 .47654 .26066 Mtetra
.715 .727 .859 r
.47654 .26066 .48334 .27066 .49554 .26311 .48877 .25386 Mtetra
.718 .747 .875 r
.48877 .25386 .49554 .26311 .50777 .25586 .50103 .24713 Mtetra
.719 .761 .886 r
.50103 .24713 .50777 .25586 .52002 .24899 .51332 .24049 Mtetra
.72 .769 .891 r
.51332 .24049 .52002 .24899 .53232 .24236 .52566 .23387 Mtetra
.721 .77 .892 r
.52566 .23387 .53232 .24236 .54465 .2358 .53803 .2272 Mtetra
.723 .769 .89 r
.53803 .2272 .54465 .2358 .55702 .22919 .55044 .22042 Mtetra
.726 .767 .885 r
.55044 .22042 .55702 .22919 .56943 .2224 .56289 .21349 Mtetra
.729 .765 .882 r
.56289 .21349 .56943 .2224 .58187 .21542 .57536 .20638 Mtetra
.732 .764 .878 r
.57536 .20638 .58187 .21542 .59434 .20821 .58788 .19909 Mtetra
.736 .764 .875 r
.58788 .19909 .59434 .20821 .60684 .20078 .60042 .19162 Mtetra
.74 .765 .873 r
.60042 .19162 .60684 .20078 .61937 .19315 .61298 .18398 Mtetra
.743 .767 .872 r
.61298 .18398 .61937 .19315 .63192 .18532 .62558 .17617 Mtetra
.747 .77 .872 r
.62558 .17617 .63192 .18532 .64449 .17731 .6382 .16821 Mtetra
.751 .773 .872 r
.6382 .16821 .64449 .17731 .65709 .16914 .65085 .1601 Mtetra
.754 .777 .872 r
.65085 .1601 .65709 .16914 .66971 .16082 .66351 .15185 Mtetra
.758 .781 .873 r
.66351 .15185 .66971 .16082 .68235 .15239 .67621 .14349 Mtetra
.76 .785 .873 r
.67621 .14349 .68235 .15239 .69501 .14386 .68892 .13502 Mtetra
.763 .789 .874 r
.68892 .13502 .69501 .14386 .70769 .13525 .70165 .12647 Mtetra
.494 .698 .96 r
.01926 .36808 .02714 .37496 .03668 .37486 .02893 .36725 Mtetra
.512 .682 .943 r
.02893 .36725 .03668 .37486 .04629 .3747 .03866 .36631 Mtetra
.526 .664 .924 r
.03866 .36631 .04629 .3747 .05598 .37445 .04847 .36526 Mtetra
.538 .647 .905 r
.04847 .36526 .05598 .37445 .06574 .3741 .05835 .36411 Mtetra
.546 .63 .886 r
.05835 .36411 .06574 .3741 .07557 .37364 .0683 .36284 Mtetra
.553 .614 .868 r
.0683 .36284 .07557 .37364 .08549 .37305 .07832 .36147 Mtetra
.559 .6 .851 r
.07832 .36147 .08549 .37305 .09548 .37233 .08841 .35999 Mtetra
.563 .588 .836 r
.08841 .35999 .09548 .37233 .10555 .37146 .09858 .3584 Mtetra
.566 .576 .823 r
.09858 .3584 .10555 .37146 .1157 .37043 .10881 .3567 Mtetra
.569 .567 .811 r
.10881 .3567 .1157 .37043 .12593 .36925 .11911 .35488 Mtetra
.572 .559 .801 r
.11911 .35488 .12593 .36925 .13624 .3679 .12948 .35296 Mtetra
.574 .552 .792 r
.12948 .35296 .13624 .3679 .14663 .36639 .13993 .35091 Mtetra
.576 .546 .784 r
.13993 .35091 .14663 .36639 .15709 .36474 .15043 .34876 Mtetra
.578 .541 .777 r
.15043 .34876 .15709 .36474 .16761 .36301 .16101 .34649 Mtetra
.579 .536 .77 r
.16101 .34649 .16761 .36301 .1782 .36122 .17165 .3441 Mtetra
.581 .53 .763 r
.17165 .3441 .1782 .36122 .18885 .35948 .18237 .3416 Mtetra
.582 .522 .754 r
.18237 .3416 .18885 .35948 .19954 .35782 .19314 .33898 Mtetra
.582 .513 .743 r
.19314 .33898 .19954 .35782 .21029 .35625 .20398 .33624 Mtetra
.581 .502 .731 r
.20398 .33624 .21029 .35625 .22109 .35471 .21489 .33339 Mtetra
.58 .491 .719 r
.21489 .33339 .22109 .35471 .23197 .35298 .22586 .33041 Mtetra
.579 .482 .708 r
.22586 .33041 .23197 .35298 .24295 .35087 .2369 .32732 Mtetra
.579 .475 .701 r
.2369 .32732 .24295 .35087 .25404 .34808 .248 .32411 Mtetra
.58 .474 .698 r
.248 .32411 .25404 .34808 .26526 .34449 .25916 .32077 Mtetra
.582 .477 .7 r
.25916 .32077 .26526 .34449 .27657 .34026 .27038 .31732 Mtetra
.586 .485 .706 r
.27038 .31732 .27657 .34026 .28797 .33555 .28167 .31374 Mtetra
.591 .497 .716 r
.28167 .31374 .28797 .33555 .29941 .33084 .29301 .31004 Mtetra
.597 .508 .725 r
.29301 .31004 .29941 .33084 .31088 .32633 .30441 .30622 Mtetra
.601 .517 .732 r
.30441 .30622 .31088 .32633 .32239 .32203 .31588 .30228 Mtetra
.605 .523 .735 r
.31588 .30228 .32239 .32203 .33393 .31791 .3274 .29821 Mtetra
.607 .525 .736 r
.3274 .29821 .33393 .31791 .34552 .31376 .33898 .29402 Mtetra
.609 .526 .736 r
.33898 .29402 .34552 .31376 .35716 .30958 .35061 .2897 Mtetra
.611 .526 .735 r
.35061 .2897 .35716 .30958 .36884 .30559 .36231 .28526 Mtetra
.611 .523 .73 r
.36231 .28526 .36884 .30559 .38057 .30181 .37405 .28069 Mtetra
.61 .516 .723 r
.37405 .28069 .38057 .30181 .39234 .29823 .38585 .276 Mtetra
.608 .507 .714 r
.38585 .276 .39234 .29823 .40417 .29464 .39771 .27119 Mtetra
.606 .497 .704 r
.39771 .27119 .40417 .29464 .41607 .29058 .40961 .26625 Mtetra
.605 .491 .698 r
.40961 .26625 .41607 .29058 .42804 .28586 .42157 .26118 Mtetra
.606 .49 .695 r
.42157 .26118 .42804 .28586 .44009 .28033 .43358 .25598 Mtetra
.608 .494 .698 r
.43358 .25598 .44009 .28033 .4522 .27411 .44563 .25066 Mtetra
.613 .503 .704 r
.44563 .25066 .4522 .27411 .46435 .26749 .45774 .24521 Mtetra
.62 .515 .714 r
.45774 .24521 .46435 .26749 .47654 .26066 .46989 .23964 Mtetra
.627 .529 .725 r
.46989 .23964 .47654 .26066 .48877 .25386 .48209 .23394 Mtetra
.633 .543 .735 r
.48209 .23394 .48877 .25386 .50103 .24713 .49434 .22811 Mtetra
.64 .555 .744 r
.49434 .22811 .50103 .24713 .51332 .24049 .50663 .22216 Mtetra
.645 .566 .751 r
.50663 .22216 .51332 .24049 .52566 .23387 .51896 .21607 Mtetra
.65 .574 .756 r
.51896 .21607 .52566 .23387 .53803 .2272 .53134 .20986 Mtetra
.655 .582 .762 r
.53134 .20986 .53803 .2272 .55044 .22042 .54375 .20353 Mtetra
.66 .59 .767 r
.54375 .20353 .55044 .22042 .56289 .21349 .55621 .19706 Mtetra
.665 .599 .772 r
.55621 .19706 .56289 .21349 .57536 .20638 .56871 .19047 Mtetra
.67 .609 .778 r
.56871 .19047 .57536 .20638 .58788 .19909 .58124 .18375 Mtetra
.676 .62 .786 r
.58124 .18375 .58788 .19909 .60042 .19162 .59381 .17691 Mtetra
.682 .633 .794 r
.59381 .17691 .60042 .19162 .61298 .18398 .60642 .16994 Mtetra
.69 .647 .803 r
.60642 .16994 .61298 .18398 .62558 .17617 .61906 .16284 Mtetra
.697 .663 .813 r
.61906 .16284 .62558 .17617 .6382 .16821 .63174 .15562 Mtetra
.705 .681 .824 r
.63174 .15562 .6382 .16821 .65085 .1601 .64444 .14826 Mtetra
.714 .7 .835 r
.64444 .14826 .65085 .1601 .66351 .15185 .65718 .14079 Mtetra
.723 .72 .848 r
.65718 .14079 .66351 .15185 .67621 .14349 .66995 .13319 Mtetra
.731 .742 .86 r
.66995 .13319 .67621 .14349 .68892 .13502 .68274 .12546 Mtetra
.74 .764 .872 r
.68274 .12546 .68892 .13502 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Sooooo`03okg3gol0003ooooo01Gooooo00?o
0000ooooooooool0DOooool0063ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`0Mooooo`?o00000_ooool00ol0003oooooooooo`1Oooooo`?o_L?O00?o
0000okg3goooool05Oooool00ol0003oooooooooo`1@ooooo`00H?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol0000Looooo`;o0000IOooool00onk_Mco_L?Ookg3g`02okg3g`03o`000?o3
bMoooooo01Cooooo00?o0000ooooool00000DOooool0063ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0001[ooooo0ol0001Vooooo`?o^kgL0onm`ml00ol0003o`lWO
ol?9g`0Fooooo`03o`000?oooooooooo04oooooo001Pooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool0000Hooooo`;o0000J?ooool5ok^mg003okg3goo3bMoo000000?o
`lWO5_ooool00ol0003oooooooooo`1>ooooo`00H?ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l000005Oooool3o`0000;ooooo00?o0000ooooooooool0Hoooool00oni^=Wo
^kgLok^mg003ok^mg004ol;8goo3bMoo`lWOo`0000;o`lWO00?oaLkQooooooooool05?ooool00ol0
003oooooooooo`1>ooooo`00H?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4
A?l000004oooool2o`0006Wooooo1?ni^=T3ok^mg0?o`/SO00?o`lWOo`000?o3bMl00oo5c^4Foooo
o`03o`000?oooooooooo04gooooo001Pooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omg
MgOo0000ooooo`0?ooooo`?o0000JOooool00onf/mGo^KSIokVhf@04okVhf@03ok^mg?o2b=oo`/SO
00?o`/SO00?o0000olG>hOo5c^400oo5c^4Fooooo`03o`000?oooooooooo04cooooo0022ooooo`;o
0000J_ooool4okJce@Co^KSI00?o`/OOol;8goo2b=l00oo2b=l00oo5dNCo0000olG>h@03olG>h@03
ol;AiOoooooooooo01Cooooo00?o0000ooooooooool0C?ooool007oooooo0ol00002ooooo`03o`00
0?oooooooooo06Gooooo00?o]:kBokJceOnf/mD01?nf/mD00oni^=Wo`/OOol;7g`02ol;7g`?o`/SO
0_o5dN@01?l0003oaLkQolG>hOo5c^43ol;AiACooooo0ol0001=ooooo`00O?ooool3o`0006cooooo
0ond[]84okJce@03ol76goo2amoo`/OO00Co`/OO00Oo`/SOolGAi?o5dNCoaM7To`000?o5dNCoaLkQ
00Co`]7U5oooool00ol0003oooooooooo`1:ooooo`00N_ooool2o`0006kooooo1?nd[]83okJce@?o
`LKO1?o2aml2olGEiPCoaM7T00?o0000ol;AiOo2dND00_o2dND2okcBjaKooooo00?o0000oooooooo
ool0B_ooool007Oooooo0ol0001^ooooo`03ok:Yd?nd[];o]:kB00Co]:kB00?o][?Eol76goo1a]l0
0oo1a]l00oo2amooaMGVolGEiP03olGEiP06olGAi?o3f>Wo`mSYo`000?o3f>Wo`]7U1Onld^/Foooo
o`03o`000?oooooooooo04Wooooo001eooooo`;o00000_ooool00ol0003oooooooooo`1Zooooo`Co
/ZW@1?nd[]800oo0aMoo`LKOol76g`03ol76g`03olGIj?o5eNKoaMGV00?oaMGV00Goa>3]ol?HjOo3
f>Wo`mSYo`000002okcNl0Co_=;[00?o/M3`ooooooooool05Oooool00ol0003oooooooooo`18oooo
o`00L_ooool3o`0000Gooooo00?o0000ooooooooool0Ioooool00on`YLgo/ZW@ok:Yd003ok:Yd0?o
]:kB0oo0aMl3ol76g`?oaMWX0oo5eNH3olCPk@03ol?HjOnlg_3o000000?o_=k`00?o_=;[ok7@l?na
d?000_nad?0Fooooo`03o`000?oooooooooo04Sooooo001`ooooo`;o0000L?ooool4ok2Uc@Go/ZW@
00?o]:kBol35goo0aMl00oo0aMl00oo1a]ooaMWXolGIj003olGIj004olGEi_o4h>goa>3]olCPk@;o
^^We00Co_=k`o`000?nlg_3o_=k`0_n_g?L5ok7@l1Kooooo00?o0000ooooooooool0Aoooool003So
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00023ooooo0ol0001`oooo
o`03ojjRbon`YLgo/:G=00?o/:G=1?nbZM000onoaMoo`<GOol35g`03ol35g`;oaMcZ1?o5fNP2ol;X
l003olCPkOnjjOGo^^We00?o^^We00?o0000ojoLmon_g?L00on_g?L2ok7@l0;oXlWc5Oooool3o`00
04Sooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A00Nooooo`;o00000oooool00ol0003oooooooooo`1[ooooo`Co[Z;;1On`YLd0
0onbZM3o_lGOoko5g`02oko5g`?o`<GO1?o5g>X01?o5fNSo`^S`ol;Xl?o2j?02ok;am@Co^^We00?o
ZNOjo`000?n_g?L00on_g?L00onOdo[oXlWcoj?9l`03oj?9laKooooo00?o0000ooooooooool01_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0
:Oooool003Sooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^01cooooo
0ol0001aooooo`03ojfNbOn^X/_o[Z;;00?o[Z;;1?n`YLd00onna=oo_lGOoko5g`04oko5g`03ol35
goo5g>[oaMcZ00;oaMcZ00Co_nobol;Xl?o2j?3o`^S`1?nblOD01onjjOGoZNOjojWWn_nYio[o0000
ojWWn_n_g?L01?nOdoX5oj?9laKooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02[ooooo000hooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP0Hooooo`?o0000Loooool3ojfNb@Co[Z;;0on`
YLd3okk4g`Co_lGO0oo4h>d00oo5g>[o_noboko_lP02oko_lP04ol;Xl?nblOGo/_7eok;am@CoW>gg
0_nYioX00ol0003oUmgnoiOMoP05oioCnP;oXlWc0onD_o@Fooooo`03o`000?oooooooooo00Cooooo
00Go410@oooooooooooooooooa0@400;ooooo`Go0000:oooool003Sooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo01Gooooo0ol0001dooooo`Co[Ik91On^X//00on`YLgo
_/COokk4g`03okk4g`03oko5goo4h>goa>3]00;oa>3]00?o^OCboko_l_noko800_noko82ojCdkP?o
QNWY0_nLkOL4ohWRo004o`000?nGgOkoUmgnoiOMoP;oWm?j0on@a_X5oiBom1Gooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000;?oo
ool003Sooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo017ooooo0ol0
0003ooooo`03o`000?oooooooooo06oooooo00?oZi_7ojfNbOn]W/T00on]W/T4ojjRb`03okg3gonn
a=oo_/CO00?o_/CO0_o3i>l3olCPk@?o^OCb00?o_nobojCdk_nTm>h00on5jNT4og?Ol0;oRN;l0_n2
dOl00ol0003oR/gnoh[=oP02oh[=oPGoT<Kj0_nD_o@2oh^elQKooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo0000;?ooool003Sooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41004Oooool2o`00
07Kooooo1?n[VlL5ojfNb@03ojjRbonm`moo_L?O00;o_L?O0onna=l4ol?Tk`04olCPkOnim?;o^OCb
okWdlP;oS^oN00?oI][?oeSCf_mHdmX00_mHdmX2og?Ol0?oM]?n0on2dOl00ol0003oP]7ooh[=oP03
oh[=oP;oT<Kj0on9]o@4oh^elQKooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oMgMgolc<c?l00000;?ooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03_ooool3o`0007Kooooo00?oZYW5oj^Kaon[VlL0
0on[VlL4ojfNb@03okc3gonm`moo_L?O00Co_L?O00?o_/COol?Tkoo3i>l00_o3i>l3ojogk`03okWd
l_n>kmko>knl00;o>knl0_mHdmX4ofSBn@CoM]?n0_n2dOl00ol0003oQK[gohFjm`04ohNimPGoRKOd
1?n;]O8Dooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l0
0000;?ooool005Wooooo0ol0001fooooo`CoZYW51On[VlL00on]W/Wo_<?Ookc3g`02okc3g`Co_L?O
0oo1j?400oo3i>oo[oO_ojogk`02ojogk`04odC1[?m=bNGoCLWUodg9i@;oF/o`1on2^_P4oh>jn003
ohFjmol0003oQK[g00;oQK[g1?n7^OH2ohVgm0;oR:g]1?n8[nlCooooo`04o`000?ooooooooooo`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02_ooooo001Foooo
o`?o00000oooool00ol0003oooooooooo`1aooooo`03ojRGa?nZVLGoZYW500?oZYW51?n[VlL00onk
`n3o_<?Ookc3g`04okc3g`03okg3goo1j?7o`NSa00;o`NSa0onRm^L01?n_mnooQ[WfohJim_n6^OH4
ohBjn0WoP[[h1?n3^_P01?l0003oQK[gohVXjOn9Z>T4ohV[j`GoR:g]1?n8[nlFooooo`03o`000?oo
oooooooo043ooooo001Dooooo`;o0000N?ooool4ojRGa0CoZYW50on[VlL3ok_3h0Co_<?O0onnk?<0
0oo1j?7oX_KWoj;fi`02oj;fi`03ohVgm?n6^OKoQ[Wf00?oQ[Wf1?n4^_P6oh:jn0;oS:7S1?n:YNH0
0ol0003oRJSYohVXj@02ohVXj@CoRJ_[1?n8[Nd4ohR_kaKooooo00?o0000ooooooooool0@?ooool0
057ooooo0ol0001hooooo`03ojND`onXUlCoZ9O400?oZ9O41OnZVLD00on[VlOo^l?Pok_3h003ok_3
h003okc3gonnk??o_^cc00;o_^cc0on@l=X00onRm^OoRKOdohVgm002ohVgm0;oQ[Wf0_nAUmH4ohnJ
fPCoSIkN1On<XN<3ohZUiP03o`000?n9Z>WoRJSY00;oRJSY1?n9Zn/2ohR]k@;oSZKU1On=[>/Foooo
o`03o`000?oooooooooo03oooooo001>ooooo`Go0000Moooool4ojND``CoZ9O41?nZVLD00onj`n7o
^l?Pok_3h003ok_3h0;o^^od0onnk?<2oi3`fP?oSKGa0_n9]o@2oi>Dd@GoTIOF1?n?V]X4ohfNgPCo
S:7S0on:YNH00ol0003oRJSYohVXj@02oi2Jf@CoSj3O1On>Y^D5ohf/jaKooooo00?o0000oooooooo
ool0?_ooool004cooooo0_l00005ooooo`03o`000?oooooooooo07;ooooo00?oYY;1ojND`onWU<<0
0onWU<<5ojRGa003ojZIaOnj`n7o^/?Q00;o^/?Q0onk`n04ok[_m003okk/lonFSLSoUXg800CoUI7=
1OnCU=44oi6GePGoSi[J0on=W]h2ohbQh`;oTY3>0onAUM<00ol0003oT9[Ioi2Jf@03oi2Jf@CoSj3O
1On>Y^D2ohf/j`;oUjoX5_ooool00ol0003oooooooooo`0nooooo`00BOooool3o`0007[ooooo1?nV
T/44ojND``CoZ9O400?o^LCRok[3hOnj`n401?nj`n400onk`n3o^^odok[_m002ok[_m0GoUXg81?nE
TLd4oi>Dd@GoTIOF0_n?V]X2oiB7``?oTh_81OnBT<h3oi6Ed`03o`000?n@V]WoT9[I00;oT9[I1On?
X=l2ohjVi@;oUjKP1OnG[nPDooooo`?o0000?oooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Pooooo`;o0000N?ooool2o`000003odH03?nUT<3oYY;100CoYY;11OnWU<<00onXUlCo^LCRokW4
hP02okW4hPCo^/?Q0onel_@01?njkoCoUh[4oiN:a?nGR/@4oiJ=b0CoUI7=1OnCU=42oi6GeP;oUH>n
1OnDQl<3oi>;b0CoTY3>0onAUM<00ol0003oT9[Ioi2Jf@03oi2Jf@;oSj3O0_nHWmT5oiNVh0GoUjoX
5Oooool00ol0003oooooooooo`0mooooo`008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo
0ol00002ooooo`03o`000?oooooooooo06kooooo00?o0000od`06om<01/01?m901D00om600coYI30
ojF@`002ojF@`0CoYY;11?nWU<<00onia>?o^LCRokW4hP04okW4hP03ok[3hOnel_Co]O;d00;o]O;d
0_nHQ[l3oiN:a0CoUXg81OnETLd2oi>Dd@;oUX6j1OnEPkh4oiB7``?oTh_81OnBT<h2oi6Ed`04o`00
0?nAUM?oT9[Ioi2Jf@;oVIWB1OnHWmT5oiNVh0;oUjoX0onR/nDEooooo`03o`000?oooooooooo03co
oooo000Rooooo`05oa0@4?ooooooooooooooool@41006oooool2o`0007Cooooo00?oD00Mod`06om<
01/00_m<01/3odT05@03oj>>__nUT<3oYI3000?oYI301OnVT/400onWU<?o^LCSokW4h`02okW4h`Co
^LCR0on_m?<00onel_CoV8JooiR6_`02oiR6_`?oUh[41OnFSLP2oiFAc@;oUWjf1OnFPKX4oiF3_PCo
U8O31?nCRlP2oi:@cP;oVHk60_nITl`00ol0003oVI?<oiVIdP04oiVIdPGoV9oI0_nGY^02oj:[g@Ko
X[?U5Oooool00ol0003oooooooooo`0kooooo`008_ooool01Ol0003ooooooooooooooooo000001So
oooo0ol0001dooooo`03o`000?m@01goD00M00?oC00K0_m901D4oj>>_PCoYI301?nVT/400onhaNCo
^LCSokW4h`04okW4h`03okW4h_n_m??o[oCc00;o[oCc0_nGP[/4oiR6_`CoUh[40_nFSLP2oiMl/`Go
UWjf1?nFPKX4oiF3_PGoU8O30_nCRlP00onJRL7oVHk6oiV>aP03oiV>aP04oiVCc?l0003oVI?<oiVC
c0GoVIWB0_nHWmT2oj:SePGoXZ_M1?nR/nD00on]^^?oooooooooo`0Cooooo`03o`000?oooooooooo
03_ooooo000Rooooo`05o`000?ooooooooooooooool000005_ooool3o`0007?ooooo00?o0000oe<0
6OmC01T00_m@01d3od`06`;oXX^l1OnSS[h5ojF@`003ojJB`OnhaNCo^<GT00;o^<GT1?nia><3ojOd
l003ojodlonGP[_oUh:k00;oUh:k1OnHQ[l2oiN:a003oiQj/?nGO;?oUgbc00;oUgbc1OnFO[H4oiJ1
^PGoUH>n1?nDQl<01?nCRlSoVXW1oiZ9`OnJRL44oiV>aP04oiVCc?l0003oVI?<oiVCc0CoVIWB00?o
XYc?oj:Se_nRXmH00onRXmH5oj:[g@03oj:ciOn]^^?o[K[S00;o[K[S5Oooool00ol0003ooooooooo
o`0jooooo`008_ooool01Ol@413ooooooooooooooooo410@01?ooooo0ol00002ooooo`03o`000?oo
oooooooo06kooooo0_m>00/4oe<06@;oD00M00?oX8Nioj:;_?nRRk`00onRRk`4oj>>_PCoYI3000?o
^<CTokS5i?nhaN@01?nhaN@00onia>?oYoC`ojOdl002ojOdl0;oUWjg1OnGP[/3oiR6_`03oiQi[_nH
N[3oV7Z`00;oV7Z`1?nGO;<4oiIn]PGoUX6j1?nEPkh2oiB7``;oVXFl1?nJRL44oiV>aP03oiVCc?l0
003oVI?<00;oVI?<00?oVIWBoj:LconRW<l00_nRW<l4oj:SePCoXZ_M00?o[K?Mojfjhon]^^<00on]
^^<Fooooo`03o`000?oooooooooo03Wooooo000Rooooo`05ogMgMonHV9SooooooiRHV?mgMgL04?oo
ool3o`0007?ooooo00?o?000odh02om>00/00_m>00/3oe<06@04oe007OnPQkWoX8Nioj27^@GoXX^l
1OnSS[h2ojF@`0?o^<CT1?nhaN@3oj7dk003ojOdl?nCNK?oUWjg00?oUWjg1?nGP[/01?nHQ[ooV7V^
oiQi[_nHNJh4oiQj/0CoUgbc1OnFO[H4oiJ1^P;oUH>n0_nJP[P5oiZ5_0?oVXW11OnIS/H01?l0003o
VI?<oj:FbOnRU/T5oj:Lc`GoXZ?F00?oXZ_MojfcgOn]/md00_n]/md3ojfjh`;o]/;S5?ooool2o`00
03_ooooo000Rooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool2o`0007Gooooo0_ll0003odh0
2`?oD`0I00?oWX>foj27^OnPQkT00onPQkT4oj:;_0GoXhjn00?oYI30okS4i?nha>@00onha>@01?nh
aNCoXOC/oj7dk?nQm>`4oi=i/`CoUWjg0_nGP[/2oiQg[0GoV7V^1?nHN[03oiMl/`GoUWjf0_nFPKX2
oi]o]0GoVX:h1?nJQK`4oiZ9`@?oVHk600?oXY74o`000?nRU/T00onRU/T5oj:Lc`;oXZ?F0_n/[ML6
ojfcg@03ojfjhonf`^?o]/;S00;o]/;S5Oooool00ol0003oooooooooo`0hooooo`00<_ooool5o`00
07?ooooo00?o0000oc`00?ll00001?m>00/01?mC01WoWX>foij3]_nNPkH5oj27^@GoXX^l0onSS[h2
okS2hPCo^<CT0_nMm>L3oi5e/0GoTgVc0_nFO[L00onHMJ[oV7N/oiQg[002oiQg[0GoV7V^1?nHN[04
oiMl/`?oUWjf00?oVgfaoi]o]?nKOk@00_nKOk@5oiZ2^0CoVXFl1?nJRL400onIS/KoXY74oj:Aa002
o`0000CoXYK91?nRW<l00on/Ym;o[:gGojb]e`03ojb]e`Co[K?M00?o][oQokK2honf`^<00_nf`^<0
0onjb>Goooooooooo`0Dooooo`03o`000?oooooooooo03Oooooo000`ooooo`;o0000M_ooool3o`00
00;o?00000CoCP0;og4?=oma3cOoW82d1OnNPkH4oj27^@GoXX^l00?oXhjnokS2h_nh`^800onh`^80
1?nha>CoWOCWoigdion?LZd5oi5e/0CoTgVc00?oUWjgoiQeZ_nHMJX01OnHMj`4oiQi[PCoV7Z`1?nG
O;<01?nFO[KoVgfaoi]m/OnKOK45oi]o]0CoVX:h1OnJQK`2oiZ9`@06oj:>_ol0003o0000o`000?nR
TLCo00001OnRU/T00onRW<oo[:OBojbWdP02ojbWdPGo[:gG00?o[K?MokJohOnf_n400_nf_n400onf
`^?o^/SUok[8i@02ok[8iAGooooo00?o0000ooooooooool0=oooool002gooooo0ol0001gooooo`?o
000000?o?000og<::oma3cL00_ma3cL3oib0]0CoWX>f1OnPQkT3oj:;_0;o]koO1?nh`^82oikdi0Co
Sg:]1?nAMK02oi=i/`;oUg:X1?nHMJX4oiQg[0CoV7V^1OnHN[02oiMl/`03oi]k[onKOK7oVgfa00?o
Vgfa1?nKOk@5oiZ2^0?oVXFl00GoXXZko`000?l0003o0000oj:>_`04oj:Aa005o`000?nRU/WoXYK9
oj:FbOn/Xlh01On/Ym84ojb]e`03okJlg_nf_n7o][oQ00;o][oQ00?o^l[Vok[8iOnjb>D01?njb>DE
ooooo`03o`000?oooooooooo03Kooooo000/ooooo`;o0000N?ooool00ol0003oH`0>of<03P03og<:
:`;oVgjb1?nLP;@4oij3]PGoX8Ni00?oXX^lokNogong_ml00ong_ml00onh`^;oW_CToikdi002ohm`
Z`CoSg:]0_nAMK02oiA_YPCoUg:X1?nHMJX4oiQg[0GoV7V^0onHN[001?nKNZgoVg^_oi]k[onKNjl5
oi]m/@CoVgnd1OnJP[P01OnJQKco0000o`000?l0003oXXZk00?oXXjo1OnRTL@00ol0003o[:?>ojbS
cP02ojbScPGo[:OB00?o[:gGokJlg_nf_=h00_nf_=h2okJoh@?o^l[V1?njb>D2ok[>jAGooooo00?o
0000ooooooooool0=Oooool002cooooo0ol0001eooooo`03ocP00?mS00koH`0>00;oH`0>00?oVgfa
oi]n/_nKO[800_nKO[85oib0]0CoWX>f0onPQkT00ong^]_o]koOokNog`03okNog`?oY?OT0on?L:/3
ohmb[@03oi9/XonDKjKoU6nV00;oU6nV1OnGLZP3oiQeZPCoV7N/1OnHNJh01?nHN[3oVgZ]oi]j[OnK
NZd4oi]k[`CoVgfa1OnKOk@2oiZ2^0?o00001?nRR[/3oj:>_`CoXY7400?o[9o:ojbSc_l000000on/
Xlh4ojbWdP03okNkg?nf_=ko][cN00?o][cN00?o][oQok_:i_nkb^H00onkb^H00onjb>Go^/kYok[>
j@03ok[>jACooooo00?o0000ooooooooool0=Oooool002cooooo00Co0000ooooool0003o0000L_oo
ool3ocP000;oH`0>0onKOK45oi]n/PCoW82d1?nNPkH00onPQkWo]k[KokNjf`02okNjf`?o]koO0onT
mn@01On?Kj[oSg2[ohm`Zon?L:_oSg:]00?oTVbS1OnDKjH4oiMbZ0?oV7FZ1OnHMj`3oiQi[P03oiai
[?nKNZgoVgZ]00?oVgZ]0onKNjl4oi]m/@CoVgnd0ol00003oj:7^0CoXXZk1?nRS[l00onRTLCo[9o:
ojbObP02ojbObP03o`000?n/Xlko[:?>00;o[:?>00?o[:OBokNkg?ng^m`00_ng^m`3okJlgP;o_<gW
1?nkb^H2ok_FkPCo^/kY00?o/lk^ooooooooool04Oooool00ol0003oooooo`000008ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c00Ioooo
o`00;?ooool2o`0000;ooooo00?o0000ooooooooool0KOooool01_l0003o>000ocP00?lh003oH`0>
oiYm/PGoVgfa1?nKO[84oib0]0?oWX>f0_ne/mL5okNjf`04okNogonTmnCoY?OTojCgi0;oSfnZ0_n?
L:/00on@JJ7oTVbSoi9/X`02oi9/X`GoU6nV1?nGLZP3oiQeZPGoV7N/00CoV7V^oiai[?nLNJcoW7V/
1OnKNZd3oi]k[`GoVgfa0ol000000onRQKGoXXNhoj:7^003oj:7^0GoXXZk0_nRS[l00on]W<Ko[9o:
ojbObP03ojbObP05ojbSc_l0003o[:?>ojbSc_ni^m/01_ng^m`00onf_=ko_<gWokc=i`02okc=i`03
ok_:i_nke^ko^mK^00?o^mK^00?o^/kYok?>k_ncc^h00_ncc^hEooooo`03o`000?oooooooooo00Go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So
8B4Q01Wooooo000[ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Joooool01?l0
003o>000ofh04_m^0183oiYm/PGoVgfa1?nKO[85oib0]003oij3]_ne/mOo]K?G00;o]K?G0ong^]/3
ojciiP;oSfnZ0_n>IYl3oi1YX@GoTVbS1?nDKjH4oiMbZ0CoV7FZ0onHMj`00onLN:[oW7V/oiai[003
oiai[0CoVgZ]0onKNjl3oi]m/@;o000000?oVgndoj:5]OnRQKD00_nRQKD4oj:7^0GoXXZk00CoXXjo
ojfLa_n]W<Ko[Ic61On/WlX00on/Xlko0000okVkf`02okVkf`Co]k_L00?o_M7Yokc=ionlcNL00_nl
cNL2ok[OlPCo^mK^00?o/]Sdok?>k_ncc^h00oncc^hEooooo`03o`000?oooooooooo00Gooooo00Go
410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool002_ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Xooooo`;oC`0000?oKP0Boi]o]?nKOk@0
1OnJOK84oi]m/@GoVgjb0onLP;@00onb[]Co]K?GokFce`04okFce`03okNjfon/nNKo[?WV00;oSVBM
1?n>IYl3oi1YX@GoTVbS1?nDKjH4oiMbZ0CoV7FZ00CoV7N/oiahZ_nLN:[oW7RZ1OnLNJ`4oi]j[@?o
Vg^_0ol000000onKOK7oXX>coj:5]@04oj:5]@GoXXNh0onRR[/00on]V/Co[Ic6ojfLaP02ojfLaPCo
[9o:00?o^[cKokVkfol000001?ni^m/00ong^mco_M7YokgAj@02okgAj@03okc=ionjgo;o^]ob00?o
^]ob00?o^mK^ok;Hm?nbf?@00_nbf?@2ok?>kP?oZLWa5Oooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q01Wooooo000[oooo
o`?o00001Oooool00ol0003oooooooooo`1Tooooo`04ob@00?m?003oC`00oi^1]PCoVgnd1OnJOK84
oi]m/@GoVgjb00?oW82dok:^e?nb[]@00_nb[]@4okFce`;o/o[Y00CoSfBLohiTWOn>I9goSVBM1?n>
IYl4oi1YX@CoTVbS1?nDKjH5oiMbZ0;oV7FZ00?oW7RYoiahZ_nLN:X00onLN:X4oiai[0CoVgZ]0ol0
00000onKNjooVgfaoj:3/`03oj:3/`CoXXFe1OnRQkP00onRR[_o[I[4ojfJa002ojfJa0Co[Ic600?o
[9o:okZlfonj_=/00_nj_=/01?ni^m_o0000okVkfoni^m/2okoGk0?o_M7Y0ongj_H2ok[OlP?o[^?i
0onbf?@2ojKCm`GoZLWa5Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00002oooool01Ol0003oEEEEo`000?l@413oc<c<01Wooooo000[ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0H?ooool01Ol;003o9000ob@00?lT003oC`0000;oVh6f1OnKOk@4oiYm
/PGoVgfa0onKO[800on`[=Co/ZkDok:^e003ok:^e0?o]K?G0_ncn^T2ohmTW0?oSVBM1On>IYl3oi1Y
X@CoTVbS1OnDKjH4oiMbZ003oiQeZ_nLN:WoW7RY00GoW7RZ1?nLNJ`01OnKNZgo0000o`000?l0003o
VgZ]00;oVg^_00?oXX:aoj:3/onRPk<00onRPk<5oj:5]@?oXXNh00?o[IW2ojfJa?n]V/@00on]V/@4
ojfLaPKo^[cK00?o^K_Ko`000?noen`00onoen`01?nmdNWo]n[fokOZm_ngj_H2oj;[nPGo[^?i00?o
/]SdojKCmonVdoL00_nVdoL2ojW9l@;oW/;a5Oooool00ol0003oooooooooo`03ooooo`05oa0@4?oo
ooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Kooooo`00:oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo05Gooooo00?o9000oah00?lN00000_lN0003ooooo`;o2`000_lT
0002oib4^@CoVh6f1?nKOk@4oiYm/PGoVgfa00?oVgjbok2/e?n`[=@00_n`[=@5ok:^e003okFceonc
n^Wo/o[Y00?oSfBL1?n>I9d4ohiVW`?oT6VQ1?nBK:<5oiA_YP?oUg:X00?oW7NXoiahZOnLN:T00_nL
N:T4oiahZP;oW7V/0ol00004oi]j[@03oi]k[onRP[7oXX:a00GoXX>c1OnRQKD00onRQkSo[IW2ojfI
`P02ojfI`PCo[I[40on]W<H2okbng0Co^[cK0_nognl01?noenco0000okoGk?noen`2ojgbm@03okOZ
m_nRjo[oX^_j00?oX^_j0_n^hoT3oikKo0;oY]?g0onKa_D4oik2lA?ooooo0ol00004ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00Kooooo`004?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo04gooooo0_le00X3obL000;o900000?o7P00oa800?lB
00000ol000001?l5003o2`00o`/00?nLQKX4oib4^@CoVh6f1?nKOk@5oiYm/P?oVgfa00?o[:gGok2/
e?n`[=@00on`[=@4ok:^e0;o/OS/00?oT6BKohmTW?n?I9`00_n?I9`4ohiTW@CoSVJO0on@JJ45oi9/
X`CoU6nV00CoUg:XoiagZ?nLMjSoW7NX1?nLN:T3oiahZP?o00000onLNJ`3oi]j[@03oj:1/?nRP[7o
XX:a00;oXX:a1OnRPk<3oj:5]@03ojjI`On]VL;o[IW200?o[IW21On]V/@00on]W<Ko_;kLokbng002
okbng003okZlfonognoo_mo_00?o_mo_00Co0000ojgbmOn]l_Go[O;e0on9j^l2oj;[nP?oTN7n0_nN
fo`3oiO:n@GoVlKe1?nN`_4Eooooo`09o`000?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo00Coc<c<odA4A?l0003o410@6Oooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`?o00002_ooool00ol0003oooooooooo`19
ooooo`03ocl05Ole00[o=@0:00;o=@0:0_lW00000olT003o6P00oa800002oa8000;o00000_l50000
1?l;003oW8Fjoib5^_nLQKX5oib4^@?oVh6f1OnKOk@4oiYm/P03oi]m/On/[MOo[:gG00;o[:gG1On`
[=@00onb[]Co/OS/ok7hk004oi1TV`?oSfBL1?n>I9d4ohiVW`?oT6VQ1OnBK:<3oiA_YP03oi]eYonL
MjSoW7NX00?oW7NX0onLN:T3o`000003oiahZ_nLNJcoW7V/00?oW7V/00CoVgZ]oj:1/?nRPK3oXX6`
1?nRP[45oj:3/`03oj:5]On^VL7o[YW100;o[YW11?n]VL84ojfJa003okk3g_nl_]co_;kL00;o_;kL
0_nmjO<4okoOk`;oU?7W00Co0000ohWZkon9j^ooRN[_0omjg_L2oi7QoP?oT<cl1OnGb_T2oi_6m@;o
UkS^1?nI^NhEooooo`03o`000?oooooooooo02oooooo0008ooooo`Ko00000_ooool01Ol@413ooooo
oooooooooooo410@00_ooooo1Ol00005ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0Aoooool2ocl05@?o=@0:00?o9`00obD04olJ00000_lJ0002oa8000;o000000?o1@00oib6_?nL
Q[`01OnLQKX4oib4^@?oVh6f1OnKOk@2oiYm/P;oZ;?P1On/[ML4ok2/e0;oXoG/00?oTVJKoi1TVon@
I9/00on@I9/3ohmTW0CoSVBM1?n>IYl4oi1YX@CoTVbS00CoU6nVoi]eYonKMJOoVgFW1OnLMjP00onL
N:Wo0000o`000005oiahZP?oW7V/1_nRPK03oj:2/@CoXX>c1_n^VL45ojfI`P03ojfJa?nn`mko_/?N
00;o_/?N00?o_;kLokgYlonmjO<00onmjO<01onognooU?7WoiCaionDlNOoGmO@oe_Ciol000000_mK
dnL2og[Nm`;oR<_n1On@c?`2oiO:n@;oU[G]1OnG^>h4oiVikQGooooo00?o0000ooooooooool0;_oo
ool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`13ooooo`04o`000?m701So?`0Eocl05@?o
=@0:0olU01<2oaX00004oa800?l0003o0000oi^6_0GoW8Jl1?nLQKX4oib4^@CoVh6f0onKOk@00onT
`NkoZ;?PojRch003ojRch0Go[:gG00?o/:cDoj?ek?nSmN`01?nBIY/4oi1TV`CoSfBL0on>I9d5ohiV
W`?oT6VQ0onBK:<00onJLjKoVgFWoi]eY`03oi]eY`;oW7NX0ol00002oiahZ@GoW7RZ00?oW7V/oj:1
/?nRPK001_nRPK04oj:2/@;oXX>c1on^VL44ojfI`P03ol3:h_nn`mko_/?N00?o_/?N00?o]O?cokgY
lonmjO<00_nmjO<01?mWfL3o0000ocVnd?li_]02ogk3o@03oh;8o_l0003oP/Sn00;oP/Sn1?n8boh2
oi3<o0?oU;7[1?nF]Nd4oiNhkP;oVKW^0onJ]^/Eooooo`03o`000?oooooooooo02gooooo000@oooo
o`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00006ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0@?ooool01?m801CoA`0HodL06?m701P2ocl05@03ocD0
2_li02Go9@0C00;o9@0C0olJ0002o`0000?oVhJl1?nLQ[`4oib5^PGoW8Bi0onKPKH00onKOkCoY<7^
ojC1kP02ojC1kPCoZ;?P1?n/[ML00omki^3oUFRLoiEXW002oiEXW0?oTVJK1?n@I9/4ohmTW0?oSVBM
1On>IYl3oi1YX@04oi9/XonJLjKoVW>VoiYcYPCoVgFW0ol00002oiagZ0CoW7RY0onLN:X:oj:1/0Co
XX:a00?oXX>cojjI`On^VL401on^VL400on]VL;o`<[Rol3:hP02ol3:hP?o_/?N0onelo<00onmjO?o
Pk;cognlnP04ognlnP?oO/?m00CoP/Sno`000?nCY>3oTjCP1OnCZnL5oiBaj`?oU[G]0_nG^>h3oiVa
j0GoV[K[5?ooool00ol0003oooooooooo`0]ooooo`004?ooool01Ol@413ooooooooooooooooo410@
00cooooo00?oMgMgolc<c?l000001_ooool2o`0000oooooo0_l0000nooooo`?oB00D0_m701P3ocl0
5@;o>@0U0_lU01<2oaX00003o`800?nKQ[coVhJl00CoVhJl1?nLQ[`5oib5^PCoW8Bi0_nKPKH3oi[D
o0?oY<7^1OnX/n000on/[MOoVFbNoiU/WP05oiEXW0?oTVJK1?n@I9/4ohmTW0CoSVBM1?n>IYl2oi1Y
X@03oiUaY?nJLjKoVW>V00?oVW>V0ol000000onKMJOoW7NXoiagZ002oiagZ0CoW7RY00?oW7RZoj:1
/?nRPK002onRPK02oj:2/@03ojjJ`_n^VL7o[YW100Oo[YW100?o`]?Wol3:h_o0b^801?o0b^801?nn
`mko]O?cokGclon9Y^P4oh>bl`;oOkcj0_nET/h3oi>Kf0;oTjCP00?o0000oi>Th?nCY>001OnCZnL2
oiBaj`;oVZKN1?nI[><5oiVaj0;oV[K[0_nO]NPEooooo`03o`000?oooooooooo02cooooo000@oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000006ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0>Oooool01?lo00SoB00DodP05?m801@2odL060;o?`0E00?o
BP0aocT09Oli02D00_lU01<2oiZ5_0WoVhJl1?nLQ[`4oib5^P;oW8Bi1?n7hO/4oi[Do0?oY<7^0_nX
/n02oiY_X0CoVFbN1?nEJ9`3oi9VV`CoT6BK1?n?I9`4ohiTW@?oSVJO00CoUfnSoiUaY?nILJCoVG6T
0_nJLjH3o`0000CoVgFW1OnLMjP2oiahZ@03oj>2/?nRPK3oXX6`00coXX6`00CoXX:aojjJ`_n^V/;o
[Y[21on^VL43ol;Ci`Co`<[R00?oWoGXohVVj?n9Y^P00_nGPk`4oiJ:a@CoUI;>1?nCVmP2oi>Th003
o`000?nCY>3oTjCP00;oTj_W0_nJWmL5oiZVgPCoVJcS0_nI/NP2oin^hPGoWkGX4oooool2o`0002ko
oooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0=Oooool01?l`003o?`08ocl02?lo00P2odP0
50?oA`0H0om:03400oli02GoVHBkoiZ5_004oiZ5_0SoVhJl1?nLQ[`2oib5^PCoKMkV0_n7hO/00on8
M[SoW8Bioib4^@03oib4^@;oZhff00?oVFnRoiY_X?nJKj000_nJKj04oiU/WPCoUFRL0onBIY/4oi1T
V`CoSfBL1?n>I9d01?n>IYooUfnSoiM_XonGKj<2oiUaY0?o00000onJLjH4oi]eY`GoW7NX00?oW7RY
oj>2/?nSP[003OnRPK000on_Vl?o[Y[2ojjJ`P02ojjJ`PKo[YW11Oo2dnL01?o0b^;oWoGXohjJf_nI
O[@5oiN3_0CoUX[51?nET/h4oi>Kf004oi>Th?l0003oW9W@oibId0GoVYoG1?nJY]h2oiV/h`;oWjSL
1OnO[^84oinej1Gooooo00?o0000ooooooooool0:oooool002Wooooo0_l0000Dooooo`03o`000?oo
oooooooo03;ooooo0ol`0002ocl020?oB00D00GoA`0HoeT0>?m:037oBP0aoiR2^@04oiV4^`CoVXFl
2OnKQ[`2oib6_0;oF=;>00?oOfR_ogm//omoK;<00_moK;<3ohQf^0GoW8Bi00?oZhffoiU_X_nIKj80
1?nJKj04oiU/WPCoUFRL0onBIY/5oi1TV`?oSfBL0on>I9d01?nGKZ7oUfnSoiM_XonGKj<3o`0000;o
VG6T1?nJLjH5oi]eY`?oW7NX00?oY8Baoj>2/?nSP[000_nSP[0:oj:1/0Co[i_30on^V/84ojjI`@;o
`^3^1?o2dnL00omch<CoVWZ^oiUn]003oiUn]0CoUh>l1?nFR/D4oiFBcP;oTi_H0_nMTlT2oibId003
o`000?nLVM3oW9W@00CoVYoG0_nJY]h2oj6RePGoWjSL1OnO[^82oinej0;oY[WW5Oooool00ol0003o
ooooooooo`0Zooooo`00:Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02oooooo
00Co6@00oc000?l`003o<0000_lo00P00om801CoHPLjof87>P03oeT0>0?oV8:i1?nIQ;/4oiZ5_0So
VhJl00CoDLg2ohIZ[?n6JZcoQVZ/0omoJ:l4ogm//`?oR7Jh0onLQ;T01?nCJj;oVFnRoiU_X_nIKj84
oiY_X0CoVFbN1?nEJ9`3oi9VV`GoT6BK0on?I9`01On>I9goUfjQoiM^XOnGKZ7oUfnS00;o00000_nG
Kj<3oiUaY0CoVW>V1OnKMJL01?nLMjSoY8BaojB4/OnTQ;44oj>2/0SoXX6`00?o/9k6ojnK`on_Vl<0
0on_Vl<4ojjJ`P03ojjI`Oo2h>ko`^3^00?o`^3^00?o`]?Woi:?cOnJNZh00_nJNZh4oiUn]0CoUh>l
1OnFR/D2oiFBcP03oij>`_nMTlWoWI?900?oWI?90_nLVM000ol0003oW9W@oiZOe`02oiZOe`03oj:L
conQX]KoXJ;F00?oXJ;F1OnOZ=`2oin^hP;oYkCR1OnV^NLDooooo`03o`000?oooooooooo02[ooooo
000Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;Oooool2oaT000;o<00000?o
?`08of@6=omR1cX00omR1cX00omI03SoUgngoiR2^@04oiR2^@?oVHBk1OnJQK`5oi^6_0;oSVjZ1?n6
JZ`3ogmX[`CoOfbc0on8M[P01?nLQ;WoTf^Roi=[X_nCJj84oiU_XP?oVVnP1?nIK9h4oiEXW0CoTVJK
1?n@I9/2ohmTW003oiM]X?nGKZ7oUfjQ00?o00001?nGKj<3oiUaY0GoVW>V0onKMJL00onVQ[;oY8Ba
ojB4/@03ojB4/@?oXh:`1_nRPK04ok2NaPCo[i_30on^V/83okg^l`;o`^3^00?oUXK1oiahZOnLN:T0
1OnJNZh3oiUn]0GoUh>l0_nFR/D2oj29^`CoWXk21?nMTlT3oibId003o`000?nLVM3oVYoG00?oXYc?
1?nQX]H4oinXg003ojR_gOnW]>;oYkCR00?oYkCR0onV^NL2ojfoiaCooooo00?o0000ooooooooool0
:Oooool002Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Zooooo`05o`800?lI
003o6@00oc000?mQ03000omT1SL00omR1c[oUWbdoiIl]004oiMo]`CoV8:i1?nIQ;/4oiZ5_0;oVhJl
0_mAcL83ohi^ZP;oQVZ/0_n:H9/3ohQOV`CoR66M0on;I:04oi=[XPCoVFnR1?nJKj03oiU/WPGoUFRL
0onBIY/4oi1TV`03ohmTW?nGKJ3o000000;o00000onGKZ44oiM_X`?oVG6T1OnJLjH2oi]eY`;oYXJb
1OnTQ;43oj>2/0CoXX6`00?o/J;9ok2Na_n`W/H00on`W/H5ojnK``06ojjJ`_nmk_?o_Nkcokg^lonH
P;OoWGJV1?nLN:T5oiYj[PCoVGjd0onGPk`00onRQkKoX8Vkoj29^`02oj29^`CoWXk21OnMTlT2oibI
d003o`000?nSV<WoXYc?00?oXYc?1OnQX]H00onOZ=coZ:oMojR_g@02ojR_g@CoYkCR00?oY[WWojfo
ion]_nL00on]_nLDooooo`03o`000?oooooooooo02Sooooo000Yooooo`?o00005oooool00ol0003o
ooooooooo`0Xooooo`04o`800?lI003o6@00oaT000;oH@0`0_nDN[<4oiIl]0CoUgng1?nHP[T4oiV4
^`;oVXFl0omMeLl3oi=aZ@;oSVjZ00?oSF:KohYPVon:H9/00_n:H9/3ohQOV`CoR66M0on;I:04oi=[
XPCoVFnR1?nJKj03oiU/WPGoUFRL0onBIY/3oi1TV`?o000000?oUffPoiM^XOnGKZ400onGKZ44oiM_
X`CoVG6T1?nJLjH00onKMJOoYXJbojJ6/P02ojJ6/PCoY8Ba1?nSP[02oj:1/0?o/J;91?n`W/H4ojnK
``;oZoK_00?o_NkcoiUk/?nHP;L00_nMMZH5oiahZ@CoVWZ^1?nIO[@00onGPkcoXXNfoj:7]P02oj:7
]PCoX8Vk1?nNS/82oifCb@;oYIC40onSV<T00ol0003oXYc?oj:Lc`03oj:Lc`;oXJ;F0_nYZmP5ojR_
g@;oYkCR0on^_ND4ojfoi`03ok34jOoooooooooo017ooooo0_l0000Zooooo`00:Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo02Gooooo00?o0000o`800?lI00000_mF02<00onDNK;o
U7ZcoiAj/`02oiAj/`GoUWbd0onGOkL5oiR2^@;oVHBk0omliNT3oiMdZ@;oTg6Y00CoSfBKoheRVon=
HY_oSF:K1?n:H9/3ohQOV`CoR66M0on;I:04oi=[XPCoVFnR1?nJKj04oiU/WPCoUFRL0onBIY/3o`00
0003oiI/X?nGKJ3oUffP00;oUffP1?nGKZ44oiM_X`CoVG6T0onJLjH00onXRKCoYXJbojJ6/P03ojJ6
/PCoY8Ba1?nSP[000onRPK3o/J;9ok6Rb@02ok6Rb@Go/9k600Co[i_3oj_fkon[m^ooZoK_0_nINk00
0onNMJCoWGJVoiefYP02oiefYPCoW7RY1OnJNZh2oiUn]003ojF5/_nRQkKoXXNf00?oXXNf1?nPRK/3
oij>`P03ojNB`?nUU<CoYIC400?oYIC40onSV<T01Ol0003oXYc?oj:LconRW<oo[:WD00GoZJ_H0onX
[md00on_^n?o[[gUojjmi@04ojjmi@03ojfoion`a>Wo/<CY00;o/<CY5?ooool00ol0003ooooooooo
o`0Wooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02;ooooo0_l000000om901?oU7VcoiAi
/`03oiAi/PGoU7Zc1?nFO;@4oiMo]`CoV8:i00CoVHBkogcUjOmliNWoVgNY0_nGM:T2oi5WW@?oSfBK
0on=HY/4ohYPV`CoR5nK0on8HId4oh]TX0?oTf^R1?nIKj84oiY_X0CoVFbN1?nEJ9`3o`0000CoUVbP
1?nGKJ04oiM^X@GoUfnS0onILJ@01?nJLjKoZ8VdojR9]?nXRK@5ojJ6/PGoY8Ba0_nSP[000onbZ<ko
/J;9ok6Rb@03ok6Rb@Co/9k60_n1j=02oiYgZ`;oVG^`0_nNMJ@4oiefYPCoW7RY1OnJNZh00onIO[Co
YHFbojF5/P05oj:7]PCoX8Vk00?oWXk2ojNB`?nWT/000_nWT/04ojFDa0?oXiS900?o0000oj:Lcon/
ZM@00on/ZM@5ojV[f004ojR_gOn_^n?o[k_Sojnkh`Co[[gU00?o/LGYok34jOn`a>T00on`a>TEoooo
o`03o`000?oooooooooo02Kooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool07oooool2o`000003oiAk]OnDNK?oU7Vc00;oU7Vc1?nDNK84oiAj/`CoUWbd1?nGOkL2
oiR2^@?oV^Sk0_nKMjT00onDJYooTFNMoi5WW@02oi5WW@?oSfBK0on=HY/4ohYPV`CoR5nK0on8HId4
oh]TX0CoTf^R0onIKj84oiY_X0CoVFbN00CoUFRLo`000?l0003o00000onEJj05oiI/X0?oUffP1?nG
KZ45oiM_X`;oVG6T00?oZHfgojR9]?nXRK@00onXRK@4ojJ6/PGoY8Ba00CoXh:`ok:Xc_nbZ<ko/ZS>
1OnaX/T00on`W/KoPNS@oh7Xd004oiYgZ`03oiUk/?nNMJCoWWFT00;oWWFT0onMMZH4oiahZ@CoVWZ^
00?oYhB`ojF5/_nUQK800_nUQK85oj:7]P;oX8Vk00?oZi:mojNB`?nWT/000onWT/05ojFDa0;oXiS9
00?o[ZOAo`000?n/ZM@01?n/ZM@2ojV[f0;o/KcR1On_^n<00on^_NGo/LGYok75j@02ok75j@;o/<CY
0on_an`Dooooo`03o`000?oooooooooo02Kooooo0006ooooo`Ko00000_ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool2o`0001gooooo00?o0000ooooooooool0
7?ooool2oiAm^0?oU7^e1OnDNK<3oiAi/PCoU7Zc1OnFO;@2oiMo]`CoZmWh00?oV^SkoieiZonKMjT0
0_nDJYl4oi5WW@?oSfBK1?n=HY/3ohYPV`CoR5nK0on8HId4oh]TX0CoTf^R0onIKj84oiY_X0?oVFbN
0_l00003oiA/XP?oUF^P1OnFK:03oiM]X0CoUfjQ1OnGKj<00onILJCoZHfgojV=]`05ojR9]0GoYXJb
0onTQ;400ond/MGo/ZS>ok:XcP02ok:XcPCo/J;900Co0000oi]eYonKMJOoVgFW0onJMj/00onOM:;o
WWFToiieY003oiieY0?oWGJV1OnLN:T2oiYj[P;oYhB`1?nUQK85oj:7]P04oj29^on[T[goZi:moj^B
_@CoYi;01?nUU<@00onaZ<oo[ZOAojjWd@02ojjWd@05o`000?n/ZMCo[:WDojbYe?ne_n801Ona_>82
ojnkh`?o//S[0onaaNT2ok3=k`Go[lO/5?ooool00ol0003oooooooooo`0Uooooo`003_ooool01Ol0
003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo01Sooooo00?oU82koiAm^?nDOKP00_nDOKP4oiAk]@CoU7Vc0onDNK85
oiAj/`CoUWbd00?oUgngoj_In?n[fOP00_n[fOP00onMNJ_oUVfQoiI]X@03oiAZW`CoTFNM0on?I9/4
oheRV`?oRV2K1?n8Gi/4ohQQW@?oRfBP1?nCJj84oiU_XP?oVVnP0ol000000onDKjGoU6bRoiA/XP02
oiA/XPCoUF^P1?nFK:03oiM]X0GoUfjQ0onGKj<00on/TK_oZHfgojV=]`02ojV=]`CoZ8Vd1OnVQ[80
0onTQ;7o];7EokBae@02okBae@Co/ZS>00?o/J;9oi]cY?nKLj@01?nKMJL01?nJMj_oWgBRoimdX_nO
M:85oiieY0?oWGJV1OnLN:T00onJNZkoYhB`ojN4/002ojN4/0?oYHFb1?nRQkH00on^U;coZi:moj^B
_@02oj^B_@GoYi;000?oYIC4ok6XconaZ<l00_naZ<l4ojjWd@03o`000?ne_n;o]KoR00;o]KoR0ona
_>82ok?=k@Go//S[00?o/LGYok3=kon`cNl00_n`cNl2ojo7k0;oZlK]5Oooool00ol0003ooooooooo
o`0Tooooo`003_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01?oo
ool00ol0003oooooooooo`0Nooooo`;o00005Oooool01?nDPkkoU82koiB0^onDP;/5oiAm^0?oU7^e
1?nDNK<3oiAi/PGoU7Zc0_nFO;@4ojc3j`03oj_In?nFKj?oUVfQ00?oUVfQ1?nDJYl3oi5WW@?oSfBK
1?n=HY/4ohYPV`?oR5nK1?n8HId3oh]TX0CoTf^R1?nIKj83o`0000CoU6nU1?nDK:84oiE[X0CoUVbP
0onGKJ05oiM^X@;oUfnS0_n/TK/4ojV=]`GoZ8Vd0onVQ[800onh_Mko];7EokBae@03okBae@?o/ZS>
1OnKLj@3oi]eY`GoWgBR1?nNMJ@4oiefYP?oW7RY00?oZHF^ojN4/?nWQ;000onWQ;04ojF5/P;oXXNf
0on^U;`3oj^B_@CoYi;000?o]Jc?ok6XconaZ<l00onaZ<l3ojjWd@03okS5i?l0003o]KoR00Co]KoR
00?o/KcRok?=kOnccNd00_nccNd2ok;8j`;o[m?c1?n`cNl2oj_;l@CoZlK]4oooool2o`0000Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
00Wooooo000>ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`03oooo
o`;o00008Oooool00ol0003oooooooooo`0>ooooo`;oU8G11?nDPkh3oiB0^`CoU7fh0onDNkD4oiAi
/`CoU7Vb0onDN[<00onW/^7o[<?[ojc3j`03ojc3j`03ofcEY?nFKj?oUVnS00CoUVfQ1?nDJYl3oi5W
W@?oSfBK1?n=HY/4ohYPV`?oR5nK1?n8HId4oh]TX0?oTf^R00GoVFnRo`000?l0003o0000oiY_X002
oiIcZ0CoU6nU1?nDK:84oiE[X0CoUVbP1?nGKJ04oiM^X@03oiM_Xon/TK_o[96k00;o[96k0onYSKL5
ojR9]003ojJ6/_nh_Mko^;gN00;o^;gN1Ond/MD00onbZ<koVg6Roi]cY004oi]cY0;oVgFW00?oXGFR
oimdX_nOM:800onOM:84oiieY0CoWGJV00CoW7RYojV5[_nYQJkoZHF^1OnWQ;04ojF5/P03oj:7]_n^
U;co[YBl00;o[YBl1?n[T[d00onWT/3o]Jc?okF/c`02okF/c`Go/JS?00Go[ZOAokS5i?nhaNCo^<GT
o`000003okFohP03okCElOnccNgo/lg]00;o/lg]0_n/foL4ojoCl`03ok3=kon[bo7oZl_a00?oZl_a
0_n[a^d2ojK3kQCooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B402Oooool000kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool2o`0002?ooooo00?o0000
ooooooooool01_ooool2oiB9a@?oU8O31OnDQL43oiB3_P?oU82k1?nDOKP3oiAk]@GoU7Vc0onDNK80
0onDN[?oYk;QojNbh@02ojNbh@?o[<?[00CoUW2VoiI_XonFKj?oUVnS1?nFKJ44oiAZW`?oTFNM1?n?
I9/3oheRV`CoRV2K0on8Gi/4ohQQW@CoRfBP00GoTf^Ro`000?l0003o0000oiU_XP02oiQf[0?oUW>X
1OnDKjD3oiA/XPCoUF^P1?nFK:04oiM]X0?oUfjQ00?o[iRoojbA^on/TK/00on/TK/4ojV=]`?oZ8Vd
0_nkcNP5okRmgP;o];7E00CoW76Qoi]aX_nKLJ;oVg6R1OnKLj@01?nKMJOoXGFRoj5eX_nQMJ84oimd
XPGoWWFT0onMMZH5ojV5[PGoYhB`0_nUQK800oncVKgo[YBlojjD_003ojjD_0CoZi:m1One[<l4ok6X
c`03okcAjOnhaNCo^<GT00?o^<GT00?o0000okCElOndeO400_ndeO400onccNgo[=_gojcKm`03ojcK
m`;o[m?c0_nXd?D4oj_;l@03ojG6l?nV`nkoY/?^00?oY/?^5?ooool00ol0003oooooooooo`04oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Wooooo000>
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`02ooooo`03oi>:a_nDRLGoU8W500?oU8W5
0onDQl<4oiB5`@?oU8>n0onDP;/5oiAm^0?oU7^e1?nDNK<2oiAi/P;oXJOK1OnW/^400on/`n_oUW2V
oiI`YP04oiI_X`?oUVfQ1?nDJYl4oi5WW@?oSfBK0on=HY/4ohYPV`CoR5nK0on8HId2oh]TX0?o0000
00?oTf^RoiMf[?nHMZ`00onHMZ`4oiIcZ0CoU6nU1?nDK:83oiE[X0GoUVbP0onGKJ000onGKZ7o[iRo
ojnH_`02ojnH_`Co[96k1?nYSKL00onXRKCo^lgXok_=j003ok_=j0;o^;gN00?oWG6PoiaaXOnLLJ40
0_nLLJ44oi]aXP?oVg>T00?oXGJRoj5eX_nQMJ800_nQMJ84oimdXPGoWWFT0_nMMZH00on/QjooZHF^
ojV5[P03ojV5[PGoYhB`00CoYHFbok>I_OncVKgo/iVm1On^U;`2oj^B_@;o^[?B1One[<l00onaZ<oo
_=7YokcAj@02okcAj@;o^<GT0onbgoL00ol0003o]=GaokCEl@03ojGSn`;o[=_g0_nSeOT5ojS@m@03
oj_;lOnUa_3oYLK`00;oYLK`0onV`nh00onS_ngoooooooooo`0Booooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S802Oooool0
02Oooooo00?o0000ooooooooool09?ooool00ol0003oTh_8oi>:aP03oi>:aPCoU8W50onDQl<4oiB5
`@CoU8>n0onDP;/4oiAm^0?oU7^e0_nDNK<2oiZRf`GoXJOK0onW/^401?n4jLgoUW2VoiI`Y_nFL:H4
oiI_X`?oUVfQ1?nDJYl4oi5WW@?oSfBK0on=HY/4ohYPV`CoR5nK0_n8HId3o`0000;oU76Y0onGMZ`5
oiQf[0?oUW>X1?nDKjD4oiA/XP?oUF^P1OnFK:02oiM]X003ok>Oa?n_V;oo[iRo00?o[iRo1On/TK/2
ojV=]`;o^>3c1?nkcNP4oieaX0CoW76Q1?nKLJ82oi]cY0;oXGJR1?nQMJ84oimdXPGoWWFT00CoWGJV
ojb7[on/Qjoo[8N_1?nYQJh4ojN4/003okRQ`OncVKgo/iVm00;o/iVm1On^U;`01?n[T[go^[?BokZc
d_nj/m84okF/c`03okgSl_nldNWo_=7Y00;o_=7Y0onVjoX2ok;Om`03oi;Wn_l0003oT^Oj00;oYN?k
0_nJfOd5oj?En@;oZ=3e0_nRb?<5ojG6l003ojK3k_nS_ngoXko]00;oXko]5?ooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<
00Wooooo000Wooooo`;o00007oooool00onBSlgoTXg:oi:=bP02oi:=bPCoTh_80onCR/H4oiB9a@?o
U8O31OnDQL43oiB3_P?oU82k0_nDOKP2ohnTh`CoU:7N1?nJX]/5oj6Wf`03ojNbhOnELZSoUG:X00?o
UW2V1?nFKj<4oiI]X@?oU6ZO1?nAIid3ohmTV`CoSF:K0on:H9/4ohQOV`;o000000?oTfjUoiAaZOnD
LJT00_nDLJT4oiMf[0CoV7J/0onFLjP4oiA_Y@CoU6bR1?nEJj04oiI/X004oiM]X?ncWlCo/io4ok>O
a0Co[iRo1On/TK/00onYSKOo^>3cokSPl`02okSPl`04ok_=j?nLL9ooW72Ooia`W`?oWG6P1?nLLJ44
oi]aXP04oi]cY?nQMZ;oXGJRoj5fXPCoXGFR1OnOM:83oiieY003ojn</?n/Qjoo[8N_00;o[8N_1OnY
QJh2ojN4/0;o^:711?ncVKd4ojjD_003ol30f_nj/m;o^[?B00?o^[?B00?o]Jc?okgSl_nmho800_nm
ho800onldNWoY^_jojK[nP02ojK[nP;oK]gZ0_nBioX00on=fOoo0000ohgIo`04oi[Io@;oXmGi0onO
b?D4oj;8l`;oYLK`0onR_nh4oj>okAGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4009ooooo`009oooool00ol0003ooooo
ooooo`0Hooooo`04oi2Cd_nATLooTI7?oi6Ac`CoTXo=1?nBSLX3oi>;b0?oTh[61OnDRLD3oiB7``Co
U8G10_nDPkh00on<[ngoS:WYohbYj@02ohbYj@CoSjCS1?nDXMh4oiZRf`;oXJOK0_n3jN<3oiEbZ0?o
UW2V1?nFKj<4oiI]X@?oU6ZO1?nAIid3ohmTV`CoSF:K0on:H9/01?n8Gi_o0000o`000?l00003oi=^
Y@GoU76Y0onGMZ`4oiQf[0?oUW>X1?nDKjD4oiA/XPCoUF^P0onFK:000on`YLco/io4ok>Oa002ok>O
a0Go[iRo0_n/TK/4ojO`m`;o^>3c1OnLL9l3oieaX0GoW76Q0onKLJ85oj5fXPCoXGFR1?nOM:82oiie
Y0;o[hb`1?n/Qjl5ojV5[P03ojN4/?nhXL7o^:7100;o^:711?ncVKd00on^U;co`<3Jol30fP02ol30
fP?o^[?B0on]mO42okgSlP?oPNO[00CoY^_jofkMj_m^gN[oK]gZ0omme?l2ohgIo`04o`000?n=fOoo
V]Wmoi[Io@?oV/Of1?nOb?D2oj;8l`;oXKk^1OnR_nh2oj>ok@;oX[c[4_ooool3o`0000Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000002Oooool002Oooooo
00?o0000ooooooooool04Oooool00on?VMWoT9KFoi2FeP02oi2FePCoT9?B0onATLl3oi:?c@CoTXg:
0onCRlP4oi>:aPCoU8W50_nDQl<2ohfflPCoS;?`0on<[nd4ohbYj@?oSjCS1OnDXMh2oiZRf`;oI=WU
0onELjX3oiEbZ0CoUW2V0onFKj<4oiI]X@CoU6ZO0onAIid3ohmTV`CoSF:K00CoRV2Ko`000?l0003o
00000onBJj84oi=^Y@CoU76Y0onGMZ`4oiQf[0?oUW>X1?nDKjD4oiA/XPCoUF^P00?oUVbPok2Uc?n`
YL`00_n`YL`3ok>Oa0Co[iRo0on4j]X2ojO`m`04oiI/WonJKYooVVjOoiY^W`GoW72O0onMLJ05oiaa
X@;oVg6R00?oXWNSoj5fX_nQMZ800onQMZ84oj5eXPCoWgBR00?oWWFTojn</?n_S;000_n_S;03ojb7
[`CoZHF^00?o`[;;okRQ`OnhXL400onhXL43ok>I_@03olGGioo0`=[o`<3J00Co`<3J00?o^[?Bojge
lOn]mO400_lf^Zl01?l0003oL/;nog;2o_mb`_h4ogC=o`;oOMCo0_nC^?42oiK2m@03o`000?nF`_Go
U/;e00;oV/Of0_nM]nX4oinkk@GoXKk^0_nR_nh2oj:jjPGoX[c[5?ooool02Ol0003ooooooooooooo
ooook^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT02Oooool002Ko
oooo0ol0000<ooooo`04oh^Qh_n=WMkoSIgNohfMgPCoSiWI1?n@U]H3oi2CdP?oTI7?0onBSld5oi:=
bP?oTh_80_nCR/H2ohfel@SoSKKb1?n</o03ohb_k@CoS:WY0on?Y><2oiBQgP?o?<3G0onEMJ`3oiEc
ZPCoUG:X0onFL:H3oiI_X`CoUVfQ1?nDJYl3oi5WW@?oSfBK0_n=HY/3o`000003ohYPVon@J:3oTV^R
00?oTV^R1?nCKZD4oiAaZ@?oUgJ/1?nHMZ`4oiIcZ0CoU6nU0onDK:83oiE[X003ojVZeon`YLco/:G<
00?o/:G<1?ncWl@01_n_V;ooQ>[JohCZf_n4j][oVFnQoiE[W`?oUVbO1?nJKYl4oia`W`?oWG6P1OnL
LJ400onKLJ;oXWNSoj9gX`05oj5fXPCoXGFR1?nOM:85ojn</0Co[8N_0_nYQJh3ol:bb`Co^:7100?o
/iVmolGGioo5enL00_o5enL4ol30fP;oRj?U1Omn]OL2og;2oP03oiJOf_nD[NOoU:gW00?oU:gW1?nC
^?42oiK2m@03o`000?nN/NKoWKOZ00CoWKOZ1?nO^nd2oj6nkP;oX[OW1OnR^^X2oj:lj`;oY;cZ5Ooo
ool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`02ooooo`;oPjka0on6ZN`3
ohVUi`CoRj7R0on=WMh4ohnIf@?oT9KF0on@Tm84oi6Ac`?oTXo=0_nBSLX2ohZbl@CoS;Ca1?n=]O48
ohfflP;oS;?`0_lEY;P3oj^La`;oZ9O400?oVgjcoiQj/?nHN[000_nHN[03oiIg[PCoUGF/0onELjX4
oiEbZ0?oUW2V1?nFKj<3oiI]X@CoU6ZO0onAIid2ohmTV`?o00000_n?Ij03oi1XX0GoTV^R0onCKZD4
oiAaZ@?oUgJ/1OnHMZ`3oiIcZ0CoU6nU0onDK:800onEJj3oZJ[GojVZe`02ojVZe`Co/:G<0oncWl@2
o`000004oj9gY?nIKj7oVFnQoi=[X@CoUVbO1?nJKYl4oia`W`CoWG6P0onLLJ400onSNJGoXWNSoj9g
X`02oj9gX`CoXGJR1?nQMJ84oimdXPGo[hb`1?n/Qjl00onYQJko`[;;ol:bb`02ol:bb`?o^:710_ni
mO45olGGi`03ol30f_nFUM3oRj?U00?oRj?U0_mn]OL2oi^Ec@CoUYoJ1OnD[NL2oi>hl@06oijZgonN
/NKoW[7Voijai_l0003oW[7V1?nM]nX2oinkk@?oX[?T1?nR]nL2oj:jjP?oY;WX1?nT_>XDooooo`03
o`000?oooooooooo01kooooo000Kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooogjbm@02ogjbm@?oPjka0on6ZN`3ohVUi`?oRj7R0on=WMh5ohnIf@?oT9KF0on@Tm82oi6Ac`;o
Q[3a1?n8/O03ohZbl@CoS;Ca1?n=]O42ohfflP;o>KkC0_nbY/d5ojjQbP;oZic700CoWH:foi]n/onK
O[?oVgjc1?nHN[04oiIg[P?oUGF/0onELjX4oiEbZ0?oUW2V1?nFKj<3oiI]X@CoU6ZO0_nAIid3o`00
0003oheVX?n?Ij3oSfNP00;oSfNP0on@J:05oi9[XP?oTfjU1?nDLJT4oiMf[0CoV7J/0onFLjP4oiA_
Y@;oU6bR0_nG/^X4ojVZe`Go/:G<00?o/io4oj9gY?nRMj@00_nFKj@3oi=[X@GoUVbO0onJKYl4oia`
W`CoWG6P0_nLLJ42oj=iY@CoXWNS1?nQMZ85oj5eXP;oWgBR0_ndTkD4ojn</0Co[8N_1_o2///00onh
XL7o^OGaokWel@02okWel@;oaMOW1?nFUM02oh^Si@;oWhg11OnKULd4oiJOfP;oU:gW0_nQXmH4oijZ
g`?oW[7V00Co0000oijai_nM]n[oWKOZ0_nR[^05oj:ci0;oX[OW0_nU]nD5ojBij0;oY;cZ0_nW_NTD
ooooo`03o`000?oooooooooo01gooooo000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`03ogjbm@?oPjka0on6ZN`3ohVUi`?oRj7R0on=WMh2ohnIf@;oOZgb0on1[_44
ohB_l@CoQ[3a1?n8/O03ohZbl@;oS;Ca0omAbnX3ol3=i003okF[conbY/go/ZK=00;o/ZK=1?n^XLX0
1?nQQkSoWH:foif2]_nMP[H4oi]n/`?oV7Z`1?nFMjh3oiEe[0CoUG>Z0onELZP3oiI`YPCoUVnS0_nF
KJ401?n?JZCoSVRSohiXXon>J:<3o`000004ohaVXOn=IZ3oSFJPoheVX0CoSfNP1?n@J:04oi9[XP?o
TfjU1OnDLJT3oiMf[0;oV7J/1?m1`mX3od[1lP?oL;cm1?nG/^X4ojVZe`;o/:G<0_n/PZP00onLN:[o
UVnToiI_Y002oiI_Y0?oTf^Q1OnFK9l3oiY^W`CoW72O1?nMLJ001?nLLJ7oXgVUoj=iYOnSNJD4oj9g
X`CoXGJR1OnQMJ801?nOM:;o]9>eokBC]OndTkD5ojn</0;o[8N_0_o>dmh4ol:bb`;oDLJR0_nimO45
oij;_`;oUYG@00?oY8Vhoin=`OnOSL400onOSL44oi^Ec@;oUYoJ0_nTWLh5oj6SePCoWZ[O0_nN/NH0
0ol0003oY:WKoj:^h004oj:^h0;oX[?T0_nV]>85ojFgi@;oY;WX0_nW^nL5ojNmjA?ooooo0_l0000N
ooooo`006oooool01Ol@413ooooooooooooooooo410@00Kooooo0_l00002ooooo`?oKjcf0oma[?H3
ogB/m@CoMZgd0omi[O<3ogb]l`?oOZgb0on1[_44ohB_l@CoQ[3a0_n8/O03oec;mP;oElca1Oo1c^@0
1?o0cNCo]J_?okF[coneZll4ok:Vc@04ojjQb_nQQkSoXHNhoj67^0CoWH:f0onKO[<3oiQj/0CoUWN^
1?nEMJ`3oiEcZP?oUG:X0_nFL:H00on>K:OoSf^Vohm[YP02ohm[YP?oSfZT0ol000001?n>J:?oS6JQ
ohaVXOn<IZ44oheVX0?oSfNP1?n@J:04oi9[XPCoTfjU1?nDLJT2oiMf[0;oMn?Z0_mnGj@3ogiTZ`Co
R76c0_nLP[L00om`_?goUk;ZoiNbjP02oiNbjP;oZJ[G0on_RZh00on/PZSoW7RZoiahZP04oiI_Y0Co
Tf^Q1?nFK9l3oiY^W`GoW72O0onMLJ05oj=iY@?oXWNS1OnQMZ83oj5eXP03okZO_OndTkGo]9>e00;o
]9>e1On_S;000on/Qjooc]?NolkCgP02olkCgP04ol:bbomAaZ;oDLJRoe76XP?oY8Ne1?nNRkl00onZ
R[?oY8VhojB9^002ojB9^0CoWhg10onKULd00onYV/KoY9g>ojBMcP03ojBMcPCoXJ?F0_nNZ]l2ojJU
e@?oY:WK00Co0000ojBYfonR[^3oXZkP0_nW/Ml5ojJdhP?oYKOU00?oZ;WUojNkionW^nL00onW^nL3
ojNmj@03ojVoj_oooooooooo013ooooo00?o0000ooooool000007_ooool001_ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo0om_[?H3og6/mP?oM:ce1?mf[O@3
ogV]l`?oO:gc0omn[O83oh6^l@;oQ:oa1?mQa_`3oek9nP;oG<_f00?o^Nodol7>i?o1c^@01?o1c^@0
0ong/=;o]J_?okF[c`03okF[c`;o/ZK=00?oY8bloj67^?nQQkP00_nQQkP4oif2]P?oVgjc1?nHN[03
oiIg[PCoUGF/0onELjX2oiEbZ004ohi]ZOn>K:OoSVbWohi/Y`CoSf^V00?oSfZTo`000?l000001?n>
J:<4ohaVX@?oSFJP0on?Ij04oi1XX0CoTV^R1?nCKZD3oiAaZ@;o/ngg0_n6HJ03ogiOY0CoOVB[0on8
LK<4oib2]`Co[8^c0_n_RZh2oj61/@?oW7RZ1?nFKj@4oi=[X@CoUVbO0onJKYl5oia`W`;oWG6P00?o
YWjXoj=iYOnSNJD00onSNJD3oj9gX`GoXGJR0_nQMJ83okZO_@Co]9>e0on_S;000onho=goc]?NolkC
gP02olkCgP03oi9i/on[QjkoZhN^00;oZhN^1?nTQkD2oij;_`?oZXZc0onTRKP5oin=`@04oi^EcOnY
V/KoZI[6ojVJaPGoY9g>0_nQXmH00onYX]3oYZGEojJUe@03ojJUe@?oY:WK00?o0000ojNagonW/Ml0
0onW/Ml4ojJdhP03ojFgiOnX^NGoZ;WU00;oZ;WU1?nW^nL00onW_NWoZKoZojVojP02ojVojQCooooo
00?o0000ooooooooool06oooool001_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00?ooooo1?m^ZoH3of^^n0?oJK;j0omX]O`3ofJio@CoIKcm1?mT`?h3of;3o@;oHLKl
0on;kNH3okW_m0Go`LkT1?ng/=83okF[c`03ojNB_onTS;coY8bl00;oY8bl1?nQQkP3oif2]PCoVgjc
0onHN[03oiIg[P;oUGF/0_n?L:/3ohi^ZP?oSVfY1?n>K:L01?n?JjKo0000o`000?l00003ohmZY0?o
SVRS1?n<IZ43oheVX0?oSfNP1?n@J:05oi9[XP?oTfjU00CoU76Yok?]monckOOoSFFO0on6HJ04ogiO
Y0?oOVB[0on8LK<5oib2]`;o[8^c00?oXhRgoj61/OnQPK400_nQPK44oiahZP?oUVnT1?nCJj44oiI/
W`?oVVjO1OnLL9l01?nMLJ3oYWjXojInZ?nVOZP4oj=iY@?oXWNS1OnQMZ800onQMJ;o^YnmokZO_@02
okZO_@Co]9>e00?o[hb`okSlgOnho=d00_nho=d00oo>dmkoVGFYoiUeZ@05oj^7[PCoY8Ne00?oWX^o
ojZ:/onZR[<00_nZR[<3ojB9^0CoWhg100?o[iW1ojVJa_nYV/H00_nYV/H4ojBMcP03ojjRc?nYX]3o
ZJ;@00;oZJ;@1OnVYMD01?nTZM_oZZoLo`000?nZ[m`5ojNag`;oY[CR0_nY^>@5ojRii@;oYk_W0_nZ
_nT3ojVojP03oj[1jooooooooooo01?ooooo00?o0000ooooooooool06_ooool001_ooooo00Go410@
oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo00Gooooo1?m^ZoH3of^^n0?oJK;j0omX
]O`3ofJio@;oIKcm1?mAaO@2odG2j@;oJMcT0onJko@3ok_Ym0Go`LkT00?o^[CDokN`d_ng/=801?ng
/=801?neZlooYi:oojNB_onWT[l3ojB<_0CoXHNh1?nMP[H3oi]n/`;oV7Z`00CoTWB^oi1a[?n@LJco
T76/1?n?L:/3ohi^ZPCoSVfY00CoSVbWo`000?l0003o00000_n?JjH4ohmZY0?oSVRS1?n<IZ43oheV
X0CoSfNP0on@J:05oi9[XP;oTfjU0oo2enT2oheUW`?oQV6P1?mnGj@3ogiTZ`CoR76c1?nLP[L00on/
Rk?oXhRgoj>8]`04oj61/@CoW7RZ0onFKj@4oi=[X@CoUVbO1?nJKYl3oia`W`03ojR3[OnVOZSoYWjX
00;oYWjX1?nSNJD4oj9gX`?oXGJR00?o`kG=okZO_OnjWkd00onjWkd4okBC]@GoWgFS0onIMJT5oj^7
[PCoY8Ne1OnZR[<4ojB9^003oin=`On_VL7o[iW100;o[iW11?nYV/H01?nTWLko[Z;<ojjRc?n^X/`5
ojVRd0;oYZGE0_n][mT3ojZ_g004o`000?nZ[mcoYk7OojNag`;o[;SR1OnY^>@2ojRii@;oZkkX1OnZ
_nT01?nY_n[oZ/7[oj[1jonZ`N/Dooooo`03o`000?oooooooooo01[ooooo000Kooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2o`0000Oooooo0_m^ZoH2ogN_mP?oL[Kj1Om/^od3ofG0oP;oG<Ck
0_mMco<3ogkQm`?oY>_j0onkh_<00onkjOCo`LkTol7>i004ol7>i0?o^[CD1?ng/=800on[V<?oYi:o
ojNB_`02ojNB_`?oY8bl1?nQQkP4oif2]P;oVgjc00CoTgN`oi9d[_nBM:koTWB^0on@LJ`4ohm`Z`Co
SVjZ00CoSVfYo`000?l0003o00000_n>K:L3ohm[YPCoSfZT1?n>J:<3ohaVX@?oSFJP1?n?Ij04oi1X
X0CoTV^R00CoTfjUol;GjOo2enWo`]OY0on=IIl4ohIQX0?oOUnT1?mnI:/3ohQa/`;oW8:g0_nLQ;P4
oj>8]`?oXH6a1?nLN:X4oiI_Y0?oTf^Q1?nFK9l4oiY^W`;oW72O0_nXPjd4ojInZ0CoXgVU1?nRMj<2
oj5fXP?o`kG=1OnjWkd2okBC]@03ojAgXOnOMJ?oWgFS00?oWgFS0_nIMJT2ok29[0GoZhN^0_nTQkD2
ok6?/PGoZXZc0_nTRKP00ondW<3o[iW1ojnI`@03ojnI`@?oZI[600?o/jK;ojjRc?n^X/`00on^X/`3
ojVRd003ok6af?n][mWo[JoI00?o[JoI0onZ[m`00ol0003o[;SRojbhhP03ojbhhP;oZKST0_n/_nP5
oj^nj0;oZ[oY0_n[`^/5oj[1jaCooooo00?o0000ooooooooool06Oooool001_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo00Oooooo1?mg[oH3og:fnP;oK;_m1?mjbOl2
ofk?o@CoS=gn00?oO^7gojC[n_nTjoX01?nkh_<3ol7=h`?o`LkT0_nk^=H4okZde003okN`d_n[V<?o
ZiS300;oZiS30onWT[l4ojB<_0?oXHNh0_nMP[H2oiIj/P?oTgN`1?nBM:h3oi1a[0?oSg2[0_n>KZX3
o`0000;oSVfY0on>K:L4ohm[YP?oSfZT1?n>J:<3ohaVX@?oSFJP1?n?Ij04oi1XX0?oTV^R0onn_m/0
0oo2enWoTFNOoheUW`03oheUW`?oQV6P0omnGj@4ogiTZ`;oR76c00?oU7Vboib4^?nLQ;P00_nLQ;P4
oj>8]`CoXH6a0onLN:X4oiI_Y0?oTf^Q1OnFK9l3oiY^W`03oia`WonXPjgoZ8>]00;oZ8>]0onVOZP5
oj=iY@?oXWNS00?oXGJRol>ecOo3]Ld00_o3]Ld5okZO_@03okBC]OnTMj7oY7NQ00GoWgFS00CoVGFY
ok29[?n`RJco/8V/1On[Qjh01?nTQkGo/Hnbok6?/_naSk85ojZ:/`04ojB9^?ndW<3o]9c0okBL`0Go
[iW100CoZI[6ok>VboncY/_o/jK;1?n^X/`00onYX]3o/K7Hok6af002ok6af0Co[JoI00GoZZoLojjj
h_n^^^;o[[[Ro`000003ojbhhP03ojk1j?n/_nSo[;oX00?o[;oX0_n[_^P3oj_3j`CoZl;[0_nZ`N/2
oj[2jaCooooo00?o0000ooooooooool06Oooool002Gooooo00?o0000ooooooooool02?ooool2ogN_
mP?oR;Kd1?n3`?/2og[9o`CoUMCm0_n<gOh2ojWRnPCo^m[`00?o^n;col7=hoo1cN<00oo1cN<00oo1
c^Co^kSFok^heP02ok^heP;o^[CD00?o[Yk7oj^H`on[V<<00on[V<<4ojNB_`?oY8bl0_nQQkP00onH
O[CoUWZboiIj/P02oiIj/PCoTgN`0onBM:h3oi1a[0;oSg2[0ol00002ohi^ZP?oSVfY0on>K:L4ohm[
YP?oSfZT1?n>J:<3ohaVX@?oSFJP1?n?Ij04oi1XX003oi9[X_nn_m_o_[oK00?o_[oK0_nAIil4oheU
W`?oQV6P0_mnGj@00onAK:CoTG6[oi5aZ`02oi5aZ`CoU7Vb0onLQ;P4oj>8]`CoXH6a0onLN:X4oiI_
Y0?oTf^Q1OnFK9l2oiY^W`03ojR6/OnXPjgoZ8>]00?oZ8>]0onVOZP5oj=iY@;oXWNS00?oc=_Uol>e
cOo3]Ld01?o3]Ld2okZO_@;oZWfR0onTMj45oimeX`Co/8V/1?n[Qjh00onmW;Oo/Hnbok6?/P02ok6?
/PCoZXZc00?o_JK2okBL`?ndW<000_ndW<04ojnI`@03okb`c_ncY/_o/jK;00;o/jK;0on^X/`00ong
]mWo/K7Hok6af004ok6af0;o[JoI0_nb_^<3ojjjhP03o`000?n^^^;o[;SR00?o[/7X0on/_nP2ojc6
k@GoZl?[0_n[`^/2oj[3k0CoZ/;[4_ooool00ol0003oooooo`00000Jooooo`009Oooool00ol0003o
ooooooooo`0:ooooo`CoR;Kd0_n3`?/3oiW8n0;oUMCm1?n/eoH00onYh_[o^m[`ok_Jl002ok_Jl0;o
`<_S1?o1cN<2okfkf0?o^kSF00?o/JC;ojjNaon^W/L00_n^W/L4oj^H``CoYi:o0_nTS;`01?nKP[So
V7jdoiQn]?nHO[@4oiIj/PCoTgN`0onBM:h2oi1a[0?o00000_n?L:/3ohi^ZP?oSVfY1?n>K:L3ohm[
YPCoSfZT0on>J:<4ohaVX@?oSFJP0on?Ij03oi1XX003ojn/eOnn_m_o_[oK00?o_[oK0onAIil4oheU
W`;oQV6P00CoTf^Qoi5/Y?nAK:CoTFbT1?nALJ/4oiAi/PCoW8Bh0onSR;L4oj61/@CoW7RZ0onFKj@4
oi=[X@CoUVbO00?oVVjOojR6/OnXQ[401OnXPjd4ojInZ0CoXgVU00CoXWNSolcKiOo<fnGoc=_U1?o3
]Ld00onWO:CoZWfRojYmXP02ojYmXPCoY7NQ0onOMJ<00onhTJko/8V/ok29[003ok29[0;oZhN^0onm
W;L4ok6?/P;oZXZc0onmY/84okBL`004ojnI`Onl/<ko_;3>okb`cPGo/jK;00Co[Z;<okNgfOng]mWo
]kOI1?na/MP00onda^Oo/[kSok:nh`03ok:nh`;o[[[R00?o[lG[o`000?n^`NP01?n^`NP00on/_nSo
[<K]ojc6k@02ojc6k@;oZl?[0_nZaNd5oj[3k0;oZ/;[0_nY`^`Dooooo`03o`000?oooooooooo01Oo
oooo000Uooooo`;o00003?ooool2ohRfm0;oVkg_0onIb?P3ojc<l0?o[=Of1?njd^`00onkf_3o`<_S
ol3;h`02ol3;h`03ol7=honm^mSo_K_H00?o_K_H00Co^kSFok6TbonaY<_o/JC;0on^W/L5oj^H``;o
Yi:o00?oWXNkoi^2^?nKP[P00_nKP[P3oiQn]0CoUWZb0onCMk03oi9d[P;o000000?oT76/ohm`Zon?
L:/00_n?L:/3ohi^ZPCoSVfY0on>K:L3ohm[YPCoSfZT0on>J:<4ohaVX@?oSFJP0on?Ij000on@J:3o
[jcEojn/e@02ojn/e@?o_[oK00CoTf^Qoi5WWonAIiooTFNO0_n=IIl2oiAZW`?oTf^Q1?nAK:@4oi5a
Z`?oU7Vb1?nLQ;P4oj>8]`?oXH6a1?nLN:X3oiI_Y0CoTf^Q0onFK9l00onOP[CoZ8JaojR6/@02ojR6
/@CoZ8>]1?nVOZP3oj=iY@;oV_?J1?o<fnD01?o3]LgoYgbTojMlY?neRJL4ojYmXPCoY7NQ0_nOMJ<3
okRA[PCo/8V/00?oZhN^okfL]onmW;L00_nmW;L4ok6?/P03ojZ:/onmY/;o_JK200;o_JK21?ndW<05
okb`cP?o/jK;00?o^/;OokNgfOng]mT00ong]mT00ona/MSo]<KWokC6i`02okC6i`?o/[kS00?o/<_^
ojo5jon_aN/00_n_aN/00ol0003o[/7Xojk1j002ojc9k`Co[<K]00?oZLO_oj[5kOnZaNd00onZaNd2
oj[3k0;oZL?]1OnY`^`Cooooo`03o`000?oooooooooo01Oooooo000Tooooo`03o`000?oooooooooo
00gooooo1?nK_Nl00onIb?So[<c`ojc<l003ojc<l003ojcGm_njd^co^];/00;o^];/0_nobN83ol3;
h`?o_KkJ0onm^mP00ondZloo/JC;ok6Tb`02ok6Tb`Co[Yk70_n[V<<2oj6=_`CoWXNk0onKP[P3oiQn
]0CoUWZb0onCMk03o`000004oi9d[_n@LJcoT76/oi1a[0?oSg2[1?n>KZX3ohi]Z@?oSVbW0on?JjH4
ohmZY0?oSVRS1?n<IZ43oheVX0;oSfNP0_nNW=85ojn/e@03okjofonCJj7oTf^Q00;oTFNO00?oT6NO
oiAZWonDJYl00_nDJYl3oi=[X@CoTFbT1?nALJ/4oiAi/P?oW8Bh1?nSR;L3oj61/@CoW7RZ0onFKj@4
oi=[X@04oiI/WonOP[CoWh:doin2]0CoZ8Ja1?nXPjd4ojInZ003oj=iYOnJlm[oV_?J00?oV_?J0_o<
fnD00on]Oj;oYgbTojMlY003okF9Y`?oZWfR1?nTMj400onOMJ?o^96^okRA[P02okRA[PCo/8V/1Onm
W;L4ok6?/PGo_JK20ondW<02olC4fPCo_;3>00?o/jK;ok[2gonj`]l00_nj`]l3okNgf@;o]]?_1?nd
a^L00onb_^?o/<_^ok3;kP02ok3;kP;o[lG[0_n[c_800ol0003o[<W_ojc9k`02ojc9k`03ojc6kOnY
anooZLO_00;oZLO_0_nZaNd3ojS5kPCoZL?]0_nY`^`2ojO1k1Cooooo00?o0000ooooooooool05_oo
ool002Cooooo00?o0000ooooooooool03_ooool2oi^mk`CoZl7Y0_n/c?03okS;j003ok[Bk?nobN;o
_lWR00?o_lWR00?o`<_Sokfnf_nm_]X00onm_]X01?nm^mSo]:_?okB[condZll3ok6Tb`?o[Yk700?o
YI?3oj6=_onQSKl00onQSKl3oij7^`?oVh:h0onHO[@4oiIj/P?o000000CoTgN`oi9d[_nBM:koTWB^
0on@LJ`3ohm`Z`CoSVjZ0on>KJT2ohi/Y`04ohYd]_n:MkSoRWNhohYg^0CoRWZl0on9OL44ohR2a`?o
THk=1OnNW=83ojn/e@04ohUSX?n<I9ooS6BOohaTW`?oT6NO1?nDJYl4oi=[X@?oTFbT1?nALJ/4oiAi
/P;oW8Bh00?oXi_=oiREconHULl00_nHULl3oh^5b0CoQGZo0on9M[P4oi5j]PCoWh:d1?nXQ[45ojR3
[@;oYWjX00?oSEjFok22Xon`PZ<00on`PZ<4ojeoXP03ojMlY?neRJOo]HVW00;o]HVW0onZOJ84ojAg
X@Go^96^1?n`RJ`00oo>^LKo_IbgokfL]`03okfL]`;o/Hnb0_o6^Lh5okfV`P04okBL`?o4a=[oa<CJ
olC4fP?o_;3>0_nme^`5ok[2g`03okNgfOnfdnoo]]?_00;o]]?_0_nda^L3ojcCm0;o/<_^0_nWdoL3
oj_>lP04o`000?n[c_;o[<W_ojc9k`?oZ<[a0_nYanl2ojO6l0GoZ<G^0_nY`nd2ojO2k@CoYl7/5?oo
ool00ol0003oooooooooo`0Eooooo`009?ooool3o`0000oooooo1?n[`NT2okK3i0?o^<_X0onna^43
oko9hP;o_/3K1?nm_]X00ong/M?o]:_?okB[c`02okB[c`Co/JC;00Co[Yk7ojFC`onUTl?oYI?31?nQ
SKl3oij7^`CoVh:h0onHO[@3o`0000CoTgN`0_nBM:h01?n>MK;oSGBbohed/_n=M;87ohac/P?oRgBd
0on:M;H4ohYg^0CoRWZl0on9OL44ohR2a`?oTHk=1OnNW=800on_[=GoRF>PohUSX003ohaTW`?oT6NO
1?nDJYl4oi=[X@?oTFbT1OnALJ/2oiAi/P03ojVF`_nSVlgoXi_=00;oXi_=1?nHULl3oh^5b0CoQGZo
0_n9M[P5oi5j]PCoWh:d0onXQ[45ojR3[@03ojInZ?n=GYKoSEjF00Go/8:S1?n]Oj85okF9Y`CoZWfR
0onTMj46okRA[P;o/8V/0_o>^LH5okfL]`04ok6?/_o6^Lkoa[W>olJicPCo_JK200?ob>c]olC4f_o4
a=X00oo4a=X00onl/<ko_MK/okgFk002okgFk0;o^/;O0on]hoT2okKCk`?oXmck0_n/do@2oioGn`Go
Ym?g0_n[c_800onUc?Co0000ojS:l@03ojS:l@03ojG7lOnWa_3oYlK`00?oYlK`0_nXaNh2ojK2kPGo
Yl;]0_nW`N`2ojK0k1;ooooo0_l00009ooooo`Co000000?o410@ooooooooool01oooool002Cooooo
00?o0000ooooooooool04?ooool00on[`NWo]/?TokK3i003okK3i003okS;j?nna^7o_/KQ00?o_/KQ
00?o_lWRokk0fonn`=/00_nn`=/00onm_][o]k7CokNad`02okNad`Co]:_?0_naY</00onXV/SoYI?3
ojFC``02ojFC``CoXHfo1?nNQk/3oi^2^0?o00000_nFN[800on@N;GoSgJcohmf/`02ohmf/`?oSWFb
0on=M;87ohac/PCoRgBd0on:M;H3ohYg^0CoRWZl0on9OL44ohR2a`?oTHk=1?nNW=84ohUSX0?oS6BO
1?n@Iil3oiAZW`CoTf^Q0onAK:@5oi5aZ`04oiAi/_nYU/;oZIK2ojVF`P?oXi_=1?nHULl3oh^5b0Co
QGZo0on9M[P4oi5j]PCoWh:d1?nXQ[43ojR3[@04ohmNU?n=GYKoSEjFok>5Y0Go/8:S1?n]Oj85okF9
Y`CoZWfR0_nTMj42ol6O]PGo^96^00Co/8V/oljia_o>^LKoc[W61?nmW;L00oo=iNWoa[W>olJicP03
olJicP03okfV`_o8k>gob>c]00;ob>c]0_o4a=X3ojS/n@;o_MK/0on4i_<2ojgSn@CoRmgn0_nSg?/2
oi3Go`CoWmOk0_nWdoL2oj3=m`CoYLcd00?o0000ojS:lOnUao400onUao42ojO6l0;oYL?^1OnV`^h2
ojO2k@OoY/3/4oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo0009oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooo
oooo01;ooooo0onf`n@2okg4g`Co_/KQ0_nn`]d3okk0f`;o^KOG1?ng/M<3okB[c`03ojbRcOnXV/So
Z9[800;oZ9[80onUTl<5oj6=_`?oWXNk0ol00003oi5k]`?oT7Re1?n?M[<4ohie/P?oSGBb1_n<Lk84
oh]d]0?oRWBf0on:MkP4ohYj_0?oRGg11?n8P/L4oi6>c@04oijLd_n8HZ7oR6:QohQRX@?oRF>P0on<
I9l4oi1WW`?oU6ZO1?nCJj44oi5/Y0?oTG6[00?o[92iojVF`_nYU/800_nYU/84oj>Kc@CoV9G?0_n;
QLP4ohEj_`?oRGJh1?nAN[H4oin2]0CoZ8Ja00GoZ8>]ohmNU?n?GYCoSejDoheNUP03ok>5Y0Go/8:S
0_n]Oj82om:b^PCo]HVW1?nZOJ801?nTMj7o`Infol6O]_o1WkH5okRA[PGoc[W60_nmW;L3olgUj@?o
a[W>0omHc:X2olS/k@?o?L2o0_nXk?T3obff_`;oQ>Kc0omSd?L2oh_MoP?oP]7o1?n@eol2oioGn`?o
V/ci0onPcOL2ojG<m004oj;7lol0003oX/Ocoj;7l`;oYLOa0_nT`^l4ojG3kP;oY/;^2OnV`>`2ojJo
jaCooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`002Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool0
0ol0003oooooooooo`0Cooooo`03okK3i?nma=oo_LCO00;o_LCO00?o_/KQokk2gOnn`]d00onn`]d0
0onn`=_o^KOGokVge`02okVge`Co]k7C00Co]:_?ojbRcOn/X/go[:;=0onXV/P4ojFC``CoXHfo0ol0
0003oi=o^PCoTG^g0on@N;D3ohmf/`CoSWFb0on=M;87ohac/P?oRgBd0on:M;H4ohYg^0CoRWZl0on9
OL44ohR2a`;oTHk=0_n:IJ83ohQRX@?oRF>P0on<I9l4oi1WW`CoU6ZO0onCJj44oi5/Y003oi5aZon/
T;Wo[92i00;o[92i1?nYU/82oj>Kc@03ohIJUon;H9_oRf2K00;oRf2K0onCJIh4ohEj_`;oRGJh1OnA
N[H3oin2]0;oZ8Ja0_nBHI@4ohmNU004oheNU_ncQJCo/hFTok>5Y0Go/8:S00Co[GnRom:b^_oB/[[o
d[:j1OneRJL3ojYmXPCo`Inf1?nhTJh2om?oe`Coc[W600?o_IbgolgUjOo=iNT00_o=iNT00oo6^Lko
Si_KohnKf`04ohnKf`?oLJcf0_m6/OP2ohbViPCoOkSh1?mgaOh2oh;Ao`?oT/7f1?nCb?T2oi[<n@;o
WL;b1OnOaO<2oj;7l`03o`000?nS`NkoY<;_00CoY<;_0_nU`nh2ojFok0KoY/3/1onV_n/Cooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool000Wooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool05Oooool3okg4g`?o
_lCN0onn`]d00onl_M_o^KOGokVge`04okVge`;o]k7C00?o[jWBojbRcOn/X/d00_n/X/d4ojRJb0;o
YI?300?oVhk5oiR8`OnHR<400_l00004oiJ3_@?oTgnj0onANkL3oi1h]@CoSgJc0on>MK83ohed/POo
S7>b1?n;M;@3ohYd]P?oRWNh1?n:N[`2ohUm`@;oH=;b00CoSVbWoheXY?n=J:CoSFRT0on:IJ83ohQR
X@?oRF>P0on<I9l4oi1WW`CoU6ZO1?nCJj43oi5/Y0Go[92i1?nYU/83ohIJU`CoRf2K0onCJIh3oi]_
WP04ohEj_on9M[SoRGJhohUf^0CoTGZf0_nOP[@2oiMTU@?oTV6D1?n?GY@4ok>5Y0Go/8:S00Co[GnR
om:b^_oB/[[od[:j1OneRJL2ojYmXP;od/G>1?o1WkH2okRA[PCodooG0_o>^LH2oi>4`003o`000?o=
iNWocNGY00?oXiC51?n?Vm/00onWU/?oVi_Boi^KdP02oi^KdPCoS:KV1?mo^?P2ogO5oP;oTkK_1OnB
`OH2oi?8n@;oVk_^1?nM`_82oio5l`;oXKg]0onS`Nh01?l0003oXl7^ojC2konT`^l2ojBnj`GoYKo/
0_nV`>`2ojJnj`WoY[o[4oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo
0009ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05ooooo`?o0000
5_ooool00onma=oo_lCNoko4gP03oko4gP04okk2gOnl_M_o_;gKokbmf`Co^KOG00?o/[7GojnYd_n_
ZM800_n_ZM84ojbRc@;oZ9[800?oWiG:oi^>aOnKS/D00ol00002oiR8`@CoUX>m0onCOkX3oi5k]`?o
T7Re1?n?M[<3ohie/P?oSGBb1on<Lk84oh]d]0?oRWBf0_n:MkP3ohbnm`?oQM3o1?n>K:L3oheXY0?o
RVFR0on8HZ44ohUSX0?oS6BO0on@Iil4oiAZW`CoTf^Q0_nAK:@2ojb</`Co[92i0onYU/801?n5F9Co
QUZGohIJUon6FYL4oh]PV`?oTfVN1?nKKih3oie^V`;oTGZf0_nKJYP4oiMTU@?oTV6D0on?GY@00on_
QZWo/hFTok>5Y002ok>5Y0Go/8:S1?oB/[X5okF9Y`04ojYmX_oBaLkod/G>om;5cPCo`Inf00Co^96^
oj:7]oneS:_o]Hb[1?nUQ;400onCQ<3o/I>hok6C^002ok6C^0CoXiC500CoSi_KojNF`onWU/?oYiK3
1OnKVm82ohbViP03ojBTeOnK[>?oVjcS00;oVjcS1OnC]^l2oi;1mP;oWK?X1OnK^nh2oig2lP;oX[[Z
1?nQ_Nd2oj?1kP03ojBlj_l0003oY;cZ00CoY;k[0_nU_n`2ojJmjPGoY[k[0_nV_n/2ojJnj`GoY[o[
4Oooool3o`0000Oooooo00?o0000ooooooooool02Oooool000Wooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool06?ooool3oko4gP;o_LCO
1?nl_M/00oni]mOo/[7Gok:ae`02ok:ae`Co[jWB0_n/X/d00onRW<ooWiG:oinEbP03o`0000;oVhk5
1?nHR<43oiJ3_@?oTgnj1?nANkL3oi1h]@?oSgJc1?n>MK83ohed/PKoS7>b0_n;M;@2oi2Rh@CoSZk/
1On<__L00on5d?ooTG6[oi5aZ`03ohi/Y`?oSFRT0on:IJ83ohQRX@CoRF>P0on<I9l3oi1WW`CoU6ZO
1?nCJj401?nAK:Co[8bcojb</on/S;<5ojb@^@03ojVF`_n5F9CoQERD00CoQUZG0on;H9/3oi=YWPCo
VfnN1?nMKY/3oi]ZV0CoUfBE0onBHI@2ohmNU0?o[hJY0oncQJ@5ok22X`03o`000?oB/[[od[:j00;o
d[:j0oneRJL00on4ilGod/G>om;5cP02om;5cP?o`Inf00?o[hR/oj:7]oneS:/00_neS:/4ojF4/@Go
/I>h0onSU<D00oncV;coYiK3ojNF``03ojNF``?oVi_B00?o[J7;ojBTeOnTY=D00_nTY=D4oi^/h`;o
TkK_0onQ[=l4oifcj0;oVk_^0_nR]NH5oj:jjP;oXKg]0_nT^NL2ojBljP03o`000?nT_>[oY;cZ00;o
Y;k[0_nV_>T4ojJmjP;oY[k[0_nV_NX5ojJnj`;oY[o[0_nW_n/>ooooo`Co000000?oooooo`000?oo
ool01_ooool00ol0003oooooooooo`09ooooo`002Oooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03oko4g_nma=oo_LCO00;o
_LCO0_nl_M/00one^]go/[7Gok:ae`04ok:ae`;o[jWB00?oYZGDoj:LconRW<l00ol00002oinEbP?o
Vhk51?nHR<44oiJ3_@?oTgnj0onANkL3oi1h]@?oSgJc1?n>MK83ohed/P;oS7>b00CoSi;Boi2If?n@
VMSoT9WH1On@X^44ohj^k0;oS;kg0_nFNK03oi5aZ`?oSVbW0on=J:@3ohYUXP?oR6:Q1?n9Hj03ohaT
W`?oT6NO1?nDJYl3oi=[X@03ojV8/_n/S;?o[8bc00;o[8bc1?n/T;T01?n8FI?oQERDohEHU?n5F9@4
ohIJU`?oRf2K1?nCJIh3oi]_WPCoWFjK0onKJYP4oiMTU@?oTV6D00?oSejDojn6ZOn_QZT00_n_QZT4
ok>5Y0?o/8:S00?o/8JXo`000?oB/[X00ooB/[X00oneRJOoQ>O5ohCWa@02ohCWa@Cod/G>00?o`Inf
ojn8[?n_R:`01?neS:/4ojF4/@03okbJ]OnaTkSo/I>h00?o/I>h00CoXiC5ok>H_?ncV;co/iRl1?nW
U/<00onKVm;o[J7;ojfQb`02ojfQb`CoY:CE0_nK[><2ojNWePGoXJcO0_nM/nP2ojJah0CoX[GV0_nR
^^X2ojJfi0GoY;WW0_nT_>X00ol0003oY[[WojJlj@04ojJlj@;oY[gZ0_nW_>T4ojJmjP;oY[k[0_nW
_^X5ojNoj`[ooooo0ol00005ooooo`03o`000?oooooooooo00?ooooo00?oEEEEofIVI_l000002ooo
ool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1Oooool2o`0001_ooooo0onma=l00ong`n?o]K[MokFjg@02okFjg@Co/[7G00?oZJgKojJUe?nVYM@0
0ol00002oj:Lc`?oWiG:1?nKS/D3oiR8`@CoUX>m0onCOkX2oi5k]`CoS8K80on<QlT4ohf9b`?oSXg>
1?n?T]83oi2If0GoT:;Q0_n>[^`2oh]YY`?oQfFT0on4HZ<3ohi/Y`?oSFRT1?n:IJ83ohQRX@?oRF>P
0on<I9l4oi1WW`?oU6ZO00?oTf^QojV8/_nYR;800_nYR;84ojb</`;o[92i0_n8FI<3ohEHU0CoQUZG
0on;H9/4oi=YWP?oVfnN1?nMKY/3oi]ZV0CoUfBE0_nBHI@00onVQK7o[hJYojn6Z@03ojn6Z@Co/hFT
0_n`PZ<2ok26Z004ojf7[_niRjGod[:jom:b^PCoYgZR0_nKLjD2om;5cP03okfBZ_n_R:co[hR/00;o
[hR/1OneS:/2ojF4/@;o_9Ze1OnaTkP4ok>H_0?oYiK300?o^:C5ojfQbon]XL/00on]XL/2ojBTe@;o
[jK?1OnWYmH2oj6/g`;oZZkJ1OnV/N02oj:eiP03ojRchOnV]^CoY[KT00?oY[KT0_nT^NL2ojNii@?o
Y[[W00Co0000ojJjionV_>WoY[cY0_nW^nP5ojNlj@;oY[gZ1_nW_^X4ojNoj`Kooooo1?l00008oooo
o`03o`000?oooooooooo017ooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnH
V9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool06oooool01?nma=oo]l?SokO3hong
`n<4okFjg@03ok:aeonY[M_oZJgK00?o00000_nVYM@4oj:Lc`?oWiG:0_nKS/D01?nBT]3oT8k=oi2>
cOn@S/d4ohj:b`?oS8S91on<Q/P3ohb7b@CoSHW;0on>SLh3ohnBdPCoT9WH0_n@X^42ohm_ZPCoRfVW
0on7IJ@3ohARX`?oQ66R0on=J:@4ohYUXP?oR6:Q0on9Hj03ohaTW`CoT6NO0_nDJYl00onTQK?oZHRb
ojV8/P03ojV8/PCo[8bc00Co[92iohQITon8FI?oR5VC0on5F9@4ohIJU`CoRf2K0onCJIh3oi]_WPCo
WFjK0onKJYP4oiMTU@03oi9QU?nVQK7oYXFa00Go[hJY1?ncQJ@01?n`PZ?o/8JXok26Z?n`QZP4okV;
Y@CoYgZR00?oVg>UokfBZ_nmTZX00_nmTZX3ojn8[0;o`i^`1?neS:/01?nUQ;7o_9ZeokbJ]OnlV[D4
ok6C^003ol6S^oncV;co/iRl00?o/iRl00CoYiK3okRTaOnhY<Go^:C51?n]XL/5ojnVc`?oYjOF00?o
/:kFojZ^f_nZ[]X00onZ[]X3ojJah003oj^bgOnX/n7oZ;?Q00;oZ;?Q0onV]^@00onY^>?oYkWUojNi
i@03ojNii@;oY[[W00?o0000ojRji_nW^nP01?nW^nP3ojNlj@03ojRmjOnW_^[oYkkZ00GoYkkZ0_nX
_nX4ojNoj`;ooooo0ol0000<ooooo`03o`000?oooooooooo017ooooo000Rooooo`03o`000?oooooo
oooo01gooooo1?ng`n<2okFjg@04ojbghOl0003o0000o`0000;oZJgK1?nVYM@2oj:Lc`04oiRNf?nE
V=CoUISDoiFHe0CoTY;@0on@S/d4ohj:b`?oS8S91_n<Q/P3ohb7b@CoSHW;1?n>SLh3ohnBdP;oT9WH
0onDMZl3ohm_ZP?oRfVW0on7IJ@3ohARX`?oQ66R0on4HZ83ohASX`04ohYUX_n8HZ7oR6:QohQRX@?o
RF>P0on<I9l4oi1WW`03oiAZWonTQK?oY8Fc00GoZHRb1?n/S;<01?n<G9CoR5VCohQITon8FI<3ohEH
U0CoQUZG1?n;H9/3oi=YWP?oVfnN1?nMKY/3oi]ZV0;oUfBE0_nJQK`4ojJ5/@Co[hJY1?ncQJ@4ok26
Z0Co^H^U1?nWNZ86okfBZP04ojn8[?o3Vk3o`i^`ol>K/0Co]Hb[1OnlV[D2ok6C^0?o`J>k0oncV;`0
0oo1[LKo^:C5okRTa@02okRTa@?o[J7;0_ngZ/`5ojnVc`04ojNWe_n`[]Ko/:kFok2^ePCoZZkJ00?o
Y[7Poj^bgOn[/]d00_n[/]d4ojRch@04ojJfi?nY^>?oZKSSojVhh`CoYkWU00GoY[[WojRji_nX^^Ko
0000ojRjiP04ojNkj003ojNljOnX_NWoZ;gY00;oZ;gY0onW_^X6ojRojP;oYko[0_nX`>/00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo01kooooo
0_ng`n<2ojg1j0;o00000on/]n43ojV]f`;oYZGD00?oVjGMoiRNf?nHW]P00_nHW]P3oiFHe0?oTY;@
0on@S/d4ohj:b`?oS8S91_n<Q/P3ohb7b@GoSHW;0_n>SLh00ol0003oXHVjoiYo]003oiYo]0?oU7J_
0on?KjX3oh]YY`?oQfFT0on4HZ<3ohAQXP?oQ6:R1?n4Hj<3ohETYP?oQVVZ0on<I9l2oi1WW`;oUW^c
1?nTQK<5ojV8/P;o[8bc0_n<G9@3ohQIT`CoQERD0on6FYL4oh]PV`;oTfVN00CoYJSHoi:OgOnBWmgo
TYoM1?n6TMH3ohV6b@CoVXFl1?nVQK45ojn6Z@?o/hFT0on`QZP2oljY/`Co^H^U0onWNZ86okfBZP04
ojn8[?o3Vk3o`i^`ol>K/0Co]Hb[00?ocJjjokbJ]OnlV[D00_nlV[D00onaTkSo`J>kol6S^`02ol6S
^`;o/iRl0oo1[LH4okRTa@04ojfQbongZ/co]j[<okNZc0Co[jK?00?o]k;Dok2^e_n`[]H00on`[]H2
ojZ^fP;o/;?K1?n[/]d2ojRch@;o[;OR1OnY^><2ojNii@;oZK[U0onX^^H01?l0003oZ;[VojNkj?nW
^nP2ojRmj0CoZ;gY00?oYkkZojRoj_nX_nX01?nX_nX7ojS0ja3ooooo00?o0000ooooooooool04?oo
ool002;ooooo0_l0000Pooooo`?o00000_n]`NP2ojbgh@04oijej?nM[N;oWJgRoif]hPCoVjGM0onH
W]P3oiFHe0?oTY;@1?n@S/d4ohj:b`?oS8S91_n<Q/P3ohb7b@;oSHW;0oll_mX01?nWTl7oXHVjoj69
^_nQRKX3oiYo]0?oU7J_0on?KjX3oh]YY`?oQfFT0on4HZ<3ohAQXP?oQ6:R1?n4Hj<3ohETYP?oQVVZ
0on9Kjl4oiIk/`CoY8Fc1OnYR;801?n/S;?oS5bDohaLU?n<G9@3ohQIT`CoQERD0on6FYL3oh]PV`03
ok6Uc?nUZ=SoYJSH00;oYJSH0onBWmd4ohJAeP?oRHK91?nJQK`3ojJ5/@Go[hJY0_ncQJ@00ondRJSo
/8JXok26Z003oljY/`Co^H^U0_nWNZ82olFP/`Go_I:Z1?o3Vk03okF<Z`;ocJjj1?nlV[D5ol6S^`03
ok>H_?o1[LKo`Jg600;o`Jg60onhY<D00oo2]/oo]j[<okNZc003okNZc003ojnVcong/]Co]k;D00;o
]k;D0on`[]H00ond]m_o/;?Kok2cf`03ok2cf`;oZk;M0_n_^N44ojbghP;oZKSS0_n[^^@5ojVji@;o
Z;[V00?oZKgXo`000?nX_NP01?nX_NP2ojRmj@;oZ;kY0onX_nX:ojS0ja3ooooo00?o0000oooooooo
ool04?ooool002;ooooo00?o0000ooooooooool07?ooool3o`000003oooooon]`NSo[L7X00;oWkk^
1?nN]NP3oif]hPCoVjGM0onHW]P3oiFHe0?oTY;@0_n@S/d2oh:Xk@CoOZ_a0omj/OH4ogBjn`?oJl?n
0_mIb?L00on^W/SoYi?1ojNC`@02ojNC`@?oXHVj0onJOk@3oiAf[`?oSfnZ1?n;JJL3ohMUY0;oQ6:S
1?n4HJ83ohARXP?oQ6>S1?n5I:H2ohIYZP?oRFn_1OnFNk<3ojB5/`CoZHRb00?oT62FohaLU?n<G9@0
0_n<G9@3ohQIT`CoQERD0on6FYL00on;H9_o/JG<ok6Uc002ok6Uc0CoYJSH0onBWmd3ohJAeP?oRHK9
1?nJQK`3ojJ5/@Go[hJY00Co/hFTokB9Z?ndRJSo/8JX1?o>ZK<4okV;Y@04ojMjX_o5X;?oaJ2colFP
/`Go_I:Z1Oo3Vk001?neS:_ocJjjolf^^_o=[[X3okbJ]@;ockc71?o1Xk/6ol6]aP04okRTaOo2]/oo
`[K?ol:fc`?o]j[<00?o_;_HokNbe?ng/]@00ong/]@00on`[]Ko];OKokBgf`02okBgf`?o/;?K00?o
/[cQojnihOn_^N400on_^N42ojbghP;o[[cT1?n[^^@2ojVji@;oZkgW0onY_NP01?l0003oZKgXojRm
j?nX_NP2ojVoj@GoZ;kY00?oZ;oZojS0jonX`>/01?nX`>/2ojS1j`CoZ<3[3oooool00ol0003ooooo
ooooo`0@ooooo`008_ooool00ol0003oooooooooo`0Iooooo`?o00001_ooool3oinnkPCoW[GX0onM
[N82oi^Ug@04ohf]k?n;Z^[oRj[Zoh^ZjPCoR:SZ0on4Yn/4oh:Xk@CoOZ_a0omj/OH2ogBjn`;o`mSY
00?o/ZW?ojjNb?n^W/P00_n^W/P4ojNC`@?oXHVj0onJOk@3oiAf[`?oSfnZ1?n;JJL3ohMUY0?oQ6:S
0on4HJ83ohARXP?oQ6>S1?n5I:H3ohIYZP?oRFn_1?nFNk<4ojB5/`;oZHRb0on@H9H3ohaLU0?oR5VC
1?n5F9@2ohIJU`03ok:L`OnaYLco/JG<00Co/JG<0_nUZ=P2ohiTW@CoU6VN00CoVVjNohJAe_n9Q/Wo
RHK91?nJQK`4ojJ5/@?o[hJY1?ndRJP5oljY/`Co^H^U1?o5X;<4okfBZP03onCCaOo3Vk3o`i^`00?o
`i^`00?o]Hb[olf^^_o=[[X00_o=[[X01?nlV[Gockc7olnlaoo?_<L3ol6S^`;oclGA1?o1[LH00oo8
cMgo`[K?ol:fc`03ol:fc`04okNZc?nl^mSo_;_Hokbkf0?o]k;D0_nj`Ml4okBgf`03ok2cfonb_>7o
/[cQ00;o/[cQ0on_^N400on__nGo[[cTojjli003ojjli0;oZk[T0_n/_nP4oj^mi`;oZKgX00?oZ[oY
o`000?nY_nT01?nY_nT2ojRnj@;oZL3[1?nX`>/6ojS1j`;oZ<3[00?oZ<7[ooooooooool03Oooool0
0ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0Fooooo`?o00002_ooool3oinn
kP;oW[GX0_n@]O03ohnak@?oSJg/0on;Z^X4ohRXjP?oQ:O[1?n2Z>d2ogj[l@;oBlG/00GoY_Caol7J
k?o1f^co`M[/ol?Hj@03ok:Yc`Co[Yk81?nWTl43oj69^P?oVWnd0onDMZl3ohm_ZP?oRfVW0on7IJ@3
ohARX`?oQ66R0on4HZ83ohASX`CoQFBV0on6JJX3ohU_[`CoUW^c1?nTQK<00onYR;;oT62Foi1PUP02
oi1PUP?oS5bD0on8FI<4ohEHU004ohIJUonbW<7o/Yc1ok:L`@Co/JG<0_n9H9`3ohiTW@CoU6VN1?nJ
KYh00on9Q/WoVXFloiZ5_002oiZ5_0?oYXFa00?o[hJYokB=[_ndSJh01?ndRJP00ooGo[oocZVcoljY
/`03oljY/`;o^H^U0_oCe=T4olFP/`;o_I:Z0ooTdlD3ol>K/003omSMfoo=[[[ocJjj00?ocJjj1Oo?
_<L01?o1Xk_oclGAolo5dOo?aM43ol6]aP?ob<gM0oo2]/l00oo1cN?o_;_Hokbkf003okbkf003okNb
e?nj`Moo^/7O00;o^/7O0_nd]m/2okC2i@Co/[cQ00?o[kWQojnoiOn__nD00_n__nD3ojjli003ojg1
jOn/_nSo[;oX00?o[;oX0_n[_NL2oj_1jP?oZ[oY00?o0000ojVojOnY_nT00_nY`N/5ojW0j`03ojS0
jonX`N_oZ<7[00[oZ<7[3_ooool00ol0003oooooooooo`0@ooooo`008_ooool2o`0001Cooooo0ol0
000>ooooo`?oTKWb1?n@]O03ohnak@?oSJg/0on;Z^X2ohRXjPCoM/3m0om]a?l2of38n`?oY_Ca0oo1
f^`00onf/]Go/ZW?ok:Yc`02ok:Yc`Co[Yk81?nWTl43oj69^P?oVWnd0onDMZl3ohm_ZP?oRfVW0on7
IJ@3ohARX`?oQ66R0on4HZ84ohASX`?oQFBV0on6JJX3ohU_[`GoUW^c0_nTQK<00om/Dj?oUVNJoi1P
UP03oi1PUP?oS5bD0on8FI<3ohEHU003ojf@^?nbW<7o/Yc100;o/Yc10onaYL`3ohUPW0?oSVBM1?nD
JIh4oiY^WP03oia_WOnJQKcoVXFl00;oVXFl0_nVQK400onaU;Wo]8f^okB=[P02okB=[P;o]8VX0_oG
o[l5oljY/`04okV;YOoCe=WodmCIom?Df@CoaJ2c00?o_I:ZonCCaOoTdlD00_oTdlD2ol>K/0?of=gK
0oo=[[X2ol_ngP?ockc70_nml?84olo5d@03ol6]a_o8cMgob<gM00;ob<gM00?o`[K?ol7=hoo1cN<0
0_o1cN<2okbkf0;o^/kY1?nj`Ml00ondc>co]<;UokC2i@03okC2i@;o/[cQ0_naa>P4ojnoi@03ojjl
i?n]`NWo[L7Y00;o[L7Y0_n/_nP2oj_2j`GoZl7Z0_nZ_nT00onY`^_o0000ojW1j`03ojW1j`;oZL3[
1_nX`N/00onX`NcoZ<7[ojS1j`05ojS1j`;oZ<3[3Oooool00ol0003oooooooooo`0@ooooo`008Ooo
ool2o`0001;ooooo0ol0000Booooo`?oTKWb0_n@]O02ohNgm@?oQKSf1?n1^_P4ogbln`;oM/3m0_mH
c^l2ogKQk@?oYnog0onmf^h01?o1f^co][;EokJbeOnf/]D4ok:Yc`;o[Yk800?oWHg2oiJ4_OnFQ;d0
0_nFQ;d3oi1k^@?oRWBe0on5Kk<3oh5//P?oRfVW0on7IJ@3ohARX`?oQ66R0on4HZ84ohASX`?oQFBV
0on6JJX4ohU_[`CoUW^c00CoY8FcofaCXom/Dj?oK5>S1?n@H9H3ohaLU0?oR5VC0_n5F9@3ojf@^0Co
/Yc100?o/JG<ohUPW?n9H9`00on9H9`3ohiTW@?oU6VN1?nJKYh01?nLKigo[j38ojnPb?n_X<P4ok6D
^@Co]8f^00?o]8VXojZ9/_nZRK800_n`R:`2oljY/`03ok28[?nYQk7odmCI00?odmCI0oo5X;<00onb
T[GoX9?7o`000003onCCa@03ol>K/?oHgM_of=gK00?of=gK00?ocJjjol_ng_o;o]h00_o;o]h00oo?
_<Oo_O3bokg`lP02okg`lP;oclGA0onelo<2olS=g@;o[n?h0oo1cN<2ojcOn@Co^/kY00?o^/7OokC<
k?ndc>`00_ndc>`2okC2i@;o[l_^1Onaa>P2ojnoi@;o[LC[0on]`NT2oj_5k@CoZl;[0_n[`NX2ojW3
k0?oZL;[00Co0000ojW2jonY`N_oZL7[0_nY`^`5ojS1j`CoZ<7/0_nX`N/2ojS1k0GoZ<3[3?ooool0
0ol0003oooooooooo`0@ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`;o000000?o410@ooooooooool00oooool00ol0003oooooooooo`0?ooooo`;o00005_ooool3
ohZgm0CoQkOe0on5^?H2oh6jn0CoN/_o0_m/cod2ohCPn`CoYnOk00GoYnogokgJk_nmf^ko_M[^okRi
fP05okJbe@;o/ZW?00?oXiK7oif=`_nMSL800_nMSL83oiJ4_@?oT7^i0on:M;D3ohE_/`?oPFbb0omm
J[<3og]/]P?oQ6:S1?n4HJ83ohARXP?oQ6>S1?n5I:H3ohIYZP?oRFn_0_nFNk<00ombF:GoK5>SofaC
X`03ofaCX`;oNEnX0_n@H9H3ohaLU0?oR5VC00?oQERDojf@^?n]T;P00_n]T;P4ok:L`@KoRF2L0on>
I9d3oiAYWP;oVVjN0_nYZ=H4ojnPb0Go/IBi0_ndSJh4ojZ9/PGo/8R/0_nYQk44om?Df@03olFP/onb
T[Go/Y:e00Go]iJd00CoVXg5okJJ_?oHgM_of=gK0onNV<d00onfW/3oUiWCoiNId`02oiNId`;o_O3b
0omET>`2okGcl`?oA<CP1?n_hoP00oo1cN?o[=oiojcOn@02ojcOn@;o^/kY0_nYeOL3okC<k0;oZ=7f
1?n_bnh2ok74j0;o[<W_1On]a>/00on]`NWoZlG]oj_5k@02oj_5k@;oZl;[0_nYa>d4ojW3k0;oZL;[
00?oZ<?]o`000?nY`^`01?nY`^`2ojS1j`?oZ<;/2?nX`N`4ojS0j`gooooo00?o0000ooooooooool0
3oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00cooooo0ol0000Iooooo`?oR[Od0_n7]oD3ohRnn0CoP/Cm
0_mjbol3ohgIo`04ohCPnonWio_oYnOkojOWn`Co^]O_00Co_M[^okRif_nh^M[o^;WJ0onf/]D00onY
WlgoXiK7oj>Fa`02oj>Fa`?oWHg20onFQ;d3oi1k^@CoRWBe0on5Kk<2oh5//P?oOFZc0omkK;H3ogYa
_@CoQ66R0on4HZ83ohASX`CoQFBV0on6JJX2ohU_[`04og5EX_moIJ_oLURUog9HY@GoK5>S1?miGjP3
ohaLU0;oR5VC00?oWX2bojf@^?n]T;P00on]T;P3ok:L`@OoRF2L0on>I9d2oiAYWP03ojFWeonYZ=Ko
ZJSF00?oZJSF0on_X<P5ok6D^@03okB=[_nXQJooZ8F_00;oZXVb0_ndSJd5ok28[0;oZHNa0_noV[44
ok:B]@03ol6M/ongU[Co]iJd00;o]iJd1OnfV[`01?nNV<go]Yk0okJN`?nfW/04oiNId`;oEI3/0_nC
Wm`3ofnWl`Co4ikH0ombeoX2ojcOn@?oS=Ko1?nYeOL00ondc>coZ=7fojSAmP02ojSAmP;o[l_^0_nW
c?<4ojc9k`;o[LC[0onYanl2oj_5k@;oZ<K_1OnYa>d2ojW3k0;oZ<C]0onX`nd00ol0003oZL;/ojW2
k007ojS2k0OoZ<7/0_nW`N`4ojS0j`cooooo00?o0000ooooooooool03oooool000Oooooo00Go410@
oooooooooooooooooa0@400;ooooo`Go00001Oooool2o`0000[ooooo0ol0000Mooooo`GoS;Sc0on8
__P2oh;4o@?oT/ol0_n=fOl2ojOMnP?o]m;^0onjenl2okVngPCo^;WJ00Co][;EojVOcOnYWlgoZIo=
0onSU/L3oif=`PCoUXBm0on@NkT3ohYd]@?oQFnc0on1K;83ogeZ/`?oNfbf0_mjLKd3ogUmb`04ohAQ
X_n4HZ;oQ6:RohARXP?oQ6>S0_n5I:H00olU/;KoPF6Toh5QY002ogUIX@CoLEFR0ombF:D5ofaCX`?o
NEnX0on>L:d4oij0/PGo[I2h00?o/Yc1ogUS[On9H9`01_n9H9`2ohiTW@03oj2IcOnUYmOoYJOG00;o
YJOG1?nYZ=H4ojnPb0;o/IBi00?oY86^ojR5[onXQJl00_nXQJl01?nZRK;o]8f]okB=[OndSJd5ok28
[004ojV7/OnoV[7o_iZaoknJ/@?o/Y:e0_o1WK<4okNF]003olNU]onfV[co]YZl00;o]YZl1OnfW/02
oiNId`;o[j7:1?nCWm`4ofnWl`?oBJ_h1?mSaOd2ohcFo`;oO/[o1?nGdo`2ojSAmP;oWLgh1OnWc?<2
ojc9k`?oY/[b0_nYanl2ojK7l@CoZ<K_0_nYa>d2ojO5k`GoZ<C]0_nX`nd00ol0003oYl?]ojS2k008
ojS2k0;oZ<7/1onW`N`2ojS0j`;oYl3[2oooool00ol0003oooooooooo`0?ooooo`001oooool01Ol0
003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001_ooool00ol0003ooooooooo
o`06ooooo`?o00008Oooool2ohbhl`?oV;c`1?nFaOL2oi;?o0?oY]?g00?oYmgjokOBk_ngd^h00ong
d^h00onjenoo^KkNokVngP02okVngP;o^;WJ00?o[JOBojVOcOnYWld00_nYWld3oj>Fa`CoWHg20onF
Q;d3oi1k^@?oRWBe0on5Kk<3oh5//P?oOFZc0omkK;H3ogYa_@?oNGg;1OmhU>82offnoP04oh]/ZOn1
HJCoPF6Toh5QY0?oNEVQ0omaEJ82of=CZ`03og9HYOm/Dj?oK5>S00?oK5>S0omiGjP3ohi`[@CoWX2b
1?n]T;P3ogUS[@?oR7:d1?nCQ;l4oj2Ic@CoYJOG1?nYZ=H2ojnPb0CoY86^1?nXQJl4okB=[@Go/8R/
1OnoV[401?nbT[Go`Ifcol6M/oo1WK<3okNF]0;oajFg1?nfV[`00oo2YKco]Yk0okJN`002okJN`0Go
[j7:0_nCWm`00on[Y=7oUJORoiFWhP02oiFWhPGoNZcc0omd_Od4ogk:o`;oUm?l0onBbO/3oig=n0;o
Ylcc0onQboH2ojK:lP;oXlOc1OnVao42ojS6k`;oY/G`1?nWaNl2ojS4k@;oYl?^0onW`nd01?l0003o
Yl?]ojS2k?nX`^`3ojO2k@;oZ<;/2?nW`N`7ojO0j`[ooooo00?o0000ooooooooool03oooool000Oo
oooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000
ooooooooool00oooool3o`0002Kooooo1?nH_?02oiK5m`?oY/Sb0_nVdoL3ok?=k@;o]m;^0onh`N43
okVngP03ok6_eon]Ym;o[JOB00;o[JOB0onYWld4oj>Fa`?oWHg20onFQ;d3oi1k^@CoRWBe0on5Kk<2
oh5//P?oOFZc0omkK;H3ogYa_@CoNGg;0omhU>82oiYn/`;oRfbY0on1HJ@3ogUIX@?oLEFR0omSDj/5
ofaCX`CoNEnX0on>L:d3oij0/P?o[I2h0_m_Fj/2ogUS[@CoR7:d1?nCQ;l4oj2Ic@;oYJOG00CoRgJg
oi5f/OnAM[7oTGJa0onKO:l5ojB1[P;oZ8F_00?o]96bokB=[OndSJd00_ndSJd4ok28[003olBS]ono
V[7o_iZa00?o_iZa1Oo1WK<01?ngU[CoajFgolNU]oo7YKL3okJJ_0;o`ZFl0onfW/02ol>Z`@Co[j7:
1?n[Y=44oiFWhP;oNZcc0_nF[NL5ohbgl`?oQl3j0_nBbO/2oiG3mPGoVLSg0_nQboH2oio6l`CoXlOc
0_nVao42ojC5l@GoY/G`0_nWaNl2ojK3kPCoYl?^0_nW`nd00onW`^go0000ojO2k@02ojO2k@WoYl7/
00?oYl3/ojO0jonW`>/01onW`>/:ooooo`03o`000?oooooooooo00oooooo0007ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00omgMgOoc<c<o`000005ooooo`04o`000?ooooooooooooooo`?o
0000:_ooool2oiRll0;oYKo/0onVb?82ok77jP?o/lg]0ong`^<4okS1h@04okVng_na[mOo/JoGok6_
e`Co[JOB0onYWld2oj>Fa`04oiN=aon@Q/CoT8K4oi26a0?oRX330on4O<<3ogilaP04ohYd]On5Kk?o
QFncohE_/`?oPFbb0ommJ[<3og]/]P;oNW6m1OmiOL/01?mhU>;oN6JbogQV/_mhI[83oh]/Z@;oPF6T
0omiFJ43og5EXP?oHe>[00?o5Tk9ofaCXom/Dj<00_m/Dj<4ogUOZ0?oSW2]1?nNP;801?n]T;SoKe^[
ofmKZom_Fj/3ogUS[@?oR7:d1?nCQ;l3oj2Ic@04oh^1`on;M[OoRgJgoh]f]`?oTGJa1?nKO:l4ojB1
[P04ojR5[ondTK;o]96bokBA/PCo]8f]0_n`R:`3olBS]`?o_iZa00?ock:nol6M/oo1WK<00oo1WK<5
olNU]`03okJJ_?o2YKco`ZFl00;o`ZFl00Co]Yk0ol>Z`Oo3Z/7o`j[10on_XLX2okZYb0CoZjCA0_nE
Yn82ojN[fPCoUZgW0_n<]o<2oi^cj@CoTk[a1?nE`oH2oiW8m`;oVl;c1OnOa_<2oj?7l`;oX/Ca1?nT
aO42ojK5l0;oYL?_1OnV`nh2ojO3kP?oY/;]0_nW`^d00ol0003oYl7/ojO1k005ojO1k0KoYl3/2OnW
`>/9ooooo`03o`000?oooooooooo00oooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00oo^k^koA4A4o`000005ooooo`Co0000;_ooool4ojFok003ojK8l_naan[o/LOZ00;o/LOZ00?o
/lg]okO2hong`^<00ong`^<2okS1h@;o/[GK1?na[mL2ojfWdP04oj:MconLU<_oW9C;oibDb`CoUhg7
0on@Q/@3ohZ0``?oQ7c30omnO<H3ogQocP?oKhgO0ommJ[<3og]/]P?oNW6m0_miOL/3oh=b^0?oN6Jb
0_m^G[000on;K:WoPF6Toh5QY003ogUIX@?oLEFR1?mSDj/01?lFC/WoK5>SofaCXom/Dj<4ogUOZ0?o
SW2]1?nNP;801?m_H;7oKe^[ofmKZom_Fj/3ogUS[@?oR7:d1OnCQ;l01?nPVLgoRh73oh^1`on;PL<2
oh]f]`?oTGJa1?nKO:l3ojB1[P03ojf@^?ndTK;o]96b00;o]96b1?ndSJd00on`R:coa:>golBS]`02
olBS]`;o_iZa0oo?/[h3ol6M/`03oljf`_o7YKOoajFg00?oajFg1Oo2YK`5ol>Z`@04ojnQb_njZLSo
^ZW8okZYb0?oZjCA00?o]jg?ojN[f_nWZmX00onWZmX2oiJ]i`;oYJkN1?nK/nT4oi>jl@;oUL?f0_nK
_O04oi_2l`;oWlKc0_nP`_45oj;4l@;oY<Ga0_nT`nl4ojG3k`;oY/?^0onV`^h2ojK2k@;oY/7]0_nV
`N`01?l0003oY/7/ojO1k?nW`N`9ojO0k0[oYl3[2Oooool00ol0003oooooooooo`0?ooooo`001ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01?ooool2o`00037ooooo
0_nU_n`3ojo2i`;o/LOZ0_nf`n@4okO2h`03okBjg_nb]M_o/[GK00?o/[GK0_na[mL00onWYMCoXYg?
oj:Mc`02oj:Mc`?oW9C;0onGSLL3oi26a0?oRX330on4O<<3ogilaPCoN7o>1?m_SMl2oe>Wn004okJe
f?nVWLgoYYg=ojJMc@CoU8K10_n3L[P3ogQV/P?oKUj`0on1HJ@2ogUIX@CoLEFR0omSDj/2oaI>b@?o
K5>S0omiGjP4ohi`[@;oWX2b0_mPD:P3ofmKZ`?oNF>]1?n8L[@3oi>4_`05og]Z]?mgI;3oMfB`ogMT
/?n;PL<00_n;M[L3oi5f/@CoVgb_0_nTPJh3ojf@^0?o]96b1?ndSJd5olBS]`03oknJ/Oo?/[kock:n
00;ock:n0_o1WK<3oljf`P?oajFg00?odKW3ol:U_?o2YK`00_o2YK`00oo:]LGo`j[1ol>Z`@02ol>Z
`@03olZfaonjZLSo^ZW800?o^ZW800CoZjCAokN]cong[Loo]jg?0onWZmX00ona[mKoYJkNojF^gP03
ojF^gP;oVk?Y0_nU]><4oijhjPCoVkg`0_nK`_<2oinnkPCoX<;a0_nRa?42oj;1k`GoY<?_0_nU`nl3
ojG1kP;oY/;^00?oY/3/ojK1kOnV`Nd00onV`Nd2ojK1k003o`000?nV`>coYl3/00GoYl3/2OnW`>/2
ojNoj`CoYl3[2?ooool00ol0003oooooooooo`0?ooooo`008_ooool00ol0003oooooooooo`0_oooo
o`?o[l;W0_ne`nD4okK3i003okO2hond^]ko];[N00;o];[N0onb]M/00on[[MWoYjGDojNUe002ojNU
e0?oXYg?0onLU</3oiN=a`?oT8K40on:P<<3ohAl``CoOWc61?mhOlh2ofn=g`04ol;<h_nf]MSo][GH
okJef0?oYYg=1?nDQ/43oh=b^0;oN6Jb0om^G[02ofYP]@04oh5QY?miFJ7oNEVQogUIX@?oLEFR1?mS
Dj/01?lFC/WoW9gCogI/^_m/Dj<4ogUOZ0?oSW2]00CoWX2bofU?XOmPD:SoH52X0_mBI/T2ofmKZ`?o
NF>]0on8L[@01?nCQ;ooRh;4og]Z]?mkJ[@4ogMT/0;oOVbc00CoRgJgoi5f/OnAM[7oTGJa0onKO:l0
0onTPJko[I2hojf@^002ojf@^0Co]96b0_ndSJd2olZhb@Coa:>g1Oo?/[h00oo1WK?oc[K2oljf`P02
oljf`P;oajFg0ooA^L<2ol:U_0?ob[G50_o3Z/43olZfa`?o^ZW800?o`K?=okN]cong[Ll00ong[Ll0
1?nWZm[o/JoFok6_e_na[mH3ojF^gP03ojjcg?nU]>?oYKCS00?oYKCS0_nN^>X2ojFgi@CoX[[[1?nO
_^h2oj32l@?oXko]0onR`Nl2ojC3k`?oY<3]0_nU`Nh2ojFok0CoY/3/0_nV`Nd2ojJok0?oY/3/00Co
0000ojK0k?nW`>coYl3/0_nW_n/6ojO0j`OoYko[0onW`>/9ooooo`03o`000?oooooooooo00kooooo
000Sooooo`03o`000?oooooooooo02oooooo00?o[l;WokG3iOne`nD00_ne`nD2okK3i0?o]KoR1?nd
^]h01?nb]M_oZjgIoj^]fOn[[MT3ojNUe0CoXYg?0onLU</3oiN=a`?oT8K40on:P<<3ohAl``?oOWc6
0_mhOlh2oe?;kPCo`/cR0onf]MP3ojJMc@?oU8K10on3L[P3ogQV/P;oKUj`0omZH;D3ogUIX@?oLEFR
0omSDj/00oo>gNCoW9gCoibMd`02ogI/^PCoNEnX0_n>L:d00ommGjGoJDnQofU?X@03of1@Z0?oDVK9
0omiHjd2ohQb]003olO=g_n;P/CoRh;400?oNfZd0omgI;03ogi//`?oTGJa0_nKO:l00onOR;_o[I2h
ojf@^003ojf@^0Co]96b00Co]8f]olZhbOo:^<Wob[S90oo4XkL2omWSgPCock:n1Oo>]/800oo7YKOo
dKW3om6i``02om6i``03ol:U_?o:]LGob[G500;ob[G500?o`j[1olZfaoo:]/L00_o:]/L00onjZLSo
`K?=ol6cc@02ol6cc@?o]jg?00?o_KGBok6_e_na[mH00ona[mH01?nU[]ko[[?Lojjcg?n^/m`3ojFd
h`03ojbfh?nU]nGoYKOU00?oYKOU0_nR^^/2ojJji`CoXkc[0_nS_nd2ojFmjPGoY;k/0_nT`>d2ojFn
j`CoYKo/0_nV`>`2ojJoj`CoY[o/0_nV`>`00ol0003oYko[ojNoj`04ojNoj`;oYl3[2_nW_n/4ojO0
j`Sooooo00?o0000ooooooooool03_ooool002Cooooo00?o0000ooooooooool0;oooool3okG3i@;o
]<?U1One_n82okBjgP;o[[CM0on[[MT4ojNUe0;oXYg?00CoV:7Joi:KfOnBVmWoTY_I0on=V=T3ohJG
g0CoPI_R1?mkYNh2og:lo@04ojOhgOo5g>[oaMcZolGLjP;o`/cR00CoYI[;oiR9`_nHRL;oV8W20on:
N[`3ogi_^0;oKfNi00CoPg:hogQV/_mhI[;oN6Jb0om^G[02ofYP]@?oJVo50omaEJ801?mSDj_oQ:_^
oi63`?nAPl03ofeQ/`;oMVbj0_mIDJh2of1H/@;oOEnU0_mYCj43of1@Z0?oDVK900?oW^VSojc4jon/
a>/00omkOl`2oeiO^`03oh^2a?mkJ[CoNfZd00?oMfB`0omnK;<3ohij^@CoWhRk1On]T;P2okBA/P03
ol[Ki_o:^<Wob[S900?ob[S900Coa:>gomWSg_oIhmkofN?N0oo?/[h2olcSj0?oc[K20_o?gn@3om6i
``03olg?foo:]LGob[G500?ob[G51Oo:]/L5ol6cc@03okN]conm]M;o_KGB00;o_KGB0_na[mH2okJe
f0Go[[?L00CoYKCSojbfh?n/]^3o[;KP0onU]nD00on[^N?oY[[WojJji`03ojJji`;oXkc[0_nW^nP4
ojFmjP;oY;k/0_nV_NX5ojFnj`;oYKo/00?oY[k[ojJojonV_n/00onV_n/2ojJok0CoYko[00?o0000
ojNojonW_n/04?nW_n/4ojO0j`Oooooo00?o0000ooooooooool03_ooool002Gooooo0_l0000`oooo
o`03okG3iOnd`nGo]<?U00;o]<?U0_ne_n83ok2khPCo[[CM0on[[MT2ojNUe003oifVg?nHXM[oV:7J
00;oV:7J0onBVmT3ohfHf@?oQYOL1?n1Vn82og^UkP03of_LaonWn=goYoSM00?oaMcZ00?o[j_CojFJ
bonUV//00_nUV//3oiR9`P?oRWZl0omnKkP2ofmW^@?oN6Jb0om^G[03ofYP]@?oJVo50on4Znh4oi63
`0;oKF6c00CoGeF_ogI/^_mIDJkoFE6^1?mPF;43ofU?X@?oH52X00?oDVK9oj[<l_oOnmD00_n/a>/3
og]oc0?oGUnk0_mkJ[@4ogMT/0?oOVbc0on>N[T3oin8^`Go[I2h00Co]96bol[Ki_o:fnKob]_V0oo:
^<T3o`0000?ofN?N00?ock:nolcSj?o<hnP00_o<hnP00oo>]/;ocmoToloOi002oloOi004om6i`oo=
cm_ocLoKolg?f`?ob[G50_o<amH3olZfa`;ob/;C0oo1/ld2ol>me@?o_KGB00?o_kgHokJef?nf]MP0
0onf]MP2ojjcg0;o/kOL1On/]^001?nU]nGoZkWSoj^ihon[^N<2ojJji`;oZ[[U1OnW^nP2ojFmjP;o
YkcX1?nV_NX2ojFnj`;oYkgZ1?nV_^/2ojJoj`;oYkkZ1onW_n/00ol0003oYkoZojNoj`0?ojNoj`Go
Yl3[1_ooool00ol0003oooooooooo`0>ooooo`009oooool00ol0003oooooooooo`0^ooooo`?o]<?U
0ona`^L4ok2khP;o[[CM00?oYK?Soj:]gonR[Ml00_nR[Ml3oifVg0CoV:7J0onBVmT3ohfHf@?oQYOL
0_n1Vn801?m<b>KoJmc7oicdiOnLm>D3ol?Tk`04olGLj_n_Zm?o[j_Cojn[d`?oYI[;0onHRL83ohYj
_0?oOVnh0_m_IkT3ofEZ``?oKUj`0omZH;D4ofY_a@03ohB[k_ng/M?o]k7C00?oTH?00_m]HK<2oemE
[`03ogI/^_mIDJkoFE6^00?oH5Ra0omiM/<2of1@Z0?oZ/cb00Co/[KKofmeb?m_MLSoKgG80omkOl`2
oeiO^`;oHV>l00CoNfZdogMT/?mgI;3oMfB`0omnK;<3ohij^@?oWhRk1?n]T;P00onSk_Oob]_Vol[K
iP03ol[KiP03olZhbOnTV<WoY9S900;oUi7<00GoWHk3oi>;b?nCRlSoTh_8o`000002olcSj003oh:9
d_mMPmoo0P0000;ocmoT0_n1h?X4olg?f`03olZeaOo<amKoc<OF00;oc<OF00?ob[K7ol[2doo:`]<0
0_o:`]<00oo1/lgo`kgEol>me@02ol>me@04okfed_no_MSo_kgHoknmf0?o][GH0_nh^m`4ok>gg0;o
[;KP0_n_^N43oj^ih`03ojfjhonZ^^GoZ[[U00?oZ[[U0_nW^nP2ojVli`GoYkcX0_nV_NX2ojNlj0Co
YkgZ0_nV_^/2ojNmj@CoYkkZ0_nW_n/2ojNnjP?oYkoZ00?o0000ojNoj_nW_n/03onW_n/4ojO0j`Ko
oooo00?o0000ooooooooool03_ooool002Sooooo00?o0000ooooooooool0;_ooool00ond`nGo/L;W
ok72i`03ok72i`;o/;_R00?oZ;[VojFchonU/n<00_nU/n<4oj:]g`?oWJKL0_nHXMX2oi2bkP?oR;Gc
1?n0_OX2ofo8o`03og[TjonLm>Go_>Kc00;o_>Kc0_o3i>l00ong^]_o[j_Cojn[d`02ojn[d`?oYI[;
0onHRL83ohYj_0?oOVnh0om_IkT2ofEZ``;oD83R0_m^G[02ofYP]@?oJVo500CodmoQokNadong/M?o
]k7C0onAPl03ofeQ/`;oGeF_0_mIDJh3of1H/@CoNGK30onZc?83ok:ff`;oKgG80_mOHK`01?mkOlco
GUnkoeiO^omNGk/2of9S_0?oMfB`0omnK;<3ohij^@CoWhRk00?o[I2hoj?^monSk_L00_nSk_L2ol[K
iP;o/:?:0_nTV<T00onRT<;oWHk3oif>``02oif>``?oTh_81?n2RM82oef3g`CoPN3j0_o=cm/2ojgQ
n@?oc<OF0_nodnT3ol[2d`;oa<gQ0oo3_MD00onoaMoo_kgHoknmf003oknmf003okJef?nh^mco^;_L
00;o^;_L0_nc]m`2okFlg`Co[kWQ00CoZkWSojfjhon]^^?o[K[S0onZ^^D2ojbli@CoZKcW0_nW_>P2
ojVli`GoYkcX0_nW_NX00onX_NWoYkgYojNmj@03ojNmj@;oYkkZ0_nW_^T4ojNnjP;oYkoZ00?o0000
ojNnj_nW_n/03_nW_n/6ojO0j`Gooooo00?o0000ooooooooool03_ooool002Wooooo00?o0000oooo
ooooool0;oooool2ok72i`?oZL3[0onX^^H4ojFch`;oXZgO0_nJ]>X3oiFbj`CoT;;^0on8]O<2oh2m
nP;oQMol00?oU^o`okcVlonli_<00_nli_<2okW5h`?o]k[K1?n_Zm<3ojFJb`?oV8W20on:N[`3ogi_
^0;oKfNi0omUJ/<3oe20hP?oJV2e00?oJVo5om?OhOnTYML00on1PLX4oi63`0;oKF6c0_mOEJl00om>
E[[oFE6^of1H/@03of1H/@CoNGK300?oZ/cbok:ffonb]]/00_nb]]/3ofmeb0;oGf6l0omNGk/2of9S
_0?oLWO91?mnK;<3ohij^@;oWhRk0_n7i?P4ol:cc0;o/:?:0_nWU/@4oj:@`P?oWHk31?nCRlP3oh:9
dP?oGH?O0_lXNND00ol0Bk_o083DojgQn@03ojgQn@03olc7e_nodnWo_m?Y00;o_m?Y00?ob/;ColC=
hOo4cN400_o4cN401?o3_MGo_lGOoko5gonoaMl3oknmf003okg3gonh^mco^;_L00;o^;_L00?o^<7Q
okFlgone_=l00one_=l2ojnih@;o/KcR1?n]^^<00onZ^^Go[;cUojbli@02ojbli@;oZKcW0_n[_>H4
ojVli`;oYkcX0_nX_NP4ojRmj@;oYkgY0_nX_NT5ojNnj@;oYkkZ00KoZ;kZojNnj_nW_^[oYkkZo`00
0?nW_^X2ojNoj`;oZ;oZ1_nW_n/2ojRoj`OoYl3[0_nX`>/4ooooo`03o`000?oooooooooo00kooooo
000Zooooo`;o0000<Oooool4ojW0j`?oZ;[V0_nU/n<2oifgj`CoV[CZ0onE/^/2oi2bkP?oSl[l0_n;
dol2oiKXnP?o]N?f00?o_>KcokW5honiaN<00oniaN<3okNjf`;o[j_C00CoViW@ohn<c?n?S<coShc<
0on5PlT3ogQlb`?oOVnh0_m_IkT4ofEZ``05oe20h_n3d_oof?_NomSkg_nobN801?nTYML2oh61bP?o
JVVo00?oTH?0ofeQ/om]HK<00omOEJl00om>E[[oFE6^of1H/@02of1H/@?oNGK30ooRl]P4ok:ff`;o
KgG80_mOHK`2oeYQ`004oeiO^omRHkcoHV>lof9S_0;oLWO90omnVN<00omnK;?oSWZiohij^@02ohg=
o@04onGQcooBa/kod/K>om;6cP;o`[?<00?o/Z;7ojNFa?nWU/@00_nWU/@4oj:@`PCoWHk30_nCRlP0
1?nNTLKoUi;=oiNBcOnGT/d3oh>Af@04oef3golXNNGo:7WUobQii@;o78WZ0ombbol2okoCj@;oYmGh
1?o4cN400onfd>go_lGOoko5g`03oko5g`05oknmf?nm`moo_L?Ookg3gonh^m`01?nh`N43okFlg`03
okC0hona_>;o/KcR00?o/KcR0_n]^^<00on__NCo[;cUojbli@02ojbli@03ojfmi_n[_>KoZkcV00?o
ZkcV0_nY_>L2ojZmi`CoZ;gX0_nX_NT2ojRmj0CoZ;gY0_nW_^T2ojRnj@CoZ;kZ0_nW_^X00onX_n[o
0000ojRojP04ojRojP;oYko[1_nX_n/2ojO0j`OoZ<3[0oooool00ol0003oooooooooo`0>ooooo`00
;?ooool00ol0003oooooooooo`0_ooooo`;oZL3[0_nQ_^h3oinkk0CoWKO[0_nJ]>X2oiJom0CoT/?g
0_n?b_`3oiKNoP04oiKXn_nehoKo]N?fokGSmP;o^LcX1?niaN<01?n/[m[oYJGFojFUe_nUYMH4oi^I
d0?oShc<0on5PlT2ogQlb`?oMH;B0omgV>H2ofEZ``;oPm;o0_oHnmh3oko9hP?oY:GG0on1PLX3ofYY
_`03oe9K_Om]HK?oGeF_00;oGeF_0_m>E[X3of1H/@03ogUf`onSjIkoh_;H00;oh_;H00?o/;kUogf7
d_mmQm800_mmQm800om@GlCoKgG8oemQ_002oemQ_0;oFV7000?oGUnkof9S_?mRHk`00ombMlT4ogjI
h`03ohg=oOoYn/GoiN7?00Cod/K>00Co`[?<ok:RaonbX/Oo/Z;71?nWU/@4oj:@`P;oWHk300?oXY73
oijAa_nNTLH00_nNTLH3oiNBc@?oPi7I1?mUT>H2odnHlP04oab9j_m@/o[oD;?joe2cnP?oYmGh00?o
a<gQokK@kOnfd>d00_nfd>d2oko5g`;o^L_X0onm`ml2okS7iPCo^<7Q00?o]KcOokC0hond`><00_nd
`><2ok6lhP;o/KoU1?n__N@00on/_>Go[KgVojfmiP02ojfmiP;oZkcV0_n[_^L5ojZmi`;oZ;gX00?o
ZKgXojRmj?nX_NP00onX_NP2ojRmj@KoZ;kY1?nX_^X3ojRojP03o`000?nX_n[oZ;oZ00WoZ;o[2onX
`>/3ooooo`03o`000?oooooooooo00gooooo000]ooooo`03o`000?oooooooooo02oooooo1?nQ_^h3
oinkk0;oWKO[0_nI_O44oiJom0;oT/?g0onGe?d2oiKNoP;o[]gh0_nfc^d4okW<j003okW5hon/[m[o
[:oJ00;o[:oJ0onUYMH3oi^Id0?oShc<0on5PlT3ogQlb`?oMH;B1?mgV>H01?n3d_oo`OkJolcRj?o<
h^P4oko9hP?oY:GG0_n1PLX3ofYY_`;oDU^m00?oKF6coemE[omOEJl01?m>E[X01Om8XoOo/MSdomkn
aOoNo/GofNOO00?o/;kU0ommQm82oe1Oa003ofmeb?mOHKcoGf6l00?oFV700_mRHk`4og9gb@;oOYWS
0_oXn</00oo[j/cogmK>om;6cP02om;6cP03ol2bc?nbX/Oo/Z;700;o/Z;71?nWU/@2oj:@`PKoXY73
0onNTLH4oiNBc@?oPi7I1?mUT>H3odnHlP;oEjci1OnBc?`2okK@k@;oYlkd1?nibnP00onm`moo^<OV
okS7iP02okS7iP;o^<7Q0_neaNH3okC0h`;o//?V1?na_nD2ojnmi0;o[koV0on]_NH2ojboi`CoZkkW
0_nZ_NL2ojZnj0CoZKgX0_nX_NP2ojVnj@SoZ;kY1OnX_^X2ojRojP03o`000?nX_n[oZ;o[00GoZ;o[
3onX`>/3ooooo`03o`000?oooooooooo00gooooo000^ooooo`03o`000?oooooooooo02oooooo0_nQ
_^h2oibmk`CoV[g`0onI_O42oiJom0?oVLci0_nGe?d3ojWFm`03ojkMn?nfc^go]/k]00;o]/k]0_ni
c>P2ok2hg`Co[:oJ1?nUYMH3oi^Id0?oShc<0on5PlT2ogQlb`CoMH;B0_mgV>H00onRm]oo`OkJolcR
j003olcRj0;o_lWR00CoWIcBohF3bOn5PlWoQH?90_mWKLD4ofYY_`;oDU^m0omOEJl2odiF^P?o/MSd
00Cog_k5omWWgooIimoofNOO0_n`_^D4ogf7dP;oD5o40_mOHK`3oeYQ`0?oIh?J0_mbMlT2oh;Bo`04
olkodooXn<_oj?S;on_Zc0;ogmK>00Cod/K>ol2bc?o0//co`;;<1?nbX/L2ojNFa003oj>CaOnRTL?o
XY7300KoXY731?nNTLH2oiNBc@04oj>IbonGVMCoUiWDoiNIe0CoQI_Q1?mbXNh2ofZ/m`;oT/cl0_n8
a?/5ojO>m0;o^L_X0on`c>h2okS7iP03ok;:joneaNKo]LGV00?o]LGV00?o]<3Sok;3i_nb`nH00_nb
`nH2ok6oi@;o[l;W1?n__nH00on]_NKo[;oWojboi`02ojboi`;oZkkW0_n[_nP4ojZnj0;oZKgX1_nY
_^T2ojRnj@;oZKkY1?nX_^T2ojRnjPGoZ;oZ00Co0000ojRoj_nX_n_oZ;o[4onX`>/2ooooo`03o`00
0?oooooooooo00gooooo000_ooooo`03o`000?oooooooooo02oooooo1?nL_Nl2oiZml0;oVl7b1?nJ
a_H2oiW<n@?oYLof0_nYe_L3ok;>kP;o]/k]0_na_^<4ok2hg`;o[:oJ00?oX:;GoiRJe?nHV]@00_nH
V]@3ohnDe0?oQ8oG1?mmU=l2og>Vl@;oMH;B00CoJ/kloj;fgonRm]oo/O_S0_o=k^/2olcRj003ok:f
fonMW=;oWIcB00;oWIcB0on5PlT2ofM]a@?oJVVo0_mBFkd3ofYme005odiF^_naf?Co/MSdok7Hm?oN
o/D00ooIiml01?nh_]koPHkGoh6>eon1S]L3ogf7dP;oD5o40omJJlT3oeYQ`0CoIh?J00GoP];oolko
dooXn<_oj?S;on_Zc003omoFcPGo`;;<0_nbX/L00onXVlSoXi?5oj>Ca@02oj>Ca@SoXY730_nNTLH0
0onVUlKoXiW;oj>Ib`02oj>Ib`?oUiWD1?n5Vn44og:QkP?oJZcg0on8a?/2ojO>m0;oWL[f1?n`c>h0
0onYbo;o//[[ok;:j`02ok;:j`;o]LGV0onaanX2ok;3iP;o/<GZ1On_`^L2ojnoiP03ojg1j?n/_nOo
[;oW00;o[;oW00?o[<3Yoj^oj?n[_nP00on[_nP2ojZnj003ojZojOnY_^WoZKkY00GoZKkY0_nY_nT4
ojVnj@;oZ;kY2?nX_nX00onX`>_o0000ojS0j`0DojS0j`;ooooo00?o0000ooooooooool03Oooool0
033ooooo0_l0000`ooooo`;oW;g_0_nM_Nl4oi_1lP;oV/Kf0onSbO<2ojG?mP;o[/__0onbc^h2ok71
iPCo/KkS0_n`^=l00onVZm[oX:;Goj2Re`02oj2Re`CoV9[D0on?U=@3ohB?e`CoOICO0_mcY_42oigW
o0;o/O_S0_o=k^/2ol7=i0?o/[KK0onMW=83ohF3b@;oIfg50omPKl/3oe9K_@CoJWgD00Go/MSdomSo
c_oTmMCoi?GDomWWg`03okRngP;oPHkG0omTLL/3oe1Oa0;oFV_90omnU=h2ofN3fP;oZ]ki00Coc_oC
onShbooXn<_ojn[<0ooOe/h2om35c`?o`;;<00?o/ZO>ojRKb?nXVlP00_nXVlP3oj>Ca@OoXY7300?o
YYK5ojJGa_nVUlH00_nVUlH4oj>Ib`?oUiWD0_n5Vn42oiRTg@?oRZSY1?mn/?<4ohZon0?oWL[f00?o
/<c^ojW;l_nYbo800_nYbo82ok;:j`;o[LW_0onaanX2ojg7k@Co/<GZ0_n_`^L2ojg3jPCo[L7X00?o
[;oWojc0jOn/`>T00_n/`>T2oj^oj0;oZ/3Y1?nZ_nT2ojVnj@OoZKoY0_nY_^T00onY_n[oZ;oZojRo
jP05ojRojPCoZ<3[00?o0000ojS0jonX`>/05?nX`>/00ooooooo0000ooooo`0>ooooo`00<_ooool0
0ol0003oooooooooo`0^ooooo`CoWKg_0_nK`O83oj?3l0;oXlWc0_n[anh4ojk;k`03ok;>k_na`NKo
/L7V00;o/L7V0_na_^<00onZ/MgoYZ_JojJ[fP02ojJ[fP?oX:;G1?nHV]@3ohnDe0CoQ8oG0_mmU=l3
oi78n`03oigWo?nann?o/O_S00;ocNk[1?o1cN@3ok:ff`?oWIcB0_n5PlT3ofM]a@;oH6o;0omRS^H2
ofYme004ohW/ioo0k_;of?o>omSocP;oi?GD00?of>7MokRng_nh_]h00_nh_]h2oh6>e`;oI77;0_mB
J</01?m@GlCoFV_9oeY[bOmJJlT4ogjDgP05oj[NnOnjg?7ogNkMomg^gOoWkM400_oThM000ooOe/ko
d<G?om35c`02om35c`04ol2bc?nbYlko/ZO>ok:WcP?oZ9_80onSTlD5oj:A``?oYYK51?nVUlH3oj>I
b`03ojbRcOnTX]?oY:;C00;oY:;C1?nHY=d3ohZXj@CoO[3c0_n:_oP00on@_OGoVLKfoiW6mP03oiW6
mP;oZL_b0_nTbO<4ojg9k`03ok77j_n]ango[LO]00;o[LO]0_n`aNX2ojc5k0Co[L?Z0_n]`NP3ojc2
jP;o[<3Y0_n[`NX4oj[0j@;oZ[oY0_nY`>X6ojVoj@;oZL3Z1?nY_nX2ojRojPWoZ<3[00Co0000ojS0
jonX`>_oZ<3[0_nX`N/?ojS0j`03ojO0jooooooo000000oooooo000cooooo`03o`000?oooooooooo
02kooooo0_nM_Nl2oj>ok@?oXl?`0_nYa>d4oj_7kP;o[/__0on``nP2ok71iP03ojfghOnZ/MgoZ[7M
00;oZ[7M1?nVZmX3oj2Re`;oV9[D00?oTJCRohfWi_n=YnH00_n=YnH4ohZ`k`;oTLSk0onPl?D2ol7`
l@?o`mc/0_o1cN@01?nY/]koVIoHoiVOf?nIWmP3oh><e0?oM8;B0_mWKLD3of1_b`?oHXkV0_o0k_82
omSocP;oi?GD0ooHhMd2okRngP03oiNRg?mTNmCoI7_D00?oI77;0omBJ</3oeY[b@;oOYCN0_njg?42
omg^g@;oingA0_oThM001OoKeM;od<G?om35coo@aLoo`[WA00Co/ZO>1?nXVlP3oj>Ca@;oXY7300?o
XiC6ojJFaOnVU/D00onVU/D4ojJGaP03oj>Ibon/X/go[:;=00GoY:;C0_nHY=d00onTZmcoVJkVoiV^
iP02oiV^iPCoS[?_0on@_OD2oiW6mP;oV/Ce1OnTbO<2ojg9k`;oZ<Wa0_n]and2ojW7k`Go[<G/0_n]
`nX00on[a>co[<;Zojc2jP02ojc2jP03oj[2jon[`N[oZl7Z00?oZl7Z0_nZ`>T00onY`N[oZL3ZojW0
jP03ojW0jP;oZKoY1_nY`>X2ojVojPSoZ<3[0onX`N/2ojS0j`03o`000?nX`N_oZ<7[00?oZ<7[0_nX
`>/2ojS1j`KoZ<3[1_nW`>/00ol0003oooooooooo`0=ooooo`00=?ooool00ol0003oooooooooo`0^
ooooo`CoXko]00?oXl?`ojW4kOnYa>d00_nYa>d2oj_7kP;o[/?Y0on``nP00on]^n?o[KOQojfgh@02
ojfgh@CoZ[7M0_nVZmX00onNZn3oV:OOoiRWg`02oiRWg`?oTJCR1?n=YnH2ohZ`k`?oV=gn0_nejOL0
0oo1l?7o`mc/ol?Lk002ol?Lk003okC1i?nY/]koZK;N00;oZK;N0onIWmP3oh><e0;oM8;B0omUPMT3
of1_b`03of:>i_o0k_;o`>kb00;of?o>0_oTmM@3omSQg@03okc5h_nGX]coUj;L00;oUj;L0_mTNm@2
ofAab`?oDVS;1OmeTn800onjg?7ogNkMomg^g@02onO]d@?oi>7@0_oKeM801?o@aLoo`[WAol:idOo2
^M44ok:WcP;oZ9_800CoXIS;oinDb?nOU<SoWiC81?nSU<H4ojJFa@;oYYO60_n]X<X4ojbRc@?oY:;C
00?o[J[DojB[g?nTZm`00_nTZm`4oiV^iP;oS[?_0_nJ]n`4oiNmlP?oV/Ce0_nTbO<3oj;7l`;oZ<Wa
0_nUao44ojW7k`;o[<G/0_nYaNh4oj_4k003ojc2j_nZ`^_oZ/;[00;oZ/;[0_n[`NX2ojW2j`CoZL7Z
0_nY`>X2ojW1j`OoZL3Z00?oZL7[ojS0jonX`>/01OnX`>/4ojS1j`;oZ<7/0onX`N/01Ol0003oZ<7[
ojS1jonX`N_oZ<7/00GoZ<7[0_nX`>/00onW`NcoYl3[ojO0j`05ojO0j`03ooooool0003ooooo00ko
oooo000eooooo`;o0000;oooool2oj>ok@?oZ<3[0_nYa>d2ojg2j@Co[/?Y00Co/<?Xojfkhon]^n?o
[K_S1?n]]n42ojZag@;oXjoQ0onNZn04oiRWg`?oTJCR0_n=YnH3oiC9nP04oiSMo_nejOOo]NWgokGY
m`?o_n;`00?o`mc/okC1i?nd`N@00_nd`N@3ojVbgPCoVIoH0_n3S=@3ogB2dP?oIH7I0on4[>l2ok3`
mP;odOSU0_oGl><00oo<fnCo_<GRokc5hP02okc5hP?oUj;L0_mTNm@3oemgd`?oDVS;0omeTn82oj_8
k`03omg^gOoWkM7oingA00?oi>7@0_oKeM800oo?bMGo`[WAol:id@02ol:id@;o/ZO>0_nWXM04oj6H
b`?oWiC80onSU<H3ojJFa@03oj^Nb_n]X<[o[J3:00?o[J3:0on/X/d00onTX]?o[J[DojfZe002ojfZ
e0CoY:_L0_nI[^H00onS]>CoV[O/oiZgk003oiZgk0;oUkgb0_nM_^l4oic2l`;oX/Oc0_nRaO84ojG7
l@;oZLO_0_nWa_04ojW5kP;oZlC/0onYa>d2oj[2j`;oZ<;/1?nY`^/2ojW1jPKoZL7[0_nY`>X2ojS1
j`CoZL7[0_nX`>/5ojS1j`KoZ<7/0_nX`N/00ol0003oZ<7/ojS1k003ojS1k0;oZ<7[1_nW`N`2ojO0
j`Kooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0;_ooool2ojS0j`;o
[<7Y1?n]`^T2ojk3j@;o[[kU1?n]^n<2ojfgh@;oYkCR1?nS[n43oij[h0;oV:OO0_nG]>`4oi>klP;o
U<Wj0onYgOT01?nejOOo_n;`okoRl?noh_02ok[=j0Co]<7T0_nY/]h00onHXM[oRiGHoh^Ef002oh^E
f0?oNXgJ0omdP]83ofF1f@03ohB/kon`l?Ko/?3f00;odOSU0_oGl><3olcKi0;o_<GR00GoX:cPoh:A
f_n2TM[oPY7JoiNRg002ofAke0;oGgOC0omcSml01?meTn;oZlS_oj_8kon[b>l3olcSj0;of>;N00?o
i>7@om_Ed_oKeM800oo?bMD2ol:id@03okB`e?nWXM3oYj7@00;oYj7@1?nQV</3oinDb0CoXiC600Co
YYK5oj^Nb_n[W/[oZik:1?n]X<X2ojbRc@;o/Z[@1?n]Z]@2ojB[g0;o[K;L1?nS]>@2oiZgk0;oX[[Z
1OnM_^l2oic2l`03oj32lOnRaO;oX/Gb00?oX/Gb0_nUao42ojC5l@CoYlK`0_nYaNh3ojO4kP;oZLC]
00?oYl?]ojS2k?nX`^`00onX`^`2ojW2j`03ojS2k?nY`N_oZL7[00GoZL7[0_nX`N`4ojS1j`;oZL7[
0onX`N`2ojS1j`03ojS2k?nX`NcoZ<7/00WoZ<7/00Co0000ojS1k?nX`NcoZ<7/2?nW`N`9ooooo`03
o`000?oooooooooo00cooooo000hooooo`03o`000?oooooooooo02kooooo1?n/`NT2ojg2j@;o[/3W
1?n^_^D2ojfkh`;oZKST1?nW]>82oj>_h@;oWk?V0onJ/^P4oiNdk0;oTk_b0onQcoP2ojWMn@;o]^7e
0_nhd^d4ok[=j0;o]<7T00?oYJkMoiRQf_nHXMX00_nHXMX4oh^Ef0;oNXgJ1?miUn@3oh>gmP;o]n;e
0_o<kn/01OoGl>?oc=_TolcKi?o<fnCo^/GS00CoX:cP0on2TMX3oemke`;oGgOC1?mcSml01?n[b>oo
c>?XolcSj?o<hnP3omSRgP03omSMfooKeM;oclWE00?oclWE00Co`[WAokB`e?nd/=Co];3D1?nWXM04
oj6Hb`?oWiC80_nSU<H00onTVlcoZik:oj^NbP02oj^NbP?o[J3:00?o/JS?ok:Zd?nbZ]000onbZ]02
ojfZe0;o/k;G1?n]/]`2oj>di0;oZkSS1?nR^^X2oifnk`?oXko]0onP`_42oj;5lP?oXlCa0_nTaO42
ojC4l0CoYLC_0_nWa>h2ojK3kPCoYl?]0_nX`^`2ojO2k@CoZ<;/0_nY`N/2ojS2k0GoZ<7/0_nX`N/2
ojS2k0;oZ<7/1_nX`^`2ojS1k0;oZ<;/1_nX`N`00onW`Nco0000ojO1k006ojO1k0cooooo00?o0000
ooooooooool03?ooool003Wooooo00?o0000ooooooooool0;_ooool2ojc1j@;o[L7Y1?n^`>L2ojjn
i@;oZk_V1?nY^>@2ojNdhP;oX[KV1?nO/nH3oiZbj0;oUkC/0onNa_@2oj7?n0?o[M[g00?o]^7eokSB
kOnhd^d00_nhd^d2ok[=j0;o[[[R0onU[]d4oiRQfP?oRiGH0omjSMX4ogVGi003oh>gm_ngh_Go]n;e
00;oc>o[0oo?i>H01?o<fnCo^/GSok[5honjaN<3oj2/h0CoPY7J0_mONmL3ofj>h@;oLhoO0onK^Nd0
1?o<hnSof>;NomSRg_oHh]h2omSMf`04om;Dfoo?bMGoclWEolo9e@;o`/3H1?nd/=@3ojNQd0;oXIS;
0_nKV]43oifIcPCoY9_<1?n[W/X01?n]X<[o/JS?ok6XconaZ<l3ok:Zd003okNbe?nc/]Oo/k;G00?o
/k;G0_n]/]`2ok:hg@CoZkSS0_nR^^X3ojRmj@;oXko]0_nW`>`4oj?2k`;oXlCa0_nT`nl4ojC4l0;o
YLC_0_nU`nl4ojK3kP;oYl?]0_nV`^h4ojO2k@;oZ<;/0_nW`^d4ojS2k0;oZ<7/4onX`^`2ojS1k0Go
Yl7/00?o0000ojO1k?nW`N`04?ooool00ol0003oooooooooo`0<ooooo`00>_ooool2o`0002oooooo
1?n]`NT2ojk0i`;oZkkX1?n[^nH2ojVhi0;oYKSW1?nR]^H2oinciP;oW[c^1?nL_o42oik6m0?oY];g
0_n]f_L3okCCl0;o^=;]0_nb`^H4ojjjhP?oYJkM0_nHXMX01?n>X>3oR9oRohROh_n8Wn84ohFVjPCo
U/3d00?o]n;eolc_joo<kn/00oo?i>H2olOFi@Co^/GS0onP[>03oh:AfP?oGg_G0om^S^43oi^ik@?o
^m7Z00?of>;NomSMfooHgM/00ooBe=/00oo?bMGo`/3Hol;0f002ol;0f0;o];3D00CoZJ_IoijOeOnN
WmGoWYoE1?nKV]44oifIcPCoY9_<0_n[W/X00on^Y]3o/JS?ok6Xc`03ok6Xc`04ok:Zd?ng/]Co]k;D
okNbe0?o/k;G00?o]kWJok:hgOnb^=d00onb^=d2oj^hh`;o[kgT0_nX_NT2ojc0j0GoYl3/0_nS`^l0
0onU`^koY<?_ojC3k`03ojC3k`;oY<C`00?oY<?_ojG3konU`nl00onU`nl2ojK3kP03ojG2k_nV`^ko
Y/;^00?oY/;^0_nW`^d2ojK2k@CoYl;]0_nX`^`3ojO2k@;oZ<;/00?oYl;]ojS2k?nX`^`01OnX`^`0
0onX`^goZ<;/ojS2k005ojS2k003ojO2k?nW`NcoYl7/00GoYl7/00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0<ooooo`00??ooool00ol0003oooooooooo`0]ooooo`;o[L7Y0_n[`NT4oj^n
j0;oZk_V0_nW^nP4ojFhi`;oX[KV0_nP^n`4oijlkP;oW;oa0onRboD2ojKBm`?o[m7b0_nddo02ok?8
jPCo//;V0_n^^^800onS/>7oVZSOoiZXg`02oiZXg`?oSZ3P0on8Wn84ohFVjP;oU/3d0_nagoL3ol7R
l003oloTi_o7e^GoamKU00;oamKU0_njaN<2ojNehP?oS9oQ0_miTMh3of^=h@CoKXkQ00CoVkW]ok_A
j_nkdN[o^m7Z0_o9f^H01?oHgM_od]CKom;DfooBe=/2olW=g@?o`/3H00?o]K[LojV[fOnYZmT00_nY
ZmT3oijOe@CoVi[A0onMVLh2ojBKc0;oYZ?C1?n^Y]03ok6Xc`03okFaeOng/]Co]k;D00?o]k;D00Co
/k;GokNif_ng^M[o]kWJ0_nb^=d2okJnh0?o[kgT0_nb`>D4ojc0j0;oYl3/0_nY`N/4ojG2kP;oY<?_
0_nU`^h4ojC3k`;oYL?_1_nU`^h2ojK2kPOoY/;]3?nW`^d2ojS2k0;oYl;]1?nX`^d2ojS2k0;oYl;]
1?nW`^`2ojO1k0Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`00?Ooo
ool00ol0003oooooooooo`0]ooooo`CoZl7Y0_n[_^P2ojRnj@CoYk_X0_nU^>L2oj:lj`CoX;_/0_nN
_>h2oj76lP?oX/_e0_nZcO83ojoAlP;o/L_]1?ncb>X2ok;2iP;oZKSS0onS/>44oiZXg`?oSZ3P0on8
Wn82ohFVjP?oV/Ce00Co/Mogol7Rl?o1h_3o`N;`0oo3gN`2olOFi@;o^<KU1?nW]N83ohbOh@;oNI7N
0om[SN44oh^/k004ok_Aj_o9f^KobM[VolWJiP?oc=SS00?od]CKolW=gOo9cMd00_o9cMd01?o2`=So
]K[LokFjg?ne^]`4ojV[f@?oWYoE0onKV]42oifIcP03oibOe_nVXm?oYZ?C00?oYZ?C1?n^Y]001?na
Z<oo]K7EokFaeOne/MD3okNbe004okZjfOng^M[o]kWJokNifP;o^[oN1?nf_^000on__NCo//3Uok;0
i@02ok;0i@;o[<3X0_n_`^P4ojW1j`;oYL;^0onW`^d3ojG2kP;oY<?_1OnU`^h2ojG1k@CoYL7^0_nV
`^d2ojK1k@CoY/;]4?nW`^d2ojS2k@KoYl;]0_nW`^`9ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03?ooool003kooooo00?o0000ooooooooool0;Oooool2oj_1j@?oZ<3[0onX_^T2
ojNkj0;oY;g[1?nR_>/2oj2kk0;oXL;`1?nQa_800onRboGoZ/gboj[=lP02oj[=lP03ojoAl_nabngo
/L_]00;o/L_]0_ncb>X2ojfniPCoZKSS0onS/>42oiZXg`03oiJYhon?Z>OoSjSW00;oSjSW1?n@/^d2
oi[4m@?o/=Kd00Co`N;`ol?Mk?o3gNco`mg/0_nmdNT4okS6i@;oYkGR00CoVZ[Roh>Kh_n3Vn;oPi_R
0omlVN@3of^=h@;oRjc/0onS`o001?o9f^Koc=SSolcHhoo<f><2olWEh`?obLgM0_noa^04okFjg0;o
ZJ_I00CoWjWMoiJPfonFX=_oUZ3K0onGW]P4oibOePCoYZ?C0_n^Y]02ok2`e`Co]K7E00?o]k;DokZj
fOnj^]T00_nj^]T00ong^M[o^[oNokZogP02okZogP;o][kP0_nh`^83ok;0i@;o]<?V1?n_`^P2ojW1
j`;oZl;[0_nW`^d2ojS2k0GoY/7]0_nU`^h6ojG1k@;oYL7^00?oYL7]ojK1kOnV`Nd00onV`Nd2ojK2
k@03ojK1kOnW`^goYl;]017oYl;]4?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00cooooo000oooooo`;o0000;oooool2ojS0j`;oYKo/1?nU_^/3ojBmj`;oX[c[0onR`Nl3oj72l0;o
XLKb0onWbO82oj[=lP?o[/_^0_nabnd2ojk2j0Co[KkV0_nY^><00onS/N?oW:cRoib/hP02oib/hP?o
UZWS1?n?Z>L2oi2bk@?oXLKc0_n`e_@3ok_Kl003ol?Mk?nmdNWo_M7Y00;o_M7Y0_nha^D00on[^^Co
VZ[RoiZZhP02oiZZhP?oPi_R0omlVN@4ognTj`;oXl?`0onbc^h00oo<f>?obMGSolWEh`02olWEh`03
olW=gOnoa^3o_lKP00;o_lKP0_ne^]`00onZ]N7oWjWMoinYg@02oinYg@?oUZ3K0onGW]P4oibOeP;o
YZ?C00?oYjcKok2`eon`/=L00on`/=L2okFae@;o^;[K0onj^]T2ok_1gP?o^[oN0_nka>44okS2hP03
ok;0iOnd`nKo]<?V00;o]<?V0_n_`^P01?n``nSoZl;[oj_2jon[`^/2ojc3jPCoZ<;/0_nV`Nd2ojO1
k0KoYL7]0_nU`>d4ojG1k@SoY/7]3onW`^dDooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool02oooool0047ooooo00?o0000ooooooooool0;Oooool4ojFok0;oYKk[0_nS_nd4oj>okP;o
X/7_0_nT`nl4ojG6l@;oYlWb0on[bNl2ojk;kP;o[/CZ1?n^`^P2ojfniP;oYkOT0onS/N<4oib/hP?o
UZWS0_n?Z>L3oiRikP;oXLKc0on]d_<2ok_Kl0?o_=G/0_nmdNT00ondaNOoZk[Toj^ji002oj^ji0Co
VZ[R0on3Vn83ogbIi0;oOjC[0_nE^>l3ok;>kP;o^M;/0oo9eN<2ol?@i0;o_lKP0_ne`N<4ojZeh@Co
WjWM0onFX=/3oiNNf0;oW9oF00?oW:ONojN/fonW[=/00_nW[=/3ok2`e`;o/[WN1?nh^]/00onj^]Wo
^l7Nok_1gP02ok_1gP03okZog_nka>7o^lCQ00;o^lCQ0_nh`^82okS6i0;o]<?V0_ndaNL4ok33j003
oj_2jon/`n[o[<?Z00;o[<?Z0_nX`^`2ojW1j`CoYl7/0_nU`Nd2ojK0k0CoYL3]0_nU`Nd2ojK0k0Wo
Y/7]2_nW`^dHooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool004;ooooo
00?o0000ooooooooool0;Oooool2ojFok0;oY;o/1?nS_nd2oj>okP;oY<7^1?nT`nl2ojG6l@?oZ<O_
0_n[bNl2ojc4k0Co[/CZ0_n^`^P2ojZkiPCoYkOT0onS/N<2oib/hP;oV[7W1?nH/nX2oiRikP;oXlOb
0on]d_<00onddo3o_=G/okcEk002okcEk003okS=j_ndaNOo]<GW00;o]<GW0_n[^^@2oinbi@?oTZSU
0on3XNH4ohJWjPCoUKS_00?o//k^okWBk?nid^`00_nid^`00oo9eN?o`m3Tol?@i002okc;iPCo]L7S
0_nZ]N400onQ/nGoUj[SoiNZh`02oiNZh`?oTJCR1?nDY>03oibWgPCoYjcK00?o/;3Gok:ig_nb^Mh0
0_nb^Mh2okRjf`;o^L;Q0onk`Mh00onlan?o^lCQok_4h@02ok_4h@04ok[8iOnha^Co^<KTokS6i0;o
^<SW1?ndaNL2ok33j0?o/<CY0on/`nX5ojW1j`;oYl7/00?oYl3/ojK0k?nV`>`00onV`>`2ojG0k@Ko
Y/3/0_nV`Nd2ojK1k0;oY/7]0_nW`Nd6ojO2kAgooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`00@oooool00ol0003oooooooooo`0]ooooo`CoY;o/0_nS_nd2ojC0k@CoY<7^
0_nT`nl3ojO5k`;oZ<O_0_n[a>`4ojc4k0;o[/CZ0_n[_^L4ojZkiP;oYkOT0_nR]NH3oinciPCoV[7W
0_nH/nX00onN_^ooXlOboj?7lP03oj?7lP05ojgBlonddo3o]=?`okCCl?nleN`01?nhcNX2okC5i`;o
Z[cV1?nO/^D3oi:Xi@?oPj7V1?n6YnX2oiFhk`;oY<G`0_nid^`3ok[Aj`03ol?@i?nlbnKo_<_V00;o
_<_V0_ne`N<2ojbmiP?oXK?U1?nGZ^<3oi6ThPCoU:CP0onLYmh2ojN/f`;oYkGS0onb^Mh00onb`NGo
^L;QokW2h@03okW2h@05ok_1g_nlan?o_<OSokc7honka>401?njb>D00onha^Co^<SWokS8i`02okS8
i`;o]<GW0oncanT2ok34j@03ojo5j_n/`n[o[<?Z00;o[<?Z1?nY`N/4ojO0k0goY/3/0_nV`N`2ojO1
k0CoYl7]0_nW`^dPooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool004Co
oooo00?o0000ooooooooool0;Oooool4ojBok0CoY<3]0_nT`Nh3ojK3kP;oYlG_0_nY`n`4oj_4k0;o
[<C/0_n[`>T4oj^ni`;oZ[_V0_nV^>H4oj:eiP?oWk?V0_nJ/NL00onL^NcoW[k_oijnk`02oijnk`;o
XlOb0on/cO42okCCl0?o]M3^0_nhcNX2ok74j0CoZ[cV0_nO/^D00onI[nKoT:[Woi2Zi`02oi2Zi`?o
RJW[1?nA]>l2ojC5l0?o[L__0_njdN/2okS?j`?o_<_V0_ndanP4ojbmiP?oXK?U0_nGZ^<00onA[>So
SJSXohfXj002ohfXj0?oTJ_W0onK/>H5ojNeh`04ok:ig_nb`NGo//7Uok;1i@;o^L;Q0onhb>H2okc7
h`?o^l_W0_njb>D2okW;j0?o^<SW00?o]/[Yok?7jOncanT00_ncanT00onbb>[o[lGZojo5jP02ojo5
jP;o[<?Z0_n/`n/4ojW1j`;oYl3/0onX`>/2ojK0k0;oYko[1?nV_n`2ojK0k003ojO0k?nW`NcoYl7/
00?oYl7/0_nW`NdTooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool004Go
oooo0_l0000_ooooo`?oY;o/0_nT`>d3ojK1k@;oY/?^0_nX`^`4ojW3k0;oZlC/0_n[`NX4oj_0j@;o
ZkkW00?oZ;_WojJhi_nV^>H00onV^>H2oj:eiP03oj6gj?nN]nWoW[OY00;oW[OY0onL^N`2oijnk`?o
YLOa0_n/cO43ok7?l0;o]M3^0_nbbN/4ok74j0;oZ[cV0_nS]^H3oiV_iPCoT:[W0on9ZN/2oi6dk`;o
W;k`0on]bnl2ok7=kPCo^<o[00?o_<_VokC7j?ndanP00_ndanP2ojbmiP03ojBkjOnJ/^WoV[;Y00;o
V[;Y0onA[>P4ohfXj0?oTJ_W0onK/>H2ojNeh`;oYkgY0onb`ND2ok77jP?o^<SV0_ngc>X3ok_;i`03
okW>j_nibnSo^L_X00?o^L_X00Go^<SWokK:jOnfb^Wo]/[Yok?7j@04ok;8jP;o[lGZ0_n^aN/4ojc3
j`GoZL7[0onX`>/5ojNoj`;oY[o/00?oYko[ojO0k?nW`>`00_nW`>`2ojO1k2Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0;ooooo`00Aoooool00ol0003oooooooooo`0]ooooo`Co
Y[o/0_nV`Nd2ojO1k0CoZ<;/0_nY`n`2oj[1j`CoZl7Z0_n[`>T00onY_NSoZ;_WojRki`02ojRki`;o
Y[SV0_nS^>L4oj6gj0;oW[OY0_nQ_Nd4oj;1k`;oYLOa0on[bo42ok7?l0;o/L_]1?nbbN/2ok74j0;o
Z[gX1?nS]^H3oiV_iP;oT:[W0_nB/>/3oi6ckPCoW;k`00?o[L__ok7=k_nacNh00_nacNh2okS?j`?o
]<c[0_ndanP00on]`n[oY;_YojBkj@02ojBkj@CoV[;Y0onA[>P2ohfXj0;oRjk]0on@/^d4oiZhk0?o
YkgY00?o//7Uok77j_naanX00_naanX00onhb>Ko]lcZokO<jP02okO<jP04ok_;ionic^[o^LkZokW>
jP;o^L_X0ongcN/2okK:j@?o]<_[0_nbb>X00on`b>co[/G[ojk5j`03ojk5j`;o[<?[0_n[`n/4ojW1
j`CoZ<3[2?nW_n/2ojO0k2cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;oooo
o`00B?ooool00ol0003oooooooooo`0]ooooo`;oY[o/0_nW`>/4ojO1k0;oZ<;/0_nY`N/4oj[1j`;o
Zl7Z00?oZKkYojVmj?nY_NP00_nY_NP2ojRki`;oYK[W1?nS^>L2oj6gj0;oXK_/1?nQ_Nd2oj;1k`;o
Y/K`0on[bo42ojk:k`Co/L_]0_nbbN/3ojk3j@?oZ[gX0_nS]^H2oijdj0?oU[3Y1?nB/>/3oi6ckP;o
W;k`0onTaO42ok7=kP;o/Lc^0_ndc>/2ok38k0Co[L?Z0_nT^nT2oijjk0?oU;?/0on>[nd5oh^^k@?o
T;;]0_nJ^>`2oiZnl@CoYlC_0_naanX2ok3<kP;o]lcZ0oned>h2okW>jP?o]]3]0_ngcN/2okG>k@?o
]<_[00?o//_]ok38k?n`b>`00_n`b>`2ojk5j`?o[LG/0_n[`n/2oj[3k0CoZL7[0_nX`>/2ojO0j`Ko
Yko[<?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo0019ooooo`03o`00
0?oooooooooo02gooooo1?nW`>/2ojO1k0KoZL7[0_nZ`N/3ojVoj@;oZKkY0_nY_NP2ojNkj0CoYK[W
0_nS^>L2oj>kjPCoXK_/0_nQ_Nd2ojC3k`CoY/K`00?oZl_aojk:kon^b^l00_n^b^l2ok7;k@?o[lK[
0_n^`nT00onY_^WoY;WXojBij002ojBij0CoW[CX0onF/>T2oi:`j`03oiNfkOnJ_?3oV[c`00?oV[c`
0_nTaO42ojS8l0;o/Lc^0_n`bnh4ok38k0;o[L?Z0_nV`N`4oijjk0?oU;?/0on>[nd2oh^^k@;oR[?a
0on@^?85oiZnl@;oYlC_00CoY/Wbok3<k_n`c>ko/<c^0_n^d?43okG@kP;o/]7`0onfd>d00oncdNoo
]Lk]okG>k@03okG>k@04okC;jonbbngo//_]ok;;k@;o/<S/0on^b>d2ojg5k0;oZlG]1?nZ`n`2ojW1
j`03ojS1jonW`>_oYl3[00?oYl3[0_nW_n/dooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool004[ooooo0_l0000^ooooo`;oYl3[0_nX`>/6ojW1j`?oZL3Z0_nY_nT00onX_^Wo
Z;gXojRmj002ojRmj0?oYk_X0_nU^^L2ojBkjPCoXk_Z0_nQ^n`3oj?0kP?oY<?_0_nVa_03oj[8k`;o
[/[_0on^b>d2ojo6j`03ojc2j_nY_^WoZKkY00;oZKkY1?nT^NP2oijdj003oibdjOnG/n_oUk?[00;o
Uk?[0onG]^d2oiZll0?oX<7`0_nXb?02oj_9l0Co/<_^0_n`b>`3oj_6k@?oY/7/0_nN^^`2oiZjkP?o
TKG_1?n</o03ohZcl@?oT;Sb0_nJ__43oi[4m0?oY/Wb00?o/<c^ojk@lOn^d?400_n^d?400oned>ko
/]7`ok;Al002ok;Al004okK@kOncdNoo/m7_ok?Ak`;o]Lk]0onbc^l2ok;;k@?o[l_^0_n^b>d00on/
b>koZlG]oj_5k@03oj_5k@;oZ/?/00?oZ<;/ojS1jonX`N/00_nX`N/2ojO0jcWooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0:ooooo`00C?ooool00ol0003oooooooooo`0/ooooo`Co
Z<3[0_nY`N/5ojW0jP03ojVojOnX_^WoZ;kY00;oZ;kY0_nX_NP2ojJmj@CoYKcY0onT^nX2oj>kjP?o
Xkk/0_nS`>h2ojK3kPCoYlK_0_nZb>l3ojc8kP;o[/S]00?o[<C[ojc2j_n/`^X00_n/`^X2ojVnj@;o
YK_X1?nQ]nP3oibdj@;oUk?[0_nJ^>d4oiblk`;oX<7`0_nUaO04oj_9l0;o/<_^0on]bNh2oj_6k@03
ojS3kOnR_nkoX[o^00?oX[o^0onJ^^h3oi6ek`;oS;?`0_n<]o<3oh^im0CoTKke0_nJa?@2oi[8m`Co
YLge0_n^d?43ojcAl`;o/]7`0_n`d_82ok?Ak`?o/=7a0_nbc^l3ojo>l0;o[l_^00?o[<_`ojc8k_n/
b>h00_n/b>h2oj_5k@?oZLC]0onX`^`2ojS1jccooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0:ooooo`00COooool00ol0003oooooooooo`0/ooooo`;oZ<3[0onY`>/2ojW0jP03ojVo
j_nY_nWoZKoY00;oZKoY0_nX_^T2ojNnjPCoY[gY0_nU_>T2ojFmj`CoY;g[0_nS_^`2ojG1kPCoY/?^
0_nWa^l3ojW6kP;o[<S^00?o[<G/ojc4jon/a>/00_n/a>/2ojc2jP;oZ;kY1?nU^nP2oj6gj0;oWkSY
0onL]n/4oiZhk@;oW;c_0_nP`>l4ojG5l0;oZlW`0on[b>l2ojg9kP03oj_7k_nX`ngoZ<?]00;oZ<?]
0_nR_nh2oinnk`?oV;[`1?n@]o44ohbgl`?oRkWd0_nA__D3oi;2m`?oV/Sg0_nUcOD2ojC?mP;o[=7c
0onZd_D2ok3BlP?o[M?d0_n`dO42ojgAl`;o[lk`0_n/c_84ojc;l0;o[<S^0onYanl2ojW4kD?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`00C_ooool00ol0003ooooooooo
o`0]ooooo`?oZL3[1?nY_nX2ojVoj@;oZ;oZ1?nW_^X2ojJmj@;oY[k[1?nU_N/2ojBmj`;oYL3]1?nU
`Nh2ojK3kP?oZ<G^0_nYa^h00on[aNgo[<G/ojc5k002ojc5k0;o[<C[0_nZ`NX4ojRnj@;oYK_X0_nS
^^T4oinhj@?oW;O[0_nJ^>d2oijlkPCoX<3_0_nUaO03ojS6k`;oZlS_1On[anh2ojS3k@;oYL;^1?nO
_^l3oiRjl0;oT;Oa0_nA^_84ohjjm0?oSKgf0_nB`_L2oiC6n0CoVl_h0_nTcoH3oj?@m`;oZ];e0onY
doH2ojgCm004oj_BmOn]dO?o[M7cojgAl`;oZ]3d1?n/c_82ojc;l0?oZL[a0_nYanm7ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02_ooool004oooooo0_l0000^ooooo`?oZL3[0_nY
_nX2ojRoj`CoZ;oZ0_nW_^X6ojJnj`;oYKg[0_nU_n`4ojG0k@;oYL7^0onW`nh2ojS5kP03ojW4kOn[
aNgoZlG]00;oZlG]0_n/aN`2oj_2j`CoZ/7Z0_nX_^T2ojJlj@CoXk[Y0_nO^>T2oinij`CoW[[/0onN
_>h2oj30k`?oY<?_0_nXa^l00onYanooZlO^oj_7kP04oj_7kP?oZLC^0onU`^h2oinnk`;oWKg_1?nG
^o43oi6jlP;oS[[d0_n@__D4oi31m`?oU<Kh0_nKboP3oic=n0;oXm3g0_nSdOP2ojWCmP;oYm?g1?n[
d_D00on]dO?oZ]3doj[@m002oj[@m0;o[<kb0_nXcO<2ojW:lDcooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0:ooooo`00DOooool00ol0003oooooooooo`0/ooooo`03ojW0jonX`>_o
Z<3[00CoZ;o[0_nX_nX2ojNoj`KoY[k[1_nU_n`2ojG0k@?oY/;]0_nW`nh00onX`ngoZLC]ojW4k@02
ojW4k@;oZlG]0_nZ`n`4oj_2j`;oZ/7Z0_nX_^T4ojJlj@;oXk[Y0_nR^NT4oinij`;oW[[/00?oXKg]
oj6ok_nQ_nh00_nQ_nh2ojC3k`;oYlC_1?nYanl2oj_7kP?oZ/K^0_nYa>h2ojO3k@CoXl3^0onM_Nl2
oiNkl@03oiRllOnC_??oTkcc00?oTkcc0on@__D2oi31m`03oiC4monGb?SoUlSh00?oUlSh0_nLcOP2
oik>n0CoXm7h1?nWdoL2oj_Bm@?oZ=;f0_nZd?@2ojO?m@;oZ<gcCoooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00[ooooo001Booooo`03o`000?oooooooooo02_ooooo1?nX`>/2ojRo
j`KoYko[0_nV_^/3ojJoj`GoYKo/0onV`Nd2ojK2k@03ojO3kOnX`ngoZ<?]00;oZ<?]0_nYa>d6oj[3
k0;oZl;[0onY_nX3ojRnj@;oY[cY0_nT^nT4oj:ij@;oWkW[00?oXK_[oj6mkOnQ_Nd00_nQ_Nd2oj6o
kP;oY<;^1?nWa>l2ojW7k`GoZ/K^0_nYa>d4ojO3k@;oXl3^00?oX[o^oifnkonM_^l00_nM_^l3oiRl
l@;oTkcc0_nF__<4oiC1mP?oU<Cg0_nGb?P3oi[:n0;oW/kh0onOcoP3oj?An0;oYm?g0_nVd_L2ojSB
mP?oY]7g0_nWcoECooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool005?o
oooo00?o0000ooooooooool0:oooool2ojS0j`?oYl3[0_nW_n/8ojJoj`KoY/3/0_nV`Nd00onW`^go
Yl?]ojO3k@02ojO3k@;oZ<?]0onY`nd5oj[3k0?oZL7[0_nY_nX2ojRnj@CoY[cY0onT^nT2oj:ij@03
oj:kj_nQ^n_oXK_[00;oXK_[0_nQ_Nd2oj>ok@CoY<;^0_nWa>l3ojS5kP;oZ/K^00?oZ/G]ojW4kOnY
a>d00onYa>d2ojO3k@03ojK1kOnR_nkoX[o^00;oX[o^0_nM_^l2oijnk`CoV[ka0onF__<2oiC1mP?o
Ul?f0onHa_L2oi[:n0?oW<ch0_nOcoP00onQd?SoXm;hoj?Bn002oj?Bn0;oY];g0onTd_P2ojKAmeOo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`00E?ooool2o`0002gooooo
1?nW`>/6ojJoj`SoY/3/00?oY/7]ojO2kOnW`^d00_nW`^d2ojO3k@?oZ<?]0_nY`nd2ojW2j`KoZL7[
0_nX_nX4ojRnj@;oY[cY00?oYKcYojBkj_nT^nX00_nT^nX3oj:kjP;oXK_[0onR_N`3oj>ok@;oY<;^
0onW`nh2ojS5kP03ojW4kOnZaNgoZ/G]00;oZ/G]0_nYa>d3ojS3k@?oY/7]1OnR_nh3oijnk`;oV[ka
0_nL_o44oiW1l`;oUl?f00?oVlGeoi_8monKb?L00_nKb?L2oic<n0?oWlgg0onQd?P2oj?Bn0?oXm7h
0_nTd_QJooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool005Kooooo00?o
0000ooooooooool0:oooool4ojO0j`;oY[o[2?nV`>`2ojK1k0?oY/7]1OnW`^d2ojS3k@;oZL;/1?nY
`^/2ojW1j`;oZL3Z1?nX_nX2ojRnj@03ojJmjOnU_>WoYKcY00;oYKcY0_nT^nX2ojBljPCoXkc[0_nR
_N`2ojBok0CoYL7]0_nW`nh00onX`ngoZLC]ojW4k@02ojW4k@;oZ/G]0onYa>`2ojS3k@;oZ<;/1?nU
`>d2oj:okP03oj:okOnO_nooWko_00?oWko_0onL_o42oiW1l`;oW<;c0onKaOD2oi_8m`?oW/[f0_nO
cOL3oj;>m`?oX]3h0_nSdOQNooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Ooo
ool005Oooooo00?o0000ooooooooool0:oooool2ojO0j`_oY/3/0onV`N`01?nV`NgoYl7/ojO1k?nW
`N`2ojO2k@;oZ<7/1?nY`^`2ojW2j`;oZL3[1?nY`>X2ojRojP03ojNnjOnV_NWoY[gY00;oY[gY0_nU
_>T2ojFljPCoY;cZ0_nS_>/2ojBnk0CoY;o/0_nU`Nd00onW`^goZ<?]ojS3k@02ojS3k@GoZLC]0_nY
a>`2ojW2k0CoZ<;/0_nU`>d00onU`>coX[o]oj:ok@02oj:ok@;oWko_0_nQ_nl4oik1l@;oW<;c0_nP
a?84oio7m0;oW/[f0_nRboD2oj;>mfKooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`09ooooo`00F?ooool00ol0003oooooooooo`0/ooooo`[oY/3/00?oYl3/ojO1k?nW`N`01?nW`N`6
ojS1k0;oZL;/0_nX`N/4ojW0j`;oZL3Z0_nX_^X3ojNnj@;oY[gY0_nV_>T4ojFljP;oY;cZ0_nT_N/4
ojBnk0;oY;o/00?oY/3/ojO2kOnW`^d00_nW`^d2ojS3k@?oZL?]0_nYa>d2ojW3k0CoZL;/0_nX`^`0
0onW`NcoYL3/ojG0k002ojG0k0;oX[o]0_nS_nd4oj6ok`;oW/7a0_nQ`_04oj34lP;oWlOd0_nSb?<2
oj;;mF[ooooo00Go0000ooooooooooooooooo`00000;ooooo`00FOooool00ol0003oooooooooo`0/
ooooo`KoY/3/1OnW`>`4ojO1k0KoZ<7/1_nX`N/2ojW0j`;oZ;oZ0_nX_^X2ojNnjPCoYkgY0onV_>T2
ojFljP?oYKgZ0onT_N/2ojBnk0;oYKo/0onV`>`2ojO2k@?oZ<;]0_nY`nd6ojW3k0;oZL;/0_nY`N/3
ojO1k0;oYL3/0onU_n`3oj>ok@;oXKo_0onS`>h3oj72l0;oX<Cb0_nSaO42oj?8lfgooooo00Go0000
ooooooooooooooooo`00000;ooooo`00F_ooool2o`0002gooooo0_nV`>`2ojO0j`OoYl3/1?nW`N`2
ojS1k0GoZ<7[0_nX`>/5ojRojP;oZ;kZ1?nW_^X2ojNmj@;oY[gZ1_nU_NX5ojFnj`;oYKo/0_nV`>`4
ojO1k0;oZ<;]2?nY`n`2ojW2k0;oZL7[0_nX`N/4ojO0j`;oYKo/0_nV_n`4ojFok@;oXl3^00?oYL7]
ojC3konT`nl00_nT`nl2oj?5lG7ooooo00Co0000oooooooooooo00002oooool005cooooo00?o0000
ooooooooool0:oooool4ojO0j`04ojO0k?nW`>_oYl3[ojO0j`?oYl3/0_nW`N`5ojS1j`KoZ<3[0onX
_nX4ojRnjPCoYkkZ1?nV_NX2ojFmjP03ojFmjonU_^_oYKk[00CoYKk[0_nV_n`4ojK0k0;oYl7/0_nX
`^`6ojW3k0CoZL;/0_nY`N/4ojS1j`;oYl3[0_nW_n/4ojJok0;oYKo]00?oY/3/ojG1kOnU`Nd00_nU
`Nd2ojC3kgGooooo00?o0000ooooool000002oooool005gooooo00?o0000ooooooooool0:oooool8
ojO0j`CoZ<3[0_nX`N/8ojS0j`GoZ;oZ0_nX_^X6ojNnjP;oY[gZ00?oY[kZojFmjonU_N/00_nU_N/2
ojFnj`KoY[o/0_nV`>`3ojO1k0?oZ<;/0_nY`n`6ojW2k0CoZL7[0_nX`N/00onX`>_oYko[ojNoj`03
ojNoj`;oY[o/00?oYko[ojK0k?nV`>`00_nV`>`2ojG1kGSooooo00Co0000oooooooooooo00002_oo
ool005kooooo00?o0000ooooooooool0:oooool8ojO0j`[oZ<3[00?oZ;o[ojRoj_nX_nX01?nX_nX8
ojNnjPGoY[kZ0_nU_N/3ojJoj`GoY[o/0onV`N`2ojO1k003ojO2k?nX`^coZ<;/00;oZ<;/2?nY`^`2
ojW1j`03ojS1jonX`>_oZ<3[00;oZ<3[2?nW_n/2ojK0k7cooooo00?o0000ooooool000002_ooool0
05oooooo0_l0000/ooooo`KoYl3[2_nX`>/3ojRoj`;oZ;oZ0onW_nX8ojNnjP03ojJnj_nV_^_oY[k[
00CoY[k[0_nV_n/2ojJok0CoY/3/0_nV`N`00onW`NcoYl;/ojO2k002ojO2k0CoZ<;/1_nY`^`2ojS1
k0?oZ<7[1OnX`>/2ojNojh?ooooo0_l0000:ooooo`00HOooool00ol0003oooooooooo`0Zooooo`;o
Yl3[3?nX`>/6ojRoj`;oYkoZ0_nW_n/6ojNnjP03ojJojonV_^_oY[k[00CoY[k[1_nV_n`2ojK0k0Go
Yl7/0_nW`^`3ojS2k@?oZ<;/0_nY`^`2ojS2k0CoZ<7/1?nX`N/2ojS0jhGooooo0ol0000:ooooo`00
H_ooool00ol0003oooooooooo`0[ooooo`_oZ<3[1_nX_n/6ojNoj`;oYkkZ00?oYko[ojJojonV_n/0
0_nV_n/2ojJnj`;oY[o[1_nV_n`00onV`NcoYl7/ojO1k004ojO1k0?oYl;]1?nX`^d7ojS2k0CoZ<7/
0_nX`N^4ooooo`Co00003Oooool006?ooooo00?o0000ooooooooool0:oooool;ojS0j`;oZ;o[3OnW
_n/8ojJoj`;oY[o/0_nV`>`3ojK1k0;oYl7/1onW`^d4ojS2k@;oZ<;/00?oZ<;]ojS2k?nX`^`00_nX
`^`2ojS1k8?ooooo1?l0000Aooooo`00I?ooool2o`0002cooooo2OnX`>/?ojNoj`GoY[o[1onV`>`2
ojK1k@CoYl7]2?nW`^d2ojS2k@;oYl;]0onX`^d2ojS2k8?ooooo0ol0000Eooooo`00I_ooool00ol0
003oooooooooo`0[ooooo`CoZ<3[0onW`>/?ojNoj`;oY[o[2?nV`>`00onV`NcoY/7]ojK1k@02ojK1
k@;oYl7]3?nW`^f5ooooo`Co00006?ooool006Oooooo00?o0000ooooooooool0:_ooool8ojO0j`go
Yko[0_nW`>`6ojK0k0GoY/7/0_nV`Nd<ojO2kHCooooo1?l0000Looooo`00J?ooool00ol0003ooooo
ooooo`0Zooooo`SoYl3[2OnW_n/3ojO0j`?oYl3/1?nV`>`2ojK1k0;oYl7/1?nW`Nd9ojO2kH?ooooo
1?l0000Pooooo`00JOooool2o`0002cooooo2?nW`>/00onW_n_oYl3[ojO0j`06ojO0j`GoYl3/0_nV
`>`6ojO1k0;oYl7]1onW`^f2ooooo`Co00009?ooool006_ooooo00?o0000ooooooooool0:_ooool=
ojO0j`OoYl3/2onW`N`4ojO2kH;ooooo0ol0000Xooooo`00K?ooool00ol0003oooooooooo`0Zoooo
o`_oYl3[2?nW`>`:ojO1k8?ooooo1?l0000[ooooo`00KOooool00ol0003oooooooooo`0[ooooo`[o
Yl3[1_nW`>`8ojO1k8;ooooo1?l0000_ooooo`00K_ooool00ol0003oooooooooo`0Zooooo`SoYl3[
1onW`>`6ojO1k87ooooo1?l0000cooooo`00Koooool2o`0002_ooooo2?nW`>/7ojO0k0;oYl7/P?oo
ool4o`0003Oooooo001aooooo`03o`000?oooooooooo02[ooooo1onW`>/2ojO0k8;ooooo1?l0000k
ooooo`00L_ooool00ol0003oooooooooo`0Zooooo`GoYl3[P_ooool3o`0003oooooo001cooooo`03
o`000?oooooooooo02[ooooo00?oYl3[ooooooooool0Ooooool4o`0004;ooooo001dooooo`;o0000
:_ooool00ol0003oooooooooo`1kooooo`Co0000A_ooool007Kooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`1hooooo`Co0000B_ooool007Oooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1dooooo`Co0000C_ooool007Sooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`1aooooo`?o0000D_ooool007Wooooo0_l0000Tooooo`03o`000?oooooooooo06go
oooo1?l0001Eooooo`00Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo06Wooooo
1?l0001Iooooo`00O?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06Gooooo1?l0
001Mooooo`00OOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo067ooooo1?l0001Q
ooooo`00O_ooool2o`0001oooooo00?o0000ooooooooool0GOooool4o`0006Gooooo0020ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0F_ooool3o`0006Wooooo0021ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0E_ooool4o`0006cooooo0022ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0D_ooool4o`00073ooooo0023ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0C_ooool4o`0007Cooooo0024ooooo`;o00006Oooool00ol0
003oooooooooo`1:ooooo`Co0000N?ooool008Kooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`16ooooo`Co0000O?ooool008Oooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`13ooooo`?o0000P?ooool008Sooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0oooooo`Co0000Poooool008Wooooo0_l0000Dooooo`03o`000?oooooooooo03_ooooo1?l00027
ooooo`00Roooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Oooooo1?l0002;oooo
o`00S?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03?ooooo1?l0002?ooooo`00
SOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo033ooooo0ol0002Cooooo`00S_oo
ool2o`0000oooooo00?o0000ooooooooool0;?ooool4o`0009Kooooo002@ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0:?ooool4o`0009[ooooo002Aooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool09?ooool4o`0009kooooo002Booooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool08Oooool4o`000:;ooooo002Cooooo`;o00002Oooool00ol0003ooooo
ooooo`0Mooooo`Co0000Y_ooool009Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Jooooo`?o0000Z_ooool009Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0F
ooooo`Co0000[Oooool009Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Boooo
o`Co0000/Oooool009Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co
0000]Oooool009Wooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo1?l0002iooooo`00Vooo
ool01?l0003oooooooooool00009ooooo`?o0000_Oooool009cooooo00?o0000ooooool000001Ooo
ool4o`000<3ooooo002Mooooo`;o000000?oooooo`000?l000000_l00034ooooo`00W_ooool2o`00
0<Sooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo002^ooooo`05oiRHV?l0003o0000odA4A?nj^[X0
2Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4QV?ooool00:kooooo
00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`Ko000000KooooooiRHV?lQ8B7ok^k^oooooom4A4@3
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8ISooooo002^ooooo`03o`000?oooooo
oooo00cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@09oooooo002^
ooooo`03o`000?oooooooooo00Cooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000
ooooooooooooooooo`00002Oooooo`00[_ooool00ol0003oooooooooo`0>ooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`00002Oooooo`00[?ooool00ol@413o0000o`000003
o`0000kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo09gooooo002^
ooooo`03o`000?oooooooooo00_ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0Woooool00:kooooo00?o0000ooooooooool02oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2Oooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -20 0 ]
[.5 .82364 20 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20.8) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69466 Mtetra
.4053 .69466 .41061 .69934 .41957 .69681 .41427 .69211 Mtetra
.41427 .69211 .41957 .69681 .42855 .69428 .42328 .68956 Mtetra
.656 .75 .919 r
.42328 .68956 .42855 .69428 .43756 .69174 .43231 .687 Mtetra
.43231 .687 .43756 .69174 .4466 .68919 .44137 .68443 Mtetra
.656 .75 .92 r
.44137 .68443 .4466 .68919 .45567 .68663 .45046 .68187 Mtetra
.655 .75 .92 r
.45046 .68187 .45567 .68663 .46478 .68407 .45958 .6793 Mtetra
.655 .751 .92 r
.45958 .6793 .46478 .68407 .47391 .68149 .46873 .67673 Mtetra
.654 .752 .921 r
.46873 .67673 .47391 .68149 .48307 .67891 .47792 .67417 Mtetra
.653 .753 .923 r
.47792 .67417 .48307 .67891 .49227 .67632 .48713 .67161 Mtetra
.653 .755 .924 r
.48713 .67161 .49227 .67632 .50149 .67371 .49637 .66905 Mtetra
.652 .757 .927 r
.49637 .66905 .50149 .67371 .51075 .6711 .50565 .66649 Mtetra
.651 .76 .929 r
.50565 .66649 .51075 .6711 .52004 .66849 .51496 .66394 Mtetra
.651 .763 .931 r
.51496 .66394 .52004 .66849 .52936 .66586 .5243 .66138 Mtetra
.65 .766 .934 r
.5243 .66138 .52936 .66586 .53871 .66322 .53368 .6588 Mtetra
.65 .77 .936 r
.53368 .6588 .53871 .66322 .54809 .66058 .54308 .65621 Mtetra
.65 .773 .938 r
.54308 .65621 .54809 .66058 .55751 .65792 .55252 .65359 Mtetra
.651 .775 .939 r
.55252 .65359 .55751 .65792 .56695 .65526 .56199 .65093 Mtetra
.652 .776 .94 r
.56199 .65093 .56695 .65526 .57643 .65259 .57149 .64824 Mtetra
.653 .777 .939 r
.57149 .64824 .57643 .65259 .58595 .6499 .58103 .64553 Mtetra
.654 .776 .939 r
.58103 .64553 .58595 .6499 .59549 .64721 .5906 .64279 Mtetra
.654 .775 .938 r
.5906 .64279 .59549 .64721 .60507 .64451 .6002 .64005 Mtetra
.653 .774 .937 r
.6002 .64005 .60507 .64451 .61468 .6418 .60983 .63732 Mtetra
.652 .773 .938 r
.60983 .63732 .61468 .6418 .62432 .63908 .6195 .63461 Mtetra
.65 .774 .939 r
.6195 .63461 .62432 .63908 .634 .63636 .6292 .63192 Mtetra
.648 .776 .941 r
.6292 .63192 .634 .63636 .64371 .63362 .63894 .62925 Mtetra
.647 .779 .944 r
.63894 .62925 .64371 .63362 .65345 .63087 .64871 .62658 Mtetra
.647 .783 .946 r
.64871 .62658 .65345 .63087 .66323 .62811 .65852 .62388 Mtetra
.648 .787 .948 r
.65852 .62388 .66323 .62811 .67304 .62535 .66836 .62114 Mtetra
.649 .789 .949 r
.66836 .62114 .67304 .62535 .68289 .62257 .67823 .61835 Mtetra
.651 .79 .948 r
.67823 .61835 .68289 .62257 .69277 .61979 .68814 .6155 Mtetra
.653 .788 .946 r
.68814 .6155 .69277 .61979 .70269 .61699 .69807 .61261 Mtetra
.655 .785 .944 r
.69807 .61261 .70269 .61699 .71264 .61418 .70805 .6097 Mtetra
.655 .781 .941 r
.70805 .6097 .71264 .61418 .72262 .61137 .71805 .60678 Mtetra
.655 .778 .939 r
.71805 .60678 .72262 .61137 .73264 .60854 .7281 .60388 Mtetra
.654 .775 .938 r
.7281 .60388 .73264 .60854 .7427 .60571 .73818 .601 Mtetra
.653 .773 .937 r
.73818 .601 .7427 .60571 .75279 .60286 .74829 .59815 Mtetra
.652 .773 .938 r
.74829 .59815 .75279 .60286 .76291 .60001 .75845 .59529 Mtetra
.651 .774 .939 r
.75845 .59529 .76291 .60001 .77308 .59714 .76864 .59244 Mtetra
.652 .775 .939 r
.76864 .59244 .77308 .59714 .78328 .59427 .77887 .58956 Mtetra
.652 .776 .94 r
.77887 .58956 .78328 .59427 .79351 .59138 .78913 .58666 Mtetra
.653 .777 .939 r
.78913 .58666 .79351 .59138 .80378 .58849 .79943 .58372 Mtetra
.655 .776 .938 r
.79943 .58372 .80378 .58849 .81409 .58558 .80976 .58074 Mtetra
.656 .774 .936 r
.80976 .58074 .81409 .58558 .82443 .58267 .82013 .57774 Mtetra
.657 .772 .934 r
.82013 .57774 .82443 .58267 .83482 .57974 .83053 .57471 Mtetra
.657 .769 .931 r
.83053 .57471 .83482 .57974 .84523 .5768 .84097 .57167 Mtetra
.658 .765 .929 r
.84097 .57167 .84523 .5768 .85569 .57385 .85144 .56862 Mtetra
.658 .762 .927 r
.85144 .56862 .85569 .57385 .86618 .57089 .86196 .56557 Mtetra
.658 .759 .925 r
.86196 .56557 .86618 .57089 .87672 .56792 .87251 .56252 Mtetra
.657 .756 .923 r
.87251 .56252 .87672 .56792 .88729 .56494 .88311 .55947 Mtetra
.657 .754 .921 r
.88311 .55947 .88729 .56494 .89789 .56195 .89374 .55642 Mtetra
.657 .752 .921 r
.89374 .55642 .89789 .56195 .90854 .55895 .90441 .55338 Mtetra
.656 .751 .92 r
.90441 .55338 .90854 .55895 .91923 .55594 .91512 .55033 Mtetra
.91512 .55033 .91923 .55594 .92995 .55292 .92587 .54728 Mtetra
.656 .75 .919 r
.92587 .54728 .92995 .55292 .94071 .54988 .93667 .54422 Mtetra
.93667 .54422 .94071 .54988 .95152 .54684 .9475 .54116 Mtetra
.656 .75 .92 r
.9475 .54116 .95152 .54684 .96236 .54378 .95837 .53809 Mtetra
.656 .751 .92 r
.95837 .53809 .96236 .54378 .97324 .54071 .96928 .53501 Mtetra
.655 .751 .92 r
.96928 .53501 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.657 .752 .92 r
.391 .69252 .39636 .6972 .4053 .69466 .39996 .68996 Mtetra
.657 .751 .92 r
.39996 .68996 .4053 .69466 .41427 .69211 .40895 .68739 Mtetra
.656 .751 .92 r
.40895 .68739 .41427 .69211 .42328 .68956 .41797 .68481 Mtetra
.656 .751 .919 r
.41797 .68481 .42328 .68956 .43231 .687 .42702 .68223 Mtetra
.656 .75 .919 r
.42702 .68223 .43231 .687 .44137 .68443 .4361 .67965 Mtetra
.655 .75 .92 r
.4361 .67965 .44137 .68443 .45046 .68187 .44521 .67707 Mtetra
.44521 .67707 .45046 .68187 .45958 .6793 .45435 .67449 Mtetra
.654 .75 .921 r
.45435 .67449 .45958 .6793 .46873 .67673 .46352 .67193 Mtetra
.653 .751 .921 r
.46352 .67193 .46873 .67673 .47792 .67417 .47273 .66938 Mtetra
.652 .752 .923 r
.47273 .66938 .47792 .67417 .48713 .67161 .48196 .66684 Mtetra
.65 .753 .925 r
.48196 .66684 .48713 .67161 .49637 .66905 .49123 .66432 Mtetra
.649 .755 .927 r
.49123 .66432 .49637 .66905 .50565 .66649 .50052 .66181 Mtetra
.648 .757 .929 r
.50052 .66181 .50565 .66649 .51496 .66394 .50985 .65932 Mtetra
.647 .76 .932 r
.50985 .65932 .51496 .66394 .5243 .66138 .51921 .65682 Mtetra
.647 .763 .934 r
.51921 .65682 .5243 .66138 .53368 .6588 .52861 .65432 Mtetra
.647 .767 .936 r
.52861 .65432 .53368 .6588 .54308 .65621 .53804 .65178 Mtetra
.648 .771 .938 r
.53804 .65178 .54308 .65621 .55252 .65359 .5475 .6492 Mtetra
.65 .774 .939 r
.5475 .6492 .55252 .65359 .56199 .65093 .55699 .64656 Mtetra
.652 .776 .939 r
.55699 .64656 .56199 .65093 .57149 .64824 .56652 .64387 Mtetra
.654 .777 .939 r
.56652 .64387 .57149 .64824 .58103 .64553 .57608 .64112 Mtetra
.655 .776 .938 r
.57608 .64112 .58103 .64553 .5906 .64279 .58567 .63834 Mtetra
.655 .775 .937 r
.58567 .63834 .5906 .64279 .6002 .64005 .59529 .63556 Mtetra
.653 .773 .937 r
.59529 .63556 .6002 .64005 .60983 .63732 .60495 .6328 Mtetra
.651 .772 .938 r
.60495 .6328 .60983 .63732 .6195 .63461 .61464 .63009 Mtetra
.648 .772 .939 r
.61464 .63009 .6195 .63461 .6292 .63192 .62437 .62744 Mtetra
.645 .774 .942 r
.62437 .62744 .6292 .63192 .63894 .62925 .63414 .62482 Mtetra
.643 .776 .944 r
.63414 .62482 .63894 .62925 .64871 .62658 .64394 .62222 Mtetra
.644 .781 .947 r
.64394 .62222 .64871 .62658 .65852 .62388 .65377 .61958 Mtetra
.646 .785 .948 r
.65377 .61958 .65852 .62388 .66836 .62114 .66364 .61687 Mtetra
.65 .788 .948 r
.66364 .61687 .66836 .62114 .67823 .61835 .67354 .61406 Mtetra
.654 .789 .947 r
.67354 .61406 .67823 .61835 .68814 .6155 .68347 .61115 Mtetra
.657 .788 .944 r
.68347 .61115 .68814 .6155 .69807 .61261 .69343 .60817 Mtetra
.659 .785 .941 r
.69343 .60817 .69807 .61261 .70805 .6097 .70342 .60515 Mtetra
.659 .781 .939 r
.70342 .60515 .70805 .6097 .71805 .60678 .71345 .60214 Mtetra
.657 .777 .937 r
.71345 .60214 .71805 .60678 .7281 .60388 .72352 .59916 Mtetra
.655 .774 .937 r
.72352 .59916 .7281 .60388 .73818 .601 .73362 .59625 Mtetra
.652 .773 .937 r
.73362 .59625 .73818 .601 .74829 .59815 .74377 .59338 Mtetra
.651 .773 .938 r
.74377 .59338 .74829 .59815 .75845 .59529 .75395 .59054 Mtetra
.65 .774 .939 r
.75395 .59054 .75845 .59529 .76864 .59244 .76417 .5877 Mtetra
.651 .775 .939 r
.76417 .5877 .76864 .59244 .77887 .58956 .77443 .58482 Mtetra
.653 .776 .939 r
.77443 .58482 .77887 .58956 .78913 .58666 .78472 .58188 Mtetra
.655 .777 .938 r
.78472 .58188 .78913 .58666 .79943 .58372 .79504 .57889 Mtetra
.657 .776 .937 r
.79504 .57889 .79943 .58372 .80976 .58074 .8054 .57584 Mtetra
.659 .774 .934 r
.8054 .57584 .80976 .58074 .82013 .57774 .81579 .57274 Mtetra
.66 .771 .932 r
.81579 .57274 .82013 .57774 .83053 .57471 .82621 .56961 Mtetra
.661 .768 .929 r
.82621 .56961 .83053 .57471 .84097 .57167 .83667 .56646 Mtetra
.661 .765 .927 r
.83667 .56646 .84097 .57167 .85144 .56862 .84717 .56331 Mtetra
.661 .761 .924 r
.84717 .56331 .85144 .56862 .86196 .56557 .8577 .56017 Mtetra
.66 .758 .923 r
.8577 .56017 .86196 .56557 .87251 .56252 .86828 .55705 Mtetra
.659 .756 .921 r
.86828 .55705 .87251 .56252 .88311 .55947 .87889 .55393 Mtetra
.658 .754 .92 r
.87889 .55393 .88311 .55947 .89374 .55642 .88955 .55084 Mtetra
.657 .752 .92 r
.88955 .55084 .89374 .55642 .90441 .55338 .90025 .54775 Mtetra
.657 .751 .92 r
.90025 .54775 .90441 .55338 .91512 .55033 .91099 .54467 Mtetra
.656 .751 .919 r
.91099 .54467 .91512 .55033 .92587 .54728 .92177 .5416 Mtetra
.656 .75 .919 r
.92177 .5416 .92587 .54728 .93667 .54422 .93259 .53852 Mtetra
.656 .75 .92 r
.93259 .53852 .93667 .54422 .9475 .54116 .94345 .53545 Mtetra
.655 .75 .92 r
.94345 .53545 .9475 .54116 .95837 .53809 .95436 .53236 Mtetra
.655 .751 .92 r
.95436 .53236 .95837 .53809 .96928 .53501 .9653 .52927 Mtetra
.9653 .52927 .96928 .53501 .98024 .53192 .97628 .52616 Mtetra
.657 .752 .92 r
.38561 .68781 .391 .69252 .39996 .68996 .39459 .68523 Mtetra
.657 .751 .92 r
.39459 .68523 .39996 .68996 .40895 .68739 .4036 .68264 Mtetra
.4036 .68264 .40895 .68739 .41797 .68481 .41263 .68004 Mtetra
.656 .751 .92 r
.41263 .68004 .41797 .68481 .42702 .68223 .4217 .67744 Mtetra
.4217 .67744 .42702 .68223 .4361 .67965 .4308 .67484 Mtetra
.655 .75 .92 r
.4308 .67484 .4361 .67965 .44521 .67707 .43993 .67224 Mtetra
.43993 .67224 .44521 .67707 .45435 .67449 .44909 .66965 Mtetra
.654 .75 .921 r
.44909 .66965 .45435 .67449 .46352 .67193 .45828 .66708 Mtetra
.652 .75 .921 r
.45828 .66708 .46352 .67193 .47273 .66938 .46751 .66453 Mtetra
.651 .75 .923 r
.46751 .66453 .47273 .66938 .48196 .66684 .47676 .66201 Mtetra
.649 .751 .924 r
.47676 .66201 .48196 .66684 .49123 .66432 .48604 .65951 Mtetra
.647 .752 .926 r
.48604 .65951 .49123 .66432 .50052 .66181 .49536 .65705 Mtetra
.645 .754 .928 r
.49536 .65705 .50052 .66181 .50985 .65932 .50471 .65461 Mtetra
.644 .756 .931 r
.50471 .65461 .50985 .65932 .51921 .65682 .51409 .65217 Mtetra
.643 .76 .933 r
.51409 .65217 .51921 .65682 .52861 .65432 .52351 .64973 Mtetra
.644 .763 .936 r
.52351 .64973 .52861 .65432 .53804 .65178 .53296 .64726 Mtetra
.645 .767 .937 r
.53296 .64726 .53804 .65178 .5475 .6492 .54244 .64473 Mtetra
.648 .771 .938 r
.54244 .64473 .5475 .6492 .55699 .64656 .55196 .64213 Mtetra
.651 .774 .939 r
.55196 .64213 .55699 .64656 .56652 .64387 .56151 .63944 Mtetra
.654 .776 .938 r
.56151 .63944 .56652 .64387 .57608 .64112 .57109 .63668 Mtetra
.656 .776 .937 r
.57109 .63668 .57608 .64112 .58567 .63834 .58071 .63385 Mtetra
.656 .775 .937 r
.58071 .63385 .58567 .63834 .59529 .63556 .59036 .63102 Mtetra
.655 .773 .936 r
.59036 .63102 .59529 .63556 .60495 .6328 .60004 .62822 Mtetra
.651 .771 .937 r
.60004 .62822 .60495 .6328 .61464 .63009 .60975 .62549 Mtetra
.647 .77 .938 r
.60975 .62549 .61464 .63009 .62437 .62744 .61951 .62285 Mtetra
.643 .77 .94 r
.61951 .62285 .62437 .62744 .63414 .62482 .6293 .62028 Mtetra
.64 .772 .943 r
.6293 .62028 .63414 .62482 .64394 .62222 .63913 .61773 Mtetra
.641 .775 .945 r
.63913 .61773 .64394 .62222 .65377 .61958 .64899 .61514 Mtetra
.645 .779 .945 r
.64899 .61514 .65377 .61958 .66364 .61687 .65888 .61246 Mtetra
.651 .783 .944 r
.65888 .61246 .66364 .61687 .67354 .61406 .66881 .60963 Mtetra
.657 .785 .942 r
.66881 .60963 .67354 .61406 .68347 .61115 .67876 .60666 Mtetra
.661 .784 .94 r
.67876 .60666 .68347 .61115 .69343 .60817 .68875 .60359 Mtetra
.663 .782 .937 r
.68875 .60359 .69343 .60817 .70342 .60515 .69876 .60048 Mtetra
.662 .778 .935 r
.69876 .60048 .70342 .60515 .71345 .60214 .70881 .59739 Mtetra
.659 .775 .935 r
.70881 .59739 .71345 .60214 .72352 .59916 .71891 .59437 Mtetra
.655 .772 .935 r
.71891 .59437 .72352 .59916 .73362 .59625 .72904 .59144 Mtetra
.651 .771 .937 r
.72904 .59144 .73362 .59625 .74377 .59338 .73921 .58858 Mtetra
.649 .772 .938 r
.73921 .58858 .74377 .59338 .75395 .59054 .74943 .58575 Mtetra
.649 .773 .939 r
.74943 .58575 .75395 .59054 .76417 .5877 .75968 .58291 Mtetra
.651 .775 .939 r
.75968 .58291 .76417 .5877 .77443 .58482 .76996 .58002 Mtetra
.654 .776 .938 r
.76996 .58002 .77443 .58482 .78472 .58188 .78027 .57704 Mtetra
.657 .776 .936 r
.78027 .57704 .78472 .58188 .79504 .57889 .79062 .57398 Mtetra
.661 .775 .934 r
.79062 .57398 .79504 .57889 .8054 .57584 .801 .57083 Mtetra
.663 .773 .931 r
.801 .57083 .8054 .57584 .81579 .57274 .81141 .56763 Mtetra
.664 .77 .928 r
.81141 .56763 .81579 .57274 .82621 .56961 .82185 .56439 Mtetra
.664 .766 .926 r
.82185 .56439 .82621 .56961 .83667 .56646 .83233 .56115 Mtetra
.664 .763 .924 r
.83233 .56115 .83667 .56646 .84717 .56331 .84285 .55791 Mtetra
.663 .76 .922 r
.84285 .55791 .84717 .56331 .8577 .56017 .85341 .55469 Mtetra
.662 .757 .921 r
.85341 .55469 .8577 .56017 .86828 .55705 .86401 .5515 Mtetra
.66 .755 .92 r
.86401 .5515 .86828 .55705 .87889 .55393 .87465 .54834 Mtetra
.659 .753 .92 r
.87465 .54834 .87889 .55393 .88955 .55084 .88534 .5452 Mtetra
.658 .752 .919 r
.88534 .5452 .88955 .55084 .90025 .54775 .89606 .54209 Mtetra
.657 .751 .919 r
.89606 .54209 .90025 .54775 .91099 .54467 .90683 .53898 Mtetra
.656 .751 .919 r
.90683 .53898 .91099 .54467 .92177 .5416 .91764 .53589 Mtetra
.656 .75 .92 r
.91764 .53589 .92177 .5416 .93259 .53852 .92849 .53279 Mtetra
.655 .75 .92 r
.92849 .53279 .93259 .53852 .94345 .53545 .93938 .5297 Mtetra
.93938 .5297 .94345 .53545 .95436 .53236 .95031 .5266 Mtetra
.655 .751 .92 r
.95031 .5266 .95436 .53236 .9653 .52927 .96129 .52349 Mtetra
.96129 .52349 .9653 .52927 .97628 .52616 .9723 .52037 Mtetra
.657 .752 .92 r
.38018 .68308 .38561 .68781 .39459 .68523 .38918 .68047 Mtetra
.38918 .68047 .39459 .68523 .4036 .68264 .39821 .67786 Mtetra
.657 .751 .92 r
.39821 .67786 .4036 .68264 .41263 .68004 .40726 .67525 Mtetra
.656 .751 .92 r
.40726 .67525 .41263 .68004 .4217 .67744 .41635 .67263 Mtetra
.41635 .67263 .4217 .67744 .4308 .67484 .42547 .67001 Mtetra
.42547 .67001 .4308 .67484 .43993 .67224 .43462 .66739 Mtetra
.655 .75 .92 r
.43462 .66739 .43993 .67224 .44909 .66965 .4438 .66478 Mtetra
.654 .75 .921 r
.4438 .66478 .44909 .66965 .45828 .66708 .45301 .6622 Mtetra
.652 .75 .921 r
.45301 .6622 .45828 .66708 .46751 .66453 .46225 .65964 Mtetra
.65 .749 .922 r
.46225 .65964 .46751 .66453 .47676 .66201 .47153 .65711 Mtetra
.648 .749 .923 r
.47153 .65711 .47676 .66201 .48604 .65951 .48083 .65462 Mtetra
.646 .749 .925 r
.48083 .65462 .48604 .65951 .49536 .65705 .49017 .65217 Mtetra
.643 .75 .927 r
.49017 .65217 .49536 .65705 .50471 .65461 .49954 .64977 Mtetra
.641 .752 .929 r
.49954 .64977 .50471 .65461 .51409 .65217 .50894 .64739 Mtetra
.64 .754 .932 r
.50894 .64739 .51409 .65217 .52351 .64973 .51838 .64501 Mtetra
.64 .758 .934 r
.51838 .64501 .52351 .64973 .53296 .64726 .52785 .64261 Mtetra
.642 .762 .936 r
.52785 .64261 .53296 .64726 .54244 .64473 .53736 .64016 Mtetra
.645 .767 .937 r
.53736 .64016 .54244 .64473 .55196 .64213 .5469 .63761 Mtetra
.649 .771 .938 r
.5469 .63761 .55196 .64213 .56151 .63944 .55647 .63495 Mtetra
.653 .774 .937 r
.55647 .63495 .56151 .63944 .57109 .63668 .56608 .63219 Mtetra
.657 .776 .937 r
.56608 .63219 .57109 .63668 .58071 .63385 .57571 .62933 Mtetra
.658 .776 .936 r
.57571 .62933 .58071 .63385 .59036 .63102 .58538 .62644 Mtetra
.657 .774 .935 r
.58538 .62644 .59036 .63102 .60004 .62822 .59509 .62357 Mtetra
.653 .77 .935 r
.59509 .62357 .60004 .62822 .60975 .62549 .60483 .62079 Mtetra
.647 .767 .936 r
.60483 .62079 .60975 .62549 .61951 .62285 .61461 .61813 Mtetra
.643 .765 .937 r
.61461 .61813 .61951 .62285 .6293 .62028 .62442 .61555 Mtetra
.64 .765 .939 r
.62442 .61555 .6293 .62028 .63913 .61773 .63427 .61304 Mtetra
.641 .768 .94 r
.63427 .61304 .63913 .61773 .64899 .61514 .64416 .61047 Mtetra
.645 .771 .94 r
.64416 .61047 .64899 .61514 .65888 .61246 .65408 .6078 Mtetra
.652 .774 .938 r
.65408 .6078 .65888 .61246 .66881 .60963 .66403 .60495 Mtetra
.66 .777 .936 r
.66403 .60495 .66881 .60963 .67876 .60666 .67401 .60194 Mtetra
.664 .777 .933 r
.67401 .60194 .67876 .60666 .68875 .60359 .68402 .59881 Mtetra
.666 .775 .931 r
.68402 .59881 .68875 .60359 .69876 .60048 .69406 .59563 Mtetra
.663 .773 .931 r
.69406 .59563 .69876 .60048 .70881 .59739 .70414 .5925 Mtetra
.659 .771 .932 r
.70414 .5925 .70881 .59739 .71891 .59437 .71426 .58947 Mtetra
.654 .769 .934 r
.71426 .58947 .71891 .59437 .72904 .59144 .72442 .58656 Mtetra
.649 .769 .936 r
.72442 .58656 .72904 .59144 .73921 .58858 .73462 .58373 Mtetra
.648 .771 .938 r
.73462 .58373 .73921 .58858 .74943 .58575 .74487 .58092 Mtetra
.648 .772 .939 r
.74487 .58092 .74943 .58575 .75968 .58291 .75514 .57808 Mtetra
.652 .774 .938 r
.75514 .57808 .75968 .58291 .76996 .58002 .76545 .57515 Mtetra
.656 .775 .937 r
.76545 .57515 .76996 .58002 .78027 .57704 .77579 .57211 Mtetra
.661 .775 .934 r
.77579 .57211 .78027 .57704 .79062 .57398 .78616 .56895 Mtetra
.665 .773 .93 r
.78616 .56895 .79062 .57398 .801 .57083 .79656 .5657 Mtetra
.667 .77 .927 r
.79656 .5657 .801 .57083 .81141 .56763 .80699 .56239 Mtetra
.668 .767 .924 r
.80699 .56239 .81141 .56763 .82185 .56439 .81746 .55904 Mtetra
.668 .763 .922 r
.81746 .55904 .82185 .56439 .83233 .56115 .82796 .55571 Mtetra
.666 .76 .92 r
.82796 .55571 .83233 .56115 .84285 .55791 .8385 .55239 Mtetra
.665 .757 .919 r
.8385 .55239 .84285 .55791 .85341 .55469 .84908 .54911 Mtetra
.663 .755 .919 r
.84908 .54911 .85341 .55469 .86401 .5515 .85971 .54588 Mtetra
.661 .753 .919 r
.85971 .54588 .86401 .5515 .87465 .54834 .87038 .54268 Mtetra
.659 .752 .919 r
.87038 .54268 .87465 .54834 .88534 .5452 .88109 .53952 Mtetra
.658 .751 .919 r
.88109 .53952 .88534 .5452 .89606 .54209 .89184 .53638 Mtetra
.657 .751 .919 r
.89184 .53638 .89606 .54209 .90683 .53898 .90264 .53326 Mtetra
.656 .751 .92 r
.90264 .53326 .90683 .53898 .91764 .53589 .91348 .53015 Mtetra
.91348 .53015 .91764 .53589 .92849 .53279 .92436 .52704 Mtetra
.655 .751 .92 r
.92436 .52704 .92849 .53279 .93938 .5297 .93528 .52392 Mtetra
.93528 .52392 .93938 .5297 .95031 .5266 .94625 .5208 Mtetra
.94625 .5208 .95031 .5266 .96129 .52349 .95725 .51768 Mtetra
.95725 .51768 .96129 .52349 .9723 .52037 .96829 .51454 Mtetra
.657 .752 .92 r
.37472 .67831 .38018 .68308 .38918 .68047 .38373 .67569 Mtetra
.38373 .67569 .38918 .68047 .39821 .67786 .39278 .67307 Mtetra
.39278 .67307 .39821 .67786 .40726 .67525 .40186 .67044 Mtetra
.40186 .67044 .40726 .67525 .41635 .67263 .41097 .6678 Mtetra
.656 .752 .92 r
.41097 .6678 .41635 .67263 .42547 .67001 .4201 .66516 Mtetra
.656 .751 .92 r
.4201 .66516 .42547 .67001 .43462 .66739 .42927 .66252 Mtetra
.655 .751 .92 r
.42927 .66252 .43462 .66739 .4438 .66478 .43847 .65988 Mtetra
.654 .75 .92 r
.43847 .65988 .4438 .66478 .45301 .6622 .4477 .65727 Mtetra
.653 .749 .921 r
.4477 .65727 .45301 .6622 .46225 .65964 .45697 .65468 Mtetra
.651 .748 .921 r
.45697 .65468 .46225 .65964 .47153 .65711 .46626 .65212 Mtetra
.648 .747 .922 r
.46626 .65212 .47153 .65711 .48083 .65462 .47558 .64962 Mtetra
.645 .746 .923 r
.47558 .64962 .48083 .65462 .49017 .65217 .48494 .64717 Mtetra
.642 .746 .924 r
.48494 .64717 .49017 .65217 .49954 .64977 .49433 .64478 Mtetra
.64 .746 .926 r
.49433 .64478 .49954 .64977 .50894 .64739 .50376 .64243 Mtetra
.637 .748 .928 r
.50376 .64243 .50894 .64739 .51838 .64501 .51321 .64012 Mtetra
.637 .751 .931 r
.51321 .64012 .51838 .64501 .52785 .64261 .52271 .6378 Mtetra
.638 .755 .933 r
.52271 .6378 .52785 .64261 .53736 .64016 .53223 .63544 Mtetra
.641 .761 .935 r
.53223 .63544 .53736 .64016 .5469 .63761 .5418 .63298 Mtetra
.646 .767 .937 r
.5418 .63298 .5469 .63761 .55647 .63495 .55139 .63039 Mtetra
.652 .772 .937 r
.55139 .63039 .55647 .63495 .56608 .63219 .56102 .62765 Mtetra
.657 .775 .936 r
.56102 .62765 .56608 .63219 .57571 .62933 .57069 .62477 Mtetra
.66 .776 .935 r
.57069 .62477 .57571 .62933 .58538 .62644 .58038 .62182 Mtetra
.661 .774 .933 r
.58038 .62182 .58538 .62644 .59509 .62357 .59011 .61885 Mtetra
.657 .77 .932 r
.59011 .61885 .59509 .62357 .60483 .62079 .59987 .61597 Mtetra
.651 .765 .932 r
.59987 .61597 .60483 .62079 .61461 .61813 .60967 .61323 Mtetra
.645 .76 .932 r
.60967 .61323 .61461 .61813 .62442 .61555 .61951 .6106 Mtetra
.641 .757 .933 r
.61951 .6106 .62442 .61555 .63427 .61304 .62938 .60807 Mtetra
.642 .758 .933 r
.62938 .60807 .63427 .61304 .64416 .61047 .6393 .6055 Mtetra
.647 .76 .932 r
.6393 .6055 .64416 .61047 .65408 .6078 .64924 .60283 Mtetra
.654 .763 .929 r
.64924 .60283 .65408 .6078 .66403 .60495 .65922 .59996 Mtetra
.662 .765 .927 r
.65922 .59996 .66403 .60495 .67401 .60194 .66922 .59691 Mtetra
.666 .766 .925 r
.66922 .59691 .67401 .60194 .68402 .59881 .67926 .59375 Mtetra
.667 .766 .924 r
.67926 .59375 .68402 .59881 .69406 .59563 .68932 .59055 Mtetra
.663 .764 .925 r
.68932 .59055 .69406 .59563 .70414 .5925 .69943 .58744 Mtetra
.657 .764 .928 r
.69943 .58744 .70414 .5925 .71426 .58947 .70957 .58445 Mtetra
.651 .764 .932 r
.70957 .58445 .71426 .58947 .72442 .58656 .71977 .5816 Mtetra
.646 .766 .936 r
.71977 .5816 .72442 .58656 .73462 .58373 .73 .57884 Mtetra
.646 .769 .939 r
.73 .57884 .73462 .58373 .74487 .58092 .74027 .57606 Mtetra
.648 .772 .939 r
.74027 .57606 .74487 .58092 .75514 .57808 .75058 .57321 Mtetra
.654 .774 .937 r
.75058 .57321 .75514 .57808 .76545 .57515 .76092 .57021 Mtetra
.66 .775 .934 r
.76092 .57021 .76545 .57515 .77579 .57211 .77128 .56706 Mtetra
.666 .773 .93 r
.77128 .56706 .77579 .57211 .78616 .56895 .78167 .56378 Mtetra
.67 .77 .925 r
.78167 .56378 .78616 .56895 .79656 .5657 .79208 .56039 Mtetra
.671 .766 .922 r
.79208 .56039 .79656 .5657 .80699 .56239 .80253 .55696 Mtetra
.671 .762 .919 r
.80253 .55696 .80699 .56239 .81746 .55904 .81302 .55351 Mtetra
.67 .759 .917 r
.81302 .55351 .81746 .55904 .82796 .55571 .82355 .5501 Mtetra
.668 .756 .916 r
.82355 .5501 .82796 .55571 .8385 .55239 .83411 .54673 Mtetra
.665 .753 .916 r
.83411 .54673 .8385 .55239 .84908 .54911 .84472 .54342 Mtetra
.663 .752 .916 r
.84472 .54342 .84908 .54911 .85971 .54588 .85538 .54016 Mtetra
.661 .751 .917 r
.85538 .54016 .85971 .54588 .87038 .54268 .86607 .53696 Mtetra
.659 .751 .918 r
.86607 .53696 .87038 .54268 .88109 .53952 .87681 .53378 Mtetra
.657 .751 .919 r
.87681 .53378 .88109 .53952 .89184 .53638 .8876 .53064 Mtetra
.656 .751 .92 r
.8876 .53064 .89184 .53638 .90264 .53326 .89843 .52751 Mtetra
.89843 .52751 .90264 .53326 .91348 .53015 .90929 .52438 Mtetra
.655 .751 .92 r
.90929 .52438 .91348 .53015 .92436 .52704 .92021 .52125 Mtetra
.655 .751 .921 r
.92021 .52125 .92436 .52704 .93528 .52392 .93116 .51812 Mtetra
.93116 .51812 .93528 .52392 .94625 .5208 .94215 .51498 Mtetra
.94215 .51498 .94625 .5208 .95725 .51768 .95318 .51183 Mtetra
.95318 .51183 .95725 .51768 .96829 .51454 .96426 .50866 Mtetra
.656 .752 .92 r
.36922 .67351 .37472 .67831 .38373 .67569 .37826 .67089 Mtetra
.37826 .67089 .38373 .67569 .39278 .67307 .38732 .66826 Mtetra
.38732 .66826 .39278 .67307 .40186 .67044 .39642 .66561 Mtetra
.656 .752 .921 r
.39642 .66561 .40186 .67044 .41097 .6678 .40555 .66296 Mtetra
.656 .753 .921 r
.40555 .66296 .41097 .6678 .4201 .66516 .4147 .6603 Mtetra
.656 .752 .921 r
.4147 .6603 .4201 .66516 .42927 .66252 .42389 .65764 Mtetra
.42389 .65764 .42927 .66252 .43847 .65988 .43311 .65497 Mtetra
.655 .751 .921 r
.43311 .65497 .43847 .65988 .4477 .65727 .44236 .65232 Mtetra
.654 .75 .92 r
.44236 .65232 .4477 .65727 .45697 .65468 .45165 .64968 Mtetra
.652 .748 .92 r
.45165 .64968 .45697 .65468 .46626 .65212 .46096 .64708 Mtetra
.649 .746 .92 r
.46096 .64708 .46626 .65212 .47558 .64962 .47031 .64453 Mtetra
.646 .745 .921 r
.47031 .64453 .47558 .64962 .48494 .64717 .47968 .64205 Mtetra
.643 .743 .922 r
.47968 .64205 .48494 .64717 .49433 .64478 .48909 .63964 Mtetra
.639 .742 .923 r
.48909 .63964 .49433 .64478 .50376 .64243 .49854 .63731 Mtetra
.635 .742 .925 r
.49854 .63731 .50376 .64243 .51321 .64012 .50802 .63505 Mtetra
.633 .744 .928 r
.50802 .63505 .51321 .64012 .52271 .6378 .51753 .63281 Mtetra
.633 .747 .931 r
.51753 .63281 .52271 .6378 .53223 .63544 .52708 .63056 Mtetra
.635 .753 .933 r
.52708 .63056 .53223 .63544 .5418 .63298 .53666 .62822 Mtetra
.641 .761 .935 r
.53666 .62822 .5418 .63298 .55139 .63039 .54628 .62573 Mtetra
.648 .768 .936 r
.54628 .62573 .55139 .63039 .56102 .62765 .55594 .62306 Mtetra
.657 .774 .935 r
.55594 .62306 .56102 .62765 .57069 .62477 .56562 .62018 Mtetra
.662 .776 .934 r
.56562 .62018 .57069 .62477 .58038 .62182 .57534 .61716 Mtetra
.666 .775 .931 r
.57534 .61716 .58038 .62182 .59011 .61885 .58509 .61406 Mtetra
.663 .77 .929 r
.58509 .61406 .59011 .61885 .59987 .61597 .59487 .61101 Mtetra
.658 .762 .927 r
.59487 .61101 .59987 .61597 .60967 .61323 .60469 .6081 Mtetra
.652 .754 .925 r
.60469 .6081 .60967 .61323 .61951 .6106 .61455 .60534 Mtetra
.646 .748 .923 r
.61455 .60534 .61951 .6106 .62938 .60807 .62445 .60272 Mtetra
.646 .745 .921 r
.62445 .60272 .62938 .60807 .6393 .6055 .63439 .60009 Mtetra
.649 .744 .919 r
.63439 .60009 .6393 .6055 .64924 .60283 .64435 .59738 Mtetra
.656 .746 .916 r
.64435 .59738 .64924 .60283 .65922 .59996 .65435 .5945 Mtetra
.662 .748 .914 r
.65435 .5945 .65922 .59996 .66922 .59691 .66438 .59144 Mtetra
.665 .75 .913 r
.66438 .59144 .66922 .59691 .67926 .59375 .67444 .5883 Mtetra
.665 .751 .914 r
.67444 .5883 .67926 .59375 .68932 .59055 .68453 .58515 Mtetra
.659 .752 .919 r
.68453 .58515 .68932 .59055 .69943 .58744 .69467 .58214 Mtetra
.652 .754 .925 r
.69467 .58214 .69943 .58744 .70957 .58445 .70485 .57929 Mtetra
.645 .758 .931 r
.70485 .57929 .70957 .58445 .71977 .5816 .71508 .57656 Mtetra
.641 .762 .936 r
.71508 .57656 .71977 .5816 .73 .57884 .72535 .5739 Mtetra
.643 .768 .939 r
.72535 .5739 .73 .57884 .74027 .57606 .73565 .57115 Mtetra
.649 .772 .939 r
.73565 .57115 .74027 .57606 .75058 .57321 .74598 .56826 Mtetra
.658 .775 .935 r
.74598 .56826 .75058 .57321 .76092 .57021 .75634 .56516 Mtetra
.666 .774 .93 r
.75634 .56516 .76092 .57021 .77128 .56706 .76672 .56187 Mtetra
.672 .771 .925 r
.76672 .56187 .77128 .56706 .78167 .56378 .77713 .55842 Mtetra
.675 .766 .919 r
.77713 .55842 .78167 .56378 .79208 .56039 .78756 .55489 Mtetra
.675 .761 .916 r
.78756 .55489 .79208 .56039 .80253 .55696 .79803 .55133 Mtetra
.674 .757 .913 r
.79803 .55133 .80253 .55696 .81302 .55351 .80854 .5478 Mtetra
.671 .754 .912 r
.80854 .5478 .81302 .55351 .82355 .5501 .81909 .54433 Mtetra
.668 .751 .913 r
.81909 .54433 .82355 .5501 .83411 .54673 .82969 .54094 Mtetra
.665 .75 .914 r
.82969 .54094 .83411 .54673 .84472 .54342 .84032 .53763 Mtetra
.662 .75 .915 r
.84032 .53763 .84472 .54342 .85538 .54016 .85101 .53438 Mtetra
.66 .75 .917 r
.85101 .53438 .85538 .54016 .86607 .53696 .86174 .53118 Mtetra
.658 .75 .918 r
.86174 .53118 .86607 .53696 .87681 .53378 .87251 .52802 Mtetra
.657 .751 .919 r
.87251 .52802 .87681 .53378 .8876 .53064 .88333 .52487 Mtetra
.656 .751 .92 r
.88333 .52487 .8876 .53064 .89843 .52751 .89418 .52174 Mtetra
.655 .752 .921 r
.89418 .52174 .89843 .52751 .90929 .52438 .90508 .5186 Mtetra
.90508 .5186 .90929 .52438 .92021 .52125 .91602 .51545 Mtetra
.91602 .51545 .92021 .52125 .93116 .51812 .92701 .5123 Mtetra
.92701 .5123 .93116 .51812 .94215 .51498 .93803 .50913 Mtetra
.93803 .50913 .94215 .51498 .95318 .51183 .94909 .50595 Mtetra
.94909 .50595 .95318 .51183 .96426 .50866 .9602 .50275 Mtetra
.656 .751 .92 r
.36369 .66869 .36922 .67351 .37826 .67089 .37275 .66606 Mtetra
.656 .752 .921 r
.37275 .66606 .37826 .67089 .38732 .66826 .38183 .66343 Mtetra
.656 .753 .921 r
.38183 .66343 .38732 .66826 .39642 .66561 .39094 .66078 Mtetra
.39094 .66078 .39642 .66561 .40555 .66296 .40009 .65812 Mtetra
.656 .754 .922 r
.40009 .65812 .40555 .66296 .4147 .6603 .40927 .65545 Mtetra
.40927 .65545 .4147 .6603 .42389 .65764 .41848 .65276 Mtetra
.656 .753 .921 r
.41848 .65276 .42389 .65764 .43311 .65497 .42772 .65006 Mtetra
.42772 .65006 .43311 .65497 .44236 .65232 .43699 .64736 Mtetra
.656 .751 .92 r
.43699 .64736 .44236 .65232 .45165 .64968 .44629 .64466 Mtetra
.654 .749 .92 r
.44629 .64466 .45165 .64968 .46096 .64708 .45563 .64199 Mtetra
.652 .747 .919 r
.45563 .64199 .46096 .64708 .47031 .64453 .465 .63937 Mtetra
.649 .743 .918 r
.465 .63937 .47031 .64453 .47968 .64205 .47439 .63681 Mtetra
.645 .74 .919 r
.47439 .63681 .47968 .64205 .48909 .63964 .48382 .63435 Mtetra
.64 .737 .919 r
.48382 .63435 .48909 .63964 .49854 .63731 .49329 .63199 Mtetra
.634 .735 .921 r
.49329 .63199 .49854 .63731 .50802 .63505 .50279 .62975 Mtetra
.63 .735 .923 r
.50279 .62975 .50802 .63505 .51753 .63281 .51232 .62759 Mtetra
.627 .738 .927 r
.51232 .62759 .51753 .63281 .52708 .63056 .52189 .62547 Mtetra
.629 .744 .931 r
.52189 .62547 .52708 .63056 .53666 .62822 .5315 .62328 Mtetra
.633 .753 .934 r
.5315 .62328 .53666 .62822 .54628 .62573 .54114 .62096 Mtetra
.643 .763 .936 r
.54114 .62096 .54628 .62573 .55594 .62306 .55082 .6184 Mtetra
.655 .772 .935 r
.55082 .6184 .55594 .62306 .56562 .62018 .56053 .61555 Mtetra
.665 .777 .933 r
.56053 .61555 .56562 .62018 .57534 .61716 .57027 .61246 Mtetra
.673 .777 .928 r
.57027 .61246 .57534 .61716 .58509 .61406 .58004 .60917 Mtetra
.673 .77 .923 r
.58004 .60917 .58509 .61406 .59487 .61101 .58984 .60588 Mtetra
.669 .76 .918 r
.58984 .60588 .59487 .61101 .60469 .6081 .59968 .60269 Mtetra
.662 .748 .914 r
.59968 .60269 .60469 .6081 .61455 .60534 .60956 .59968 Mtetra
.654 .737 .91 r
.60956 .59968 .61455 .60534 .62445 .60272 .61947 .59686 Mtetra
.652 .73 .906 r
.61947 .59686 .62445 .60272 .63439 .60009 .62942 .59411 Mtetra
.652 .726 .903 r
.62942 .59411 .63439 .60009 .64435 .59738 .63941 .59133 Mtetra
.657 .726 .9 r
.63941 .59133 .64435 .59738 .65435 .5945 .64943 .58843 Mtetra
.661 .727 .898 r
.64943 .58843 .65435 .5945 .66438 .59144 .65949 .5854 Mtetra
.661 .729 .899 r
.65949 .5854 .66438 .59144 .67444 .5883 .66957 .58235 Mtetra
.659 .732 .904 r
.66957 .58235 .67444 .5883 .68453 .58515 .6797 .57936 Mtetra
.651 .735 .911 r
.6797 .57936 .68453 .58515 .69467 .58214 .68987 .57656 Mtetra
.642 .741 .921 r
.68987 .57656 .69467 .58214 .70485 .57929 .70009 .57395 Mtetra
.636 .749 .93 r
.70009 .57395 .70485 .57929 .71508 .57656 .71036 .57144 Mtetra
.634 .758 .937 r
.71036 .57144 .71508 .57656 .72535 .5739 .72066 .56892 Mtetra
.641 .767 .94 r
.72066 .56892 .72535 .5739 .73565 .57115 .73099 .56621 Mtetra
.651 .773 .938 r
.73099 .56621 .73565 .57115 .74598 .56826 .74135 .56326 Mtetra
.663 .775 .933 r
.74135 .56326 .74598 .56826 .75634 .56516 .75173 .56 Mtetra
.673 .773 .925 r
.75173 .56 .75634 .56516 .76672 .56187 .76212 .5565 Mtetra
.679 .768 .918 r
.76212 .5565 .76672 .56187 .77713 .55842 .77255 .55286 Mtetra
.681 .761 .912 r
.77255 .55286 .77713 .55842 .78756 .55489 .783 .54915 Mtetra
.679 .755 .909 r
.783 .54915 .78756 .55489 .79803 .55133 .79349 .54548 Mtetra
.676 .751 .907 r
.79349 .54548 .79803 .55133 .80854 .5478 .80402 .54188 Mtetra
.671 .747 .908 r
.80402 .54188 .80854 .5478 .81909 .54433 .8146 .5384 Mtetra
.667 .746 .909 r
.8146 .5384 .81909 .54433 .82969 .54094 .82522 .53503 Mtetra
.663 .746 .912 r
.82522 .53503 .82969 .54094 .84032 .53763 .83589 .53175 Mtetra
.66 .747 .914 r
.83589 .53175 .84032 .53763 .85101 .53438 .84661 .52854 Mtetra
.658 .748 .917 r
.84661 .52854 .85101 .53438 .86174 .53118 .85737 .52538 Mtetra
.656 .75 .919 r
.85737 .52538 .86174 .53118 .87251 .52802 .86818 .52224 Mtetra
.655 .751 .92 r
.86818 .52224 .87251 .52802 .88333 .52487 .87903 .5191 Mtetra
.655 .752 .921 r
.87903 .5191 .88333 .52487 .89418 .52174 .88992 .51596 Mtetra
.655 .753 .922 r
.88992 .51596 .89418 .52174 .90508 .5186 .90085 .51281 Mtetra
.90085 .51281 .90508 .5186 .91602 .51545 .91182 .50964 Mtetra
.91182 .50964 .91602 .51545 .92701 .5123 .92283 .50645 Mtetra
.656 .753 .922 r
.92283 .50645 .92701 .5123 .93803 .50913 .93388 .50325 Mtetra
.656 .753 .921 r
.93388 .50325 .93803 .50913 .94909 .50595 .94497 .50003 Mtetra
.656 .752 .921 r
.94497 .50003 .94909 .50595 .9602 .50275 .9561 .4968 Mtetra
.655 .751 .921 r
.35813 .66383 .36369 .66869 .37275 .66606 .3672 .66121 Mtetra
.655 .752 .921 r
.3672 .66121 .37275 .66606 .38183 .66343 .3763 .65858 Mtetra
.655 .753 .922 r
.3763 .65858 .38183 .66343 .39094 .66078 .38544 .65593 Mtetra
.655 .754 .922 r
.38544 .65593 .39094 .66078 .40009 .65812 .3946 .65327 Mtetra
.656 .754 .922 r
.3946 .65327 .40009 .65812 .40927 .65545 .4038 .65059 Mtetra
.656 .755 .922 r
.4038 .65059 .40927 .65545 .41848 .65276 .41303 .64788 Mtetra
.657 .755 .922 r
.41303 .64788 .41848 .65276 .42772 .65006 .42229 .64515 Mtetra
.42229 .64515 .42772 .65006 .43699 .64736 .43158 .64241 Mtetra
.657 .754 .921 r
.43158 .64241 .43699 .64736 .44629 .64466 .44091 .63965 Mtetra
.657 .752 .92 r
.44091 .63965 .44629 .64466 .45563 .64199 .45026 .6369 Mtetra
.655 .749 .919 r
.45026 .6369 .45563 .64199 .465 .63937 .45965 .63418 Mtetra
.653 .745 .917 r
.45965 .63418 .465 .63937 .47439 .63681 .46907 .63152 Mtetra
.648 .74 .917 r
.46907 .63152 .47439 .63681 .48382 .63435 .47852 .62896 Mtetra
.642 .736 .916 r
.47852 .62896 .48382 .63435 .49329 .63199 .48801 .62653 Mtetra
.635 .731 .918 r
.48801 .62653 .49329 .63199 .50279 .62975 .49752 .62427 Mtetra
.628 .729 .92 r
.49752 .62427 .50279 .62975 .51232 .62759 .50708 .62215 Mtetra
.622 .729 .923 r
.50708 .62215 .51232 .62759 .52189 .62547 .51667 .62015 Mtetra
.621 .734 .928 r
.51667 .62015 .52189 .62547 .5315 .62328 .52629 .61814 Mtetra
.624 .743 .932 r
.52629 .61814 .5315 .62328 .54114 .62096 .53596 .61603 Mtetra
.635 .756 .935 r
.53596 .61603 .54114 .62096 .55082 .6184 .54566 .61365 Mtetra
.651 .768 .935 r
.54566 .61365 .55082 .6184 .56053 .61555 .5554 .61088 Mtetra
.667 .777 .932 r
.5554 .61088 .56053 .61555 .57027 .61246 .56516 .60773 Mtetra
.681 .779 .925 r
.56516 .60773 .57027 .61246 .58004 .60917 .57495 .60422 Mtetra
.686 .772 .917 r
.57495 .60422 .58004 .60917 .58984 .60588 .58478 .60058 Mtetra
.684 .759 .908 r
.58478 .60058 .58984 .60588 .59968 .60269 .59463 .59696 Mtetra
.676 .742 .9 r
.59463 .59696 .59968 .60269 .60956 .59968 .60452 .59355 Mtetra
.666 .725 .893 r
.60452 .59355 .60956 .59968 .61947 .59686 .61445 .5904 Mtetra
.66 .713 .887 r
.61445 .5904 .61947 .59686 .62942 .59411 .62441 .5874 Mtetra
.656 .704 .882 r
.62441 .5874 .62942 .59411 .63941 .59133 .63442 .5845 Mtetra
.657 .701 .879 r
.63442 .5845 .63941 .59133 .64943 .58843 .64446 .58157 Mtetra
.64446 .58157 .64943 .58843 .65949 .5854 .65454 .57863 Mtetra
.653 .703 .883 r
.65454 .57863 .65949 .5854 .66957 .58235 .66465 .57578 Mtetra
.648 .708 .891 r
.66465 .57578 .66957 .58235 .6797 .57936 .67481 .57309 Mtetra
.637 .715 .903 r
.67481 .57309 .6797 .57936 .68987 .57656 .68503 .57066 Mtetra
.627 .725 .917 r
.68503 .57066 .68987 .57656 .70009 .57395 .69529 .56843 Mtetra
.622 .738 .93 r
.69529 .56843 .70009 .57395 .71036 .57144 .7056 .56624 Mtetra
.625 .753 .939 r
.7056 .56624 .71036 .57144 .72066 .56892 .71594 .56391 Mtetra
.639 .767 .94 r
.71594 .56391 .72066 .56892 .73099 .56621 .7263 .56123 Mtetra
.656 .774 .936 r
.7263 .56123 .73099 .56621 .74135 .56326 .73668 .55815 Mtetra
.672 .775 .928 r
.73668 .55815 .74135 .56326 .75173 .56 .74707 .55467 Mtetra
.682 .771 .918 r
.74707 .55467 .75173 .56 .76212 .5565 .75748 .55092 Mtetra
.686 .763 .91 r
.75748 .55092 .76212 .5565 .77255 .55286 .76792 .54706 Mtetra
.685 .756 .905 r
.76792 .54706 .77255 .55286 .783 .54915 .77839 .54319 Mtetra
.681 .749 .903 r
.77839 .54319 .783 .54915 .79349 .54548 .7889 .53943 Mtetra
.675 .745 .903 r
.7889 .53943 .79349 .54548 .80402 .54188 .79946 .53582 Mtetra
.669 .743 .905 r
.79946 .53582 .80402 .54188 .8146 .5384 .81007 .53237 Mtetra
.664 .743 .909 r
.81007 .53237 .8146 .5384 .82522 .53503 .82072 .52906 Mtetra
.66 .744 .912 r
.82072 .52906 .82522 .53503 .83589 .53175 .83143 .52585 Mtetra
.657 .746 .916 r
.83143 .52585 .83589 .53175 .84661 .52854 .84219 .5227 Mtetra
.655 .749 .919 r
.84219 .5227 .84661 .52854 .85737 .52538 .85298 .51958 Mtetra
.654 .751 .921 r
.85298 .51958 .85737 .52538 .86818 .52224 .86382 .51646 Mtetra
.654 .752 .922 r
.86382 .51646 .86818 .52224 .87903 .5191 .8747 .51333 Mtetra
.654 .754 .923 r
.8747 .51333 .87903 .5191 .88992 .51596 .88562 .51019 Mtetra
.655 .754 .923 r
.88562 .51019 .88992 .51596 .90085 .51281 .89658 .50701 Mtetra
.89658 .50701 .90085 .51281 .91182 .50964 .90758 .50381 Mtetra
.656 .754 .922 r
.90758 .50381 .91182 .50964 .92283 .50645 .91862 .50058 Mtetra
.91862 .50058 .92283 .50645 .93388 .50325 .9297 .49734 Mtetra
.656 .753 .921 r
.9297 .49734 .93388 .50325 .94497 .50003 .94082 .49408 Mtetra
.657 .753 .921 r
.94082 .49408 .94497 .50003 .9561 .4968 .95198 .4908 Mtetra
.654 .751 .921 r
.35253 .65894 .35813 .66383 .3672 .66121 .36162 .65633 Mtetra
.654 .752 .922 r
.36162 .65633 .3672 .66121 .3763 .65858 .37074 .65371 Mtetra
.654 .753 .922 r
.37074 .65371 .3763 .65858 .38544 .65593 .37989 .65107 Mtetra
.654 .754 .923 r
.37989 .65107 .38544 .65593 .3946 .65327 .38907 .64841 Mtetra
.655 .755 .923 r
.38907 .64841 .3946 .65327 .4038 .65059 .39829 .64573 Mtetra
.656 .756 .924 r
.39829 .64573 .4038 .65059 .41303 .64788 .40754 .64302 Mtetra
.657 .757 .923 r
.40754 .64302 .41303 .64788 .42229 .64515 .41682 .64027 Mtetra
.658 .757 .923 r
.41682 .64027 .42229 .64515 .43158 .64241 .42614 .6375 Mtetra
.659 .757 .922 r
.42614 .6375 .43158 .64241 .44091 .63965 .43548 .63468 Mtetra
.659 .755 .921 r
.43548 .63468 .44091 .63965 .45026 .6369 .44486 .63185 Mtetra
.659 .753 .919 r
.44486 .63185 .45026 .6369 .45965 .63418 .45427 .62901 Mtetra
.657 .748 .917 r
.45427 .62901 .45965 .63418 .46907 .63152 .46371 .62622 Mtetra
.654 .743 .915 r
.46371 .62622 .46907 .63152 .47852 .62896 .47319 .62351 Mtetra
.647 .736 .914 r
.47319 .62351 .47852 .62896 .48801 .62653 .48269 .62096 Mtetra
.638 .729 .914 r
.48269 .62096 .48801 .62653 .49752 .62427 .49223 .61861 Mtetra
.629 .723 .915 r
.49223 .61861 .49752 .62427 .50708 .62215 .5018 .61648 Mtetra
.618 .72 .919 r
.5018 .61648 .50708 .62215 .51667 .62015 .51141 .61458 Mtetra
.613 .723 .924 r
.51141 .61458 .51667 .62015 .52629 .61814 .52106 .61276 Mtetra
.612 .731 .93 r
.52106 .61276 .52629 .61814 .53596 .61603 .53074 .61092 Mtetra
.623 .746 .934 r
.53074 .61092 .53596 .61603 .54566 .61365 .54047 .60878 Mtetra
.643 .763 .935 r
.54047 .60878 .54566 .61365 .5554 .61088 .55023 .60617 Mtetra
.667 .777 .931 r
.55023 .60617 .5554 .61088 .56516 .60773 .56002 .60298 Mtetra
.691 .782 .921 r
.56002 .60298 .56516 .60773 .57495 .60422 .56983 .59919 Mtetra
.702 .775 .908 r
.56983 .59919 .57495 .60422 .58478 .60058 .57967 .59509 Mtetra
.704 .759 .895 r
.57967 .59509 .58478 .60058 .59463 .59696 .58954 .59087 Mtetra
.695 .736 .883 r
.58954 .59087 .59463 .59696 .60452 .59355 .59944 .58685 Mtetra
.681 .713 .873 r
.59944 .58685 .60452 .59355 .61445 .5904 .60937 .58318 Mtetra
.67 .695 .864 r
.60937 .58318 .61445 .5904 .62441 .5874 .61935 .5798 Mtetra
.66 .681 .859 r
.61935 .5798 .62441 .5874 .63442 .5845 .62937 .5767 Mtetra
.655 .674 .856 r
.62937 .5767 .63442 .5845 .64446 .58157 .63943 .57375 Mtetra
.65 .672 .858 r
.63943 .57375 .64446 .58157 .65454 .57863 .64953 .57096 Mtetra
.641 .673 .865 r
.64953 .57096 .65454 .57863 .66465 .57578 .65967 .56845 Mtetra
.63 .679 .878 r
.65967 .56845 .66465 .57578 .67481 .57309 .66988 .56624 Mtetra
.616 .688 .895 r
.66988 .56624 .67481 .57309 .68503 .57066 .68014 .56439 Mtetra
.604 .704 .914 r
.68014 .56439 .68503 .57066 .69529 .56843 .69045 .56273 Mtetra
.603 .725 .931 r
.69045 .56273 .69529 .56843 .7056 .56624 .70081 .56096 Mtetra
.613 .747 .941 r
.70081 .56096 .7056 .56624 .71594 .56391 .71119 .55888 Mtetra
.638 .767 .941 r
.71119 .55888 .71594 .56391 .7263 .56123 .72158 .55619 Mtetra
.663 .776 .933 r
.72158 .55619 .7263 .56123 .73668 .55815 .73198 .55291 Mtetra
.682 .775 .921 r
.73198 .55291 .73668 .55815 .74707 .55467 .74238 .54915 Mtetra
.692 .768 .91 r
.74238 .54915 .74707 .55467 .75748 .55092 .75279 .54509 Mtetra
.693 .758 .902 r
.75279 .54509 .75748 .55092 .76792 .54706 .76324 .54099 Mtetra
.689 .749 .897 r
.76324 .54099 .76792 .54706 .77839 .54319 .77373 .53698 Mtetra
.681 .742 .897 r
.77373 .53698 .77839 .54319 .7889 .53943 .78427 .53319 Mtetra
.673 .738 .9 r
.78427 .53319 .7889 .53943 .79946 .53582 .79486 .52962 Mtetra
.665 .738 .904 r
.79486 .52962 .79946 .53582 .81007 .53237 .8055 .52627 Mtetra
.659 .74 .909 r
.8055 .52627 .81007 .53237 .82072 .52906 .8162 .52307 Mtetra
.655 .743 .914 r
.8162 .52307 .82072 .52906 .83143 .52585 .82695 .51996 Mtetra
.653 .747 .919 r
.82695 .51996 .83143 .52585 .84219 .5227 .83774 .51689 Mtetra
.652 .75 .921 r
.83774 .51689 .84219 .5227 .85298 .51958 .84857 .51381 Mtetra
.652 .753 .923 r
.84857 .51381 .85298 .51958 .86382 .51646 .85945 .51072 Mtetra
.653 .755 .924 r
.85945 .51072 .86382 .51646 .8747 .51333 .87036 .50758 Mtetra
.654 .756 .924 r
.87036 .50758 .8747 .51333 .88562 .51019 .88131 .50441 Mtetra
.655 .756 .924 r
.88131 .50441 .88562 .51019 .89658 .50701 .8923 .5012 Mtetra
.656 .756 .923 r
.8923 .5012 .89658 .50701 .90758 .50381 .90332 .49796 Mtetra
.657 .755 .923 r
.90332 .49796 .90758 .50381 .91862 .50058 .91439 .49469 Mtetra
.657 .755 .922 r
.91439 .49469 .91862 .50058 .9297 .49734 .9255 .4914 Mtetra
.657 .754 .921 r
.9255 .4914 .9297 .49734 .94082 .49408 .93665 .48809 Mtetra
.657 .753 .92 r
.93665 .48809 .94082 .49408 .95198 .4908 .94784 .48476 Mtetra
.653 .751 .921 r
.34689 .65403 .35253 .65894 .36162 .65633 .356 .65142 Mtetra
.653 .751 .922 r
.356 .65142 .36162 .65633 .37074 .65371 .36514 .6488 Mtetra
.653 .752 .923 r
.36514 .6488 .37074 .65371 .37989 .65107 .37431 .64616 Mtetra
.653 .753 .923 r
.37431 .64616 .37989 .65107 .38907 .64841 .38351 .64352 Mtetra
.654 .754 .924 r
.38351 .64352 .38907 .64841 .39829 .64573 .39275 .64084 Mtetra
.654 .756 .924 r
.39275 .64084 .39829 .64573 .40754 .64302 .40202 .63814 Mtetra
.656 .757 .924 r
.40202 .63814 .40754 .64302 .41682 .64027 .41132 .6354 Mtetra
.657 .758 .924 r
.41132 .6354 .41682 .64027 .42614 .6375 .42065 .63261 Mtetra
.659 .759 .924 r
.42065 .63261 .42614 .6375 .43548 .63468 .43002 .62976 Mtetra
.661 .759 .922 r
.43002 .62976 .43548 .63468 .44486 .63185 .43942 .62686 Mtetra
.663 .757 .92 r
.43942 .62686 .44486 .63185 .45427 .62901 .44886 .62392 Mtetra
.662 .754 .918 r
.44886 .62392 .45427 .62901 .46371 .62622 .45832 .62098 Mtetra
.66 .748 .915 r
.45832 .62098 .46371 .62622 .47319 .62351 .46782 .6181 Mtetra
.654 .741 .913 r
.46782 .6181 .47319 .62351 .48269 .62096 .47735 .61536 Mtetra
.644 .732 .912 r
.47735 .61536 .48269 .62096 .49223 .61861 .48691 .61285 Mtetra
.632 .722 .912 r
.48691 .61285 .49223 .61861 .5018 .61648 .4965 .61063 Mtetra
.617 .715 .915 r
.4965 .61063 .5018 .61648 .51141 .61458 .50612 .60876 Mtetra
.607 .712 .92 r
.50612 .60876 .51141 .61458 .52106 .61276 .51579 .60709 Mtetra
.6 .716 .926 r
.51579 .60709 .52106 .61276 .53074 .61092 .52549 .60554 Mtetra
.609 .732 .932 r
.52549 .60554 .53074 .61092 .54047 .60878 .53524 .60371 Mtetra
.632 .752 .935 r
.53524 .60371 .54047 .60878 .55023 .60617 .54503 .60135 Mtetra
.665 .773 .93 r
.54503 .60135 .55023 .60617 .56002 .60298 .55484 .5982 Mtetra
.701 .784 .916 r
.55484 .5982 .56002 .60298 .56983 .59919 .56468 .59414 Mtetra
.72 .779 .899 r
.56468 .59414 .56983 .59919 .57967 .59509 .57454 .58947 Mtetra
.726 .761 .88 r
.57454 .58947 .57967 .59509 .58954 .59087 .58442 .58446 Mtetra
.716 .733 .864 r
.58442 .58446 .58954 .59087 .59944 .58685 .59432 .5796 Mtetra
.699 .705 .851 r
.59432 .5796 .59944 .58685 .60937 .58318 .60426 .57517 Mtetra
.682 .679 .841 r
.60426 .57517 .60937 .58318 .61935 .5798 .61423 .57123 Mtetra
.665 .66 .835 r
.61423 .57123 .61935 .5798 .62937 .5767 .62426 .56782 Mtetra
.652 .648 .833 r
.62426 .56782 .62937 .5767 .63943 .57375 .63433 .56485 Mtetra
.639 .642 .837 r
.63433 .56485 .63943 .57375 .64953 .57096 .64446 .56232 Mtetra
.623 .641 .848 r
.64446 .56232 .64953 .57096 .65967 .56845 .65464 .56034 Mtetra
.606 .647 .865 r
.65464 .56034 .65967 .56845 .66988 .56624 .66489 .55885 Mtetra
.586 .659 .888 r
.66489 .55885 .66988 .56624 .68014 .56439 .6752 .55779 Mtetra
.572 .68 .913 r
.6752 .55779 .68014 .56439 .69045 .56273 .68557 .55689 Mtetra
.578 .711 .933 r
.68557 .55689 .69045 .56273 .70081 .56096 .69598 .55565 Mtetra
.601 .742 .944 r
.69598 .55565 .70081 .56096 .71119 .55888 .7064 .55381 Mtetra
.641 .768 .94 r
.7064 .55381 .71119 .55888 .72158 .55619 .71682 .55105 Mtetra
.674 .777 .927 r
.71682 .55105 .72158 .55619 .73198 .55291 .72723 .54748 Mtetra
.694 .772 .912 r
.72723 .54748 .73198 .55291 .74238 .54915 .73764 .54336 Mtetra
.702 .763 .899 r
.73764 .54336 .74238 .54915 .75279 .54509 .74806 .53896 Mtetra
.697 .75 .892 r
.74806 .53896 .75279 .54509 .76324 .54099 .75852 .53466 Mtetra
.69 .741 .891 r
.75852 .53466 .76324 .54099 .77373 .53698 .76903 .53058 Mtetra
.678 .736 .894 r
.76903 .53058 .77373 .53698 .78427 .53319 .7796 .52685 Mtetra
.668 .734 .9 r
.7796 .52685 .78427 .53319 .79486 .52962 .79023 .52341 Mtetra
.659 .736 .907 r
.79023 .52341 .79486 .52962 .8055 .52627 .80091 .5202 Mtetra
.653 .74 .913 r
.80091 .5202 .8055 .52627 .8162 .52307 .81165 .51714 Mtetra
.65 .745 .919 r
.81165 .51714 .8162 .52307 .82695 .51996 .82244 .51414 Mtetra
.649 .749 .923 r
.82244 .51414 .82695 .51996 .83774 .51689 .83327 .51114 Mtetra
.65 .753 .925 r
.83327 .51114 .83774 .51689 .84857 .51381 .84414 .50809 Mtetra
.651 .756 .926 r
.84414 .50809 .84857 .51381 .85945 .51072 .85504 .50499 Mtetra
.653 .757 .926 r
.85504 .50499 .85945 .51072 .87036 .50758 .86598 .50183 Mtetra
.655 .758 .925 r
.86598 .50183 .87036 .50758 .88131 .50441 .87696 .49862 Mtetra
.656 .757 .924 r
.87696 .49862 .88131 .50441 .8923 .5012 .88798 .49536 Mtetra
.657 .757 .923 r
.88798 .49536 .8923 .5012 .90332 .49796 .89903 .49207 Mtetra
.658 .756 .922 r
.89903 .49207 .90332 .49796 .91439 .49469 .91013 .48875 Mtetra
.658 .755 .922 r
.91013 .48875 .91439 .49469 .9255 .4914 .92126 .48541 Mtetra
.658 .754 .921 r
.92126 .48541 .9255 .4914 .93665 .48809 .93244 .48205 Mtetra
.658 .753 .92 r
.93244 .48205 .93665 .48809 .94784 .48476 .94366 .47868 Mtetra
.652 .751 .922 r
.34122 .64908 .34689 .65403 .356 .65142 .35035 .64646 Mtetra
.35035 .64646 .356 .65142 .36514 .6488 .35951 .64384 Mtetra
.652 .752 .923 r
.35951 .64384 .36514 .6488 .37431 .64616 .36869 .64121 Mtetra
.36869 .64121 .37431 .64616 .38351 .64352 .37792 .63857 Mtetra
.652 .753 .924 r
.37792 .63857 .38351 .64352 .39275 .64084 .38717 .63592 Mtetra
.653 .755 .925 r
.38717 .63592 .39275 .64084 .40202 .63814 .39646 .63324 Mtetra
.654 .757 .925 r
.39646 .63324 .40202 .63814 .41132 .6354 .40578 .63052 Mtetra
.656 .759 .926 r
.40578 .63052 .41132 .6354 .42065 .63261 .41513 .62775 Mtetra
.658 .761 .926 r
.41513 .62775 .42065 .63261 .43002 .62976 .42452 .6249 Mtetra
.661 .763 .925 r
.42452 .6249 .43002 .62976 .43942 .62686 .43394 .62198 Mtetra
.665 .763 .923 r
.43394 .62198 .43942 .62686 .44886 .62392 .4434 .61896 Mtetra
.667 .761 .921 r
.4434 .61896 .44886 .62392 .45832 .62098 .45289 .61589 Mtetra
.667 .757 .918 r
.45289 .61589 .45832 .62098 .46782 .6181 .46241 .61281 Mtetra
.663 .749 .914 r
.46241 .61281 .46782 .6181 .47735 .61536 .47197 .60983 Mtetra
.654 .738 .911 r
.47197 .60983 .47735 .61536 .48691 .61285 .48155 .60706 Mtetra
.64 .725 .91 r
.48155 .60706 .48691 .61285 .4965 .61063 .49116 .60464 Mtetra
.621 .712 .911 r
.49116 .60464 .4965 .61063 .50612 .60876 .5008 .60267 Mtetra
.604 .703 .914 r
.5008 .60267 .50612 .60876 .51579 .60709 .51049 .6011 Mtetra
.588 .701 .921 r
.51049 .6011 .51579 .60709 .52549 .60554 .52021 .59983 Mtetra
.593 .714 .928 r
.52021 .59983 .52549 .60554 .53524 .60371 .52998 .59838 Mtetra
.615 .738 .933 r
.52998 .59838 .53524 .60371 .54503 .60135 .53979 .5964 Mtetra
.659 .768 .93 r
.53979 .5964 .54503 .60135 .55484 .5982 .54963 .59338 Mtetra
.709 .786 .912 r
.54963 .59338 .55484 .5982 .56468 .59414 .55949 .58907 Mtetra
.738 .784 .889 r
.55949 .58907 .56468 .59414 .57454 .58947 .56937 .58376 Mtetra
.751 .764 .864 r
.56937 .58376 .57454 .58947 .58442 .58446 .57925 .57774 Mtetra
.74 .732 .844 r
.57925 .57774 .58442 .58446 .59432 .5796 .58916 .57177 Mtetra
.72 .698 .828 r
.58916 .57177 .59432 .5796 .60426 .57517 .59909 .56629 Mtetra
.695 .666 .817 r
.59909 .56629 .60426 .57517 .61423 .57123 .60907 .56155 Mtetra
.669 .64 .811 r
.60907 .56155 .61423 .57123 .62426 .56782 .61909 .55772 Mtetra
.647 .622 .81 r
.61909 .55772 .62426 .56782 .63433 .56485 .62918 .55473 Mtetra
.626 .612 .816 r
.62918 .55473 .63433 .56485 .64446 .56232 .63932 .55258 Mtetra
.6 .607 .831 r
.63932 .55258 .64446 .56232 .65464 .56034 .64955 .55134 Mtetra
.572 .611 .852 r
.64955 .55134 .65464 .56034 .66489 .55885 .65985 .55086 Mtetra
.545 .624 .881 r
.65985 .55086 .66489 .55885 .6752 .55779 .67023 .55088 Mtetra
.528 .65 .912 r
.67023 .55088 .6752 .55779 .68557 .55689 .68066 .55096 Mtetra
.547 .695 .937 r
.68066 .55096 .68557 .55689 .69598 .55565 .69112 .55034 Mtetra
.588 .738 .947 r
.69112 .55034 .69598 .55565 .7064 .55381 .70158 .54871 Mtetra
.647 .77 .938 r
.70158 .54871 .7064 .55381 .71682 .55105 .71202 .54577 Mtetra
.69 .778 .918 r
.71202 .54577 .71682 .55105 .72723 .54748 .72243 .54177 Mtetra
.707 .768 .9 r
.72243 .54177 .72723 .54748 .73764 .54336 .73284 .53722 Mtetra
.71 .755 .887 r
.73284 .53722 .73764 .54336 .74806 .53896 .74327 .53249 Mtetra
.699 .741 .883 r
.74327 .53249 .74806 .53896 .75852 .53466 .75375 .52807 Mtetra
.687 .733 .886 r
.75375 .52807 .75852 .53466 .76903 .53058 .76429 .52404 Mtetra
.671 .73 .893 r
.76429 .52404 .76903 .53058 .7796 .52685 .7749 .52047 Mtetra
.659 .731 .903 r
.7749 .52047 .7796 .52685 .79023 .52341 .78558 .51725 Mtetra
.651 .737 .912 r
.78558 .51725 .79023 .52341 .80091 .5202 .79631 .51425 Mtetra
.645 .743 .92 r
.79631 .51425 .80091 .5202 .81165 .51714 .80709 .51136 Mtetra
.645 .75 .926 r
.80709 .51136 .81165 .51714 .82244 .51414 .81792 .50845 Mtetra
.646 .755 .929 r
.81792 .50845 .82244 .51414 .83327 .51114 .82878 .50549 Mtetra
.649 .758 .929 r
.82878 .50549 .83327 .51114 .84414 .50809 .83968 .50243 Mtetra
.652 .76 .929 r
.83968 .50243 .84414 .50809 .85504 .50499 .85061 .49929 Mtetra
.654 .76 .927 r
.85061 .49929 .85504 .50499 .86598 .50183 .86158 .49607 Mtetra
.656 .759 .926 r
.86158 .49607 .86598 .50183 .87696 .49862 .87258 .49279 Mtetra
.658 .758 .924 r
.87258 .49279 .87696 .49862 .88798 .49536 .88363 .48947 Mtetra
.658 .757 .923 r
.88363 .48947 .88798 .49536 .89903 .49207 .89471 .48612 Mtetra
.659 .756 .922 r
.89471 .48612 .89903 .49207 .91013 .48875 .90583 .48275 Mtetra
.659 .755 .921 r
.90583 .48275 .91013 .48875 .92126 .48541 .917 .47936 Mtetra
.659 .754 .92 r
.917 .47936 .92126 .48541 .93244 .48205 .9282 .47596 Mtetra
.659 .753 .92 r
.9282 .47596 .93244 .48205 .94366 .47868 .93945 .47256 Mtetra
.652 .751 .922 r
.33552 .6441 .34122 .64908 .35035 .64646 .34466 .64146 Mtetra
.652 .75 .922 r
.34466 .64146 .35035 .64646 .35951 .64384 .35384 .63883 Mtetra
.35384 .63883 .35951 .64384 .36869 .64121 .36305 .63619 Mtetra
.651 .751 .922 r
.36305 .63619 .36869 .64121 .37792 .63857 .37229 .63355 Mtetra
.651 .751 .923 r
.37229 .63355 .37792 .63857 .38717 .63592 .38156 .63091 Mtetra
.651 .753 .924 r
.38156 .63091 .38717 .63592 .39646 .63324 .39086 .62826 Mtetra
.651 .754 .925 r
.39086 .62826 .39646 .63324 .40578 .63052 .4002 .62558 Mtetra
.653 .757 .926 r
.4002 .62558 .40578 .63052 .41513 .62775 .40958 .62285 Mtetra
.655 .76 .927 r
.40958 .62285 .41513 .62775 .42452 .6249 .41898 .62006 Mtetra
.659 .764 .927 r
.41898 .62006 .42452 .6249 .43394 .62198 .42843 .61716 Mtetra
.664 .767 .926 r
.42843 .61716 .43394 .62198 .4434 .61896 .43791 .61412 Mtetra
.669 .768 .924 r
.43791 .61412 .4434 .61896 .45289 .61589 .44742 .61097 Mtetra
.673 .767 .921 r
.44742 .61097 .45289 .61589 .46241 .61281 .45697 .60772 Mtetra
.672 .76 .917 r
.45697 .60772 .46241 .61281 .47197 .60983 .46655 .60449 Mtetra
.666 .75 .913 r
.46655 .60449 .47197 .60983 .48155 .60706 .47615 .60139 Mtetra
.652 .734 .91 r
.47615 .60139 .48155 .60706 .49116 .60464 .48579 .59864 Mtetra
.631 .717 .909 r
.48579 .59864 .49116 .60464 .5008 .60267 .49546 .59642 Mtetra
.607 .7 .91 r
.49546 .59642 .5008 .60267 .51049 .6011 .50516 .59478 Mtetra
.58 .688 .915 r
.50516 .59478 .51049 .6011 .52021 .59983 .5149 .5937 Mtetra
.576 .694 .922 r
.5149 .5937 .52021 .59983 .52998 .59838 .52468 .59265 Mtetra
.592 .715 .929 r
.52468 .59265 .52998 .59838 .53979 .5964 .53451 .59119 Mtetra
.646 .755 .928 r
.53451 .59119 .53979 .5964 .54963 .59338 .54438 .58847 Mtetra
.711 .784 .909 r
.54438 .58847 .54963 .59338 .55949 .58907 .55427 .58406 Mtetra
.755 .789 .881 r
.55427 .58406 .55949 .58907 .56937 .58376 .56417 .57811 Mtetra
.777 .772 .848 r
.56417 .57811 .56937 .58376 .57925 .57774 .57406 .57094 Mtetra
.767 .737 .826 r
.57406 .57094 .57925 .57774 .58916 .57177 .58397 .56361 Mtetra
.743 .699 .809 r
.58397 .56361 .58916 .57177 .59909 .56629 .5939 .55678 Mtetra
.711 .661 .798 r
.5939 .55678 .59909 .56629 .60907 .56155 .60386 .551 Mtetra
.677 .628 .793 r
.60386 .551 .60907 .56155 .61909 .55772 .61388 .5466 Mtetra
.644 .604 .794 r
.61388 .5466 .61909 .55772 .62918 .55473 .62397 .54359 Mtetra
.61 .587 .802 r
.62397 .54359 .62918 .55473 .63932 .55258 .63414 .54196 Mtetra
.57 .576 .82 r
.63414 .54196 .63932 .55258 .64955 .55134 .64441 .54171 Mtetra
.527 .574 .846 r
.64441 .54171 .64955 .55134 .65985 .55086 .65477 .54254 Mtetra
.488 .587 .88 r
.65477 .54254 .65985 .55086 .67023 .55088 .66522 .54389 Mtetra
.468 .619 .916 r
.66522 .54389 .67023 .55088 .68066 .55096 .67572 .54509 Mtetra
.51 .683 .944 r
.67572 .54509 .68066 .55096 .69112 .55034 .68624 .54506 Mtetra
.583 .739 .95 r
.68624 .54506 .69112 .55034 .70158 .54871 .69673 .5435 Mtetra
.662 .772 .932 r
.69673 .5435 .70158 .54871 .71202 .54577 .70717 .54022 Mtetra
.708 .774 .904 r
.70717 .54022 .71202 .54577 .72243 .54177 .71758 .53565 Mtetra
.718 .758 .884 r
.71758 .53565 .72243 .54177 .73284 .53722 .72799 .53067 Mtetra
.714 .743 .875 r
.72799 .53067 .73284 .53722 .74327 .53249 .73844 .5257 Mtetra
.696 .731 .877 r
.73844 .5257 .74327 .53249 .75375 .52807 .74895 .5213 Mtetra
.679 .726 .885 r
.74895 .5213 .75375 .52807 .76429 .52404 .75953 .51748 Mtetra
.661 .727 .898 r
.75953 .51748 .76429 .52404 .7749 .52047 .77019 .5142 Mtetra
.647 .732 .911 r
.77019 .5142 .7749 .52047 .78558 .51725 .78091 .51129 Mtetra
.64 .741 .922 r
.78091 .51129 .78558 .51725 .79631 .51425 .79169 .50851 Mtetra
.638 .749 .929 r
.79169 .50851 .79631 .51425 .80709 .51136 .80252 .50575 Mtetra
.641 .757 .932 r
.80252 .50575 .80709 .51136 .81792 .50845 .81338 .50288 Mtetra
.645 .761 .933 r
.81338 .50288 .81792 .50845 .82878 .50549 .82427 .4999 Mtetra
.65 .763 .931 r
.82427 .4999 .82878 .50549 .83968 .50243 .8352 .49678 Mtetra
.654 .762 .929 r
.8352 .49678 .83968 .50243 .85061 .49929 .84615 .49354 Mtetra
.657 .761 .926 r
.84615 .49354 .85061 .49929 .86158 .49607 .85714 .49023 Mtetra
.659 .759 .924 r
.85714 .49023 .86158 .49607 .87258 .49279 .86817 .48687 Mtetra
.659 .757 .922 r
.86817 .48687 .87258 .49279 .88363 .48947 .87924 .48348 Mtetra
.66 .755 .921 r
.87924 .48348 .88363 .48947 .89471 .48612 .89035 .48007 Mtetra
.66 .754 .92 r
.89035 .48007 .89471 .48612 .90583 .48275 .9015 .47666 Mtetra
.659 .753 .92 r
.9015 .47666 .90583 .48275 .917 .47936 .9127 .47324 Mtetra
.659 .753 .919 r
.9127 .47324 .917 .47936 .9282 .47596 .92393 .46982 Mtetra
.92393 .46982 .9282 .47596 .93945 .47256 .93521 .46639 Mtetra
.653 .751 .921 r
.32977 .63908 .33552 .6441 .34466 .64146 .33894 .63642 Mtetra
.653 .75 .921 r
.33894 .63642 .34466 .64146 .35384 .63883 .34813 .63375 Mtetra
.652 .749 .921 r
.34813 .63375 .35384 .63883 .36305 .63619 .35736 .63108 Mtetra
.651 .749 .921 r
.35736 .63108 .36305 .63619 .37229 .63355 .36662 .62843 Mtetra
.65 .748 .921 r
.36662 .62843 .37229 .63355 .38156 .63091 .37591 .62579 Mtetra
.65 .749 .922 r
.37591 .62579 .38156 .63091 .39086 .62826 .38524 .62315 Mtetra
.649 .75 .923 r
.38524 .62315 .39086 .62826 .4002 .62558 .39459 .62053 Mtetra
.649 .753 .925 r
.39459 .62053 .4002 .62558 .40958 .62285 .40398 .61787 Mtetra
.65 .757 .927 r
.40398 .61787 .40958 .62285 .41898 .62006 .41341 .61517 Mtetra
.654 .762 .929 r
.41341 .61517 .41898 .62006 .42843 .61716 .42287 .61237 Mtetra
.66 .768 .93 r
.42287 .61237 .42843 .61716 .43791 .61412 .43237 .60941 Mtetra
.667 .774 .929 r
.43237 .60941 .43791 .61412 .44742 .61097 .44191 .60627 Mtetra
.676 .777 .926 r
.44191 .60627 .44742 .61097 .45697 .60772 .45148 .60292 Mtetra
.68 .775 .922 r
.45148 .60292 .45697 .60772 .46655 .60449 .46109 .59946 Mtetra
.681 .767 .916 r
.46109 .59946 .46655 .60449 .47615 .60139 .47072 .59596 Mtetra
.669 .75 .911 r
.47072 .59596 .47615 .60139 .48579 .59864 .48038 .59275 Mtetra
.649 .728 .906 r
.48038 .59275 .48579 .59864 .49546 .59642 .49008 .59007 Mtetra
.619 .702 .904 r
.49008 .59007 .49546 .59642 .50516 .59478 .4998 .58814 Mtetra
.581 .678 .907 r
.4998 .58814 .50516 .59478 .5149 .5937 .50955 .58709 Mtetra
.562 .672 .912 r
.50955 .58709 .5149 .5937 .52468 .59265 .51935 .58641 Mtetra
.563 .686 .923 r
.51935 .58641 .52468 .59265 .53451 .59119 .5292 .58561 Mtetra
.624 .734 .926 r
.5292 .58561 .53451 .59119 .54438 .58847 .53909 .58343 Mtetra
.706 .779 .909 r
.53909 .58343 .54438 .58847 .55427 .58406 .54901 .57913 Mtetra
.769 .796 .875 r
.54901 .57913 .55427 .58406 .56417 .57811 .55893 .57266 Mtetra
.802 .782 .834 r
.55893 .57266 .56417 .57811 .57406 .57094 .56884 .56423 Mtetra
.795 .746 .808 r
.56884 .56423 .57406 .57094 .58397 .56361 .57875 .5553 Mtetra
.769 .704 .791 r
.57875 .5553 .58397 .56361 .5939 .55678 .58867 .5468 Mtetra
.731 .661 .781 r
.58867 .5468 .5939 .55678 .60386 .551 .59862 .5397 Mtetra
.686 .621 .778 r
.59862 .5397 .60386 .551 .61388 .5466 .60863 .53456 Mtetra
.641 .589 .78 r
.60863 .53456 .61388 .5466 .62397 .54359 .61873 .53151 Mtetra
.591 .563 .791 r
.61873 .53151 .62397 .54359 .63414 .54196 .62892 .53057 Mtetra
.532 .542 .811 r
.62892 .53057 .63414 .54196 .64441 .54171 .63924 .53161 Mtetra
.465 .531 .841 r
.63924 .53161 .64441 .54171 .65477 .54254 .64967 .53407 Mtetra
.409 .542 .878 r
.64967 .53407 .65477 .54254 .66522 .54389 .66019 .53699 Mtetra
.387 .581 .918 r
.66019 .53699 .66522 .54389 .67572 .54509 .67076 .53941 Mtetra
.472 .673 .952 r
.67076 .53941 .67572 .54509 .68624 .54506 .68132 .53989 Mtetra
.588 .747 .953 r
.68132 .53989 .68624 .54506 .69673 .5435 .69183 .53816 Mtetra
.684 .775 .92 r
.69183 .53816 .69673 .5435 .70717 .54022 .70227 .53429 Mtetra
.727 .768 .885 r
.70227 .53429 .70717 .54022 .71758 .53565 .71267 .52901 Mtetra
.725 .745 .868 r
.71267 .52901 .71758 .53565 .72799 .53067 .72309 .52361 Mtetra
.712 .729 .863 r
.72309 .52361 .72799 .53067 .73844 .5257 .73355 .51856 Mtetra
.687 .718 .873 r
.73355 .51856 .73844 .5257 .74895 .5213 .74411 .51441 Mtetra
.664 .718 .889 r
.74411 .51441 .74895 .5213 .75953 .51748 .75475 .51103 Mtetra
.644 .725 .907 r
.75475 .51103 .75953 .51748 .77019 .5142 .76546 .50819 Mtetra
.631 .736 .924 r
.76546 .50819 .77019 .5142 .78091 .51129 .77624 .50563 Mtetra
.629 .75 .934 r
.77624 .50563 .78091 .51129 .79169 .50851 .78707 .50305 Mtetra
.632 .76 .94 r
.78707 .50305 .79169 .50851 .80252 .50575 .79793 .50036 Mtetra
.64 .767 .94 r
.79793 .50036 .80252 .50575 .81338 .50288 .80882 .49745 Mtetra
.648 .768 .937 r
.80882 .49745 .81338 .50288 .82427 .4999 .81974 .49434 Mtetra
.655 .767 .932 r
.81974 .49434 .82427 .4999 .8352 .49678 .83068 .49107 Mtetra
.659 .764 .927 r
.83068 .49107 .8352 .49678 .84615 .49354 .84165 .4877 Mtetra
.661 .76 .924 r
.84165 .4877 .84615 .49354 .85714 .49023 .85267 .48427 Mtetra
.662 .757 .921 r
.85267 .48427 .85714 .49023 .86817 .48687 .86372 .48081 Mtetra
.661 .754 .919 r
.86372 .48081 .86817 .48687 .87924 .48348 .87481 .47736 Mtetra
.661 .752 .918 r
.87481 .47736 .87924 .48348 .89035 .48007 .88595 .47391 Mtetra
.66 .751 .918 r
.88595 .47391 .89035 .48007 .9015 .47666 .89713 .47047 Mtetra
.659 .751 .918 r
.89713 .47047 .9015 .47666 .9127 .47324 .90836 .46704 Mtetra
.90836 .46704 .9127 .47324 .92393 .46982 .91963 .46361 Mtetra
.658 .752 .919 r
.91963 .46361 .92393 .46982 .93521 .46639 .93095 .46018 Mtetra
.655 .751 .921 r
.32399 .63404 .32977 .63908 .33894 .63642 .33318 .63132 Mtetra
.654 .75 .92 r
.33318 .63132 .33894 .63642 .34813 .63375 .3424 .6286 Mtetra
.654 .748 .919 r
.3424 .6286 .34813 .63375 .35736 .63108 .35165 .62588 Mtetra
.653 .747 .919 r
.35165 .62588 .35736 .63108 .36662 .62843 .36093 .62319 Mtetra
.651 .746 .919 r
.36093 .62319 .36662 .62843 .37591 .62579 .37024 .62052 Mtetra
.649 .745 .919 r
.37024 .62052 .37591 .62579 .38524 .62315 .37958 .61789 Mtetra
.647 .745 .921 r
.37958 .61789 .38524 .62315 .39459 .62053 .38895 .61529 Mtetra
.646 .746 .922 r
.38895 .61529 .39459 .62053 .40398 .61787 .39836 .61271 Mtetra
.645 .749 .925 r
.39836 .61271 .40398 .61787 .41341 .61517 .4078 .61013 Mtetra
.647 .755 .928 r
.4078 .61013 .41341 .61517 .42287 .61237 .41728 .60747 Mtetra
.652 .763 .931 r
.41728 .60747 .42287 .61237 .43237 .60941 .4268 .60468 Mtetra
.661 .773 .932 r
.4268 .60468 .43237 .60941 .44191 .60627 .43635 .60167 Mtetra
.673 .782 .931 r
.43635 .60167 .44191 .60627 .45148 .60292 .44595 .59835 Mtetra
.684 .786 .928 r
.44595 .59835 .45148 .60292 .46109 .59946 .45558 .59477 Mtetra
.693 .784 .921 r
.45558 .59477 .46109 .59946 .47072 .59596 .46525 .59093 Mtetra
.689 .771 .914 r
.46525 .59093 .47072 .59596 .48038 .59275 .47494 .5872 Mtetra
.674 .748 .907 r
.47494 .5872 .48038 .59275 .49008 .59007 .48466 .58385 Mtetra
.64 .715 .902 r
.48466 .58385 .49008 .59007 .4998 .58814 .4944 .58136 Mtetra
.594 .68 .901 r
.4944 .58136 .4998 .58814 .50955 .58709 .50418 .58003 Mtetra
.557 .656 .902 r
.50418 .58003 .50955 .58709 .51935 .58641 .51399 .57952 Mtetra
.534 .652 .911 r
.51399 .57952 .51935 .58641 .5292 .58561 .52386 .57944 Mtetra
.591 .702 .92 r
.52386 .57944 .5292 .58561 .53909 .58343 .53377 .57803 Mtetra
.686 .762 .91 r
.53377 .57803 .53909 .58343 .54901 .57913 .54371 .57427 Mtetra
.774 .8 .874 r
.54371 .57427 .54901 .57913 .55893 .57266 .55367 .5676 Mtetra
.824 .796 .825 r
.55367 .5676 .55893 .57266 .56884 .56423 .5636 .55807 Mtetra
.824 .765 .797 r
.5636 .55807 .56884 .56423 .57875 .5553 .57352 .5475 Mtetra
.801 .724 .779 r
.57352 .5475 .57875 .5553 .58867 .5468 .58343 .53712 Mtetra
.757 .677 .773 r
.58343 .53712 .58867 .5468 .59862 .5397 .59336 .52849 Mtetra
.703 .631 .774 r
.59336 .52849 .59862 .5397 .60863 .53456 .60337 .52246 Mtetra
.641 .589 .78 r
.60337 .52246 .60863 .53456 .61873 .53151 .61347 .51939 Mtetra
.568 .55 .794 r
.61347 .51939 .61873 .53151 .62892 .53057 .62369 .51929 Mtetra
.477 .514 .817 r
.62369 .51929 .62892 .53057 .63924 .53161 .63405 .52182 Mtetra
.369 .484 .846 r
.63405 .52182 .63924 .53161 .64967 .53407 .64456 .52611 Mtetra
.287 .488 .88 r
.64456 .52611 .64967 .53407 .66019 .53699 .65515 .53064 Mtetra
.278 .542 .92 r
.65515 .53064 .66019 .53699 .67076 .53941 .66579 .53413 Mtetra
.444 .678 .964 r
.66579 .53413 .67076 .53941 .68132 .53989 .67637 .53477 Mtetra
.616 .762 .949 r
.67637 .53477 .68132 .53989 .69183 .53816 .68688 .53246 Mtetra
.711 .771 .9 r
.68688 .53246 .69183 .53816 .70227 .53429 .69731 .52776 Mtetra
.742 .753 .862 r
.69731 .52776 .70227 .53429 .71267 .52901 .7077 .52171 Mtetra
.725 .727 .851 r
.7077 .52171 .71267 .52901 .72309 .52361 .71813 .51608 Mtetra
.702 .713 .857 r
.71813 .51608 .72309 .52361 .73355 .51856 .72863 .51128 Mtetra
.67 .709 .877 r
.72863 .51128 .73355 .51856 .74411 .51441 .73925 .50766 Mtetra
.641 .714 .901 r
.73925 .50766 .74411 .51441 .75475 .51103 .74996 .50492 Mtetra
.623 .73 .924 r
.74996 .50492 .75475 .51103 .76546 .50819 .76074 .50257 Mtetra
.613 .746 .94 r
.76074 .50257 .76546 .50819 .77624 .50563 .77157 .50033 Mtetra
.621 .763 .947 r
.77157 .50033 .77624 .50563 .78707 .50305 .78243 .49784 Mtetra
.632 .771 .947 r
.78243 .49784 .78707 .50305 .79793 .50036 .79332 .49506 Mtetra
.646 .774 .942 r
.79332 .49506 .79793 .50036 .80882 .49745 .80423 .49198 Mtetra
.656 .772 .935 r
.80423 .49198 .80882 .49745 .81974 .49434 .81516 .48866 Mtetra
.662 .767 .928 r
.81516 .48866 .81974 .49434 .83068 .49107 .82612 .4852 Mtetra
.665 .761 .922 r
.82612 .4852 .83068 .49107 .84165 .4877 .83711 .48166 Mtetra
.665 .756 .918 r
.83711 .48166 .84165 .4877 .85267 .48427 .84814 .47811 Mtetra
.664 .752 .916 r
.84814 .47811 .85267 .48427 .86372 .48081 .85922 .47458 Mtetra
.662 .75 .915 r
.85922 .47458 .86372 .48081 .87481 .47736 .87034 .47109 Mtetra
.661 .748 .915 r
.87034 .47109 .87481 .47736 .88595 .47391 .88151 .46762 Mtetra
.659 .748 .916 r
.88151 .46762 .88595 .47391 .89713 .47047 .89273 .46418 Mtetra
.658 .748 .917 r
.89273 .46418 .89713 .47047 .90836 .46704 .90399 .46076 Mtetra
.657 .749 .918 r
.90399 .46076 .90836 .46704 .91963 .46361 .9153 .45735 Mtetra
.657 .751 .919 r
.9153 .45735 .91963 .46361 .93095 .46018 .92665 .45393 Mtetra
.657 .752 .92 r
.31818 .62896 .32399 .63404 .33318 .63132 .32739 .62618 Mtetra
.657 .75 .919 r
.32739 .62618 .33318 .63132 .3424 .6286 .33662 .62338 Mtetra
.656 .748 .917 r
.33662 .62338 .3424 .6286 .35165 .62588 .3459 .6206 Mtetra
.655 .745 .916 r
.3459 .6206 .35165 .62588 .36093 .62319 .3552 .61783 Mtetra
.653 .743 .916 r
.3552 .61783 .36093 .62319 .37024 .62052 .36453 .6151 Mtetra
.651 .741 .915 r
.36453 .6151 .37024 .62052 .37958 .61789 .37389 .61243 Mtetra
.647 .739 .916 r
.37389 .61243 .37958 .61789 .38895 .61529 .38329 .60982 Mtetra
.644 .738 .918 r
.38329 .60982 .38895 .61529 .39836 .61271 .39271 .60729 Mtetra
.64 .739 .921 r
.39271 .60729 .39836 .61271 .4078 .61013 .40217 .60482 Mtetra
.639 .744 .925 r
.40217 .60482 .4078 .61013 .41728 .60747 .41166 .60235 Mtetra
.64 .752 .93 r
.41166 .60235 .41728 .60747 .4268 .60468 .42119 .59982 Mtetra
.648 .766 .935 r
.42119 .59982 .4268 .60468 .43635 .60167 .43076 .59708 Mtetra
.662 .781 .937 r
.43076 .59708 .43635 .60167 .44595 .59835 .44037 .594 Mtetra
.68 .795 .936 r
.44037 .594 .44595 .59835 .45558 .59477 .45003 .59048 Mtetra
.701 .803 .929 r
.45003 .59048 .45558 .59477 .46525 .59093 .45973 .58643 Mtetra
.708 .797 .92 r
.45973 .58643 .46525 .59093 .47494 .5872 .46945 .58218 Mtetra
.704 .777 .908 r
.46945 .58218 .47494 .5872 .48466 .58385 .47921 .57798 Mtetra
.674 .739 .9 r
.47921 .57798 .48466 .58385 .4944 .58136 .48898 .57459 Mtetra
.624 .693 .894 r
.48898 .57459 .4944 .58136 .50418 .58003 .49878 .57252 Mtetra
.567 .648 .89 r
.49878 .57252 .50418 .58003 .51399 .57952 .5086 .57188 Mtetra
.509 .618 .895 r
.5086 .57188 .51399 .57952 .52386 .57944 .51848 .57247 Mtetra
.547 .658 .908 r
.51848 .57247 .52386 .57944 .53377 .57803 .52841 .57211 Mtetra
.644 .732 .913 r
.52841 .57211 .53377 .57803 .54371 .57427 .53838 .56944 Mtetra
.766 .801 .881 r
.53838 .56944 .54371 .57427 .55367 .5676 .54837 .56309 Mtetra
.842 .814 .823 r
.54837 .56309 .55367 .5676 .5636 .55807 .55833 .55283 Mtetra
.854 .791 .789 r
.55833 .55283 .5636 .55807 .57352 .5475 .56826 .54075 Mtetra
.837 .753 .771 r
.56826 .54075 .57352 .5475 .58343 .53712 .57818 .52839 Mtetra
.79 .704 .77 r
.57818 .52839 .58343 .53712 .59336 .52849 .58811 .51806 Mtetra
.726 .653 .777 r
.58811 .51806 .59336 .52849 .60337 .52246 .5981 .51102 Mtetra
.643 .6 .79 r
.5981 .51102 .60337 .52246 .61347 .51939 .60821 .50793 Mtetra
.535 .544 .81 r
.60821 .50793 .61347 .51939 .62369 .51929 .61846 .50878 Mtetra
.389 .48 .832 r
.61846 .50878 .62369 .51929 .63405 .52182 .62888 .51297 Mtetra
.208 .413 .843 r
.62888 .51297 .63405 .52182 .64456 .52611 .63945 .51921 Mtetra
.099 .408 .859 r
.63945 .51921 .64456 .52611 .65515 .53064 .65011 .52522 Mtetra
.143 .499 .907 r
.65011 .52522 .65515 .53064 .66579 .53413 .6608 .52941 Mtetra
.445 .705 .977 r
.6608 .52941 .66579 .53413 .67637 .53477 .67139 .52967 Mtetra
.665 .781 .935 r
.67139 .52967 .67637 .53477 .68688 .53246 .68188 .52622 Mtetra
.738 .762 .872 r
.68188 .52622 .68688 .53246 .69731 .52776 .69228 .52042 Mtetra
.75 .734 .837 r
.69228 .52042 .69731 .52776 .7077 .52171 .70265 .51364 Mtetra
.717 .705 .838 r
.70265 .51364 .7077 .52171 .71813 .51608 .71312 .50809 Mtetra
.68 .694 .856 r
.71312 .50809 .71813 .51608 .72863 .51128 .72369 .50401 Mtetra
.641 .698 .887 r
.72369 .50401 .72863 .51128 .73925 .50766 .73438 .50126 Mtetra
.605 .713 .921 r
.73438 .50126 .73925 .50766 .74996 .50492 .74517 .49935 Mtetra
.594 .741 .946 r
.74517 .49935 .74996 .50492 .76074 .50257 .75602 .49749 Mtetra
.596 .763 .959 r
.75602 .49749 .76074 .50257 .77157 .50033 .7669 .49543 Mtetra
.62 .78 .958 r
.7669 .49543 .77157 .50033 .78243 .49784 .77778 .49283 Mtetra
.641 .785 .951 r
.77778 .49283 .78243 .49784 .79332 .49506 .78868 .48977 Mtetra
.658 .781 .939 r
.78868 .48977 .79332 .49506 .80423 .49198 .7996 .48637 Mtetra
.668 .772 .928 r
.7996 .48637 .80423 .49198 .81516 .48866 .81053 .48273 Mtetra
.67 .762 .919 r
.81053 .48273 .81516 .48866 .82612 .4852 .8215 .47904 Mtetra
.67 .754 .914 r
.8215 .47904 .82612 .4852 .83711 .48166 .83251 .47533 Mtetra
.667 .748 .911 r
.83251 .47533 .83711 .48166 .84814 .47811 .84357 .4717 Mtetra
.664 .745 .91 r
.84357 .4717 .84814 .47811 .85922 .47458 .85467 .46814 Mtetra
.661 .743 .911 r
.85467 .46814 .85922 .47458 .87034 .47109 .86583 .46464 Mtetra
.659 .743 .912 r
.86583 .46464 .87034 .47109 .88151 .46762 .87703 .4612 Mtetra
.657 .744 .914 r
.87703 .4612 .88151 .46762 .89273 .46418 .88829 .45779 Mtetra
.656 .746 .916 r
.88829 .45779 .89273 .46418 .90399 .46076 .89959 .4544 Mtetra
.655 .747 .918 r
.89959 .4544 .90399 .46076 .9153 .45735 .91093 .45102 Mtetra
.655 .749 .919 r
.91093 .45102 .9153 .45735 .92665 .45393 .92232 .44763 Mtetra
.659 .752 .919 r
.31232 .62385 .31818 .62896 .32739 .62618 .32155 .621 Mtetra
.659 .75 .918 r
.32155 .621 .32739 .62618 .33662 .62338 .33082 .61814 Mtetra
.659 .748 .916 r
.33082 .61814 .33662 .62338 .3459 .6206 .34011 .61528 Mtetra
.658 .746 .915 r
.34011 .61528 .3459 .6206 .3552 .61783 .34943 .61243 Mtetra
.656 .743 .914 r
.34943 .61243 .3552 .61783 .36453 .6151 .35879 .6096 Mtetra
.654 .74 .913 r
.35879 .6096 .36453 .6151 .37389 .61243 .36818 .60684 Mtetra
.65 .736 .912 r
.36818 .60684 .37389 .61243 .38329 .60982 .37759 .60416 Mtetra
.645 .733 .913 r
.37759 .60416 .38329 .60982 .39271 .60729 .38703 .6016 Mtetra
.638 .73 .915 r
.38703 .6016 .39271 .60729 .40217 .60482 .39651 .59917 Mtetra
.634 .731 .918 r
.39651 .59917 .40217 .60482 .41166 .60235 .40601 .59684 Mtetra
.629 .736 .924 r
.40601 .59684 .41166 .60235 .42119 .59982 .41555 .59458 Mtetra
.633 .748 .931 r
.41555 .59458 .42119 .59982 .43076 .59708 .42513 .5922 Mtetra
.643 .765 .937 r
.42513 .5922 .43076 .59708 .44037 .594 .43476 .58954 Mtetra
.665 .789 .941 r
.43476 .58954 .44037 .594 .45003 .59048 .44443 .58633 Mtetra
.696 .81 .936 r
.44443 .58633 .45003 .59048 .45973 .58643 .45415 .58238 Mtetra
.718 .818 .927 r
.45415 .58238 .45973 .58643 .46945 .58218 .46391 .57783 Mtetra
.733 .809 .911 r
.46391 .57783 .46945 .58218 .47921 .57798 .47371 .57282 Mtetra
.713 .775 .901 r
.47371 .57282 .47921 .57798 .48898 .57459 .48352 .56831 Mtetra
.67 .726 .891 r
.48352 .56831 .48898 .57459 .49878 .57252 .49334 .56497 Mtetra
.595 .66 .883 r
.49334 .56497 .49878 .57252 .5086 .57188 .50319 .56365 Mtetra
.502 .598 .882 r
.50319 .56365 .5086 .57188 .51848 .57247 .51307 .56452 Mtetra
.505 .608 .889 r
.51307 .56452 .51848 .57247 .52841 .57211 .52302 .56524 Mtetra
.576 .675 .907 r
.52302 .56524 .52841 .57211 .53838 .56944 .53301 .56423 Mtetra
.732 .783 .894 r
.53301 .56423 .53838 .56944 .54837 .56309 .54303 .55903 Mtetra
.846 .83 .831 r
.54303 .55903 .54837 .56309 .55833 .55283 .55304 .54888 Mtetra
.88 .826 .79 r
.55304 .54888 .55833 .55283 .56826 .54075 .563 .53592 Mtetra
.878 .801 .77 r
.563 .53592 .56826 .54075 .57818 .52839 .57293 .52191 Mtetra
.836 .761 .779 r
.57293 .52191 .57818 .52839 .58811 .51806 .58287 .51001 Mtetra
.766 .712 .802 r
.58287 .51001 .58811 .51806 .5981 .51102 .59287 .50198 Mtetra
.652 .649 .834 r
.59287 .50198 .5981 .51102 .60821 .50793 .60299 .49886 Mtetra
.471 .561 .865 r
.60299 .49886 .60821 .50793 .61846 .50878 .61328 .50067 Mtetra
.198 .43 .859 r
.61328 .50067 .61846 .50878 .62888 .51297 .62375 .50637 Mtetra
0 .276 .776 r
.62375 .50637 .62888 .51297 .63945 .51921 .63439 .51425 Mtetra
0 .285 .758 r
.63439 .51425 .63945 .51921 .65011 .52522 .64509 .52109 Mtetra
.024 .477 .877 r
.64509 .52109 .65011 .52522 .6608 .52941 .65579 .52513 Mtetra
.512 .759 .985 r
.65579 .52513 .6608 .52941 .67139 .52967 .66636 .5242 Mtetra
.726 .785 .9 r
.66636 .5242 .67139 .52967 .68188 .52622 .6768 .51902 Mtetra
.755 .74 .838 r
.6768 .51902 .68188 .52622 .69228 .52042 .68717 .51207 Mtetra
.746 .709 .817 r
.68717 .51207 .69228 .52042 .70265 .51364 .69756 .50496 Mtetra
.697 .684 .834 r
.69756 .50496 .70265 .51364 .71312 .50809 .70807 .50007 Mtetra
.643 .679 .869 r
.70807 .50007 .71312 .50809 .72369 .50401 .71874 .49723 Mtetra
.596 .697 .913 r
.71874 .49723 .72369 .50401 .73438 .50126 .72953 .49559 Mtetra
.557 .721 .95 r
.72953 .49559 .73438 .50126 .74517 .49935 .7404 .49446 Mtetra
.566 .759 .969 r
.7404 .49446 .74517 .49935 .75602 .49749 .75129 .49287 Mtetra
.593 .783 .971 r
.75129 .49287 .75602 .49749 .7669 .49543 .7622 .49068 Mtetra
.634 .794 .959 r
.7622 .49068 .7669 .49543 .77778 .49283 .77309 .48771 Mtetra
.662 .789 .943 r
.77309 .48771 .77778 .49283 .78868 .48977 .78399 .48417 Mtetra
.674 .776 .926 r
.78399 .48417 .78868 .48977 .7996 .48637 .7949 .48036 Mtetra
.679 .763 .915 r
.7949 .48036 .7996 .48637 .81053 .48273 .80584 .47641 Mtetra
.676 .751 .908 r
.80584 .47641 .81053 .48273 .8215 .47904 .81683 .47252 Mtetra
.672 .744 .905 r
.81683 .47252 .8215 .47904 .83251 .47533 .82786 .46873 Mtetra
.667 .74 .905 r
.82786 .46873 .83251 .47533 .84357 .4717 .83895 .46508 Mtetra
.662 .738 .906 r
.83895 .46508 .84357 .4717 .85467 .46814 .85009 .46155 Mtetra
.659 .739 .909 r
.85009 .46155 .85467 .46814 .86583 .46464 .86128 .4581 Mtetra
.656 .74 .912 r
.86128 .4581 .86583 .46464 .87703 .4612 .87252 .45472 Mtetra
.655 .742 .914 r
.87252 .45472 .87703 .4612 .88829 .45779 .88381 .45135 Mtetra
.654 .745 .916 r
.88381 .45135 .88829 .45779 .89959 .4544 .89515 .448 Mtetra
.653 .747 .918 r
.89515 .448 .89959 .4544 .91093 .45102 .90653 .44465 Mtetra
.653 .749 .92 r
.90653 .44465 .91093 .45102 .92232 .44763 .91796 .44128 Mtetra
.66 .752 .919 r
.30643 .61871 .31232 .62385 .32155 .621 .31568 .61582 Mtetra
.661 .752 .917 r
.31568 .61582 .32155 .621 .33082 .61814 .32497 .6129 Mtetra
.661 .75 .916 r
.32497 .6129 .33082 .61814 .34011 .61528 .33428 .60996 Mtetra
.661 .748 .915 r
.33428 .60996 .34011 .61528 .34943 .61243 .34363 .60702 Mtetra
.661 .745 .913 r
.34363 .60702 .34943 .61243 .35879 .6096 .35301 .60407 Mtetra
.659 .741 .911 r
.35301 .60407 .35879 .6096 .36818 .60684 .36242 .60117 Mtetra
.655 .736 .909 r
.36242 .60117 .36818 .60684 .37759 .60416 .37186 .59834 Mtetra
.65 .73 .907 r
.37186 .59834 .37759 .60416 .38703 .6016 .38133 .59564 Mtetra
.641 .723 .907 r
.38133 .59564 .38703 .6016 .39651 .59917 .39082 .59314 Mtetra
.633 .718 .909 r
.39082 .59314 .39651 .59917 .40601 .59684 .40035 .59084 Mtetra
.621 .716 .914 r
.40035 .59084 .40601 .59684 .41555 .59458 .4099 .58878 Mtetra
.617 .723 .922 r
.4099 .58878 .41555 .59458 .42513 .5922 .41949 .58679 Mtetra
.617 .738 .933 r
.41949 .58679 .42513 .5922 .43476 .58954 .42911 .58472 Mtetra
.637 .769 .943 r
.42911 .58472 .43476 .58954 .44443 .58633 .4388 .58214 Mtetra
.673 .804 .945 r
.4388 .58214 .44443 .58633 .45415 .58238 .44853 .5787 Mtetra
.714 .834 .939 r
.44853 .5787 .45415 .58238 .46391 .57783 .45832 .57424 Mtetra
.754 .843 .918 r
.45832 .57424 .46391 .57783 .47371 .57282 .46815 .56865 Mtetra
.756 .821 .903 r
.46815 .56865 .47371 .57282 .48352 .56831 .47801 .5629 Mtetra
.731 .772 .886 r
.47801 .5629 .48352 .56831 .49334 .56497 .48788 .55773 Mtetra
.647 .69 .877 r
.48788 .55773 .49334 .56497 .50319 .56365 .49775 .555 Mtetra
.525 .599 .87 r
.49775 .555 .50319 .56365 .51307 .56452 .50765 .55546 Mtetra
.475 .564 .866 r
.50765 .55546 .51307 .56452 .52302 .56524 .51759 .5571 Mtetra
.481 .593 .888 r
.51759 .5571 .52302 .56524 .53301 .56423 .5276 .55831 Mtetra
.657 .74 .911 r
.5276 .55831 .53301 .56423 .54303 .55903 .53766 .55525 Mtetra
.828 .845 .859 r
.53766 .55525 .54303 .55903 .55304 .54888 .54771 .54646 Mtetra
.898 .874 .805 r
.54771 .54646 .55304 .54888 .563 .53592 .55773 .53367 Mtetra
.919 .867 .773 r
.55773 .53367 .563 .53592 .57293 .52191 .5677 .51868 Mtetra
.892 .851 .795 r
.5677 .51868 .57293 .52191 .58287 .51001 .57766 .50563 Mtetra
.825 .827 .85 r
.57766 .50563 .58287 .51001 .59287 .50198 .58768 .49675 Mtetra
.657 .768 .931 r
.58768 .49675 .59287 .50198 .60299 .49886 .59783 .49361 Mtetra
.267 .584 .945 r
.59783 .49361 .60299 .49886 .61328 .50067 .60816 .49623 Mtetra
0 .244 .708 r
.60816 .49623 .61328 .50067 .62375 .50637 .61868 .50306 Mtetra
.529 0 0 r
.61868 .50306 .62375 .50637 .63439 .51425 .62936 .51187 Mtetra
.445 0 0 r
.62936 .51187 .63439 .51425 .64509 .52109 .64008 .51851 Mtetra
.001 .526 .851 r
.64008 .51851 .64509 .52109 .65579 .52513 .65076 .52115 Mtetra
.639 .822 .971 r
.65076 .52115 .65579 .52513 .66636 .5242 .66127 .518 Mtetra
.776 .774 .851 r
.66127 .518 .66636 .5242 .6768 .51902 .67163 .51053 Mtetra
.76 .711 .807 r
.67163 .51053 .6768 .51902 .68717 .51207 .68199 .5026 Mtetra
.729 .68 .803 r
.68199 .5026 .68717 .51207 .69756 .50496 .69241 .49586 Mtetra
.659 .659 .839 r
.69241 .49586 .69756 .50496 .70807 .50007 .70302 .49236 Mtetra
.576 .659 .893 r
.70302 .49236 .70807 .50007 .71874 .49723 .71382 .49134 Mtetra
.522 .698 .949 r
.71382 .49134 .71874 .49723 .72953 .49559 .72471 .49093 Mtetra
.495 .738 .981 r
.72471 .49093 .72953 .49559 .7404 .49446 .73564 .49035 Mtetra
.55 .789 .988 r
.73564 .49035 .7404 .49446 .75129 .49287 .74656 .48864 Mtetra
.615 .81 .975 r
.74656 .48864 .75129 .49287 .7622 .49068 .75746 .48587 Mtetra
.664 .804 .95 r
.75746 .48587 .7622 .49068 .77309 .48771 .76834 .48222 Mtetra
.688 .785 .925 r
.76834 .48222 .77309 .48771 .78399 .48417 .77922 .47803 Mtetra
.689 .762 .907 r
.77922 .47803 .78399 .48417 .7949 .48036 .79013 .47376 Mtetra
.686 .747 .897 r
.79013 .47376 .7949 .48036 .80584 .47641 .80108 .46956 Mtetra
.677 .736 .895 r
.80108 .46956 .80584 .47641 .81683 .47252 .81209 .4656 Mtetra
.67 .731 .896 r
.81209 .4656 .81683 .47252 .82786 .46873 .82315 .46184 Mtetra
.663 .73 .9 r
.82315 .46184 .82786 .46873 .83895 .46508 .83428 .45829 Mtetra
.658 .732 .904 r
.83428 .45829 .83895 .46508 .85009 .46155 .84546 .45487 Mtetra
.655 .735 .909 r
.84546 .45487 .85009 .46155 .86128 .4581 .8567 .45153 Mtetra
.652 .739 .913 r
.8567 .45153 .86128 .4581 .87252 .45472 .86798 .44822 Mtetra
.652 .742 .916 r
.86798 .44822 .87252 .45472 .88381 .45135 .87931 .44491 Mtetra
.652 .745 .918 r
.87931 .44491 .88381 .45135 .89515 .448 .89069 .44159 Mtetra
.652 .747 .92 r
.89069 .44159 .89515 .448 .90653 .44465 .90211 .43826 Mtetra
.652 .749 .921 r
.90211 .43826 .90653 .44465 .91796 .44128 .91357 .43489 Mtetra
.66 .752 .919 r
.3005 .61354 .30643 .61871 .31568 .61582 .30977 .61063 Mtetra
.661 .753 .918 r
.30977 .61063 .31568 .61582 .32497 .6129 .31908 .60769 Mtetra
.662 .753 .918 r
.31908 .60769 .32497 .6129 .33428 .60996 .32841 .60472 Mtetra
.663 .753 .917 r
.32841 .60472 .33428 .60996 .34363 .60702 .33779 .60172 Mtetra
.664 .751 .915 r
.33779 .60172 .34363 .60702 .35301 .60407 .34719 .59867 Mtetra
.664 .748 .913 r
.34719 .59867 .35301 .60407 .36242 .60117 .35663 .59562 Mtetra
.663 .743 .91 r
.35663 .59562 .36242 .60117 .37186 .59834 .3661 .59258 Mtetra
.658 .736 .907 r
.3661 .59258 .37186 .59834 .38133 .59564 .37559 .58966 Mtetra
.65 .726 .904 r
.37559 .58966 .38133 .59564 .39082 .59314 .38511 .58692 Mtetra
.639 .715 .903 r
.38511 .58692 .39082 .59314 .40035 .59084 .39466 .58447 Mtetra
.623 .705 .905 r
.39466 .58447 .40035 .59084 .4099 .58878 .40423 .5824 Mtetra
.609 .701 .909 r
.40423 .5824 .4099 .58878 .41949 .58679 .41382 .58062 Mtetra
.595 .704 .919 r
.41382 .58062 .41949 .58679 .42911 .58472 .42345 .5791 Mtetra
.604 .728 .932 r
.42345 .5791 .42911 .58472 .4388 .58214 .43313 .5773 Mtetra
.632 .768 .945 r
.43313 .5773 .4388 .58214 .44853 .5787 .44287 .57479 Mtetra
.685 .821 .948 r
.44287 .57479 .44853 .5787 .45832 .57424 .45268 .571 Mtetra
.75 .858 .929 r
.45268 .571 .45832 .57424 .46815 .56865 .46254 .56552 Mtetra
.785 .864 .908 r
.46254 .56552 .46815 .56865 .47801 .5629 .47244 .5589 Mtetra
.793 .831 .881 r
.47244 .5589 .47801 .5629 .48788 .55773 .48237 .55175 Mtetra
.718 .752 .879 r
.48237 .55175 .48788 .55773 .49775 .555 .49228 .5469 Mtetra
.587 .644 .874 r
.49228 .5469 .49775 .555 .50765 .55546 .5022 .54577 Mtetra
.48 .552 .852 r
.5022 .54577 .50765 .55546 .51759 .5571 .51215 .54747 Mtetra
.396 .508 .855 r
.51215 .54747 .51759 .5571 .5276 .55831 .52216 .5508 Mtetra
.538 .642 .9 r
.52216 .5508 .5276 .55831 .53766 .55525 .53224 .55065 Mtetra
.754 .813 .899 r
.53224 .55065 .53766 .55525 .54771 .54646 .54235 .54476 Mtetra
.882 .912 .843 r
.54235 .54476 .54771 .54646 .55773 .53367 .55243 .53384 Mtetra
.933 .939 .777 r
.55243 .53384 .55773 .53367 .5677 .51868 .56247 .51935 Mtetra
.917 .966 .791 r
.56247 .51935 .5677 .51868 .57766 .50563 .57249 .50617 Mtetra
.826 .994 .857 r
.57249 .50617 .57766 .50563 .58768 .49675 .58256 .49692 Mtetra
.397 .853 .872 r
.58256 .49692 .58768 .49675 .59783 .49361 .59275 .49376 Mtetra
.357 0 0 r
.59275 .49376 .59783 .49361 .60816 .49623 .60312 .49672 Mtetra
.625 .07 0 r
.60312 .49672 .60816 .49623 .61868 .50306 .61367 .50364 Mtetra
.674 .136 0 r
.61367 .50364 .61868 .50306 .62936 .51187 .62437 .51193 Mtetra
.48 0 0 r
.62437 .51193 .62936 .51187 .64008 .51851 .63506 .51665 Mtetra
.277 .743 .946 r
.63506 .51665 .64008 .51851 .65076 .52115 .64565 .51632 Mtetra
.756 .818 .901 r
.64565 .51632 .65076 .52115 .66127 .518 .65608 .51019 Mtetra
.795 .736 .798 r
.65608 .51019 .66127 .518 .67163 .51053 .66638 .50052 Mtetra
.746 .677 .785 r
.66638 .50052 .67163 .51053 .68199 .5026 .67675 .49249 Mtetra
.693 .654 .807 r
.67675 .49249 .68199 .5026 .69241 .49586 .68727 .48731 Mtetra
.594 .644 .87 r
.68727 .48731 .69241 .49586 .70302 .49236 .69801 .48592 Mtetra
.453 .643 .939 r
.69801 .48592 .70302 .49236 .71382 .49134 .70894 .48689 Mtetra
.409 .706 .983 r
.70894 .48689 .71382 .49134 .72471 .49093 .71991 .48731 Mtetra
.454 .769 .997 r
.71991 .48731 .72471 .49093 .73564 .49035 .73087 .4866 Mtetra
.583 .821 .989 r
.73087 .4866 .73564 .49035 .74656 .48864 .74178 .48415 Mtetra
.666 .819 .957 r
.74178 .48415 .74656 .48864 .75746 .48587 .75265 .48038 Mtetra
.698 .789 .921 r
.75265 .48038 .75746 .48587 .76834 .48222 .7635 .47589 Mtetra
.705 .762 .896 r
.7635 .47589 .76834 .48222 .77922 .47803 .77436 .47109 Mtetra
.695 .739 .885 r
.77436 .47109 .77922 .47803 .79013 .47376 .78528 .46655 Mtetra
.684 .728 .883 r
.78528 .46655 .79013 .47376 .80108 .46956 .79625 .46231 Mtetra
.672 .722 .887 r
.79625 .46231 .80108 .46956 .81209 .4656 .8073 .45847 Mtetra
.662 .723 .894 r
.8073 .45847 .81209 .4656 .82315 .46184 .81842 .45492 Mtetra
.655 .728 .902 r
.81842 .45492 .82315 .46184 .83428 .45829 .82959 .45155 Mtetra
.651 .733 .909 r
.82959 .45155 .83428 .45829 .84546 .45487 .84082 .4483 Mtetra
.649 .739 .915 r
.84082 .4483 .84546 .45487 .8567 .45153 .8521 .44507 Mtetra
.649 .743 .918 r
.8521 .44507 .8567 .45153 .86798 .44822 .86343 .44183 Mtetra
.65 .747 .92 r
.86343 .44183 .86798 .44822 .87931 .44491 .87479 .43854 Mtetra
.651 .749 .921 r
.87479 .43854 .87931 .44491 .89069 .44159 .8862 .43522 Mtetra
.651 .75 .922 r
.8862 .43522 .89069 .44159 .90211 .43826 .89765 .43186 Mtetra
.652 .75 .921 r
.89765 .43186 .90211 .43826 .91357 .43489 .90915 .42846 Mtetra
.657 .752 .92 r
.29453 .60833 .3005 .61354 .30977 .61063 .30382 .60546 Mtetra
.658 .754 .921 r
.30382 .60546 .30977 .61063 .31908 .60769 .31314 .60255 Mtetra
.66 .756 .922 r
.31314 .60255 .31908 .60769 .32841 .60472 .3225 .5996 Mtetra
.662 .758 .922 r
.3225 .5996 .32841 .60472 .33779 .60172 .33189 .59659 Mtetra
.665 .759 .92 r
.33189 .59659 .33779 .60172 .34719 .59867 .34132 .59348 Mtetra
.668 .759 .918 r
.34132 .59348 .34719 .59867 .35663 .59562 .35078 .59031 Mtetra
.67 .755 .914 r
.35078 .59031 .35663 .59562 .3661 .59258 .36028 .58706 Mtetra
.669 .748 .91 r
.36028 .58706 .3661 .59258 .37559 .58966 .36981 .58384 Mtetra
.665 .737 .904 r
.36981 .58384 .37559 .58966 .38511 .58692 .37937 .5807 Mtetra
.654 .721 .898 r
.37937 .5807 .38511 .58692 .39466 .58447 .38894 .57785 Mtetra
.636 .703 .895 r
.38894 .57785 .39466 .58447 .40423 .5824 .39854 .57544 Mtetra
.614 .685 .893 r
.39854 .57544 .40423 .5824 .41382 .58062 .40815 .57358 Mtetra
.585 .672 .9 r
.40815 .57358 .41382 .58062 .42345 .5791 .41779 .57238 Mtetra
.574 .679 .911 r
.41779 .57238 .42345 .5791 .43313 .5773 .42746 .57135 Mtetra
.575 .707 .932 r
.42746 .57135 .43313 .5773 .44287 .57479 .43719 .57014 Mtetra
.624 .776 .954 r
.43719 .57014 .44287 .57479 .45268 .571 .44699 .56771 Mtetra
.707 .853 .952 r
.44699 .56771 .45268 .571 .46254 .56552 .45686 .5633 Mtetra
.789 .903 .921 r
.45686 .5633 .46254 .56552 .47244 .5589 .46681 .55659 Mtetra
.843 .891 .873 r
.46681 .55659 .47244 .5589 .48237 .55175 .47679 .54768 Mtetra
.8 .83 .874 r
.47679 .54768 .48237 .55175 .49228 .5469 .48677 .54013 Mtetra
.692 .723 .873 r
.48677 .54013 .49228 .5469 .5022 .54577 .49673 .53597 Mtetra
.534 .578 .845 r
.49673 .53597 .5022 .54577 .51215 .54747 .50669 .53639 Mtetra
.352 .45 .822 r
.50669 .53639 .51215 .54747 .52216 .5508 .51669 .54118 Mtetra
.402 .513 .857 r
.51669 .54118 .52216 .5508 .53224 .55065 .52678 .54436 Mtetra
.581 .703 .926 r
.52678 .54436 .53224 .55065 .54235 .54476 .53693 .54302 Mtetra
.79 .932 .926 r
.53693 .54302 .54235 .54476 .55243 .53384 .54709 .53603 Mtetra
.86 .996 .772 r
.54709 .53603 .55243 .53384 .56247 .51935 .55722 .52405 Mtetra
.68 .919 .598 r
.55722 .52405 .56247 .51935 .57249 .50617 .56733 .51225 Mtetra
0 0 0 r
.56733 .51225 .57249 .50617 .58256 .49692 .57747 .50339 Mtetra
.243 0 0 r
.57747 .50339 .58256 .49692 .59275 .49376 .58773 .50023 Mtetra
.533 .08 .122 r
.58773 .50023 .59275 .49376 .60312 .49672 .59815 .50277 Mtetra
.622 .171 .161 r
.59815 .50277 .60312 .49672 .61367 .50364 .60871 .50828 Mtetra
.624 .146 .1 r
.60871 .50828 .61367 .50364 .62437 .51193 .61938 .51402 Mtetra
.291 0 0 r
.61938 .51402 .62437 .51193 .63506 .51665 .62998 .51475 Mtetra
.688 .926 .97 r
.62998 .51475 .63506 .51665 .64565 .51632 .64045 .50979 Mtetra
.809 .771 .818 r
.64045 .50979 .64565 .51632 .65608 .51019 .65078 .50024 Mtetra
.79 .695 .76 r
.65078 .50024 .65608 .51019 .66638 .50052 .66104 .48905 Mtetra
.713 .641 .776 r
.66104 .48905 .66638 .50052 .67675 .49249 .67148 .48226 Mtetra
.618 .618 .829 r
.67148 .48226 .67675 .49249 .68727 .48731 .68217 .48011 Mtetra
.452 .616 .92 r
.68217 .48011 .68727 .48731 .69801 .48592 .69307 .48142 Mtetra
.204 .585 .943 r
.69307 .48142 .69801 .48592 .70894 .48689 .70412 .48414 Mtetra
.271 .707 .964 r
.70412 .48414 .70894 .48689 .71991 .48731 .71513 .48463 Mtetra
.49 .83 .998 r
.71513 .48463 .71991 .48731 .73087 .4866 .72606 .48278 Mtetra
.663 .847 .971 r
.72606 .48278 .73087 .4866 .74178 .48415 .73691 .4789 Mtetra
.72 .805 .918 r
.73691 .4789 .74178 .48415 .75265 .48038 .74772 .47376 Mtetra
.719 .758 .883 r
.74772 .47376 .75265 .48038 .7635 .47589 .75854 .46842 Mtetra
.709 .729 .866 r
.75854 .46842 .7635 .47589 .77436 .47109 .76941 .46325 Mtetra
.689 .712 .866 r
.76941 .46325 .77436 .47109 .78528 .46655 .78035 .45875 Mtetra
.673 .707 .873 r
.78035 .45875 .78528 .46655 .79625 .46231 .79138 .45481 Mtetra
.659 .711 .886 r
.79138 .45481 .79625 .46231 .8073 .45847 .80249 .45134 Mtetra
.649 .719 .899 r
.80249 .45134 .8073 .45847 .81842 .45492 .81367 .44815 Mtetra
.645 .73 .911 r
.81367 .44815 .81842 .45492 .82959 .45155 .8249 .44506 Mtetra
.643 .739 .919 r
.8249 .44506 .82959 .45155 .84082 .4483 .83618 .44198 Mtetra
.645 .747 .924 r
.83618 .44198 .84082 .4483 .8521 .44507 .8475 .43883 Mtetra
.646 .752 .926 r
.8475 .43883 .8521 .44507 .86343 .44183 .85886 .43561 Mtetra
.649 .755 .926 r
.85886 .43561 .86343 .44183 .87479 .43854 .87026 .43229 Mtetra
.652 .755 .925 r
.87026 .43229 .87479 .43854 .8862 .43522 .88169 .4289 Mtetra
.653 .754 .924 r
.88169 .4289 .8862 .43522 .89765 .43186 .89317 .42545 Mtetra
.654 .753 .922 r
.89317 .42545 .89765 .43186 .90915 .42846 .90469 .42197 Mtetra
.654 .751 .921 r
.28853 .60308 .29453 .60833 .30382 .60546 .29783 .60028 Mtetra
.654 .754 .923 r
.29783 .60028 .30382 .60546 .31314 .60255 .30716 .59745 Mtetra
.655 .758 .925 r
.30716 .59745 .31314 .60255 .3225 .5996 .31653 .59458 Mtetra
.658 .762 .927 r
.31653 .59458 .3225 .5996 .33189 .59659 .32594 .59162 Mtetra
.662 .766 .927 r
.32594 .59162 .33189 .59659 .34132 .59348 .33539 .58855 Mtetra
.667 .77 .926 r
.33539 .58855 .34132 .59348 .35078 .59031 .34487 .58536 Mtetra
.674 .771 .923 r
.34487 .58536 .35078 .59031 .36028 .58706 .3544 .58199 Mtetra
.678 .768 .919 r
.3544 .58199 .36028 .58706 .36981 .58384 .36396 .57853 Mtetra
.681 .76 .912 r
.36396 .57853 .36981 .58384 .37937 .5807 .37356 .57497 Mtetra
.674 .745 .904 r
.37356 .57497 .37937 .5807 .38894 .57785 .38318 .57158 Mtetra
.66 .723 .896 r
.38318 .57158 .38894 .57785 .39854 .57544 .39282 .56853 Mtetra
.635 .695 .889 r
.39282 .56853 .39854 .57544 .40815 .57358 .40247 .56614 Mtetra
.598 .666 .887 r
.40247 .56614 .40815 .57358 .41779 .57238 .41212 .56468 Mtetra
.567 .646 .888 r
.41212 .56468 .41779 .57238 .42746 .57135 .4218 .56395 Mtetra
.534 .642 .902 r
.4218 .56395 .42746 .57135 .43719 .57014 .43151 .56382 Mtetra
.554 .687 .928 r
.43151 .56382 .43719 .57014 .44699 .56771 .44128 .56306 Mtetra
.617 .776 .957 r
.44128 .56306 .44699 .56771 .45686 .5633 .45114 .56071 Mtetra
.745 .888 .945 r
.45114 .56071 .45686 .5633 .46681 .55659 .4611 .55525 Mtetra
.853 .926 .876 r
.4611 .55525 .46681 .55659 .47679 .54768 .47114 .54604 Mtetra
.863 .913 .863 r
.47114 .54604 .47679 .54768 .48677 .54013 .48118 .53628 Mtetra
.815 .839 .868 r
.48118 .53628 .48677 .54013 .49673 .53597 .49121 .52811 Mtetra
.64 .675 .867 r
.49121 .52811 .49673 .53597 .50669 .53639 .5012 .52546 Mtetra
.383 .473 .828 r
.5012 .52546 .50669 .53639 .51669 .54118 .51121 .52952 Mtetra
.338 .432 .81 r
.51121 .52952 .51669 .54118 .52678 .54436 .52129 .53482 Mtetra
.375 .502 .859 r
.52129 .53482 .52678 .54436 .53693 .54302 .53146 .53841 Mtetra
.562 .765 .973 r
.53146 .53841 .53693 .54302 .54709 .53603 .54169 .53687 Mtetra
.714 .986 .874 r
.54169 .53687 .54709 .53603 .55722 .52405 .55191 .52962 Mtetra
0 0 0 r
.55191 .52962 .55722 .52405 .56733 .51225 .56213 .52114 Mtetra
.078 0 0 r
.56213 .52114 .56733 .51225 .57747 .50339 .57238 .51378 Mtetra
.364 0 .159 r
.57238 .51378 .57747 .50339 .58773 .50023 .58271 .5106 Mtetra
.51 .116 .228 r
.58271 .5106 .58773 .50023 .59815 .50277 .59316 .51163 Mtetra
.534 .119 .2 r
.59316 .51163 .59815 .50277 .60871 .50828 .60371 .5138 Mtetra
.447 0 .018 r
.60371 .5138 .60871 .50828 .61938 .51402 .61429 .51475 Mtetra
.491 .904 .847 r
.61429 .51475 .61938 .51402 .62998 .51475 .62477 .50995 Mtetra
.838 .826 .837 r
.62477 .50995 .62998 .51475 .64045 .50979 .63511 .49997 Mtetra
.797 .7 .757 r
.63511 .49997 .64045 .50979 .65078 .50024 .64539 .48823 Mtetra
.761 .655 .745 r
.64539 .48823 .65078 .50024 .66104 .48905 .65569 .47772 Mtetra
.654 .616 .799 r
.65569 .47772 .66104 .48905 .67148 .48226 .66628 .474 Mtetra
.444 .579 .894 r
.66628 .474 .67148 .48226 .68217 .48011 .67717 .47588 Mtetra
.092 .524 .907 r
.67717 .47588 .68217 .48011 .69307 .48142 .68821 .4794 Mtetra
0 .464 .774 r
.68821 .4794 .69307 .48142 .70412 .48414 .69931 .4824 Mtetra
.311 .77 .949 r
.69931 .4824 .70412 .48414 .71513 .48463 .71029 .48157 Mtetra
.653 .878 .982 r
.71029 .48157 .71513 .48463 .72606 .48278 .72113 .47756 Mtetra
.736 .811 .911 r
.72113 .47756 .72606 .48278 .73691 .4789 .7319 .47193 Mtetra
.742 .754 .863 r
.7319 .47193 .73691 .4789 .74772 .47376 .74266 .46562 Mtetra
.717 .715 .847 r
.74266 .46562 .74772 .47376 .75854 .46842 .75349 .45993 Mtetra
.697 .698 .848 r
.75349 .45993 .75854 .46842 .76941 .46325 .76439 .45498 Mtetra
.672 .695 .863 r
.76439 .45498 .76941 .46325 .78035 .45875 .77541 .45098 Mtetra
.653 .701 .882 r
.77541 .45098 .78035 .45875 .79138 .45481 .78651 .44766 Mtetra
.641 .716 .902 r
.78651 .44766 .79138 .45481 .80249 .45134 .79769 .4447 Mtetra
.633 .73 .918 r
.79769 .4447 .80249 .45134 .81367 .44815 .80893 .44191 Mtetra
.634 .745 .929 r
.80893 .44191 .81367 .44815 .8249 .44506 .82022 .43902 Mtetra
.636 .755 .934 r
.82022 .43902 .8249 .44506 .83618 .44198 .83154 .43603 Mtetra
.642 .762 .935 r
.83154 .43603 .83618 .44198 .8475 .43883 .84289 .43286 Mtetra
.647 .764 .934 r
.84289 .43286 .8475 .43883 .85886 .43561 .85428 .42955 Mtetra
.652 .763 .931 r
.85428 .42955 .85886 .43561 .87026 .43229 .8657 .42612 Mtetra
.655 .762 .928 r
.8657 .42612 .87026 .43229 .88169 .4289 .87716 .42261 Mtetra
.657 .759 .925 r
.87716 .42261 .88169 .4289 .89317 .42545 .88866 .41904 Mtetra
.658 .755 .922 r
.88866 .41904 .89317 .42545 .90469 .42197 .90021 .41544 Mtetra
.649 .75 .923 r
.28248 .59781 .28853 .60308 .29783 .60028 .29179 .59508 Mtetra
.648 .753 .926 r
.29179 .59508 .29783 .60028 .30716 .59745 .30114 .59236 Mtetra
.649 .758 .929 r
.30114 .59236 .30716 .59745 .31653 .59458 .31052 .58961 Mtetra
.651 .764 .932 r
.31052 .58961 .31653 .59458 .32594 .59162 .31994 .58678 Mtetra
.654 .771 .935 r
.31994 .58678 .32594 .59162 .33539 .58855 .3294 .58386 Mtetra
.661 .779 .936 r
.3294 .58386 .33539 .58855 .34487 .58536 .3389 .58078 Mtetra
.67 .786 .936 r
.3389 .58078 .34487 .58536 .3544 .58199 .34845 .57747 Mtetra
.68 .791 .933 r
.34845 .57747 .3544 .58199 .36396 .57853 .35804 .57391 Mtetra
.692 .79 .925 r
.35804 .57391 .36396 .57853 .37356 .57497 .36768 .57003 Mtetra
.695 .779 .916 r
.36768 .57003 .37356 .57497 .38318 .57158 .37734 .56606 Mtetra
.693 .759 .902 r
.37734 .56606 .38318 .57158 .39282 .56853 .38704 .56212 Mtetra
.671 .724 .889 r
.38704 .56212 .39282 .56853 .40247 .56614 .39674 .55872 Mtetra
.636 .683 .877 r
.39674 .55872 .40247 .56614 .41212 .56468 .40645 .55627 Mtetra
.59 .637 .866 r
.40645 .55627 .41212 .56468 .4218 .56395 .41615 .55506 Mtetra
.527 .597 .867 r
.41615 .55506 .4218 .56395 .43151 .56382 .42585 .5554 Mtetra
.498 .596 .882 r
.42585 .5554 .43151 .56382 .44128 .56306 .4356 .55622 Mtetra
.488 .642 .925 r
.4356 .55622 .44128 .56306 .45114 .56071 .4454 .5567 Mtetra
.622 .807 .971 r
.4454 .5567 .45114 .56071 .4611 .55525 .45534 .55405 Mtetra
.802 .943 .918 r
.45534 .55405 .4611 .55525 .47114 .54604 .46539 .5467 Mtetra
.874 .978 .842 r
.46539 .5467 .47114 .54604 .48118 .53628 .4755 .53604 Mtetra
.908 .938 .816 r
.4755 .53604 .48118 .53628 .49121 .52811 .48563 .52358 Mtetra
.794 .818 .871 r
.48563 .52358 .49121 .52811 .5012 .52546 .49569 .51611 Mtetra
.529 .589 .859 r
.49569 .51611 .5012 .52546 .51121 .52952 .50572 .51651 Mtetra
.376 .431 .79 r
.50572 .51651 .51121 .52952 .52129 .53482 .51579 .52163 Mtetra
.257 .355 .773 r
.51579 .52163 .52129 .53482 .53146 .53841 .52595 .52933 Mtetra
.294 .47 .863 r
.52595 .52933 .53146 .53841 .54169 .53687 .5362 .53392 Mtetra
.404 .771 .994 r
.5362 .53392 .54169 .53687 .55191 .52962 .54651 .53333 Mtetra
.022 0 0 r
.54651 .53333 .55191 .52962 .56213 .52114 .55685 .53006 Mtetra
.245 0 .048 r
.55685 .53006 .56213 .52114 .57238 .51378 .5672 .5254 Mtetra
.384 .007 .194 r
.5672 .5254 .57238 .51378 .58271 .5106 .57761 .52222 Mtetra
.435 .055 .217 r
.57761 .52222 .58271 .5106 .59316 .51163 .58809 .52052 Mtetra
.331 0 .092 r
.58809 .52052 .59316 .51163 .60371 .5138 .59859 .51745 Mtetra
0 0 0 r
.59859 .51745 .60371 .5138 .61429 .51475 .60906 .51166 Mtetra
.872 .882 .84 r
.60906 .51166 .61429 .51475 .62477 .50995 .6194 .50065 Mtetra
.828 .717 .742 r
.6194 .50065 .62477 .50995 .63511 .49997 .62963 .48646 Mtetra
.76 .638 .726 r
.62963 .48646 .63511 .49997 .64539 .48823 .63992 .47485 Mtetra
.699 .611 .754 r
.63992 .47485 .64539 .48823 .65569 .47772 .65039 .468 Mtetra
.502 .572 .858 r
.65039 .468 .65569 .47772 .66628 .474 .66119 .46911 Mtetra
0 .342 .798 r
.66119 .46911 .66628 .474 .67717 .47588 .6723 .47532 Mtetra
.391 0 0 r
.6723 .47532 .67717 .47588 .68821 .4794 .68342 .47973 Mtetra
.157 0 0 r
.68342 .47973 .68821 .4794 .69931 .4824 .69447 .48079 Mtetra
.573 .907 .977 r
.69447 .48079 .69931 .4824 .71029 .48157 .70532 .47705 Mtetra
.777 .846 .903 r
.70532 .47705 .71029 .48157 .72113 .47756 .71603 .4701 Mtetra
.759 .746 .841 r
.71603 .4701 .72113 .47756 .7319 .47193 .72673 .46279 Mtetra
.733 .698 .817 r
.72673 .46279 .7319 .47193 .74266 .46562 .73748 .45596 Mtetra
.696 .672 .823 r
.73748 .45596 .74266 .46562 .75349 .45993 .74836 .4507 Mtetra
.667 .67 .843 r
.74836 .4507 .75349 .45993 .76439 .45498 .75936 .44673 Mtetra
.642 .684 .874 r
.75936 .44673 .76439 .45498 .77541 .45098 .77047 .44373 Mtetra
.621 .705 .905 r
.77047 .44373 .77541 .45098 .78651 .44766 .78167 .44129 Mtetra
.615 .733 .93 r
.78167 .44129 .78651 .44766 .79769 .4447 .79293 .43888 Mtetra
.614 .754 .945 r
.79293 .43888 .79769 .4447 .80893 .44191 .80423 .43637 Mtetra
.625 .771 .95 r
.80423 .43637 .80893 .44191 .82022 .43902 .81556 .43354 Mtetra
.635 .778 .95 r
.81556 .43354 .82022 .43902 .83154 .43603 .82691 .43045 Mtetra
.646 .779 .945 r
.82691 .43045 .83154 .43603 .84289 .43286 .83828 .42712 Mtetra
.653 .777 .939 r
.83828 .42712 .84289 .43286 .85428 .42955 .84968 .42361 Mtetra
.657 .772 .934 r
.84968 .42361 .85428 .42955 .8657 .42612 .86112 .42 Mtetra
.66 .767 .929 r
.86112 .42 .8657 .42612 .87716 .42261 .8726 .41632 Mtetra
.661 .762 .925 r
.8726 .41632 .87716 .42261 .88866 .41904 .88412 .41259 Mtetra
.661 .757 .921 r
.88412 .41259 .88866 .41904 .90021 .41544 .89569 .40886 Mtetra
.647 .749 .924 r
.27639 .59249 .28248 .59781 .29179 .59508 .28572 .58981 Mtetra
.645 .751 .926 r
.28572 .58981 .29179 .59508 .30114 .59236 .29508 .58715 Mtetra
.644 .754 .929 r
.29508 .58715 .30114 .59236 .31052 .58961 .30448 .58449 Mtetra
.644 .758 .932 r
.30448 .58449 .31052 .58961 .31994 .58678 .31391 .58181 Mtetra
.644 .764 .936 r
.31391 .58181 .31994 .58678 .3294 .58386 .32338 .5791 Mtetra
.649 .774 .94 r
.32338 .5791 .3294 .58386 .3389 .58078 .33289 .57625 Mtetra
.657 .786 .943 r
.33289 .57625 .3389 .58078 .34845 .57747 .34244 .5732 Mtetra
.67 .8 .945 r
.34244 .5732 .34845 .57747 .35804 .57391 .35205 .56982 Mtetra
.689 .812 .941 r
.35205 .56982 .35804 .57391 .36768 .57003 .36171 .56598 Mtetra
.705 .817 .935 r
.36171 .56598 .36768 .57003 .37734 .56606 .37141 .56175 Mtetra
.719 .81 .921 r
.37141 .56175 .37734 .56606 .38704 .56212 .38117 .55712 Mtetra
.712 .783 .907 r
.38117 .55712 .38704 .56212 .39674 .55872 .39094 .55262 Mtetra
.691 .741 .89 r
.39094 .55262 .39674 .55872 .40645 .55627 .40072 .54864 Mtetra
.64 .68 .872 r
.40072 .54864 .40645 .55627 .41615 .55506 .41048 .54602 Mtetra
.566 .613 .858 r
.41048 .54602 .41615 .55506 .42585 .5554 .42021 .54545 Mtetra
.5 .56 .848 r
.42021 .54545 .42585 .5554 .4356 .55622 .42995 .54659 Mtetra
.425 .528 .859 r
.42995 .54659 .4356 .55622 .4454 .5567 .43971 .54914 Mtetra
.483 .618 .908 r
.43971 .54914 .4454 .5567 .45534 .55405 .44958 .54991 Mtetra
.645 .81 .962 r
.44958 .54991 .45534 .55405 .46539 .5467 .45959 .54684 Mtetra
.823 .98 .887 r
.45959 .54684 .46539 .5467 .4755 .53604 .46972 .53823 Mtetra
.917 .977 .764 r
.46972 .53823 .4755 .53604 .48563 .52358 .47993 .52411 Mtetra
.898 .967 .822 r
.47993 .52411 .48563 .52358 .49569 .51611 .49009 .51223 Mtetra
.755 .843 .917 r
.49009 .51223 .49569 .51611 .50572 .51651 .50019 .5064 Mtetra
.502 .559 .846 r
.50019 .5064 .50572 .51651 .51579 .52163 .51027 .50756 Mtetra
.277 .354 .762 r
.51027 .50756 .51579 .52163 .52595 .52933 .52042 .51532 Mtetra
.27 .351 .763 r
.52042 .51532 .52595 .52933 .5362 .53392 .53066 .52323 Mtetra
.315 .443 .831 r
.53066 .52323 .5362 .53392 .54651 .53333 .541 .52838 Mtetra
.29 .623 .96 r
.541 .52838 .54651 .53333 .55685 .53006 .55141 .5303 Mtetra
.177 .713 .783 r
.55141 .5303 .55685 .53006 .5672 .5254 .56185 .52874 Mtetra
0 0 0 r
.56185 .52874 .5672 .5254 .57761 .52222 .57231 .52555 Mtetra
.57231 .52555 .57761 .52222 .58809 .52052 .58279 .52072 Mtetra
.785 .992 .883 r
.58279 .52072 .58809 .52052 .59859 .51745 .59322 .51239 Mtetra
.855 .816 .81 r
.59322 .51239 .59859 .51745 .60906 .51166 .60359 .50079 Mtetra
.812 .689 .729 r
.60359 .50079 .60906 .51166 .6194 .50065 .61386 .48637 Mtetra
.779 .64 .708 r
.61386 .48637 .6194 .50065 .62963 .48646 .62411 .47207 Mtetra
.704 .602 .74 r
.62411 .47207 .62963 .48646 .63992 .47485 .63455 .46441 Mtetra
.569 .592 .836 r
.63455 .46441 .63992 .47485 .65039 .468 .64526 .4638 Mtetra
0 .355 .788 r
.64526 .4638 .65039 .468 .66119 .46911 .65627 .46936 Mtetra
.629 .069 0 r
.65627 .46936 .66119 .46911 .6723 .47532 .66748 .47723 Mtetra
.388 0 0 r
.66748 .47723 .6723 .47532 .68342 .47973 .67855 .47951 Mtetra
.416 .863 .891 r
.67855 .47951 .68342 .47973 .69447 .48079 .68942 .47617 Mtetra
.785 .844 .896 r
.68942 .47617 .69447 .48079 .70532 .47705 .70012 .46889 Mtetra
.784 .736 .809 r
.70012 .46889 .70532 .47705 .71603 .4701 .71073 .45978 Mtetra
.738 .677 .792 r
.71073 .45978 .71603 .4701 .72673 .46279 .72144 .45208 Mtetra
.702 .656 .8 r
.72144 .45208 .72673 .46279 .73748 .45596 .73226 .44614 Mtetra
.661 .654 .833 r
.73226 .44614 .73748 .45596 .74836 .4507 .74326 .44228 Mtetra
.623 .671 .875 r
.74326 .44228 .74836 .4507 .75936 .44673 .75439 .43984 Mtetra
.598 .707 .92 r
.75439 .43984 .75936 .44673 .77047 .44373 .76561 .43793 Mtetra
.579 .74 .952 r
.76561 .43793 .77047 .44373 .78167 .44129 .7769 .43616 Mtetra
.588 .772 .967 r
.7769 .43616 .78167 .44129 .79293 .43888 .78821 .43397 Mtetra
.604 .789 .97 r
.78821 .43397 .79293 .43888 .80423 .43637 .79954 .43139 Mtetra
.628 .796 .963 r
.79954 .43139 .80423 .43637 .81556 .43354 .81088 .42832 Mtetra
.645 .794 .954 r
.81088 .42832 .81556 .43354 .82691 .43045 .82224 .42491 Mtetra
.656 .787 .944 r
.82224 .42491 .82691 .43045 .83828 .42712 .83363 .42129 Mtetra
.662 .779 .935 r
.83363 .42129 .83828 .42712 .84968 .42361 .84504 .41752 Mtetra
.664 .771 .929 r
.84504 .41752 .84968 .42361 .86112 .42 .8565 .41372 Mtetra
.665 .765 .924 r
.8565 .41372 .86112 .42 .8726 .41632 .868 .40989 Mtetra
.665 .76 .921 r
.868 .40989 .8726 .41632 .88412 .41259 .87954 .40605 Mtetra
.664 .757 .92 r
.87954 .40605 .88412 .41259 .89569 .40886 .89113 .40224 Mtetra
.647 .749 .924 r
.27027 .58715 .27639 .59249 .28572 .58981 .27962 .58443 Mtetra
.645 .748 .924 r
.27962 .58443 .28572 .58981 .29508 .58715 .289 .58175 Mtetra
.643 .747 .925 r
.289 .58175 .29508 .58715 .30448 .58449 .29841 .57912 Mtetra
.64 .748 .927 r
.29841 .57912 .30448 .58449 .31391 .58181 .30785 .57653 Mtetra
.635 .751 .932 r
.30785 .57653 .31391 .58181 .32338 .5791 .31733 .57402 Mtetra
.635 .76 .938 r
.31733 .57402 .32338 .5791 .33289 .57625 .32684 .57148 Mtetra
.635 .773 .946 r
.32684 .57148 .33289 .57625 .34244 .5732 .33639 .56887 Mtetra
.645 .794 .954 r
.33639 .56887 .34244 .5732 .35205 .56982 .346 .56599 Mtetra
.663 .819 .959 r
.346 .56599 .35205 .56982 .36171 .56598 .35566 .56265 Mtetra
.689 .846 .958 r
.35566 .56265 .36171 .56598 .37141 .56175 .36538 .55867 Mtetra
.725 .861 .946 r
.36538 .55867 .37141 .56175 .38117 .55712 .37517 .55384 Mtetra
.745 .855 .931 r
.37517 .55384 .38117 .55712 .39094 .55262 .38501 .54848 Mtetra
.754 .823 .906 r
.38501 .54848 .39094 .55262 .40072 .54864 .39488 .54276 Mtetra
.717 .757 .884 r
.39488 .54276 .40072 .54864 .41048 .54602 .40474 .53794 Mtetra
.651 .673 .858 r
.40474 .53794 .41048 .54602 .42021 .54545 .41457 .53492 Mtetra
.562 .58 .829 r
.41457 .53492 .42021 .54545 .42995 .54659 .42435 .53457 Mtetra
.448 .491 .811 r
.42435 .53457 .42995 .54659 .43971 .54914 .4341 .53743 Mtetra
.399 .469 .816 r
.4341 .53743 .43971 .54914 .44958 .54991 .4439 .54125 Mtetra
.372 .528 .882 r
.4439 .54125 .44958 .54991 .45959 .54684 .45379 .54421 Mtetra
.619 .869 .99 r
.45379 .54421 .45959 .54684 .46972 .53823 .46386 .541 Mtetra
.84 .997 .771 r
.46386 .541 .46972 .53823 .47993 .52411 .4741 .52938 Mtetra
.805 .96 .634 r
.4741 .52938 .47993 .52411 .49009 .51223 .48436 .5151 Mtetra
.884 .99 .748 r
.48436 .5151 .49009 .51223 .50019 .5064 .49458 .50171 Mtetra
.767 .815 .89 r
.49458 .50171 .50019 .5064 .51027 .50756 .50474 .49527 Mtetra
.466 .498 .807 r
.50474 .49527 .51027 .50756 .52042 .51532 .51488 .49787 Mtetra
.386 .382 .733 r
.51488 .49787 .52042 .51532 .53066 .52323 .5251 .50451 Mtetra
.362 .356 .718 r
.5251 .50451 .53066 .52323 .541 .52838 .53542 .51246 Mtetra
.406 .413 .754 r
.53542 .51246 .541 .52838 .55141 .5303 .54584 .51795 Mtetra
.52 .531 .807 r
.54584 .51795 .55141 .5303 .56185 .52874 .5563 .51906 Mtetra
.648 .645 .833 r
.5563 .51906 .56185 .52874 .57231 .52555 .56678 .51584 Mtetra
.74 .682 .795 r
.56678 .51584 .57231 .52555 .58279 .52072 .57723 .50828 Mtetra
.773 .656 .733 r
.57723 .50828 .58279 .52072 .59322 .51239 .58761 .4963 Mtetra
.765 .619 .697 r
.58761 .4963 .59322 .51239 .60359 .50079 .59792 .48183 Mtetra
.735 .584 .687 r
.59792 .48183 .60359 .50079 .61386 .48637 .60823 .46862 Mtetra
.702 .573 .707 r
.60823 .46862 .61386 .48637 .62411 .47207 .61863 .45947 Mtetra
.557 .547 .799 r
.61863 .45947 .62411 .47207 .63455 .46441 .62933 .45943 Mtetra
0 .272 .742 r
.62933 .45943 .63455 .46441 .64526 .4638 .64033 .46646 Mtetra
.666 .154 .014 r
.64033 .46646 .64526 .4638 .65627 .46936 .65148 .47442 Mtetra
.599 .116 .079 r
.65148 .47442 .65627 .46936 .66748 .47723 .66263 .47972 Mtetra
0 0 0 r
.66263 .47972 .66748 .47723 .67855 .47951 .6735 .47648 Mtetra
.847 .905 .875 r
.6735 .47648 .67855 .47951 .68942 .47617 .68411 .46693 Mtetra
.791 .716 .781 r
.68411 .46693 .68942 .47617 .70012 .46889 .69467 .45648 Mtetra
.745 .649 .754 r
.69467 .45648 .70012 .46889 .71073 .45978 .70528 .44699 Mtetra
.692 .619 .77 r
.70528 .44699 .71073 .45978 .72144 .45208 .71609 .44078 Mtetra
.646 .619 .809 r
.71609 .44078 .72144 .45208 .73226 .44614 .72708 .43729 Mtetra
.595 .647 .872 r
.72708 .43729 .73226 .44614 .74326 .44228 .73825 .43566 Mtetra
.538 .69 .937 r
.73825 .43566 .74326 .44228 .75439 .43984 .74953 .43496 Mtetra
.518 .752 .981 r
.74953 .43496 .75439 .43984 .76561 .43793 .76085 .4339 Mtetra
.522 .792 .995 r
.76085 .4339 .76561 .43793 .7769 .43616 .77219 .43229 Mtetra
.572 .823 .992 r
.77219 .43229 .7769 .43616 .78821 .43397 .78351 .4298 Mtetra
.617 .828 .981 r
.78351 .4298 .78821 .43397 .79954 .43139 .79484 .42666 Mtetra
.649 .817 .964 r
.79484 .42666 .79954 .43139 .81088 .42832 .80617 .42304 Mtetra
.666 .801 .947 r
.80617 .42304 .81088 .42832 .82224 .42491 .81752 .41912 Mtetra
.671 .784 .934 r
.81752 .41912 .82224 .42491 .83363 .42129 .82891 .41513 Mtetra
.672 .772 .925 r
.82891 .41513 .83363 .42129 .84504 .41752 .84034 .4111 Mtetra
.669 .762 .92 r
.84034 .4111 .84504 .41752 .8565 .41372 .85182 .40715 Mtetra
.667 .757 .918 r
.85182 .40715 .8565 .41372 .868 .40989 .86334 .40325 Mtetra
.665 .755 .917 r
.86334 .40325 .868 .40989 .87954 .40605 .87492 .39939 Mtetra
.663 .754 .918 r
.87492 .39939 .87954 .40605 .89113 .40224 .88655 .39556 Mtetra
.652 .751 .922 r
.2641 .58177 .27027 .58715 .27962 .58443 .27348 .57891 Mtetra
.651 .746 .919 r
.27348 .57891 .27962 .58443 .289 .58175 .28289 .5761 Mtetra
.647 .741 .918 r
.28289 .5761 .289 .58175 .29841 .57912 .29232 .57335 Mtetra
.642 .736 .917 r
.29232 .57335 .29841 .57912 .30785 .57653 .30179 .57071 Mtetra
.635 .733 .919 r
.30179 .57071 .30785 .57653 .31733 .57402 .31128 .56824 Mtetra
.629 .733 .923 r
.31128 .56824 .31733 .57402 .32684 .57148 .3208 .56588 Mtetra
.621 .738 .931 r
.3208 .56588 .32684 .57148 .33639 .56887 .33035 .56367 Mtetra
.622 .754 .941 r
.33035 .56367 .33639 .56887 .346 .56599 .33994 .56136 Mtetra
.627 .779 .954 r
.33994 .56136 .346 .56599 .35566 .56265 .34958 .55884 Mtetra
.65 .82 .965 r
.34958 .55884 .35566 .56265 .36538 .55867 .35929 .5557 Mtetra
.69 .863 .964 r
.35929 .5557 .36538 .55867 .37517 .55384 .36908 .55158 Mtetra
.732 .898 .954 r
.36908 .55158 .37517 .55384 .38501 .54848 .37895 .54638 Mtetra
.78 .905 .928 r
.37895 .54638 .38501 .54848 .39488 .54276 .38889 .53992 Mtetra
.785 .876 .914 r
.38889 .53992 .39488 .54276 .40474 .53794 .39885 .53329 Mtetra
.757 .807 .893 r
.39885 .53329 .40474 .53794 .41457 .53492 .4088 .5273 Mtetra
.669 .694 .864 r
.4088 .5273 .41457 .53492 .42435 .53457 .4187 .52373 Mtetra
.544 .566 .827 r
.4187 .52373 .42435 .53457 .4341 .53743 .42852 .52388 Mtetra
.434 .458 .786 r
.42852 .52388 .4341 .53743 .4439 .54125 .43831 .52753 Mtetra
.307 .379 .774 r
.43831 .52753 .4439 .54125 .45379 .54421 .44811 .53409 Mtetra
.412 .513 .851 r
.44811 .53409 .45379 .54421 .46386 .541 .45807 .537 Mtetra
.696 .832 .948 r
.45807 .537 .46386 .541 .4741 .52938 .46823 .53274 Mtetra
.773 .985 .739 r
.46823 .53274 .4741 .52938 .48436 .5151 .47851 .52186 Mtetra
.78 .925 .555 r
.47851 .52186 .48436 .5151 .49458 .50171 .48884 .50574 Mtetra
.811 .979 .693 r
.48884 .50574 .49458 .50171 .50474 .49527 .49911 .49293 Mtetra
.751 .91 .946 r
.49911 .49293 .50474 .49527 .51488 .49787 .50932 .48704 Mtetra
.551 .572 .829 r
.50932 .48704 .51488 .49787 .5251 .50451 .51954 .48699 Mtetra
.449 .422 .737 r
.51954 .48699 .5251 .50451 .53542 .51246 .52983 .49154 Mtetra
.48 .416 .708 r
.52983 .49154 .53542 .51246 .54584 .51795 .5402 .49568 Mtetra
.541 .448 .698 r
.5402 .49568 .54584 .51795 .5563 .51906 .55063 .4969 Mtetra
.611 .493 .694 r
.55063 .4969 .5563 .51906 .56678 .51584 .56109 .49365 Mtetra
.665 .527 .685 r
.56109 .49365 .56678 .51584 .57723 .50828 .57152 .4859 Mtetra
.694 .543 .678 r
.57152 .4859 .57723 .50828 .58761 .4963 .58191 .4752 Mtetra
.704 .555 .683 r
.58191 .4752 .58761 .4963 .59792 .48183 .59228 .46407 Mtetra
.669 .555 .716 r
.59228 .46407 .59792 .48183 .60823 .46862 .60276 .45756 Mtetra
.57 .581 .825 r
.60276 .45756 .60823 .46862 .61863 .45947 .61341 .45692 Mtetra
.403 0 0 r
.61341 .45692 .61863 .45947 .62933 .45943 .62433 .46329 Mtetra
.71 .233 .116 r
.62433 .46329 .62933 .45943 .64033 .46646 .63547 .47305 Mtetra
.581 .123 .131 r
.63547 .47305 .64033 .46646 .65148 .47442 .64655 .47754 Mtetra
.09 0 0 r
.64655 .47754 .65148 .47442 .66263 .47972 .65745 .47533 Mtetra
.835 .854 .86 r
.65745 .47533 .66263 .47972 .6735 .47648 .66808 .4658 Mtetra
.807 .697 .743 r
.66808 .4658 .6735 .47648 .68411 .46693 .67854 .45253 Mtetra
.739 .624 .731 r
.67854 .45253 .68411 .46693 .69467 .45648 .68912 .44219 Mtetra
.691 .601 .75 r
.68912 .44219 .69467 .45648 .70528 .44699 .69989 .43542 Mtetra
.632 .608 .808 r
.69989 .43542 .70528 .44699 .71609 .44078 .71089 .43244 Mtetra
.548 .639 .893 r
.71089 .43244 .71609 .44078 .72708 .43729 .72209 .43197 Mtetra
.45 .699 .973 r
.72209 .43197 .72708 .43729 .73825 .43566 .7334 .43215 Mtetra
.365 .735 .989 r
.7334 .43215 .73825 .43566 .74953 .43496 .74477 .43218 Mtetra
.427 .801 .993 r
.74477 .43218 .74953 .43496 .76085 .4339 .75612 .43091 Mtetra
.528 .843 .999 r
.75612 .43091 .76085 .4339 .77219 .43229 .76744 .42853 Mtetra
.62 .848 .986 r
.76744 .42853 .77219 .43229 .78351 .4298 .77874 .42513 Mtetra
.667 .826 .96 r
.77874 .42513 .78351 .4298 .79484 .42666 .79003 .4211 Mtetra
.681 .796 .936 r
.79003 .4211 .79484 .42666 .80617 .42304 .80135 .41682 Mtetra
.684 .774 .919 r
.80135 .41682 .80617 .42304 .81752 .41912 .81269 .41245 Mtetra
.679 .757 .91 r
.81269 .41245 .81752 .41912 .82891 .41513 .82409 .40822 Mtetra
.674 .748 .907 r
.82409 .40822 .82891 .41513 .84034 .4111 .83555 .40411 Mtetra
.668 .744 .907 r
.83555 .40411 .84034 .4111 .85182 .40715 .84706 .40017 Mtetra
.664 .743 .909 r
.84706 .40017 .85182 .40715 .86334 .40325 .85863 .39633 Mtetra
.661 .745 .913 r
.85863 .39633 .86334 .40325 .87492 .39939 .87025 .39257 Mtetra
.659 .749 .916 r
.87025 .39257 .87492 .39939 .88655 .39556 .88193 .38884 Mtetra
.661 .753 .918 r
.25789 .57635 .2641 .58177 .27348 .57891 .2673 .57328 Mtetra
.66 .746 .913 r
.2673 .57328 .27348 .57891 .28289 .5761 .27675 .57022 Mtetra
.657 .737 .908 r
.27675 .57022 .28289 .5761 .29232 .57335 .28622 .56722 Mtetra
.652 .727 .904 r
.28622 .56722 .29232 .57335 .30179 .57071 .29572 .56435 Mtetra
.643 .718 .902 r
.29572 .56435 .30179 .57071 .31128 .56824 .30524 .56168 Mtetra
.633 .709 .902 r
.30524 .56168 .31128 .56824 .3208 .56588 .31478 .55927 Mtetra
.617 .703 .906 r
.31478 .55927 .3208 .56588 .33035 .56367 .32433 .55721 Mtetra
.605 .705 .914 r
.32433 .55721 .33035 .56367 .33994 .56136 .33391 .55539 Mtetra
.59 .717 .932 r
.33391 .55539 .33994 .56136 .34958 .55884 .34352 .55379 Mtetra
.594 .754 .955 r
.34352 .55379 .34958 .55884 .35929 .5557 .35319 .55192 Mtetra
.61 .813 .978 r
.35319 .55192 .35929 .5557 .36908 .55158 .36293 .54941 Mtetra
.653 .891 .982 r
.36293 .54941 .36908 .55158 .37895 .54638 .37277 .54561 Mtetra
.724 .951 .95 r
.37277 .54561 .37895 .54638 .38889 .53992 .38272 .53993 Mtetra
.778 .975 .915 r
.38272 .53993 .38889 .53992 .39885 .53329 .39275 .5327 Mtetra
.836 .952 .892 r
.39275 .5327 .39885 .53329 .4088 .5273 .40284 .5241 Mtetra
.811 .863 .887 r
.40284 .5241 .4088 .5273 .4187 .52373 .41291 .51634 Mtetra
.718 .717 .848 r
.41291 .51634 .4187 .52373 .42852 .52388 .42291 .511 Mtetra
.568 .545 .789 r
.42291 .511 .42852 .52388 .43831 .52753 .4328 .51057 Mtetra
.399 .395 .739 r
.4328 .51057 .43831 .52753 .44811 .53409 .44259 .51627 Mtetra
.349 .355 .725 r
.44259 .51627 .44811 .53409 .45807 .537 .45243 .52376 Mtetra
.312 .393 .784 r
.45243 .52376 .45807 .537 .46823 .53274 .4624 .52996 Mtetra
.479 .816 .999 r
.4624 .52996 .46823 .53274 .47851 .52186 .47258 .52845 Mtetra
.534 .82 .476 r
.47258 .52845 .47851 .52186 .48884 .50574 .48294 .51683 Mtetra
0 0 0 r
.48294 .51683 .48884 .50574 .49911 .49293 .49332 .5017 Mtetra
.49332 .5017 .49911 .49293 .50932 .48704 .50366 .48661 Mtetra
.875 .96 .854 r
.50366 .48661 .50932 .48704 .51954 .48699 .51396 .47605 Mtetra
.676 .632 .798 r
.51396 .47605 .51954 .48699 .52983 .49154 .52424 .47142 Mtetra
.599 .496 .708 r
.52424 .47142 .52983 .49154 .5402 .49568 .53457 .46915 Mtetra
.582 .454 .672 r
.53457 .46915 .5402 .49568 .55063 .4969 .54494 .46757 Mtetra
.598 .456 .659 r
.54494 .46757 .55063 .4969 .56109 .49365 .55534 .46427 Mtetra
.616 .468 .658 r
.55534 .46427 .56109 .49365 .57152 .4859 .56577 .45925 Mtetra
.614 .475 .669 r
.56577 .45925 .57152 .4859 .58191 .4752 .57623 .45491 Mtetra
.594 .493 .709 r
.57623 .45491 .58191 .4752 .59228 .46407 .58677 .45295 Mtetra
.386 .479 .832 r
.58677 .45295 .59228 .46407 .60276 .45756 .59749 .45696 Mtetra
.647 .089 0 r
.59749 .45696 .60276 .45756 .61341 .45692 .60842 .46558 Mtetra
.671 .256 .248 r
.60842 .46558 .61341 .45692 .62433 .46329 .61947 .47428 Mtetra
.6 .203 .262 r
.61947 .47428 .62433 .46329 .63547 .47305 .63053 .47947 Mtetra
.097 0 0 r
.63053 .47947 .63547 .47305 .64655 .47754 .64133 .47442 Mtetra
.897 .886 .814 r
.64133 .47442 .64655 .47754 .65745 .47533 .65185 .46152 Mtetra
.785 .651 .715 r
.65185 .46152 .65745 .47533 .66808 .4658 .6623 .44726 Mtetra
.732 .587 .694 r
.6623 .44726 .66808 .4658 .67854 .45253 .6728 .4348 Mtetra
.664 .555 .721 r
.6728 .4348 .67854 .45253 .68912 .44219 .68358 .42858 Mtetra
.586 .553 .785 r
.68358 .42858 .68912 .44219 .69989 .43542 .69465 .42737 Mtetra
.46 .603 .907 r
.69465 .42737 .69989 .43542 .71089 .43244 .70592 .42866 Mtetra
.181 .611 .942 r
.70592 .42866 .71089 .43244 .72209 .43197 .71731 .43081 Mtetra
.051 .607 .815 r
.71731 .43081 .72209 .43197 .7334 .43215 .7287 .43158 Mtetra
.159 .697 .827 r
.7287 .43158 .7334 .43215 .74477 .43218 .74007 .43077 Mtetra
.451 .862 .958 r
.74007 .43077 .74477 .43218 .75612 .43091 .75136 .42801 Mtetra
.635 .89 .986 r
.75136 .42801 .75612 .43091 .76744 .42853 .7626 .42392 Mtetra
.696 .839 .951 r
.7626 .42392 .76744 .42853 .77874 .42513 .77383 .41917 Mtetra
.708 .791 .916 r
.77383 .41917 .77874 .42513 .79003 .4211 .78508 .41412 Mtetra
.697 .754 .895 r
.78508 .41412 .79003 .4211 .80135 .41682 .79638 .4093 Mtetra
.687 .734 .886 r
.79638 .4093 .80135 .41682 .81269 .41245 .80774 .40471 Mtetra
.675 .723 .886 r
.80774 .40471 .81269 .41245 .82409 .40822 .81917 .40049 Mtetra
.667 .721 .889 r
.81917 .40049 .82409 .40822 .83555 .40411 .83067 .39654 Mtetra
.66 .723 .896 r
.83067 .39654 .83555 .40411 .84706 .40017 .84224 .39279 Mtetra
.655 .728 .903 r
.84224 .39279 .84706 .40017 .85863 .39633 .85386 .38917 Mtetra
.652 .735 .91 r
.85386 .38917 .85863 .39633 .87025 .39257 .86554 .38562 Mtetra
.652 .743 .916 r
.86554 .38562 .87025 .39257 .88193 .38884 .87727 .38207 Mtetra
.668 .754 .915 r
.25164 .57089 .25789 .57635 .2673 .57328 .26109 .56763 Mtetra
.669 .748 .91 r
.26109 .56763 .2673 .57328 .27675 .57022 .27057 .56433 Mtetra
.668 .741 .905 r
.27057 .56433 .27675 .57022 .28622 .56722 .28008 .56104 Mtetra
.664 .731 .899 r
.28008 .56104 .28622 .56722 .29572 .56435 .28962 .55783 Mtetra
.658 .719 .893 r
.28962 .55783 .29572 .56435 .30524 .56168 .29918 .55476 Mtetra
.647 .703 .888 r
.29918 .55476 .30524 .56168 .31478 .55927 .30876 .55196 Mtetra
.631 .687 .884 r
.30876 .55196 .31478 .55927 .32433 .55721 .31835 .54957 Mtetra
.612 .671 .882 r
.31835 .54957 .32433 .55721 .33391 .55539 .32795 .54766 Mtetra
.586 .659 .888 r
.32795 .54766 .33391 .55539 .34352 .55379 .33755 .54637 Mtetra
.571 .663 .9 r
.33755 .54637 .34352 .55379 .35319 .55192 .34719 .54536 Mtetra
.556 .686 .926 r
.34719 .54536 .35319 .55192 .36293 .54941 .35687 .54447 Mtetra
.579 .757 .962 r
.35687 .54447 .36293 .54941 .37277 .54561 .36663 .54275 Mtetra
.632 .86 .985 r
.36663 .54275 .37277 .54561 .38272 .53993 .37651 .53951 Mtetra
.696 .957 .948 r
.37651 .53951 .38272 .53993 .39275 .5327 .38651 .53403 Mtetra
.78 .995 .868 r
.38651 .53403 .39275 .5327 .40284 .5241 .39664 .52573 Mtetra
.824 .998 .843 r
.39664 .52573 .40284 .5241 .41291 .51634 .40683 .5161 Mtetra
.863 .957 .867 r
.40683 .5161 .41291 .51634 .42291 .511 .41702 .50622 Mtetra
.767 .808 .886 r
.41702 .50622 .42291 .511 .4328 .51057 .42711 .49976 Mtetra
.573 .584 .825 r
.42711 .49976 .4328 .51057 .44259 .51627 .43706 .499 Mtetra
.428 .411 .738 r
.43706 .499 .44259 .51627 .45243 .52376 .44693 .50388 Mtetra
.302 .306 .698 r
.44693 .50388 .45243 .52376 .4624 .52996 .4568 .51359 Mtetra
.368 .385 .746 r
.4568 .51359 .4624 .52996 .47258 .52845 .46683 .51992 Mtetra
.583 .644 .876 r
.46683 .51992 .47258 .52845 .48294 .51683 .47707 .51869 Mtetra
.722 .988 .825 r
.47707 .51869 .48294 .51683 .49332 .5017 .48744 .51033 Mtetra
0 0 0 r
.48744 .51033 .49332 .5017 .50366 .48661 .49787 .49587 Mtetra
.49787 .49587 .50366 .48661 .51396 .47605 .50827 .48165 Mtetra
.575 .859 .534 r
.50827 .48165 .51396 .47605 .52424 .47142 .51863 .47045 Mtetra
.813 .962 .906 r
.51863 .47045 .52424 .47142 .53457 .46915 .52899 .4623 Mtetra
.71 .74 .875 r
.52899 .4623 .53457 .46915 .54494 .46757 .53936 .45733 Mtetra
.647 .634 .823 r
.53936 .45733 .54494 .46757 .55534 .46427 .54978 .454 Mtetra
.6 .612 .836 r
.54978 .454 .55534 .46427 .56577 .45925 .56026 .45233 Mtetra
.412 .613 .933 r
.56026 .45233 .56577 .45925 .57623 .45491 .57083 .45385 Mtetra
.395 0 0 r
.57083 .45385 .57623 .45491 .58677 .45295 .58153 .45846 Mtetra
.664 .204 .15 r
.58153 .45846 .58677 .45295 .59749 .45696 .59238 .46613 Mtetra
.657 .245 .251 r
.59238 .46613 .59749 .45696 .60842 .46558 .60335 .4741 Mtetra
.508 .076 .153 r
.60335 .4741 .60842 .46558 .61947 .47428 .61427 .47593 Mtetra
.428 .861 .753 r
.61427 .47593 .61947 .47428 .63053 .47947 .62505 .47055 Mtetra
.825 .731 .761 r
.62505 .47055 .63053 .47947 .64133 .47442 .6356 .45749 Mtetra
.778 .623 .687 r
.6356 .45749 .64133 .47442 .65185 .46152 .646 .44096 Mtetra
.712 .564 .686 r
.646 .44096 .65185 .46152 .6623 .44726 .65655 .42929 Mtetra
.659 .55 .72 r
.65655 .42929 .6623 .44726 .6728 .4348 .66734 .42336 Mtetra
.551 .57 .826 r
.66734 .42336 .6728 .4348 .68358 .42858 .67843 .42324 Mtetra
.187 .547 .93 r
.67843 .42324 .68358 .42858 .69465 .42737 .68976 .42664 Mtetra
.253 0 0 r
.68976 .42664 .69465 .42737 .70592 .42866 .70117 .42981 Mtetra
.289 0 0 r
.70117 .42981 .70592 .42866 .71731 .43081 .7126 .43162 Mtetra
0 0 0 r
.7126 .43162 .71731 .43081 .7287 .43158 .72393 .43055 Mtetra
.473 .882 .942 r
.72393 .43055 .7287 .43158 .74007 .43077 .73517 .42719 Mtetra
.695 .881 .967 r
.73517 .42719 .74007 .43077 .75136 .42801 .74635 .42224 Mtetra
.733 .805 .909 r
.74635 .42224 .75136 .42801 .7626 .42392 .75751 .41643 Mtetra
.719 .745 .873 r
.75751 .41643 .7626 .42392 .77383 .41917 .7687 .41073 Mtetra
.705 .715 .857 r
.7687 .41073 .77383 .41917 .78508 .41412 .77995 .40531 Mtetra
.686 .699 .856 r
.77995 .40531 .78508 .41412 .79638 .4093 .79128 .40052 Mtetra
.673 .695 .862 r
.79128 .40052 .79638 .4093 .80774 .40471 .80269 .39624 Mtetra
.662 .698 .873 r
.80269 .39624 .80774 .40471 .81917 .40049 .81419 .39237 Mtetra
.653 .705 .885 r
.81419 .39237 .81917 .40049 .83067 .39654 .82575 .38879 Mtetra
.649 .715 .896 r
.82575 .38879 .83067 .39654 .84224 .39279 .83738 .38535 Mtetra
.646 .724 .905 r
.83738 .38535 .84224 .39279 .85386 .38917 .84906 .38198 Mtetra
.644 .732 .913 r
.84906 .38198 .85386 .38917 .86554 .38562 .8608 .37864 Mtetra
.645 .741 .919 r
.8608 .37864 .86554 .38562 .87727 .38207 .87259 .37524 Mtetra
.671 .755 .914 r
.24535 .5654 .25164 .57089 .26109 .56763 .25483 .56204 Mtetra
.674 .753 .91 r
.25483 .56204 .26109 .56763 .27057 .56433 .26434 .55859 Mtetra
.676 .749 .906 r
.26434 .55859 .27057 .56433 .28008 .56104 .27389 .55506 Mtetra
.677 .742 .9 r
.27389 .55506 .28008 .56104 .28962 .55783 .28347 .55151 Mtetra
.677 .731 .891 r
.28347 .55151 .28962 .55783 .29918 .55476 .29308 .54791 Mtetra
.67 .714 .881 r
.29308 .54791 .29918 .55476 .30876 .55196 .30272 .54445 Mtetra
.659 .692 .87 r
.30272 .54445 .30876 .55196 .31835 .54957 .31237 .54125 Mtetra
.639 .664 .858 r
.31237 .54125 .31835 .54957 .32795 .54766 .32203 .53859 Mtetra
.61 .635 .851 r
.32203 .53859 .32795 .54766 .33755 .54637 .33167 .53674 Mtetra
.579 .609 .847 r
.33167 .53674 .33755 .54637 .34719 .54536 .34131 .53576 Mtetra
.536 .59 .856 r
.34131 .53576 .34719 .54536 .35687 .54447 .35095 .53583 Mtetra
.513 .604 .882 r
.35095 .53583 .35687 .54447 .36663 .54275 .36062 .5362 Mtetra
.488 .661 .938 r
.36062 .5362 .36663 .54275 .37651 .53951 .37036 .53638 Mtetra
.513 .813 .999 r
.37036 .53638 .37651 .53951 .38651 .53403 .38022 .53477 Mtetra
.544 .927 .891 r
.38022 .53477 .38651 .53403 .39664 .52573 .39026 .53013 Mtetra
.503 .864 .626 r
.39026 .53013 .39664 .52573 .40683 .5161 .40045 .52216 Mtetra
.63 .894 .572 r
.40045 .52216 .40683 .5161 .41702 .50622 .41077 .51065 Mtetra
.795 .979 .701 r
.41077 .51065 .41702 .50622 .42711 .49976 .4211 .49835 Mtetra
.88 .914 .846 r
.4211 .49835 .42711 .49976 .43706 .499 .43137 .48741 Mtetra
.674 .62 .786 r
.43137 .48741 .43706 .499 .44693 .50388 .44148 .48267 Mtetra
.481 .413 .704 r
.44148 .48267 .44693 .50388 .4568 .51359 .45143 .4865 Mtetra
.407 .333 .661 r
.45143 .4865 .4568 .51359 .46683 .51992 .46136 .49523 Mtetra
.336 .297 .667 r
.46136 .49523 .46683 .51992 .47707 .51869 .47137 .50609 Mtetra
.323 .414 .8 r
.47137 .50609 .47707 .51869 .48744 .51033 .48157 .5117 Mtetra
.213 .732 .715 r
.48157 .5117 .48744 .51033 .49787 .49587 .49195 .50888 Mtetra
.166 0 .1 r
.49195 .50888 .49787 .49587 .50827 .48165 .50241 .50051 Mtetra
.19 0 .208 r
.50241 .50051 .50827 .48165 .51863 .47045 .51289 .48864 Mtetra
.214 0 .212 r
.51289 .48864 .51863 .47045 .52899 .4623 .52336 .47781 Mtetra
.277 0 .202 r
.52336 .47781 .52899 .4623 .53936 .45733 .53383 .47028 Mtetra
.383 .011 .204 r
.53383 .47028 .53936 .45733 .54978 .454 .54433 .46695 Mtetra
.507 .129 .259 r
.54433 .46695 .54978 .454 .56026 .45233 .55492 .46782 Mtetra
.579 .22 .324 r
.55492 .46782 .56026 .45233 .57083 .45385 .56561 .47203 Mtetra
.592 .248 .356 r
.56561 .47203 .57083 .45385 .58153 .45846 .57641 .47732 Mtetra
.538 .2 .343 r
.57641 .47732 .58153 .45846 .59238 .46613 .58724 .47909 Mtetra
.369 0 .197 r
.58724 .47909 .59238 .46613 .60335 .4741 .59803 .47529 Mtetra
.872 .994 .792 r
.59803 .47529 .60335 .4741 .61427 .47593 .60863 .46295 Mtetra
.82 .674 .701 r
.60863 .46295 .61427 .47593 .62505 .47055 .61907 .44526 Mtetra
.72 .549 .658 r
.61907 .44526 .62505 .47055 .6356 .45749 .62952 .42968 Mtetra
.671 .509 .658 r
.62952 .42968 .6356 .45749 .646 .44096 .6401 .41905 Mtetra
.589 .483 .701 r
.6401 .41905 .646 .44096 .65655 .42929 .65102 .41711 Mtetra
.39 .465 .817 r
.65102 .41711 .65655 .42929 .66734 .42336 .66226 .42151 Mtetra
.388 0 0 r
.66226 .42151 .66734 .42336 .67843 .42324 .67366 .42732 Mtetra
.571 .057 0 r
.67366 .42732 .67843 .42324 .68976 .42664 .68513 .43236 Mtetra
.451 0 0 r
.68513 .43236 .68976 .42664 .70117 .42981 .69652 .4338 Mtetra
.178 0 0 r
.69652 .4338 .70117 .42981 .7126 .43162 .70779 .43183 Mtetra
.514 .915 .869 r
.70779 .43183 .7126 .43162 .72393 .43055 .71893 .42674 Mtetra
.773 .887 .927 r
.71893 .42674 .72393 .43055 .73517 .42719 .72999 .41979 Mtetra
.755 .759 .856 r
.72999 .41979 .73517 .42719 .74635 .42224 .74106 .41263 Mtetra
.728 .697 .82 r
.74106 .41263 .74635 .42224 .75751 .41643 .75216 .40578 Mtetra
.698 .663 .813 r
.75216 .40578 .75751 .41643 .7687 .41073 .76337 .39999 Mtetra
.677 .653 .819 r
.76337 .39999 .7687 .41073 .77995 .40531 .77468 .3951 Mtetra
.66 .656 .835 r
.77468 .3951 .77995 .40531 .79128 .40052 .7861 .39104 Mtetra
.648 .667 .855 r
.7861 .39104 .79128 .40052 .80269 .39624 .7976 .38755 Mtetra
.641 .685 .875 r
.7976 .38755 .80269 .39624 .81419 .39237 .80918 .38432 Mtetra
.636 .701 .893 r
.80918 .38432 .81419 .39237 .82575 .38879 .82082 .38124 Mtetra
.637 .717 .905 r
.82082 .38124 .82575 .38879 .83738 .38535 .83251 .37811 Mtetra
.637 .728 .914 r
.83251 .37811 .83738 .38535 .84906 .38198 .84425 .37494 Mtetra
.639 .736 .919 r
.84425 .37494 .84906 .38198 .8608 .37864 .85604 .37171 Mtetra
.642 .742 .922 r
.85604 .37171 .8608 .37864 .87259 .37524 .86786 .36837 Mtetra
.666 .754 .916 r
.23902 .55988 .24535 .5654 .25483 .56204 .2485 .55661 Mtetra
.67 .759 .917 r
.2485 .55661 .25483 .56204 .26434 .55859 .25803 .55324 Mtetra
.675 .764 .918 r
.25803 .55324 .26434 .55859 .27389 .55506 .2676 .54974 Mtetra
.681 .766 .916 r
.2676 .54974 .27389 .55506 .28347 .55151 .27721 .54607 Mtetra
.689 .765 .91 r
.27721 .54607 .28347 .55151 .29308 .54791 .28687 .54218 Mtetra
.691 .756 .901 r
.28687 .54218 .29308 .54791 .30272 .54445 .29656 .53819 Mtetra
.691 .739 .888 r
.29656 .53819 .30272 .54445 .31237 .54125 .30629 .53413 Mtetra
.678 .711 .873 r
.30629 .53413 .31237 .54125 .32203 .53859 .31603 .53037 Mtetra
.656 .674 .856 r
.31603 .53037 .32203 .53859 .33167 .53674 .32576 .52716 Mtetra
.621 .63 .838 r
.32576 .52716 .33167 .53674 .34131 .53576 .33548 .52493 Mtetra
.574 .583 .824 r
.33548 .52493 .34131 .53576 .35095 .53583 .34516 .52412 Mtetra
.532 .546 .815 r
.34516 .52412 .35095 .53583 .36062 .5362 .35482 .52458 Mtetra
.48 .52 .822 r
.35482 .52458 .36062 .5362 .37036 .53638 .36448 .52632 Mtetra
.471 .55 .855 r
.36448 .52632 .37036 .53638 .38022 .53477 .37422 .52784 Mtetra
.493 .652 .93 r
.37422 .52784 .38022 .53477 .39026 .53013 .38407 .52803 Mtetra
.575 .877 .993 r
.38407 .52803 .39026 .53013 .40045 .52216 .39411 .52508 Mtetra
.601 .94 .76 r
.39411 .52508 .40045 .52216 .41077 .51065 .40434 .51764 Mtetra
.521 .816 .478 r
.40434 .51764 .41077 .51065 .4211 .49835 .41472 .50634 Mtetra
.642 .859 .481 r
.41472 .50634 .4211 .49835 .43137 .48741 .42518 .49194 Mtetra
.775 .972 .687 r
.42518 .49194 .43137 .48741 .44148 .48267 .43554 .47976 Mtetra
.784 .886 .919 r
.43554 .47976 .44148 .48267 .45143 .4865 .44576 .47297 Mtetra
.537 .522 .786 r
.44576 .47297 .45143 .4865 .46136 .49523 .45585 .47348 Mtetra
.377 .343 .693 r
.45585 .47348 .46136 .49523 .47137 .50609 .46586 .48149 Mtetra
.389 .334 .675 r
.46586 .48149 .47137 .50609 .48157 .5117 .47597 .49013 Mtetra
.438 .386 .702 r
.47597 .49013 .48157 .5117 .49195 .50888 .48623 .49585 Mtetra
.525 .526 .799 r
.48623 .49585 .49195 .50888 .50241 .50051 .49662 .49668 Mtetra
.692 .848 .958 r
.49662 .49668 .50241 .50051 .51289 .48864 .50711 .49227 Mtetra
0 0 0 r
.50711 .49227 .51289 .48864 .52336 .47781 .51764 .48639 Mtetra
.15 0 0 r
.51764 .48639 .52336 .47781 .53383 .47028 .52819 .48086 Mtetra
.337 0 .123 r
.52819 .48086 .53383 .47028 .54433 .46695 .53877 .47752 Mtetra
.424 .02 .166 r
.53877 .47752 .54433 .46695 .55492 .46782 .54941 .47637 Mtetra
.408 0 .097 r
.54941 .47637 .55492 .46782 .56561 .47203 .56012 .47558 Mtetra
.102 0 0 r
.56012 .47558 .56561 .47203 .57641 .47732 .57086 .47333 Mtetra
.794 .864 .901 r
.57086 .47333 .57641 .47732 .58724 .47909 .58155 .46579 Mtetra
.772 .651 .728 r
.58155 .46579 .58724 .47909 .59803 .47529 .59217 .45331 Mtetra
.737 .572 .67 r
.59217 .45331 .59803 .47529 .60863 .46295 .60269 .43783 Mtetra
.716 .547 .66 r
.60269 .43783 .60863 .46295 .61907 .44526 .61319 .42295 Mtetra
.658 .523 .688 r
.61319 .42295 .61907 .44526 .62952 .42968 .62388 .41564 Mtetra
.55 .528 .784 r
.62388 .41564 .62952 .42968 .6401 .41905 .63485 .41574 Mtetra
0 .302 .705 r
.63485 .41574 .6401 .41905 .65102 .41711 .64609 .42134 Mtetra
.658 .166 .069 r
.64609 .42134 .65102 .41711 .66226 .42151 .65752 .42924 Mtetra
.582 .135 .154 r
.65752 .42924 .66226 .42151 .67366 .42732 .66894 .43402 Mtetra
.441 0 .037 r
.66894 .43402 .67366 .42732 .68513 .43236 .68028 .43486 Mtetra
0 0 0 r
.68028 .43486 .68513 .43236 .69652 .4338 .69145 .43111 Mtetra
.768 .928 .939 r
.69145 .43111 .69652 .4338 .70779 .43183 .70249 .42413 Mtetra
.777 .757 .835 r
.70249 .42413 .70779 .43183 .71893 .42674 .71348 .41577 Mtetra
.747 .678 .785 r
.71348 .41577 .71893 .42674 .72999 .41979 .72445 .40715 Mtetra
.711 .637 .773 r
.72445 .40715 .72999 .41979 .74106 .41263 .73553 .39985 Mtetra
.687 .624 .78 r
.73553 .39985 .74106 .41263 .75216 .40578 .74671 .39384 Mtetra
.663 .626 .802 r
.74671 .39384 .75216 .40578 .76337 .39999 .75803 .38929 Mtetra
.644 .639 .83 r
.75803 .38929 .76337 .39999 .77468 .3951 .76946 .38576 Mtetra
.632 .664 .863 r
.76946 .38576 .77468 .3951 .7861 .39104 .78099 .3828 Mtetra
.622 .689 .892 r
.78099 .3828 .7861 .39104 .7976 .38755 .79259 .38015 Mtetra
.622 .715 .913 r
.79259 .38015 .7976 .38755 .80918 .38432 .80425 .37743 Mtetra
.623 .734 .926 r
.80425 .37743 .80918 .38432 .82082 .38124 .81595 .3746 Mtetra
.631 .747 .931 r
.81595 .3746 .82082 .38124 .83251 .37811 .82768 .37154 Mtetra
.636 .753 .932 r
.82768 .37154 .83251 .37811 .84425 .37494 .83945 .36831 Mtetra
.641 .753 .93 r
.83945 .36831 .84425 .37494 .85604 .37171 .85126 .36493 Mtetra
.646 .751 .926 r
.85126 .36493 .85604 .37171 .86786 .36837 .8631 .36144 Mtetra
.653 .751 .921 r
.23264 .55431 .23902 .55988 .2485 .55661 .24212 .55134 Mtetra
.655 .762 .928 r
.24212 .55134 .2485 .55661 .25803 .55324 .25164 .54829 Mtetra
.661 .777 .935 r
.25164 .54829 .25803 .55324 .2676 .54974 .26121 .54508 Mtetra
.671 .791 .938 r
.26121 .54508 .2676 .54974 .27721 .54607 .27083 .54163 Mtetra
.685 .802 .937 r
.27083 .54163 .27721 .54607 .28687 .54218 .2805 .53782 Mtetra
.699 .809 .933 r
.2805 .53782 .28687 .54218 .29656 .53819 .29024 .53364 Mtetra
.716 .804 .92 r
.29024 .53364 .29656 .53819 .30629 .53413 .30003 .52899 Mtetra
.721 .785 .903 r
.30003 .52899 .30629 .53413 .31603 .53037 .30986 .52414 Mtetra
.717 .749 .877 r
.30986 .52414 .31603 .53037 .32576 .52716 .31972 .51918 Mtetra
.691 .694 .848 r
.31972 .51918 .32576 .52716 .33548 .52493 .32958 .51476 Mtetra
.652 .632 .817 r
.32958 .51476 .33548 .52493 .34516 .52412 .33941 .51136 Mtetra
.6 .565 .787 r
.33941 .51136 .34516 .52412 .35482 .52458 .34918 .50963 Mtetra
.538 .503 .765 r
.34918 .50963 .35482 .52458 .36448 .52632 .35889 .51021 Mtetra
.486 .459 .753 r
.35889 .51021 .36448 .52632 .37422 .52784 .36856 .51268 Mtetra
.419 .431 .765 r
.36856 .51268 .37422 .52784 .38407 .52803 .37823 .51685 Mtetra
.385 .479 .833 r
.37823 .51685 .38407 .52803 .39411 .52508 .388 .52037 Mtetra
.323 .661 .973 r
.388 .52037 .39411 .52508 .40434 .51764 .39795 .5215 Mtetra
0 0 0 r
.39795 .5215 .40434 .51764 .41472 .50634 .40811 .51826 Mtetra
.052 0 0 r
.40811 .51826 .41472 .50634 .42518 .49194 .41849 .50927 Mtetra
.021 0 .094 r
.41849 .50927 .42518 .49194 .43554 .47976 .42902 .49537 Mtetra
0 0 0 r
.42902 .49537 .43554 .47976 .44576 .47297 .43961 .47786 Mtetra
.851 .976 .672 r
.43961 .47786 .44576 .47297 .45585 .47348 .4501 .463 Mtetra
.752 .672 .773 r
.4501 .463 .45585 .47348 .46586 .48149 .46043 .45425 Mtetra
.573 .445 .668 r
.46043 .45425 .46586 .48149 .47597 .49013 .47064 .45302 Mtetra
.483 .356 .631 r
.47064 .45302 .47597 .49013 .48623 .49585 .4808 .45926 Mtetra
.456 .339 .63 r
.4808 .45926 .48623 .49585 .49662 .49668 .49104 .46748 Mtetra
.445 .353 .657 r
.49104 .46748 .49662 .49668 .50711 .49227 .5014 .47475 Mtetra
.445 .425 .742 r
.5014 .47475 .50711 .49227 .51764 .48639 .51188 .47905 Mtetra
.497 .648 .925 r
.51188 .47905 .51764 .48639 .52819 .48086 .52246 .47922 Mtetra
.555 .895 .982 r
.52246 .47922 .52819 .48086 .53877 .47752 .53308 .47586 Mtetra
.767 .946 .937 r
.53308 .47586 .53877 .47752 .54941 .47637 .54373 .46896 Mtetra
.819 .758 .796 r
.54373 .46896 .54941 .47637 .56012 .47558 .55436 .45789 Mtetra
.752 .604 .693 r
.55436 .45789 .56012 .47558 .57086 .47333 .56494 .44381 Mtetra
.699 .523 .646 r
.56494 .44381 .57086 .47333 .58155 .46579 .57548 .42874 Mtetra
.662 .482 .63 r
.57548 .42874 .58155 .46579 .59217 .45331 .58602 .41563 Mtetra
.605 .441 .633 r
.58602 .41563 .59217 .45331 .60269 .43783 .59671 .41004 Mtetra
.528 .416 .67 r
.59671 .41004 .60269 .43783 .61319 .42295 .60761 .41205 Mtetra
.134 .333 .797 r
.60761 .41205 .61319 .42295 .62388 .41564 .61878 .42029 Mtetra
.722 .256 .143 r
.61878 .42029 .62388 .41564 .63485 .41574 .63016 .43126 Mtetra
.621 .254 .326 r
.63016 .43126 .63485 .41574 .64609 .42134 .64155 .43861 Mtetra
.542 .189 .319 r
.64155 .43861 .64609 .42134 .65752 .42924 .65286 .44099 Mtetra
.359 0 .161 r
.65286 .44099 .65752 .42924 .66894 .43402 .66401 .43751 Mtetra
.425 .815 .583 r
.66401 .43751 .66894 .43402 .68028 .43486 .675 .42954 Mtetra
.84 .835 .841 r
.675 .42954 .68028 .43486 .69145 .43111 .68588 .4191 Mtetra
.772 .672 .754 r
.68588 .4191 .69145 .43111 .70249 .42413 .69672 .40797 Mtetra
.715 .6 .726 r
.69672 .40797 .70249 .42413 .71348 .41577 .70764 .39856 Mtetra
.683 .573 .726 r
.70764 .39856 .71348 .41577 .72445 .40715 .71869 .39109 Mtetra
.653 .568 .746 r
.71869 .39109 .72445 .40715 .73553 .39985 .72991 .38597 Mtetra
.63 .58 .78 r
.72991 .38597 .73553 .39985 .74671 .39384 .74128 .38258 Mtetra
.611 .612 .828 r
.74128 .38258 .74671 .39384 .75803 .38929 .75277 .38026 Mtetra
.592 .653 .879 r
.75277 .38026 .75803 .38929 .76946 .38576 .76437 .37849 Mtetra
.587 .704 .923 r
.76437 .37849 .76946 .38576 .78099 .3828 .77601 .37661 Mtetra
.585 .742 .951 r
.77601 .37661 .78099 .3828 .79259 .38015 .7877 .37452 Mtetra
.6 .772 .962 r
.7877 .37452 .79259 .38015 .80425 .37743 .7994 .37195 Mtetra
.615 .786 .963 r
.7994 .37195 .80425 .37743 .81595 .3746 .81113 .36899 Mtetra
.633 .788 .957 r
.81113 .36899 .81595 .3746 .82768 .37154 .82288 .36566 Mtetra
.646 .784 .948 r
.82288 .36566 .82768 .37154 .83945 .36831 .83465 .36207 Mtetra
.654 .775 .938 r
.83465 .36207 .83945 .36831 .85126 .36493 .84646 .35831 Mtetra
.657 .763 .928 r
.84646 .35831 .85126 .36493 .8631 .36144 .85831 .35446 Mtetra
.637 .747 .928 r
.22623 .54871 .23264 .55431 .24212 .55134 .23569 .54607 Mtetra
.635 .759 .937 r
.23569 .54607 .24212 .55134 .25164 .54829 .2452 .54343 Mtetra
.637 .776 .947 r
.2452 .54343 .25164 .54829 .26121 .54508 .25475 .54069 Mtetra
.644 .797 .956 r
.25475 .54069 .26121 .54508 .27083 .54163 .26435 .53773 Mtetra
.654 .82 .963 r
.26435 .53773 .27083 .54163 .2805 .53782 .27401 .53447 Mtetra
.672 .846 .966 r
.27401 .53447 .2805 .53782 .29024 .53364 .28374 .53075 Mtetra
.698 .869 .962 r
.28374 .53075 .29024 .53364 .30003 .52899 .29355 .52639 Mtetra
.724 .883 .954 r
.29355 .52639 .30003 .52899 .30986 .52414 .30342 .5214 Mtetra
.753 .88 .937 r
.30342 .5214 .30986 .52414 .31972 .51918 .31336 .5157 Mtetra
.76 .852 .919 r
.31336 .5157 .31972 .51918 .32958 .51476 .32334 .50975 Mtetra
.751 .797 .89 r
.32334 .50975 .32958 .51476 .33941 .51136 .33334 .50384 Mtetra
.705 .713 .854 r
.33334 .50384 .33941 .51136 .34918 .50963 .3433 .49896 Mtetra
.64 .619 .813 r
.3433 .49896 .34918 .50963 .35889 .51021 .35319 .49589 Mtetra
.567 .528 .771 r
.35319 .49589 .35889 .51021 .36856 .51268 .363 .49531 Mtetra
.489 .449 .739 r
.363 .49531 .36856 .51268 .37823 .51685 .37272 .49786 Mtetra
.444 .407 .722 r
.37272 .49786 .37823 .51685 .388 .52037 .38242 .5023 Mtetra
.405 .391 .73 r
.38242 .5023 .388 .52037 .39795 .5215 .39217 .50775 Mtetra
.416 .452 .789 r
.39217 .50775 .39795 .5215 .40811 .51826 .40208 .51152 Mtetra
.496 .665 .938 r
.40208 .51152 .40811 .51826 .41849 .50927 .41219 .51152 Mtetra
.516 .908 .779 r
.41219 .51152 .41849 .50927 .42902 .49537 .42254 .5055 Mtetra
0 0 0 r
.42254 .5055 .42902 .49537 .43961 .47786 .43311 .49262 Mtetra
.43311 .49262 .43961 .47786 .4501 .463 .44372 .47713 Mtetra
.44372 .47713 .4501 .463 .46043 .45425 .45428 .46189 Mtetra
.45428 .46189 .46043 .45425 .47064 .45302 .46472 .45168 Mtetra
.544 .896 .976 r
.46472 .45168 .47064 .45302 .4808 .45926 .47505 .44839 Mtetra
.508 .556 .84 r
.47505 .44839 .4808 .45926 .49104 .46748 .48537 .44924 Mtetra
.478 .437 .734 r
.48537 .44924 .49104 .46748 .5014 .47475 .49574 .45247 Mtetra
.512 .43 .7 r
.49574 .45247 .5014 .47475 .51188 .47905 .50619 .45484 Mtetra
.559 .45 .687 r
.50619 .45484 .51188 .47905 .52246 .47922 .51672 .45462 Mtetra
.604 .478 .682 r
.51672 .45462 .52246 .47922 .53308 .47586 .52732 .45121 Mtetra
.642 .502 .677 r
.52732 .45121 .53308 .47586 .54373 .46896 .53794 .44462 Mtetra
.67 .521 .674 r
.53794 .44462 .54373 .46896 .55436 .45789 .54856 .43543 Mtetra
.687 .54 .681 r
.54856 .43543 .55436 .45789 .56494 .44381 .55918 .42533 Mtetra
.68 .558 .711 r
.55918 .42533 .56494 .44381 .57548 .42874 .56983 .41762 Mtetra
.646 .625 .814 r
.56983 .41762 .57548 .42874 .58602 .41563 .58057 .41407 Mtetra
.229 0 0 r
.58057 .41407 .58602 .41563 .59671 .41004 .59148 .41752 Mtetra
.669 .231 .202 r
.59148 .41752 .59671 .41004 .60761 .41205 .60261 .42609 Mtetra
.647 .271 .317 r
.60261 .42609 .60761 .41205 .61878 .42029 .61388 .43496 Mtetra
.606 .233 .308 r
.61388 .43496 .61878 .42029 .63016 .43126 .62519 .44121 Mtetra
.427 .009 .14 r
.62519 .44121 .63016 .43126 .64155 .43861 .63637 .44051 Mtetra
.515 .902 .749 r
.63637 .44051 .64155 .43861 .65286 .44099 .64739 .43368 Mtetra
.819 .774 .811 r
.64739 .43368 .65286 .44099 .66401 .43751 .65827 .42297 Mtetra
.763 .639 .724 r
.65827 .42297 .66401 .43751 .675 .42954 .66907 .41052 Mtetra
.719 .58 .698 r
.66907 .41052 .675 .42954 .68588 .4191 .6799 .39907 Mtetra
.693 .559 .698 r
.6799 .39907 .68588 .4191 .69672 .40797 .69081 .38954 Mtetra
.661 .551 .72 r
.69081 .38954 .69672 .40797 .70764 .39856 .70191 .3832 Mtetra
.632 .563 .759 r
.70191 .3832 .70764 .39856 .71869 .39109 .71319 .37942 Mtetra
.599 .598 .822 r
.71319 .37942 .71869 .39109 .72991 .38597 .72462 .37751 Mtetra
.554 .65 .899 r
.72462 .37751 .72991 .38597 .74128 .38258 .73618 .37666 Mtetra
.513 .719 .965 r
.73618 .37666 .74128 .38258 .75277 .38026 .74782 .37587 Mtetra
.479 .767 .994 r
.74782 .37587 .75277 .38026 .76437 .37849 .7595 .37483 Mtetra
.498 .809 1 r
.7595 .37483 .76437 .37849 .77601 .37661 .7712 .37305 Mtetra
.537 .832 .999 r
.7712 .37305 .77601 .37661 .7877 .37452 .7829 .37062 Mtetra
.59 .841 .992 r
.7829 .37062 .7877 .37452 .7994 .37195 .79461 .36753 Mtetra
.628 .836 .98 r
.79461 .36753 .7994 .37195 .81113 .36899 .80633 .36395 Mtetra
.651 .82 .965 r
.80633 .36395 .81113 .36899 .82288 .36566 .81807 .36005 Mtetra
.664 .804 .949 r
.81807 .36005 .82288 .36566 .83465 .36207 .82983 .35592 Mtetra
.67 .787 .936 r
.82983 .35592 .83465 .36207 .84646 .35831 .84163 .35168 Mtetra
.671 .771 .925 r
.84163 .35168 .84646 .35831 .85831 .35446 .85348 .34743 Mtetra
.624 .743 .932 r
.21976 .54307 .22623 .54871 .23569 .54607 .22923 .54069 Mtetra
.617 .752 .942 r
.22923 .54069 .23569 .54607 .2452 .54343 .23872 .5384 Mtetra
.613 .764 .952 r
.23872 .5384 .2452 .54343 .25475 .54069 .24826 .53612 Mtetra
.61 .782 .964 r
.24826 .53612 .25475 .54069 .26435 .53773 .25783 .53378 Mtetra
.604 .807 .978 r
.25783 .53378 .26435 .53773 .27401 .53447 .26745 .53136 Mtetra
.606 .842 .989 r
.26745 .53136 .27401 .53447 .28374 .53075 .27714 .52862 Mtetra
.611 .882 .991 r
.27714 .52862 .28374 .53075 .29355 .52639 .28689 .52537 Mtetra
.624 .923 .975 r
.28689 .52537 .29355 .52639 .30342 .5214 .29674 .52133 Mtetra
.658 .955 .946 r
.29674 .52133 .30342 .5214 .31336 .5157 .30669 .51623 Mtetra
.702 .975 .92 r
.30669 .51623 .31336 .5157 .32334 .50975 .31672 .51007 Mtetra
.774 .979 .912 r
.31672 .51007 .32334 .50975 .33334 .50384 .32685 .50273 Mtetra
.813 .938 .911 r
.32685 .50273 .33334 .50384 .3433 .49896 .33701 .49494 Mtetra
.802 .835 .876 r
.33701 .49494 .3433 .49896 .35319 .49589 .34718 .48717 Mtetra
.729 .693 .816 r
.34718 .48717 .35319 .49589 .363 .49531 .3573 .48077 Mtetra
.643 .568 .754 r
.3573 .48077 .363 .49531 .37272 .49786 .36731 .4768 Mtetra
.566 .469 .703 r
.36731 .4768 .37272 .49786 .38242 .5023 .37721 .47618 Mtetra
.496 .396 .672 r
.37721 .47618 .38242 .5023 .39217 .50775 .38698 .47966 Mtetra
.451 .358 .66 r
.38698 .47966 .39217 .50775 .40208 .51152 .39673 .48588 Mtetra
.4 .335 .669 r
.39673 .48588 .40208 .51152 .41219 .51152 .40652 .49385 Mtetra
.327 .347 .729 r
.40652 .49385 .41219 .51152 .42254 .5055 .41643 .5013 Mtetra
0 .341 .757 r
.41643 .5013 .42254 .5055 .43311 .49262 .42651 .50619 Mtetra
.457 .081 .236 r
.42651 .50619 .43311 .49262 .44372 .47713 .43684 .50539 Mtetra
.389 .099 .346 r
.43684 .50539 .44372 .47713 .45428 .46189 .4474 .49734 Mtetra
.337 .074 .359 r
.4474 .49734 .45428 .46189 .46472 .45168 .45807 .48356 Mtetra
.227 0 .306 r
.45807 .48356 .46472 .45168 .47505 .44839 .4688 .46579 Mtetra
0 0 .044 r
.4688 .46579 .47505 .44839 .48537 .44924 .47945 .44891 Mtetra
.917 .941 .804 r
.47945 .44891 .48537 .44924 .49574 .45247 .49003 .43531 Mtetra
.715 .586 .71 r
.49003 .43531 .49574 .45247 .50619 .45484 .50056 .42531 Mtetra
.624 .472 .656 r
.50056 .42531 .50619 .45484 .51672 .45462 .51106 .41915 Mtetra
.588 .433 .639 r
.51106 .41915 .51672 .45462 .52732 .45121 .52159 .4157 Mtetra
.56 .414 .639 r
.52159 .4157 .52732 .45121 .53794 .44462 .53216 .41497 Mtetra
.511 .396 .66 r
.53216 .41497 .53794 .44462 .54856 .43543 .54281 .4181 Mtetra
.364 .377 .74 r
.54281 .4181 .54856 .43543 .55918 .42533 .55358 .42487 Mtetra
.698 .159 0 r
.55358 .42487 .55918 .42533 .56983 .41762 .5645 .43498 Mtetra
.662 .306 .36 r
.5645 .43498 .56983 .41762 .58057 .41407 .57557 .44606 Mtetra
.589 .285 .421 r
.57557 .44606 .58057 .41407 .59148 .41752 .58671 .45314 Mtetra
.535 .244 .419 r
.58671 .45314 .59148 .41752 .60261 .42609 .59783 .45445 Mtetra
.432 .139 .364 r
.59783 .45445 .60261 .42609 .61388 .43496 .60884 .44842 Mtetra
.04 0 .058 r
.60884 .44842 .61388 .43496 .62519 .44121 .6197 .43658 Mtetra
.895 .844 .787 r
.6197 .43658 .62519 .44121 .63637 .44051 .63047 .42211 Mtetra
.757 .605 .689 r
.63047 .42211 .63637 .44051 .64739 .43368 .64119 .40707 Mtetra
.697 .531 .659 r
.64119 .40707 .64739 .43368 .65827 .42297 .65194 .39378 Mtetra
.664 .501 .654 r
.65194 .39378 .65827 .42297 .66907 .41052 .66279 .38325 Mtetra
.63 .486 .668 r
.66279 .38325 .66907 .41052 .6799 .39907 .67382 .37691 Mtetra
.599 .49 .701 r
.67382 .37691 .6799 .39907 .69081 .38954 .68506 .37401 Mtetra
.56 .521 .768 r
.68506 .37401 .69081 .38954 .70191 .3832 .69648 .3736 Mtetra
.487 .585 .878 r
.69648 .3736 .70191 .3832 .71319 .37942 .70805 .3746 Mtetra
.34 .673 .977 r
.70805 .3746 .71319 .37942 .72462 .37751 .7197 .37565 Mtetra
.139 .658 .886 r
.7197 .37565 .72462 .37751 .73618 .37666 .73141 .37625 Mtetra
.11 .662 .792 r
.73141 .37625 .73618 .37666 .74782 .37587 .74311 .37564 Mtetra
.205 .732 .816 r
.74311 .37564 .74782 .37587 .7595 .37483 .7548 .37393 Mtetra
.385 .84 .913 r
.7548 .37393 .7595 .37483 .7712 .37305 .76647 .37112 Mtetra
.535 .893 .975 r
.76647 .37112 .7712 .37305 .7829 .37062 .77813 .36749 Mtetra
.625 .889 .988 r
.77813 .36749 .7829 .37062 .79461 .36753 .7898 .36334 Mtetra
.667 .861 .974 r
.7898 .36334 .79461 .36753 .80633 .36395 .80148 .35883 Mtetra
.68 .83 .955 r
.80148 .35883 .80633 .36395 .81807 .36005 .8132 .35423 Mtetra
.685 .805 .939 r
.8132 .35423 .81807 .36005 .82983 .35592 .82496 .34957 Mtetra
.685 .787 .928 r
.82496 .34957 .82983 .35592 .84163 .35168 .83676 .34492 Mtetra
.681 .772 .92 r
.83676 .34492 .84163 .35168 .85348 .34743 .84861 .34035 Mtetra
.627 .744 .931 r
.21326 .53739 .21976 .54307 .22923 .54069 .22275 .53494 Mtetra
.62 .74 .932 r
.22275 .53494 .22923 .54069 .23872 .5384 .23226 .53262 Mtetra
.613 .738 .934 r
.23226 .53262 .23872 .5384 .24826 .53612 .2418 .53043 Mtetra
.605 .739 .94 r
.2418 .53043 .24826 .53612 .25783 .53378 .25137 .52837 Mtetra
.591 .746 .951 r
.25137 .52837 .25783 .53378 .26745 .53136 .26097 .5265 Mtetra
.583 .766 .966 r
.26097 .5265 .26745 .53136 .27714 .52862 .27061 .52462 Mtetra
.571 .798 .985 r
.27061 .52462 .27714 .52862 .28689 .52537 .2803 .52264 Mtetra
.567 .849 .997 r
.2803 .52264 .28689 .52537 .29674 .52133 .29007 .52017 Mtetra
.56 .9 .979 r
.29007 .52017 .29674 .52133 .30669 .51623 .29993 .5169 Mtetra
.544 .926 .903 r
.29993 .5169 .30669 .51623 .31672 .51007 .3099 .51245 Mtetra
.55 .926 .801 r
.3099 .51245 .31672 .51007 .32685 .50273 .32 .50642 Mtetra
.563 .916 .718 r
.32 .50642 .32685 .50273 .33701 .49494 .3302 .49893 Mtetra
.658 .952 .726 r
.3302 .49893 .33701 .49494 .34718 .48717 .3405 .48997 Mtetra
.763 .995 .806 r
.3405 .48997 .34718 .48717 .3573 .48077 .35082 .4806 Mtetra
.838 .964 .887 r
.35082 .4806 .3573 .48077 .36731 .4768 .36113 .47162 Mtetra
.773 .8 .875 r
.36113 .47162 .36731 .4768 .37721 .47618 .37134 .46472 Mtetra
.646 .612 .801 r
.37134 .46472 .37721 .47618 .38698 .47966 .38141 .4612 Mtetra
.547 .476 .727 r
.38141 .4612 .38698 .47966 .39673 .48588 .39137 .46144 Mtetra
.472 .39 .682 r
.39137 .46144 .39673 .48588 .40652 .49385 .40124 .46579 Mtetra
.428 .343 .658 r
.40124 .46579 .40652 .49385 .41643 .5013 .41109 .47312 Mtetra
.393 .32 .655 r
.41109 .47312 .41643 .5013 .42651 .50619 .42099 .48215 Mtetra
.427 .364 .684 r
.42099 .48215 .42651 .50619 .43684 .50539 .43108 .48851 Mtetra
.525 .481 .75 r
.43108 .48851 .43684 .50539 .4474 .49734 .4414 .48957 Mtetra
.703 .719 .862 r
.4414 .48957 .4474 .49734 .45807 .48356 .45192 .48453 Mtetra
.856 .991 .839 r
.45192 .48453 .45807 .48356 .4688 .46579 .46259 .47369 Mtetra
0 0 0 r
.46259 .47369 .4688 .46579 .47945 .44891 .47327 .4614 Mtetra
.47327 .4614 .47945 .44891 .49003 .43531 .48393 .44996 Mtetra
.164 0 .118 r
.48393 .44996 .49003 .43531 .50056 .42531 .49455 .44079 Mtetra
.31 0 .2 r
.49455 .44079 .50056 .42531 .51106 .41915 .50516 .43472 Mtetra
.397 .04 .239 r
.50516 .43472 .51106 .41915 .52159 .4157 .51578 .43126 Mtetra
.467 .106 .268 r
.51578 .43126 .52159 .4157 .53216 .41497 .52645 .43043 Mtetra
.536 .171 .294 r
.52645 .43043 .53216 .41497 .54281 .4181 .53718 .43271 Mtetra
.579 .206 .299 r
.53718 .43271 .54281 .4181 .55358 .42487 .54802 .4373 Mtetra
.597 .206 .272 r
.54802 .4373 .55358 .42487 .5645 .43498 .55896 .44278 Mtetra
.562 .113 .143 r
.55896 .44278 .5645 .43498 .57557 .44606 .56998 .44683 Mtetra
.13 .676 .717 r
.56998 .44683 .57557 .44606 .58671 .45314 .581 .44503 Mtetra
.764 .74 .831 r
.581 .44503 .58671 .45314 .59783 .45445 .59194 .43705 Mtetra
.749 .607 .701 r
.59194 .43705 .59783 .45445 .60884 .44842 .60277 .42368 Mtetra
.728 .557 .66 r
.60277 .42368 .60884 .44842 .6197 .43658 .6135 .40756 Mtetra
.696 .522 .649 r
.6135 .40756 .6197 .43658 .63047 .42211 .62424 .39312 Mtetra
.672 .507 .653 r
.62424 .39312 .63047 .42211 .64119 .40707 .63505 .38169 Mtetra
.645 .502 .674 r
.63505 .38169 .64119 .40707 .65194 .39378 .64601 .37443 Mtetra
.613 .516 .72 r
.64601 .37443 .65194 .39378 .66279 .38325 .65715 .371 Mtetra
.541 .557 .82 r
.65715 .371 .66279 .38325 .67382 .37691 .66849 .37104 Mtetra
.303 .608 .953 r
.66849 .37104 .67382 .37691 .68506 .37401 .68001 .37323 Mtetra
.189 0 0 r
.68001 .37323 .68506 .37401 .69648 .3736 .69164 .37584 Mtetra
.367 0 0 r
.69164 .37584 .69648 .3736 .70805 .3746 .70333 .37805 Mtetra
.325 0 0 r
.70333 .37805 .70805 .3746 .7197 .37565 .71503 .37875 Mtetra
.199 0 0 r
.71503 .37875 .7197 .37565 .73141 .37625 .72671 .37796 Mtetra
0 0 0 r
.72671 .37796 .73141 .37625 .74311 .37564 .73835 .37554 Mtetra
.385 .847 .86 r
.73835 .37554 .74311 .37564 .7548 .37393 .74996 .37189 Mtetra
.602 .918 .975 r
.74996 .37189 .7548 .37393 .76647 .37112 .76156 .36741 Mtetra
.683 .885 .973 r
.76156 .36741 .76647 .37112 .77813 .36749 .77316 .36241 Mtetra
.7 .837 .948 r
.77316 .36241 .77813 .36749 .7898 .36334 .78479 .3573 Mtetra
.702 .803 .928 r
.78479 .3573 .7898 .36334 .80148 .35883 .79647 .35218 Mtetra
.694 .779 .916 r
.79647 .35218 .80148 .35883 .8132 .35423 .80819 .34724 Mtetra
.689 .767 .911 r
.80819 .34724 .8132 .35423 .82496 .34957 .81997 .34243 Mtetra
.684 .761 .91 r
.81997 .34243 .82496 .34957 .83676 .34492 .83181 .33776 Mtetra
.679 .759 .912 r
.83181 .33776 .83676 .34492 .84861 .34035 .8437 .33321 Mtetra
.645 .749 .925 r
.20671 .53168 .21326 .53739 .22275 .53494 .21625 .52882 Mtetra
.64 .734 .917 r
.21625 .52882 .22275 .53494 .23226 .53262 .22582 .52607 Mtetra
.632 .718 .909 r
.22582 .52607 .23226 .53262 .2418 .53043 .23541 .52353 Mtetra
.62 .704 .905 r
.23541 .52353 .2418 .53043 .25137 .52837 .24501 .52127 Mtetra
.601 .692 .906 r
.24501 .52127 .25137 .52837 .26097 .5265 .25462 .51942 Mtetra
.583 .687 .912 r
.25462 .51942 .26097 .5265 .27061 .52462 .26424 .51795 Mtetra
.557 .691 .929 r
.26424 .51795 .27061 .52462 .2803 .52264 .27387 .5169 Mtetra
.533 .717 .957 r
.27387 .5169 .2803 .52264 .29007 .52017 .28355 .51599 Mtetra
.488 .763 .992 r
.28355 .51599 .29007 .52017 .29993 .5169 .29327 .51507 Mtetra
.411 .819 .978 r
.29327 .51507 .29993 .5169 .3099 .51245 .30308 .51357 Mtetra
.25 .762 .771 r
.30308 .51357 .3099 .51245 .32 .50642 .31301 .51103 Mtetra
0 0 0 r
.31301 .51103 .32 .50642 .3302 .49893 .32307 .50689 Mtetra
.32307 .50689 .3302 .49893 .3405 .48997 .33329 .50061 Mtetra
.33329 .50061 .3405 .48997 .35082 .4806 .34364 .49226 Mtetra
.34364 .49226 .35082 .4806 .36113 .47162 .3541 .4818 Mtetra
.3541 .4818 .36113 .47162 .37134 .46472 .36462 .47014 Mtetra
.733 .954 .657 r
.36462 .47014 .37134 .46472 .38141 .4612 .37515 .45803 Mtetra
.86 .862 .84 r
.37515 .45803 .38141 .4612 .39137 .46144 .3856 .44734 Mtetra
.711 .609 .742 r
.3856 .44734 .39137 .46144 .40124 .46579 .39594 .43937 Mtetra
.617 .477 .668 r
.39594 .43937 .40124 .46579 .41109 .47312 .40617 .43448 Mtetra
.563 .407 .628 r
.40617 .43448 .41109 .47312 .42099 .48215 .41631 .43319 Mtetra
.526 .366 .606 r
.41631 .43319 .42099 .48215 .43108 .48851 .42639 .43578 Mtetra
.495 .338 .598 r
.42639 .43578 .43108 .48851 .4414 .48957 .43643 .44229 Mtetra
.455 .316 .603 r
.43643 .44229 .4414 .48957 .45192 .48453 .4465 .45206 Mtetra
.367 .287 .633 r
.4465 .45206 .45192 .48453 .46259 .47369 .45666 .46391 Mtetra
0 .143 .687 r
.45666 .46391 .46259 .47369 .47327 .4614 .46697 .47441 Mtetra
.629 .248 .302 r
.46697 .47441 .47327 .4614 .48393 .44996 .47746 .48168 Mtetra
.556 .253 .41 r
.47746 .48168 .48393 .44996 .49455 .44079 .4881 .48524 Mtetra
.52 .243 .434 r
.4881 .48524 .49455 .44079 .50516 .43472 .49886 .48481 Mtetra
.5 .232 .439 r
.49886 .48481 .50516 .43472 .51578 .43126 .50969 .48138 Mtetra
.475 .211 .433 r
.50969 .48138 .51578 .43126 .52645 .43043 .52057 .47494 Mtetra
.425 .162 .41 r
.52057 .47494 .52645 .43043 .53718 .43271 .53147 .46448 Mtetra
.306 .038 .334 r
.53147 .46448 .53718 .43271 .54802 .4373 .54234 .45026 Mtetra
0 0 0 r
.54234 .45026 .54802 .4373 .55896 .44278 .55316 .43275 Mtetra
.859 .723 .711 r
.55316 .43275 .55896 .44278 .56998 .44683 .56391 .41383 Mtetra
.698 .514 .635 r
.56391 .41383 .56998 .44683 .581 .44503 .57463 .39695 Mtetra
.64 .45 .61 r
.57463 .39695 .581 .44503 .59194 .43705 .58537 .38333 Mtetra
.61 .422 .603 r
.58537 .38333 .59194 .43705 .60277 .42368 .59616 .37365 Mtetra
.589 .411 .609 r
.59616 .37365 .60277 .42368 .6135 .40756 .60706 .3679 Mtetra
.569 .412 .629 r
.60706 .3679 .6135 .40756 .62424 .39312 .6181 .36581 Mtetra
.537 .425 .673 r
.6181 .36581 .62424 .39312 .63505 .38169 .62929 .36686 Mtetra
.433 .455 .782 r
.62929 .36686 .63505 .38169 .64601 .37443 .64066 .3707 Mtetra
0 .354 .761 r
.64066 .3707 .64601 .37443 .65715 .371 .65219 .37602 Mtetra
.563 .059 .017 r
.65219 .37602 .65715 .371 .66849 .37104 .66381 .38091 Mtetra
.549 .121 .181 r
.66381 .38091 .66849 .37104 .68001 .37323 .67548 .38461 Mtetra
.5 .09 .195 r
.67548 .38461 .68001 .37323 .69164 .37584 .68714 .38615 Mtetra
.428 .008 .138 r
.68714 .38615 .69164 .37584 .70333 .37805 .69877 .38557 Mtetra
.279 0 0 r
.69877 .38557 .70333 .37805 .71503 .37875 .71034 .38279 Mtetra
0 0 0 r
.71034 .38279 .71503 .37875 .72671 .37796 .72186 .37835 Mtetra
.506 .911 .846 r
.72186 .37835 .72671 .37796 .73835 .37554 .73336 .37283 Mtetra
.717 .931 .96 r
.73336 .37283 .73835 .37554 .74996 .37189 .74485 .3667 Mtetra
.738 .843 .929 r
.74485 .3667 .74996 .37189 .76156 .36741 .75637 .36055 Mtetra
.727 .782 .896 r
.75637 .36055 .76156 .36741 .77316 .36241 .76794 .35453 Mtetra
.709 .746 .881 r
.76794 .35453 .77316 .36241 .78479 .3573 .77957 .34895 Mtetra
.695 .728 .875 r
.77957 .34895 .78479 .3573 .79647 .35218 .79126 .34374 Mtetra
.683 .721 .879 r
.79126 .34374 .79647 .35218 .80819 .34724 .80304 .33896 Mtetra
.674 .723 .886 r
.80304 .33896 .80819 .34724 .81997 .34243 .81488 .33447 Mtetra
.669 .731 .896 r
.81488 .33447 .81997 .34243 .83181 .33776 .82679 .33019 Mtetra
.665 .742 .908 r
.82679 .33019 .83181 .33776 .8437 .33321 .83876 .32602 Mtetra
.67 .755 .914 r
.20012 .52592 .20671 .53168 .21625 .52882 .20973 .52244 Mtetra
.667 .734 .9 r
.20973 .52244 .21625 .52882 .22582 .52607 .21938 .519 Mtetra
.659 .711 .886 r
.21938 .519 .22582 .52607 .23541 .52353 .22905 .51572 Mtetra
.647 .687 .874 r
.22905 .51572 .23541 .52353 .24501 .52127 .23872 .51273 Mtetra
.631 .663 .863 r
.23872 .51273 .24501 .52127 .25462 .51942 .2484 .51016 Mtetra
.611 .638 .853 r
.2484 .51016 .25462 .51942 .26424 .51795 .25808 .50811 Mtetra
.586 .615 .848 r
.25808 .50811 .26424 .51795 .27387 .5169 .26774 .50675 Mtetra
.562 .598 .847 r
.26774 .50675 .27387 .5169 .28355 .51599 .2774 .50602 Mtetra
.534 .589 .856 r
.2774 .50602 .28355 .51599 .29327 .51507 .28707 .50596 Mtetra
.514 .601 .879 r
.28707 .50596 .29327 .51507 .30308 .51357 .29677 .50616 Mtetra
.49 .642 .924 r
.29677 .50616 .30308 .51357 .31301 .51103 .30653 .50635 Mtetra
.469 .738 .986 r
.30653 .50635 .31301 .51103 .32307 .50689 .3164 .50581 Mtetra
.388 .828 .948 r
.3164 .50581 .32307 .50689 .33329 .50061 .3264 .50391 Mtetra
0 0 0 r
.3264 .50391 .33329 .50061 .34364 .49226 .33655 .50002 Mtetra
.33655 .50002 .34364 .49226 .3541 .4818 .34688 .49355 Mtetra
.34688 .49355 .3541 .4818 .36462 .47014 .35736 .48452 Mtetra
.35736 .48452 .36462 .47014 .37515 .45803 .36797 .47295 Mtetra
.36797 .47295 .37515 .45803 .3856 .44734 .3786 .46034 Mtetra
.3786 .46034 .3856 .44734 .39594 .43937 .38922 .44773 Mtetra
.38922 .44773 .39594 .43937 .40617 .43448 .39979 .43617 Mtetra
.794 .999 .841 r
.39979 .43617 .40617 .43448 .41631 .43319 .41026 .42679 Mtetra
.714 .76 .889 r
.41026 .42679 .41631 .43319 .42639 .43578 .42059 .42174 Mtetra
.537 .52 .784 r
.42059 .42174 .42639 .43578 .43643 .44229 .4308 .42201 Mtetra
.441 .397 .714 r
.4308 .42201 .43643 .44229 .4465 .45206 .44096 .42671 Mtetra
.396 .336 .672 r
.44096 .42671 .4465 .45206 .45666 .46391 .45113 .43462 Mtetra
.435 .345 .655 r
.45113 .43462 .45666 .46391 .46697 .47441 .46143 .44182 Mtetra
.49 .372 .646 r
.46143 .44182 .46697 .47441 .47746 .48168 .47189 .44632 Mtetra
.531 .394 .639 r
.47189 .44632 .47746 .48168 .4881 .48524 .48247 .44792 Mtetra
.564 .413 .634 r
.48247 .44792 .4881 .48524 .49886 .48481 .49316 .44645 Mtetra
.582 .424 .632 r
.49316 .44645 .49886 .48481 .50969 .48138 .50392 .44297 Mtetra
.6 .436 .631 r
.50392 .44297 .50969 .48138 .52057 .47494 .51473 .43746 Mtetra
.627 .456 .632 r
.51473 .43746 .52057 .47494 .53147 .46448 .52556 .42886 Mtetra
.653 .478 .634 r
.52556 .42886 .53147 .46448 .54234 .45026 .5364 .41733 Mtetra
.681 .502 .638 r
.5364 .41733 .54234 .45026 .55316 .43275 .5472 .40305 Mtetra
.698 .521 .645 r
.5472 .40305 .55316 .43275 .56391 .41383 .55797 .38801 Mtetra
.688 .527 .663 r
.55797 .38801 .56391 .41383 .57463 .39695 .56875 .37619 Mtetra
.664 .536 .699 r
.56875 .37619 .57463 .39695 .58537 .38333 .57958 .36882 Mtetra
.596 .552 .776 r
.57958 .36882 .58537 .38333 .59616 .37365 .59055 .36683 Mtetra
.322 .583 .937 r
.59055 .36683 .59616 .37365 .60706 .3679 .60168 .36924 Mtetra
.493 0 0 r
.60168 .36924 .60706 .3679 .6181 .36581 .61296 .37391 Mtetra
.599 .152 .161 r
.61296 .37391 .6181 .36581 .62929 .36686 .62437 .37966 Mtetra
.595 .2 .263 r
.62437 .37966 .62929 .36686 .64066 .3707 .6359 .38546 Mtetra
.574 .194 .283 r
.6359 .38546 .64066 .3707 .65219 .37602 .6475 .39021 Mtetra
.524 .14 .255 r
.6475 .39021 .65219 .37602 .66381 .38091 .65909 .3924 Mtetra
.443 .036 .171 r
.65909 .3924 .66381 .38091 .67548 .38461 .67066 .39197 Mtetra
.252 0 0 r
.67066 .39197 .67548 .38461 .68714 .38615 .68217 .3889 Mtetra
0 0 0 r
.68217 .3889 .68714 .38615 .69877 .38557 .69363 .38377 Mtetra
.716 .957 .948 r
.69363 .38377 .69877 .38557 .71034 .38279 .70504 .37722 Mtetra
.771 .835 .901 r
.70504 .37722 .71034 .38279 .72186 .37835 .71643 .3699 Mtetra
.747 .742 .847 r
.71643 .3699 .72186 .37835 .73336 .37283 .72785 .36257 Mtetra
.725 .693 .819 r
.72785 .36257 .73336 .37283 .74485 .3667 .7393 .35549 Mtetra
.704 .666 .81 r
.7393 .35549 .74485 .3667 .75637 .36055 .75083 .3491 Mtetra
.689 .655 .812 r
.75083 .3491 .75637 .36055 .76794 .35453 .76243 .34334 Mtetra
.675 .654 .822 r
.76243 .34334 .76794 .35453 .77957 .34895 .77413 .33829 Mtetra
.664 .661 .836 r
.77413 .33829 .77957 .34895 .79126 .34374 .78591 .33379 Mtetra
.656 .673 .854 r
.78591 .33379 .79126 .34374 .80304 .33896 .79777 .32972 Mtetra
.649 .688 .872 r
.79777 .32972 .80304 .33896 .81488 .33447 .80971 .32594 Mtetra
.645 .706 .891 r
.80971 .32594 .81488 .33447 .82679 .33019 .82172 .32234 Mtetra
.643 .726 .908 r
.82172 .32234 .82679 .33019 .83876 .32602 .83378 .31877 Mtetra
.692 .759 .903 r
.19348 .52013 .20012 .52592 .20973 .52244 .20317 .51601 Mtetra
.692 .74 .888 r
.20317 .51601 .20973 .52244 .21938 .519 .21291 .51183 Mtetra
.687 .717 .873 r
.21291 .51183 .21938 .519 .22905 .51572 .22267 .50769 Mtetra
.678 .692 .857 r
.22267 .50769 .22905 .51572 .23872 .51273 .23245 .50369 Mtetra
.666 .665 .839 r
.23245 .50369 .23872 .51273 .2484 .51016 .24224 .49991 Mtetra
.648 .633 .822 r
.24224 .49991 .2484 .51016 .25808 .50811 .25202 .49656 Mtetra
.626 .601 .805 r
.25202 .49656 .25808 .50811 .26774 .50675 .2618 .49381 Mtetra
.601 .567 .788 r
.2618 .49381 .26774 .50675 .2774 .50602 .27155 .49187 Mtetra
.572 .535 .776 r
.27155 .49187 .2774 .50602 .28707 .50596 .28127 .49095 Mtetra
.544 .509 .768 r
.28127 .49095 .28707 .50596 .29677 .50616 .29097 .49102 Mtetra
.512 .49 .769 r
.29097 .49102 .29677 .50616 .30653 .50635 .30065 .49216 Mtetra
.485 .488 .785 r
.30065 .49216 .30653 .50635 .3164 .50581 .31036 .49396 Mtetra
.448 .507 .827 r
.31036 .49396 .3164 .50581 .3264 .50391 .32011 .49612 Mtetra
.388 .583 .919 r
.32011 .49612 .3264 .50391 .33655 .50002 .32995 .49789 Mtetra
.127 .644 .889 r
.32995 .49789 .33655 .50002 .34688 .49355 .33992 .49863 Mtetra
.282 0 0 r
.33992 .49863 .34688 .49355 .35736 .48452 .35004 .49774 Mtetra
.364 0 .17 r
.35004 .49774 .35736 .48452 .36797 .47295 .36032 .49466 Mtetra
.378 .055 .286 r
.36032 .49466 .36797 .47295 .3786 .46034 .37076 .489 Mtetra
.369 .075 .329 r
.37076 .489 .3786 .46034 .38922 .44773 .38135 .48053 Mtetra
.36 .079 .346 r
.38135 .48053 .38922 .44773 .39979 .43617 .39203 .47006 Mtetra
.341 .067 .344 r
.39203 .47006 .39979 .43617 .41026 .42679 .40275 .45812 Mtetra
.311 .035 .323 r
.40275 .45812 .41026 .42679 .42059 .42174 .41349 .44558 Mtetra
.213 0 .238 r
.41349 .44558 .42059 .42174 .4308 .42201 .42421 .43278 Mtetra
0 0 0 r
.42421 .43278 .4308 .42201 .44096 .42671 .43496 .4184 Mtetra
.851 .739 .739 r
.43496 .4184 .44096 .42671 .45113 .43462 .44572 .40247 Mtetra
.693 .512 .637 r
.44572 .40247 .45113 .43462 .46143 .44182 .45643 .38682 Mtetra
.633 .437 .6 r
.45643 .38682 .46143 .44182 .47189 .44632 .46708 .37266 Mtetra
.598 .399 .583 r
.46708 .37266 .47189 .44632 .48247 .44792 .47765 .36157 Mtetra
.574 .376 .574 r
.47765 .36157 .48247 .44792 .49316 .44645 .48817 .35432 Mtetra
.557 .361 .57 r
.48817 .35432 .49316 .44645 .50392 .44297 .49867 .35074 Mtetra
.542 .349 .569 r
.49867 .35074 .50392 .44297 .51473 .43746 .5092 .35083 Mtetra
.524 .338 .57 r
.5092 .35083 .51473 .43746 .52556 .42886 .51978 .35479 Mtetra
.504 .329 .577 r
.51978 .35479 .52556 .42886 .5364 .41733 .53046 .36186 Mtetra
.479 .325 .594 r
.53046 .36186 .5364 .41733 .5472 .40305 .54127 .37048 Mtetra
.423 .327 .642 r
.54127 .37048 .5472 .40305 .55797 .38801 .5522 .3794 Mtetra
.016 .327 .812 r
.5522 .3794 .55797 .38801 .56875 .37619 .56324 .38682 Mtetra
.602 .187 .229 r
.56324 .38682 .56875 .37619 .57958 .36882 .57438 .39267 Mtetra
.579 .247 .371 r
.57438 .39267 .57958 .36882 .59055 .36683 .58562 .39829 Mtetra
.566 .257 .403 r
.58562 .39829 .59055 .36683 .60168 .36924 .59696 .40333 Mtetra
.55 .248 .408 r
.59696 .40333 .60168 .36924 .61296 .37391 .60837 .4069 Mtetra
.53 .228 .4 r
.60837 .4069 .61296 .37391 .62437 .37966 .61982 .40846 Mtetra
.493 .185 .373 r
.61982 .40846 .62437 .37966 .6359 .38546 .63125 .40716 Mtetra
.428 .102 .308 r
.63125 .40716 .6359 .38546 .6475 .39021 .64265 .40323 Mtetra
.266 0 .13 r
.64265 .40323 .6475 .39021 .65909 .3924 .65401 .39703 Mtetra
0 0 0 r
.65401 .39703 .65909 .3924 .67066 .39197 .66532 .38916 Mtetra
.822 .934 .904 r
.66532 .38916 .67066 .39197 .68217 .3889 .6766 .38021 Mtetra
.783 .746 .818 r
.6766 .38021 .68217 .3889 .69363 .38377 .68787 .37083 Mtetra
.735 .652 .767 r
.68787 .37083 .69363 .38377 .70504 .37722 .69916 .36182 Mtetra
.706 .608 .745 r
.69916 .36182 .70504 .37722 .71643 .3699 .7105 .35346 Mtetra
.683 .586 .74 r
.7105 .35346 .71643 .3699 .72785 .36257 .72192 .34619 Mtetra
.668 .578 .745 r
.72192 .34619 .72785 .36257 .7393 .35549 .73344 .33993 Mtetra
.654 .58 .759 r
.73344 .33993 .7393 .35549 .75083 .3491 .74505 .33473 Mtetra
.644 .589 .778 r
.74505 .33473 .75083 .3491 .76243 .34334 .75677 .33035 Mtetra
.636 .605 .802 r
.75677 .33035 .76243 .34334 .77413 .33829 .76858 .3266 Mtetra
.629 .624 .827 r
.76858 .3266 .77413 .33829 .78591 .33379 .78048 .3233 Mtetra
.626 .647 .852 r
.78048 .3233 .78591 .33379 .79777 .32972 .79245 .32023 Mtetra
.622 .67 .875 r
.79245 .32023 .79777 .32972 .80971 .32594 .8045 .31731 Mtetra
.62 .693 .896 r
.8045 .31731 .80971 .32594 .82172 .32234 .8166 .31442 Mtetra
.621 .715 .914 r
.8166 .31442 .82172 .32234 .83378 .31877 .82876 .31146 Mtetra
.7 .761 .899 r
.18679 .51429 .19348 .52013 .20317 .51601 .19653 .50994 Mtetra
.703 .754 .892 r
.19653 .50994 .20317 .51601 .21291 .51183 .20632 .50545 Mtetra
.704 .746 .884 r
.20632 .50545 .21291 .51183 .22267 .50769 .21614 .50085 Mtetra
.703 .732 .873 r
.21614 .50085 .22267 .50769 .23245 .50369 .226 .49617 Mtetra
.701 .714 .859 r
.226 .49617 .23245 .50369 .24224 .49991 .23589 .49143 Mtetra
.691 .688 .842 r
.23589 .49143 .24224 .49991 .25202 .49656 .24579 .48681 Mtetra
.676 .656 .822 r
.24579 .48681 .25202 .49656 .2618 .49381 .25571 .48243 Mtetra
.654 .617 .8 r
.25571 .48243 .2618 .49381 .27155 .49187 .26561 .4786 Mtetra
.627 .577 .778 r
.26561 .4786 .27155 .49187 .28127 .49095 .27548 .47554 Mtetra
.597 .535 .756 r
.27548 .47554 .28127 .49095 .29097 .49102 .28532 .47351 Mtetra
.565 .496 .736 r
.28532 .47351 .29097 .49102 .30065 .49216 .29512 .47278 Mtetra
.536 .463 .72 r
.29512 .47278 .30065 .49216 .31036 .49396 .30488 .47332 Mtetra
.507 .435 .711 r
.30488 .47332 .31036 .49396 .32011 .49612 .31461 .4752 Mtetra
.486 .421 .709 r
.31461 .4752 .32011 .49612 .32995 .49789 .32436 .47797 Mtetra
.468 .417 .718 r
.32436 .47797 .32995 .49789 .33992 .49863 .33415 .48128 Mtetra
.456 .434 .745 r
.33415 .48128 .33992 .49863 .35004 .49774 .34403 .4845 Mtetra
.447 .484 .805 r
.34403 .4845 .35004 .49774 .36032 .49466 .35402 .48703 Mtetra
.452 .625 .926 r
.35402 .48703 .36032 .49466 .37076 .489 .36418 .48779 Mtetra
.37 .818 .944 r
.36418 .48779 .37076 .489 .38135 .48053 .37451 .48599 Mtetra
.026 0 0 r
.37451 .48599 .38135 .48053 .39203 .47006 .38499 .48201 Mtetra
.19 0 .047 r
.38499 .48201 .39203 .47006 .40275 .45812 .39559 .4758 Mtetra
.219 0 .169 r
.39559 .4758 .40275 .45812 .41349 .44558 .40631 .46685 Mtetra
.193 0 .201 r
.40631 .46685 .41349 .44558 .42421 .43278 .41714 .45506 Mtetra
.12 0 .181 r
.41714 .45506 .42421 .43278 .43496 .4184 .42803 .44045 Mtetra
.047 0 .149 r
.42803 .44045 .43496 .4184 .44572 .40247 .43895 .42391 Mtetra
.087 0 .162 r
.43895 .42391 .44572 .40247 .45643 .38682 .44978 .40877 Mtetra
.203 0 .219 r
.44978 .40877 .45643 .38682 .46708 .37266 .46053 .39658 Mtetra
.323 .019 .286 r
.46053 .39658 .46708 .37266 .47765 .36157 .4712 .38758 Mtetra
.41 .104 .332 r
.4712 .38758 .47765 .36157 .48817 .35432 .48184 .38185 Mtetra
.454 .149 .356 r
.48184 .38185 .48817 .35432 .49867 .35074 .49248 .37827 Mtetra
.487 .178 .367 r
.49248 .37827 .49867 .35074 .5092 .35083 .50315 .37685 Mtetra
.531 .212 .372 r
.50315 .37685 .5092 .35083 .51978 .35479 .51387 .37871 Mtetra
.573 .243 .372 r
.51387 .37871 .51978 .35479 .53046 .36186 .52466 .3838 Mtetra
.611 .272 .37 r
.52466 .3838 .53046 .36186 .54127 .37048 .53557 .3919 Mtetra
.628 .285 .37 r
.53557 .3919 .54127 .37048 .5522 .3794 .5466 .40144 Mtetra
.605 .264 .366 r
.5466 .40144 .5522 .3794 .56324 .38682 .55776 .40909 Mtetra
.569 .231 .355 r
.55776 .40909 .56324 .38682 .57438 .39267 .56899 .41393 Mtetra
.528 .187 .334 r
.56899 .41393 .57438 .39267 .58562 .39829 .58028 .41589 Mtetra
.469 .112 .278 r
.58028 .41589 .58562 .39829 .59696 .40333 .5916 .4151 Mtetra
.352 0 .131 r
.5916 .4151 .59696 .40333 .60837 .4069 .60294 .41205 Mtetra
0 0 0 r
.60294 .41205 .60837 .4069 .61982 .40846 .61426 .40676 Mtetra
.779 .963 .925 r
.61426 .40676 .61982 .40846 .63125 .40716 .62553 .39886 Mtetra
.793 .755 .818 r
.62553 .39886 .63125 .40716 .64265 .40323 .63676 .38911 Mtetra
.745 .641 .745 r
.63676 .38911 .64265 .40323 .65401 .39703 .64796 .37864 Mtetra
.714 .586 .71 r
.64796 .37864 .65401 .39703 .66532 .38916 .65916 .36805 Mtetra
.692 .555 .694 r
.65916 .36805 .66532 .38916 .6766 .38021 .67037 .358 Mtetra
.677 .54 .69 r
.67037 .358 .6766 .38021 .68787 .37083 .68164 .34884 Mtetra
.662 .532 .695 r
.68164 .34884 .68787 .37083 .69916 .36182 .69298 .34104 Mtetra
.65 .533 .707 r
.69298 .34104 .69916 .36182 .7105 .35346 .70442 .33455 Mtetra
.639 .539 .726 r
.70442 .33455 .7105 .35346 .72192 .34619 .71597 .32938 Mtetra
.629 .553 .75 r
.71597 .32938 .72192 .34619 .73344 .33993 .72762 .32527 Mtetra
.62 .573 .779 r
.72762 .32527 .73344 .33993 .74505 .33473 .73938 .32198 Mtetra
.612 .597 .811 r
.73938 .32198 .74505 .33473 .75677 .33035 .75123 .31923 Mtetra
.608 .625 .843 r
.75123 .31923 .75677 .33035 .76858 .3266 .76315 .31675 Mtetra
.604 .652 .871 r
.76315 .31675 .76858 .3266 .78048 .3233 .77515 .3144 Mtetra
.604 .678 .893 r
.77515 .3144 .78048 .3233 .79245 .32023 .78721 .31197 Mtetra
.605 .697 .909 r
.78721 .31197 .79245 .32023 .8045 .31731 .79932 .30947 Mtetra
.606 .712 .919 r
.79932 .30947 .8045 .31731 .8166 .31442 .81149 .30687 Mtetra
.61 .724 .926 r
.81149 .30687 .8166 .31442 .82876 .31146 .82371 .3041 Mtetra
.691 .759 .904 r
.18006 .50842 .18679 .51429 .19653 .50994 .1898 .50429 Mtetra
.698 .769 .906 r
.1898 .50429 .19653 .50994 .20632 .50545 .19959 .49999 Mtetra
.706 .777 .908 r
.19959 .49999 .20632 .50545 .21614 .50085 .20943 .49547 Mtetra
.715 .782 .905 r
.20943 .49547 .21614 .50085 .226 .49617 .21932 .49067 Mtetra
.725 .78 .896 r
.21932 .49067 .226 .49617 .23589 .49143 .22927 .48551 Mtetra
.73 .768 .883 r
.22927 .48551 .23589 .49143 .24579 .48681 .23927 .48008 Mtetra
.73 .745 .864 r
.23927 .48008 .24579 .48681 .25571 .48243 .24931 .4744 Mtetra
.719 .709 .84 r
.24931 .4744 .25571 .48243 .26561 .4786 .25938 .46871 Mtetra
.702 .664 .81 r
.25938 .46871 .26561 .4786 .27548 .47554 .26946 .46316 Mtetra
.674 .613 .778 r
.26946 .46316 .27548 .47554 .28532 .47351 .27952 .45809 Mtetra
.643 .561 .747 r
.27952 .45809 .28532 .47351 .29512 .47278 .28956 .45379 Mtetra
.611 .512 .717 r
.28956 .45379 .29512 .47278 .30488 .47332 .29955 .45055 Mtetra
.58 .469 .692 r
.29955 .45055 .30488 .47332 .31461 .4752 .3095 .44869 Mtetra
.554 .434 .671 r
.3095 .44869 .31461 .4752 .32436 .47797 .3194 .44824 Mtetra
.531 .407 .656 r
.3194 .44824 .32436 .47797 .33415 .48128 .32926 .44928 Mtetra
.515 .388 .646 r
.32926 .44928 .33415 .48128 .34403 .4845 .33913 .45154 Mtetra
.501 .376 .642 r
.33913 .45154 .34403 .4845 .35402 .48703 .34901 .45483 Mtetra
.493 .373 .645 r
.34901 .45483 .35402 .48703 .36418 .48779 .35894 .45856 Mtetra
.487 .38 .658 r
.35894 .45856 .36418 .48779 .37451 .48599 .36897 .46233 Mtetra
.472 .397 .69 r
.36897 .46233 .37451 .48599 .38499 .48201 .37907 .46608 Mtetra
.436 .441 .766 r
.37907 .46608 .38499 .48201 .39559 .4758 .38927 .46956 Mtetra
.301 .6 .949 r
.38927 .46956 .39559 .4758 .40631 .46685 .39962 .47155 Mtetra
.348 0 0 r
.39962 .47155 .40631 .46685 .41714 .45506 .41009 .47187 Mtetra
.5 .138 .283 r
.41009 .47187 .41714 .45506 .42803 .44045 .42062 .47267 Mtetra
.537 .232 .399 r
.42062 .47267 .42803 .44045 .43895 .42391 .43118 .47494 Mtetra
.551 .273 .446 r
.43118 .47494 .43895 .42391 .44978 .40877 .44176 .47928 Mtetra
.555 .289 .468 r
.44176 .47928 .44978 .40877 .46053 .39658 .4524 .48517 Mtetra
.545 .288 .477 r
.4524 .48517 .46053 .39658 .4712 .38758 .46318 .48955 Mtetra
.532 .281 .481 r
.46318 .48955 .4712 .38758 .48184 .38185 .4741 .49074 Mtetra
.515 .269 .48 r
.4741 .49074 .48184 .38185 .49248 .37827 .48515 .48723 Mtetra
.498 .255 .477 r
.48515 .48723 .49248 .37827 .50315 .37685 .49629 .47903 Mtetra
.482 .241 .471 r
.49629 .47903 .50315 .37685 .51387 .37871 .50745 .4676 Mtetra
.466 .223 .461 r
.50745 .4676 .51387 .37871 .52466 .3838 .51862 .45461 Mtetra
.457 .208 .446 r
.51862 .45461 .52466 .3838 .53557 .3919 .52976 .44316 Mtetra
.443 .181 .419 r
.52976 .44316 .53557 .3919 .5466 .40144 .54091 .43377 Mtetra
.405 .116 .358 r
.54091 .43377 .5466 .40144 .55776 .40909 .55208 .42584 Mtetra
.277 0 .189 r
.55208 .42584 .55776 .40909 .56899 .41393 .56326 .41838 Mtetra
.472 .832 .571 r
.56326 .41838 .56899 .41393 .58028 .41589 .57444 .40921 Mtetra
.825 .798 .825 r
.57444 .40921 .58028 .41589 .5916 .4151 .5856 .39851 Mtetra
.732 .608 .72 r
.5856 .39851 .5916 .4151 .60294 .41205 .59675 .3875 Mtetra
.686 .533 .673 r
.59675 .3875 .60294 .41205 .61426 .40676 .60789 .37646 Mtetra
.663 .498 .651 r
.60789 .37646 .61426 .40676 .62553 .39886 .61903 .36542 Mtetra
.65 .481 .641 r
.61903 .36542 .62553 .39886 .63676 .38911 .63018 .35481 Mtetra
.639 .471 .64 r
.63018 .35481 .63676 .38911 .64796 .37864 .64136 .34523 Mtetra
.631 .468 .643 r
.64136 .34523 .64796 .37864 .65916 .36805 .65259 .33688 Mtetra
.622 .468 .653 r
.65259 .33688 .65916 .36805 .67037 .358 .66391 .33005 Mtetra
.614 .474 .667 r
.66391 .33005 .67037 .358 .68164 .34884 .67532 .32466 Mtetra
.605 .485 .689 r
.67532 .32466 .68164 .34884 .69298 .34104 .68683 .32067 Mtetra
.597 .504 .719 r
.68683 .32067 .69298 .34104 .70442 .33455 .69846 .31779 Mtetra
.59 .531 .757 r
.69846 .31779 .70442 .33455 .71597 .32938 .71019 .31571 Mtetra
.581 .565 .801 r
.71019 .31571 .71597 .32938 .72762 .32527 .72201 .31412 Mtetra
.576 .608 .848 r
.72201 .31412 .72762 .32527 .73938 .32198 .73391 .31269 Mtetra
.57 .65 .889 r
.73391 .31269 .73938 .32198 .75123 .31923 .74588 .31125 Mtetra
.572 .689 .92 r
.74588 .31125 .75123 .31923 .76315 .31675 .7579 .30955 Mtetra
.576 .718 .939 r
.7579 .30955 .76315 .31675 .77515 .3144 .76996 .30758 Mtetra
.588 .738 .947 r
.76996 .30758 .77515 .3144 .78721 .31197 .78206 .30524 Mtetra
.599 .747 .947 r
.78206 .30524 .78721 .31197 .79932 .30947 .7942 .30261 Mtetra
.61 .748 .943 r
.7942 .30261 .79932 .30947 .81149 .30687 .80638 .29974 Mtetra
.618 .744 .936 r
.80638 .29974 .81149 .30687 .82371 .3041 .81861 .29669 Mtetra
.664 .753 .917 r
.17328 .5025 .18006 .50842 .1898 .50429 .18297 .49909 Mtetra
.669 .78 .932 r
.18297 .49909 .1898 .50429 .19959 .49999 .19271 .49553 Mtetra
.677 .809 .946 r
.19271 .49553 .19959 .49999 .20943 .49547 .2025 .49173 Mtetra
.688 .84 .956 r
.2025 .49173 .20943 .49547 .21932 .49067 .21236 .48758 Mtetra
.705 .867 .959 r
.21236 .48758 .21932 .49067 .22927 .48551 .22229 .48297 Mtetra
.722 .89 .957 r
.22229 .48297 .22927 .48551 .23927 .48008 .2323 .47786 Mtetra
.743 .903 .949 r
.2323 .47786 .23927 .48008 .24931 .4744 .24238 .47218 Mtetra
.761 .904 .94 r
.24238 .47218 .24931 .4744 .25938 .46871 .25252 .46604 Mtetra
.776 .888 .925 r
.25252 .46604 .25938 .46871 .26946 .46316 .26271 .45948 Mtetra
.778 .852 .907 r
.26271 .45948 .26946 .46316 .27952 .45809 .27294 .45275 Mtetra
.765 .796 .878 r
.27294 .45275 .27952 .45809 .28956 .45379 .28318 .44605 Mtetra
.735 .724 .841 r
.28318 .44605 .28956 .45379 .29955 .45055 .29341 .43976 Mtetra
.695 .648 .799 r
.29341 .43976 .29955 .45055 .3095 .44869 .3036 .43418 Mtetra
.652 .577 .758 r
.3036 .43418 .3095 .44869 .3194 .44824 .31376 .42963 Mtetra
.611 .516 .721 r
.31376 .42963 .3194 .44824 .32926 .44928 .32387 .4264 Mtetra
.58 .469 .692 r
.32387 .4264 .32926 .44928 .33913 .45154 .33394 .42448 Mtetra
.554 .432 .668 r
.33394 .42448 .33913 .45154 .34901 .45483 .34397 .42395 Mtetra
.533 .404 .651 r
.34397 .42395 .34901 .45483 .35894 .45856 .354 .42481 Mtetra
.516 .384 .64 r
.354 .42481 .35894 .45856 .36897 .46233 .36402 .427 Mtetra
.505 .373 .634 r
.36402 .427 .36897 .46233 .37907 .46608 .37407 .43009 Mtetra
.498 .367 .632 r
.37407 .43009 .37907 .46608 .38927 .46956 .38418 .43374 Mtetra
.5 .369 .634 r
.38418 .43374 .38927 .46956 .39962 .47155 .39438 .4373 Mtetra
.5 .374 .639 r
.39438 .4373 .39962 .47155 .41009 .47187 .40468 .4407 Mtetra
.468 .361 .65 r
.40468 .4407 .41009 .47187 .42062 .47267 .415 .44587 Mtetra
.408 .339 .668 r
.415 .44587 .42062 .47267 .43118 .47494 .42535 .4532 Mtetra
.353 .334 .699 r
.42535 .4532 .43118 .47494 .44176 .47928 .43579 .46106 Mtetra
.332 .354 .733 r
.43579 .46106 .44176 .47928 .4524 .48517 .44638 .46819 Mtetra
.419 .424 .758 r
.44638 .46819 .4524 .48517 .46318 .48955 .45713 .47247 Mtetra
.534 .493 .756 r
.45713 .47247 .46318 .48955 .4741 .49074 .46805 .47283 Mtetra
.617 .534 .738 r
.46805 .47283 .4741 .49074 .48515 .48723 .47909 .46929 Mtetra
.678 .568 .724 r
.47909 .46929 .48515 .48723 .49629 .47903 .49022 .46184 Mtetra
.731 .603 .714 r
.49022 .46184 .49629 .47903 .50745 .4676 .5014 .45044 Mtetra
.76 .618 .702 r
.5014 .45044 .50745 .4676 .51862 .45461 .51258 .43613 Mtetra
.757 .607 .691 r
.51258 .43613 .51862 .45461 .52976 .44316 .52373 .42105 Mtetra
.73 .571 .676 r
.52373 .42105 .52976 .44316 .54091 .43377 .53485 .40647 Mtetra
.687 .523 .659 r
.53485 .40647 .54091 .43377 .55208 .42584 .54595 .39404 Mtetra
.656 .489 .646 r
.54595 .39404 .55208 .42584 .56326 .41838 .55705 .38336 Mtetra
.648 .475 .636 r
.55705 .38336 .56326 .41838 .57444 .40921 .56815 .3725 Mtetra
.644 .469 .632 r
.56815 .3725 .57444 .40921 .5856 .39851 .57925 .36152 Mtetra
.639 .465 .631 r
.57925 .36152 .5856 .39851 .59675 .3875 .59034 .35109 Mtetra
.634 .462 .633 r
.59034 .35109 .59675 .3875 .60789 .37646 .60146 .34155 Mtetra
.626 .46 .638 r
.60146 .34155 .60789 .37646 .61903 .36542 .61262 .33335 Mtetra
.619 .463 .649 r
.61262 .33335 .61903 .36542 .63018 .35481 .62384 .32655 Mtetra
.613 .471 .665 r
.62384 .32655 .63018 .35481 .64136 .34523 .63513 .32117 Mtetra
.606 .486 .689 r
.63513 .32117 .64136 .34523 .65259 .33688 .64651 .31713 Mtetra
.595 .506 .724 r
.64651 .31713 .65259 .33688 .66391 .33005 .65799 .31444 Mtetra
.581 .538 .772 r
.65799 .31444 .66391 .33005 .67532 .32466 .66958 .31281 Mtetra
.56 .584 .835 r
.66958 .31281 .67532 .32466 .68683 .32067 .68127 .31192 Mtetra
.526 .641 .906 r
.68127 .31192 .68683 .32067 .69846 .31779 .69305 .31146 Mtetra
.483 .702 .965 r
.69305 .31146 .69846 .31779 .71019 .31571 .70491 .31104 Mtetra
.436 .745 .993 r
.70491 .31104 .71019 .31571 .72201 .31412 .71683 .31046 Mtetra
.418 .778 .995 r
.71683 .31046 .72201 .31412 .73391 .31269 .72881 .30944 Mtetra
.431 .801 .994 r
.72881 .30944 .73391 .31269 .74588 .31125 .74082 .30795 Mtetra
.478 .824 .998 r
.74082 .30795 .74588 .31125 .7579 .30955 .75286 .30587 Mtetra
.53 .836 .999 r
.75286 .30587 .7579 .30955 .76996 .30758 .76492 .30328 Mtetra
.58 .834 .993 r
.76492 .30328 .76996 .30758 .78206 .30524 .77701 .30021 Mtetra
.614 .82 .979 r
.77701 .30021 .78206 .30524 .7942 .30261 .78913 .29676 Mtetra
.635 .799 .961 r
.78913 .29676 .7942 .30261 .80638 .29974 .80128 .29306 Mtetra
.646 .773 .941 r
.80128 .29306 .80638 .29974 .81861 .29669 .81347 .28921 Mtetra
.621 .742 .933 r
.16646 .49655 .17328 .5025 .18297 .49909 .17607 .49407 Mtetra
.616 .776 .957 r
.17607 .49407 .18297 .49909 .19271 .49553 .18572 .49154 Mtetra
.612 .815 .978 r
.18572 .49154 .19271 .49553 .2025 .49173 .19543 .48884 Mtetra
.605 .857 .991 r
.19543 .48884 .2025 .49173 .21236 .48758 .20521 .48585 Mtetra
.594 .894 .988 r
.20521 .48585 .21236 .48758 .22229 .48297 .21506 .48247 Mtetra
.575 .921 .961 r
.21506 .48247 .22229 .48297 .2323 .47786 .22499 .47858 Mtetra
.555 .93 .909 r
.22499 .47858 .2323 .47786 .24238 .47218 .23502 .47403 Mtetra
.531 .922 .842 r
.23502 .47403 .24238 .47218 .25252 .46604 .24513 .46879 Mtetra
.529 .915 .786 r
.24513 .46879 .25252 .46604 .26271 .45948 .25534 .46276 Mtetra
.546 .917 .757 r
.25534 .46276 .26271 .45948 .27294 .45275 .26562 .45605 Mtetra
.602 .943 .771 r
.26562 .45605 .27294 .45275 .28318 .44605 .27597 .44867 Mtetra
.683 .978 .823 r
.27597 .44867 .28318 .44605 .29341 .43976 .28636 .44086 Mtetra
.771 .991 .887 r
.28636 .44086 .29341 .43976 .3036 .43418 .29678 .43282 Mtetra
.811 .936 .912 r
.29678 .43282 .3036 .43418 .31376 .42963 .3072 .42488 Mtetra
.789 .821 .878 r
.3072 .42488 .31376 .42963 .32387 .4264 .31761 .41732 Mtetra
.737 .698 .814 r
.31761 .41732 .32387 .4264 .33394 .42448 .328 .4103 Mtetra
.684 .598 .754 r
.328 .4103 .33394 .42448 .34397 .42395 .33836 .404 Mtetra
.638 .523 .707 r
.33836 .404 .34397 .42395 .354 .42481 .34869 .39881 Mtetra
.602 .469 .672 r
.34869 .39881 .354 .42481 .36402 .427 .35897 .39492 Mtetra
.584 .436 .647 r
.35897 .39492 .36402 .427 .37407 .43009 .36927 .3916 Mtetra
.574 .414 .627 r
.36927 .3916 .37407 .43009 .38418 .43374 .37959 .38854 Mtetra
.562 .394 .612 r
.37959 .38854 .38418 .43374 .39438 .4373 .38992 .38627 Mtetra
.552 .38 .602 r
.38992 .38627 .39438 .4373 .40468 .4407 .40027 .38489 Mtetra
.544 .369 .594 r
.40027 .38489 .40468 .4407 .415 .44587 .41064 .38433 Mtetra
.541 .362 .588 r
.41064 .38433 .415 .44587 .42535 .4532 .42106 .38406 Mtetra
.553 .366 .581 r
.42106 .38406 .42535 .4532 .43579 .46106 .43161 .38168 Mtetra
.563 .368 .575 r
.43161 .38168 .43579 .46106 .44638 .46819 .44227 .37667 Mtetra
.563 .363 .568 r
.44227 .37667 .44638 .46819 .45713 .47247 .45299 .37069 Mtetra
.56 .357 .563 r
.45299 .37069 .45713 .47247 .46805 .47283 .46373 .36482 Mtetra
.55 .348 .56 r
.46373 .36482 .46805 .47283 .47909 .46929 .47446 .36116 Mtetra
.542 .342 .559 r
.47446 .36116 .47909 .46929 .49022 .46184 .48521 .35972 Mtetra
.542 .344 .562 r
.48521 .35972 .49022 .46184 .5014 .45044 .49601 .35841 Mtetra
.547 .351 .567 r
.49601 .35841 .5014 .45044 .51258 .43613 .50688 .35612 Mtetra
.562 .367 .575 r
.50688 .35612 .51258 .43613 .52373 .42105 .51781 .35118 Mtetra
.577 .384 .583 r
.51781 .35118 .52373 .42105 .53485 .40647 .52877 .34412 Mtetra
.581 .391 .59 r
.52877 .34412 .53485 .40647 .54595 .39404 .53975 .33733 Mtetra
.58 .395 .596 r
.53975 .33733 .54595 .39404 .55705 .38336 .55077 .33136 Mtetra
.577 .398 .603 r
.55077 .33136 .55705 .38336 .56815 .3725 .56182 .32629 Mtetra
.576 .405 .612 r
.56182 .32629 .56815 .3725 .57925 .36152 .57291 .32201 Mtetra
.581 .419 .627 r
.57291 .32201 .57925 .36152 .59034 .35109 .58406 .318 Mtetra
.582 .435 .647 r
.58406 .318 .59034 .35109 .60146 .34155 .59526 .31457 Mtetra
.574 .451 .674 r
.59526 .31457 .60146 .34155 .61262 .33335 .60655 .31246 Mtetra
.562 .477 .716 r
.60655 .31246 .61262 .33335 .62384 .32655 .61792 .31148 Mtetra
.545 .524 .782 r
.61792 .31148 .62384 .32655 .63513 .32117 .62939 .31126 Mtetra
.503 .596 .88 r
.62939 .31126 .63513 .32117 .64651 .31713 .64096 .3116 Mtetra
.376 .675 .975 r
.64096 .3116 .64651 .31713 .65799 .31444 .65262 .31234 Mtetra
.117 .64 .881 r
.65262 .31234 .65799 .31444 .66958 .31281 .66436 .3132 Mtetra
.1 0 0 r
.66436 .3132 .66958 .31281 .68127 .31192 .67618 .31383 Mtetra
.182 0 0 r
.67618 .31383 .68127 .31192 .69305 .31146 .68806 .31404 Mtetra
.172 0 0 r
.68806 .31404 .69305 .31146 .70491 .31104 .69999 .31357 Mtetra
.111 0 0 r
.69999 .31357 .70491 .31104 .71683 .31046 .71194 .31239 Mtetra
0 0 0 r
.71194 .31239 .71683 .31046 .72881 .30944 .72392 .3104 Mtetra
.17 .702 .707 r
.72392 .3104 .72881 .30944 .74082 .30795 .73592 .3077 Mtetra
.356 .83 .859 r
.73592 .3077 .74082 .30795 .75286 .30587 .74792 .30431 Mtetra
.508 .895 .954 r
.74792 .30431 .75286 .30587 .76492 .30328 .75995 .30039 Mtetra
.606 .9 .987 r
.75995 .30039 .76492 .30328 .77701 .30021 .77199 .29605 Mtetra
.656 .873 .98 r
.77199 .29605 .77701 .30021 .78913 .29676 .78406 .2914 Mtetra
.678 .835 .959 r
.78406 .2914 .78913 .29676 .80128 .29306 .79616 .28657 Mtetra
.684 .797 .935 r
.79616 .28657 .80128 .29306 .81347 .28921 .8083 .28168 Mtetra
.581 .73 .945 r
.15958 .49055 .16646 .49655 .17607 .49407 .16913 .4888 Mtetra
.568 .754 .965 r
.16913 .4888 .17607 .49407 .18572 .49154 .17872 .48709 Mtetra
.554 .782 .983 r
.17872 .48709 .18572 .49154 .19543 .48884 .18836 .48533 Mtetra
.535 .813 .997 r
.18836 .48533 .19543 .48884 .20521 .48585 .19805 .48345 Mtetra
.503 .842 .997 r
.19805 .48345 .20521 .48585 .21506 .48247 .20781 .48139 Mtetra
.453 .859 .964 r
.20781 .48139 .21506 .48247 .22499 .47858 .21764 .479 Mtetra
.379 .842 .876 r
.21764 .479 .22499 .47858 .23502 .47403 .22755 .47614 Mtetra
.282 .776 .728 r
.22755 .47614 .23502 .47403 .24513 .46879 .23756 .47269 Mtetra
0 0 0 r
.23756 .47269 .24513 .46879 .25534 .46276 .24766 .4685 Mtetra
.24766 .4685 .25534 .46276 .26562 .45605 .25787 .46351 Mtetra
.25787 .46351 .26562 .45605 .27597 .44867 .26817 .45763 Mtetra
.26817 .45763 .27597 .44867 .28636 .44086 .27855 .45094 Mtetra
.27855 .45094 .28636 .44086 .29678 .43282 .28901 .44347 Mtetra
.28901 .44347 .29678 .43282 .3072 .42488 .29952 .43545 Mtetra
.29952 .43545 .3072 .42488 .31761 .41732 .31007 .42707 Mtetra
.31007 .42707 .31761 .41732 .328 .4103 .32064 .41853 Mtetra
.32064 .41853 .328 .4103 .33836 .404 .33121 .41003 Mtetra
.33121 .41003 .33836 .404 .34869 .39881 .34176 .40197 Mtetra
.574 .928 .752 r
.34176 .40197 .34869 .39881 .35897 .39492 .35228 .3946 Mtetra
.763 .973 .923 r
.35228 .3946 .35897 .39492 .36927 .3916 .36282 .38735 Mtetra
.784 .848 .899 r
.36282 .38735 .36927 .3916 .37959 .38854 .37337 .38011 Mtetra
.727 .715 .839 r
.37337 .38011 .37959 .38854 .38992 .38627 .38389 .37385 Mtetra
.674 .619 .786 r
.38389 .37385 .38992 .38627 .40027 .38489 .3944 .36869 Mtetra
.658 .566 .74 r
.3944 .36869 .40027 .38489 .41064 .38433 .40494 .3632 Mtetra
.652 .526 .697 r
.40494 .3632 .41064 .38433 .42106 .38406 .41555 .35656 Mtetra
.656 .5 .66 r
.41555 .35656 .42106 .38406 .43161 .38168 .42626 .34741 Mtetra
.654 .479 .635 r
.42626 .34741 .43161 .38168 .44227 .37667 .43704 .33604 Mtetra
.633 .452 .62 r
.43704 .33604 .44227 .37667 .45299 .37069 .44779 .32546 Mtetra
.607 .426 .612 r
.44779 .32546 .45299 .37069 .46373 .36482 .45848 .31735 Mtetra
.571 .397 .608 r
.45848 .31735 .46373 .36482 .47446 .36116 .4691 .31363 Mtetra
.534 .371 .606 r
.4691 .31363 .47446 .36116 .48521 .35972 .4797 .31432 Mtetra
.51 .357 .609 r
.4797 .31432 .48521 .35972 .49601 .35841 .49035 .3175 Mtetra
.498 .357 .619 r
.49035 .3175 .49601 .35841 .50688 .35612 .50108 .3215 Mtetra
.52 .387 .64 r
.50108 .3215 .50688 .35612 .51781 .35118 .51191 .32329 Mtetra
.553 .432 .668 r
.51191 .32329 .51781 .35118 .52877 .34412 .52283 .32256 Mtetra
.577 .48 .707 r
.52283 .32256 .52877 .34412 .53975 .33733 .53381 .32068 Mtetra
.591 .529 .753 r
.53381 .32068 .53975 .33733 .55077 .33136 .54485 .31847 Mtetra
.567 .566 .812 r
.54485 .31847 .55077 .33136 .56182 .32629 .55595 .31738 Mtetra
.511 .625 .901 r
.55595 .31738 .56182 .32629 .57291 .32201 .56713 .31729 Mtetra
.401 .722 .989 r
.56713 .31729 .57291 .32201 .58406 .318 .57838 .31722 Mtetra
.07 .629 .795 r
.57838 .31722 .58406 .318 .59526 .31457 .58971 .3173 Mtetra
.281 0 0 r
.58971 .3173 .59526 .31457 .60655 .31246 .60112 .31807 Mtetra
.41 0 0 r
.60112 .31807 .60655 .31246 .61792 .31148 .61264 .31933 Mtetra
.448 0 .047 r
.61264 .31933 .61792 .31148 .62939 .31126 .62424 .32063 Mtetra
.459 .013 .102 r
.62424 .32063 .62939 .31126 .64096 .3116 .63591 .32178 Mtetra
.455 .02 .122 r
.63591 .32178 .64096 .3116 .65262 .31234 .64767 .32258 Mtetra
.437 .003 .115 r
.64767 .32258 .65262 .31234 .66436 .3132 .65948 .32284 Mtetra
.402 0 .081 r
.65948 .32284 .66436 .3132 .67618 .31383 .67133 .32229 Mtetra
.348 0 .016 r
.67133 .32229 .67618 .31383 .68806 .31404 .68322 .32091 Mtetra
.26 0 0 r
.68322 .32091 .68806 .31404 .69999 .31357 .69513 .31862 Mtetra
.127 0 0 r
.69513 .31862 .69999 .31357 .71194 .31239 .70705 .31551 Mtetra
0 0 0 r
.70705 .31551 .71194 .31239 .72392 .3104 .71899 .31163 Mtetra
.314 .796 .735 r
.71899 .31163 .72392 .3104 .73592 .3077 .73093 .30712 Mtetra
.519 .915 .905 r
.73093 .30712 .73592 .3077 .74792 .30431 .74289 .30213 Mtetra
.637 .933 .968 r
.74289 .30213 .74792 .30431 .75995 .30039 .75487 .29678 Mtetra
.688 .904 .972 r
.75487 .29678 .75995 .30039 .77199 .29605 .76687 .29123 Mtetra
.708 .866 .957 r
.76687 .29123 .77199 .29605 .78406 .2914 .7789 .28554 Mtetra
.713 .83 .937 r
.7789 .28554 .78406 .2914 .79616 .28657 .79097 .2798 Mtetra
.71 .799 .92 r
.79097 .2798 .79616 .28657 .8083 .28168 .80308 .27409 Mtetra
.561 .723 .95 r
.15266 .48451 .15958 .49055 .16913 .4888 .16219 .48308 Mtetra
.548 .731 .96 r
.16219 .48308 .16913 .4888 .17872 .48709 .17175 .48176 Mtetra
.533 .742 .971 r
.17175 .48176 .17872 .48709 .18836 .48533 .18135 .48053 Mtetra
.513 .756 .984 r
.18135 .48053 .18836 .48533 .19805 .48345 .19099 .47938 Mtetra
.48 .772 .996 r
.19099 .47938 .19805 .48345 .20781 .48139 .20067 .47832 Mtetra
.434 .792 .997 r
.20067 .47832 .20781 .48139 .21764 .479 .21041 .47722 Mtetra
.355 .795 .961 r
.21041 .47722 .21764 .479 .22755 .47614 .2202 .47601 Mtetra
.235 .75 .847 r
.2202 .47601 .22755 .47614 .23756 .47269 .23007 .47454 Mtetra
0 0 0 r
.23007 .47454 .23756 .47269 .24766 .4685 .24002 .47267 Mtetra
.055 0 0 r
.24002 .47267 .24766 .4685 .25787 .46351 .25006 .47026 Mtetra
.15 0 0 r
.25006 .47026 .25787 .46351 .26817 .45763 .26021 .46715 Mtetra
.21 0 0 r
.26021 .46715 .26817 .45763 .27855 .45094 .27045 .46327 Mtetra
.244 0 .063 r
.27045 .46327 .27855 .45094 .28901 .44347 .2808 .45851 Mtetra
.269 0 .132 r
.2808 .45851 .28901 .44347 .29952 .43545 .29123 .45295 Mtetra
.284 0 .178 r
.29123 .45295 .29952 .43545 .31007 .42707 .30174 .44664 Mtetra
.294 0 .209 r
.30174 .44664 .31007 .42707 .32064 .41853 .31232 .4397 Mtetra
.301 0 .23 r
.31232 .4397 .32064 .41853 .33121 .41003 .32294 .43227 Mtetra
.306 0 .243 r
.32294 .43227 .33121 .41003 .34176 .40197 .3336 .42453 Mtetra
.306 0 .246 r
.3336 .42453 .34176 .40197 .35228 .3946 .34428 .41661 Mtetra
.294 0 .237 r
.34428 .41661 .35228 .3946 .36282 .38735 .35498 .40846 Mtetra
.28 0 .222 r
.35498 .40846 .36282 .38735 .37337 .38011 .3657 .40018 Mtetra
.287 0 .216 r
.3657 .40018 .37337 .38011 .38389 .37385 .3764 .39256 Mtetra
.292 0 .203 r
.3764 .39256 .38389 .37385 .3944 .36869 .38709 .38564 Mtetra
.217 0 .146 r
.38709 .38564 .3944 .36869 .40494 .3632 .39784 .3775 Mtetra
.057 0 .023 r
.39784 .3775 .40494 .3632 .41555 .35656 .40868 .36755 Mtetra
0 0 0 r
.40868 .36755 .41555 .35656 .42626 .34741 .41955 .35639 Mtetra
.41955 .35639 .42626 .34741 .43704 .33604 .43042 .34485 Mtetra
.43042 .34485 .43704 .33604 .44779 .32546 .44124 .33515 Mtetra
.057 0 0 r
.44124 .33515 .44779 .32546 .45848 .31735 .45199 .3283 Mtetra
.285 0 .065 r
.45199 .3283 .45848 .31735 .4691 .31363 .4627 .32457 Mtetra
.417 0 .133 r
.4627 .32457 .4691 .31363 .4797 .31432 .4734 .32397 Mtetra
.504 .069 .146 r
.4734 .32397 .4797 .31432 .49035 .3175 .48413 .32625 Mtetra
.555 .111 .149 r
.48413 .32625 .49035 .3175 .50108 .3215 .49493 .33038 Mtetra
.544 .1 .144 r
.49493 .33038 .50108 .3215 .51191 .32329 .50582 .33416 Mtetra
.516 .094 .177 r
.50582 .33416 .51191 .32329 .52283 .32256 .51681 .33675 Mtetra
.481 .091 .224 r
.51681 .33675 .52283 .32256 .53381 .32068 .5279 .33753 Mtetra
.463 .095 .254 r
.5279 .33753 .53381 .32068 .54485 .31847 .53905 .33709 Mtetra
.485 .126 .283 r
.53905 .33709 .54485 .31847 .55595 .31738 .55028 .33737 Mtetra
.501 .149 .301 r
.55028 .33737 .55595 .31738 .56713 .31729 .56159 .33833 Mtetra
.5 .153 .31 r
.56159 .33833 .56713 .31729 .57838 .31722 .57298 .33917 Mtetra
.498 .155 .316 r
.57298 .33917 .57838 .31722 .58971 .3173 .58444 .3398 Mtetra
.496 .156 .319 r
.58444 .3398 .58971 .3173 .60112 .31807 .59599 .34025 Mtetra
.49 .149 .314 r
.59599 .34025 .60112 .31807 .61264 .31933 .6076 .3404 Mtetra
.479 .133 .301 r
.6076 .3404 .61264 .31933 .62424 .32063 .61928 .34006 Mtetra
.462 .108 .279 r
.61928 .34006 .62424 .32063 .63591 .32178 .63101 .33909 Mtetra
.435 .07 .245 r
.63101 .33909 .63591 .32178 .64767 .32258 .64278 .33735 Mtetra
.395 .013 .192 r
.64278 .33735 .64767 .32258 .65948 .32284 .65459 .33479 Mtetra
.329 0 .109 r
.65459 .33479 .65948 .32284 .67133 .32229 .66641 .33132 Mtetra
.226 0 0 r
.66641 .33132 .67133 .32229 .68322 .32091 .67825 .32705 Mtetra
.056 0 0 r
.67825 .32705 .68322 .32091 .69513 .31862 .69011 .32206 Mtetra
0 0 0 r
.69011 .32206 .69513 .31862 .70705 .31551 .70197 .3165 Mtetra
.469 .888 .793 r
.70197 .3165 .70705 .31551 .71899 .31163 .71384 .31052 Mtetra
.643 .958 .93 r
.71384 .31052 .71899 .31163 .73093 .30712 .72574 .30424 Mtetra
.713 .935 .961 r
.72574 .30424 .73093 .30712 .74289 .30213 .73766 .29785 Mtetra
.733 .892 .952 r
.73766 .29785 .74289 .30213 .75487 .29678 .74961 .29141 Mtetra
.734 .854 .937 r
.74961 .29141 .75487 .29678 .76687 .29123 .7616 .28504 Mtetra
.73 .825 .923 r
.7616 .28504 .76687 .29123 .7789 .28554 .77363 .27875 Mtetra
.725 .804 .913 r
.77363 .27875 .7789 .28554 .79097 .2798 .7857 .27254 Mtetra
.72 .788 .906 r
.7857 .27254 .79097 .2798 .80308 .27409 .79782 .26643 Mtetra
.582 .73 .945 r
.14569 .47843 .15266 .48451 .16219 .48308 .15528 .47662 Mtetra
.577 .716 .938 r
.15528 .47662 .16219 .48308 .17175 .48176 .16489 .47495 Mtetra
.57 .703 .931 r
.16489 .47495 .17175 .48176 .18135 .48053 .17453 .47345 Mtetra
.56 .691 .927 r
.17453 .47345 .18135 .48053 .19099 .47938 .1842 .47217 Mtetra
.546 .682 .928 r
.1842 .47217 .19099 .47938 .20067 .47832 .19388 .47116 Mtetra
.532 .679 .932 r
.19388 .47116 .20067 .47832 .21041 .47722 .2036 .47036 Mtetra
.514 .682 .942 r
.2036 .47036 .21041 .47722 .2202 .47601 .21335 .46977 Mtetra
.496 .698 .959 r
.21335 .46977 .2202 .47601 .23007 .47454 .22314 .46926 Mtetra
.469 .724 .98 r
.22314 .46926 .23007 .47454 .24002 .47267 .233 .46874 Mtetra
.428 .76 .996 r
.233 .46874 .24002 .47267 .25006 .47026 .24292 .46806 Mtetra
.351 .783 .969 r
.24292 .46806 .25006 .47026 .26021 .46715 .25292 .46708 Mtetra
.216 .738 .832 r
.25292 .46708 .26021 .46715 .27045 .46327 .26301 .46565 Mtetra
0 0 0 r
.26301 .46565 .27045 .46327 .2808 .45851 .2732 .4636 Mtetra
.09 0 0 r
.2732 .4636 .2808 .45851 .29123 .45295 .28349 .46088 Mtetra
.179 0 0 r
.28349 .46088 .29123 .45295 .30174 .44664 .29387 .45744 Mtetra
.239 0 .018 r
.29387 .45744 .30174 .44664 .31232 .4397 .30433 .45334 Mtetra
.278 0 .107 r
.30433 .45334 .31232 .4397 .32294 .43227 .31488 .44863 Mtetra
.301 0 .167 r
.31488 .44863 .32294 .43227 .3336 .42453 .32549 .44328 Mtetra
.316 0 .207 r
.32549 .44328 .3336 .42453 .34428 .41661 .33617 .43735 Mtetra
.333 0 .237 r
.33617 .43735 .34428 .41661 .35498 .40846 .34689 .43117 Mtetra
.353 .026 .264 r
.34689 .43117 .35498 .40846 .3657 .40018 .35763 .42498 Mtetra
.378 .059 .291 r
.35763 .42498 .3657 .40018 .3764 .39256 .36838 .41914 Mtetra
.397 .083 .311 r
.36838 .41914 .3764 .39256 .38709 .38564 .37914 .41364 Mtetra
.386 .078 .315 r
.37914 .41364 .38709 .38564 .39784 .3775 .38997 .40713 Mtetra
.374 .072 .32 r
.38997 .40713 .39784 .3775 .40868 .36755 .40088 .39946 Mtetra
.397 .1 .34 r
.40088 .39946 .40868 .36755 .41955 .35639 .41177 .39239 Mtetra
.432 .14 .368 r
.41177 .39239 .41955 .35639 .43042 .34485 .42265 .38658 Mtetra
.462 .177 .394 r
.42265 .38658 .43042 .34485 .44124 .33515 .43352 .38213 Mtetra
.48 .2 .411 r
.43352 .38213 .44124 .33515 .45199 .3283 .44439 .37879 Mtetra
.481 .205 .418 r
.44439 .37879 .45199 .3283 .4627 .32457 .45532 .37508 Mtetra
.478 .202 .417 r
.45532 .37508 .4627 .32457 .4734 .32397 .46631 .371 Mtetra
.484 .204 .412 r
.46631 .371 .4734 .32397 .48413 .32625 .47731 .36804 Mtetra
.492 .203 .403 r
.47731 .36804 .48413 .32625 .49493 .33038 .48835 .36644 Mtetra
.501 .2 .388 r
.48835 .36644 .49493 .33038 .50582 .33416 .49944 .36613 Mtetra
.504 .194 .374 r
.49944 .36613 .50582 .33416 .51681 .33675 .5106 .36642 Mtetra
.487 .172 .359 r
.5106 .36642 .51681 .33675 .5279 .33753 .52183 .36556 Mtetra
.469 .152 .345 r
.52183 .36556 .5279 .33753 .53905 .33709 .53313 .36368 Mtetra
.471 .148 .337 r
.53313 .36368 .53905 .33709 .55028 .33737 .54449 .36216 Mtetra
.472 .143 .326 r
.54449 .36216 .55028 .33737 .56159 .33833 .55592 .361 Mtetra
.467 .128 .308 r
.55592 .361 .56159 .33833 .57298 .33917 .56741 .35983 Mtetra
.455 .108 .286 r
.56741 .35983 .57298 .33917 .58444 .3398 .57897 .35842 Mtetra
.433 .076 .257 r
.57897 .35842 .58444 .3398 .59599 .34025 .59058 .35642 Mtetra
.401 .029 .213 r
.59058 .35642 .59599 .34025 .6076 .3404 .60223 .35378 Mtetra
.352 0 .145 r
.60223 .35378 .6076 .3404 .61928 .34006 .61393 .35051 Mtetra
.272 0 .038 r
.61393 .35051 .61928 .34006 .63101 .33909 .62566 .34656 Mtetra
.131 0 0 r
.62566 .34656 .63101 .33909 .64278 .33735 .63742 .34186 Mtetra
0 0 0 r
.63742 .34186 .64278 .33735 .65459 .33479 .64919 .33647 Mtetra
.427 .859 .743 r
.64919 .33647 .65459 .33479 .66641 .33132 .66097 .33044 Mtetra
.656 .963 .925 r
.66097 .33044 .66641 .33132 .67825 .32705 .67277 .32393 Mtetra
.74 .929 .952 r
.67277 .32393 .67825 .32705 .69011 .32206 .68458 .31709 Mtetra
.757 .868 .929 r
.68458 .31709 .69011 .32206 .70197 .3165 .69641 .31007 Mtetra
.752 .818 .904 r
.69641 .31007 .70197 .3165 .71384 .31052 .70827 .30303 Mtetra
.743 .784 .886 r
.70827 .30303 .71384 .31052 .72574 .30424 .72016 .29606 Mtetra
.733 .761 .875 r
.72016 .29606 .72574 .30424 .73766 .29785 .73209 .28929 Mtetra
.725 .749 .872 r
.73209 .28929 .73766 .29785 .74961 .29141 .74407 .28274 Mtetra
.717 .744 .873 r
.74407 .28274 .74961 .29141 .7616 .28504 .75611 .27646 Mtetra
.711 .745 .878 r
.75611 .27646 .7616 .28504 .77363 .27875 .76819 .27039 Mtetra
.708 .751 .886 r
.76819 .27039 .77363 .27875 .7857 .27254 .78033 .26449 Mtetra
.705 .76 .895 r
.78033 .26449 .7857 .27254 .79782 .26643 .79252 .25872 Mtetra
.628 .744 .931 r
.13868 .4723 .14569 .47843 .15528 .47662 .14838 .46959 Mtetra
.624 .714 .911 r
.14838 .46959 .15528 .47662 .16489 .47495 .15811 .467 Mtetra
.617 .685 .892 r
.15811 .467 .16489 .47495 .17453 .47345 .16785 .4646 Mtetra
.606 .657 .874 r
.16785 .4646 .17453 .47345 .1842 .47217 .17762 .46247 Mtetra
.592 .632 .86 r
.17762 .46247 .1842 .47217 .19388 .47116 .18738 .4607 Mtetra
.578 .609 .847 r
.18738 .4607 .19388 .47116 .2036 .47036 .19716 .45929 Mtetra
.563 .59 .839 r
.19716 .45929 .2036 .47036 .21335 .46977 .20695 .4583 Mtetra
.55 .576 .833 r
.20695 .4583 .21335 .46977 .22314 .46926 .21676 .45766 Mtetra
.537 .568 .833 r
.21676 .45766 .22314 .46926 .233 .46874 .22659 .45734 Mtetra
.528 .568 .839 r
.22659 .45734 .233 .46874 .24292 .46806 .23646 .45724 Mtetra
.519 .576 .853 r
.23646 .45724 .24292 .46806 .25292 .46708 .24638 .45727 Mtetra
.512 .598 .876 r
.24638 .45727 .25292 .46708 .26301 .46565 .25636 .45728 Mtetra
.505 .635 .912 r
.25636 .45728 .26301 .46565 .2732 .4636 .26641 .45712 Mtetra
.489 .692 .958 r
.26641 .45712 .2732 .4636 .28349 .46088 .27654 .45669 Mtetra
.447 .762 .996 r
.27654 .45669 .28349 .46088 .29387 .45744 .28676 .45586 Mtetra
.32 .783 .941 r
.28676 .45586 .29387 .45744 .30433 .45334 .29707 .45465 Mtetra
0 0 0 r
.29707 .45465 .30433 .45334 .31488 .44863 .30746 .45303 Mtetra
.102 0 0 r
.30746 .45303 .31488 .44863 .32549 .44328 .31793 .45085 Mtetra
.216 0 0 r
.31793 .45085 .32549 .44328 .33617 .43735 .3285 .4481 Mtetra
.308 0 .053 r
.3285 .4481 .33617 .43735 .34689 .43117 .3391 .44531 Mtetra
.373 0 .164 r
.3391 .44531 .34689 .43117 .35763 .42498 .34975 .44277 Mtetra
.409 .047 .235 r
.34975 .44277 .35763 .42498 .36838 .41914 .36044 .44027 Mtetra
.43 .087 .28 r
.36044 .44027 .36838 .41914 .37914 .41364 .37118 .43782 Mtetra
.442 .111 .309 r
.37118 .43782 .37914 .41364 .38997 .40713 .38197 .43525 Mtetra
.459 .141 .339 r
.38197 .43525 .38997 .40713 .40088 .39946 .3928 .43293 Mtetra
.5 .193 .377 r
.3928 .43293 .40088 .39946 .41177 .39239 .4036 .4329 Mtetra
.528 .232 .407 r
.4036 .4329 .41177 .39239 .42265 .38658 .41439 .43529 Mtetra
.529 .242 .424 r
.41439 .43529 .42265 .38658 .43352 .38213 .42526 .4377 Mtetra
.517 .239 .431 r
.42526 .4377 .43352 .38213 .44439 .37879 .43627 .43849 Mtetra
.486 .216 .429 r
.43627 .43849 .44439 .37879 .45532 .37508 .44745 .43482 Mtetra
.452 .187 .42 r
.44745 .43482 .45532 .37508 .46631 .371 .45877 .42666 Mtetra
.432 .167 .409 r
.45877 .42666 .46631 .371 .47731 .36804 .47013 .41685 Mtetra
.418 .148 .394 r
.47013 .41685 .47731 .36804 .48835 .36644 .4815 .40705 Mtetra
.424 .141 .376 r
.4815 .40705 .48835 .36644 .49944 .36613 .49285 .39966 Mtetra
.434 .134 .356 r
.49285 .39966 .49944 .36613 .5106 .36642 .50421 .39458 Mtetra
.419 .106 .325 r
.50421 .39458 .5106 .36642 .52183 .36556 .5156 .38973 Mtetra
.398 .072 .292 r
.5156 .38973 .52183 .36556 .53313 .36368 .52703 .38477 Mtetra
.379 .04 .259 r
.52703 .38477 .53313 .36368 .54449 .36216 .53851 .37985 Mtetra
.349 0 .209 r
.53851 .37985 .54449 .36216 .55592 .361 .55002 .37496 Mtetra
.307 0 .132 r
.55002 .37496 .55592 .361 .56741 .35983 .56158 .37032 Mtetra
.231 0 .013 r
.56158 .37032 .56741 .35983 .57897 .35842 .57317 .36565 Mtetra
.067 0 0 r
.57317 .36565 .57897 .35842 .59058 .35642 .58481 .36037 Mtetra
0 0 0 r
.58481 .36037 .59058 .35642 .60223 .35378 .59646 .35452 Mtetra
.549 .93 .845 r
.59646 .35452 .60223 .35378 .61393 .35051 .60814 .34825 Mtetra
.723 .947 .953 r
.60814 .34825 .61393 .35051 .62566 .34656 .61985 .34157 Mtetra
.761 .863 .924 r
.61985 .34157 .62566 .34656 .63742 .34186 .63156 .33447 Mtetra
.755 .785 .877 r
.63156 .33447 .63742 .34186 .64919 .33647 .6433 .32706 Mtetra
.742 .729 .84 r
.6433 .32706 .64919 .33647 .66097 .33044 .65505 .31948 Mtetra
.729 .692 .816 r
.65505 .31948 .66097 .33044 .67277 .32393 .66682 .31186 Mtetra
.717 .668 .801 r
.66682 .31186 .67277 .32393 .68458 .31709 .67862 .30436 Mtetra
.708 .653 .794 r
.67862 .30436 .68458 .31709 .69641 .31007 .69046 .29707 Mtetra
.699 .646 .793 r
.69046 .29707 .69641 .31007 .70827 .30303 .70234 .2901 Mtetra
.693 .644 .797 r
.70234 .2901 .70827 .30303 .72016 .29606 .71427 .28348 Mtetra
.687 .648 .805 r
.71427 .28348 .72016 .29606 .73209 .28929 .72627 .27729 Mtetra
.683 .656 .818 r
.72627 .27729 .73209 .28929 .74407 .28274 .73832 .27146 Mtetra
.679 .669 .833 r
.73832 .27146 .74407 .28274 .75611 .27646 .75044 .266 Mtetra
.677 .686 .851 r
.75044 .266 .75611 .27646 .76819 .27039 .76263 .26082 Mtetra
.676 .707 .872 r
.76263 .26082 .76819 .27039 .78033 .26449 .77488 .25583 Mtetra
.676 .732 .893 r
.77488 .25583 .78033 .26449 .79252 .25872 .78718 .25095 Mtetra
.677 .756 .911 r
.13161 .46613 .13868 .4723 .14838 .46959 .14147 .46223 Mtetra
.671 .719 .885 r
.14147 .46223 .14838 .46959 .15811 .467 .15135 .45839 Mtetra
.661 .684 .861 r
.15135 .45839 .15811 .467 .16785 .4646 .16125 .45469 Mtetra
.648 .65 .838 r
.16125 .45469 .16785 .4646 .17762 .46247 .17116 .45122 Mtetra
.633 .618 .817 r
.17116 .45122 .17762 .46247 .18738 .4607 .18108 .44806 Mtetra
.618 .588 .798 r
.18108 .44806 .18738 .4607 .19716 .45929 .191 .44527 Mtetra
.602 .56 .78 r
.191 .44527 .19716 .45929 .20695 .4583 .20091 .44291 Mtetra
.588 .536 .764 r
.20091 .44291 .20695 .4583 .21676 .45766 .21083 .44099 Mtetra
.574 .514 .75 r
.21083 .44099 .21676 .45766 .22659 .45734 .22075 .43952 Mtetra
.563 .497 .739 r
.22075 .43952 .22659 .45734 .23646 .45724 .23068 .43847 Mtetra
.553 .483 .73 r
.23068 .43847 .23646 .45724 .24638 .45727 .24064 .43779 Mtetra
.546 .473 .724 r
.24064 .43779 .24638 .45727 .25636 .45728 .25062 .43741 Mtetra
.541 .467 .721 r
.25062 .43741 .25636 .45728 .26641 .45712 .26065 .43724 Mtetra
.539 .466 .722 r
.26065 .43724 .26641 .45712 .27654 .45669 .27073 .43717 Mtetra
.539 .47 .726 r
.27073 .43717 .27654 .45669 .28676 .45586 .28087 .43709 Mtetra
.539 .477 .734 r
.28087 .43709 .28676 .45586 .29707 .45465 .29108 .43701 Mtetra
.54 .488 .747 r
.29108 .43701 .29707 .45465 .30746 .45303 .30135 .43686 Mtetra
.546 .509 .765 r
.30135 .43686 .30746 .45303 .31793 .45085 .3117 .43643 Mtetra
.556 .537 .789 r
.3117 .43643 .31793 .45085 .3285 .4481 .32214 .43562 Mtetra
.551 .567 .823 r
.32214 .43562 .3285 .4481 .3391 .44531 .33263 .43489 Mtetra
.535 .602 .867 r
.33263 .43489 .3391 .44531 .34975 .44277 .34317 .43439 Mtetra
.537 .657 .913 r
.34317 .43439 .34975 .44277 .36044 .44027 .35379 .43353 Mtetra
.54 .712 .951 r
.35379 .43353 .36044 .44027 .37118 .43782 .36449 .43225 Mtetra
.493 .736 .98 r
.36449 .43225 .37118 .43782 .38197 .43525 .37524 .43131 Mtetra
.338 .724 .984 r
.37524 .43131 .38197 .43525 .3928 .43293 .38601 .43133 Mtetra
.181 0 0 r
.38601 .43133 .3928 .43293 .4036 .4329 .39674 .43402 Mtetra
.524 0 0 r
.39674 .43402 .4036 .4329 .41439 .43529 .40747 .43917 Mtetra
.533 .005 0 r
.40747 .43917 .41439 .43529 .42526 .4377 .41832 .44359 Mtetra
.434 0 0 r
.41832 .44359 .42526 .4377 .43627 .43849 .42936 .44531 Mtetra
.125 0 0 r
.42936 .44531 .43627 .43849 .44745 .43482 .44062 .44162 Mtetra
0 0 0 r
.44062 .44162 .44745 .43482 .45877 .42666 .45205 .4325 Mtetra
.598 .885 .579 r
.45205 .4325 .45877 .42666 .47013 .41685 .46354 .42064 Mtetra
.77 .979 .716 r
.46354 .42064 .47013 .41685 .4815 .40705 .47503 .40802 Mtetra
.796 .998 .847 r
.47503 .40802 .4815 .40705 .49285 .39966 .48647 .39785 Mtetra
.764 .954 .936 r
.48647 .39785 .49285 .39966 .50421 .39458 .4979 .39035 Mtetra
.748 .876 .938 r
.4979 .39035 .50421 .39458 .5156 .38973 .50935 .38381 Mtetra
.735 .816 .915 r
.50935 .38381 .5156 .38973 .52703 .38477 .52082 .37761 Mtetra
.739 .779 .885 r
.52082 .37761 .52703 .38477 .53851 .37985 .53232 .37096 Mtetra
.735 .733 .849 r
.53232 .37096 .53851 .37985 .55002 .37496 .54385 .36394 Mtetra
.712 .68 .817 r
.54385 .36394 .55002 .37496 .56158 .37032 .5554 .35715 Mtetra
.695 .637 .787 r
.5554 .35715 .56158 .37032 .57317 .36565 .56698 .35042 Mtetra
.687 .606 .76 r
.56698 .35042 .57317 .36565 .58481 .36037 .57859 .34329 Mtetra
.68 .583 .74 r
.57859 .34329 .58481 .36037 .59646 .35452 .59022 .33585 Mtetra
.672 .565 .726 r
.59022 .33585 .59646 .35452 .60814 .34825 .60186 .32835 Mtetra
.666 .552 .716 r
.60186 .32835 .60814 .34825 .61985 .34157 .61353 .32082 Mtetra
.662 .544 .709 r
.61353 .32082 .61985 .34157 .63156 .33447 .62522 .31326 Mtetra
.659 .539 .707 r
.62522 .31326 .63156 .33447 .6433 .32706 .63694 .30579 Mtetra
.655 .537 .707 r
.63694 .30579 .6433 .32706 .65505 .31948 .64869 .29853 Mtetra
.653 .537 .71 r
.64869 .29853 .65505 .31948 .66682 .31186 .66048 .29156 Mtetra
.65 .541 .717 r
.66048 .29156 .66682 .31186 .67862 .30436 .67232 .28498 Mtetra
.648 .547 .726 r
.67232 .28498 .67862 .30436 .69046 .29707 .68421 .2788 Mtetra
.646 .555 .738 r
.68421 .2788 .69046 .29707 .70234 .2901 .69616 .27309 Mtetra
.644 .567 .753 r
.69616 .27309 .70234 .2901 .71427 .28348 .70818 .26782 Mtetra
.642 .581 .771 r
.70818 .26782 .71427 .28348 .72627 .27729 .72027 .263 Mtetra
.64 .599 .792 r
.72027 .263 .72627 .27729 .73832 .27146 .73243 .25856 Mtetra
.638 .62 .816 r
.73243 .25856 .73832 .27146 .75044 .266 .74467 .25443 Mtetra
.637 .645 .841 r
.74467 .25443 .75044 .266 .76263 .26082 .75698 .25054 Mtetra
.636 .674 .869 r
.75698 .25054 .76263 .26082 .77488 .25583 .76936 .24679 Mtetra
.636 .706 .897 r
.76936 .24679 .77488 .25583 .78718 .25095 .7818 .24311 Mtetra
.715 .763 .89 r
.12449 .45992 .13161 .46613 .14147 .46223 .13451 .45484 Mtetra
.708 .729 .867 r
.13451 .45484 .14147 .46223 .15135 .45839 .14455 .44976 Mtetra
.697 .696 .845 r
.14455 .44976 .15135 .45839 .16125 .45469 .15462 .44473 Mtetra
.685 .664 .823 r
.15462 .44473 .16125 .45469 .17116 .45122 .1647 .43983 Mtetra
.671 .633 .803 r
.1647 .43983 .17116 .45122 .18108 .44806 .17478 .43511 Mtetra
.656 .602 .782 r
.17478 .43511 .18108 .44806 .191 .44527 .18487 .43065 Mtetra
.64 .573 .763 r
.18487 .43065 .191 .44527 .20091 .44291 .19496 .42653 Mtetra
.625 .546 .745 r
.19496 .42653 .20091 .44291 .21083 .44099 .20504 .42277 Mtetra
.61 .521 .729 r
.20504 .42277 .21083 .44099 .22075 .43952 .21512 .41946 Mtetra
.596 .498 .713 r
.21512 .41946 .22075 .43952 .23068 .43847 .2252 .41658 Mtetra
.583 .478 .7 r
.2252 .41658 .23068 .43847 .24064 .43779 .23528 .41419 Mtetra
.572 .461 .689 r
.23528 .41419 .24064 .43779 .25062 .43741 .24536 .41225 Mtetra
.562 .447 .68 r
.24536 .41225 .25062 .43741 .26065 .43724 .25545 .41077 Mtetra
.555 .436 .673 r
.25545 .41077 .26065 .43724 .27073 .43717 .26557 .40965 Mtetra
.549 .428 .667 r
.26557 .40965 .27073 .43717 .28087 .43709 .27572 .40883 Mtetra
.544 .422 .664 r
.27572 .40883 .28087 .43709 .29108 .43701 .2859 .4083 Mtetra
.541 .418 .662 r
.2859 .4083 .29108 .43701 .30135 .43686 .29613 .40801 Mtetra
.29613 .40801 .30135 .43686 .3117 .43643 .30642 .40771 Mtetra
.543 .42 .663 r
.30642 .40771 .3117 .43643 .32214 .43562 .31678 .40726 Mtetra
.542 .422 .665 r
.31678 .40726 .32214 .43562 .33263 .43489 .3272 .40686 Mtetra
.542 .423 .667 r
.3272 .40686 .33263 .43489 .34317 .43439 .33768 .40649 Mtetra
.553 .432 .668 r
.33768 .40649 .34317 .43439 .35379 .43353 .34826 .4054 Mtetra
.566 .439 .667 r
.34826 .4054 .35379 .43353 .36449 .43225 .35895 .40346 Mtetra
.56 .433 .664 r
.35895 .40346 .36449 .43225 .37524 .43131 .36968 .40188 Mtetra
.544 .42 .662 r
.36968 .40188 .37524 .43131 .38601 .43133 .38041 .40133 Mtetra
.514 .398 .659 r
.38041 .40133 .38601 .43133 .39674 .43402 .39113 .40275 Mtetra
.488 .376 .653 r
.39113 .40275 .39674 .43402 .40747 .43917 .40186 .40587 Mtetra
.504 .381 .645 r
.40186 .40587 .40747 .43917 .41832 .44359 .41272 .40812 Mtetra
.535 .397 .639 r
.41272 .40812 .41832 .44359 .42936 .44531 .42373 .40809 Mtetra
.576 .421 .634 r
.42373 .40809 .42936 .44531 .44062 .44162 .43491 .40434 Mtetra
.611 .445 .632 r
.43491 .40434 .44062 .44162 .45205 .4325 .44623 .39686 Mtetra
.635 .465 .636 r
.44623 .39686 .45205 .4325 .46354 .42064 .45763 .38708 Mtetra
.648 .479 .641 r
.45763 .38708 .46354 .42064 .47503 .40802 .46904 .3764 Mtetra
.639 .478 .649 r
.46904 .3764 .47503 .40802 .48647 .39785 .48043 .3674 Mtetra
.622 .471 .656 r
.48043 .3674 .48647 .39785 .4979 .39035 .4918 .36038 Mtetra
.612 .466 .659 r
.4918 .36038 .4979 .39035 .50935 .38381 .5032 .35439 Mtetra
.609 .466 .662 r
.5032 .35439 .50935 .38381 .52082 .37761 .51462 .34876 Mtetra
.62 .475 .663 r
.51462 .34876 .52082 .37761 .53232 .37096 .52608 .34226 Mtetra
.629 .482 .663 r
.52608 .34226 .53232 .37096 .54385 .36394 .53757 .33501 Mtetra
.628 .48 .662 r
.53757 .33501 .54385 .36394 .5554 .35715 .54908 .32778 Mtetra
.626 .477 .66 r
.54908 .32778 .5554 .35715 .56698 .35042 .56061 .32059 Mtetra
.626 .476 .658 r
.56061 .32059 .56698 .35042 .57859 .34329 .57217 .31324 Mtetra
.626 .475 .657 r
.57217 .31324 .57859 .34329 .59022 .33585 .58375 .30586 Mtetra
.623 .474 .658 r
.58375 .30586 .59022 .33585 .60186 .32835 .59536 .29871 Mtetra
.621 .473 .66 r
.59536 .29871 .60186 .32835 .61353 .32082 .607 .29185 Mtetra
.62 .475 .663 r
.607 .29185 .61353 .32082 .62522 .31326 .61869 .28528 Mtetra
.618 .478 .669 r
.61869 .28528 .62522 .31326 .63694 .30579 .63041 .27907 Mtetra
.616 .482 .676 r
.63041 .27907 .63694 .30579 .64869 .29853 .64218 .27333 Mtetra
.614 .488 .685 r
.64218 .27333 .64869 .29853 .66048 .29156 .65402 .26806 Mtetra
.612 .496 .697 r
.65402 .26806 .66048 .29156 .67232 .28498 .66591 .26326 Mtetra
.611 .507 .712 r
.66591 .26326 .67232 .28498 .68421 .2788 .67788 .25893 Mtetra
.609 .52 .729 r
.67788 .25893 .68421 .2788 .69616 .27309 .68992 .25504 Mtetra
.607 .536 .748 r
.68992 .25504 .69616 .27309 .70818 .26782 .70204 .25154 Mtetra
.605 .554 .771 r
.70204 .25154 .70818 .26782 .72027 .263 .71423 .24838 Mtetra
.603 .575 .795 r
.71423 .24838 .72027 .263 .73243 .25856 .72651 .24549 Mtetra
.601 .599 .822 r
.72651 .24549 .73243 .25856 .74467 .25443 .73886 .24279 Mtetra
.599 .626 .849 r
.73886 .24279 .74467 .25443 .75698 .25054 .75129 .24022 Mtetra
.596 .655 .878 r
.75129 .24022 .75698 .25054 .76936 .24679 .7638 .23772 Mtetra
.594 .687 .907 r
.7638 .23772 .76936 .24679 .7818 .24311 .77637 .23521 Mtetra
.734 .766 .878 r
.11732 .45366 .12449 .45992 .13451 .45484 .12745 .44786 Mtetra
.73 .745 .864 r
.12745 .44786 .13451 .45484 .14455 .44976 .13761 .44199 Mtetra
.724 .725 .85 r
.13761 .44199 .14455 .44976 .15462 .44473 .14779 .4361 Mtetra
.717 .703 .836 r
.14779 .4361 .15462 .44473 .1647 .43983 .158 .43022 Mtetra
.708 .68 .821 r
.158 .43022 .1647 .43983 .17478 .43511 .16822 .42438 Mtetra
.697 .655 .805 r
.16822 .42438 .17478 .43511 .18487 .43065 .17845 .41865 Mtetra
.684 .63 .789 r
.17845 .41865 .18487 .43065 .19496 .42653 .18869 .4131 Mtetra
.67 .604 .772 r
.18869 .4131 .19496 .42653 .20504 .42277 .19893 .40781 Mtetra
.655 .578 .756 r
.19893 .40781 .20504 .42277 .21512 .41946 .20917 .40285 Mtetra
.639 .552 .741 r
.20917 .40285 .21512 .41946 .2252 .41658 .21939 .39827 Mtetra
.624 .529 .726 r
.21939 .39827 .2252 .41658 .23528 .41419 .22961 .39415 Mtetra
.609 .507 .713 r
.22961 .39415 .23528 .41419 .24536 .41225 .23982 .39049 Mtetra
.596 .487 .701 r
.23982 .39049 .24536 .41225 .25545 .41077 .25003 .38733 Mtetra
.585 .471 .69 r
.25003 .38733 .25545 .41077 .26557 .40965 .26024 .38456 Mtetra
.577 .457 .68 r
.26024 .38456 .26557 .40965 .27572 .40883 .27048 .3821 Mtetra
.571 .446 .671 r
.27048 .3821 .27572 .40883 .2859 .4083 .28075 .37988 Mtetra
.567 .436 .662 r
.28075 .37988 .2859 .4083 .29613 .40801 .29105 .37779 Mtetra
.566 .429 .654 r
.29105 .37779 .29613 .40801 .30642 .40771 .30141 .3756 Mtetra
.567 .424 .647 r
.30141 .3756 .30642 .40771 .31678 .40726 .31185 .37314 Mtetra
.567 .419 .639 r
.31185 .37314 .31678 .40726 .3272 .40686 .32234 .37051 Mtetra
.567 .413 .632 r
.32234 .37051 .3272 .40686 .33768 .40649 .33289 .36766 Mtetra
.573 .412 .625 r
.33289 .36766 .33768 .40649 .34826 .4054 .34353 .36395 Mtetra
.579 .412 .619 r
.34353 .36395 .34826 .4054 .35895 .40346 .35427 .35931 Mtetra
.574 .403 .613 r
.35427 .35931 .35895 .40346 .36968 .40188 .36504 .3549 Mtetra
.565 .392 .607 r
.36504 .3549 .36968 .40188 .38041 .40133 .37581 .35122 Mtetra
.554 .381 .601 r
.37581 .35122 .38041 .40133 .39113 .40275 .38658 .3485 Mtetra
.546 .37 .594 r
.38658 .3485 .39113 .40275 .40186 .40587 .39736 .34657 Mtetra
.547 .365 .587 r
.39736 .34657 .40186 .40587 .41272 .40812 .40822 .34426 Mtetra
.55 .364 .582 r
.40822 .34426 .41272 .40812 .42373 .40809 .41916 .34114 Mtetra
.553 .364 .579 r
.41916 .34114 .42373 .40809 .43491 .40434 .43017 .33731 Mtetra
.557 .367 .579 r
.43017 .33731 .43491 .40434 .44623 .39686 .44124 .33277 Mtetra
.564 .374 .583 r
.44124 .33277 .44623 .39686 .45763 .38708 .45238 .32741 Mtetra
.569 .382 .588 r
.45238 .32741 .45763 .38708 .46904 .3764 .46355 .32166 Mtetra
.568 .386 .595 r
.46355 .32166 .46904 .3764 .48043 .3674 .47475 .31671 Mtetra
.564 .387 .601 r
.47475 .31671 .48043 .3674 .4918 .36038 .48597 .31271 Mtetra
.56 .389 .607 r
.48597 .31271 .4918 .36038 .5032 .35439 .49723 .30946 Mtetra
.56 .393 .612 r
.49723 .30946 .5032 .35439 .51462 .34876 .50854 .30644 Mtetra
.57 .405 .619 r
.50854 .30644 .51462 .34876 .52608 .34226 .5199 .30247 Mtetra
.581 .418 .625 r
.5199 .30247 .52608 .34226 .53757 .33501 .53131 .29764 Mtetra
.587 .427 .632 r
.53131 .29764 .53757 .33501 .54908 .32778 .54276 .29257 Mtetra
.592 .436 .639 r
.54276 .29257 .54908 .32778 .56061 .32059 .55425 .28733 Mtetra
.598 .446 .646 r
.55425 .28733 .56061 .32059 .57217 .31324 .56577 .28181 Mtetra
.603 .455 .653 r
.56577 .28181 .57217 .31324 .58375 .30586 .57733 .27617 Mtetra
.605 .462 .66 r
.57733 .27617 .58375 .30586 .59536 .29871 .58893 .27066 Mtetra
.606 .469 .669 r
.58893 .27066 .59536 .29871 .607 .29185 .60057 .26539 Mtetra
.606 .476 .678 r
.60057 .26539 .607 .29185 .61869 .28528 .61227 .26043 Mtetra
.605 .484 .688 r
.61227 .26043 .61869 .28528 .63041 .27907 .62402 .25587 Mtetra
.602 .491 .7 r
.62402 .25587 .63041 .27907 .64218 .27333 .63583 .25182 Mtetra
.598 .5 .714 r
.63583 .25182 .64218 .27333 .65402 .26806 .64771 .24824 Mtetra
.595 .512 .731 r
.64771 .24824 .65402 .26806 .66591 .26326 .65967 .24513 Mtetra
.591 .525 .749 r
.65967 .24513 .66591 .26326 .67788 .25893 .67171 .24242 Mtetra
.587 .541 .77 r
.67171 .24242 .67788 .25893 .68992 .25504 .68383 .24006 Mtetra
.583 .558 .793 r
.68383 .24006 .68992 .25504 .70204 .25154 .69604 .23796 Mtetra
.579 .578 .816 r
.69604 .23796 .70204 .25154 .71423 .24838 .70832 .23605 Mtetra
.575 .599 .84 r
.70832 .23605 .71423 .24838 .72651 .24549 .72068 .23427 Mtetra
.572 .621 .863 r
.72068 .23427 .72651 .24549 .73886 .24279 .73313 .23253 Mtetra
.569 .643 .884 r
.73313 .23253 .73886 .24279 .75129 .24022 .74564 .23081 Mtetra
.565 .664 .904 r
.74564 .23081 .75129 .24022 .7638 .23772 .75824 .22906 Mtetra
.562 .685 .922 r
.75824 .22906 .7638 .23772 .77637 .23521 .7709 .22725 Mtetra
.738 .766 .875 r
.1101 .44736 .11732 .45366 .12745 .44786 .12028 .44137 Mtetra
.739 .762 .871 r
.12028 .44137 .12745 .44786 .13761 .44199 .13049 .43527 Mtetra
.74 .756 .866 r
.13049 .43527 .13761 .44199 .14779 .4361 .14073 .42908 Mtetra
.739 .749 .86 r
.14073 .42908 .14779 .4361 .158 .43022 .151 .4228 Mtetra
.738 .739 .852 r
.151 .4228 .158 .43022 .16822 .42438 .16131 .41641 Mtetra
.734 .725 .843 r
.16131 .41641 .16822 .42438 .17845 .41865 .17164 .41 Mtetra
.728 .708 .832 r
.17164 .41 .17845 .41865 .18869 .4131 .18199 .4036 Mtetra
.718 .688 .82 r
.18199 .4036 .18869 .4131 .19893 .40781 .19234 .39731 Mtetra
.706 .665 .807 r
.19234 .39731 .19893 .40781 .20917 .40285 .2027 .3912 Mtetra
.693 .641 .793 r
.2027 .3912 .20917 .40285 .21939 .39827 .21306 .38533 Mtetra
.677 .615 .779 r
.21306 .38533 .21939 .39827 .22961 .39415 .22342 .3798 Mtetra
.662 .59 .764 r
.22342 .3798 .22961 .39415 .23982 .39049 .23377 .37461 Mtetra
.646 .565 .749 r
.23377 .37461 .23982 .39049 .25003 .38733 .24411 .3698 Mtetra
.634 .542 .733 r
.24411 .3698 .25003 .38733 .26024 .38456 .25446 .36524 Mtetra
.624 .522 .718 r
.25446 .36524 .26024 .38456 .27048 .3821 .26484 .36083 Mtetra
.616 .504 .703 r
.26484 .36083 .27048 .3821 .28075 .37988 .27525 .35645 Mtetra
.611 .488 .688 r
.27525 .35645 .28075 .37988 .29105 .37779 .2857 .35198 Mtetra
.608 .475 .674 r
.2857 .35198 .29105 .37779 .30141 .3756 .2962 .34724 Mtetra
.606 .463 .661 r
.2962 .34724 .30141 .3756 .31185 .37314 .30677 .3421 Mtetra
.603 .452 .649 r
.30677 .3421 .31185 .37314 .32234 .37051 .31738 .33669 Mtetra
.601 .443 .639 r
.31738 .33669 .32234 .37051 .33289 .36766 .32805 .33097 Mtetra
.602 .437 .63 r
.32805 .33097 .33289 .36766 .34353 .36395 .33878 .32454 Mtetra
.604 .432 .622 r
.33878 .32454 .34353 .36395 .35427 .35931 .34959 .31736 Mtetra
.6 .425 .616 r
.34959 .31736 .35427 .35931 .36504 .3549 .36041 .31017 Mtetra
.593 .416 .61 r
.36041 .31017 .36504 .3549 .37581 .35122 .37123 .30322 Mtetra
.59 .409 .604 r
.37123 .30322 .37581 .35122 .38658 .3485 .38209 .29608 Mtetra
.586 .4 .596 r
.38209 .29608 .38658 .3485 .39736 .34657 .39297 .2888 Mtetra
.579 .389 .589 r
.39297 .2888 .39736 .34657 .40822 .34426 .40387 .28176 Mtetra
.569 .378 .583 r
.40387 .28176 .40822 .34426 .41916 .34114 .41475 .27554 Mtetra
.553 .364 .578 r
.41475 .27554 .41916 .34114 .43017 .33731 .42559 .27164 Mtetra
.538 .352 .577 r
.42559 .27164 .43017 .33731 .44124 .33277 .4364 .27005 Mtetra
.533 .351 .58 r
.4364 .27005 .44124 .33277 .45238 .32741 .44726 .26929 Mtetra
.532 .355 .586 r
.44726 .26929 .45238 .32741 .46355 .32166 .45817 .26879 Mtetra
.534 .362 .594 r
.45817 .26879 .46355 .32166 .47475 .31671 .46916 .26815 Mtetra
.537 .37 .602 r
.46916 .26815 .47475 .31671 .48597 .31271 .48021 .26734 Mtetra
.536 .374 .609 r
.48021 .26734 .48597 .31271 .49723 .30946 .49133 .26677 Mtetra
.536 .38 .615 r
.49133 .26677 .49723 .30946 .50854 .30644 .50253 .26621 Mtetra
.545 .391 .622 r
.50253 .26621 .50854 .30644 .5199 .30247 .51379 .26488 Mtetra
.554 .403 .63 r
.51379 .26488 .5199 .30247 .53131 .29764 .52512 .26285 Mtetra
.56 .414 .64 r
.52512 .26285 .53131 .29764 .54276 .29257 .53652 .26052 Mtetra
.566 .427 .651 r
.53652 .26052 .54276 .29257 .55425 .28733 .54797 .2579 Mtetra
.575 .442 .663 r
.54797 .2579 .55425 .28733 .56577 .28181 .55947 .25488 Mtetra
.582 .458 .676 r
.55947 .25488 .56577 .28181 .57733 .27617 .57103 .25159 Mtetra
.588 .473 .69 r
.57103 .25159 .57733 .27617 .58893 .27066 .58264 .24821 Mtetra
.592 .489 .706 r
.58264 .24821 .58893 .27066 .60057 .26539 .5943 .24485 Mtetra
.594 .504 .722 r
.5943 .24485 .60057 .26539 .61227 .26043 .60603 .24166 Mtetra
.594 .519 .74 r
.60603 .24166 .61227 .26043 .62402 .25587 .61782 .23871 Mtetra
.589 .533 .76 r
.61782 .23871 .62402 .25587 .63583 .25182 .62968 .23616 Mtetra
.584 .548 .781 r
.62968 .23616 .63583 .25182 .64771 .24824 .64162 .23397 Mtetra
.577 .564 .803 r
.64162 .23397 .64771 .24824 .65967 .24513 .65364 .23212 Mtetra
.569 .582 .826 r
.65364 .23212 .65967 .24513 .67171 .24242 .66575 .23053 Mtetra
.562 .6 .849 r
.66575 .23053 .67171 .24242 .68383 .24006 .67793 .22914 Mtetra
.555 .618 .87 r
.67793 .22914 .68383 .24006 .69604 .23796 .6902 .22786 Mtetra
.55 .636 .889 r
.6902 .22786 .69604 .23796 .70832 .23605 .70255 .2266 Mtetra
.547 .653 .905 r
.70255 .2266 .70832 .23605 .72068 .23427 .71497 .22532 Mtetra
.547 .668 .917 r
.71497 .22532 .72068 .23427 .73313 .23253 .72747 .22394 Mtetra
.547 .68 .926 r
.72747 .22394 .73313 .23253 .74564 .23081 .74003 .22246 Mtetra
.548 .689 .932 r
.74003 .22246 .74564 .23081 .75824 .22906 .75267 .2209 Mtetra
.55 .697 .936 r
.75267 .2209 .75824 .22906 .7709 .22725 .76539 .21923 Mtetra
.724 .764 .885 r
.10283 .44102 .1101 .44736 .12028 .44137 .11296 .43555 Mtetra
.73 .782 .894 r
.11296 .43555 .12028 .44137 .13049 .43527 .12314 .42997 Mtetra
.737 .8 .903 r
.12314 .42997 .13049 .43527 .14073 .42908 .13335 .42426 Mtetra
.743 .817 .91 r
.13335 .42426 .14073 .42908 .151 .4228 .1436 .4184 Mtetra
.75 .833 .915 r
.1436 .4184 .151 .4228 .16131 .41641 .1539 .41236 Mtetra
.755 .845 .919 r
.1539 .41236 .16131 .41641 .17164 .41 .16424 .40618 Mtetra
.759 .855 .921 r
.16424 .40618 .17164 .41 .18199 .4036 .17461 .39989 Mtetra
.761 .859 .923 r
.17461 .39989 .18199 .4036 .19234 .39731 .18501 .39355 Mtetra
.76 .859 .923 r
.18501 .39355 .19234 .39731 .2027 .3912 .19543 .38722 Mtetra
.757 .853 .921 r
.19543 .38722 .2027 .3912 .21306 .38533 .20586 .38094 Mtetra
.753 .839 .917 r
.20586 .38094 .21306 .38533 .22342 .3798 .21631 .37476 Mtetra
.747 .818 .908 r
.21631 .37476 .22342 .3798 .23377 .37461 .22677 .36865 Mtetra
.739 .789 .893 r
.22677 .36865 .23377 .37461 .24411 .3698 .23725 .36264 Mtetra
.73 .753 .87 r
.23725 .36264 .24411 .3698 .25446 .36524 .24775 .35662 Mtetra
.72 .714 .843 r
.24775 .35662 .25446 .36524 .26484 .36083 .25829 .35054 Mtetra
.707 .675 .816 r
.25829 .35054 .26484 .36083 .27525 .35645 .26885 .34443 Mtetra
.694 .64 .791 r
.26885 .34443 .27525 .35645 .2857 .35198 .27943 .33832 Mtetra
.681 .611 .771 r
.27943 .33832 .2857 .35198 .2962 .34724 .29004 .33229 Mtetra
.67 .59 .757 r
.29004 .33229 .2962 .34724 .30677 .3421 .30066 .32642 Mtetra
.659 .576 .751 r
.30066 .32642 .30677 .3421 .31738 .33669 .31128 .32088 Mtetra
.652 .571 .752 r
.31128 .32088 .31738 .33669 .32805 .33097 .32191 .3157 Mtetra
.657 .58 .757 r
.32191 .3157 .32805 .33097 .33878 .32454 .33258 .31038 Mtetra
.67 .601 .769 r
.33258 .31038 .33878 .32454 .34959 .31736 .3433 .3047 Mtetra
.687 .63 .786 r
.3433 .3047 .34959 .31736 .36041 .31017 .35407 .29866 Mtetra
.707 .657 .798 r
.35407 .29866 .36041 .31017 .37123 .30322 .3649 .29205 Mtetra
.737 .675 .79 r
.3649 .29205 .37123 .30322 .38209 .29608 .37582 .28396 Mtetra
.749 .665 .768 r
.37582 .28396 .38209 .29608 .39297 .2888 .38681 .27452 Mtetra
.727 .628 .747 r
.38681 .27452 .39297 .2888 .40387 .28176 .39781 .26528 Mtetra
.69 .587 .735 r
.39781 .26528 .40387 .28176 .41475 .27554 .40875 .25749 Mtetra
.617 .531 .735 r
.40875 .25749 .41475 .27554 .42559 .27164 .41958 .25355 Mtetra
.532 .481 .745 r
.41958 .25355 .42559 .27164 .4364 .27005 .43033 .25346 Mtetra
.489 .472 .766 r
.43033 .25346 .4364 .27005 .44726 .26929 .44111 .25484 Mtetra
.471 .492 .799 r
.44111 .25484 .44726 .26929 .45817 .26879 .45197 .25644 Mtetra
.508 .551 .835 r
.45197 .25644 .45817 .26879 .46916 .26815 .46294 .2567 Mtetra
.56 .597 .847 r
.46294 .2567 .46916 .26815 .48021 .26734 .47401 .25547 Mtetra
.579 .599 .837 r
.47401 .25547 .48021 .26734 .49133 .26677 .48516 .25367 Mtetra
.588 .582 .813 r
.48516 .25367 .49133 .26677 .50253 .26621 .49636 .25153 Mtetra
.595 .562 .787 r
.49636 .25153 .50253 .26621 .51379 .26488 .50764 .249 Mtetra
.595 .547 .771 r
.50764 .249 .51379 .26488 .52512 .26285 .51896 .24636 Mtetra
.585 .535 .765 r
.51896 .24636 .52512 .26285 .53652 .26052 .53035 .24408 Mtetra
.577 .531 .767 r
.53035 .24408 .53652 .26052 .54797 .2579 .5418 .24213 Mtetra
.574 .538 .777 r
.5418 .24213 .54797 .2579 .55947 .25488 .55332 .24036 Mtetra
.572 .555 .796 r
.55332 .24036 .55947 .25488 .57103 .25159 .5649 .23867 Mtetra
.573 .582 .824 r
.5649 .23867 .57103 .25159 .58264 .24821 .57655 .23699 Mtetra
.572 .616 .857 r
.57655 .23699 .58264 .24821 .5943 .24485 .58826 .23528 Mtetra
.57 .655 .894 r
.58826 .23528 .5943 .24485 .60603 .24166 .60005 .23352 Mtetra
.561 .693 .929 r
.60005 .23352 .60603 .24166 .61782 .23871 .6119 .23175 Mtetra
.543 .725 .958 r
.6119 .23175 .61782 .23871 .62968 .23616 .62383 .23008 Mtetra
.521 .748 .978 r
.62383 .23008 .62968 .23616 .64162 .23397 .63583 .2285 Mtetra
.499 .761 .989 r
.63583 .2285 .64162 .23397 .65364 .23212 .64791 .22703 Mtetra
.483 .768 .994 r
.64791 .22703 .65364 .23212 .66575 .23053 .66006 .22561 Mtetra
.475 .772 .996 r
.66006 .22561 .66575 .23053 .67793 .22914 .67229 .2242 Mtetra
.476 .773 .996 r
.67229 .2242 .67793 .22914 .6902 .22786 .68459 .22275 Mtetra
.488 .773 .995 r
.68459 .22275 .6902 .22786 .70255 .2266 .69697 .2212 Mtetra
.504 .771 .991 r
.69697 .2212 .70255 .2266 .71497 .22532 .70941 .2195 Mtetra
.525 .766 .985 r
.70941 .2195 .71497 .22532 .72747 .22394 .72192 .21763 Mtetra
.542 .757 .976 r
.72192 .21763 .72747 .22394 .74003 .22246 .73449 .21559 Mtetra
.557 .745 .964 r
.73449 .21559 .74003 .22246 .75267 .2209 .74712 .21342 Mtetra
.569 .731 .951 r
.74712 .21342 .75267 .2209 .76539 .21923 .75983 .21113 Mtetra
.692 .759 .903 r
.09551 .43462 .10283 .44102 .11296 .43555 .10553 .43019 Mtetra
.698 .794 .924 r
.10553 .43019 .11296 .43555 .12314 .42997 .1156 .42564 Mtetra
.703 .831 .944 r
.1156 .42564 .12314 .42997 .13335 .42426 .12572 .42096 Mtetra
.706 .868 .959 r
.12572 .42096 .13335 .42426 .1436 .4184 .13588 .4161 Mtetra
.705 .903 .967 r
.13588 .4161 .1436 .4184 .1539 .41236 .14611 .41102 Mtetra
.696 .932 .966 r
.14611 .41102 .1539 .41236 .16424 .40618 .15638 .40575 Mtetra
.681 .952 .954 r
.15638 .40575 .16424 .40618 .17461 .39989 .16671 .40027 Mtetra
.658 .961 .932 r
.16671 .40027 .17461 .39989 .18501 .39355 .17708 .39462 Mtetra
.631 .96 .905 r
.17708 .39462 .18501 .39355 .19543 .38722 .18749 .38881 Mtetra
.611 .956 .878 r
.18749 .38881 .19543 .38722 .20586 .38094 .19795 .38283 Mtetra
.601 .952 .86 r
.19795 .38283 .20586 .38094 .21631 .37476 .20845 .37669 Mtetra
.612 .956 .858 r
.20845 .37669 .21631 .37476 .22677 .36865 .21899 .37035 Mtetra
.641 .966 .872 r
.21899 .37035 .22677 .36865 .23725 .36264 .22957 .36378 Mtetra
.684 .977 .896 r
.22957 .36378 .23725 .36264 .24775 .35662 .24019 .357 Mtetra
.728 .978 .918 r
.24019 .357 .24775 .35662 .25829 .35054 .25086 .34999 Mtetra
.751 .965 .934 r
.25086 .34999 .25829 .35054 .26885 .34443 .26154 .34303 Mtetra
.756 .945 .943 r
.26154 .34303 .26885 .34443 .27943 .33832 .27222 .33629 Mtetra
.738 .927 .953 r
.27222 .33629 .27943 .33832 .29004 .33229 .28288 .33013 Mtetra
.697 .919 .968 r
.28288 .33013 .29004 .33229 .30066 .32642 .2935 .32482 Mtetra
.613 .917 .978 r
.2935 .32482 .30066 .32642 .31128 .32088 .30407 .32056 Mtetra
.434 .868 .919 r
.30407 .32056 .31128 .32088 .32191 .3157 .31462 .3174 Mtetra
.187 .713 .702 r
.31462 .3174 .32191 .3157 .33258 .31038 .32517 .31473 Mtetra
.041 0 0 r
.32517 .31473 .33258 .31038 .3433 .3047 .33578 .3121 Mtetra
.156 0 0 r
.33578 .3121 .3433 .3047 .35407 .29866 .34647 .30882 Mtetra
.177 0 0 r
.34647 .30882 .35407 .29866 .3649 .29205 .35728 .30427 Mtetra
.098 0 0 r
.35728 .30427 .3649 .29205 .37582 .28396 .36825 .29716 Mtetra
0 0 0 r
.36825 .29716 .37582 .28396 .38681 .27452 .37936 .28762 Mtetra
.37936 .28762 .38681 .27452 .39781 .26528 .39048 .27789 Mtetra
.054 0 0 r
.39048 .27789 .39781 .26528 .40875 .25749 .40154 .26961 Mtetra
.269 0 .055 r
.40154 .26961 .40875 .25749 .41958 .25355 .41246 .26565 Mtetra
.44 .02 .144 r
.41246 .26565 .41958 .25355 .43033 .25346 .42329 .26603 Mtetra
.487 .071 .176 r
.42329 .26603 .43033 .25346 .44111 .25484 .43414 .26787 Mtetra
.483 .071 .182 r
.43414 .26787 .44111 .25484 .45197 .25644 .44509 .26954 Mtetra
.41 0 .146 r
.44509 .26954 .45197 .25644 .46294 .2567 .45617 .26878 Mtetra
.3 0 .07 r
.45617 .26878 .46294 .2567 .47401 .25547 .46738 .26545 Mtetra
.186 0 0 r
.46738 .26545 .47401 .25547 .48516 .25367 .47865 .26083 Mtetra
.022 0 0 r
.47865 .26083 .48516 .25367 .49636 .25153 .48997 .25556 Mtetra
0 0 0 r
.48997 .25556 .49636 .25153 .50764 .249 .50133 .25032 Mtetra
.393 .848 .789 r
.50133 .25032 .50764 .249 .51896 .24636 .51273 .24558 Mtetra
.458 .879 .926 r
.51273 .24558 .51896 .24636 .53035 .24408 .52417 .24195 Mtetra
.45 .849 .975 r
.52417 .24195 .53035 .24408 .5418 .24213 .53567 .23938 Mtetra
.407 .809 .982 r
.53567 .23938 .5418 .24213 .55332 .24036 .54723 .23768 Mtetra
.343 .777 .969 r
.54723 .23768 .55332 .24036 .5649 .23867 .55886 .23658 Mtetra
.274 .751 .934 r
.55886 .23658 .5649 .23867 .57655 .23699 .57057 .23573 Mtetra
.198 .717 .873 r
.57057 .23573 .57655 .23699 .58826 .23528 .58236 .23491 Mtetra
.14 .685 .799 r
.58236 .23491 .58826 .23528 .60005 .23352 .59422 .23389 Mtetra
.095 .652 .73 r
.59422 .23389 .60005 .23352 .6119 .23175 .60615 .23264 Mtetra
0 0 0 r
.60615 .23264 .6119 .23175 .62383 .23008 .61814 .23117 Mtetra
.61814 .23117 .62383 .23008 .63583 .2285 .63021 .2295 Mtetra
.63021 .2295 .63583 .2285 .64791 .22703 .64234 .22767 Mtetra
.139 .684 .728 r
.64234 .22767 .64791 .22703 .66006 .22561 .65453 .22566 Mtetra
.205 .732 .794 r
.65453 .22566 .66006 .22561 .67229 .2242 .66679 .2235 Mtetra
.287 .784 .868 r
.66679 .2235 .67229 .2242 .68459 .22275 .67911 .22116 Mtetra
.375 .826 .934 r
.67911 .22116 .68459 .22275 .69697 .2212 .69149 .21861 Mtetra
.456 .848 .979 r
.69149 .21861 .69697 .2212 .70941 .2195 .70392 .21586 Mtetra
.523 .848 .998 r
.70392 .21586 .70941 .2195 .72192 .21763 .71642 .21287 Mtetra
.568 .83 .995 r
.71642 .21287 .72192 .21763 .73449 .21559 .72896 .20971 Mtetra
.597 .801 .978 r
.72896 .20971 .73449 .21559 .74712 .21342 .74156 .2064 Mtetra
.613 .769 .954 r
.74156 .2064 .74712 .21342 .75983 .21113 .75422 .20298 Mtetra
.639 .747 .927 r
.08813 .42819 .09551 .43462 .10553 .43019 .098 .42507 Mtetra
.637 .792 .957 r
.098 .42507 .10553 .43019 .1156 .42564 .10792 .42187 Mtetra
.628 .84 .981 r
.10792 .42187 .1156 .42564 .12572 .42096 .1179 .41855 Mtetra
.607 .882 .991 r
.1179 .41855 .12572 .42096 .13588 .4161 .12793 .41507 Mtetra
.569 .909 .974 r
.12793 .41507 .13588 .4161 .14611 .41102 .13803 .41138 Mtetra
.505 .905 .919 r
.13803 .41138 .14611 .41102 .15638 .40575 .14819 .40747 Mtetra
.422 .867 .825 r
.14819 .40747 .15638 .40575 .16671 .40027 .15841 .4033 Mtetra
.331 .801 .709 r
.15841 .4033 .16671 .40027 .17708 .39462 .1687 .39888 Mtetra
0 0 0 r
.1687 .39888 .17708 .39462 .18749 .38881 .17906 .39418 Mtetra
.17906 .39418 .18749 .38881 .19795 .38283 .18947 .38918 Mtetra
.18947 .38918 .19795 .38283 .20845 .37669 .19996 .38385 Mtetra
.19996 .38385 .20845 .37669 .21899 .37035 .2105 .37822 Mtetra
.2105 .37822 .21899 .37035 .22957 .36378 .22109 .3723 Mtetra
.22109 .3723 .22957 .36378 .24019 .357 .23173 .36621 Mtetra
.23173 .36621 .24019 .357 .25086 .34999 .2424 .36006 Mtetra
.054 0 0 r
.2424 .36006 .25086 .34999 .26154 .34303 .25307 .35415 Mtetra
.133 0 0 r
.25307 .35415 .26154 .34303 .27222 .33629 .26373 .34871 Mtetra
.215 0 .021 r
.26373 .34871 .27222 .33629 .28288 .33013 .27437 .34395 Mtetra
.289 0 .092 r
.27437 .34395 .28288 .33013 .2935 .32482 .28498 .34004 Mtetra
.345 0 .148 r
.28498 .34004 .2935 .32482 .30407 .32056 .29557 .33698 Mtetra
.385 .004 .187 r
.29557 .33698 .30407 .32056 .31462 .3174 .30615 .33473 Mtetra
.406 .03 .209 r
.30615 .33473 .31462 .3174 .32517 .31473 .31675 .33292 Mtetra
.413 .043 .223 r
.31675 .33292 .32517 .31473 .33578 .3121 .32741 .33116 Mtetra
.403 .039 .228 r
.32741 .33116 .33578 .3121 .34647 .30882 .33815 .32882 Mtetra
.377 .02 .226 r
.33815 .32882 .34647 .30882 .35728 .30427 .34902 .32526 Mtetra
.312 0 .207 r
.34902 .32526 .35728 .30427 .36825 .29716 .36008 .31907 Mtetra
.247 0 .189 r
.36008 .31907 .36825 .29716 .37936 .28762 .37128 .31032 Mtetra
.247 0 .197 r
.37128 .31032 .37936 .28762 .39048 .27789 .38252 .30117 Mtetra
.29 0 .222 r
.38252 .30117 .39048 .27789 .40154 .26961 .39371 .2932 Mtetra
.393 .054 .267 r
.39371 .2932 .40154 .26961 .41246 .26565 .40477 .28924 Mtetra
.474 .128 .298 r
.40477 .28924 .41246 .26565 .42329 .26603 .41573 .28929 Mtetra
.494 .145 .303 r
.41573 .28929 .42329 .26603 .43414 .26787 .42673 .29053 Mtetra
.486 .135 .295 r
.42673 .29053 .43414 .26787 .44509 .26954 .43782 .2914 Mtetra
.434 .082 .268 r
.43782 .2914 .44509 .26954 .45617 .26878 .44906 .2897 Mtetra
.368 .018 .233 r
.44906 .2897 .45617 .26878 .46738 .26545 .46041 .28536 Mtetra
.327 0 .206 r
.46041 .28536 .46738 .26545 .47865 .26083 .47183 .27978 Mtetra
.3 0 .184 r
.47183 .27978 .47865 .26083 .48997 .25556 .4833 .2736 Mtetra
.291 0 .169 r
.4833 .2736 .48997 .25556 .50133 .25032 .49479 .26747 Mtetra
.294 0 .158 r
.49479 .26747 .50133 .25032 .51273 .24558 .50632 .26178 Mtetra
.308 0 .15 r
.50632 .26178 .51273 .24558 .52417 .24195 .51788 .2569 Mtetra
.321 0 .134 r
.51788 .2569 .52417 .24195 .53567 .23938 .52949 .25289 Mtetra
.331 0 .111 r
.52949 .25289 .53567 .23938 .54723 .23768 .54115 .24974 Mtetra
.336 0 .081 r
.54115 .24974 .54723 .23768 .55886 .23658 .55287 .24729 Mtetra
.333 0 .044 r
.55287 .24729 .55886 .23658 .57057 .23573 .56467 .24532 Mtetra
.323 0 .005 r
.56467 .24532 .57057 .23573 .58236 .23491 .57653 .2436 Mtetra
.301 0 0 r
.57653 .2436 .58236 .23491 .59422 .23389 .58847 .24182 Mtetra
.275 0 0 r
.58847 .24182 .59422 .23389 .60615 .23264 .60047 .23988 Mtetra
.239 0 0 r
.60047 .23988 .60615 .23264 .61814 .23117 .61253 .23764 Mtetra
.194 0 0 r
.61253 .23764 .61814 .23117 .63021 .2295 .62466 .23509 Mtetra
.135 0 0 r
.62466 .23509 .63021 .2295 .64234 .22767 .63683 .23221 Mtetra
.058 0 0 r
.63683 .23221 .64234 .22767 .65453 .22566 .64906 .22902 Mtetra
0 0 0 r
.64906 .22902 .65453 .22566 .66679 .2235 .66134 .22554 Mtetra
.66134 .22554 .66679 .2235 .67911 .22116 .67367 .22179 Mtetra
.319 .806 .788 r
.67367 .22179 .67911 .22116 .69149 .21861 .68604 .21778 Mtetra
.456 .882 .908 r
.68604 .21778 .69149 .21861 .70392 .21586 .69846 .21352 Mtetra
.562 .907 .973 r
.69846 .21352 .70392 .21586 .71642 .21287 .71092 .20905 Mtetra
.625 .888 .988 r
.71092 .20905 .71642 .21287 .72896 .20971 .72342 .2044 Mtetra
.657 .848 .974 r
.72342 .2044 .72896 .20971 .74156 .2064 .73597 .19962 Mtetra
.669 .802 .946 r
.73597 .19962 .74156 .2064 .75422 .20298 .74857 .19475 Mtetra
.57 .726 .948 r
.0807 .4217 .08813 .42819 .098 .42507 .09041 .41991 Mtetra
.553 .769 .978 r
.09041 .41991 .098 .42507 .10792 .42187 .10017 .41807 Mtetra
.524 .81 .998 r
.10017 .41807 .10792 .42187 .1179 .41855 .11 .41615 Mtetra
.476 .838 .993 r
.11 .41615 .1179 .41855 .12793 .41507 .11988 .41411 Mtetra
.404 .84 .946 r
.11988 .41411 .12793 .41507 .13803 .41138 .12983 .41189 Mtetra
.309 .801 .847 r
.12983 .41189 .13803 .41138 .14819 .40747 .13986 .40945 Mtetra
.205 .726 .711 r
.13986 .40945 .14819 .40747 .15841 .4033 .14996 .40675 Mtetra
0 0 0 r
.14996 .40675 .15841 .4033 .1687 .39888 .16014 .40376 Mtetra
.16014 .40376 .1687 .39888 .17906 .39418 .17041 .40042 Mtetra
.02 0 0 r
.17041 .40042 .17906 .39418 .18947 .38918 .18075 .39673 Mtetra
.061 0 0 r
.18075 .39673 .18947 .38918 .19996 .38385 .19117 .39265 Mtetra
.1 0 0 r
.19117 .39265 .19996 .38385 .2105 .37822 .20166 .38828 Mtetra
.138 0 0 r
.20166 .38828 .2105 .37822 .22109 .3723 .2122 .3837 Mtetra
.187 0 0 r
.2122 .3837 .22109 .3723 .23173 .36621 .22278 .37915 Mtetra
.241 0 .039 r
.22278 .37915 .23173 .36621 .2424 .36006 .23338 .3748 Mtetra
.297 0 .107 r
.23338 .3748 .2424 .36006 .25307 .35415 .24397 .37089 Mtetra
.347 0 .166 r
.24397 .37089 .25307 .35415 .26373 .34871 .25456 .36757 Mtetra
.382 .015 .211 r
.25456 .36757 .26373 .34871 .27437 .34395 .26515 .36471 Mtetra
.406 .049 .243 r
.26515 .36471 .27437 .34395 .28498 .34004 .27576 .36225 Mtetra
.418 .068 .261 r
.27576 .36225 .28498 .34004 .29557 .33698 .28641 .35997 Mtetra
.423 .076 .27 r
.28641 .35997 .29557 .33698 .30615 .33473 .2971 .35775 Mtetra
.426 .079 .271 r
.2971 .35775 .30615 .33473 .31675 .33292 .30785 .35566 Mtetra
.425 .077 .268 r
.30785 .35566 .31675 .33292 .32741 .33116 .31864 .35359 Mtetra
.419 .069 .263 r
.31864 .35359 .32741 .33116 .33815 .32882 .32951 .35129 Mtetra
.405 .056 .257 r
.32951 .35129 .33815 .32882 .34902 .32526 .34047 .34835 Mtetra
.359 .017 .242 r
.34047 .34835 .34902 .32526 .36008 .31907 .35159 .34335 Mtetra
.315 0 .234 r
.35159 .34335 .36008 .31907 .37128 .31032 .36286 .3362 Mtetra
.317 0 .247 r
.36286 .3362 .37128 .31032 .38252 .30117 .37418 .3285 Mtetra
.345 .023 .269 r
.37418 .3285 .38252 .30117 .39371 .2932 .38549 .32147 Mtetra
.411 .086 .301 r
.38549 .32147 .39371 .2932 .40477 .28924 .3967 .3175 Mtetra
.464 .133 .32 r
.3967 .3175 .40477 .28924 .41573 .28929 .40784 .31661 Mtetra
.473 .138 .317 r
.40784 .31661 .41573 .28929 .42673 .29053 .41903 .3164 Mtetra
.461 .122 .304 r
.41903 .3164 .42673 .29053 .43782 .2914 .43031 .31565 Mtetra
.416 .074 .275 r
.43031 .31565 .43782 .2914 .44906 .2897 .44171 .31275 Mtetra
.365 .023 .246 r
.44171 .31275 .44906 .2897 .46041 .28536 .45322 .30776 Mtetra
.345 .002 .232 r
.45322 .30776 .46041 .28536 .47183 .27978 .46478 .30212 Mtetra
.339 0 .23 r
.46478 .30212 .47183 .27978 .4833 .2736 .47639 .29625 Mtetra
.343 .003 .235 r
.47639 .29625 .4833 .2736 .49479 .26747 .48803 .2904 Mtetra
.349 .009 .24 r
.48803 .2904 .49479 .26747 .50632 .26178 .49971 .28466 Mtetra
.351 .011 .24 r
.49971 .28466 .50632 .26178 .51788 .2569 .51142 .27897 Mtetra
.349 .005 .233 r
.51142 .27897 .51788 .2569 .52949 .25289 .52317 .27347 Mtetra
.347 0 .217 r
.52317 .27347 .52949 .25289 .54115 .24974 .53496 .26836 Mtetra
.342 0 .193 r
.53496 .26836 .54115 .24974 .55287 .24729 .5468 .26372 Mtetra
.337 0 .16 r
.5468 .26372 .55287 .24729 .56467 .24532 .5587 .25969 Mtetra
.325 0 .12 r
.5587 .25969 .56467 .24532 .57653 .2436 .57065 .2561 Mtetra
.305 0 .071 r
.57065 .2561 .57653 .2436 .58847 .24182 .58267 .25272 Mtetra
.277 0 .017 r
.58267 .25272 .58847 .24182 .60047 .23988 .59474 .24936 Mtetra
.233 0 0 r
.59474 .24936 .60047 .23988 .61253 .23764 .60687 .24579 Mtetra
.177 0 0 r
.60687 .24579 .61253 .23764 .62466 .23509 .61905 .24192 Mtetra
.101 0 0 r
.61905 .24192 .62466 .23509 .63683 .23221 .63127 .23765 Mtetra
.002 0 0 r
.63127 .23765 .63683 .23221 .64906 .22902 .64353 .23301 Mtetra
0 0 0 r
.64353 .23301 .64906 .22902 .66134 .22554 .65583 .228 Mtetra
.65583 .228 .66134 .22554 .67367 .22179 .66816 .22267 Mtetra
.43 .869 .796 r
.66816 .22267 .67367 .22179 .68604 .21778 .68053 .21707 Mtetra
.562 .934 .907 r
.68053 .21707 .68604 .21778 .69846 .21352 .69293 .21124 Mtetra
.651 .942 .961 r
.69293 .21124 .69846 .21352 .71092 .20905 .70536 .20522 Mtetra
.697 .914 .969 r
.70536 .20522 .71092 .20905 .72342 .2044 .71783 .19905 Mtetra
.716 .868 .954 r
.71783 .19905 .72342 .2044 .73597 .19962 .73033 .19278 Mtetra
.719 .82 .928 r
.73033 .19278 .73597 .19962 .74857 .19475 .74288 .18646 Mtetra
.504 .702 .959 r
.07322 .41517 .0807 .4217 .09041 .41991 .08281 .41435 Mtetra
.481 .73 .98 r
.08281 .41435 .09041 .41991 .10017 .41807 .09245 .41353 Mtetra
.452 .756 .994 r
.09245 .41353 .10017 .41807 .11 .41615 .10215 .41266 Mtetra
.412 .777 .995 r
.10215 .41266 .11 .41615 .11988 .41411 .11193 .41171 Mtetra
.361 .786 .973 r
.11193 .41171 .11988 .41411 .12983 .41189 .12177 .41062 Mtetra
.298 .777 .922 r
.12177 .41062 .12983 .41189 .13986 .40945 .13168 .40936 Mtetra
.228 .746 .842 r
.13168 .40936 .13986 .40945 .14996 .40675 .14168 .40785 Mtetra
.157 .697 .738 r
.14168 .40785 .14996 .40675 .16014 .40376 .15177 .40607 Mtetra
0 0 0 r
.15177 .40607 .16014 .40376 .17041 .40042 .16194 .40394 Mtetra
.16194 .40394 .17041 .40042 .18075 .39673 .1722 .4015 Mtetra
.02 0 0 r
.1722 .4015 .18075 .39673 .19117 .39265 .18254 .39872 Mtetra
.084 0 0 r
.18254 .39872 .19117 .39265 .20166 .38828 .19294 .39577 Mtetra
.149 0 0 r
.19294 .39577 .20166 .38828 .2122 .3837 .2034 .39275 Mtetra
.22 0 0 r
.2034 .39275 .2122 .3837 .22278 .37915 .21389 .3899 Mtetra
.286 0 .008 r
.21389 .3899 .22278 .37915 .23338 .3748 .22439 .38739 Mtetra
.335 0 .082 r
.22439 .38739 .23338 .3748 .24397 .37089 .23492 .38522 Mtetra
.371 0 .136 r
.23492 .38522 .24397 .37089 .25456 .36757 .24546 .38338 Mtetra
.383 0 .167 r
.24546 .38338 .25456 .36757 .26515 .36471 .25607 .38148 Mtetra
.381 0 .179 r
.25607 .38148 .26515 .36471 .27576 .36225 .26676 .37925 Mtetra
.369 0 .176 r
.26676 .37925 .27576 .36225 .28641 .35997 .27754 .37658 Mtetra
.35 0 .16 r
.27754 .37658 .28641 .35997 .2971 .35775 .2884 .37344 Mtetra
.346 0 .144 r
.2884 .37344 .2971 .35775 .30785 .35566 .2993 .37046 Mtetra
.352 0 .133 r
.2993 .37046 .30785 .35566 .31864 .35359 .31023 .36792 Mtetra
.366 0 .132 r
.31023 .36792 .31864 .35359 .32951 .35129 .32117 .36589 Mtetra
.378 0 .142 r
.32117 .36589 .32951 .35129 .34047 .34835 .33216 .36412 Mtetra
.345 0 .144 r
.33216 .36412 .34047 .34835 .35159 .34335 .34328 .36103 Mtetra
.311 0 .156 r
.34328 .36103 .35159 .34335 .36286 .3362 .35454 .35627 Mtetra
.313 0 .188 r
.35454 .35627 .36286 .3362 .37418 .3285 .36589 .35067 Mtetra
.332 0 .218 r
.36589 .35067 .37418 .3285 .38549 .32147 .37727 .34498 Mtetra
.385 .04 .252 r
.37727 .34498 .38549 .32147 .3967 .3175 .38862 .34101 Mtetra
.423 .075 .268 r
.38862 .34101 .3967 .3175 .40784 .31661 .39995 .33877 Mtetra
.415 .061 .253 r
.39995 .33877 .40784 .31661 .41903 .3164 .41133 .33644 Mtetra
.383 .02 .219 r
.41133 .33644 .41903 .3164 .43031 .31565 .42281 .33327 Mtetra
.313 0 .158 r
.42281 .33327 .43031 .31565 .44171 .31275 .43439 .32841 Mtetra
.238 0 .094 r
.43439 .32841 .44171 .31275 .45322 .30776 .44605 .32223 Mtetra
.225 0 .067 r
.44605 .32223 .45322 .30776 .46478 .30212 .45773 .31629 Mtetra
.242 0 .07 r
.45773 .31629 .46478 .30212 .47639 .29625 .46944 .31087 Mtetra
.269 0 .091 r
.46944 .31087 .47639 .29625 .48803 .2904 .48119 .30589 Mtetra
.29 0 .117 r
.48119 .30589 .48803 .2904 .49971 .28466 .49298 .30106 Mtetra
.288 0 .132 r
.49298 .30106 .49971 .28466 .51142 .27897 .50482 .29576 Mtetra
.28 0 .135 r
.50482 .29576 .51142 .27897 .52317 .27347 .5167 .28999 Mtetra
.266 0 .126 r
.5167 .28999 .52317 .27347 .53496 .26836 .52862 .28389 Mtetra
.248 0 .102 r
.52862 .28389 .53496 .26836 .5468 .26372 .54057 .27771 Mtetra
.232 0 .067 r
.54057 .27771 .5468 .26372 .5587 .25969 .55257 .27187 Mtetra
.206 0 .014 r
.55257 .27187 .5587 .25969 .57065 .2561 .56461 .26636 Mtetra
.171 0 0 r
.56461 .26636 .57065 .2561 .58267 .25272 .5767 .2612 Mtetra
.118 0 0 r
.5767 .2612 .58267 .25272 .59474 .24936 .58884 .25619 Mtetra
.039 0 0 r
.58884 .25619 .59474 .24936 .60687 .24579 .60102 .25112 Mtetra
0 0 0 r
.60102 .25112 .60687 .24579 .61905 .24192 .61325 .24587 Mtetra
.61325 .24587 .61905 .24192 .63127 .23765 .62551 .24026 Mtetra
.323 .784 .654 r
.62551 .24026 .63127 .23765 .64353 .23301 .63781 .23431 Mtetra
.459 .881 .778 r
.63781 .23431 .64353 .23301 .65583 .228 .65013 .228 Mtetra
.574 .942 .872 r
.65013 .228 .65583 .228 .66816 .22267 .66248 .22139 Mtetra
.659 .963 .928 r
.66248 .22139 .66816 .22267 .68053 .21707 .67486 .21452 Mtetra
.711 .953 .951 r
.67486 .21452 .68053 .21707 .69293 .21124 .68726 .20745 Mtetra
.739 .926 .953 r
.68726 .20745 .69293 .21124 .70536 .20522 .69968 .20023 Mtetra
.751 .89 .942 r
.69968 .20023 .70536 .20522 .71783 .19905 .71214 .1929 Mtetra
.753 .854 .925 r
.71214 .1929 .71783 .19905 .73033 .19278 .72462 .18551 Mtetra
.749 .818 .906 r
.72462 .18551 .73033 .19278 .74288 .18646 .73713 .1781 Mtetra
.462 .685 .962 r
.06568 .40859 .07322 .41517 .08281 .41435 .0752 .40831 Mtetra
.445 .698 .974 r
.0752 .40831 .08281 .41435 .09245 .41353 .08478 .40804 Mtetra
.427 .712 .983 r
.08478 .40804 .09245 .41353 .10215 .41266 .09443 .40777 Mtetra
.408 .726 .989 r
.09443 .40777 .10215 .41266 .11193 .41171 .10413 .40744 Mtetra
.387 .739 .992 r
.10413 .40744 .11193 .41171 .12177 .41062 .1139 .40704 Mtetra
.365 .753 .988 r
.1139 .40704 .12177 .41062 .13168 .40936 .12375 .40649 Mtetra
.342 .764 .976 r
.12375 .40649 .13168 .40936 .14168 .40785 .13369 .40576 Mtetra
.316 .771 .953 r
.13369 .40576 .14168 .40785 .15177 .40607 .1437 .4048 Mtetra
.288 .771 .917 r
.1437 .4048 .15177 .40607 .16194 .40394 .15381 .40355 Mtetra
.244 .755 .862 r
.15381 .40355 .16194 .40394 .1722 .4015 .164 .40207 Mtetra
.186 .719 .784 r
.164 .40207 .1722 .4015 .18254 .39872 .17426 .40037 Mtetra
0 0 0 r
.17426 .40037 .18254 .39872 .19294 .39577 .18458 .39864 Mtetra
.02 0 0 r
.18458 .39864 .19294 .39577 .2034 .39275 .19495 .39702 Mtetra
.136 0 0 r
.19495 .39702 .2034 .39275 .21389 .3899 .20535 .39563 Mtetra
.235 0 0 r
.20535 .39563 .21389 .3899 .22439 .38739 .21577 .39458 Mtetra
.288 0 0 r
.21577 .39458 .22439 .38739 .23492 .38522 .22625 .39361 Mtetra
.311 0 0 r
.22625 .39361 .23492 .38522 .24546 .38338 .2368 .39253 Mtetra
.287 0 0 r
.2368 .39253 .24546 .38338 .25607 .38148 .24747 .39074 Mtetra
.225 0 0 r
.24747 .39074 .25607 .38148 .26676 .37925 .25828 .38787 Mtetra
.14 0 0 r
.25828 .38787 .26676 .37925 .27754 .37658 .26923 .38405 Mtetra
.028 0 0 r
.26923 .38405 .27754 .37658 .2884 .37344 .28027 .37946 Mtetra
0 0 0 r
.28027 .37946 .2884 .37344 .2993 .37046 .29133 .37529 Mtetra
.014 0 0 r
.29133 .37529 .2993 .37046 .31023 .36792 .30235 .37221 Mtetra
.116 0 0 r
.30235 .37221 .31023 .36792 .32117 .36589 .31333 .37052 Mtetra
.24 0 0 r
.31333 .37052 .32117 .36589 .33216 .36412 .3243 .37007 Mtetra
.254 0 0 r
.3243 .37007 .33216 .36412 .34328 .36103 .33536 .36914 Mtetra
.246 0 0 r
.33536 .36914 .34328 .36103 .35454 .35627 .34656 .36704 Mtetra
.251 0 0 r
.34656 .36704 .35454 .35627 .36589 .35067 .35788 .36378 Mtetra
.257 0 .045 r
.35788 .36378 .36589 .35067 .37727 .34498 .3693 .35957 Mtetra
.294 0 .094 r
.3693 .35957 .37727 .34498 .38862 .34101 .38075 .35558 Mtetra
.304 0 .099 r
.38075 .35558 .38862 .34101 .39995 .33877 .39224 .35184 Mtetra
.238 0 .035 r
.39224 .35184 .39995 .33877 .41133 .33644 .40382 .34713 Mtetra
.112 0 0 r
.40382 .34713 .41133 .33644 .42281 .33327 .41548 .34125 Mtetra
0 0 0 r
.41548 .34125 .42281 .33327 .43439 .32841 .42722 .33418 Mtetra
.42722 .33418 .43439 .32841 .44605 .32223 .439 .32662 Mtetra
.439 .32662 .44605 .32223 .45773 .31629 .45077 .32031 Mtetra
.45077 .32031 .45773 .31629 .46944 .31087 .46255 .31539 Mtetra
.46255 .31539 .46944 .31087 .48119 .30589 .47436 .31157 Mtetra
.072 0 0 r
.47436 .31157 .48119 .30589 .49298 .30106 .48621 .30818 Mtetra
.09 0 0 r
.48621 .30818 .49298 .30106 .50482 .29576 .49813 .30401 Mtetra
.079 0 0 r
.49813 .30401 .50482 .29576 .5167 .28999 .51011 .29886 Mtetra
.04 0 0 r
.51011 .29886 .5167 .28999 .52862 .28389 .52213 .29261 Mtetra
0 0 0 r
.52213 .29261 .52862 .28389 .54057 .27771 .53418 .28562 Mtetra
.53418 .28562 .54057 .27771 .55257 .27187 .54627 .2785 Mtetra
.54627 .2785 .55257 .27187 .56461 .26636 .55839 .27145 Mtetra
.55839 .27145 .56461 .26636 .5767 .2612 .57054 .26474 Mtetra
.57054 .26474 .5767 .2612 .58884 .25619 .58274 .25827 Mtetra
.42 .853 .73 r
.58274 .25827 .58884 .25619 .60102 .25112 .59497 .25189 Mtetra
.523 .918 .833 r
.59497 .25189 .60102 .25112 .61325 .24587 .60724 .24547 Mtetra
.612 .954 .901 r
.60724 .24547 .61325 .24587 .62551 .24026 .61955 .23881 Mtetra
.674 .963 .936 r
.61955 .23881 .62551 .24026 .63781 .23431 .63188 .2319 Mtetra
.718 .955 .949 r
.63188 .2319 .63781 .23431 .65013 .228 .64423 .22468 Mtetra
.744 .938 .949 r
.64423 .22468 .65013 .228 .66248 .22139 .65661 .21721 Mtetra
.76 .916 .942 r
.65661 .21721 .66248 .22139 .67486 .21452 .669 .20952 Mtetra
.767 .892 .932 r
.669 .20952 .67486 .21452 .68726 .20745 .68142 .20168 Mtetra
.769 .869 .922 r
.68142 .20168 .68726 .20745 .69968 .20023 .69386 .19374 Mtetra
.769 .847 .91 r
.69386 .19374 .69968 .20023 .71214 .1929 .70633 .18574 Mtetra
.765 .827 .9 r
.70633 .18574 .71214 .1929 .72462 .18551 .71882 .1777 Mtetra
.761 .807 .89 r
.71882 .1777 .72462 .18551 .73713 .1781 .73134 .16968 Mtetra
.471 .689 .962 r
.05808 .40196 .06568 .40859 .0752 .40831 .06764 .40154 Mtetra
.471 .685 .96 r
.06764 .40154 .0752 .40831 .08478 .40804 .07725 .40115 Mtetra
.473 .682 .957 r
.07725 .40115 .08478 .40804 .09443 .40777 .08691 .40076 Mtetra
.475 .68 .955 r
.08691 .40076 .09443 .40777 .10413 .40744 .09664 .40036 Mtetra
.479 .68 .954 r
.09664 .40036 .10413 .40744 .1139 .40704 .10642 .39992 Mtetra
.486 .682 .953 r
.10642 .39992 .1139 .40704 .12375 .40649 .11628 .39939 Mtetra
.495 .687 .953 r
.11628 .39939 .12375 .40649 .13369 .40576 .12622 .39872 Mtetra
.504 .694 .954 r
.12622 .39872 .13369 .40576 .1437 .4048 .13623 .3979 Mtetra
.514 .704 .956 r
.13623 .3979 .1437 .4048 .15381 .40355 .14632 .39687 Mtetra
.519 .714 .96 r
.14632 .39687 .15381 .40355 .164 .40207 .15649 .3957 Mtetra
.52 .726 .967 r
.15649 .3957 .164 .40207 .17426 .40037 .16673 .39444 Mtetra
.507 .737 .977 r
.16673 .39444 .17426 .40037 .18458 .39864 .17701 .39321 Mtetra
.481 .745 .987 r
.17701 .39321 .18458 .39864 .19495 .39702 .18734 .39216 Mtetra
.448 .753 .994 r
.18734 .39216 .19495 .39702 .20535 .39563 .19771 .39126 Mtetra
.412 .754 .995 r
.19771 .39126 .20535 .39563 .21577 .39458 .20813 .39052 Mtetra
.424 .771 .996 r
.20813 .39052 .21577 .39458 .22625 .39361 .21864 .38951 Mtetra
.48 .795 .999 r
.21864 .38951 .22625 .39361 .2368 .39253 .22926 .38788 Mtetra
.583 .815 .988 r
.22926 .38788 .2368 .39253 .24747 .39074 .24005 .38506 Mtetra
.671 .805 .947 r
.24005 .38506 .24747 .39074 .25828 .38787 .25102 .38071 Mtetra
.706 .768 .9 r
.25102 .38071 .25828 .38787 .26923 .38405 .26212 .37527 Mtetra
.713 .727 .861 r
.26212 .37527 .26923 .38405 .28027 .37946 .2733 .3692 Mtetra
.68 .683 .847 r
.2733 .3692 .28027 .37946 .29133 .37529 .28445 .36406 Mtetra
.623 .641 .847 r
.28445 .36406 .29133 .37529 .30235 .37221 .2955 .36076 Mtetra
.545 .601 .86 r
.2955 .36076 .30235 .37221 .31333 .37052 .30644 .35968 Mtetra
.444 .564 .882 r
.30644 .35968 .31333 .37052 .3243 .37007 .31732 .36069 Mtetra
.406 .585 .914 r
.31732 .36069 .3243 .37007 .33536 .36914 .32826 .36193 Mtetra
.405 .656 .961 r
.32826 .36193 .33536 .36914 .34656 .36704 .33934 .36239 Mtetra
.437 .763 .996 r
.33934 .36239 .34656 .36704 .35788 .36378 .35057 .36135 Mtetra
.489 .858 .986 r
.35057 .36135 .35788 .36378 .3693 .35957 .36196 .35853 Mtetra
.514 .9 .951 r
.36196 .35853 .3693 .35957 .38075 .35558 .37346 .35452 Mtetra
.606 .935 .955 r
.37346 .35452 .38075 .35558 .39224 .35184 .38507 .34932 Mtetra
.742 .935 .95 r
.38507 .34932 .39224 .35184 .40382 .34713 .39679 .34233 Mtetra
.795 .869 .903 r
.39679 .34233 .40382 .34713 .41548 .34125 .4086 .33382 Mtetra
.792 .793 .853 r
.4086 .33382 .41548 .34125 .42722 .33418 .42045 .32451 Mtetra
.767 .736 .825 r
.42045 .32451 .42722 .33418 .439 .32662 .4323 .3154 Mtetra
.713 .688 .824 r
.4323 .3154 .439 .32662 .45077 .32031 .44411 .3084 Mtetra
.656 .652 .834 r
.44411 .3084 .45077 .32031 .46255 .31539 .45591 .30363 Mtetra
.604 .631 .851 r
.45591 .30363 .46255 .31539 .47436 .31157 .46771 .30073 Mtetra
.572 .637 .877 r
.46771 .30073 .47436 .31157 .48621 .30818 .47957 .29877 Mtetra
.592 .683 .905 r
.47957 .29877 .48621 .30818 .49813 .30401 .49149 .29617 Mtetra
.632 .746 .93 r
.49149 .29617 .49813 .30401 .51011 .29886 .5035 .29248 Mtetra
.689 .812 .941 r
.5035 .29248 .51011 .29886 .52213 .29261 .51556 .28722 Mtetra
.731 .857 .94 r
.51556 .28722 .52213 .29261 .53418 .28562 .52766 .28073 Mtetra
.751 .878 .938 r
.52766 .28073 .53418 .28562 .54627 .2785 .5398 .2736 Mtetra
.76 .881 .933 r
.5398 .2736 .54627 .2785 .55839 .27145 .55197 .26617 Mtetra
.754 .869 .932 r
.55197 .26617 .55839 .27145 .57054 .26474 .56417 .2589 Mtetra
.748 .851 .926 r
.56417 .2589 .57054 .26474 .58274 .25827 .57641 .25177 Mtetra
.741 .83 .919 r
.57641 .25177 .58274 .25827 .59497 .25189 .58867 .24481 Mtetra
.738 .812 .91 r
.58867 .24481 .59497 .25189 .60724 .24547 .60098 .23788 Mtetra
.738 .798 .9 r
.60098 .23788 .60724 .24547 .61955 .23881 .61331 .23083 Mtetra
.739 .788 .892 r
.61331 .23083 .61955 .23881 .63188 .2319 .62568 .22363 Mtetra
.743 .782 .885 r
.62568 .22363 .63188 .2319 .64423 .22468 .63807 .21621 Mtetra
.746 .779 .88 r
.63807 .21621 .64423 .22468 .65661 .21721 .65048 .2086 Mtetra
.748 .777 .876 r
.65048 .2086 .65661 .21721 .669 .20952 .66292 .20084 Mtetra
.75 .777 .875 r
.66292 .20084 .669 .20952 .68142 .20168 .67538 .19297 Mtetra
.751 .777 .874 r
.67538 .19297 .68142 .20168 .69386 .19374 .68787 .18505 Mtetra
.752 .779 .875 r
.68787 .18505 .69386 .19374 .70633 .18574 .70038 .17709 Mtetra
.753 .782 .877 r
.70038 .17709 .70633 .18574 .71882 .1777 .71293 .16912 Mtetra
.753 .785 .879 r
.71293 .16912 .71882 .1777 .73134 .16968 .7255 .16118 Mtetra
.519 .708 .957 r
.05043 .39529 .05808 .40196 .06764 .40154 .06009 .39419 Mtetra
.525 .689 .942 r
.06009 .39419 .06764 .40154 .07725 .40115 .0698 .39313 Mtetra
.531 .671 .926 r
.0698 .39313 .07725 .40115 .08691 .40076 .07957 .39209 Mtetra
.536 .654 .911 r
.07957 .39209 .08691 .40076 .09664 .40036 .08938 .39106 Mtetra
.54 .638 .897 r
.08938 .39106 .09664 .40036 .10642 .39992 .09925 .39002 Mtetra
.544 .625 .883 r
.09925 .39002 .10642 .39992 .11628 .39939 .10918 .38894 Mtetra
.55 .615 .87 r
.10918 .38894 .11628 .39939 .12622 .39872 .11918 .38777 Mtetra
.554 .606 .86 r
.11918 .38777 .12622 .39872 .13623 .3979 .12925 .38652 Mtetra
.559 .6 .851 r
.12925 .38652 .13623 .3979 .14632 .39687 .13938 .38515 Mtetra
.561 .595 .844 r
.13938 .38515 .14632 .39687 .15649 .3957 .14957 .38375 Mtetra
.561 .59 .84 r
.14957 .38375 .15649 .3957 .16673 .39444 .15983 .38234 Mtetra
.557 .587 .839 r
.15983 .38234 .16673 .39444 .17701 .39321 .17012 .38102 Mtetra
.55 .582 .839 r
.17012 .38102 .17701 .39321 .18734 .39216 .18046 .37988 Mtetra
.548 .58 .839 r
.18046 .37988 .18734 .39216 .19771 .39126 .19085 .3788 Mtetra
.55 .578 .836 r
.19085 .3788 .19771 .39126 .20813 .39052 .2013 .37767 Mtetra
.57 .582 .825 r
.2013 .37767 .20813 .39052 .21864 .38951 .21187 .37595 Mtetra
.6 .585 .808 r
.21187 .37595 .21864 .38951 .22926 .38788 .2226 .37324 Mtetra
.633 .586 .784 r
.2226 .37324 .22926 .38788 .24005 .38506 .23351 .36905 Mtetra
.661 .584 .758 r
.23351 .36905 .24005 .38506 .25102 .38071 .24461 .36313 Mtetra
.67 .573 .737 r
.24461 .36313 .25102 .38071 .26212 .37527 .25583 .35617 Mtetra
.667 .558 .722 r
.25583 .35617 .26212 .37527 .2733 .3692 .26711 .34881 Mtetra
.641 .533 .716 r
.26711 .34881 .2733 .3692 .28445 .36406 .27831 .34275 Mtetra
.598 .501 .715 r
.27831 .34275 .28445 .36406 .2955 .36076 .28937 .33903 Mtetra
.543 .464 .716 r
.28937 .33903 .2955 .36076 .30644 .35968 .30028 .33801 Mtetra
.482 .427 .719 r
.30028 .33801 .30644 .35968 .31732 .36069 .31109 .33957 Mtetra
.461 .419 .724 r
.31109 .33957 .31732 .36069 .32826 .36193 .32193 .34186 Mtetra
.47 .435 .737 r
.32193 .34186 .32826 .36193 .33934 .36239 .33289 .34373 Mtetra
.511 .475 .753 r
.33289 .34373 .33934 .36239 .35057 .36135 .34403 .34399 Mtetra
.569 .524 .765 r
.34403 .34399 .35057 .36135 .36196 .35853 .35536 .34203 Mtetra
.619 .562 .768 r
.35536 .34203 .36196 .35853 .37346 .35452 .36687 .33798 Mtetra
.66 .584 .759 r
.36687 .33798 .37346 .35452 .38507 .34932 .37852 .33184 Mtetra
.691 .591 .739 r
.37852 .33184 .38507 .34932 .39679 .34233 .3903 .32346 Mtetra
.704 .585 .72 r
.3903 .32346 .39679 .34233 .4086 .33382 .40216 .31345 Mtetra
.7 .572 .707 r
.40216 .31345 .4086 .33382 .42045 .32451 .41404 .30299 Mtetra
.685 .555 .702 r
.41404 .30299 .42045 .32451 .4323 .3154 .42591 .29324 Mtetra
.647 .529 .705 r
.42591 .29324 .4323 .3154 .44411 .3084 .43771 .28609 Mtetra
.604 .502 .711 r
.43771 .28609 .44411 .3084 .45591 .30363 .44948 .28166 Mtetra
.563 .479 .719 r
.44948 .28166 .45591 .30363 .46771 .30073 .46124 .2796 Mtetra
.536 .47 .729 r
.46124 .2796 .46771 .30073 .47957 .29877 .47305 .27886 Mtetra
.545 .487 .741 r
.47305 .27886 .47957 .29877 .49149 .29617 .48494 .27773 Mtetra
.57 .517 .756 r
.48494 .27773 .49149 .29617 .5035 .29248 .49692 .27556 Mtetra
.613 .559 .769 r
.49692 .27556 .5035 .29248 .51556 .28722 .50898 .27161 Mtetra
.65 .595 .78 r
.50898 .27161 .51556 .28722 .52766 .28073 .52109 .26615 Mtetra
.677 .623 .788 r
.52109 .26615 .52766 .28073 .5398 .2736 .53325 .25967 Mtetra
.693 .641 .793 r
.53325 .25967 .5398 .2736 .55197 .26617 .54544 .25257 Mtetra
.696 .648 .798 r
.54544 .25257 .55197 .26617 .56417 .2589 .55766 .24542 Mtetra
.696 .65 .8 r
.55766 .24542 .56417 .2589 .57641 .25177 .56991 .2383 Mtetra
.693 .649 .802 r
.56991 .2383 .57641 .25177 .58867 .24481 .5822 .23136 Mtetra
.691 .649 .804 r
.5822 .23136 .58867 .24481 .60098 .23788 .59453 .22451 Mtetra
.692 .651 .805 r
.59453 .22451 .60098 .23788 .61331 .23083 .60689 .21763 Mtetra
.694 .656 .808 r
.60689 .21763 .61331 .23083 .62568 .22363 .61929 .21071 Mtetra
.698 .663 .812 r
.61929 .21071 .62568 .22363 .63807 .21621 .63171 .20365 Mtetra
.703 .673 .817 r
.63171 .20365 .63807 .21621 .65048 .2086 .64417 .1965 Mtetra
.708 .684 .824 r
.64417 .1965 .65048 .2086 .66292 .20084 .65666 .18924 Mtetra
.714 .697 .833 r
.65666 .18924 .66292 .20084 .67538 .19297 .66919 .18193 Mtetra
.718 .711 .842 r
.66919 .18193 .67538 .19297 .68787 .18505 .68174 .1746 Mtetra
.723 .727 .853 r
.68174 .1746 .68787 .18505 .70038 .17709 .69433 .16725 Mtetra
.728 .744 .865 r
.69433 .16725 .70038 .17709 .71293 .16912 .70695 .15992 Mtetra
.732 .763 .878 r
.70695 .15992 .71293 .16912 .7255 .16118 .71961 .15261 Mtetra
.59 .733 .943 r
.04273 .38856 .05043 .39529 .06009 .39419 .05257 .38629 Mtetra
.593 .698 .916 r
.05257 .38629 .06009 .39419 .0698 .39313 .06246 .38406 Mtetra
.593 .666 .89 r
.06246 .38406 .0698 .39313 .07957 .39209 .07239 .38186 Mtetra
.592 .637 .865 r
.07239 .38186 .07957 .39209 .08938 .39106 .08236 .37968 Mtetra
.59 .612 .842 r
.08236 .37968 .08938 .39106 .09925 .39002 .09238 .37751 Mtetra
.588 .59 .822 r
.09238 .37751 .09925 .39002 .10918 .38894 .10245 .37534 Mtetra
.587 .572 .804 r
.10245 .37534 .10918 .38894 .11918 .38777 .11258 .37313 Mtetra
.585 .556 .788 r
.11258 .37313 .11918 .38777 .12925 .38652 .12276 .37089 Mtetra
.584 .542 .774 r
.12276 .37089 .12925 .38652 .13938 .38515 .13299 .36862 Mtetra
.581 .53 .763 r
.13299 .36862 .13938 .38515 .14957 .38375 .14327 .36636 Mtetra
.577 .519 .753 r
.14327 .36636 .14957 .38375 .15983 .38234 .15359 .36418 Mtetra
.571 .508 .745 r
.15359 .36418 .15983 .38234 .17012 .38102 .16395 .36213 Mtetra
.565 .498 .738 r
.16395 .36213 .17012 .38102 .18046 .37988 .17434 .3603 Mtetra
.562 .49 .732 r
.17434 .3603 .18046 .37988 .19085 .3788 .18478 .35851 Mtetra
.563 .485 .725 r
.18478 .35851 .19085 .3788 .2013 .37767 .19528 .35667 Mtetra
.574 .486 .718 r
.19528 .35667 .2013 .37767 .21187 .37595 .2059 .35421 Mtetra
.592 .492 .71 r
.2059 .35421 .21187 .37595 .2226 .37324 .21667 .35074 Mtetra
.615 .502 .701 r
.21667 .35074 .2226 .37324 .23351 .36905 .22763 .34579 Mtetra
.638 .512 .693 r
.22763 .34579 .23351 .36905 .24461 .36313 .23878 .33911 Mtetra
.649 .515 .686 r
.23878 .33911 .24461 .36313 .25583 .35617 .25005 .33132 Mtetra
.652 .512 .68 r
.25005 .33132 .25583 .35617 .26711 .34881 .26138 .32301 Mtetra
.636 .497 .676 r
.26138 .32301 .26711 .34881 .27831 .34275 .27265 .31568 Mtetra
.606 .472 .672 r
.27265 .31568 .27831 .34275 .28937 .33903 .28379 .31029 Mtetra
.568 .439 .665 r
.28379 .31029 .28937 .33903 .30028 .33801 .2948 .30724 Mtetra
.53 .405 .655 r
.2948 .30724 .30028 .33801 .31109 .33957 .30569 .30653 Mtetra
.515 .387 .644 r
.30569 .30653 .31109 .33957 .32193 .34186 .31659 .30675 Mtetra
.515 .381 .636 r
.31659 .30675 .32193 .34186 .33289 .34373 .32757 .30698 Mtetra
.529 .386 .631 r
.32757 .30698 .33289 .34373 .34403 .34399 .33869 .30615 Mtetra
.548 .397 .628 r
.33869 .30615 .34403 .34399 .35536 .34203 .34997 .30371 Mtetra
.566 .409 .627 r
.34997 .30371 .35536 .34203 .36687 .33798 .36139 .2996 Mtetra
.584 .421 .627 r
.36139 .2996 .36687 .33798 .37852 .33184 .37295 .29383 Mtetra
.601 .434 .628 r
.37295 .29383 .37852 .33184 .3903 .32346 .38462 .28642 Mtetra
.613 .445 .63 r
.38462 .28642 .3903 .32346 .40216 .31345 .39635 .27795 Mtetra
.617 .451 .635 r
.39635 .27795 .40216 .31345 .41404 .30299 .4081 .26947 Mtetra
.612 .454 .643 r
.4081 .26947 .41404 .30299 .42591 .29324 .41984 .26191 Mtetra
.591 .447 .654 r
.41984 .26191 .42591 .29324 .43771 .28609 .43153 .2567 Mtetra
.563 .436 .665 r
.43153 .2567 .43771 .28609 .44948 .28166 .44321 .25386 Mtetra
.534 .425 .676 r
.44321 .25386 .44948 .28166 .46124 .2796 .45489 .25299 Mtetra
.517 .42 .684 r
.45489 .25299 .46124 .2796 .47305 .27886 .46664 .25312 Mtetra
.526 .432 .691 r
.46664 .25312 .47305 .27886 .48494 .27773 .47848 .25274 Mtetra
.547 .45 .696 r
.47848 .25274 .48494 .27773 .49692 .27556 .49041 .25124 Mtetra
.578 .474 .7 r
.49041 .25124 .49692 .27556 .50898 .27161 .50243 .24797 Mtetra
.604 .495 .703 r
.50243 .24797 .50898 .27161 .52109 .26615 .51452 .2432 Mtetra
.622 .511 .706 r
.51452 .2432 .52109 .26615 .53325 .25967 .52666 .23738 Mtetra
.634 .523 .71 r
.52666 .23738 .53325 .25967 .54544 .25257 .53884 .23094 Mtetra
.638 .53 .715 r
.53884 .23094 .54544 .25257 .55766 .24542 .55105 .22441 Mtetra
.64 .536 .721 r
.55105 .22441 .55766 .24542 .56991 .2383 .5633 .21793 Mtetra
.64 .541 .727 r
.5633 .21793 .56991 .2383 .5822 .23136 .5756 .21166 Mtetra
.64 .548 .734 r
.5756 .21166 .5822 .23136 .59453 .22451 .58793 .20552 Mtetra
.643 .556 .742 r
.58793 .20552 .59453 .22451 .60689 .21763 .60031 .19944 Mtetra
.646 .566 .751 r
.60031 .19944 .60689 .21763 .61929 .21071 .61274 .19338 Mtetra
.651 .579 .761 r
.61274 .19338 .61929 .21071 .63171 .20365 .6252 .18727 Mtetra
.657 .594 .772 r
.6252 .18727 .63171 .20365 .64417 .1965 .63771 .18112 Mtetra
.664 .611 .785 r
.63771 .18112 .64417 .1965 .65666 .18924 .65026 .17492 Mtetra
.67 .63 .8 r
.65026 .17492 .65666 .18924 .66919 .18193 .66285 .1687 Mtetra
.677 .652 .818 r
.66285 .1687 .66919 .18193 .68174 .1746 .67549 .16249 Mtetra
.684 .677 .837 r
.67549 .16249 .68174 .1746 .69433 .16725 .68817 .1563 Mtetra
.691 .705 .858 r
.68817 .1563 .69433 .16725 .70695 .15992 .7009 .15012 Mtetra
.697 .736 .881 r
.7009 .15012 .70695 .15992 .71961 .15261 .71368 .14397 Mtetra
.656 .751 .92 r
.03496 .38178 .04273 .38856 .05257 .38629 .04503 .3781 Mtetra
.651 .71 .891 r
.04503 .3781 .05257 .38629 .06246 .38406 .05514 .37445 Mtetra
.644 .672 .862 r
.05514 .37445 .06246 .38406 .07239 .38186 .06528 .37084 Mtetra
.637 .64 .837 r
.06528 .37084 .07239 .38186 .08236 .37968 .07545 .36726 Mtetra
.629 .611 .813 r
.07545 .36726 .08236 .37968 .09238 .37751 .08566 .36372 Mtetra
.622 .586 .793 r
.08566 .36372 .09238 .37751 .10245 .37534 .0959 .36021 Mtetra
.616 .565 .774 r
.0959 .36021 .10245 .37534 .11258 .37313 .10619 .3567 Mtetra
.61 .547 .759 r
.10619 .3567 .11258 .37313 .12276 .37089 .11652 .35321 Mtetra
.605 .531 .745 r
.11652 .35321 .12276 .37089 .13299 .36862 .12688 .34973 Mtetra
.6 .517 .733 r
.12688 .34973 .13299 .36862 .14327 .36636 .13728 .34632 Mtetra
.594 .504 .722 r
.13728 .34632 .14327 .36636 .15359 .36418 .14772 .34302 Mtetra
.587 .491 .713 r
.14772 .34302 .15359 .36418 .16395 .36213 .15817 .33988 Mtetra
.58 .479 .705 r
.15817 .33988 .16395 .36213 .17434 .3603 .16865 .33696 Mtetra
.576 .47 .697 r
.16865 .33696 .17434 .3603 .18478 .35851 .17917 .33412 Mtetra
.573 .462 .689 r
.17917 .33412 .18478 .35851 .19528 .35667 .18974 .33127 Mtetra
.579 .461 .682 r
.18974 .33127 .19528 .35667 .2059 .35421 .20041 .32796 Mtetra
.59 .464 .677 r
.20041 .32796 .2059 .35421 .21667 .35074 .2112 .32384 Mtetra
.606 .471 .672 r
.2112 .32384 .21667 .35074 .22763 .34579 .22215 .31851 Mtetra
.624 .482 .668 r
.22215 .31851 .22763 .34579 .23878 .33911 .23328 .31171 Mtetra
.636 .489 .666 r
.23328 .31171 .23878 .33911 .25005 .33132 .24452 .30388 Mtetra
.643 .494 .665 r
.24452 .30388 .25005 .33132 .26138 .32301 .25583 .2954 Mtetra
.637 .489 .665 r
.25583 .2954 .26138 .32301 .27265 .31568 .26712 .28741 Mtetra
.62 .475 .663 r
.26712 .28741 .27265 .31568 .28379 .31029 .27833 .28062 Mtetra
.595 .453 .658 r
.27833 .28062 .28379 .31029 .2948 .30724 .28945 .27544 Mtetra
.568 .427 .649 r
.28945 .27544 .2948 .30724 .30569 .30653 .30047 .27198 Mtetra
.552 .407 .638 r
.30047 .27198 .30569 .30653 .31659 .30675 .31149 .26939 Mtetra
.545 .394 .627 r
.31149 .26939 .31659 .30675 .32757 .30698 .32254 .26713 Mtetra
.547 .39 .62 r
.32254 .26713 .32757 .30698 .33869 .30615 .33368 .2645 Mtetra
.553 .39 .615 r
.33368 .2645 .33869 .30615 .34997 .30371 .34491 .26114 Mtetra
.56 .394 .613 r
.34491 .26114 .34997 .30371 .36139 .2996 .35624 .25697 Mtetra
.568 .399 .613 r
.35624 .25697 .36139 .2996 .37295 .29383 .36766 .252 Mtetra
.576 .407 .615 r
.36766 .252 .37295 .29383 .38462 .28642 .37916 .24628 Mtetra
.582 .415 .62 r
.37916 .24628 .38462 .28642 .39635 .27795 .39071 .2402 Mtetra
.583 .421 .628 r
.39071 .2402 .39635 .27795 .4081 .26947 .40228 .23443 Mtetra
.578 .425 .637 r
.40228 .23443 .4081 .26947 .41984 .26191 .41386 .22954 Mtetra
.561 .422 .649 r
.41386 .22954 .41984 .26191 .43153 .2567 .42543 .22638 Mtetra
.541 .417 .66 r
.42543 .22638 .43153 .2567 .44321 .25386 .43701 .22485 Mtetra
.522 .41 .668 r
.43701 .22485 .44321 .25386 .45489 .25299 .44862 .22455 Mtetra
.514 .408 .672 r
.44862 .22455 .45489 .25299 .46664 .25312 .46031 .22475 Mtetra
.525 .416 .673 r
.46031 .22475 .46664 .25312 .47848 .25274 .4721 .22431 Mtetra
.542 .427 .673 r
.4721 .22431 .47848 .25274 .49041 .25124 .48398 .22283 Mtetra
.564 .443 .672 r
.48398 .22283 .49041 .25124 .50243 .24797 .49595 .21986 Mtetra
.583 .456 .673 r
.49595 .21986 .50243 .24797 .51452 .2432 .50799 .21565 Mtetra
.596 .467 .676 r
.50799 .21565 .51452 .2432 .52666 .23738 .52009 .21061 Mtetra
.604 .477 .68 r
.52009 .21061 .52666 .23738 .53884 .23094 .53223 .2051 Mtetra
.607 .484 .686 r
.53223 .2051 .53884 .23094 .55105 .22441 .54442 .19956 Mtetra
.609 .491 .693 r
.54442 .19956 .55105 .22441 .5633 .21793 .55665 .19411 Mtetra
.609 .498 .702 r
.55665 .19411 .5633 .21793 .5756 .21166 .56894 .18887 Mtetra
.61 .505 .71 r
.56894 .18887 .5756 .21166 .58793 .20552 .58128 .18379 Mtetra
.612 .515 .72 r
.58128 .18379 .58793 .20552 .60031 .19944 .59367 .17882 Mtetra
.614 .525 .73 r
.59367 .17882 .60031 .19944 .61274 .19338 .60611 .17392 Mtetra
.618 .539 .742 r
.60611 .17392 .61274 .19338 .6252 .18727 .61861 .16902 Mtetra
.623 .554 .756 r
.61861 .16902 .6252 .18727 .63771 .18112 .63117 .16413 Mtetra
.628 .572 .772 r
.63117 .16413 .63771 .18112 .65026 .17492 .64377 .15925 Mtetra
.634 .592 .79 r
.64377 .15925 .65026 .17492 .66285 .1687 .65644 .15439 Mtetra
.639 .616 .811 r
.65644 .15439 .66285 .1687 .67549 .16249 .66916 .14956 Mtetra
.644 .643 .834 r
.66916 .14956 .67549 .16249 .68817 .1563 .68194 .14476 Mtetra
.649 .674 .861 r
.68194 .14476 .68817 .1563 .7009 .15012 .69479 .13999 Mtetra
.653 .71 .89 r
.69479 .13999 .7009 .15012 .71368 .14397 .70769 .13525 Mtetra
.706 .762 .896 r
.02714 .37496 .03496 .38178 .04503 .3781 .03745 .36981 Mtetra
.696 .721 .869 r
.03745 .36981 .04503 .3781 .05514 .37445 .04779 .36472 Mtetra
.685 .685 .844 r
.04779 .36472 .05514 .37445 .06528 .37084 .05815 .35968 Mtetra
.674 .653 .821 r
.05815 .35968 .06528 .37084 .07545 .36726 .06853 .35469 Mtetra
.663 .624 .8 r
.06853 .35469 .07545 .36726 .08566 .36372 .07893 .34976 Mtetra
.653 .6 .782 r
.07893 .34976 .08566 .36372 .0959 .36021 .08936 .34488 Mtetra
.645 .578 .765 r
.08936 .34488 .0959 .36021 .10619 .3567 .09982 .34004 Mtetra
.637 .559 .75 r
.09982 .34004 .10619 .3567 .11652 .35321 .1103 .33526 Mtetra
.629 .542 .737 r
.1103 .33526 .11652 .35321 .12688 .34973 .12081 .33053 Mtetra
.622 .527 .726 r
.12081 .33053 .12688 .34973 .13728 .34632 .13135 .32589 Mtetra
.615 .513 .716 r
.13135 .32589 .13728 .34632 .14772 .34302 .14191 .32135 Mtetra
.608 .5 .706 r
.14191 .32135 .14772 .34302 .15817 .33988 .15249 .31697 Mtetra
.6 .488 .697 r
.15249 .31697 .15817 .33988 .16865 .33696 .16308 .31276 Mtetra
.594 .476 .688 r
.16308 .31276 .16865 .33696 .17917 .33412 .17371 .30866 Mtetra
.59 .467 .68 r
.17371 .30866 .17917 .33412 .18974 .33127 .18437 .30461 Mtetra
.59 .461 .673 r
.18437 .30461 .18974 .33127 .20041 .32796 .19509 .30034 Mtetra
.594 .459 .667 r
.19509 .30034 .20041 .32796 .2112 .32384 .2059 .29564 Mtetra
.602 .462 .664 r
.2059 .29564 .2112 .32384 .22215 .31851 .21682 .29025 Mtetra
.613 .47 .663 r
.21682 .29025 .22215 .31851 .23328 .31171 .22785 .28398 Mtetra
.623 .479 .665 r
.22785 .28398 .23328 .31171 .24452 .30388 .23898 .27703 Mtetra
.633 .489 .669 r
.23898 .27703 .24452 .30388 .25583 .2954 .25017 .26956 Mtetra
.635 .496 .675 r
.25017 .26956 .25583 .2954 .26712 .28741 .26138 .26219 Mtetra
.631 .496 .679 r
.26138 .26219 .26712 .28741 .27833 .28062 .27257 .25529 Mtetra
.62 .488 .68 r
.27257 .25529 .27833 .28062 .28945 .27544 .28372 .24918 Mtetra
.604 .473 .676 r
.28372 .24918 .28945 .27544 .30047 .27198 .29484 .24397 Mtetra
.59 .456 .667 r
.29484 .24397 .30047 .27198 .31149 .26939 .30595 .23935 Mtetra
.58 .441 .657 r
.30595 .23935 .31149 .26939 .32254 .26713 .31708 .23513 Mtetra
.574 .43 .648 r
.31708 .23513 .32254 .26713 .33368 .2645 .32825 .23101 Mtetra
.572 .424 .641 r
.32825 .23101 .33368 .2645 .34491 .26114 .33946 .22686 Mtetra
.571 .421 .638 r
.33946 .22686 .34491 .26114 .35624 .25697 .35073 .22264 Mtetra
.572 .421 .638 r
.35073 .22264 .35624 .25697 .36766 .252 .36205 .21835 Mtetra
.573 .425 .641 r
.36205 .21835 .36766 .252 .37916 .24628 .37341 .21402 Mtetra
.575 .43 .648 r
.37341 .21402 .37916 .24628 .39071 .2402 .38482 .20981 Mtetra
.573 .436 .657 r
.38482 .20981 .39071 .2402 .40228 .23443 .39626 .20599 Mtetra
.568 .441 .668 r
.39626 .20599 .40228 .23443 .41386 .22954 .40773 .20276 Mtetra
.556 .442 .679 r
.40773 .20276 .41386 .22954 .42543 .22638 .41922 .20045 Mtetra
.544 .439 .686 r
.41922 .20045 .42543 .22638 .43701 .22485 .43075 .19893 Mtetra
.535 .434 .687 r
.43075 .19893 .43701 .22485 .44862 .22455 .44234 .19791 Mtetra
.532 .429 .682 r
.44234 .19791 .44862 .22455 .46031 .22475 .45401 .19699 Mtetra
.54 .428 .675 r
.45401 .19699 .46031 .22475 .4721 .22431 .46576 .19556 Mtetra
.55 .43 .67 r
.46576 .19556 .4721 .22431 .48398 .22283 .47759 .19343 Mtetra
.562 .436 .666 r
.47759 .19343 .48398 .22283 .49595 .21986 .48951 .19042 Mtetra
.572 .443 .666 r
.48951 .19042 .49595 .21986 .50799 .21565 .5015 .1867 Mtetra
.579 .449 .668 r
.5015 .1867 .50799 .21565 .52009 .21061 .51354 .18255 Mtetra
.584 .457 .673 r
.51354 .18255 .52009 .21061 .53223 .2051 .52564 .17817 Mtetra
.586 .464 .681 r
.52564 .17817 .53223 .2051 .54442 .19956 .5378 .17383 Mtetra
.587 .472 .689 r
.5378 .17383 .54442 .19956 .55665 .19411 .55001 .1696 Mtetra
.587 .48 .698 r
.55001 .1696 .55665 .19411 .56894 .18887 .56229 .16556 Mtetra
.588 .488 .708 r
.56229 .16556 .56894 .18887 .58128 .18379 .57462 .16166 Mtetra
.589 .498 .719 r
.57462 .16166 .58128 .18379 .59367 .17882 .58702 .15787 Mtetra
.59 .509 .731 r
.58702 .15787 .59367 .17882 .60611 .17392 .59948 .15418 Mtetra
.593 .521 .744 r
.59948 .15418 .60611 .17392 .61861 .16902 .612 .15053 Mtetra
.595 .536 .758 r
.612 .15053 .61861 .16902 .63117 .16413 .6246 .14694 Mtetra
.598 .553 .775 r
.6246 .14694 .63117 .16413 .64377 .15925 .63726 .14339 Mtetra
.601 .573 .794 r
.63726 .14339 .64377 .15925 .65644 .15439 .64999 .1399 Mtetra
.603 .595 .816 r
.64999 .1399 .65644 .15439 .66916 .14956 .6628 .13646 Mtetra
.605 .621 .841 r
.6628 .13646 .66916 .14956 .68194 .14476 .67567 .13308 Mtetra
.605 .652 .869 r
.67567 .13308 .68194 .14476 .69479 .13999 .68863 .12975 Mtetra
.604 .686 .901 r
.68863 .12975 .69479 .13999 .70769 .13525 .70165 .12647 Mtetra
.74 .766 .874 r
.01926 .36808 .02714 .37496 .03745 .36981 .0298 .36165 Mtetra
.728 .732 .854 r
.0298 .36165 .03745 .36981 .04779 .36472 .04034 .35529 Mtetra
.716 .701 .835 r
.04034 .35529 .04779 .36472 .05815 .35968 .0509 .34901 Mtetra
.705 .674 .817 r
.0509 .34901 .05815 .35968 .06853 .35469 .06147 .34281 Mtetra
.694 .649 .801 r
.06147 .34281 .06853 .35469 .07893 .34976 .07205 .33669 Mtetra
.683 .627 .786 r
.07205 .33669 .07893 .34976 .08936 .34488 .08265 .33064 Mtetra
.674 .607 .772 r
.08265 .33064 .08936 .34488 .09982 .34004 .09326 .32467 Mtetra
.665 .589 .76 r
.09326 .32467 .09982 .34004 .1103 .33526 .10389 .31877 Mtetra
.657 .572 .748 r
.10389 .31877 .1103 .33526 .12081 .33053 .11454 .31295 Mtetra
.649 .558 .738 r
.11454 .31295 .12081 .33053 .13135 .32589 .1252 .3072 Mtetra
.642 .544 .728 r
.1252 .3072 .13135 .32589 .14191 .32135 .13589 .30153 Mtetra
.635 .531 .718 r
.13589 .30153 .14191 .32135 .15249 .31697 .1466 .29593 Mtetra
.629 .518 .709 r
.1466 .29593 .15249 .31697 .16308 .31276 .15732 .29041 Mtetra
.622 .505 .699 r
.15732 .29041 .16308 .31276 .17371 .30866 .16807 .28497 Mtetra
.615 .493 .69 r
.16807 .28497 .17371 .30866 .18437 .30461 .17885 .27959 Mtetra
.61 .482 .681 r
.17885 .27959 .18437 .30461 .19509 .30034 .18965 .2743 Mtetra
.605 .474 .675 r
.18965 .2743 .19509 .30034 .2059 .29564 .20048 .26908 Mtetra
.602 .469 .673 r
.20048 .26908 .2059 .29564 .21682 .29025 .21133 .26393 Mtetra
.602 .47 .674 r
.21133 .26393 .21682 .29025 .22785 .28398 .22221 .25885 Mtetra
.604 .478 .682 r
.22221 .25885 .22785 .28398 .23898 .27703 .23312 .25385 Mtetra
.609 .493 .696 r
.23312 .25385 .23898 .27703 .25017 .26956 .24407 .24893 Mtetra
.617 .516 .717 r
.24407 .24893 .25017 .26956 .26138 .26219 .25504 .24408 Mtetra
.626 .544 .741 r
.25504 .24408 .26138 .26219 .27257 .25529 .26605 .2393 Mtetra
.635 .572 .766 r
.26605 .2393 .27257 .25529 .28372 .24918 .27709 .23459 Mtetra
.64 .593 .786 r
.27709 .23459 .28372 .24918 .29484 .24397 .28816 .22997 Mtetra
.641 .603 .795 r
.28816 .22997 .29484 .24397 .30595 .23935 .29927 .22541 Mtetra
.639 .603 .797 r
.29927 .22541 .30595 .23935 .31708 .23513 .31042 .22093 Mtetra
.636 .598 .795 r
.31042 .22093 .31708 .23513 .32825 .23101 .32161 .21652 Mtetra
.633 .593 .791 r
.32161 .21652 .32825 .23101 .33946 .22686 .33284 .21219 Mtetra
.63 .589 .79 r
.33284 .21219 .33946 .22686 .35073 .22264 .34411 .20793 Mtetra
.628 .588 .79 r
.34411 .20793 .35073 .22264 .36205 .21835 .35543 .20375 Mtetra
.626 .59 .793 r
.35543 .20375 .36205 .21835 .37341 .21402 .36678 .19964 Mtetra
.625 .593 .797 r
.36678 .19964 .37341 .21402 .38482 .20981 .37819 .1956 Mtetra
.624 .595 .801 r
.37819 .1956 .38482 .20981 .39626 .20599 .38964 .19164 Mtetra
.621 .593 .8 r
.38964 .19164 .39626 .20599 .40773 .20276 .40114 .18775 Mtetra
.616 .581 .792 r
.40114 .18775 .40773 .20276 .41922 .20045 .41268 .18394 Mtetra
.608 .557 .772 r
.41268 .18394 .41922 .20045 .43075 .19893 .42428 .18021 Mtetra
.598 .528 .746 r
.42428 .18021 .43075 .19893 .44234 .19791 .43593 .17655 Mtetra
.588 .499 .72 r
.43593 .17655 .44234 .19791 .45401 .19699 .44764 .17296 Mtetra
.58 .475 .699 r
.44764 .17296 .45401 .19699 .46576 .19556 .4594 .16945 Mtetra
.574 .459 .684 r
.4594 .16945 .46576 .19556 .47759 .19343 .47122 .16602 Mtetra
.57 .449 .676 r
.47122 .16602 .47759 .19343 .48951 .19042 .48309 .16267 Mtetra
.568 .447 .675 r
.48309 .16267 .48951 .19042 .5015 .1867 .49503 .15939 Mtetra
.567 .449 .678 r
.49503 .15939 .5015 .1867 .51354 .18255 .50702 .15618 Mtetra
.568 .455 .685 r
.50702 .15618 .51354 .18255 .52564 .17817 .51908 .15306 Mtetra
.569 .463 .694 r
.51908 .15306 .52564 .17817 .5378 .17383 .53121 .15001 Mtetra
.57 .472 .704 r
.53121 .15001 .5378 .17383 .55001 .1696 .5434 .14704 Mtetra
.571 .482 .716 r
.5434 .14704 .55001 .1696 .56229 .16556 .55566 .14414 Mtetra
.572 .493 .727 r
.55566 .14414 .56229 .16556 .57462 .16166 .56799 .14133 Mtetra
.572 .503 .739 r
.56799 .14133 .57462 .16166 .58702 .15787 .5804 .13859 Mtetra
.573 .514 .751 r
.5804 .13859 .58702 .15787 .59948 .15418 .59287 .13594 Mtetra
.573 .526 .764 r
.59287 .13594 .59948 .15418 .612 .15053 .60542 .13336 Mtetra
.573 .539 .779 r
.60542 .13336 .612 .15053 .6246 .14694 .61805 .13087 Mtetra
.572 .554 .795 r
.61805 .13087 .6246 .14694 .63726 .14339 .63076 .12845 Mtetra
.572 .571 .814 r
.63076 .12845 .63726 .14339 .64999 .1399 .64355 .12612 Mtetra
.57 .591 .835 r
.64355 .12612 .64999 .1399 .6628 .13646 .65642 .12387 Mtetra
.567 .613 .858 r
.65642 .12387 .6628 .13646 .67567 .13308 .66938 .1217 Mtetra
.562 .638 .884 r
.66938 .1217 .67567 .13308 .68863 .12975 .68243 .11961 Mtetra
.554 .666 .912 r
.68243 .11961 .68863 .12975 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Nooooo`;oSj?R1?n=Z^T00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo057ooooo001Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool07Oooool3o`0000;ooooo00?o0000ooooooooool0F?oo
ool2oi6Lf`GoSj?R0on=Z^T00ol0003oSJ[Yooooo`0Eooooo`03o`000?oooooooooo053ooooo001P
ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0001cooooo0_l0001Gooooo`;oTY;@1?nA
UmD6oi6Lf`GoSj?R0_n=Z^T00ol0003oVZoVooooo`0Dooooo`03o`000?oooooo0000057ooooo001P
ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0000Jooooo`?o0000
EOooool2oi:=b`GoTY;@1?nAUmD6oi6Lf`;oSj?R0_nJY]h2oiZ_iP03o`000?nJ[nKoVZoV01Kooooo
00?o0000ooooooooool0Coooool0063ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgM
gOmEEEGoooooo`0001Sooooo0_l0001Dooooo`;oTXW71OnBSL/4oi:Bd0CoTIOE1OnAW=/00onJW]Oo
VZKNoiZVgP03oiZVgP03oiZ_i_l0003oVZoV00;oVZoV5_ooool00ol0003oooooooooo`1>ooooo`00
H?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000005Oooool3o`0000;o
oooo00?o0000ooooooooool0BOooool2oi:3`0CoTXK31OnBRLL4oi:=b`CoTY;@1OnAUmD00onAW=_o
VYkGoiZNe`03oiZNe`CoVZKN00GoVZoVo`000?nJ[nKoVZoVojNeh`0Fooooo`03o`000?oooooooooo
04kooooo001Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000Coooo
o`;o0000COooool2oi:0_@GoTX?01?nBQ/<4oi:9a`CoTXg;1OnBT]02oi6Ge@;oVYS@1_nJW]L5oiZV
gP03o`000?nW]N?oYkGS00;oYkGS5_ooool00ol0003oooooooooo`1=ooooo`00H?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool03oooool3o`0004_ooooo0_nBO[X5oi:0
_@CoTX?01?nBQ/<4oi:9a`GoTXg;0_nBT]02oiVBb`GoVYS@1_nJW]L2oiZVgP;oYZcL00?o0000ojNe
honW]N<00onW]N<Fooooo`03o`000?oooooooooo04cooooo0022ooooo`;o0000Boooool00onBNkOo
TWjjoi9n^P02oi9n^PGoTX2m1?nBPl04oi:6``GoTXW70_nBSL/2oiV=aPGoVI;;1?nJV=05oiZNe`03
ojBTeOnV[=coYZcL00;oYZcL00?o0000ojNehonW]N<00_nW]N<00onb_>7oooooooooo`0Dooooo`03
o`000?oooooooooo04cooooo001oooooo`?o00000_ooool00ol0003oooooooooo`14ooooo`;oTGRd
1?nBNkL4oi9n^PCoTX2m1OnBPl04oi:6``;oTXW70_nHRL85oiV=aPCoVI;;1OnJV=000onJW]OoY:CE
ojBTe@02ojBTe@CoYZcL00?o0000ojJ/g?nW]N<01?nb_>4Dooooo`?o0000COooool007cooooo0ol0
0018ooooo`;oTGJa1?nAN;@4oi9k]`CoTWjj1OnBP;d4oi:3`0;oTXK30_nGQKh5oiR9`PCoVHg61OnI
T//2oiZHd0;oXig?1_nTY=D3ojJ/g003o`000?n`]=_o/[cQ00Co/[cQ5oooool00ol0003ooooooooo
o`1:ooooo`00N_ooool2o`0004Oooooo0_nAM:l4oi5f/@GoTGRd1?nBNkL3oi9n^PGoTX2m0_nBPl02
oiN2^`GoUhFn1?nHRL84oiV=aPCoVI;;00?oXYO:oj>MconSWLl00onSWLl5ojBTe@06ojJ/g?n`]=_o
/;CKok2dfol0003o/;CK0onb_>42ok_3h1Kooooo00?o0000ooooooooool0B_ooool007Oooooo0ol0
0015ooooo`;oTG:]1?nAM:l5oi5f/@CoTGRd1?nBNkL4oi9n^P?oTX2m00?oUWnhoiN2^onGP[/00onG
P[/4oiN5_PCoV8W21OnISLH00onIT/_oXYO:oj:GbP02oj:GbPCoXig?1?nTY=D00on_[MKo/;CKok2d
f`02ok2df`03o`000?n`]=_o/[cQ00Go^l?P5_ooool00ol0003oooooooooo`19ooooo`00MOooool2
o`0000;ooooo00?o0000ooooooooool0?oooool2oi5b[0CoTG:]1OnAM:l4oi5f/@CoTGRd1?nBNkL4
oi9n^P03oi:0_OnFOkSoUWnh00;oUWnh1?nGP[/4oiN5_PGoV8W20_nISLH2oj2Ba@GoXYO:1OnSWLl0
0onTY=Go[jgFojn]eP02ojn]eP?o/;CK00?o0000okZngOnk`n001?nk`n000oo0b>7oooooooooo`0E
ooooo`03o`000?oooooooooo04Sooooo001booooo`?o00001Oooool00ol0003oooooooooo`0koooo
o`03oi5b[OnALZcoTG:/00;oTG:/1OnALZd4oi5d[`CoTGJa1OnAN;@4oi9k]`;oTWjj00?oUWbeoiIo
^?nFOkP00onFOkP4oiN2^`GoUhFn0onHRL800onOSL7oX9;5oj2Ba@03oj2Ba@CoXYO:1?nSWLl00on]
Y]7o[jgFojn]eP04ojn]eP03ok2dfonj_]go000000;o^[kM0onk`n03ol38hAKooooo00?o0000oooo
ooooool0B?ooool0073ooooo0_l00012ooooo`;oTWF_0onALZd5oi5b[0CoTG:]1?nAM:l5oi5f/@Co
TGRd0_nBNkL2oiIj/PCoUWbe1OnFOkP4oiN2^`CoUhFn00?oV8W2oin=`OnOSL400_nOSL44oj2Ba@Go
XYO:00?oXig?ojfVdOn]Y]400_n]Y]44ojn]eP04okVjf_nj_]go^[kMo`0000?o^[kM00?o^l?Pol38
hOo0b>400oo0b>4Fooooo`03o`000?oooooooooo04Oooooo000hooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000Pooooo`?o0000@?ooool2oiAi/PCoTWF_1?nALZd4oi5b
[0CoTG:]1?nAM:l5oi5f/@;oTGRd0_nFN;04oiIj/PCoUWbe1OnFOkP4oiN2^`;oUhFn0_nNRKd5oin=
`@CoX9;51?nRUlX00on[XLco[JKAojfVd@03ojfVd@?o[jgF0oni^]X01Onj_]go0000okZngOnj_]go
`<SP00Go`<SQ00?o`/kSooooooooool04oooool3o`0004Sooooo000hooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Nooooo`;o00000ooo
ool00ol0003oooooooooo`0jooooo`03oiIo^?nDNK;oU7Vb00;oU7Vb1OnBMJl3oi5b[@CoTG:/1?nA
LZd5oi5d[`?oTGJa00?oUWJ^oiIh/?nFN;000_nFN;05oiIj/PCoUWbe1?nFOkP3oiN2^`03oif6^_nN
RKgoWXVm00?oWXVm1?nOSL45oj2Ba@03oj:Gb_n[XLcoZj7<00;oZj7<1On]Y]400on_[MKo^K[JokVj
fP03okVjfP03o`000?o0b>3o`<SP00;o`<SP0oo0b>43ol;>haKooooo00?o0000ooooooooool01_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0
:Oooool003Sooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^01cooooo
0ol0000nooooo`;oVHNn0onFOkP5oiAi/PCoTWF_0onALZd4oi5b[0GoTG:]1?nAM:l01?nAM[7oUWJ^
oiIf[_nFMZh5oiIh/0CoUWZb1?nFO;D5oiIo^004oiN2^onMQ[[oWHJjoif6^PCoWXVm1OnOSL43oj2B
a@03ojVLb?n[XLcoZj7<00?oZj7<1?n]Y]400ong]]Oo^K[JokVjfP03okVjfP03ol37gol0003o`<SP
00Co`<SP00?o`<SQol;>hoo2c^<00oo2c^<Fooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Zooooo`00>?ooool01Ol0
003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h06?ooool3o`0003kooooo00?oVhk5
oiV7__nIQkh00_nIQkh4oiIo^0CoU7Vb1?nBMJl3oi5b[@CoTG:/1OnALZd2oi5d[`;oUGB/1OnFMZh4
oiIh/0CoUWZb1?nFO;D4oiIo^003oib3^?nMQ[[oWHJj00;oWHJj1OnNRKd4oin=`@03oj2BaOnYW<So
ZIc800;oZIc81On[XL`00on]Y]7o]kKGokNfe`02okNfe`?o^K[J0_o0aml00ol0003o`<SPol38h002
ol38h0;o`m?V1?o2c^<2okoAiaKooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol0000[ooooo`00>?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool05Oooool3o`0003kooooo1?nKS/D4oiV7_P?oUWnh1?nDNK84oi9e[`?oTG:]1OnA
LZ`3oi5b[@03oiAbZonEM:coUGB/00;oUGB/1OnFMZh4oiIh/0GoUWZb1?nFO;D01?nFOkSoW8>hoib3
^?nLPkP5oif6^PCoWXVm0onOSL400onXV<GoZIc8ojVLb004ojVLb0?oZj7<00?o][;EokNfeong]]L0
1?ng]]L01oni^][o`<OOol37goo0amoo0000ol37goo0b>001Oo3dnH00oo2c^?o_m7WokoAi`03okoA
iaGooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;?ooool003Sooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oo
oooooooo017ooooo0ol00003ooooo`03o`000?oooooooooo03Sooooo0_nMU<X5oi^>a@CoVHNn0onF
OkP4oiAi/PCoTWF_1?nALZd4oi5b[004oi5b[OnDLZ_oU7:[oiAbZ`GoUGB/1?nFMZh4oiIh/0GoUWZb
0_nFO;D2oib1]@GoW8>h1?nMQ[X5oij9_@04oin=`OnXV<GoZ9S5ojRHa@KoZIc800CoZj7<okJbeOnf
/]Go][;E1?ng]]L00oo0a]oo`<OOol37g`02ol37g`03o`000?o4f>Soa=SX00Co`m?V0_o0f^`4okoA
i`03okSAkOoooooooooo01Cooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000_ooooo00CogMgMoeEEEOoooooo0000;?ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41004Oooool2o`0003kooooo00?oWYO<oifDb_nMU<X0
0onMU<X4oi^>a@CoVHNn0onFOkP5oiAi/PCoTWF_0onALZd2oi5b[0;oTW6Z1OnDLZ/4oiEd[0CoUWJ^
1OnFN;03oiIj/P03oi]o/onLPKGoW86e00?oW86e1?nLPkP4oif6^PCoWXVm00?oYYC2ojRHaOnXV<D0
0onXV<D4ojVLb003okF_d_nf/]Go][;E00?o][;E00?o]kKGol36goo0a]l00_o0a]l3ol37g`05o`00
0?o4f>Soa=SXolCHj?o3dnH01Oo0f^`00onodNOo^=7]okSAk@02okSAkAKooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;?ooool003So
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03_ooool3
o`0003cooooo0_nOV<d4oijGc0CoWIC:1OnKS/D4oiV7_P?oUWnh1?nDNK84oi9e[`;oTG:]00?oSfnZ
oi9aZ_nBLJX00_nBLJX5oiAbZ`CoUGB/1?nFMZh5oiIh/004oiIj/_nKOk?oVgncoi]o/`GoW86e1?nL
PkP5oif6^P03oij9_OnVU<;oYYC200;oYYC21?nXV<D3ojVLb0;o]JoB1?nf/]D00onoa]oo`<KOol36
g`04ol36g`03ol37goo4f>So000000;oa=SX0_o0ho44ol3Jk003okONm?nhdNgo^=7]00Co^=7]5?oo
ool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002cooooo
001Iooooo`?o0000>oooool00onOUlcoWiS=oinHc@03oinHc@CoWYO<0onMU<X5oi^>a@CoVHNn0onF
OkP2oiAi/P;oRVf/1?n<KZ/4ohm_ZPCoTW6Z1?nDLZ/4oiEd[0GoUWJ^0onFN;000onKOK7oVgncoi]o
/`03oi]o/`CoW86e1OnLPkP3oif6^P03ojF@`?nVU<;oYYC200?oYYC21OnXV<D00onYW<So]JoBokF_
dP02okF_dP;o][;E0onoa]l4ol36g`;oa=k/00?oa=SXo`000?o4f>P01?o0ho400oo0f^co]mkdokON
m002okONm0Co^=7]00?oZlgbooooooooool04Oooool01?l0003oooooooooool00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0[ooooo`00E_ooool3o`0000?ooooo
00?o0000ooooooooool0=oooool3oinGc0CoWiS=1?nNUl`4oifDbP;oVhk50_n;L:l4ohQ_[`?oR6f^
1?n:KJ`4oha^Z`CoSfnZ1?nBLJX4oiAbZ`GoUGB/1?nFMZh01?nFN;3oVgfaoi]m/OnKOK45oi]o/`Go
W86e1?nLPkP00onMQ[[oYI30ojF@`002ojF@`0CoYYC21?nXV<D00onc[=7o]JoBokF_dP03okF_dP03
okJbeOnoa]oo_lKO00?o_lKO00?o`<KOolCNk?o4g^`00oo4g^`00ol0003o`>?aol3Sl@02ol3Sl@;o
/^Wh1Ongg_@00onhdNgoZlgboj_=lP02oj_=lQKooooo00?o0000ooooooooool0@?ooool005Cooooo
0_l0000mooooo`;oX9O;1?nOUl`4oinHc@GoWYO<0_nMU<X00on>LJgoRg2_oh]`[`02oh]`[`CoR6n_
0on8KJh5ohY][0CoS6j[0on?KjX4oi9aZPCoU7:[1OnEM:`2oiIf[P;oVg^_1OnKOK44oi]o/`GoW86e
0_nLPkP2ojB>_@GoYI301OnVU<800onXV<Go/jcAok>/d@02ok>/d@?o]JoB00?o_lKPoko6gonoa]l0
0onoa]l2olCTkPCoa=k/00Co_Ngco`000?nmkO?o`>?a1OnbjOP2okONm0;oZ=Wi1On[cO8Fooooo`03
o`000?oooooooooo043ooooo001Aooooo`?o0000>oooool2oj2FbPGoX9O;0onOUl`5oinHc@;oWYO<
0_nAL:/3ohia[@GoRg2_1?n8Kjl3ohQ][PCoRVf/1?n<KZ/4ohm_ZP?oTW6Z1OnDLZ/3oiEd[003oiYj
[_nKNjooVg^_00;oVg^_1OnKOK45oi]o/`?oW86e00?oXhbkojB>_OnTS[d00onTS[d4ojF@`0CoYYC2
00?o/ZW?ok>/dOnc[=401?nc[=401?ne[m;o_lKPoko6h?noa^03oko6g`Coa>C^00Goa=k/okg]lonm
kO?o_Ngco`000002ojKamPCo/^Wh00?oWn?lojSInOnXfOT00onXfOT2oj_=lP?oW<Cd5_ooool00ol0
003oooooooooo`0oooooo`00C_ooool5o`0003Wooooo00?oXIK:oj2Fb_nPU/X00onPU/X4oj2Gb`Co
WiO<0_nOV<d2oi9_Z0CoTG2[1?n>LJd4oh]`[`CoR6n_0on8KJh4ohY][0CoS6j[1?n?KjX3oi9aZPGo
U7:[00CoUGB/oiYj[_nJNZkoVWZ^1OnKNjl4oi]m/@GoVgnc00?oW86eoj><^onSS;/00_nSS;/4ojB>
_@GoYI3000?oYYC2ok:YconbZLl00_nbZLl4ok>/d@03okk7hOnoa^3o_lKP00?o_lKP00?o_lKOolCT
k_o4i>h00_o4i>h3okKcl`03okg]lonVlOKo000000?oY_7f00?o/^WhoioSo?nOho`00_nOho`2ojSI
n@?oV<gj1OnLa?@Fooooo`03o`000?oooooooooo03kooooo001<ooooo`;o00001Oooool00ol0003o
ooooooooo`0eooooo`?oXIK:1?nPU/X5oj2Gb`;oWiO<00?oTfjUoi9_Z?nBKjP00_nBKjP5oi5`Z`?o
SW6]1?n;L:l4ohQ_[`?oR6f^1?n:KJ`4oha^Z`CoSfnZ1?nBLJX3oiAbZ`03oiQg[OnJNZkoVWZ^00?o
VWZ^1?nKNjl5oi]m/@?oVgnc00?oXhZjoj><^onSS;/00onSS;/4ojB>_@CoYI3000?o/JO>ok:Yconb
ZLl00onbZLl3ok>/d@?o_/OQ0onoa^03ol;Zl@03olCTk_nflo?o]_?c00;o]_?c0on?knP00ol0003o
Y_7fohoXn@02ohoXn@;oWn?l0onAe?h5oiS=nP;oW<Cd0_nA^o<Fooooo`03o`000?oooooooooo03ko
oooo0019ooooo`?o0000??ooool2oj:GbPCoXIK:1?nPU/X4oj2Gb`04oi9/Y?nCKZGoTfjUoi=^Y@Go
TVnX1?nAL:/3ohia[@CoRg2_1?n8Kjl3ohQ][PCoRVf/1?n<KZ/5ohm_ZP?oTW6Z00CoU7:[oiQg[OnH
MjgoV7N]1OnJNZh4oi]k[`GoVgfa00CoVgncoj>:^_nSR[[oXhZj1OnSS;/5ojB>_@03ojF@`?naYlko
/JO>00;o/JO>1OnbZLl00onc[=7o_/OQokk7h@02okk7h@03oko6h?o2j_7o`^[a00;o`^[a0onXm^d0
1?nflo?oSnoXoho_j?n?knP3ogCQj003o`000?n?j?WoQMWo00?oQMWo1?nAe?h2oiS=nP?oS[kf1?nA
^o<Dooooo`?o0000?oooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Pooooo`;o0000??oo
ool00onRVL_oXYO:oj:GbP03oj:GbP?oXIK:1OnPU/X01?nPUl_oTVbToi9/Y?nBK:@4oi=^Y@CoTVnX
1?nAL:/3ohia[@CoRg2_1?n8Kjl3ohQ][PGoRVf/1?n<KZ/4ohm_ZP;oTW6Z00?oUGB/oiQg[OnHMjd0
0onHMjd4oiYj[PGoVg^_0onKOK400onSRKSoXhZjoj>:^P03oj>:^PGoXhbk0onTS[d00onaY/ko/JO>
ok6WcP03ok6WcPCo/ZW?00?o_/SRokk7hOnnan400onnan401?nnl?;o`^[aol;ZlOo2j_43ojSfk@;o
K]k;0omAc/T2ogCQj003ogCIn_l0003oM=Wj00;oQMWo0on6a?`4oh[1n@GoS[kf1?nA^o<Eooooo`03
o`000?oooooooooo03gooooo000Rooooo`05ogMgMonHV9SooooooiRHV?mgMgL07Oooool3o`0000;o
oooo00?o0000ooooooooool0=_ooool00onSV/coXYW;oj:Ib`02oj:Ib`CoXYO:1?nQU/X2oj2FbP;o
TV^S1OnBK:@3oi=^Y@CoTVnX1?nAL:/4ohia[@CoRg2_1?n8Kjl3ohQ][PCoRVf/1?n<KZ/2ohm_ZP;o
T76/0onEM:`5oiQg[@CoVWZ^1OnKNjl01?nKOK7oXhVhoj>9^?nSRKP5oj>:^PGoXhbk00?oY8jmok6V
c_naY/h00_naY/h5ok6WcP03ok:Yconnb>;o_/SR00;o_/SR0onnan43okk`lP03ol;ZlOnXm^goZ?K]
00;oK]k;0_m9b=h2oeoCk`?oO<Gn00CoPLGmo`000?n1aOgoPLGm1On6a?`4oh[1n@;oS[kf0_n</>h5
ohbbkaGooooo00?o0000ooooooooool0??ooool002;ooooo00Go410@oooooooooooooooooa0@400K
ooooo`;o0000??ooool4oj>Jc0?oXYW;1OnRUlX2oj6FbPGoTV^S1OnBK:@3oi=^Y@CoTVnX1OnAL:/3
ohia[@CoRg2_1?n8Kjl3ohQ][P;oRVf/0_n6JZ`4ohY][0CoT76/1?nEM:`4oiQg[@CoVWZ^1?nKNjl0
0onSQkOoXhVhoj>9^003oj>9^0CoXhZj1?nSS;/00on`Y/go/JK>ok6VcP03ok6VcPCo/JO>00?o_LWT
okk8h_nnb>801?nnb>801?nnan7o__3bokk`l_nnl?82oi;ag`03o`000?miaOkoNLGn00CoNLGn1Oml
aOh01?l0003oPLGmoh75oOn1aOd2ohK4o0;oS:_Z1On<[^d4ohb`kPGoS;;_5Oooool00ol0003ooooo
ooooo`0kooooo`008_ooool01Ol0003ooooooooooooooooo000001Sooooo0ol0000looooo`03ojBJ
bonSV/coXi[<00?oXi[<0onRVL/4oj:GbP03oi9/Y?nBJj?oTV^S00KoTV^S1?nBK:@3oi=^Y@CoTVnX
1OnAL:/2ohia[@03ohm/Y_n:JZSoRVZX00;oRVZX1?n5J:/3oh=X[0CoQVZ/1?n:KJ`5oi1a[0?oUGB/
1?nHMjd5oiYj[P;oVg^_0_nSQkL5oj>9^0GoXhZj0_nSS;/3ok2Vc@Go/JK>00?o/JO>okg9i?nmbN@0
0_nmbN@4okk8hP;o]oCb00?o__3boi;agonBlMl00_mka?h8ogW5oP;oO<Gn0_n<X^<01?l0003oS:OW
ohbWion<YnL5ohb[jPGoS:k]1?n</>h2ohbbk`;oSjo/5Oooool00ol0003oooooooooo`0kooooo`00
8_ooool01Ol0003ooooooooooooooooo000001Kooooo0ol0000kooooo`03oj>GbOnTV/_oY9[;00;o
Y9[;1?nSV/`4oj:Ib`04oj:Gb_nBK:CoTVbToi9/Y0SoTV^S1?nBK:@3oi=^Y@GoTVnX0onAL:/01?nC
K:?oSfbVohm/Y_n?K:H4ohYZZ0CoQFR[0on3J:`5ohIZ[0CoRVf/1?n@LJ`3oiEd[0CoV7N]1OnJNZh0
0onKNjooXhNgoj>7]`02oj>7]`CoXhVh1OnSR[X00onSS;_o/:K=ok2Vc@02ok2Vc@Co/JK>00?o_<cV
okg9i?nmbN@01?nmbN@01Onnb>;o]oCbokOdl_ngm?;oMN7700;oOl;m0_mka?h00onAU=?oSiWIohnI
f@02ohnIf@CoSYkN1?n<X^<00ol0003oS:OWohbWi`02ohbWi`GoS:_Z0_n<[^d2oi6ThPCoT:WW1On?
[n`Eooooo`03o`000?oooooooooo03[ooooo000Rooooo`05oa0@4?ooooooooooooooool@41004ooo
ool3o`0000;ooooo00?o0000ooooooooool0=oooool4oj>Gb@?oY9[;1OnSV/`2oj:Ib`03oi9^YOnB
K:CoTVbT00;oTVbT2?nBJj<4oi9/Y0CoTfjU1?nBKjP01?nAL:_oTfbSoi=/XonCK:<4ohm/YPCoRVZX
1?n5J:/3oh=X[0CoQVZ/1?n:KJ`4oi1a[0?oUGB/1OnHMjd3oiYj[P03oj:5]OnSQkOoXhNg00?oXhNg
1OnSRKP3oj>:^P03ok6VcOn`Y/go/:K=00?o/:K=0onaY/h3okc<iPCo_LWT0on/m^l00ongm?;oTi3=
oi>@c@02oi>@c@CoTICC1?n?VMT4ohjNgP?oS:;S00?o0000ohbRhon<YnL00on<YnL2ohb[jP;oTYkL
1OnAY>84oi2Yi`CoSjo/5_ooool00ol0003oooooooooo`0iooooo`008_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg013ooooo0ol0000mooooo`03oj:Ba?nSUlWoXiO900?oXiO91?nTV//2oj>Jc0;oU72X
0onBKZD5oi9/Y0OoTV^S1OnBK:@3oi=^Y@;oTVnX0_nEJj04oi=/X`CoSfbV1?n:JZP4ohEXZ`?oPfR/
1?n6JZ`4ohY][0CoT76/1?nEM:`4oiQg[@03oiYj[_nRQKGoXXFe00;oXXFe1?nSQkL5oj>9^003oj>:
^_naY/go/JK=00;o/JK=1On`Y/d00onaY/ko_<cVokc<iP03okc<iP04okg9i?n/m^oo[?K_ojcfk`Co
UHc70onCT<d4oi6Dd`GoSiWI1?n>W]h2ohbRh`03o`000?nDTm3oTiWG00?oTiWG1OnBW]`5oi6ThP?o
T:WW0_n?[n`3oiR_j1Cooooo0_l0000kooooo`008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00ko
oooo0_l0000mooooo`03oj2;_OnRT/CoXY;400;oXY;41?nSUlT3ojBJb`03oiMdZ_nDL:SoU72X00;o
U72X1?nBKZD4oi9/Y0OoTV^S1OnBK:@2oi=^Y@03oiAZW_nEJj3oUF^P00;oUF^P1?nCK:<4ohm/YPCo
RVZX1?n5J:/3oh=X[0CoQVZ/1?n:KJ`4oi1a[0CoUGB/0_nHMjd2oin2]0GoXXFe1OnSQkL3oj>9^003
ok:Vc?naY/go/JK=00?o/JK=1?n`Y/d2okc?j0Co_<cV0_nLm>H00ol0003oUXS2oiJ8`P04oiF<a`Co
Ti3=1?nAU=<2ohnIf@;oUX[51?nES//2oiBCd003o`000?nDTm3oU9?@00CoTiWG1OnBW]`2oi6ThP;o
VJ3I0onHYn06oiR_j1Gooooo00?o0000ooooooooool0>?ooool003;ooooo1Ol0000kooooo`CoX8^m
0onRT/@5oj>Gb@03ojBJbonGM:[oUgBZ00GoU72X0onBKZD4oi9/Y0SoTV^S1?nBK:@00onCKZGoU6ZN
oiAZWP04oiE[X0CoTfbS1?n?K:H4ohYZZ0CoQFR[0on3J:`4ohIZ[0CoRVf/1On@LJ`2oiEd[003oiYn
/onOP[CoWh:d00;oWh:d1OnRQKD5oj>7]`03oj>9^?nbY/co/ZK<00;o/ZK<1OnaY/d00on`Y/go_<oX
okc?j003okc?j004okc<i_nLm>KoW?CVoiR4_@CoUXS21?nES<L4oi>@c@;oTICC0_nGQ[l5oiJ:a@Co
UHk;0_l00002oiBCd0GoTiWG0_nBW]`2oiVIdPCoVJ3I1?nHYn04oiR_j003oj:diOoooooooooo01Co
oooo00?o0000ooooooooool0=oooool0033ooooo0_l0000nooooo`03oif4]onPRkgoX8^m00?oX8^m
1?nRT/@2oj>Gb@;oVWV]1?nGM:X4oiA`Z0?oTVjU1?nBK:@8oi9[X`?oTVbT00CoTfRMoiAZW_nDJYko
U6ZN1OnEJj04oi=/X`?oSfbV1?n:JZP4ohEXZ`?oPfR/1On6JZ`4ohY][0CoT76/00CoUGB/oiYn/onJ
O[?oVWjc1?nOP[@5oj:5]@?oXhNg00?o/ZG<ok:Vc?nbY/`00onbY/`4ok6Vc@;o_MC[1?nlcnP2ohG[
e@?oV8Bm1?nFR<85oiF<a`;oTi3=00?oV8>koiN6_onGQ[l00onGQ[l4oiJ:a@06oiF>bol0003o0000
o`000?nDTm3o00000onDTm02oi>Ie`;oVY?;1?nIVM85oiVPf@CoV:OP00?oV:oXoj:diOnR]>D00_nR
]>DEooooo`03o`000?oooooooooo03Oooooo000]ooooo`?o0000?Oooool00onKO[;oWHBgoif4]`02
oif4]`CoX8^m0onRT/@00onNO:koVWV]oiYi[@02oiYi[@CoUgBZ1?nDL:P3oi9^Y@CoTVbT2?nBJj<0
1?nBK:CoTfRMoi=XWOnCJ9d4oiAZWPCoUF^P1?nCK:<4ohm/YPCoRVZX1?n5J:/3oh=X[0CoQVZ/1?n:
KJ`2oi1a[0;oTgVc1?nJO[<4oin2]0GoXXFe00?oXhNgok:Uc?nbYL`00_nbYL`5ok:Vc003ok6VcOnm
e>_o_MC[00?o_MC[00Co_<oXohG[eOn5jmGoV86h1?nHQ;d5oiJ8`P;oUHc70_nIOkH4oiR3^`CoUhJo
0_nFR/D3o`0000CoUHk;00CoU9?@o`000?nJSLGoVXg51OnJTl/4oiVIdPCoVJ3I0_nHYn03oj:/gPGo
X[CU5Oooool00ol0003oooooooooo`0fooooo`00;?ooool2o`0003gooooo0onKO[84oif4]`GoX8^m
00?oXY;4oiil[_nNO:h01OnJNJd3oiMdZPCoU72X0onBKZD5oi9/Y0KoTV^S00?oTFJLoi=XWOnCJ9d0
0_nCJ9d4oiAZWPCoUF^P1?nCK:<4ohm/YPCoRVZX1?n5J:/3oh=X[0;oQVZ/0_n6K[04ohac/PCoTgVc
1?nJO[<4oin2]0CoXXFe00?o/JC;ok:Uc?nbYL`00onbYL`4ok:Vc0;o_mW]1?nme>/2of_J^P?oV86h
1OnHQ;d2oiJ8`P;oVWfc1OnIOkH3oiR3^`?oUhJo0ol00003oiJ:a@;oUHk;0_nKRKl2oiZ=a@03o`00
0?nJSLGoVXg500CoVY?;1?nIVM82oiVPf@;oXjGG1_nR[=h2oj:di@?o[K_T5Oooool00ol0003ooooo
ooooo`0eooooo`00;?ooool3o`0003[ooooo00?oVWZ^oi]n/_nKO[800onKO[83oif4]`CoX8^m00?o
XGj]oiil[_nNO:h00_nNO:h4oiYi[@?oUgBZ1?nDL:P4oi9^Y@CoTVbT1?nBJj<3oi5VW0CoTfRM1?nD
JYh4oiE[X0CoTfbS1?n?K:H2ohYZZ0;oT6nZ1?n8K:d3ohA[[`CoQVj`1?n<Lk85oi=i/`CoVWjc1?nO
P[@2oj:5]@?o/JC;1OnbYL`00onbY/co_mW]okoIk@03okoIk@03okgDjom[f[[oJmZj00;oUgfd1?nH
PKP3oiR4_@03oiYk/?nJOK?oVWfc00;oVWfc1OnIOkH3oiR3^`?o00000_nGQ[l2oiJ:a@;oVhFj1OnK
RKl2oiZ=a@03o`000?nJSLGoVY?;00CoVY?;0_nIVM800onSW]3oXjGGoj>Ue`03oj>Ue`CoXZcN00?o
[KCOojfki?n]^n@01?n]^n@Dooooo`03o`000?oooooooooo03Gooooo000/ooooo`04o`000?oooooo
0000o`0003Kooooo00CoVWR/oiYj[_nJNZkoVWZ^1OnKO[84oif4]`04oj2;_OnQOZgoXGj]oj5n[@Co
WWb^1?nJNJd3oiMdZPGoU72X0onBKZD4oi9/Y0;oTV^S00?oSfBLoi5VW?nAIY`00_nAIY`4oi=XW@Co
U6ZN1?nEJj04oi=/X`;oSfbV0_nGLZL4oi1_ZPCoR6b]0on4Jjl5ohI^/0CoS7>b1?nCNK<4oiYn/`Co
Wh:d00?oXXFeok6TbonaY</00_naY</4ok:Uc0;o`Mk^1?nofNd00ol0003oUWV`oiMm]004oiMm]0?o
V86h00CoV8BmoiYk/?nJNk3oVW^`1OnJOK<4oiUo]P?o000000GoV8>koiN6_onGQ[ooUhJooib1]P05
oi^5^PCoVhVo0_nJSLD00ol0003oVXg5oiZCb`03oiZCb`03oj>Ib_nSW]3oXik@00;oXik@1OnSYML0
0onR[=ko[KCOojfdg`02ojfdg`Co[K_T00?o]<;Uooooooooool04Oooool00ol0003oooooo`000008
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@
olc<c00Iooooo`00;?ooool2o`0000;ooooo00?o0000ooooooooool0<Oooool3oiYh[0CoVWZ^1?nK
O[84oif4]`GoXGj]0onNO:h4oiYi[@CoUgBZ1?nDL:P3oi9^Y@;oTVbT0_n=Hid3ohmTW0GoTFJL0onC
J9d4oiAZWPGoUF^P0onCK:<4oiMbY`GoT6nZ1?n8K:d3ohA[[`CoQVj`1?n<Lk84oi=i/`CoVWjc0onO
P[@00on]WlWo/JC;ok6Tb`03ok6Tb`?o/ZG<1?o1g^h00onofNgoUWV`oiIi/002oiIi/0GoUgfd0_nH
PKP00onKNJgoVW^`oiYk/003oiYk/0CoVWfc00GoVGnfo`000?l0003o0000oiUo]P03oiR3^`04oiN6
_onLPKKoW86foib1]PGoVhFj1?nKRKl3oiZ=a@03o`000?nJSLGoVY?;00?oXiW:1?nSW]04oj>Ue`03
ojf_fOn]]=oo[KCO00Co[KCO00?o[K_TokC2iOnd`^D00_nd`^DEooooo`03o`000?oooooooooo00Go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So
8B4Q01Wooooo000[ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;_ooool6oiYh
[0?oVWZ^1OnKO[82oif4]`03oj9n[?nQOZgoXGj]00?oXGj]0onNO:h4oiYi[@CoUgBZ1?nDL:P2oi9^
Y@03ohaSW_n=HigoSF>M00;oSF>M0on?I9`5oi5VW0CoTfRM0onDJYh5oiE[X0;oTfbS00?oW7BToiMb
YonGLZL00onGLZL4oi1_ZPCoR6b]0on4Jjl4ohI^/0CoS7>b1OnCNK<4oiYn/`04oin2]?n]WlWo[Io9
ojfOb@Go/JC;00?o/ZG<ol7Nk_o1g^h00_o1g^h2oiAe[@GoUWV`0onGOK@01?nKN:_oVgV]oi]i[OnK
NJd5oiYk/0?oVWfc0_l00004oiUo]P;oV8>k00?oW7jboib1]_nLPKH00onLPKH4oi^5^PGoVhVo0_nJ
SLD00onTU<Go0000oj>IbP04oj>IbPCoXik@00?oXjGGojf_fOn][mT00_n][mT4ojfdg`03okG0h_nd
`^Go]<;U00?o]<;U5Oooool00ol0003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000001Wooooo000[ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0;?ooool7oiYh[0?oVWZ^1OnKO[801?nMQ;OoXWj/oj9n[?nROZ`4oj5n[@?o
WWb^1OnJNJd3oiMdZP;oU72X0_n;I:03ohaSWPCoSF>M1?n?I9`4oi5VW0CoTfRM1?nDJYh4oiE[X004
oi=/XonLM:CoW7BToiadY0CoUg:W1?n@KjX4ohQ/[@?oQ6^_1?n6K[04ohac/PGoTgVc0_nJO[<2ojJH
a`Co[Io91?naY</3ol;QkP03ol7Nk_nCLJWoU7F]00;oU7F]1OnFNK001?nGOKCoVgR[oi]hZonKN:/4
oi]i[@CoVW^`0ol00002oiYm/`?oVGnf00CoWGb_oian/_nLO[;oW7jb1OnLPKH5oi^5^P?oVhVo00Ko
Y970ojBDaOnTU<GoY9C5o`000?nTU<D4oj>IbP;oXik@0_n]ZmD6ojf_f@03ojfdgone`>;o]L3R00;o
]L3R0ond`^D2okS9iaGooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Iooooo`00:oooool3o`0000Gooooo00?o0000oooo
ooooool0:?ooool2oiYi[0SoVWR/1?nJNZh3oi]n/P03oj9mZonROZcoXWj/00;oXWj/1?nQOZd4oiil
[PCoVWV]0_nGM:X00on=J:?oRfBPoh]TX002oh]TX0?oS6>N1?n=Hid4ohmTW0CoTFJL1?nCJ9d4oiAZ
WP?oUF^P00?oWG>RoiadY?nLM:@00_nLM:@4oiMbY`CoT6nZ1?n8K:d3ohA[[`GoQVj`1?n<Lk83oi=i
/`03oib?a?nVV<OoYYS700?oYYS71?n]WlT00onaY<_o`^7^ol;QkP02ol;QkP?oTg6Y1?nDMJd3oiIi
/003oiYfZ?nKN:_oVgR[00?oVgR[0onKNJd01?nJNk3o0000o`000?l00005oiYm/`04oiUo]_nMO:oo
WGb_oiel[`CoW7jb1?nLPKH5oi^5^P03oi^9_onTTL3oY97000;oY9700onTU<D01Ol0003oXiW:oj>I
b_nSVL[o[ZOA00Go[J_E1?n][mT00onf_^3o]L3RokG0hP03okG0hP03okC2iOnhbNOo^<WW00?o^<WW
5Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003o
EEEEo`000?l@413oc<c<01Wooooo000[ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool09?ooool00onLNjkoVWV/oiYi[002oiYi[0SoVWR/1?nJNZh01?nKO[;oXWf[oj9mZonROJ/4oj9n
[0GoXGj]0onNO:h2oiYi[@;oTFfV0on=J:<4oh]TX0CoS6>N0on=Hid4ohmTW0CoTFJL1?nCJ9d4oiAZ
WP04oiE[X?nMLj;oWG>RoiecXPCoW7BT1?nGLZL4oi1_ZPGoR6b]0on4Jjl4ohI^/0CoS7>b00?oTgVc
oib?a?nLSl@00_nLSl@4ojJHa`?o[Io90_o0h?03ol;QkPCoTg6Y1?nDMJd01?nFNK3oVWJXoiYfZ?nJ
MZP5oi]hZ`04oi]i[Ol0003o0000o`0000CoVW^`0onJOK<00onMNjgoWGb_oiel[`03oiel[`?oW7jb
1OnLPKH3oi^5^P03ojF>_?nTTL3oY97000?oY9701?nTU<D00ol0003oXiW:ojjWd@02ojjWd@Go[J_E
00?o[JoIokJnh?nf_^000_nf_^03okG0hP;o^LgY1?nhbNL00onec>_oooooooooo`0Cooooo`03o`00
0?oooooooooo00?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo01_o
oooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08_ooool2oiak[PGoVWV/
2?nJN:`2oiYj[P03oimjZ_nROJ_oXWf[00;oXWf[1?nROZ`5oj5n[@;oWWb^00?oV7>Xoi5]Y_nAKJH0
0_nAKJH3oheXX`CoRfBP1?n<Hih3oheSW@CoSfBL1?nAIY`4oi=XW@?oU6ZN00?oW76QoiecX_nMLj80
0onMLj83oiadY0CoUg:W1On@KjX4ohQ/[@?oQ6^_0_n6K[02oh]l_@CoTHC11OnLSl@5ojJHa`03ojfO
bOo0h?3o`>3`00;o`>3`00?o`^7^oi1]Y_nCLJT01?nCLJT2oiAe[@03oiYdYonJMZSoVWJX00?oVWJX
0_nKN:/3o`0000;oVgV]1OnJNk001?nJOK?oWG^]oiek[OnMNjd5oiel[`?oW7jb1OnLPKH00onKQK[o
YHjlojF>_002ojF>_0CoY9701?nTU<D00on_YLko0000ojjWd@02ojjWd@Co[J_E00?o]kkOokJnh?nf
_^001?nf_^000one`>;o^LgYokW=j@02okW=j@03okS9ionec>_o]Lc[00;o]Lc[4oooool3o`0000Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01_ooooo000@ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07oooool00onMO[3oW7^^oiak[P02oiak
[PCoVWV/2?nJN:`00onJNZkoWgZZoimjZP04oj9mZ`GoXWj/0onQOZd01?nNNJWoV7>XoiQcZ?nHLjP4
oi5]YPCoSFRS0on;I:04ohaSWP?oSF>M1?n?I9`4oi5VW0CoTfRM0_nDJYh2oiaaX@GoWG>R0onLM:@5
oiMbY`CoT6nZ0_n8K:d2oi1j^0?oRGRj1On;O;d4oi64`@CoW8o41?nVV<L2ok_Kl0?o`>3`1?n@KJH4
oi=aZ@03oiAe[OnJM:OoVWBW00CoVWJX0ol00002oi]hZ`CoVgV]0onJNk000onNNZ_oWG^]oiek[@03
oiek[@CoWGb_1?nLO[83oib1]P03ojF<^OnUS[coYHjl00?oYHjl1OnTTL001OnTU<Go[jG>ojnUc_n_
YLko000000Co[ZOA00?o[J_EokNngong_]l00_ng_]l4okJnh003ok[Ck?nicNWo^LgY00;o^LgY0_nf
e>l5okG<jaGooooo00Wo0000ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<
c<coA4A4o`000?l@410Iooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47
ooooo`03o`000?oooooooooo00Cooooo0ol0000:ooooo`03o`000?oooooooooo01gooooo0_nMO[04
oiak[PCoVWV/1onJN:`00onLN:WoWgZZoimjZP02oimjZPCoXWf[1?nROZ`01?nQOZgoWWVYoiiiZOnN
NJT4oiQcZ0?oTFfV1?n=J:<3oh]TX0CoS6>N1?n=Hid3ohmTW0GoTFJL0onCJ9d01?nDJYkoW76Qoiaa
XOnLLJ45oiecXPCoW7BT1?nGLZL2oi1_ZP;oVX2f1?n@N[P4ohUh^PCoRgbm1?nAQ<45oib?a003ojJH
aonkfo3o^m_`00?o^m_`00?o`>3`ohmYXon@KJH00on@KJH2oi=aZ@;oVG:U1?nJM:L3o`000003oiYf
Z?nKN:_oVgR[00;oVgR[1?nKNJd01?nJNk3oWWZ[oiijZonNNZ/5oiek[@CoWGb_1?nLO[800onLPKKo
YHbiojF<^@02ojF<^@CoYHjl1?nTTL000onaY<co[jG>ojnUcP03ojnUcP04o`000?n^Ym7o[ZOAokVo
g`Ko]kkO00?o][kPok[Ck?njdn`00_njdn`00onicNWo]]C_okKDk`03okKDk`;o]Lc[0_n_c>lEoooo
o`03o`000?oooooooooo02oooooo0008ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@
00_ooooo1Ol00005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06Oooool2oin1
/PCoWGj`0onLNjh4oiYi[0GoVWR/0onLN:T4oimjZPCoXWf[0onROZ`00onSOJ[oWWVYoiiiZ@02oiii
Z@CoV7>X0onAKJH4oheXX`CoRfBP0on<Hih4oheSW@?oSfBL1OnAIY`2oi=XW@03oiU_X?nLLJ7oW76Q
00?oW76Q1?nMLj84oiadY0?oUg:W00?oYHNdoiZ0]_nJP;H00_nJP;H5oi1j^0?oRGRj1?n;O;d4oi64
`@CoW8o40_n`co04ok_Kl0?oSfVS0on@KJH00onGKj?oVG:UoiUbY@02oiUbY@;oVWBW0_l00004oiYf
Z0GoVgR[0_nKNJd00onNNJWoWWZ[oiijZ`03oiijZ`CoWG^]1OnMO:l2oian/P03ojJ:]onUS;WoYHbi
00?oYHbi1OnUS[`00onTTL3o/JC<ok6Tc002ok6Tc0Co[jG>00?o[ZOAo`000?ni_ml00_ni_ml4okNn
g`03ok_Jkonjdnco^]?/00;o^]?/0_negO@4okKDk`03ojgEmOn_c>oo[lc_00?o[lc_5Oooool00ol0
003oooooooooo`0^ooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgM
gOoooooo00001_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Gooooo00?oXHBe
oin1/_nOPK800_nOPK84oien/0?oW7^^1OnJNJ`2oiYh[003oiYfZOnLN:WoW7RY00;oW7RY1?nONZX4
oj9mZ`;oXWj/0_nSOJX4oiiiZ@CoV7>X1?nAKJH3oheXX`CoRfBP0on<Hih4oheSW@CoSfBL1?nAIY`0
0onCJ9goVFnPoiU_X005oiaaX@CoWG>R1?nLM:@01?nGLZOoYHNdojF7]?nUQk@5oiZ0]PCoT7Zh0on9
N;X5oh]l_@CoTHC100?oW8o4ok3?l?n`co000on`co000onkfo3oSFNQoheWX@03ohmYX`04oi1]Y_nG
Kj?oUfnSoiM_X`?oVG:U0ol00002oiYdY`CoVWJX1OnKN:/01?nKNJgoWWVYoiiiZOnNNJT4oiijZ`Co
WG^]1OnMO:l01?nLO[;oYXZgojJ:]onVR[L4ojF<^@CoYHjl00?o/ZG;ok6Tc?naY<`00onaY<`3ojnU
cP03ok_2goni_moo000000Co^KoO00?o]kkOok_Jkonkf^l00_nkf^l00onjdnco]MgdokGMm003okGM
m003okKDkon]eOGo[MGe00;o[MGe0_n_c>l3ojG5l1Gooooo00?o0000ooooooooool0;Oooool0013o
oooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Cooooo`;oXHBe1?nOPK84oien/0?oW7^^1OnJNJ`0
0onJN:coVWJYoiYfZ@04oiahZ@CoWgZZ1?nROJ/00onROZcoXgfZoj=mZP02oj=mZP?oWWVY1?nHLjP4
oi5]YP?oSFRS1?n;I:03ohaSWPCoSF>M1?n?I9`3oi5VW004oiE[X?nIKj3oVFnPoiU_X0GoW76Q1OnM
Lj83oiadY0GoYHNd1?nJP;H4oi1j^0CoRGRj1?n;O;d2oi64`@?oXKk^1?n`co04oheWX@;oSfVS00?o
UVfQoiM_XonGKj<00_nGKj<3o`0000;oVG:U0onJM:L5oiYfZ0?oVgR[00?oWWVXoiiiZOnNNJT00_nN
NJT4oiijZ`GoWG^]0onMO:l00onWRKGoYXZgojJ:]`02ojJ:]`GoYHbi0_nUS[`3ok:Ub`Go/JC<00Ko
[jG>ok_2gonk`]oo^l;OokVogol00002okVog`?o^nCc0_nkf^l3ok3Wn0;o]Mgd1?nWgoX2ojgEm@;o
X/cf1OnUaO0Dooooo`03o`000?oooooooooo02gooooo000@ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00omgMgOoc<c<o`000006ooooo`;o00003oooool2o`00017ooooo00?oXXNgoj64]OnQ
Q;D00_nQQ;D4oin1/P?oWGj`1?nLNjh3oiYi[003oiQeZ_nJMZWoVWJY00;oVWJY1?nLN:T3oimjZPCo
XWf[1OnSOJX4oiiiZ@?oV7>X1?nAKJH3oheXX`CoRfBP1?n<Hih3oheSW@CoSfBL00CoTFJLoiE[X?nE
Jj3oUF^P1?nIKj04oiaaX@GoWG>R0_nLM:@00on_S[?oYHNdojF7]003ojF7]0CoVX2f1On@N[P3ohUh
^P;oRgbm0_nG[^L6oj6nkP03ok3?l?n;I9ooRfBO00CoSFNQ00CoSfVSoiI]XOnFKJ7oUfnS0ol00000
0onGKj?oVG:UoiUbY@02oiUbY@?oVWBW1OnJMZP01?nKN:_oWWVXoiiiZ?nNNJP4oiiiZ@CoWWZ[1OnM
Njd00onMO:ooYhVeojN9]@02ojN9]@?oYXZg1OnUS;T00onUS[co/ZG;ok:Ub`02ok:Ub`Co/JC<00?o
_/SRok_2gonk`]l00onk`]l00oni_moo0000ok_Tl`02ok_Tl`03oj?^mon`ioSo/>Oh00;o/>Oh0_nK
i_`4ojOOnP03oigAn_nRc?KoX/cf00?oX/cf0_nUaO02oijnkaGooooo00?o0000ooooooooool0;?oo
ool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`?oXXNg1?nQQ;D4oin1/PCoWGj`0onL
Njh01?nJNJcoV7FZoiQeZ_nHMJX4oiYfZ@CoW7RY1?nONZX2oj9mZ`03ojAnZ_nSOJ[oXgfZ00?oXgfZ
1?nNNJT4oiQcZ0?oTFfV1?n=J:<3oh]TX0CoS6>N0on=Hid3ohmTW003oi1XX?nEJj3oUF^P00;oUF^P
1?nIKj04oiaaX@GoWG>R00CoW7BTojn>/on_S[?o[hjc1?nUQk@5oiZ0]PCoT7Zh0_n9N;X00onBXn3o
UjkWoiN^i`03oiN^i`CoXKk^00CoRF6Moh]TWon;I9ooRfBO0_n=Ij42oiA[W`04oiI]XOl0003o0000
o`0000CoUfnS1?nILZD4oiYdY`?oVWJX00?oWgVXoiiiZ?nNNJP00onNNJP4oiiiZ@CoWWZ[0onMNjd0
0onWRKCoYhVeojN9]@03ojN9]@CoYXZg0onUS;T00oneYl_o/ZG;ok:Ub`04ok:Ub`03ok6Tc?nnb>;o
_/SR00;o_/SR0onk`]l3okK_mP03o`000?nSk_OoXnkg00;oXnkg00?o/>Ohoi_Vo?nKi_`00onKi_`0
0onWgo[oWM7joigAnP02oigAnP;oX/cf0_nL_o45oijnka?ooooo0_l0000^ooooo`004?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Wooooo00?oY8^joj:7]onRQkL00onRQkL3oj64]@CoWh6b1?nMO[02
oiak[P03oiMf[?nHMJ[oV7FZ00;oV7FZ1?nJMZT4oiahZ@CoWgZZ00CoXWf[ojAnZ_nTOZ[oY7jZ1?nS
OJX4oiiiZ@CoV7>X0onAKJH4oheXX`?oRfBP1?n<Hih3oheSW@04ohmTW?n@J:3oT6RPoi1XX0CoUF^P
1?nIKj04oiaaX@GoWG>R1?n_S[<5ojF7]0CoVX2f0_n@N[P2oiZQf@CoTZ?P1OnG[^L01?nQ_^koRF6M
ohUQWOn9HId2oh]TW`03oi5WW_nDJiooU6^O00?o00000onFKJ44oiM_X`CoVG:U1?nJM:L01?nJMZSo
WgVXoimiZ?nONJP5oiiiZ0CoWWVY1?nNNZ/01?nMNjgoYhVdojN9]?nWRK@5ojN9]@CoYXZg00?oYHbi
okFWboneYl/00_neYl/4ok:Ub`03ol3Aionnb>;o_/SR00?o_/SR00?o^l;OokK_m_nfkoH00_nfkoH0
1?n4j^Oo0000oj?^monSk_L2oh;Um0;oQmKo1OnDeOh2oigAnP?oVKob1?nL_o44oijnkaGooooo00?o
0000ooooooooool0:oooool002Wooooo0_l0000Dooooo`03o`000?oooooooooo00Oooooo0onTRkX4
oj:7]`CoXHBe0onOPK82oien/0;oUgN^0onGMZ`4oiQeZPCoVWJY1?nLN:T3oimjZP03oj9mZ_nTOZ[o
Y7jZ00;oY7jZ1?nSOJX4oiiiZ@CoV7>X0onAKJH4oheXX`?oRfBP0_n<Hih2ohMRX@?oS6FP1?n@J:04
oiE[X0CoVFnP1OnLLJ43oiecXP03ok>B]?n_S[?o[hjc00;o[hjc1OnUQk@2oiZ0]P;oYjKE1OnJXMT4
oi:Sh0;oUjkW0_n9Gi/2ohUQW@;oSfBL0_nAIih3o`0000;oU6^O1?nFKJ44oiM_X`GoVG:U0onJM:L5
oimiZ0CoWWVX1?nNNJT4oiijZ`GoYhVd1OnWRKD2ojJ:]`03okN[cOneYl_o]JO;00?o]JO;0onbYL/3
ol3Ai`?o_/SR0onTmNh01_nfkoKoQ>[WohCZion4j^OoFmCKo`0000?oN];o0on7e_l2oiCEoP?oU[cb
1OnI_o84oibol@;oW[k_0_nL^NdEooooo`03o`000?oooooooooo02[ooooo000Yooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool01?ooool00onVS[coY8^jojB;^P02ojB;^PCoXXNg1?nQ
Q;D2oin1/P03oiQi/?nGMjkoUgN^00;oUgN^1?nGMZ`4oiQeZP?oVWJY1?nLN:T01?nONZ[oXWfZoj9m
Z_nROJX4ojAnZPGoXgfZ0onNNJT2oiQcZ0;oTG2Z0on7IjL4oh=SY0?oPf6R1?n7HZ43ohaUX0GoT6RP
0onEJj04oiU_X0GoW76Q0_nMLj83ok>B]0Co[hjc0onUQk@00onf/=;oYjKEojNVe@03ojNVe@GoVZ7I
0_nBXn000on9GY[oREnKohUOV`02ohmSV`CoSfBL0_l000000onAIikoU6^OoiA[W`03oiA[W`?oUVfQ
1?nGKj<5oiUbY@;oVWBW00?oX7VXoimiZ?nONJP00onONJP4oiiiZ0GoWWVY0_nNNZ/00onXRKCoYhVd
ojN9]003ojN9]0GoYhVe00CoYXZgokN[cOngZlgo]j_=1OneYl/00onbYL_o`=7Wol3Ai`03ol3Ai`03
okk8h_nTmNkoY?G^00;oD<^l00?oJlOnofk=o_m^cOh00_m^cOh01?mjd_oo0000oi:`jonB/>/4oi>g
l0GoU[cb0_nI_o82oiZbj0CoVkK[1OnL^NdDooooo`03o`000?oooooooooo02[ooooo000Yooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool00_ooool3ojJ>_0?oY8^j1OnRQkL2oj64]@04
oiUl/_nHNK3oV7V`oiQi/0CoUgN^1?nGMZ`4oiQeZPCoVWJY0_nLN:T00onONj_oXWfZoj9mZP03oj9m
ZP?oY7jZ1OnSOJX2oiiiZ@03oi]h[?nAL:[oTG2Z00;oTG2Z0on7IjL4oh=SY0?oPf6R1?n7HZ43ohaU
X0GoT6RP1?nEJj03oiU_X0GoW76Q00?oWG>Rok>B]?ncT[@00_ncT[@4ojn>/`03ojF7]?nf/=;o][3B
00;o][3B1OnWY]D2oiZQf@;oR5bH0_n9GYX00on@HiWoSf>KohmSV`02ohmSV`04ohmTW?l0003o0000
o`0000CoTFNN1?nDJil3oiI]X@GoUfnS1?nILZD01?nJM:OoX7VXoj1iZ?nPNJP4oimiZ0CoWWVX1OnN
NJT01?nNNZ_oZ8VdojR9]?nXRK@4ojN9]0CoYhVe00?o^[7@okN[cOngZld00_ngZld4okFWb`;o`Mk]
1?o0dNL3ofnnoP;oJlOn0_nCVmT4oi6Vh`;oT[3[00?o0000oi:`jonB/>/01?nC]o02oiJllP;oVZgT
1OnJ/^P4oi^fj`;oW;W]0onN]nTDooooo`03o`000?oooooooooo02Wooooo000Yooooo`03o`000?oo
oooooooo01Kooooo00?o0000ojRB_onXT[l01?nVS[`4ojB;^PCoXXNg00?oXHBeoiUl/_nIO;801?nH
NK03oiMg[PCoUgJ/1?nHMJX4oiYfZ@03oiahZOnONj_oWg^[00GoXWfZ0onTOZX4oj=mZP04oj9o[OnK
N:coVgR/oi]h[0CoTG2Z1?n7IjL3oh=SY0?oPf6R1?n7HZ44ohaUX0CoT6RP1?nEJj04oiU_X0?oW76Q
00?o]9Fhok>B]?ncT[@00oncT[@4ojn>/`Go][3B1?nWY]D00on8FYKoR5bHohQLV002ohQLV003ohUN
V_n@HiWoT6>I00;oSf>K0ol00003ohmTW0CoTFNN1?nDJil3oiI]X@GoUfnS0onILZD5oj1iZ0CoWgVX
1OnNNJP3oiiiZ@03ojV;]OnXRKCoZ8Vd00;oZ8Vd1OnWRK@2ojN9]@?o^[7@1?ngZld00oneYl_o`Mk]
ol7Nk@03ol7Nk@03ol3AionGQl7oU93=00?oU93=1OnCVmT4oi6Vh`04oi:`jol0003oT[3[oi:`j`;o
TkO`0_nJY]h5oiZ]i0CoV[;X0_nK]^/2oijai@KoW[OY5?ooool00ol0003oooooooooo`0Xooooo`00
:Oooool3o`0001Cooooo00?oZYK2ojRB_onXT[l00onXT[l3ojJ>_0CoY8^j0_nRQkL2oi]o]0CoVGbb
0onHNK04oiMg[P?oUgJ/1?nHMJX3oiYfZ@03oi]h[?nONj_oWg^[00;oWg^[1?nROJX4ojAnZP;oXgfZ
0_nROjd4oi]h[0?oTG2Z1?n7IjL3oh=SY0CoPf6R0on7HZ44ohaUX0CoT6RP1?nEJj04oiU_X0;oW76Q
0ondUKP5ok>B]0;o[hjc0_o4_=<5okJ`dP04ojNVeOn8FYKoR5ZFohQJUP;oR5bH0_nAHYP2oi1SV@?o
00000_n?Hi/4ohmTW0CoTFNN1?nDJil4oiI]X@CoUfnS00?oVG:Uoj1iZ?nPNJP01OnPNJP4oimiZ0Go
WWVX00?oWWVYojV;]OnYRkD00_nYRkD3ojR9]0GoYhVd00?oYhVeokZad?nj/M000_nj/M03okN[c@?o
_Ngc0_o1g^d00onHPKSoUhO1oiN7`@02oiN7`@CoU93=1OnCVmT3oi6Vh`;oT[3[00?o0000oi^OeonJ
Y]h01?nJY]h5oiZ]i0;oV[;X00?oWj_OoijaiOnN/ND00onN/ND4oijgj@03ojBij?oooooooooo017o
oooo0_l0000Zooooo`00:Oooool00ol0003oooooooooo`0Cooooo`?oZYK21?nXT[l4ojJ>_0;oY8^j
00?oWH>goi]o]?nKOk@00_nKOk@4oiUl/P?oV7V`1?nGMjh4oiMf[0?oV7FZ00CoVWJYoi]h[?nKN:co
VgR/1?nONj/4oj9mZPCoY7jZ00?oXgfZoj9o[OnROjd00_nROjd3oi]h[0CoTG2Z0on7IjL3oh=SY0Co
Pf6R0on7HZ44ohaUX0CoT6RP1?nEJj04oiU_X003oiaaXOndUKSo]9Fh00;o]9Fh1OncT[@01?n_S[?o
a;cColBldoo4_=<4okJ`dP;oR5VD0_n8FYH01?nAHIKoTF:Hoi5RV?nAHYP3o`000003oi1SVOn?Hi_o
Sf>K00?oSf>K0on?I9`4oi5WWPCoU6^O1?nFKJ43oiM_X`03oj1jZ?nPNJSoX7VX00KoX7VX1OnONJP3
oiiiZ003ojZ=]onYRkGoZH^e00?oZH^e1?nXRK@3ojN9]003okfjeonj/M3o^[7@00Co^[7@00Co]j_=
okg]lonmkO?o_Ngc1OnHPKP3oiN7`@GoU93=0_nCVmT2oijBa`?oW9S?0onKWmL00ol0003oVioGoiZV
gP04oiZVgP;oVZgT0_nPYMX4oin[g`GoW[7U00?oW[OYojBij?nT^NP00_nT^NPDooooo`03o`000?oo
oooooooo02Oooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0
0005ooooo`03o`000?oooooooooo01;ooooo00?o[9_5ojZF`_nZU/800_nZU/84ojRB_`CoYXjl00?o
Y8^joif3]onMPkL01?nKOk@4oiUl/P?oV7V`1?nGMjh4oiMf[0;oV7FZ00?oUgJ]oi]h[?nKN:`00_nK
N:`4oimkZ`GoXWfZ0_nTOZX00onVPjkoXWn]oj9o[@03oj9o[@?oVgR/1?nAL:X3ohMWY`CoPf>T0on3
HJ84ohMRX@?oS6FP1?n@J:04oiE[X0?oVFnP00?o/9NmokBE^?ndUKP00ondUKP4ok>B]003ol[;f_o4
_=?oa;cC00?oa;cC00?o][3BohQIU?n8FI@00_n8FI@00on8FYKoTF6Foi5QUP03o`000003oi5RV?n@
HiWoT6>I00;oT6>I1?n?Hi/3ohmTW0CoTFNN1?nDJil4oiI]X@04oiM_XonPNZSoX7ZXoj1jZ0SoX7VX
1OnONJP01?nNNJSoZXfgojZ=]onZSKL5ojV;]@CoZ8Vd00?oYhVdokfjeonm^]L00_nm^]L4okZad0;o
YoK/00Co_NgcoiYl/?nJO;3oVWb`1?nHPKP3oiN7`@CoU93=00?oXHfooijBaonNT/L00onNT/L3oibH
c`;oVioG00?o0000oi^OeonKWmL00_nJY]h2oj6Od`GoX:GJ1?nOZml2oijai@;oYKCT1OnT^NPEoooo
o`03o`000?oooooooooo02Kooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo013ooooo1?n/VlD3
ojZF`PGoZ9:o0_nVS[`00onOQ[WoWH>goif3]`02oif3]`CoVgnd0onIO;84oiQi/0?oUgN^0_nGMZ`2
oiAf[P?oUgJ]1?nKN:`4oimkZ`GoXWfZ00?oY7jZojJ3[_nVPjh01OnROjd3oi]h[0CoTG2Z0on7IjL4
oh=SY0?oPf6R1?n7HZ43ohaUX0GoT6RP0onEJj02oiU_X0?o/9Nm1OndUKP2ok>B]0?ob/_J0oo4_=<2
ohUJT`?oR5VD00CoT5nEo`000?l0003o00001?nAHYP4oi1SV@CoSf>K1?n?I9`3oi5WWPGoU6^O0onF
KJ45oj1jZ0SoX7VX0onONJP00on/T;WoZXfgojZ=]`03ojZ=]`GoZH^e0_nXRK@00oo1b>3o_K[Gokfj
e`04okfje`04okZad?nWm^coYoK/ojOfk0GoVWb`1?nHPKP4oiN7`@03oiB@cOnQSKooXHfo00;oXHfo
1?nNT/L4oibHc`;oVioG00?o0000oj:JcOnQWm<01?nQWm<4oj2UfP;oWj_O0onV/=l4ojFdi0;oY;WX
0onZ_NPDooooo`03o`000?oooooooooo02Kooooo0006ooooo`Ko00000_ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool2o`0000oooooo00?o[Z39ojbKaOn/VlD0
0on/VlD4ojZF`P?oZ9:o00?oXHZloin6^OnOQ[T00_nOQ[T3oif3]`CoVgnd1?nIO;83oiQi/0;oUgN^
00?oTWJ`oiAf[_nDMZh00_nDMZh4oiMf[@CoVgR/0onONj/4oj9mZP03ojJ3[onVPjkoYX>^00;oYX>^
1?nROjd3oi]h[0CoTG2Z1?n7IjL3oh=SY0?oPf6R1?n7HZ43ohaUX0GoT6RP0onEJj000onIKj3o/9Nm
ok2G_@02ok2G_@Go]9Fh00?o/i:dol[;f_o:bmX00oo:bmX01_o4_=?oREZCohUJTon9FY?oR5VDoi1O
U@;o00000onAHIH5oi5RV0?oT6>I1?n?Hi/4ohmTW0?oTFNN1OnDJil2oiI]X@03oj1jZOnPNZSoX7ZX
00?oX7ZX2?nPNJP2oimiZ0;o[92i1OnZSKL5ojV;]@04ojR9]?o1b>3o`LSPol78h0Co_K[G00?oKM^n
oimgYonMNJX00onMNJX4oiYl/0GoV86h0_nGQl400onSRKWoXHfooj6=_`03oj6=_`GoWY;70_nLV<l0
1_nTU/OoXY[=oj:JcOnRV/go0000oj:Jc@CoXIoC0_nPYMX2ojN/fPKoY[3O0_nU]>@2oj^ki@GoZ[gX
5?ooool00ol0003oooooooooo`0Uooooo`003_ooool01Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`0=ooooo`?o[Z391?n/VlD4ojZF`P04ojRB
_onQR[coXHZloj6:_0CoWhJi0onMPkL4oi]o]0CoVGbb0_nHNK001?nCN;;oTWJ`oi9f/?nBM[05oiAf
[P?oUgJ]1?nKN:`4oimkZ`;oXWfZ0_nVPjl4ojJ3[PCoXWn]1?nKN:`3oi5`ZPCoQfNW0on3Hj@4oh=Q
XP?oQf:Q1?n<IJ04oi1XX0;oUF^P00?oZ9G2ok2G_On`Ukd00on`Ukd4okBE^003ol_Nioo:bm[ob/_J
00?ob/_J0_n=GI<2ohUJT`?o00000_n@GiD4oi5QUPCoTF:H0on@HiT4ohmSV`CoSfBL1?nAIih4oiA[
W`04oiI]XOnPNZWoX7ZYoj1jZ@CoX7ZX2?nPNJP00onONJSo[92iojb@^@02ojb@^@CoZXfg1?nYRkD0
0oo2g>co`LSPol78h003ol78h003okfjeonHPKWoWgNW00;oWgNW1?nMNJX5oiYl/0?oV86h00?oYXRd
oj>9^OnSRKT00_nSRKT4oj6=_`CoWY;700?oYiC2ojBFaonTU/L00_nTU/L3oj:Jc@05o`000?nQWm?o
XIoCoj6OdonYZMH01OnW[=X4ojJ`g`03ojbih_n[^nGoZk_U00?oZk_U0_nZ_NP2ojg2jAGooooo00?o
0000ooooooooool09?ooool000kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00Cooooo00?o0000ooooooooool02oooool00onaY/go[Z39ojjPb@03ojjPb@Co[9_50_nZ
U/800onSSkooXHZloj6:_002oj6:_0CoWhJi1?nMPkL3oi]o]0;oVGbb0_nDN[@3oi=h/PCoTWJ`1?nD
MZh3oiMf[@CoVgR/1?nONj/01?nROJ[oYX>_ojJ3[onVPjl4ojJ3[PGoXWn]0onKN:`2oi5`ZP05oh]f
]omkKKSoNffhog]]^?n7IjL00on3Hj@4oh=QXP?oQf:Q1?n<IJ03oi1XX003oij?a?nXUL;oZ9G200;o
Z9G21On`Ukd2okBE^0?obmkW0oo:bmX00on=GI?oSEfDo`000002o`000003ohiMU?n@GiGoT5nE00;o
T5nE1?nAHIH4oi5RV0?oT6>I1?n?Hi/4ohmTW0CoTFNN0onDJil00onQNjWoX7ZYoj1jZ@02oj1jZ@Co
X7ZX1onPNJP00on^UKgo[92iojb@^@03ojb@^@GoZXfg0_nYRkD3ol;Lk0?o`LSP0_nKO;05oimgY`?o
WGVZ1OnJO;000onHPKSoYXRdojJ8]002ojJ8]0?oXhVi1OnQSKl01?nNT/OoYiC2ojND`_nWU<84ojBF
a`?oXY[=00?o0000oj:JcOnQWm<00onYZMH5ojN/fP03ojJ`gon/^N;o[;WR00;o[;WR0on[^nD00on_
`^So[L;Yojg2j@03ojg2jA?ooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c009ooooo`003_ooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool00oooool2o`0000_ooooo0onaY/d4ojjPb@?o[9_500?o
YI?3oj>?_onSSkl00_nSSkl4oj6:_0CoWhJi0onMPkL2oi]o]003oiIm]_nDN[CoU7Zd00;oU7Zd1?nC
N;83oi9f/0CoU7J^0onGMZd4oi]h[0?oWg^[00?oXh>aojJ3[onVPjl00_nVPjl4ojJ3[PGoXWn]0_nK
N:`01?nIP;OoRgJgoh]f]on;M[L4og]]^0?oMV^i1?n3HJ83ohMRX@CoS6FP00?oT6RPoij?a?nNSl@0
0_nNSl@3ojRE`PGo/9Nm00?o]9Fhol_Nioo;g^L00oo;g^L01Oo:bm[o0000o`000?l0003oSEfD00?o
SUfD1?n@GiD4oi5QUPCoTF:H0on@HiT4ohmSV`CoSfBL1?nAIih01?nDJiooXG^Yoj5kZOnQNjT4oj1j
Z@CoX7ZX1_nPNJP3ojjE_@Co[92i1OnZSKL00onYRkGo`]c/ol;Lk002ol;Lk005ol78h?nLN:[oVgb`
oi]l/?nQMj@01OnOMjL3oieiZPCoVWb`00?oZHRaojJ8]?nVR;@00onVR;@3oj>9^@CoXHfo00?oZi>n
ojND`_nWU<800onWU<84ojBFa`;oXY[=00?o[:OBo`000?nYZMH01?nYZMH2ojN/fP?o[[SQ1?n/^N80
0on[^nGo[l;Xojo2j002ojo2j0?o[L;Y0_n^aN/Dooooo`03o`000?oooooooooo00Gooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Wooooo
000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo0_l0000:ooooo`03okB/dOnaY/go/JK=00;o/JK=1On^X<T01?n/VlGoYI?3ojFC`onUTl<3oj>?
_`CoXHZl1?nOQ[T2oif3]`04oiR1^?nFOKKoUWffoiIm]PGoU7Zd0onCN;83oi9f/0CoU7J^0onGMZd4
oi]h[004oimkZonSPk7oXh>aoj>3/@GoYX>_1?nVPjh3oj9o[@04ojB8]onIP;OoVH2goiV0]`CoRgJg
0omkKKP3ogI[^@CoN6nl0on2NL04oi66``GoWXo40onXUL84ok2G_@?o_Noc0_o;g^L3o`0000CoSEfD
0on>GI@4oi1OU@CoTF6F1?nAHYP3oi1SV@GoSf>K0on?I9`3oi5WWP03oiiiZOnQNjWoXG^Y00?oXG^Y
0onPNZT5oj1jZ0?oX7VX00?o[i_2ojjE_On^UKd00_n^UKd5ojb@^@?oZXfg0onil_<2ol;Lk0?oW7RZ
00CoVgb`oj5gY?nQMjCoXGNT1?nOMjL4oieiZP;oVWb`0_nYR;45ojJ8]0CoXhVi00?oXHfooj^C__n[
Tkh00_n[Tkh4ojND`P?oY9K700?o/:O?ojbWd_n/Ym800_n/Ym801Ol0003oZJWFojVYe_nYZMKo/K[O
00Ko[[SQ0_n/^N82ok34j@Go[l;X00?o[L;Yojk5jon^aN/00_n^aN/Dooooo`03o`000?oooooooooo
00Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000002Ooo
ool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1?ooool00ol0003oooooooooo`07ooooo`Co]:cA1?naY/d2ojjPb@;oYiW81?nUTl<3oj>?_`CoXHZl
0_nOQ[T2oiV4^`?oV86h1?nFOKH4oiAj]0?oTgRb0onBM[04oiAf[PCoUgJ]0_nKN:`00onMP;?oXh>a
oj>3/@03oj>3/@CoYX>_1?nVPjh01?nROjgoY8RgojB8]onTR;L4oiV0]`?oRgJg1?mkKKP3ogI[^@Co
N6nl0on2NL04oi66``CoWXo41?nXUL800on`Ukgo_Nocokg_l`02okg_l`?o00000on<GI@4oheMU0?o
SUfD1?n@GiD4oi5QUPCoTF:H0on@HiT5ohmSV`?oSfBL00CoTFNNoiiiZOnNNJWoWWVY1OnQNjT3oj1j
Z@GoX7ZX00?oX7VXojnK`_n_Vl800_n_Vl83ojjE_@Go[92i00CoZXfgokWblonil_?o^O;c0_nNMZH4
oiahZP03oj=hXonQMjCoXGNT00;oXGNT1?nOMjL4oieiZP03oiYl/?nYR;7oZHRa00;oZHRa1OnVR;@2
oj>9^@03ojjF_On[TkkoZi>n00?oZi>n1?nWU<800onTU/Oo/:O?ok2Wc`02ok2Wc`Co[:OB00?o0000
ok6jgona^]l00_na^]l4ojjhh@03ok77j_n`a>Wo/<CY00?o/<CY0_n_`^P2ojo9k@Co[/G[00?oZlG/
ooooooooool04_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002ooo
ool01Olb<S;oV9RHoooooonHV9So<S8b00Wooooo000Wooooo`03o`000?oooooooooo00Gooooo0_ng
/mD4okB/d@?o/JK=00?oZIo<ojNIb?nWVLP00onWVLP3ojFC``CoXhno0_nQR[`00onJQkkoVHBkoiV4
^`03oiV4^`?oV86h0onFOKH4oiAj]0?oTgRb1?nBM[04oiAf[P?oUgJ]00?oVgR/oif0/onMP;<01OnS
Pk44ojJ3[`?oYX>^00?oZXjhojB8]onTR;L00_nTR;L4oiV0]`?oRgJg1?mkKKP3ogI[^@CoN6nl0on2
NL04oi66``GoWXo40_nXUL83oi__m0?o00000on<GIH3ohaMU0CoSEfD1?n>GI@3oi1OU@CoTF6F1?nA
HYP4oi1SV@CoSf>K0_n?I9`00onKMjWoWWVYoiiiZ@03oiiiZ@CoXG^Y1?nPNZT3oj1jZ003ok6SbOn_
Vl;o[i_200?o[i_21?n^UKd3ojb@^@04ohc^f?nPMJ?oX7FSoj1eX`CoWWJV0_nLN:X2oj=hX`CoXGNT
1?nOMjL4oieiZPGoZHRa1OnVR;@01?nSRKWo[YJmojjF_On^U[d4oj^C_P?oYiC200?o]:[?ok2Wcon`
Yll00on`Yll3ojbWdP03okFnhOl0003o/K[O00Co/K[O00?o[[SQok77j_naanX00_naanX3ok34j@03
ojo>l?n_bNgo[lW]00?o[lW]00?o[/G[oj_5k?n[aN`00_n[aN`Dooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`02Oooool0
02Oooooo0_l00005ooooo`Co]k?E1?nd[=401?naY/goZIo<ojVOc?nYWl`4ojNIb0CoYI?30_nSSkl0
0onLS<;oVXNnoiZ7_P02oiZ7_PCoVHBk0onHPKP3oiIm]PCoU7Zd1?nCN;83oi9f/0CoU7J^0_nGMZd0
0onGOKGoWH2coif0/`02oif0/`CoXh>a1?nVPjl00onVPjkoZXjhojZ>^002ojZ>^0CoY8Rg0onIP;L4
oh]f]`?oNffh0omfJkT4ogQ__0?oPWW01?nAQ/<5oij?a003ojRE`_nKkoCoVnod00;o00000_n;GYP4
ohaMUP?oS5fD1?n=GI@4ohiMU0?oT5nE1?nAHIH4oi5RV0CoT6>I1?n?Hi/00on?I9coVgNYoi]gZ@05
oiiiZ@CoXG^Y1?nPNZT2oj1jZ0?o/J?91?n_Vl84ojjE_@03ojb@^OnRMZ;oXWJR00CoX7FS1?nNMZH0
0onLN:[oXgRSoj=hX`02oj=hX`?oXGNT1OnOMjL2oieiZP03ojf:/?nYR;7oZHRa00?oZHRa1?nVR;@0
0ondVkko[YJmojjF_@02ojjF_@GoZi>n00CoYiC2okBZcondZ/oo]:[?1On`Yll01On/Ym;o]KkQokFn
hOne_^7o000000?o/K[O00?o/lg]ok77j_naanX00onaanX00on`a>Wo[lk`ojo>l002ojo>l0;o[lW]
0on[bNl4oj_5k1Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go410@okZj^_oooooo^[Zjoa0@4009ooooo`009oooool00ol0003oooooooooo`02ooooo`03
okZkf_ng/mGo]k?E00Co]k?E0_nd[=400on/Ym;oZIo<ojVOc002ojVOc0CoYiW80onUTl<00onMT<Ko
W8c2oib<`P02oib<`P?oVXNn1?nIQ;/3oiR1^0CoUWff1?nDN[@3oi=h/P;oTWJ`00?oT7bioi9l]onB
O;L00_nBO;L3oiMm]@CoWH2c1OnSPk42ojJ3[`03oj^B_?nZS[SoZXjh00?oZXjh1?nTR;L4oiV0]`?o
RgJg1?mkKKP3ogI[^@CoN6nl0on2NL04oi66``;oWXo40_n3i_<3o`000004oheQVOn;GYSoRejHoh]N
V0CoS5fF1?n<GI@3oheMU0CoSUfD1?n@GiD3oi5QUPGoTF:H0on@HiT3ohmSV`03oiagZ?nKMjWoVgNY
00;oVgNY1?nNNJT4oj5kZ@CoX7ZY00?oX7ZXok6SbOnaXlT00_naXlT5ojnK`P;o[YFm1?nRMZ85oj1e
X`?oWWJV1OnSN:<3oj5gY0GoWgNW00CoWGVZojf:/?n]R[3o[HZ`1OnYR;42ojJ8]0;o]9^n1?n^U[d4
oj^C_P03okVadOndZ/oo]:[?00;o]:[?1?n`Yll00onjb>Go]KkQokFnh@03okFnh@03o`000?nccNgo
/lg]00;o/lg]0_naanX4ojkDm0;o[lk`0_nYcO85oj_9k`;oZlG/0_nX`ndBooooo`?o00001?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000009ooooo`009ooo
ool01?l0003oooooooooooooool3okZkfPCo]k?E00?o[joHojbWd_n/Ym800_n/Ym83ojVOc0GoYiW8
00CoYI?3oif@a_nMT<KoWI360onLS<83oiZ7_PGoVHBk0onHPKP3oiIm]PCoU7Zd0_nCN;801?n?OK_o
T7bioi1l^On@O;T4oi9l]`CoUgfe0onMP;<5oj>3/@04ojJ3[on[T[coZi:loj^B_0CoZXjh1?nTR;L4
oiV0]`;oRgJg00GoRiWLog6@hOmaT>7oLI3Qog]]^003ogI[^@CoN6nl0on2NL02oi66``?oOM_l0ol0
0004oheQV@?oRejH1?n<GIH4ohaMU0?oSEfD1?n>GI@4oi1OU@?oTF6F1OnAHYP3oi1SV@04ohmSVonL
MjSoW7NXoiagZ0CoVgNY1?nNNJT5oj5kZ@;oX7ZY00?o]ZkAok6SbOnaXlT00onaXlT5ojnK`P03ojjE
_OnSMj7oXWJR00?oXWJR1OnPMJ<2oiifYP03ojIkY?nSN:?oXgRS00?oXgRS1?nQMj@3oimgY`03ok6>
/On]R[3o[HZ`00;o[HZ`1OnYR;401?nVR;Co]9^nokBK__ndVkh5ojjF_@04oj^C__ni/M7o^K7AokVa
d@Go]:[?00?o/:O?ok[8iOnjb>D00_njb>D2okFnh@;o/mKb00Co0000ok?=kOnccNgo/lg]0_nZg?T4
ojkDm003ojKAmonYcO;oZLgb00?oZLgb0_n[bNl2ojO6l0GoZ<?]5?ooool02Ol0003ooooooooooooo
ooook^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT02Oooool002Ko
oooo0ol000000onma=oo^[_JokZkfP03okZkfP03okNceOn_[mSo[joH00;o[joH0on/Ym84ojVOc0;o
YiW80_nOU//4oif@aP?oW8c21?nJQkh4oiV4^`?oV86h0_nFOKH00onBP[koT7nloi1o_002oi1o_0Co
Sgfk0on@O;T3oi9l]`CoUgfe1?nMP;<3oj>3/@03ojVE`_n[T[coZi:l00;oZi:l1OnZS[P3ojB8]`;o
VH2g0_nOY=P4oh^Ig0?oLI3Q1OmWUNT3ofNWmPCoKl?n0ol00003oi1TV`CoSF6I1?n;GYP3ohaMUPCo
S5fD0on=GI@4ohiMU0CoT5nE1?nAHIH4oi5RV0;oT6>I00?oWgRWoiagZ?nLMjP00onLMjP3oi]gZ@Co
WWVY1OnQNjT01?nPNZWo]ZkAokJ^dOnf[]45ok6Sb@;o[i_21?nSMj44oj9fXPGoX7FS00?oWWJVojIk
Y?nVNj@01OnSN:<4oj5gY0;oWgNW0_naS[44ojf:/0CoZHRa00?o_:K4okBK__ndVkh00ondVkh3ojjF
_@03oknmf?ni/M7o^K7A00?o^K7A0ondZ/l2okcGk@?o^/SU0_n^h_T4ok?FlP03o`000?nccNgoZ]ci
00?oZ]ci00?o[]CdojKAmonVdOL00_nVdOL2ojW=lP;oYLSb1OnWa_02ojS3k@;oYL3]5Oooool00ol0
003oooooooooo`0Nooooo`009_ooool00ol0003o_LCOokg4g`02okg4g`?o^[_J0_nb^=h4ojn_f0Co
[:OB0_nYWl`00onQW=3oWiK;oinFb`03oinFb`?oWI361?nLS<83oiZ7_P;oVHBk0_nDQl<3oi>4`0Co
TX:n0on@Ok`4ohmm^`?oT7bi1?nBO;L3oiMm]@CoWH2c00?oXh>aojVE`_nYUL800_nYUL83oj^B_0Go
ZXjh0_nTR;L2ojj^f0CoWjCH1?n;VM`3og6@h@GoIiGY0omWYoH3o`0000?oTVNL1?n@I9/3oheQV@Co
RejH0on<GIH4ohaMU0?oSEfD1?n>GI@4oi1OU@CoTF6F1?nAHYP00on@HiWoWgRWoimhY`05oiagZ0?o
VgNY1OnNNJT3oj5kZ@03okbkfOnf[]7o]ZkA00;o]ZkA1?naXlT00onCIicoY7RQojAhX@04oj=gX@Co
XWJR1OnPMJ<4ojIkY0CoXgRS1?nQMj@00onOMjOo/Hjaok6>/@02ok6>/@Co[HZ`0_nYR;43okbVa0Co
]9^n0_n^U[d3oknmf0Co^K7A00?o]:[?okcGkOnlend00onlend00onjb>Go[^;iojkRn@02ojkRn@;o
/mKb0_nOho`00ol0003oZ]cioj[Ln@03oj3FnP;oY]7g0onRbO@4ojG8lP;oYlK`0onT`>h4ojG0kACo
oooo00?o0000ooooooooool07_ooool001_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooo_LCO00?o_LCO00?o^[_Jok:hg_nb^=h00_nb^=h4ojn_f0;o[:OB00?oXj?Foj6Ld?nQ
W=000_nQW=04oinFb`CoWI360onLS<82oiZ7_P03oiF:a_nDQl?oU8O300?oU8O30onCQ<03oi:2_P?o
T7nl1?n?OK/3oi1l^@CoTWbg1?nGOKD2oif0/`03oj:Fb?nYUL;oZIG200?oZIG21?n[T[`3ojZ>^003
okJjg?n^[]So[ZkH00?o[ZkH1?nOY=P4oh^Ig0?oLI3Q0_mWUNT00onAJJ7oTVVOo`000002o`0000?o
U6VN0onBIi`4oi1TV`?oSF6I1?n;GYP3ohaMUPCoS5fD0on=GI@4ohiMU0CoT5nE1?nAHIH3oi5RV003
oj=jY_nON:OoWgRW00;oWgRW1?nLMjP3oi]gZ@GoWWVY00?oXG^YokbkfOnl^mT00_nl^mT4okJ^d@03
ok6SbOnCII[oTfNL00?oY7RQ1OnSMj44oj9fXP?oX7FS00?oZGnVojIkY?nVNj@00_nVNj@5oj=hX`?o
XGNT1OnaS[44ojf:/003ojV8/OnlY/Co_:K400;o_:K41?ndVkh00on^U[go_kgHoknmf002oknmf0?o
^K7A0ongk_D2okcGk@?oV^_i0_n^h_T4ohSTn@;oWn?l00?oUmOmo`000?nGeod00_nPe_X2oig9mPGo
X/Wd0_nUb?82oj;0kPGoY<3^0_nU`>d2ojBmk1Cooooo00?o0000ooooooooool07Oooool001_ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00;o_LCO0ond`nD4ok:hgP;o
[joH00?oY:cLoj>Se_nSXmH00_nSXmH4oj6Ld0CoWiK;0onMT<H2oib<`P03oiF>bOnER/KoUH[600;o
UH[61?nDQl<3oi>4`0?oTX:n1?n@Ok`4ohmm^`?oT7bi0onBO;L4oiMm]@04oif0/onRU/SoXYK8oj:F
b0CoZIG21?n[T[`00onZS[So][[LokJjg002okJjg0Go[ZkH0_nOY=P01?nKNJcoVgJYoi]fZOnKMZT2
oiYcYP03oi5[XonAJJ7oTFVQ00?o00000_nBJIl4oiAYWP?oTVNL1?n@I9/3oheQV@CoRejH0on<GIH4
ohaMU0CoSEfD0on>GI@4oi1OU@CoTF6F0_nAHYP2oj=jYPCoWgRW1?nLMjP4oi]gZ@?oWWVY00?o_LOR
okbkfOnl^mT01?nl^mT2okJ^d@?oTfFJ1OnTN:44oj=gX@CoXWJR0_nPMJ<2ojUoYPCoYW^T1OnSN:<2
oj5gY003okJF]OnaS[7o/Hja00?o/Hja1?n]R[05okbVa0?o]9^n0_o5eNH5oknmf003okVadOngk_Go
]nke00CoH]SL0_nJjoT3of;Gj@;oR>Ci0on9e?l2oiOGo@03o`000?nIaOKoWLWf00CoWLWf0_nRbO@2
oj6okPGoX/3^0_nT`>h2oj>lj`GoY;g/4oooool2o`0001kooooo000Kooooo`05oa0@4?oooooooooo
ooooool@41001_ooool2o`0000;ooooo1Ond`nD2ok:hgP03ojJei?nT[=coY:cL00;oY:cL0onSXmH5
oj6Ld0;oWiK;00CoUYOBoiJBcOnFT/goUY;=1?nES/T3oiF:aPCoU8O30onCQ<04oi:2_P?oT7nl1?n?
OK/3oi1l^@?oTWbg0_nGOKD2oiVEcPCoXYK81OnYUL82oj^B_0;o]<CV1?nf^]`4ojj^f004oial/?nK
NJcoVgV/oi1]Y`?oTFbU0_nAJj<3o`0000;oTFVQ1?nBJIl3oiAYWP?oTVNL1?n@I9/4oheQV@?oRejH
1?n<GIH3ohaMU0CoSEfD0on>GI@4oi1OU@CoTF6F00?oTF:Hoj=jY_nSNZH00_nSNZH3oimhY`CoW7NX
1?nKMjT00onNNJWo_LORokg7hP02okg7hPCo_;_I0onDIIP3oi=UVPGoY7RQ1?nSMj44oj9fXP03oj1e
XonYOjKoZGnV00;oZGnV0onVNj@5oj=hX`04oj5gY?nfU[Go]YJeokJF]@Go/Hja0_n]R[02olRnd@Go
_:K400?o]9^nolGEi_o5eNH00_o5eNH2oknmf0;oPNWH00?o0000oabYb_lLZLX00_n3^?L5og[4oP?o
Oloo0_n9e?l3oiFml`;oVLGf00Co0000oiW5m_nMbOKoWLWf0onO^nd4oj6okP;oX/3^0onS^^T4oj>l
j`;oY;g/0_nU_N/Booooo`03o`000?oooooo000001kooooo000Kooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`02ooooo`;o]<?U0_nW`>/4ojJei0CoY:cL0onSXmH2oj6L
d0;oUicG1?nFUm83oiJBc@?oUHk90onER/H5oiB7``?oThC00onBP[h3oi1o_0;oSgfk0_n<U=H3ohbC
eP?oTICC1OnIULh3oj:Fb0GoZIG200?oZi:lokC4i_nda>H00_nda>H4okJjg004ojj^f?nLO;3oTFnY
oi5_Z@?oT6fW0onAK:D2o`000003oi5[XonAJJ7oTFVQ00;oTFVQ1?nBJIl3oiAYWPCoTVNL0on@I9/4
oheQV@?oRejH1?n<GIH3ohaMU0CoSEfD0on>GI@4oi1OU@?oTF6F00?oYGZToj=jY_nSNZH00onSNZH3
oimhY`GoW7NX0_nKMjT2okc@jPGo_LOR00?o_;_IoiATUonDIIP00onDIIP2oi=UVP03ojEiX_nTN:7o
Y7RQ00?oY7RQ1?nSMj44oj9fXPGoZGnV0onVNj@5oj=hX`Co]YJe1OnaS[401?n]R[3ob;kAolRndOo8
_]44okbVa0;o]oCb0oo5eNH2oiVIdPCoSJKV1On3^?L2og[4oP;oUjOQ1?nF]>`5oiFml`;oVLGf00?o
0000oingjOnO^nd01?nO^nd2oj6okP03oj>gionS^^WoXk[Y00CoXk[Y0_nS_>/00onT^nWoYKg[ojFm
j`03ojFmjaCooooo00?o0000ooooooooool06oooool001_ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00?ooooo1?nW`>/4ojJei0;oY:cL00?oUj[SoiNSgOnGXmd00_nG
Xmd4oiNLe`?oUYOB0onFT/d3oiF>b@CoUH[61?nDQl<3oi>4`0;oTX:n00?oSYKFohbDe_n<U=H01_n<
U=H3ohbCeP?oTICC1?nIULh4oj:Fb0;oZIG20on[c_85okC4iP;o][[L00?oTW:[oi5_ZOnAKjT00_nA
KjT3oi1]Y`?o000000CoTFbUoi5[XonAJj?oTF^S0onAJJ44oi9YW`CoU6VN0onBIi`3oi1TV`CoSF6I
0on;GYP4ohaMUP?oS5fD1?n=GI@4ohiMU0?oT5nE0_nAHIH2ojEjY0GoXgZV0onON:L5oiagZ003oi]g
ZOnld>[o_=3Z00;o_=3Z0_nman84oiATU`CoU6FH00CoTfFJojEiX_nUNJ;oYGVR1?nTN:45oj=gX@;o
XWJR00?o[hR/ojUoY_nYOjH00onYOjH4ojIkY0?oXgRS0_nnY;h3okJF]@Co/Hja00?od^oWolRndOo8
_]400oo8_]400onlY/Co]oCbokOdlP03okOdlP03olGEi_nIVM;oVIWB00;oVIWB1?n=Y^H2oh>hm`;o
W9cC1OnGYn44oiJdk0;oUKgc0_nO/>@2oingj@03o`000?nO]nWoWkOY00;oWk_]0_nR/n@4oj>gi`Co
Xk[Y00?oYKWWojBkjOnT^nT00_nT^nT3ojFmj`03ojJnj_oooooooooo01?ooooo00?o0000oooooooo
ool06_ooool001_ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo00Go
oooo1?nW`>/2ojJei003oiNbj_nGZ^?oUj[S00;oUj[S1?nGXmd3oiNLe`?oUYOB1?nFT/d3oiF>b@;o
UH[600?oSiWIohnHf?n?V=P00_n?V=P3ohnGe`CoSYKF1on<U=H3ohbCePCoTICC1?nIULh2oj:Fb0?o
UM3l1?n[c_82okC4iP;oTgB^0onBLZ/4oi5_Z@?o00001?nAK:D3oi5[X`?oTFVQ1?nBJIl4oiAYWP?o
TVNL0on@I9/4oheQV@?oRejH1?n<GIH3ohaMU0CoSEfD1?n>GI@3oi1OU@03oi5QU_nUNZCoYGZT00;o
YGZT1?nSNZH4oimhY`?oW7NX0_noh?03okc@jP?oTf:E1?nDI9L3oiAUV003ojMmYOnUNJ;oYGVR00;o
YGVR1?nTN:45oj=gX@04oj9fX_n_R:co[hR/ojn8[0CoZGnV1?nVNj@2oj=hX`?o_ZBn1?nfU[D2ok6>
/@?od^oW0oo8_]43o`0000;o]oCb0onQT<85oiVIdP;oSJKV00?oXIC7oibLdonLW=<00onLW=<4oiNW
h@;oU[C/0onQZM`4oin`i0;oWkOY00?o0000ojB_gonR/n@01?nR/n@4oj>gi`03oj>jjOnU^NOoYKWW
00;oYKWW1?nT^nT01?nU_N_oY[kZojJnj_nV_^XDooooo`03o`000?oooooooooo01[ooooo000Koooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000Oooooo0_nW`>/2oiNkl@?oUk;Z0onGZ^<5
oiNSg@?oUicG0onFUm82oiJBc@04ohbMg_n=VmcoSI_LohfKg0CoSiWI1?n?V=P3ohnGe`?oSYKF2?n<
U=H3ohbCePCoTICC0_nIULh2og[;o`GoUM3l0_n[c_82oiEh/0CoTgB^0onBLZ/3o`0000?oT6fW1?nA
K:D3oi5[X`CoTFVQ0onBJIl4oiAYWP?oTVNL0on@I9/4oheQV@?oRejH1?n<GIH3ohaMU0CoSEfD1?n>
GI@3oi1OU@GoYGZT1?nSNZH4oimhY`03oiagZ?noh?3o_n3`00?o_n3`00?o_=3Zoi=RUOnCHYD00_nC
HYD4oiATU`;oU6FH0_nWOJD4ojEiXPCoY7RQ1OnSMj44ojn8[0CoZGnV1?nVNj@00onSN:?o_ZBnokjT
_P02okjT_PCo]YJe00?o/Hjaom;_iooBknL00ooBknL00oo8_]7oVGfcohn5a004ojV=^0CoXI320_nI
VM82ojNA_PCoXIC71OnLW=<2oiNWh@03ojBSe?nQZMcoXJWL00CoXJWL0_nO/>@01_nUZ][oY:oOojB_
gonT[moo0000ojB_g`CoX[?T0_nS]nL2ojJgi@GoYKWW0_nT^nT2ojJlj0GoY[kZ5?ooool00ol0003o
ooooooooo`0Iooooo`006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooooooo
ool01oooool4oiNkl@?oUk;Z0onGZ^<2oiNSg@;oRJOY0on:XnD3oh^OhPCoS9gN0on=Vm`4ohnIf@?o
SiSH1?n?UmL3ohjFePKoS9CF0_mb`?h5ofW1oP?oK<Gn0omjbol2oiG@o0?oV7bc0onEN;04oi=d[P?o
00000onAKjT4oi1]Y`?oTFbU0onAJj<4oi5YX@?oTVVO1?nDJIh3oi9WW0CoT6BK0on=HIT4oh]NV0?o
S5fF1?n<GI@3oheMU0CoSUfD0_n@GiD00onRMj;oYGZTojEjY003ojEjY0GoXgZV0_nON:L3ol?dk`;o
_n3`0on?GI<5oi=RU@?oU6BG00CoU6FHojMmYOnWOJGoYgfU1?nUNJ85ojAhX@?oXgNQ00?o^i^hojn8
[?n_R:`00_n_R:`5ojUoYP?oYW^T1_nnY;h2okJF]@?o00000_oBknL4oiUm/`GoZHfh1?nQT<85ojNA
_PCoXIC70_nLW=<2ojVPc@CoY:?D1?nQZM`00onXYmGoYJ[JojFZfP02ojFZfP?oY:oO00?o0000oj:c
i?nR/n@00onW]>84ojJgi@;oYKWW0onW^^L4ojJlj0;oY[kZ0_nX_nXDooooo`03o`000?oooooooooo
01Wooooo000Uooooo`03o`000?oooooooooo00Sooooo0_nG^o42ohBem0?oQ[3a1?n7Znd3ohVWj@?o
RZ?U0on;Wn83ohbMgPCoSI_L1?n?VMT3ohnHf0;oSiOG0on5^OL3oh6lnPCoNkkl0omb`?h2ofW1oP;o
/JC;0on]WLL01?nOQkWoVh6foi^1]_nKPKH4oiQl/`?oUGR`00CoTgB^o`000?l0003o00000onBLZ/4
oi5_Z@?oT6fW0onAK:D3oi5[X`CoTFVQ0onBJIl4oiAYWP?oTVNL1?n@I9/3oheQV@CoRejH0on<GIH4
ohaMU0?oSEfD1?n>GI@00on@GiGoXWNRoj9gXP05ojEjY0GoXgZV00CoWgRWol?dkoo3m>oo`oC_0on<
FI43ohmMT`GoTf:E0onDI9L5ojMmY@?oYGVR1OnTN:42oj=gX@;o^i^h1?n_R:`5ojUoYP;oYW^T0_o;
`M45okjT_P03okJF]OnYP:OoZH2W00GoXGb[0_nIOK<2ok6?/PCoZHfh0onQT<82ojjB^@CoYi6n0onQ
U<L00on_WlOoZJ3=ojVPc@03ojVPc@CoY:?D00?oXJWLojRWeOnXYmD00_nXYmD4ojFZfP;oY:oO00?o
0000ojVbgonW]>801?nW]>82ojJgi@;oZ;WU1OnW^^L2ojJlj0;oZKkY1?nX_nXBooooo`03o`000?oo
oooo000001[ooooo000Uooooo`03o`000?oooooooooo00[ooooo0on4]O@3ohJ`l@CoQj_]0on9YnT3
ohZSi@?oRioR0on<WMh2ohfKg0;oPK7d1?n3]?@3ohBfm@GoQKWg0on1_?X2og^no0Go]:[>1?naY</0
0on]WLOoWhNioin7^@04oi^1]P?oV7bc00CoUGR`o`000?l0003o00000onCM:h3oi9bZ`CoTFnY0on@
KJL4oi5/Y@?oTF^S0onAJJ44oi9YW`?oU6VN0onBIi`4oi1TV`?oSF6I1?n;GYP3ohaMUPCoS5fD0on=
GI@3ohiMU003oiaaXOnRMj;oXWNR00;oXWNR1?nUNZ@5oj=jYP;obooH00?o`oC_ohaITOn<FI400_n<
FI43ohmMT`GoTf:E0onDI9L5ojMmY@?oYGVR1OnTN:401?nSMj7o^i^hok^K^?nkVkP4ojn8[0GoZGnV
00CoYW^Tol_1dOo;`M7obl7A1?nnY;h4ojV0Y`GoXGb[00CoVGfcok6?/_naSk;o/Hnb1OnYSKP01?nQ
T<;o[Y:iojjB^On^T[T5ojNA_P04oj6Daon_WlOo[io7ojnOa`CoZJ3=0_nTXm@2ojfWd@GoZ:OE0_nU
Z]X2ojbag0?oZK;O00Co0000ojVbgonW]>;oYkCR0_nZ^><5ojRii@;oYk[W0_nY_^P5ojVnj@;oZ;oZ
0_nY`N/Dooooo`03o`000?oooooooooo01Oooooo000Uooooo`;o00003?ooool3ohBem0?oQ[3a0_n7
Znd4ogV^m0CoNZkd1?ml[_<3ogj_l`?oPK7d1?n3]?@3ohBfm@;oQKWg0ol_^<P00oo2f^_o`]_/okN`
d@02okN`d@Go]:[>0_naY</00onSSKgoWhNioin7^@02oin7^@?oVh6f0_nHO;<2o`0000?oUGR`0onC
M:h3oi9bZ`CoTFnY0on@KJL4oi5/Y@?oTF^S0onAJJ44oi9YW`?oU6VN0onBIi`4oi1TV`?oSF6I1?n;
GYP3ohaMUPCoS5fD0on=GI@2ohiMU0;oW76Q1?nRMj85ojEjY0?oXgZV0_o;omP2ohYHS`CoS5VA0on?
GI<5oi=RU@;oU6BG0_n_QJP4ojMmY@CoYGVR0onTN:400ooCc=?o^i^hok^K^003ok^K^0Co[hR/0onY
OjH00oo7m^cobl7Aol_1d@03ol_1d@04okjT__nUP:co/XNXok:7Z0?oZH2W1?nQO:/00onhU;;o/Hnb
ok6?/P02ok6?/PCoZHfh00?o]iViojjB^On^T[T00_n^T[T4ojNA_P03okJSaOn_WlOo[io700;o[io7
0onYX<d00onbZM3o[JOAojfWd@03ojfWd@?oZ:OE00?o[k;Kojbag?n//M`00on//M`3ojVbg`03o`00
0?nZ^>?oZ[SS00?oZ[SS0_nX^ND2oj^nj0GoZKkX0_nY_^T2oj[1jPGoZL7[4oooool00ol0003ooooo
ooooo`0Gooooo`009?ooool00ol0003oooooooooo`0=ooooo`?oN;3f0omh[oD6ogV^m0CoNZkd1?ml
[_<3ogj_l`?oPK7d0_n3]?@2odW5jP03ofcMdon^loCo[_?d00Co`][[00?o^[GDokN`dOng/=400_ng
/=44okBZcP03ojNC`OnSSKgoXhfm00;oXhfm0onOQkT2oi^1]P?o00000_nHO;<3oiEh/0CoTgB^0onB
LZ/3oi5_Z@?oT6fW1?nAK:D3oi5[X`?oTFVQ1?nBJIl2oiAYWP04oi1`Z_n?KZWoSfjYohm^Z@CoRf^Y
0on3IJP3ogaPY`04oh]NV?n<GIKoS5fFohaMUPCoS5fD0on=GI@01?n>GICoW76QoiaaXOnLLJ44oj9g
XPGoYGZT0_nSNZH00oo;omSoRUN?ohYHS`03ohYHS`?oS5VA1?n?GI<4oi=RU@04oiATUon_QJSo[hFX
ojn5Z0CoYgfU1?nUNJ82ojAhX@?odlcC1?nkVkP4ojn8[003ojUoY_o7m^coaoK/00;oaoK/0_o;`M42
ojb1Y`04ojF0[?nbQjSo/XNXok:7Z0CoZH2W0_nQO:/3okRD/PCo/Hnb0_nYSKP3okNI^@Co[Y:i00Co
Yi6nokJSaOnfXlGo]Z?51On_WlL01?nYX<go/ZW@ok:Yd?nbZM05ojfWd@04ojRWeOn_/]_o[k;Kojnb
f`Co[;7L00GoZK;Oojbih_n/^N;o[;WRo`000003ojZhh`03ojboj?n[_^SoZkkX00?oZkkX0_nY_^P3
oj[1j`CoZ/7Z1?nY`N/Dooooo`03o`000?oooooooooo01Kooooo000Tooooo`03o`000?oooooooooo
00kooooo0omh/?H3ogR_m@KoNJkd0_mj[_@3of>mo@CoGL3l0omG`oT2oe35l`04ocBi]_m/gM?o/^kg
ok;^m`Co`MS[00Co`][[okZee?nj]MCo^[GD1?ng/=401?ndZ/koYi?1ojNC`OnWTl44oj>=_@;oWhNi
0ol00002oi^1]P?oV7bc0onEN;04oi=d[P?oTW:[0onAKjT3oi1]Y`;oTFbU0_n;JjT6ohY/ZPCoSFj[
0on@L:X3ohm^Z@CoRf^Y0on3IJP4ogaPY`?oPF6U1?n<GI@2oheMU003oi=[X_nLLJ7oW76Q00?oW76Q
0onRMj85ojEjY004oj=jY_n:EhooRUN?ohYGS`CoRUR?0on<FI44ohmMT`CoTf:E1?n_QJP4ojMmY@Co
YGVR00?oY7RQom?<dooCc=<00_oCc=<4ok^K^0?o[hR/00?oUVVKoi5YXOl000000_o7m^`5ojb1Y`Co
/XNX1?nYP:L00onQO:_o^9BbokRD/P02okRD/PCo/Hnb00?oZHfhokNI^OngVKT00_ngVKT4ojjB^@Go
]Z?50on_WlL00onj/]7o/ZW@ok:Yd002ok:Yd0Co[JOA00?o];OKojnbfon_/]/00on_/]/2ojbag0;o
[k_R0on/^N800ol0003o[;WRojZhh`03ojboj0?oZkkX0_n[`n/5oj[1j`;oZ/7Z0_nZ`^/4ojW1jaCo
oooo00?o0000ooooooooool05Oooool002Cooooo0ol0000?ooooo`CoMZof1?ma/_T3offfn`?oJ;Wm
0omS_Od2oeg0o0;oC<K/0om?cMP2oh7Wj`;o/^kg1?o1f>/00onk^MOo^[GDokZee003okZee0;o]k3A
00?oZi[5ojNC`OnWTl400onWTl42oj>=_@?o00000_nOQkT3oi^1]P?oV7bc0_nEN;000on>KjcoS6fZ
oha]ZP02oha]ZP?oRfbY1_n:JjT4oh][Z@KoRVbZ1?n=KZ/4oi1`ZP?oSfjY1?n;JjT3oh=UZ0?oO62W
0on1HJD4ohQUX`?oTf^R1OnLLJ43oj9gXPGoYGZT1?n:Ehl4ohYHS`?oS5VA1?n?GI<4oi=RU@Co[hFX
1OnWOJD3ojEiXP03ogSDT_oCc=?odlcC00;odlcC1?nkVkP01?n_R:coUVVKoiIYVonFJI/4ok:5YPGo
[86W1?nbQjP4ojV0Y`Go^9Bb1?naSk85okNI^@?o[Y:i0_no[LP4okJSa@03ojnOaonj/]7o^[;A00;o
^[;A1?nbZM000on]Ym7o];OKokBgf`02okBgf`?o[k;K00?o//7Uojnkh_n_^n800on_^n82ojbihP03
ojg1j?l0003o[;oX00Co[;oX00?oZkkXoj_3jon[`n/00_n[`n/2oj[1j`;oZ/?/1OnZ`^/4ojW1ja;o
oooo0_l00009ooooo`Co000000?o410@ooooooooool01oooool002Cooooo00?o0000ooooooooool0
4?ooool4ogJ_mP;oLK;i0_mk^_X4og?1oP?oJLKn0_mLbOT3ofOGlP;oTNSi0ondioL3okoEjP03ol7H
jonk^MOo^kWG00;o^kWG0onj]M@00on_XLWoZi[5oj^Ja@02oj^Ja@?oYi?10ol00002oj>=_@?oWhNi
0_nKPKH01?nBM[3oSg:^ohmb[_n?LZh3ohi_[0CoS6fZ0on;K:T6ohY[Z@CoRf^Y1on:K:X3ohe^Z`Co
T72Z0on?KZT4oh][Z@?oPfFX0omlH:L3oh5QY@CoR6FS0onCJj85oiaaX@CoXWNR0onUNZ@00on<FHoo
RUN?ohYGS`02ohYGS`CoRUR?0on<FI44ohmMT`?oTf:E0_njTZd3ojn5Z0GoYgfU0_nUNJ83ogSDTPCo
dlcC0_nkVkP00onLK9[oUVVKoiIYV`02oiIYV`Co/XFV1?n/PJL2ol6J/0?o/XNX1?nYP:L6okRD/P;o
/Hnb0_o5[<45okNI^@04ojjB^Ono[LSo_jg8okn]b0?o]Z?500?o`L;KokZbdOnj/]400onj/]42ok:Y
d0?o^;kO1?nd]m/00on_/]_o//7Uok;1i@02ok;1i@;o[k_R0on_a^/3ojg1j003o`000?n/_nSo[;oX
00;o[<G/1?n[`n/00onYaNgoZ/?/oj[3k003oj[3k0;oZ/;[0_nY`n`5ojW1ja?ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`09ooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`0Booooo`CoPK?e0omk^_X2og?1
oPCoQ/oo0_mie_h2oi_Qo@Co]=ke00Co]>OgokoEj_noeN[o_mGZ0_nl_MX5ok^ie`04okZee?n_XLWo
[j79ojnQb@?oZi[50ol000000onWTl7oXhfmoj>=_@02oiQo]P?oUGZc0onBM[03ohmb[PCoSVn/0on<
KJX4oh]/Z@KoRV^Y0on;JjT7ohY/ZP?oSFj[1?n@L:X3ohm^Z@CoRf^Y0on3IJP3ogaPY`?oPF6U1?n8
IJ<4oi=[XPCoW76Q1?nRMj82ojEjY0?oS5V?0on:Ehl4ohYHS`CoS5VA0on?GI<2oi=RU@?o^Y:]1?n_
QJP4ojMmY@04ojEiX_nbPj;o/X>Rok:3XPCoXg>L1?nLK9X3oiIYV`;o^XjX1?nbQJH2ojb1Y`?o`IZ`
1?nbQjP2ojV0Y`;o`j>i1OnhU;801?naSk;oaJc1olF/`Oo5[<44okNI^@03olK1eOno[LSo_jg800?o
_jg800Co]Z?5ol72foo1`]_o`L;K0onj/]400onkc^So^;kOokRng`04okRng`;o];OK0_neb^X3ok;1
i@;o[/__1On_a^/2ojg1j003o`000?n[b>oo[<G/00?o[<G/00?oZl?[ojW5kOnYaNd00_nYaNd2oj[3
k0;oZ<C]1OnY`n`2ojW1j`;oZ<7/5?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Wooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo01?ooooo0_n1/oD2oi6ilPCoSLCj0_n6col4
oj3Gn`03oi_QoOndg_Go]=ke00;o]=ke0onndNP00onoeN[o_;gJokbmfP02okbmfP?o^kWG00?o/ZO>
ojnQbOn_XLT00_n_XLT3o`000004oj^JaOnWTl7oYi?1oib5^PCoV7nf0onEN[<4oi9f/0?oSg:^0on>
Kj`3oha]ZPCoRfbY1_n:JjT4oh][Z@KoRVbZ1?n=KZ/3oi1`ZP?oSfjY1?n;JjT3oh=UZ0?oO62W1?n1
HJD3ohQUX`CoTf^R1?nLLJ44oj9gXP03ojEjY?nIhYCoS5V?00;oS5V?0on:Ehl4ohYHS`CoS5VA0on?
GI<00onCHYGo^Y:]okZB[@02okZB[@Co[hFX0onWOJD00onbQJGo/X>Rok:3XP03ok:3XP?oXg>L1?nL
K9X2oiIYV`?o^XjX1?nbQJH00on/PJOo`IZ`ol6J/002ol6J/0Co/XNX00CoZH2Wol>S^Oo3XkWo`j>i
1OnhU;84olF/`@?o]iVi0_o6`MD4okn]b003olGSkOo1`]_o`L;K00?o`L;K00Co^[;Aok_>j?nkc^So
^lkX1?nh_]l00onbe_?o]L[ZokG:jP03okG:jP03ok;1iOn^bnoo[/__00;o[/__0_n_a^/2oj[=lP?o
ZlS_00Co0000oj_8kon/aNco[<G/0_nYanl3ojW5k@;oZ<G_1?nXa>d2ojW3k0?oZ<;/1?nX`N`Coooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool000Wooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool05Oooool4oi6i
lP;oSLCj1?nSb_@2oj3Gn`Co/mCa00Go]=keokkAj?nndNSo_]7Xokfog006okbmfP05ok^ieonbYlko
/ZO>ok:Wc_n_XLT00_l00003oj^Ja@04oin;__nLQK[oW8Fjoib5^PCoV7nf1?nEN[<3oi9f/0?oSg:^
0on>Kj`4oha]ZP?oRfbY1_n:JjT4oh][Z@KoRVbZ1?n=KZ/3oi1`ZP?oSfjY1?n;JjT3oh=UZ0CoO62W
0on1HJD3ohQUX`CoTf^R1OnLLJ43oj9gXP03oiWRU?n<FHooS5V?00;oS5V?0on:Ehl4ohYHS`CoS5VA
0on?GI<5okZB[@Co[hFX00?oYgfUok:5YOnbQJD00_oK^KH4ok:3XP?oXg>L1?nLK9X00onFJI_o^XjX
okZ>Z002okZ>Z0Co/XFV1Oo1V[04ok:7Z0Co`j>i1?nhU;82omOEe`CoaJc100?o]iViolK1eOo6`MD0
0_o6`MD2okn]b0?oaN?]0oo1`]/2ok7Qm`Co^lkX00?o^;kOok;Flonbe_<00_nbe_<2okG:jP;oZ]?e
1?n^bnl00onVdOKoZ/gboj[=lP03oj[=lP;oZlS_00?oYlWao`000?nYanl01?nYanl00onYaNgoZ<G_
ojS5k`02ojS5k`;oZ<C]0_nW`nd5ojS2k0;oZ<7/0_nW`>`Cooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02Oooool000Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Gooooo0ol0000Fooooo`;oTKWb0onS_nd3oj?:m0;o//_/1?nce?43okc<i`04okkA
j?nm_mco_KoLokfog0Co_;gJ00?o]JkBok:Wc_nbYlh00ol00003ojnQb@04oj^JaOnORkkoWh^noin;
_P?oW8Fj1?nHOkH3oiEj/`?oTWJ`0on?LZh3ohi_[0CoS6fZ0on;K:T6ohY[Z@CoRf^Y1_n:K:X4ohe^
Z`CoT72Z0on?KZT4oh][Z@?oPfFX0omlH:L3oh5QY@?oR6FS1?nCJj85oiaaX@;oXWNR00?oVN:DohmK
T?n<FHl00on<FHl3ohYGS`CoRUR?1?n<FI43ohmMT`Go^Y:]1?n_QJP00on^P:?o/XFUok:5Y@02om^i
]PCo/X>R1?nSLi`3oia/VPGo^XjX1?nbQJH00ooUf<Wo`IZ`ol6J/002ol6J/0Co/XNX00?odLK?ol>S
^Oo3XkT00_o3XkT2okRD/P?oemGG0oo5[<42olC]l0Coa/7E00?o_jg8olGSkOo5hnd00_o5hnd00oo1
`]_o/N7gok7Qm`03ok7Qm`;o^lkX0onRho`2ok;Fl`;oW]Wl1?nZdoD00on^bnooY]7fojKAmP02ojKA
mP;oZ/gb0_nUbo@4ojO9l@03o`000?nYanooZLO_00;oYlK`1?nXaNl00onV`nkoYl?]ojO3k@03ojO3
k@;oZ<;/0_nW`N`5ojO0k17ooooo0ol00007ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo
01Sooooo1?nS_nd00onSb_Co//_/ok;;k002ok;;k003ok?DlOnlc>Oo_<cW00;o_<cW00?o_L7Mokfo
g?nm_m`00onm_m`00onl_M[o]JkBokF^dP03o`0000?o/ZO>0_n_XLT00onST/?oWh^noin;_P02oin;
_P?oW8Fj1?nHOkH3oiEj/`?oTWJ`0on?LZh3ohi_[0CoS6fZ0on;K:T6ohY[Z@CoRf^Y1on:K:X3ohe^
Z`CoT72Z0on?KZT4oh][Z@?oPfFX0omlH:L3oh5QY@CoR6FS0onCJj85oiaaX@04oj9gX_n?Fi3oSe^@
ohmKT0CoS5V?0on:Ehl4ohYHS`CoS5VA0_n?GI<2ol6K/0Go^Y:]0_n_QJP2ojj0X`04ok:5YOoK^KKo
fkVfom^i]PCo/X>R1?nSLi`3oia/VPGo^XjX0onbQJH2onGHb@Go`IZ`0_nbQjP2om76c`Co`j>i00?o
^9BbomOEeooGeML00ooGeML00oo5[<7oa>g`olC]l002olC]l0;oa/7E0on3j]h2olGSk@?oNN7a0_na
hOL3og?Lm@;oX^?l0on7eol4oikIo0;oZ]?e0onMdo/2ojKAmP;oX<_f1?nUbo@2ojO9l@03ojG7lOl0
003oYLOa00CoYlK`00?oZ<G_ojK3k_nV`nh00_nV`nh2ojO3k@;oY/7/1OnW`N`2ojO0k0;oY[o[3_oo
ool4o`000003ooooool0003ooooo00Kooooo00?o0000ooooooooool02Oooool000Wooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06Ooo
ool2oj>ok@?o/L;W0_nbbn`4ok[8i004okc<ionm`Mgo_L7Mokg1g@?o_KoL00Co]k?Fo`000?l0003o
00000one[]82ok:WcP03ojNJb?nST/?oXi;300;oXi;30onORkh3oib5^PCoV7nf1?nEN[<3oi9f/0?o
Sg:^0on>Kj`3oha]ZPCoRfbY1_n:JjT3oh][Z@OoRVbZ0on=KZ/2oi1`ZP?oR[Kc1?mn_?X4oeJin`04
obh00?mlH:OoO62WogaPY`?oPF6U1?n8IJ<4oi=[XP?oW76Q0_n@G943ohmKT0CoS5V?0on:Ehl4ohYH
S`CoS5VA00CoSefCol6K/?o1Vk3o`I^`1OnjTZd01On_QJSo[X2Sojj0Xon^P:?o/XFU00?ofkVf1?nb
Pj84oj=cW0;oW6bJ0_noVk<5okZ>Z004ok:5Y_oUf<WoiMS9onGHb@Go`IZ`00Co/XNXom76cooAa/oo
dLK?0oo3XkT3ofc@U@;oemGG0onFSLP2olC]l003ogFJj?nQVlkoXI_>00CoS:?T1?mc/_T4oeflo@Co
KLgn0_n7eol2ohG:oPCoT];m0_nMdo/2oi[9n0GoX<_f0_nUbo@2oj;7l`?oYLOa00Co0000ojG7lOnW
a_3oYlK`0onU`nl2ojK3kP;oY/7]1?nV`N`2ojO1k0;oY[o/1OnV_n/:ooooo`?o00001Oooool00ol0
003oooooooooo`03ooooo`03oeEEEOmVIVKo000000_ooooo0009ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo0_l0000Kooooo`?o/L;W0_ni`n84
ok[8i0;o_L?N1?nm`Md3o`000003okNce_ne[];o]JkB00;o]JkB00?oZj;=ojNJb?nWV/P00_nWV/P3
oj>B``CoWh^n0onLQKX3oiQo]PCoUGZc0onBM[03ohmb[P?oSVn/0on<KJX4oh]/Z@KoRV^Y0_n;JjT0
0on>RLWoSI7BohfAdP02ohfAdP?oR9[M1On9Z>T4ohZfl`;oO[cj0_moGJ43ogmNXP?oSF6J00?oO62W
oh5QYOn1HJD00_n1HJD3ohQUX`CoTf^R0_nLLJ43oi1LT@?oSe^@1?n<FHl3ohYGS`CoRUR?1?n<FI40
1?n?GI?o`I^`ol6K/?o1Vk04okZB[@Go[X2S1?oK^KH5ok:3XP?oXg>L00CoW6bJoknK/onoVk?o_i^c
1OnjSZP00onbQJKoiMS9onGHb@02onGHb@?o`IZ`00?oPnJoom76cooAa/l00ooAa/l00oo3XkWoZ8bh
ojR<^004ojV>^0CoUXg81OnQVlh4ohbSi0;oLk;i00?oV:GOohV`kon9/>l00_n9/>l5ohC0n`CoQL[n
0_nBd_d3oiK5m`?oV/Wh0_nPboH2oio5l`GoX/Oc0_nUao400onT`noo0000ojC3k`02ojG3k`;oYL3]
1OnV`Nd2ojK1k0;oY[o[1?nV_n`4ojJoj`Kooooo1?l00008ooooo`03o`000?oooooooooo017ooooo
0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Go
oooo00?o0000ooooooooool06oooool00ona`^Oo^L?RokW3hP02okW3hP03ok[8i?nm`mko_L?N00?o
_L?N0ol000000oni^MWo]k?FokNceP02okNceP03okF^d_n[X/goZj;=00;oZj;=0onWV/P3oj>B``Co
Wh^n0onLQKX2oiQo]P03oi1o_On=Nk[oSG^j00;oSG^j0on;NKT3ohYg^0?oRGNh0on9N;T4ohUj^`?o
RWbo0on;P/<4ohj9b@CoSI7B0on8V]d5ohVXj@;oR[Kc0_n1Gj83ogmMX@?oOejR0omoGj<00on=HI[o
PF6Uoh5QY@02oh5QY@?oR6FS1?nCJj800onLLJ7oT5jCoi1LT@02oi1LT@?oSe^@1?n<FHl4ohYGS`?o
RUR?1?n<FI45ol6K/0;o^Y:]00?oYgZRojj0Xon^P:<00on^P:<00ol0003ofkVfom^i]P02om^i]PCo
/X>R0_nSLi`00oo3_MCo_i^coknK/`02oknK/`Go^XjX0_nXQK03onGHb@05ol6J/?n[PZSoZh:XoiIk
/onfT:l00_oAa/l4ojR<^003ok^F/OnYS[SoZHjh00;oZHjh0onFSLP2ok2I_`CoXI_>0_n<Xn@2ojFN
c`CoV:GO1?n9/>l2ohC0n`?oVKC[1?nD_O<2oiK5m`;oWK_^1OnM`O43oio5l`;oX/Oc0onR`Nl2ojC3
k`03o`000?nU_ncoYL3]00CoYL3]0_nV`Nd7ojJoj`;oY[o/1_nV_n/2ooooo`?o00003?ooool00ol0
003oooooooooo`0Aooooo`008_ooool00ol0003oooooooooo`0Mooooo`?o^L?R0onla=l01?nm`mko
0000o`000?l00005okVif@;o]k?F0_n_ZM84oj^Rc@?oYi[81?nST/<2oin;_P04oiJ9`onBPkooTX>o
oi:3_`CoT7nm0on=NkX4oh]i^@?oRWNh0on9MkP3ohUh^@?oRGZk1?n:O;l3oh^2``?oSXW91?n=TM84
ohRJg@;oRJSY00?oR6NVohARXon4HZ<00on1Gj83ogmMX@?oOejR1?moGj<2ogMLYP03oh]NV?n1HJGo
R6FS00;oR6FS0onCJj83oi1NT`?oT5bA0on?Fi04ohaIS`CoRUN?0on:F8l3ohaIT@;o`Yjc1?o1Vk00
1?njTZgoYgZRojMjX_nWNZ83ojj0X`?o[hZ^0ooK^KH4ok:3XP04oj=cW?o3_MCo`kgDol>me0?o_i^c
1?njSZP00ongS:SoZ8F`okR<Z002okR<Z0CoZh:X1OnfT:l2ojR<^0;o^iJa1OnYS[P01?nFSLSo/9Vo
ok2I_on`VKl3oj6KcP03ok6NaOnUW/ooYIk?00?oYIk?1?nHYMl2ohV`k`;oWj_O1OnI]>/2oiBml`;o
W[CW1?nM^nh2oig1l@;oX[[[1OnR_^d2oj;1k`;oY;g[0_nU_n`01?l0003oYKo/ojG0kOnU`>d3ojJn
j`KoY[o[0_nV_^/7ojJoj`;oYko[00?o0000ooooooooool03_ooool00ol0003oooooooooo`0@oooo
o`008_ooool00ol0003oooooooooo`0Nooooo`04okW3h_nla=oo_<COokc4g`;o000000Co_L?NokZn
gOnj_]go^[kM0oni^MT00onb/]So[jWBojnYdP03ojnYdPCoZj;=0onWV/P2oj>B``03oiZ?aonFRL?o
UXW300;oUXW30onBPkl3oi1o_@?oSG^j1?n;NKT3ohYg^0?oRGNh0on9N;T4ohUj^`?oRWbo0on;P/<4
ohj9b@CoSI7B0_n8V]d4ohQWYP?oQ6:S0_n1Gj84ogmMX@;oOejR1?moGj<3ogMLYP?oRUbF00?oSEfD
oi=[X_n=GI@01?n@GY<3oi1LT@CoSe^@0on<FHl4ohYGS`?oRUR?0_n<FI43ol:N/`Co`I^`1?nWNZ82
ojj0X`03oj^5[?n_RZko[hZ^00;o[hZ^0_nbQJD2ok:3XP;o8Jfg1?o3_M@4oknK/`;o^XjX0_ngS:P0
1?nXQK3o^8bXokR<Z?nhS:P4oj^2Z0Go]Y2_00?oZ8bhok^F/OnkU[400_nkU[43ojV>^003okfO^on`
VKoo/9Vo00?o/9Vo00CoXI_>ok6NaOnaW/Go/Ik51?nUW/l2oiRUg`?oZJOE1?nOZml2oiVdj`;oY:oO
1OnN]>L2oifkkP;oY;OV1?nR^^/2oj:nk@;oYK[Y1OnT_N/2ojFok003o`000?nV_N[oY[k[00CoY[k[
0_nV_n/2ojJmjPCoY[k[0_nV_n/7ojNoja3ooooo00?o0000ooooooooool04?ooool002;ooooo0_l0
000Pooooo`?o000000?o_<COok_4h?nj_]d01?nj_]d01?ni^MWo/[;Hok:bf?nb/]P5ojnYdP;oZj;=
00CoXYkAoijFc?nNU/coWYK<1?nJSlL3oiJ9``?oTX>o0on@Okd4ohek^P?oRgVi0on:MkP3ohUg^0?o
RGRi1?n9N[/3ohYl_`CoRh;30_n>RLT2ohMXY`?oU7Ra0on=KZ/3ohQWYP?oQ6:S0on1Gj83ogmMX@?o
OejR0omoGj<3ogMLYP;oJ5J[00CoRUbFoheMU?n=GICoSEfD1?n@GY<3oi1LT@CoSe^@0on<FHl4ohYG
S`?oRUR?00?oS5VAol:N/oo2W[<00_o2W[<3ol6K/003oj1dXOnWNZ;oYgZR00;oYgZR00?o[X2Soj^5
[?n[QJ`01?n_RZh5ok:5Y@03ojUkXOlQ[KOo`kgD00;o`kgD1?noVk<01?njSZSo]hbXokN<Z?ngS:P4
okR<Z0?oZh:X0_o7Wjl4okJ@[`Go^iJa0_nYS[P3okfO^`Co/9Vo1?naW/D3ojFNc`03ok>Wc?nYYmGo
ZJOE00CoZJOE0_nOZml00onZZmOoY:oOojB_g`03ojB_g`;oW[CW0_nW/n45ojBgiP;oX[[[00?oY[SV
ojFjjOnU^^T00onU^^T2ojBmj`;oY[_X0onV_NX01?l0003oY[gZojJnjonV_^/2ojJmj@GoY[gZ0_nV
_^/2ojNnjPSoYko[4?ooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0L
ooooo`?o000000?ooooookc4gonka>000onka>03okZng@03okFjgOnb/]So/[;H00?o/[;H0_n_ZM82
ojFVePCoXYkA0onNU/`3oiZ?a`?oUXW30onBPkl4oi1o_@?oSG^j1?n;NKT3ohYg^0?oRGNh0on9N;T3
ohUj^`CoRWbo0_n;P/<2ohe_Z`?oQfRW0on3HjD2oh1PY004ohe^Zon8IjKoR6NVohQWYP?oQ6:S0on1
Gj83ogmMX@?oOejR0omoGj<3ogMLYP?oJ5J[0on=GI@4oi1NT`?oT5bA1?n?Fi03ohaIS`CoRUN?0on:
F8l6ol:N/`03ol6K/?nPM:7oX7BQ00CoYgZR0on[QJ`3ojn:[P;o`9Za1?nbQJD2ojUkX@Co`kgD0_no
Vk<5okN<Z0Go^8bX00CoZh:XolNO[oo7Wjooain_1?nfT:l00oo8Y[Oo^iJaok^F/@02ok^F/@03ojV>
^?nmWk_o_Ink00;o_Ink0on`VKl2okjV`@Co/Ik500CoYIk?ok>Wc?ncYlco/jO<1?nYYmD00onb[=;o
ZZ_GojZ[e`02ojZ[e`?oY:oO00?o[;7LojNchOnW/n400onW/n43ojBgiP03ojRfh_nV^>KoY[SV00;o
Y[SV0onU^^T00onW^^KoY[_XojJkj003ojJkj0;oY[gZ00?o0000ojNlj?nV_NT01?nV_NT3ojJmjP03
ojNmjOnW_^[oYkkZ00?oYkkZ2?nW_n/?ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`00
0?oooooooooo01Wooooo0ol00006ooooo`Co^lCP00Co^[kMokFjgOne^]go]K[M0onb/]P00onY[mco
YJKFojFVeP03ojFVeP?oXYkA0onNU/`3oiZ?a`CoUXW30onBPkl3oi1o_@?oSG^j1?n;NKT3ohYg^0?o
RGNh0on9N;T2ohUj^`;oDLS`0onDN;44ohe_Z`?oQfRW0on3HjD3oh1PY0?oR6NV0on4HZ<3oh5OXP?o
OefQ0omoGZ83ogmOX`CoMebV0_mXEZ/00omJEK;oSEfDoheMU004oi1NT`?oT5bA1?n?Fi03ohaIS`Co
RUN?0on:F8l00onkV[Ko`Yjcol:N/`03ol:N/`?oX7BQ1?nWNZ84oj^5[004ojn:[_o0V[7o`9Zaol2J
/@Co/XFU1?nYNj44okbBZ`Co]hbX00?odJbcokR<Z?nhS:P00onhS:P01?n[PZSoain_olNO[oo7Wjl3
okJ@[`;ob:Jg1?nkU[46okfO^`04ok2I_onnY/7o_ZK1okjV`@?o/Ik500?o_:g:ok>Wc?ncYl`00onc
Yl`00onYYmGo/ZcBok:/dP02ok:/dPCoZZ_G00CoY:oOojbag?n//Mco[;7L1?nW/n400onT]nKoZ;KR
ojRfhP02ojRfhPCoY[SV00CoYK[YojNji_nW^^KoYk[V1?nV^nP01OnV_N[oYkcXojNlj?l0003oYkcX
00CoY[gY00?oY[gZojNmjOnW_NT00_nW_NT4ojNnjPOoYko[00?oZ<3[ooooooooool03Oooool00ol0
003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0Fooooo`?o00002_ooool2ok_4h0;o
]l?S1?ne^]d01?nb/]SoZJoLojV_g?nY[m`4ojFVePCoXYkA0onNU/`3oiZ?a`;oUXW300CoS9?EohVA
eOn9TMGoRI7E0on7TMH3ohBCfPCoPiWP1?n1X^T4ogfam@;oL/?n00CoY8nooib3]onLPkOoW8>g0onD
N;43ohe_Z`?oQfRW0on3HjD3oh1PY0?oOUnU0on4HZ<3oh5OXP?oOefQ0omoGZ84ogmOX`?oMebV0_mX
EZ/2oeYE/P03oheMU?n@GY?oT5jC00;oT5jC0on@G944ohmKT0?oS5V?1?n:Ehl2ohYHS`;o^iZf1Oo2
W[<4oj1dX@;oYgZR00?oY82]oj^5[?n[QJ`00_n[QJ`01?n_RZko`9Zaol2J/Oo0V[45ok:5Y@?oZG^Q
1OnlTZ/2okN<Z0;odJbc1OnhS:P5olNO[`04okJ@[oo8Y[Oob:JgolRV]`Co^iJa00?oc[:nokfO^onm
Wk/00_nmWk/00oo:]lOo_ZK1okjV`@03okjV`@04ok6NaOnl[L[o_:g:okb]bP?o/jO<00?o^k;Aok:/
d_nb[=800onb[=82ojZ[e`;o/[;I1On//M`2ojNch@;o[;CO1?nX]^82ojJhiP;oZKWT1OnW^^H2ojJk
j0;oZ;_W0onW_>P00ol0003oY[gYojJmj@06ojNmj@03ojRnjOnW_^[oYkkZ00?oYkkZ0_nW_n/2ojRo
j`CoZ<3[3_ooool00ol0003oooooooooo`0@ooooo`008_ooool2o`0001Cooooo0ol0000>ooooo`Co
]l?S0_ne^]d2oj^hhP?oZJoL1OnUY]H2oj:Nd@04oiNQg?nCVmSoTi_Hoi>Kf0?oT9OF1?n<TmD3ohVA
e@?oQi7F0on4TmX4oh>Ih0CoPJ;Y0_mm/OD4ojB?_`?oW8>g0onDN;43ohe_Z`?oQfRW0on3HjD3oh1P
Y0?oOUnU0omlHJP3oh5OXPCoOefQ0_moGZ84ogmOX`?oMebV0omXEZ/2oeYE/PCoT5jC0on@G944ohmK
T0?oS5V?1?n:Ehl01?n:F8oo^iZfok^J]_nkV[H4ol:N/`GoX7BQ00?oYgZRojB0[OnTP:d01?n[QJ`4
ol2J/@Go/XFU0_nYNj42olFV^PCo_9:[00?o]hbXom6//ooA[;<00_oA[;<4okR<Z003om>k`_o7Wjoo
ain_00;oain_00?o]Y2_olRV]oo8Y[L00_o8Y[L2ok^F/@;oc[:n0onmWk/2olZga`Co_ZK100?ob;c?
okb]b_nl[LX00onl[LX01?ncYlco^k;Aok^bdOnk/]43ok:/dP03okNgf?nb/]Wo/[;I00?o/[;I0_n/
/M`2ok2fg@Go[;CO0_nX]^82ojbhh`CoZKWT0_nW^^H2ojVjiPGoZ;_W0_nW_>P00onX_NSo0000ojNm
j@04ojNmj@CoZ;kY0onW_^X00onX_n[oZ;o[ojRoj`03ojRoj`CoZ<3[3Oooool00ol0003ooooooooo
o`0@ooooo`008Oooool2o`0001;ooooo0ol0000Booooo`;o]l?S0_n]`NT4oj^hhP?oZJoL0_nUY]H2
oi^Xg`CoUj7L0onCVmP3oi2GeP?oS9?E0on9TMD3ohNAePCoQ9?J1?n3VN02oh6Rj@Co[9c70onTSkl3
oib3]`?oU7Ra1?n=Kj/2ohMXY`?oPf>U1?n0H:@2ogiOY@?oO66X0omhIK04ogmMX@?oOejR0omoGj<3
ogMLYP?oJ5J[0_mJEK82oeAJ^`;oT5jC0on@G944ohmKT0?oS5V?0on:Ehl00on]TKWo^iZfok^J]P03
ok^J]P;o`Yjc00?oVFnQoj1dXOnPM:400onPM:401?nWNZ;oY82]ojB0[OnTP:d2oj^5[0;odL;;0oo0
V[45ok:5Y@04ojUkXOo5Y[[oaJJjolFV^PCo_9:[1OoA[;<3okR<Z0;odk_21?o7Wjl5olRV]`03ok^F
/Oo>/[koc[:n00;oc[:n00?o_InkolZgaoo:]lL00_o:]lL2okjV`@?ob;c?0onl[LX00oo2_]Oo^k;A
ok^bd@03ok^bd@04ok:/d_ng]mSo]kOHokNgf0?o/[;I00?o]K[Mok2fgOn`]]d00on`]]d2ojbdg`;o
[k[R1On/^><2ojVii0;oZk_U1?nY^^H2ojRki`;oZKcW0onX_NP01?l0003oZ;gXojNmjOnW_NT6ojRn
j@03ojNnj_nX_n[oZ;oZ00;oZ;oZ0_nX_n/7ojS0j`cooooo00?o0000ooooooooool04?ooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool03oooool2o`0001Kooooo1?n]`NT2oj^hhP;oWkKY1?nM[n@3oi^X
g`?oUj7L1?nCVmP3oi2GeP?oS9?E0on9TMD3ohNAeP;oQ9?J0omIb?P00oo2io3oa^?/ok>Yc`02ok>Y
c`?o[9c71?nTSkl3oib3]`;oU7Ra1?n=Kj/3ohMXY`?oPf>U0on0H:@3ogiOY@;oO66X0omhIK03ofm`
a004ogmMXOmoGZ;oOejRogmNXP?oOenS1?mgG:H2ofQFZ`?oFUFb0omDF[/3oi1LT@CoSe^@0on<FHl0
0on:Ehoo[I6iojfA^@02ojfA^@Co^iZf00Co`YjcoiU_XOnIKj7oVFnQ0onPM:45ojB0[@04oj^5[?oA
`/_odL;;om72b`Co`9Za0onbQJD00oo;gNKoaJJjolFV^P02olFV^PCo_9:[00?ogok:om6//ooA[;<0
0_oA[;<2okR<Z0?odk_21?o7Wjl00ooUh]3ob:JgolRV]`02olRV]`Goc[:n1Oo:]lL00onnY/7ob;c?
olRlc`02olRlc`03okb]b_o2_]Oo`[kG00;o`[kG0onk/]400onm`Mco]kOHokNgf003okNgf004ok:b
fOne^]go]K[MokFjg@?o/;KM00?o/KgRojnjh_n_^^800on_^^82ojbhh`;o[KcU1On[^nD2ojVjiP;o
Z[gW1?nY_>L2ojRmj003ojVnjOl0003oZ;kY00KoZ;kY1OnX_nX:ojS0j`gooooo00?o0000oooooooo
ool03oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00cooooo0ol0000Iooooo`;o[L7Y0onP_^h3oinfj@Co
WJoT0onKZ=l3oiNQg0;oTi_H00?oR:g^oh>^lOn3[_400_n3[_43ogjbm@CoN;Wj0_m]`_h4ol;Wl003
okReeoncZLoo/jW?00;o/jW?1?n/W<L3ojB?_`?oW8>g0onDN;43ohe_Z`?oQfRW0on3HjD3oh1PY0?o
OUnU0omlHJP3ogQU/0CoKg340_m=VO83ogmOX`CoMebV0omXEZ/2oeYE/P?oE5Zk0om[K<84ohmKT0;o
S5V?00?oWHRlojfA^On]TKT00on]TKT4ok^J]PCoVFnQ0_nPM:42oiYj[P?oY82]00?oa?;_om72booA
`//00_oA`//4ol2J/@04ok:5YOo;gNKobmgVol_MiPGoaJJj0_nlTZ/2omonbPCodJbc00?o^8bXom>k
`_oC^l800ooC^l82olNO[`;oiN;@0oo8Y[L2omGJg0?oc[:n0_oHiml3olZga`03olSHiOo8_<oob;c?
00?ob;c?1Oo2_]L00onk/]7o_L7Lokg1g002okg1g0?o]kOH00?o^<;RokFjgOne^]d00one^]d01?n`
]]go/KgRok6mh_na_N83ojnjhP;o[koU1?n]_>D2oj^ki@;o[;kW1OnZ_NL2ojVli`;oZKkX0onY_^T0
0ol0003oZ;kYojRnj@02ojVojPCoZ;oZ3_nX`>/<ooooo`03o`000?oooooooooo00oooooo0007oooo
o`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo0_l0000:ooooo`?o00007Oooool5
oj2nkP?oWkKY0_nM[n@00onA/nkoSk3]ohn`k@02ohn`k@?oRjk]0on8[Nh4oh>^l@?oO[;e0_mh^OX0
1Om8a[[o_^ObokkWl_nnio;o`^O`00Co^;GG1?ncZLl2ojbLa`04oiR8`On@O[coT7jloi1n_0?oRGJh
0on1KkH3ohe_Z`?oQfRW0on3HjD3oh1PY0?oOUnU0omlHJP3ogQU/0GoKg3400?oCIWbogQS[_m]EjP0
0_m]EjP00omTDJOoT6RPoi1XX002ohIMV`03ogiFVOmJEK;oFUFb00CoE5Zk0_m[K<84ohQn`@CoWHRl
1?n]TKT3ok^J]P;oU6bQ0onIKj401OnPM:7oVWZ^oiYj[_nJNZkoY82]00Coa?;_1?oA`//2ol2J/@03
oiegZ?nMNJ_obmgV00?obmgV1?o5Y[X00onlTZ_ogok:omonbP02omonbP;odJbc0_m]g<05om>k`P03
olNO[ooUh]3oiN;@00;oiN;@00?ob:JgomGJg?oEf]`00_oEf]`00oo>/[kof>OOomSWg`02omSWg`04
olZgaoo8f>Gob=SUolSHi@?ob;c?0_o6f>L3ol:ne`;o_<oY1?nm`M`00ong]mSo^<;RokS2hP02okS2
hP;o]K[M0_nd`nD5ok6mhP03ojnjh_n__nGo[koU00;o[koU0_n]_>D2ojg0j0Co[;kW0_nZ_NL2ojZo
j@GoZKkX0_nY_^T00ol0003oZKoZojVojP03ojVojP03ojRoj_nX`>_oZ<3[00ooZ<3[2oooool00ol0
003oooooooooo`0?ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgM
gOoooooo00001_ooool00ol0003oooooooooo`06ooooo`?o00008Oooool2oj2nkP?oU;[a0onC]o03
oi6ckPCoSk3]0on;[^d3ohR]kP;oPjka0_mJboH3of7Gh004ohk^j?nnio;o_^ObokkWlP;o^[kM1?nh
]ML2ok>Yc`;oX9?71?nHR<43oi1n_0;oRGJh0on1KkH3oga[]@?oQfRW0on3HjD3oh1PY0?oOUnU0oml
HJP3ogQU/0CoKg340omhHjh3ofeGZ0;oI56W00CoT6RPohIMVon6GI_oQUfK0omnEYT3oeAJ^`?oJfc2
1?n8O/43oif8_0Go[I6i00Co^iZfoiA/XOnDK:7oU6bQ0_nIKj42ohmc[`;oVWZ^0on>iO/2olCbk`04
oiAd[?nIM:SoVGBXoiUdZ0CoWGNX0_nMNJ/3ol_MiP;oaJJj0_ndSZh2oj^>]`;o_9F_1?ncT[@01Oo7
XkGo]9Zmom>k`_oC^l;o]9Zm00;o/Yc10_oUh]000onbW<7oP9;Koh2Bf`02omGJg0?o00000_oHiml2
of[Li0Gob=SU00?ob;c?olKHioo6f>L00_o6f>L00oo2_]Oo_<oYokc?j@02okc?j@;o_L7L0_nhc^/3
okS2hP;o//W[1?nd`nD2ok6mhP;o/<?X1?n__nD00on]`n[o[L3Xojg0j003ojg0j0;o[;kW0_n[`NT4
ojZoj@;oZKkX0_nY`>X3ojVojP04o`000?nY_n[oZKoZojVojP;oZL3[0onX`>/2ojS1j`KoZ<3[0_nX
`N/5ojS0j`[ooooo00?o0000ooooooooool03oooool000Oooooo00Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool00oooool3o`0002Kooooo
1?nD^_43oi>gl0?oTK?^0_n?/>d2oh?1n`CoN/Gn0_m_b_l2og?KmP?oTn_f0onhho@00onnio;o^[kM
okZng@02okZng@;o^;GG00?oYig<oj2CaonPTlL00_nPTlL4oiR8`@?oT7jl0on9M[P2oh5_]P?oO6^e
0omgJ[L3oh=SY@CoP62T0_mnGjD4ogaQZ0?oN6F`00CoKg34og=KZ?mcFjSoS7Vj0omhHjh2ofeGZ0?o
I56W0on6GI/3ogiFV@;oM52J00CoE5Zkof]/`_m[K<;oJfc21?n8O/43oif8_0Co[I6i00?oT6VRoiA/
XOnDK:400_nDK:400onIKj7oOjG/ognUk003ognUk0;oS^Gk00CoVGjeoiAd[?nDM:coU7B/0onIM:P5
oiegZ0;oWGV[00?o/H^]okB>[_ndSZh00ondSZh01?n[S[Oo_9F_okbE[onlUJl3ok>B]0;oaj>e1?nd
V[d00oo2XkWo/Yc1ok:L`@02ok:L`@GoYig<1?maU>@3oaN6j0;ob=SU1?nBj?X2olKHi`?oYn3k0_nl
cnT2ojWHn0Co^<k[00?o^<;Rok;9jonbbN/00_nbbN/2okC3i@;o/<S/1?n``nP00on__nGo[L?Zojg3
jP02ojg3jP;o[L3X0_n[`n/5oj_1j@;oZ[oY0_nZ`N/4ojW0jP;oZKoZ00?oZL7[o`000?nY`>/01?nY
`>/00onX`>_oZ<7[ojS1j`02ojS1j`;oZ<3[1_nX`N/4ojS0j`[ooooo00?o0000ooooooooool03ooo
ool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Gooooo00Co
0000oooooooooooooooo0ol0000Zooooo`;oU;[a0_n?^O<3ohbkm@CoR;gh0on3`O/2og[5oP;oP=Oo
0onHi?`3okCMm@;o^>?d0_nja>83okZng@03ojfWd_nWWLcoYig<00;oYig<1?nPTlL3oiR8`@?oT7jl
0on9M[P3oh5_]P?oO6^e0_mgJ[L3ogA__PCoP62T0omnGjD3ogaQZ0;oN6F`0_mnIJ`3og=KZ0?oN6>^
0_m]EjP3ofAAY`;oKEf_00CoQUfKogiFVOmnEYWoOUJI1?mdD9X2of]/`PCoR7k11?nMR;`2ojfA^@;o
T6VR0_nDK:44og5/_@?oOjG/00Co[J7<oiUn]OnIO[GoVGje0onDM:`3oiUdZ0GoWGNX00CoWGV[ok6;
[OnaRjgo/H^]1?ndSZh5okbE[`04ok>B]?o7XkGoaj>eolNS]@?o]9Zm0_o2XkT3ok:L`@;o`ZNn0onW
WL`00onfY<KoWYkDoijNe002oijNe0GoLig[00?o=9Gao`1fa_m?aO800_m?aO82ojOPn`;oOMCo1OnY
f?P2okS>j`;oZ]7d0_nbbN/2ojW=l`Go/<S/0_n``nP2ojc6k@?o[L?Z0_n[aNd4oj_3j`;oZl7Y0_nZ
`^`5oj[1j`;oZL3Z1OnY`N/00ol0003oZL3[ojW0j`05ojS1j`;oZ<7/2?nX`N/5ojS0j`Wooooo00?o
0000ooooooooool03oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000000Gooooo1?l0000^ooooo`CoSkWc0on<^oD2ohRmn0?oSLSk0_n8d?l4oi[Ko@04oiSTo?nd
gOGo]=geokCMm@;o^LOU1?nja>801?nj_]go[JOBojfWd_n]Ym83ojNMc0CoX9?71?nHR<43oi1n_0;o
RGJh0on1KkH3oga[]@?oMfZg0_mdKkh3og9kcP04oh1PY?mnGjGoOUnUogiOY@;oO66X00?oG]7aoi1h
/on@N;<00omnIJ`2og=KZ003ofIEZomhHjkoN6>^00?oKENX0_mTDJL3ofeM[`?oOUJI0omdD9X3ok>h
g003of]/`_n8O/7oR7k100;oR7k10onMR;`00on]TKWoM5JQogAFX@03og5JZ0CoLFbm00CoOjG/ojfQ
c?n]XLco[J7<0onIO[D3oiAd[0?oVGBX1?nMMjP00onZQZoo/H^]ok6;[@02ok6;[@Co]8j^00?o`ijb
okbE[onlUJl00_nlUJl00oncT[Coaj>eolNS]@02olNS]@03okBJ_Oo2XkWo`Z>i00;o`Z>i00?o/Yc1
ol:W__o2Ykh00_o2Ykh01?nWWLco]ZC6okJTa_nfY<H4oijNe0;oLig[0_nHY=h3og>Tl0CoAKCf0omm
e?l2ojWHn0?oUM;m0_nZdO@2oig?n@CoZLgc0_n`b>`2ojW9l@Go[<K]00?o[L?Zoj_5kOn[aNd00_n[
aNd2oj_3j`;oZLC]1?nZ`^`2oj[1j`;oZL;/1onY`N/00ol0003oZ<7[ojS1j`02ojS1j`KoZ<7/0_nX
`N/2ojS1k0CoZ<7[1?nX`>/9ooooo`03o`000?oooooooooo00oooooo0007ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`04ooooo`;o0000<Oooool2ohnil`;oU;[a1?nA
`OL2ohg8n`?oW=3j0_nJfod4ok3Gm003okCMmOnianGo^LOU00;o^LOU0_nja>800on`/=Oo[JOBojfW
dP02ojfWdPCoYig<0onPTlL4oiR8`@?oT7jl0on9M[P2oh5_]P?oO6^e0omgJ[L3ogA__PCoLW_>0omc
Wnd01?nTTL7oT7Rcoi1h/on@N;<3ogiU[0;oLe^X0_mVEJ/01?mhHjkoKENXofeGZ?m]EjP3ofAAY`;o
KEf_0on6Nkl00omdD9[o/kSLok>hg002ok>hg0;oRHG91?n8O/42oif8_004og]KXOmdEZ7oM5JQogAF
X@CoLEZX0_maK;d2ohfBe0?oLVbl1?nIO[D2oiAd[0CoVGBX0_nMMjP2ojZ6[`Co/H^]0ondSZh2ol>N
/PCo_9F_1Oo7XkD5ol:S^@Go`ZNn1OnfY<H2oijNe003ok6Wc_nHY=koV:CN00?oV:CN1?mcY?03ofRd
n`CoM<Co0_nEd_d2ohc9o0CoWLoi0_nYcO<2oj;;m@CoZLWa0_n/a^d3ojS7l0;oZlG]0_nWaNl5ojW4
k@;oZ/;/0_nX`nd4ojW2k0;oZL7[0_nX`^`3ojS1k003o`000?nX`N_oZ<7/00coZ<7/1?nX`N/4ojS0
j`Sooooo00?o0000ooooooooool03oooool002;ooooo00?o0000ooooooooool0;oooool4oiBjl@;o
TL7g0onMa_@2oic@nPCo[Lob0_n`eo@2okO8i`?o^LOU00?o/kKKok2`eon`/=L00_n`/=L4ojfWdP;o
Yig<00CoVI79oi:8a_nBR<KoTXS61?n;P/@3oh=ma0?oO7c80on1KkH3oga[]@;oMfZg0omdKkh5og9k
cP03og>OkOnTTL7oY97100?oT7Rc0omnIJ`3og=KZ0;oIUF[0om]EjP3ofAAY`?oKEf_0on6Nkl3ok>h
g0?oJ5FY0_mPEk42of=E[0;oL6:c00?oNe^QogAFXOmdEZ400_mdEZ42og5JZ0?o/MWe0on=T]@2og9/
_0?oNVZe00CoVGjeoiAd[?nDM:coU7B/0onIM:P01?nMMjSoZXJ_ojZ6[onZQZl5ok6;[@04okB>[_o3
W[;o`ijbol>N/PCo_9F_00?ock2jolNS]Oo7XkD00_o7XkD00ooC]kgo`Z>iol:S^@02ol:S^@03olbc
`Oo2Ykko`ZNn00;o`ZNn00?ob[72okJTa_nfY<H00_nfY<H4ok6WcP?oV:CN00?oZ:SFoi>Xi?nCZ>@0
0_nCZ>@5ohFblP?oO[ck1?n<bO`2oig?n@;oUlSh1?nRboD2ojW9l@?oY<Sc0_nXao02ojG6l@CoYlG_
0_nYa>d2ojO4kPGoZ<?]0_nY`^`00onX`^goZ<;/ojS2k003ojS2k0;oZ<7/00?oZ<;/o`000?nX`^`0
3?nX`N`5ojS1j`?oZ<3[2Oooool00ol0003oooooooooo`0>ooooo`008oooool00ol0003ooooooooo
o`0_ooooo`;oU;[a0_nN_Nh3oig6m0?oZlO^0on]co82okC6j0Co]lSW00Co^LOUok>ffonc]]_o/kKK
1?n`/=L2ojfWdP03oj2Ic_nITLWoVI7900;oVI790onBR<H3oh^2a0?oPgg40omlO<P3og:1d`?oO6^e
0omgJ[L3ogA__P;oLW_>00?o^[7@oi67aOmmL[d00_mmL[d3oi1h/`?oOVF/0omcFjP2ofIEZ`;oDeRj
00CoKENXofAAYomTDJOoI56W0om]GJl4ohIk_`03ok>hg?mkJKCoJ5FY00;oJ5FY0_mPEk42of=E[0?o
L6:c1?mdEZ401_maFZSo/MWeok7ImOnafOGoMgo>ol3XlP;oSI;D0_mbK;`4ogYZ]@?oRW:b0_nIM:P0
0onLO[7oZXJ_ojZ6[`03ojZ6[`Co/H^]00?o]8j^ol>N/_o3W[800_o3W[82okbE[`;ock2j0oo7XkD2
om>g_@?o`Z>i0_o</l43ol:W_P;ob[720onfY<H2okj]b0Co/JO>00CoV:CNojRXe_nXZ=KoZ:SF1?nC
Z>@2ohFblP;oV;;Y1?n>^?<4oi32n0;oUlSh0_nH`oD4oik7m@;oY<Sc0_nQaO85ojG6l@;oYlG_0_nU
a>l4ojO4kP;oZ<?]0_nW`nd4ojS2k@;oZ<;/0onW`^d2ojS2k003o`000?nW`NcoZ<7/00coZ<7/0_nX
`N/2ojO0j`CoZ<3[2?ooool00ol0003oooooooooo`0>ooooo`009?ooool00ol0003oooooooooo`0_
ooooo`CoW[g^00?oWLKdoj_7k_n[anh00on[anh00on]co;o]<KXokC6j002okC6j0;o]lSW0_nc^ml4
ok>ff`;o/;3G00?oYJ;Boj2Ic_nPVLh00_nPVLh3oiVAb@?oTXS61?n;P/@3oh=ma0?oO7c80ombPM<4
of>Ej`05ob2Thoo@l>WocMGPolgEh?nSW]001?nAQlD2ogeb_@;oLFRh0_n@N;<2ogiU[0?oLe^X0omV
EJ/2oe=H^P?oI56W0om]GJl4ohIk_`;oNfVd0omXEJT00omFC:[oH5Naof=E[002of=E[0;oL6:c1_n6
Q/`01?nafOGoMgo>ogMoc_mgOlh2of9Q^`?oLVbl0omjJ[D3ohYb/P?oW7ja1OnZQZl3ok6;[@03olFW
^oo3W[;o`ijb00?o`ijb00?o_9F_oln`^_o?/;X00_o?/;X00oo7XkGodkNmom>g_@02om>g_@03ol:S
^Oo</l7oc;?100;oc;?100?o`ZNnolZa`_o:/L800_o:/L801?nfY<Ko_Zg8okj]b?nn[LP3ok6WcP03
okZ^cOnXZ=KoZ:SF00?oZ:SF0_nCZ>@2ojB]gPCoV;;Y1?n>^?<2oi32n0;oV;gb1?nH`oD2oik7m@;o
W/?b1?nQaO82ojG6l@;oXlC`1OnUa>l2ojO4kP;oY/?^1?nW`nd2ojS2k@GoYl;]0_nW`^`2ojO1k004
o`000?nW`NcoZ<7/ojS1k0;oYl7/1onX`N`00onW`NcoYl3[ojO0j`03ojO0j`;oZ<3[0_nW`>/7oooo
o`03o`000?oooooooooo00kooooo000Uooooo`;o0000<?ooool2oijmkP?oZL3Z0_n[anh3ok;4i`?o
]<KX0_nd_^84ok>kg`;o/kKK00?oZZ[FojFRd_nUX]800_nUX]83oj2IcP?oVI790onBR<H4oh^2a0?o
Pgg40omlO<P4og:1d`;oHiG[0_o@l>T00ond]][oXik@oj>Nd002oj>Nd0?oTHO50ommL[d3og5X^0?o
OVF/0_mcFjP3ofIEZ`?oDeRj00?o05O1ofAAYomTDJL00om]GJl2ohIk_`03ofeY_?mkJKCoNfVd00?o
J5FY0_mFC:X00omPEk7oHeF/of=E[003og1R/`CoQXK<0_o4d><3ogMocP?oHV6k0_mbK;`3ogYZ]@?o
RW:b1?nLO[44ojZ6[`;o/H^]0_o5Yk/5ol>N/PGock2j1?oC]kd00ooFdmKoc;?1olbc`@02olbc`@03
olo5dOo:/L;ob[7200;ob[7200?obkc<okj]b?nn[LP00onn[LP01?naYlko^Zk=okZ^cOnj[/d2ojRX
eP;o/ZoE1OnT[Mh2oiRbj@;oY;;S1?nJ]^/4oiRmlP;oV<?e00?oW;k`oik3l_nN`o800onN`o82oj75
lP;oXL;`1?nSa?02ojG4k`;oYL;^1OnV`nh2ojO3k@;oY/;]0_nW`^d2ojO1k@GoYl;/0_nW`N`00ol0
003oYl7/ojO1k003ojO1k0;oZ<7/1_nW`N`9ojO0j`Kooooo00?o0000ooooooooool03_ooool002Oo
oooo00?o0000ooooooooool0;_ooool3ojW0jP?o/<;W1?nba>L00onda^So];kRokBnhP02okBnhP;o
/k_O00?o[K7KojZZe_nZZ]H00_nZZ]H4ojFRdP?oX9W>0onITLT3oi:8aP?oRh;40on3OL@4ogalb0;o
LX7C00CoHm?bolKjjOo0c>?o`<cS0ond]]X3oj>Nd0?oTHO50ommL[d3og5X^0?oIfBj0_mcFjP3ofIE
Z`CoDeRj00?o05O1olC>h_m]GJl00_m]GJl01On6NkooKFVlofeY_?m=C[;oNfVd00?oJ5FY0omFC:X2
of=E[0?oL6:c0on6Q/`01?oRoKooa=3SolC@hoo4d><2ogMocP?oHV6k00?oG5^gog9/_?mjJ[D00_mj
J[D4ohYb/P?oW7ja1?nZQZl00onaRjgoaJNkolFW^`02olFW^`?o`ijb00?of]3?oln`^_o?/;X00_o?
/;X2omoQe`;odkNm0ooFdmH2olbc`@?oclGA0_o:/L83ol^lc0?o_Zg800?o`[K>okZ^cOnj[/d00_nj
[/d5ok:_e@;oY:gN0_n^/M/5ojBbh`;oV[K[0_nT]^H4oinjk0?oW;k`0_nN`o82oj6ok`GoXL;`0_nS
a?02ojC1kPCoYL;^0_nV`nh5ojK2k@;oY/7]1?nW`Nd2ojO2k0GoYl7/00?o0000ojO1k?nW`N`02OnW
`N`2ojO0k0SoYl3[1_ooool00ol0003oooooooooo`0>ooooo`00:?ooool00ol0003oooooooooo`0^
ooooo`03ojW0j_n``^Oo/<;W00?o/<;W0_nba>L2ok?1i0?o];kR00?o[kOOojfafon]/M/00_n]/M/4
ojZZeP;oYJ;B00CoW:?JoiJMfOnFWMWoUYgI0on?VMP3ohRFf`CoPiWQ1OmmY>`2ogRlo0;oa_[Y1?o0
c><3okBffP?oXik@0onAQlD2ogeb_@?oLFRh0omWI;X2ofYcb@04og=KZ?mVEJ_oIUF[ofIEZ`;oDeRj
00?oQ>S7olC>h_o4c^800_o4c^82oi:Ed`?oKFVl00?oCDjbog]Y]?mXEJT00_mXEJT2oeI<ZP;oDVW<
00OoHeF/og1R/om`H[?oL6:cohJ6c?oRoKoo`MOZ00?oP8oH00?oAU[3ogMoc_mgOlh00omRHK/00omL
FkOoLVblogYZ]@02ogYZ]@?oRW:b0onLO[44ojZ6[`GoaJNk0_o3W[83om[@c`;ock2j0ooOhML00ooC
]kgoe]?FomKCeP02omKCeP03olbc`Oo?aM7oclGA00;oclGA00?ob[72ol^lc?o;_<`00_o;_<`00onn
[LSo`[K>ol:fcP02ol:fcP;o^Zk=0_nn]M43ok:_e@03okNde_n^/M_o[[7K00?o[[7K0_nT/^<2oj^e
h0GoY;KV0_nO^^`2ojBij0CoXKc/0onQ_nl2oj72l0?oXko]1?nT`Nh2ojG2kP?oYL7]0_nV`^d00onV
`>coY/7]ojK1k@03ojK1k@;oYl7]2?nW`N`00ol0003oYl7/ojO1k005ojO1k0OoYl3/2?nW`>/5oooo
o`03o`000?oooooooooo00kooooo000Yooooo`03o`000?oooooooooo02oooooo0_n``^L3ok?2iPCo
/l7T00Co];kRojnggon_]moo[kOO1?n]/M/2ojZZeP03oj6Yg?nLXm[oW:?J00;oW:?J0onFWMT3ohnI
f0?oR9KK1?n3VN42ogfTk0;o?l?50_ncnN/2ol;Jj`?o`<cS00CoYZ7AoiV@bOnIT<WoVI390on9P<<3
ogae`0?oOG:m0omaJ;P2ofMT^P?oJW?90omVEJ/00omCF;[oOZ[`okNgf@04oi6;b@;oIVFm0om]JK`2
ode>/P?oJ5FY0omFC:X2oe9Yc0;oL6:c0_oRoKl3ol7GjP?oP8oH00?oAU[3ogMoc_mRHK/00_mRHK/2
oeaK]`?oNVZe0on:L[84oian/@;oZXJ_0_nm[//4olFW^`03ol>N/_oJd<oof]3?00;of]3?00Cock2j
omoQeooOhMOogn7G0_mmimP3omKCeP;o/>gh0oo?aM400oo1dNKobkc<ol^lc003ol^lc0Go`[K>00?o
^Zk=okjedOnn]M400_nn]M401?nb[mGo]kCFokNde_ng]=H3ojjaf`03ok>ffon[]N3oZkGP00?oZkGP
0_nT]^H2ojVgh`GoY;WX0_nQ_>`00onU^nWoXkg/oj>mk003oj>mk0;oXko]0_nU_^/4ojFok@;oYL7]
0_nV_n`4ojK0k0;oY/7]0_nV`>`;ojO1k004o`000?nW`NcoYl7/ojO1k0SoYl3/2onW`>/4ooooo`03
o`000?oooooooooo00kooooo000Zooooo`;o0000<Oooool4ok?2iP;o/l7T0_na_N<4ojngg`;o[K7K
00?oYJoOoj6Yg?nQZM`00_nQZM`3oibSfPCoUYgI0on?VMP3ohRFf`;oPiWQ0_mYdOX2oh_]i`;o/oW[
1?o2f^/01?o0c>?oYZ7AojJQdOnVXM43oiV@b@?oRH330_mlML03of]^``?oLFRh0omWI;X3ofYcb@?o
OZ[`0ong]mT3oi6;b@?oIVFm0_m]JK`2ode>/P;oGV:n00CoJ5FYoeI<Z_mFC:[oETbZ0omBJL`00oo7
k8koc_FRonGgdP04ol7GjP;oP8oH0_m6F/<3of9Q^`;oG5^g0_mWJL400omjJ[GoRW:bohYb/P02ohYb
/P?oW7ja00CoZXJ_okf^bonm[/_o_Jk;0oo5Yk/3olSmhP;of]3?0_nTVLX00on8Rloogn7GohR;c`03
of=je003omKCe_n`kOSo/>gh00;o/>gh00CoclGAol7Ai_o1dNKo`M7V0oo;_<`2olK6f@?o`[K>0_o1
_MH3okjed@03oknke_ng]=Ko]kCF00?o]kCF00Co[[7Kok>ffonc]]_o/kKK0on[]N000on_]mooZKOS
ojVgh`03ojVgh`;oY;WX0_nY^^D4ojFkj@;oXkg/0_nV_>T5ojFnj`;oYKo]0_nV_^/4ojJok0;oY/3/
0_nV_n/4ojK0k0;oYl7/0_nW`>`6ojO1k003ojO0k?l0003oYl3/00KoYl3/3onW`>/3ooooo`03o`00
0?oooooooooo00kooooo000/ooooo`03o`000?oooooooooo02oooooo0_nc`^H2ok72i`Co/KgS0_n_
]ml2ojRfhP?oYJoO1?nQZM`3oibSfP;oUYgI0_n>/>d4ohRgm0;oO<?m0on?i_X2ojSdlP?o`>7_0_o2
f^/00on`/MWoYZ7AojJQd@02ojJQd@?oVI390on9P<<3ogae`0;oJfk30omRN]D3ofMT^PCoJW?900?o
OZ[`oloLhong]mT00_ng]mT3oi6;b@?oIVFm0_mIF[T00om]JKcoCDjbode>/P02oeiR_PCoETbZ00Go
DVW<olO/S_o>mJ;oiOOBol_AgP04ohNFf`;oH6k:0_m6F/<2odEI``;oHV6k0_mLFkL2ofMY`@CoRW:b
0_nLO[400onUYMGo_Jk;okf^b`03okf^b`04olFW^oo8oN;ob?gRolSmhP;o^JO61?nTVLX3ohR;c`?o
Hg[D0_leJML3odJnlPCo`M7V00?obkc<olK6fOo6a]T00_o6a]T00oo2]/ko`KgFol6meP02ol6meP04
okjedOno^mKo_k_FoknkeP?o]kCF0_ni^]T4ok>ff`04oj^eh?n_]moo[kOOojngg`?oZKOS0_n]^N84
ojVji@;oYK_Y0_nX^nL4ojJlj@;oYKk[0_nW_NT5ojJnj`;oY[o/00?oYko[ojJojonV_n/00onV_n/2
ojK0k0;oYl3[1?nW`>`2ojO1k0;oYl3[0onW`>`00ol0003oYl3/ojO0k00DojO0j`?ooooo00?o0000
ooooooooool03Oooool002gooooo00?o0000ooooooooool0;oooool4ok72i`;o/KgS0_nZ^nH4ojRf
hP?oYJoO0_nQZM`2oiVai`?oUJoY1?n>/>d2ohRgm0?oTMWo00?oSnKjojSdl_nXm?801?o0hNl2okNo
h0?o/;7I0onVXM43oiV@b@?oRH330omlML03of]^``?oHW[E0_mBZOT2ofYcb@;od_oG0oo?g><3okNg
f@?oTH_90_mVIKd3oeUJ^@;oCDjb0_mNH[h5oiFTh003olGl_OoUmm;obm7N00;obm7N0on7U]/3of1^
bP;oAU[30om5FL<2oeaK]`;oIfW11?n5Qlh4ojFUe@?o_Jk;00?o0000omK2aooF`/L01OniYlH2ojBI
bP04ojBFaonAS<_oTHc;oi6<b`?oNX?A0oleJML00olIJ=_o08KIodJnlP02ol7AiP;oXm;h0oo6a]T2
okW8iP?o`KgF00?o_<?Ooknke_no^mH00ono^mH00ong]=Ko^K[IokVjf@02okVjf@;o/kKK00?o][[L
ojnggon_]ml00on_]ml00onY]n?o[KWRojfihP02ojfihP;oZK[U00?oZk[TojRkionX^nL00onX^nL2
ojJlj@;oZ;cX1?nW_NT2ojJnj`;oYkkY1?nW_n/2ojJoj`;oYko[1OnW`>/2ojO0k0KoYl3[0_nW`>`0
0ol0003oYl3[ojO0j`0DojO0j`?ooooo00?o0000ooooooooool03Oooool002kooooo00?o0000oooo
ooooool0;oooool2ok72i`;oZl7Y1?nZ^nH2ojRfhP03oj6gj?nN]>OoW[CW00;oW[CW1?nI/NL3oiF_
j@;oS[3]0onBc?`2oi7Io`;oWnci1?nih_@00oo0hNoo]koPokNoh002okNoh0?o/;7I0onVXM43oiV@
b@?oRH330_mlML03of]^``CoHW[E00CoDZWioh3MX?oBomOod_oG0oo?g><01?n[/MgoRi3Coh^@don;
T=<2ofmeb@03oi6;bOmVIKgoIVFm00?oFEZi0_m?I<P3oeiR_P?oUJCP00?oaObmon[j`ooXl=001?o;
dMh3ohNFf`;oH6k:0_m1F/D3odEI``;oD77D0omWJL44ohF7cPCoYJGE00Co_Jk;omK2aooF`/Ooe/;7
0_o:]<D3okVWaP04ok>Qa_nTU/OoY9K7ojBFa`CoTHc;0_mjPm43oeikf004ocEYeolIJ=_o1W[Po`Ij
h0CoXm;h00?oa/KIokW8i_nib>H00_nib>H01?o1_MKo_<?Ookc3gonl`ml3oknkeP03okg0g?ni^]Wo
^K[I00;o^K[I00?o^KkNokJjg?nf^]`00_nf^]`2ojngg`;o/[_P1?n]^N800on_^n;oZk[Toj^ji002
oj^ji0;oZ;_W0_n[^nH5ojRlj0;oYkgY0_nX_NP4ojNnj@;oYko[0_nX_^X4ojNoj`;oYl3[0_nW_n/;
ojO0j`03o`000?nW`>_oYl3[01CoYl3[0_ooool00ol0003oooooooooo`0=ooooo`00;oooool00ol0
003oooooooooo`0_ooooo`CoZl7Y0_nZ^nH2oj>kjP?oXKOX1?nN]>L2oiVai`;oUkkc1?nEa?L2oi;<
o0;oW>7m0onbg_H2okWRm0?o^<SW0_ng_n02ojN/f`?oWZ7F0onBUM83ohR;d0?oNXGB0omhS=X3of]^
``;oHW[E00?oTn3noh_]i?o7o]h00ooFln@01?o?g>?oZk7Moj^agOn[/Md3oh^@d`;oKgG90omVIKd3
oeUJ^@;oCfC80omNH[h01?nEY>3oaObmon[j`ooZn/<2onS`d0;obm7N00CoXjcMof9idomRNM?oHWWC
0omPK/X2od5Ja@;oAEW30om@LM@3ofMY`@?oQHO>0_nUYMD2on_Ma@;oh<g500Goe/;7olZdaOo:]<Go
b[C5okVWaP03ok>QaPCoY9K70onAS</3ogZ3d@?oGW_H0_m9O>42obAoj004o`Ijh?n3`_coPl;loh?2
o0;o^LSV0_nZanl4okc3g`03oknke_nm`=co_L3L00;o_L3L00?o^K[IokVng_ni_]h00_ni_]h2okJj
g0;o][kO1?nb^n000on]^N;o[k_RojnkhP02ojnkhP;oZk[T0_n]_>@4oj^kiP;oZ;cX0_nZ_>L5ojRm
j0;oYkkY00?oZ;kYojRnj_nX_^X00onX_^X2ojNoj`;oZ;oZ1?nW_n/2ojO0j`;oZ<3[1onW`>/00ol0
003oYl3[ojO0j`09ojO0j`;oYko[2?nW`>/2ooooo`03o`000?oooooooooo00gooooo000`ooooo`;o
0000<?ooool2oj_1j@;oYKo/1?nS^nX3oj6gj0;oW[CW0_nJ_O04oiNnl`;oULCg0onKeod01?nLhOgo
/]kfok;Nm_nbg_H2okO=j`?o^<SW00?o[KKOojN/fonW[=/00_nW[=/4oijQeP?oTYGB0on8Rm03ogZ5
dP?oN8cJ0omnY^h2oh_]i004olOng_oFlnCoe_?TomKci0;o`LkT0on[/Md3oh^@d`;oKgG90_m>HLH0
1?mVIKgoFEZioeUJ^OmIF[T4odmTb004og[@oonbe?;oeoo5on[j``;oj?3@0_o@e]h3oj>/g@;oHWWC
0_mFK/l00omPK/[o@E[5od5Ja@02od]hg003odEI`om@LMCoD77D00;oD77D0_m:WoD00ooLo/Gok_36
on_Ma@02on_Ma@?oh<g51?o:]<D5ok>QaP?oY9K71?nAS</3ogZ3d@?oGW_H0_m9O>42obAoj0CoLKCj
1?nZanl2okc3g`;o]/GV0onm`=`2ok[4hPCo^KkN00?o][[LokJngonf_]l00_nf_]l2ok:kh0;o/[gR
1?n_^n800on[^^Co[KcTojfli002ojfli0;oZk_V0_n/_>H4ojZli`;oZ;gX0_nY_^P4ojRnj@;oZ;kZ
0_nX_nT5ojRojP;oYko[00?oZ;o[ojS0jonX`>/00onX`>/6ojO0j`03o`000?nW`>_oYl3[00KoYl3[
1_nW_n/8ojO0j`03ooooool0003ooooo00kooooo000booooo`03o`000?oooooooooo02kooooo1?nU
_n`2oj>kjP;oW[g^1?nL_>l3oiZml0;oUkkc0onJc_X2oi_Go@?o[=Sg00?o/]kfokO=jongcN/00_ng
cN/01?nhb>Oo[KKOojffgon]]]l4ojN/f`?oWZ7F1?nBUM83ohR;d0?oNXGB0omhS=X01?mnY^koRngT
oh_]i?nbm?82olOijP03olSPjOo1c^Co`LkT00;o`LkT0on[/Md2oh^@d`?oKgG90_m>HLH3oeUJ^@?o
CfC80_nbe?801?oGolGoj_[3onS`d?oXl=04om3FgP?oXjcM0_mRNM<3oeI^c`;o@E[50_m;N=`2oe1a
e0;oIlGn00Co]_cOomcnaOo^l<Kok_360_o[gLD3on3=a@;oe/350_o:]<D2ol6]a@Co/j760onTU/L4
oiN@bP?oR8[?0omgQmL3odUlh@;oAh[[1?ma]?X2oj[7k`;oWL?b1?nfaNH00onm`=co^/CRok[4hP02
ok[4hP;o^KkN0_ng`^83okJng`03okG1honb_N;o/[gR00?o/[gR0_n_^n82ok2mi0?o[KcT00?o[[gU
ojbli_n/_>H00on/_>H2ojZli`;oZkkW1?nY_^P2ojRnj@;oZKkY1?nX_nT4ojRojPCoZ;o[1OnX`>/2
ojO0j`;oZ<3[0_nW`>/01?l0003oYl3[ojO0jonW`>/:ojNoj`SoYl3[00?oooooo`000?ooool03_oo
ool003?ooooo00?o0000ooooooooool0;_ooool2ojFok0;oX;k^1?nN_Nh2oiblk`;oW<?c1?nLb?H2
oi[>nP?oYm7f0_n/f?L3ok;?kP;o]lg[0_n`_N<4ojffg`?oYjcK0_nNXMH00onDVmSoRIOKohVGf`02
ohVGf`CoPi[Q1?mlZO02oh?@o`;o/_Cb0_o7nNX3olSPj@;o`LkT00CoYZcKohnDe?n?U=CoSiCD0omb
OLl2ofmeb@;oCV760omYPmT01_mIF[WoCfC8ok;Dl_nbe?;oeoo5om;jh`;ogo[G00Gog>WLom3Fg_o@
e]kod=KNok6ig`03ohRCf0;oFW?B0omFK/l3oen0f`?oBgSL00?oIlGnoho3nOo:k^d00_oQjML2onGO
cP?oh<g50ooF`<D00oo:]<Go`Jg5ol6]a@02ol6]a@;o/j7600?o[ik7ojBFaonTU/L00_nTU/L4oiN@
bP?oR8[?0omgQmL2ofR:h004odUlhOm7R^_oAh[[odN:j`;oLJgf1OnM`o82okK5iP;o[lK[0onja>80
0onea^Oo]l;RokO2hP03okO2hP04okJngone`N?o]L7SokG1h`;o/[gR0_nb_n@5ok2mi004ojfli?n^
_NGo[[gUojjmi@;o[;cV0_n/_^L5oj^ni`;oZKkX00?oZ[kXojVnjOnY_^T00onY_^T2ojRoj@;oZKoZ
1?nX_nX2ojRoj`_oZ<3[0_nW`>/00ol0003oYl3[ojNoj`0;ojNoj`SoYl3[00?o0000ooooooooool0
3Oooool003Cooooo00?o0000ooooooooool0;_ooool4oj2nkP;oW[g^0_nM`?44oic3l`;oW<Sf0onT
c?@2ojOAmP?o[lg_0_nbcnh2ok31iPCo/;gS0_n]]]l01?nSZM_oW:;IoibRfOnLX]T4oiBKf0CoRIOK
1?n3V^42ogbYl0?oXMcl00?o/_CbolOij_o7nNX00_o8h>T2okO1hPCoYZcK0on?U=@2og9mc`?oIWS@
0_m>HLH4ofV3f@05ok;Dl_nNg_god_[Som;jhooOn]L00ooLjM`01?o@e]ko/KWOok6igona^Ml3ohRC
f0;oFW?B0omFK/l3oen0f`?oSl?i00Cob^k]on7YeooQjMOohNWG0_oUglh00ooQdl[oh<g5omK0a@03
omK0a@Go`Jg51?n_W/L3ojBFa`CoUi3:1?n8R/l3ogN7e`;oJ8[P1?mSU>/2ogR/l`;oWL?b0_nF_o<5
ojo6j`04ok[4h_nea^Oo]LKWokG6i`;o]l;R0_nda>H3okG1h`;o/l?V1?nb_n@2ok2mi0;o/;oU0on^
_ND2ojjoi`Co[;kW0_n[_^L2oj^oj0CoZ[kX0_nY_^T2ojZoj@GoZKoZ0_nX_nX2ojW0jPcoZ<3[0onW
`>/00ol0003oYl3[ojNoj`0:ojNoj`OoYl3[00?oooooo`000?ooool03_ooool003Gooooo0_l0000_
ooooo`;oX;k^0onO_^h3oig0l@;oW<?c0onSa_82ojC<m0?oZl[`0_n_cNl2ok33j0Co/<7V0_n`_N<0
0onX/MkoXjWKoj>Yf`02oj>Yf`?oW:;I1?nDVmP3ohVGf`;oPi[Q0onD`OH2oj7Lo0?o^O?c00?oanO]
ol7Bioo1d^L01?ng`N84ojJ/f`;oSiCD0ombOLl2ofIhd0?oGhOQ0_mYPmT2oikNo@;od_[S00Gogo[G
omcYg?oLjMcog>WLolcDg`05ok6ig`;oR9?H0_mJLm83ofJ3f`CoGh3K00?oSl?iol[^kOoQjML00_oQ
jML2onGOcP;ohM?:00Cof/[9omK0aOoF`<Goe/350_o=^LL3ol6]a@;o^jW70on_W/L4ojBFa`;oUi3:
00?oW9K=oi6CdOnATm400_nATm43ohJBf0?oO9KQ1?mSU>/3ogR/l`?oU[oc0_n_a^/3ojW5kP;o]LKW
0_n`an/4okC4iP03okG1honc`nKo/l?V00;o/l?V0_nb_n@2ok72iPCo/;oU00?o[[gUojjoion^_nL0
0_n^_nL2ojbni`;o[L3X1?n[_nP2ojZnj0;oZl3Y1?nZ_nT2ojVojPGoZL3Z0_nY`>/<ojS0j`;oYl3[
00?o0000ojO0jonW_n/02onW_n/2ojO0j`Kooooo00?o0000ooooooooool03?ooool003Oooooo00?o
0000ooooooooool0;_ooool2oinnkP;oXko]1?nR`^l2oj?6lP;oZLK_0on[b_02ojk4jPCo/<?X0_n`
`NH2oj^fh@?oZ;7N1?nSZM/3oibRf@;oU9_H0_nBZNH3ohj_k@?oU<7f0onWi?/00onilo?oanO]olOW
k@04ol7Bi`;o]l7R00?oXjkOoi2Lfon@W=/00_n@W=/3ogn?f@?oLWg?0_mVN=04oen7h@03oikNoOoB
n^?od_[S00;of^gP00?og>WLolcDgoo<e=l00_o<e=l2ok6ig`;oUZCO0omjSMX2oeYcdP?oIX?K0onD
/nd3ol7@iP03on7YeooUglkoiMo>00?ohM?:0_oJb/T00ooF`<GocKW7olfia`02olfia`04ol6]aOnk
ZLOo^jW7ok^Ya`Co[ik70_nTU/L00onTV/_oW9K=oibFc@02oibFc@CoTI?A0on6T]P3ogbFh@?oMikZ
0on2[_45oiFml`;oZLG^0_nUaO04ok37j`;o]<CV0onaaNT2ok?3iP03ok74j?na`^Ko/L;V00?o/L;V
0_n`_nD3ojo1i`;o[[oW00?o[L7Xojg0j?n]`>P00on]`>P2oj^oj003oj_1jOn[`>WoZl3Y00?oZl3Y
0_nZ_nT3oj[0jP;oZL3Z00?oZL7[ojW0jonY`>/00onY`>/;ojS0j`?oYl3[00?o0000ojO0jonW_n/0
2OnW_n/9ooooo`03o`000?oooooooooo00cooooo000hooooo`03o`000?oooooooooo02kooooo1?nS
_nd2oj;2k`;oYl?]1?nYa^l00on[b_3o[/CZojk4jP02ojk4jP;o/<?X0_n]^n@4oj^fh@?oZ;7N0_nS
ZM/2oib[h@?oUZSS1?nBZNH3ohj_k@04oiC1m_nWi?_oYnCkojOTn`;o^nGd0_nnf^h3ol7Bi`03ok2m
honS[]ooXjkO00;oXjkO1?n@W=/2ogn?f@?oK8OK0omkW^P2oen7h@;oYLof00CocO7[om[]h?oJkN3o
f^gP0_oGi=l2olcDg`;o]l3Q1?nFY=l2ogZ=fP?oIH;J0omVPm/01?nD/ngo`M3Vol7@i_o1d>H3om?H
f`?ohM?:0ooJb/T01OoB`lcocKW7olfiaoo=^LOoa;C:00Go^jW70_n_W/L00on]X<_oY9[;ojBJb`02
ojBJb`?oW9K=1?nATm44ohJBf0?oO9KQ0omgW^X3oh:^l@;oUKgc0_nF_?85ojG5l0;o/<O[00?o[<K]
ok75jOnaaNT00_naaNT00on^a^_o/LCXok74j002ok74j0;o/L;V0_n_`nP4ojo1i`03ojk2jOn]`NSo
[L7X00;o[L7X0_n]`>P2ojc1j@CoZl7Y0_n[`>T3oj_1jP;oZ/3Z0_nZ`N/4ojW1j`;oZL3[0_nX`N/<
ojS0j`?oYl3[00?o0000ojNojonW_n/01OnW_n/<ooooo`03o`000?oooooooooo00cooooo000ioooo
o`03o`000?oooooooooo02kooooo0_nS_nd2ojO0j`CoYl?]0_nYa^l3ojc3j`;o[/CZ0_n]_NH4ojfk
i0;oZkKQ00?oYK?Soj6_h_nQ[n800_nQ[n84oib[h@?oUZSS0_nBZNH2oiS1m0?oW=3j0on`g?H00onk
iOCo_][^okkJkP02okkJkP04ol7Bion`_N?o/;gSok2mh`CoXjkO0on@W=/3ogn?f@?oK8OK1?mkW^P0
0onUcoKocO7[om[]h002om[]h0?oenCO00?obmCQokO0hOng`>400_ng`>43oiJTg`?oNXgJ0omUP]X4
ohVTiP04ol7@i_oCf=_odmSKom?Hf`;of=CD00CohM?:om[:bOoJb/Wof/[90ooB`l`01?o=^LOoa;C:
olBdb_o4]<X3ok^Ya`03okJYc?n]X<_o[J3;00;o[J3;1?nTV//3oibFc@;oTI?A00?oVI_Doi:Lf_nB
W=X00_nBW=X3oh^Oh@CoQjKY0on</Nl4oiJllP;oYLG`0_nTa?04ojc6k@03ok75jOn^a^_o[/K[00;o
[/K[0_naa>P2ojk5j`Co[l?X00?o[l7Wojk2jOn^`^T00_n^`^T2ojg1j0;o[<;Z1?n/`NT2oj_1j@;o
Zl;Z0on[`NX2oj[2j`CoZ/7[1?nY`N/4ojS1j`;oZ<3[0_nX`N/6ojS0j`GoYl3[00?o0000ojNojonW
_n/04?ooool00ol0003oooooooooo`0<ooooo`00>_ooool2o`0002oooooo1?nW`>/2ojO3k@?oZl;Z
0_n/`n/2ojfoi`Co[KgV0_n]^n@2ojRhi0?oYK?S1?nQ[n82oib[h@;oV[CY0onG]nh4oiS1m004oic@
n_n`g?Ko/=cfok3LmP?o^Mcb0_nnf^h3okK8j0?o/;gS0_nS[]l01?nGXmgoQYSMohJHgOn6V=d3ognH
h@CoK8OK0_mkW^P01OnOc_So_^?aokkSlOnnho7of^gP00?oenCO0oo;e>42okO0h@04ojF`h?n6VMko
QYWNohJIgP?oNI3M1?mUP]X2ohVTiP04ojRmjOoCf=_odmSKom?Hf`?of=CD0_oGd=800ooJb/Wod/?<
om;3c002om;3c0Goa;C:00Co^jW7okJYc?nfZLco]ZW<1?n]X</2ojBJb`04ojFOconPW=3oX9c@oj2L
d0CoVI_D1?nBW=X3oh^Oh@CoQjKY0on</Nl2oiJllP;oVKga1?nTa?02ojc6k@?oZLK^0_n^a^/2ojc6
k@Co[/G[0_n_`nP3ojg4j`;o[/;Y00?o[<C[ojc2j_n/`^X00on/`^X2ojc1j@;oZl?[1?n[`^X00on[
`N[oZ/;[oj[2j`02oj[2j`;oZ/7[00?oZL;/ojW1jonY`N/00onY`N/8ojS1j`?oZ<3[1onW`>/00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo000looooo`03o`000?oooooooooo02go
oooo0_nW`>/2oj[1jP?oZl;Z0_n/`>P4ojfoi`;o[KgV0_nY^nH4ojRhi0?oYK?S0_nQ[n82oifci`Co
V[CY0onG]nh2oiS1m0;oY]7g0on`f?D2okWLlP;o^<o[0onfb>P00on[^N?oXZkPoj:^h002oj:^h0?o
Uj?M0on6V=d3ognHh@CoO:C/00CoWlkhokkSlOnnho7o_^?a0oo9in/01?oGi=oobmCQol_DhOo;e>42
ok_5hP?oYK3P0on6VMh2ogV@g@CoNiOS1?nX_NT01?oCf=_of=CDomSDe?oHe=@3omO@dP04om;;dooB
`lcod/?<om;3c0;obkk>0oo4]<X00onn//oo]ZW<okJYc002okJYc0;o[J3;0_n[Xll4ojFOc`?oX9c@
1?nIVm@3oi:LfP;oRioQ0_nFZ><3oi:^j@GoTkK^0onI_O42ojC4l0?oXlC`0_nYa^h00onWa^oo[<K]
ojc6k@03ojc6k@;o[/G[0_n/aN`2ojg4j`;o[<G/1?n/a>/2ojc2jP;oZlC/1On[`n/2oj_2jP;oZl?/
0_nZ`^/2ojW3k0CoZL;/0_nY`N/2ojS2k0SoZ<7[1?nX`>/2ojO0j`Gooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0<ooooo`00?Oooool00ol0003oooooooooo`0]ooooo`CoZ/7Z00?o
Zl;Zojc0j?n/`>P00_n/`>P2ojfoi`;oZkgW1?nY^nH2ojRhi003ojBgi_nR]NKoX[GV00;oX[GV1?nM
/nL2oiZdj@;oWl7`1?nPao@01?nVdOOo/=Seok3HmOn`f?D2okCAk`Co^<o[00Co]/SXoj^ihon[^N?o
ZkWS1?nR[^03oiNSg@?oQYSM0omoV>42ogbTk0?oWLKd00Co_^?aolWWjoo9in_obNO[0oo8gNP00oo;
e>7o^lGRok_5hP02ok_5hP?oYK3P0on6VMh2ogV@g@CoNiOS0_nX_NT3ok_8i004omSDe?oGd=;oem3B
omO@dP?od/_C00God/?<ol^nc_o;_/kobkk>olBdbP04okjbc`;o]ZW<00?o/J[Aoj^Scon[Xll00on[
Xll3ojFOc`CoX9c@0_nIVm@00onOY=WoVjGMoi^Ug@02oi^Ug@CoUZSS0onB[^T2oi>fkP;oV[W^1?nL
_o04oj?4l0CoYlK_0_n/a^d2ojW6kP?o[<G/0_nZa^h4ojc5k0;o[<C[0_n[aN`4oj_4k0;oZl?[0on[
a>`2oj_3k0;oZLC]1?nY`n`4ojW2k0CoZ<;/0_nX`N/3ojS1k0?oZ<7[0_nX`>/9ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03?ooool003kooooo00?o0000ooooooooool0;Oooool2
oj[1jP?oZl7Y0_n/`>P2oj^oj0CoZkgW0_nY^nH2ojJji`?oY;OV1?nR]NH2oifci`;oW[c^1?nO`O02
oj37m0?oZM7e00?o/=SeokCAkonddNl00_nddNl2okS?j`;o/L;V1?n[^N<2oj:^h003oiVZhonAYN?o
TJGS00;oTJGS0on8Y>H4ohf_k@;oWLKd0ondf_<01?o9in_ob=gXolSMj?o8gNP2ol7Bi`?o^lGR00Co
ZkWToiRXh_nHZ>;oV:SR0on0VN43oh6Kh`;oNiOS0_nC[>P3ok_8i0?oa<gQ00?oem3Bom;;dooBbm<0
0_oBbm<3ol^ncP03olBldonn//oo_[;?00?o_[;?00Co]ZW<ok6ZdOnaZ]7o/J[A1?n[Xll2ojFOc`03
ojJUeOnSY=KoXjCF00;oXjCF1?nOY=T4oi^Ug@;oUZSS0_nM/>D3oiZdj@CoV[W^0_nL_o02oio0l0Co
XlC`0_nWa^l2ojK5l0CoZLK^00?o[<G/oj[6k_nZa^h00_nZa^h2ojc5k0;oZ/G^1?n[aN`2oj_4k0?o
Z/G]0_n[a>`00onYaNgoZLC]ojW4k@03ojW4k@;oZL?/00?oZL?]ojW2k?nY`^`00onY`^`4ojS2k0;o
Z<7/4?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo000oooooo`;o0000
;oooool2oj_1j@;oZl7Z1?n[_nP2oj^mi`;oZ;cX1?nV^^L3ojBgiP;oX[GV0_nQ^n`4oijlkP;oWl7`
0onUbo@2ojWAm@?o/<o`0_nddNl2ok77jPCo/L;V0_n[^N<2oj:ah`?oVJ[S1?nAYN<3ohRTiP;oSJo]
0onOa_@2okCJl`?o_m_]00?ob=gXol7Bioo1d^L00_o1d^L01?nkaN;oZkWToj^ii?n[^N@3oiRXhP?o
P9WQ0on1Vn<4oi>/j004ok_8i?o4cN7oa<gQolC=h@;oa/cO0ooBbm<2olg8e@04ol^nc_o4_=?oa;cC
olBld`?o_[;?00?o^;;Cok6ZdOnaZ]400onaZ]42oj^Sc`03ojZXeOnVYMGoYZGE00;oYZGE1?nSY=H3
oinTf@;oVjGM0_nQ[N05oif`i@?oV[CY0_nJ^Nh2oinlkPCoWl3`0_nSa?03ojC4l0?oY/G`0_nYa^h3
ojS6k`;oZ/K^00?oZ<K_oj[5k_nZaNh00onZaNh2oj_5k0;oZ/G^0_nZaNd2ojW5kPCoZLG]1?nYa>d4
ojW3k@;oZL;/0onX`nd2ojS2k1Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0;
ooooo`00@Oooool00ol0003oooooooooo`0]ooooo`CoZl7Z0_n[_nP2ojRnj@CoZ;cX0_nV^^L2ojBl
jPCoX[_[0onQ^n`2oijlkP?oX/Gb0_nUbo@3oj_<l@;o/<o`0_nab^`4ok77jP;o/L;V0_nX^ND4oj:a
h`?oVJ[S0_nAYN<2oi:]j@?oTkC^0onOa_@3ojoBlP;o_m_]0_o1en/2ol7Bi`;o]/KV1?n[^N@4oiRX
hP?oP9WQ0on1Vn<2oi>/j0?oY;_Y00?oa<gQolK<goo6c=l00_o6c=l01?oBbm?ocLSEolg8eOo=b=D5
olBld`04okjbconh/]?o^;;CokRbd`?o/J[A00?o[ZgGojZXeOnZZ=D00_nZZ=D4ojJUe@;oXjCF00?o
YZcKojB/gOnT[=d00_nT[=d4oj6]h0;oWK3U0_nS]nL4oj2ijPCoWkc^0_nO`?02oj;2k`CoY<C`1?nV
aO02ojS6k`;oYlK_1?nXa^l2oj[5kP?oZLK_0_nZaNh2ojW6k`CoZLG^0_nYaNd2ojS5kPCoZLC]0_nY
`nd5ojS3kASooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`00@_ooool0
0ol0003oooooooooo`0]ooooo`;oZl7Z0_nY`>/4ojRnj@;oZ;cX0_nU_N/4ojBljP;oX[_[0_nR`>h4
oj;2l0;oX/Gb0onXbO42oj_<l@;o[/[^1?nab^`2ok77jP;o[;kW1?nX^ND2oj:ah`03oif_i?nE[>Ko
UJcV00;oUJcV1?nB[NT3oi>dkP05oio6m?n_d_;o[m;bojoBl_nfeO000oo1en/2ok_?j@Co]/KV0_n[
^N@2oinai0?oTJGS0on2W^D4ohbXj0?oY;_Y00?o[l?XolK<goo6c=l00_o6c=l01?o4bmoocLSEolg8
eOo=b=D2olK5f@?oa;cC0_nm^mP4okRbd`04ok6ZdOn^[MOo[ZgGojj]e`CoZZSE0_nVYMD00onW[=_o
YZcKojJ/f`02ojJ/f`CoY:cM0_nQ[N02ojFei0CoXkOW0_nP^NX2ojBmj`CoX[o^0_nR`^l2ojC3k`Co
Y<C`0_nVaO02ojG5l0CoYlK_0_nXa^l3ojO6k`;oZLK_00?oZ<K_ojW6konYa^l00onYa^l2ojW5kP03
ojS6konXaNkoZ<G^00?oZ<G^0_nYa>d2ojS4kP;oZ<?]7Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00_ooooo0013ooooo`03o`000?oooooooooo02gooooo1?nY`>/2ojRnj@;oY[k[
1?nU_N/2ojBljP;oXko]1?nR`>h2oj;2l0?oY/K`0_nXbO42oj_9k`Co[/[^0_nab^`3ojk2j@?o[;kW
0_nX^ND00onR/nGoWJoToif_i002oif_i0CoUJcV0_nB[NT00onJ^^koXLCaoj74l@03oj74l@05ojoB
l_nfeO3o]]G`okKEl?o1en/01?nkcnT2okK6iP;o[;gV1?nO/N@3oi6Uh`?oPYkU1?n<Z>P01OnT^nWo
[l?Xojo3j?n_`nSoa/cO00Coa<_O00?ocLSEolK5fOo6aMT00_o6aMT00oo4_=?o_K_Hokfkf002okfk
f0;o^;;C0_nb]=T4ojj]e`;oZZSE00?oZ:kKojN/fonW[=/00_nW[=/4ojJ/f`;oY:cM0_nW/n84ojFe
i0;oXkOW0_nV_>T4ojBmj`;oX[o^0_nU`^h4ojC3k`;oY<C`00?oYLC`ojG5l?nUaO000onUaO02ojO6
k`;oY/K`0_nWa^l2ojO6l0CoZ<K_0_nYa^l6ojS6k`;oZ<G^0onXaNl2ojS4kR3ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`00A?ooool00ol0003oooooooooo`0]ooooo`;o
ZL3[0_nV`>`4ojJnj`;oYKg[0_nT_n`4oj>ok@;oX/3^0onT`nl2ojK6l0;oZLO_1?n[bNl2ojk:kP?o
[LC[0_n^`^T01?nZ_>OoYkSUojNhiOnW^>D4oj:ci@;oWJoT0_nK/nP3oiRdj`CoV[[^0_nQa?43ojc=
l@;o]]G`0ongdNd2ok_?j@?o]<KX0on/_NH2oinai0;oV:kV0on>YnH3ohRVj@CoUk?[0_n_`nP2okC7
j0?oa<_O0oo1bN42olK5f@;o`<?M0onm^mP00ong^mgo/[CIok:df@03ok:df@;o[ZgG00?oZk7MojR^
fonX[]/00_nX[]/4ojN/f`;oYZcK00?oZ;?QojNch_nW/n800onW/n82ojFei003ojRkionV_>WoY[cY
00?oY[cY0_nT_N/00onV`NcoYL;^ojG2kP03ojG2kP;oY<?_0_nUa>l3ojG4l0GoYLG`1?nVa_04ojO6
l0;oZ<K_0onWa_02ojS6k`03ojO6l?nWa^ooYlK_00?oYlK_0_nXaNlTooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool004Gooooo0_l0000_ooooo`?oY/3/0_nV_^/3ojFok0?o
Y;o/0_nS_nd3ojC2kP;oY<?_0_nWaNl4ojW7k`;oZlW_0on/aN`2ojg4j`03oj^oj?nZ_>OoZ[cW00;o
Z[cW0onW^>D2oj:ci@;oWkCW1?nK/nP3oiRdj`;oV[[^0onSa?42ojc=l@?o//o_0_ngdNd2okG<j`?o
]<KX0_n/_nP3oj>giPCoV:kV0on>YnH3ohRVj@;oUk?[0_nO^nd4okC7j005olC;goo1bN7o`LWQol79
hOnlb><01Oo0`md01?nm^mSo]k_MokNkgOng^md2ok:df@;o[[KO1?n[/Md3ojR^f`;oYjcK1_nX/n42
ojNchP;oZK[V1?nX^nL2ojJlj@;oZ<3[1?nV`N`2ojG2kP?oY/?^0_nUa>l2ojK4k`KoYLG`0_nVaO04
ojK6l0coYlK`0_nWa^lYooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool0
04Oooooo00?o0000ooooooooool0;Oooool6ojFok0;oYL3]1?nT`Nd2ojC2kP;oY/?^1?nWaNl2ojW7
k`;oZ/G]0on/aN`00on[`NWoZkoXoj^oj002oj^oj0;oZ[cW0_nV^NL3oj>gi`CoWkCW0_nK/nP2oifi
k0CoWKc^0_nSa?42oj[9l0?o//o_0_nccNd4okG<j`03okC6j?n/_nSo[;oX00;o[;oX0onS]nH2oiR^
iP03oiB]j?n?[>WoSjcY00;oSjcY0on@[n`4oinkk@;o]<OX0onfb>P01?o1bN7o_<SSokc8honlb><2
ol33g@;o^L;Q0ong^md00ona_>;o[[KOojjfg`03ojjfg`?oZk7M0_nX[]/2ojNdh@KoZ;?Q0_nY^^D4
ojVjiP;oZ;_W0_nZ`>T4ojS0j`;oY/7/0onX`nd2ojK3kP03ojO4konVa>ooY/C_00?oY/C_0_nUaO06
ojK5l0CoY/K`0_nWa_02ojK6l0KoYlK`;?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00_ooooo0018ooooo`03o`000?oooooooooo02gooooo1?nU_n`4ojG0k@;oY<7]0_nV`^d4ojK3
kP;oYlG_0_nYa>d4oj[5k@04ojc5k?n[`NWoZl7Yoj_1j@;oZkoX0_nX_>P4ojJii`?oXkOW0_nO]>L2
oijgj@CoWKW/0_nM_>h2ojC3k`CoZ/W`00?o//o_ok?=kOnccNd00_nccNd2okG<j`?o/<GY0_n/_nP0
1?nV^^OoW[?WoijcionN/nL4oiB]j0CoSjcY0on@[n`2oinkk@?oYL7]0_nfb>P01?nebNWo_<SSokc8
honlb><2okS7iPCo^L;Q00Co]k_Mok6lh_na_>;o/KcR1?n^]]l2oj^ag@;oZ;KS1?nW]>42ojRch@;o
Z;WV1?nY^^D2ojVjiP;oZ[oY1?nZ`>T2ojS0j`?oZL?/0_nX`nd00onXaNkoYlC_ojO4k`02ojO4k`;o
Y/C_0onVaNl5ojK5l0_oY/K`0_nWa_0`ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02oooool004Wooooo00?o0000ooooooooool0;Oooool4ojFok0CoYL3]1?nV`^d2ojK3kP?oZ<?]
0onYa>d2oj[5k@;oZl;[0_n[`NT2ojVnj0CoZ;cX0_nV^NL2ojBij0?oX[OX1?nN]nT2oifik0;oX[o^
1?nT`nl2oj[9l0?o[/__0_nccNd3ok78j`;o/<GY00?oZkoYojJjionV^^L00_nV^^L3oijci`CoU:gX
0_n?[>T00onC/NcoUkO]oiNgk@02oiNgk@;oYL7]0_nXa>h4okG9j@03okc8honhanKo^<OV00;o^<OV
0_ni`^42okC2i@Co/KcR0_n^]]l2ojZii0CoZ;KS0_nW]>42ojJii`CoZ;WV0_nY^^D00onY_nWoZ[oY
ojZoj@03ojZoj@;oZ/3Y0_nZa>`2ojW3k0;oZLG^1?nXaNh2ojO4k`?oYlG_1?nVaNl4ojK5l0[oY/K`
=?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo001:ooooo`;o0000;_oo
ool2ojFok0;oY[o/1?nU`>d2ojK2k@?oYl;/0_nX`nd00onY`^coZ/;[oj[2j`02oj[2j`;oZl;[0_nY
_nT4ojVnj0;oZ;cX0_nV^^P4ojBij0?oX[OX0_nN]nT2oj6lk0CoX[o^0_nT`nl3ojW7k`;o[/__0_n_
bNd2ok78j`;o[/CZ1?n[_nT2ojJji`;oXKOX0onK/nP3oiB`jPCoTk7/0_nG]nd2oiflkPCoZ<C^0_ne
bNT3ok?8jP;o^<OV0_nca^P4okC2i@;o/KcR0on]_NH3ojZii0;oZ;KS00?oY[[WojJiionV^NL00onV
^NL2ojRiiP03ojNnj_nY_nWoZKoY00;oZKoY0_nZ_nT5oj[4k0;oZ/K^1?nYaNh2ojS5kP?oZ<K_0_nW
aNl00onWa^ooY/G_ojK5k`03ojK5k`?oY/G`1_nVa_0iooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02_ooool004cooooo00?o0000ooooooooool0;?ooool4ojJok0;oYL3]0onW`N`2
ojO2k003ojS1k?nY`^coZL;/00;oZL;/0_nZ`^/2ojW0jPCoZKoY0_nY_^P2ojNlj0CoY[[X0_nT^NP2
oj>jjPCoX[_[0onQ_>`2oj:okP?oYLC_0_nYanl2ojc8kP;o[lW]0_n^a^`4ojk4jP;oZkoY0_nV^nP4
oj6gj0?oVk?X0onD/>X2oi>ak0;oUkK]1?nM_>h2ojS4kP;oZ/G^0oncb>X2ok38j`Co/lKX0_nd`^D2
ojo2j0;o[KgV0_nY_nT4ojNlj0?oY[[W0_nV^NL3ojJnj`?oYkkZ0_nY_nT3ojW3k@;oZ/C/0_nYa^h4
oj[6kP;oZLG^0onYanl3ojS6k`CoYlK_0_nVaNl3ojO5k`?oY/G`0_nVa_0looooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02_ooool004gooooo00?o0000ooooooooool0;?ooool2ojJo
k0?oYl3[0_nW`N`00onX`N_oZ<7/ojS1k002ojS1k0;oZL;/1_nY`>X2ojVoj@;oZ;gY1?nW_>P2ojJj
j0;oYK_Y1?nS^^X2oj:kj`;oXkk/1?nS`>h2ojG4k`04ojW5k_n/b>ko[<S^ojc8kP;o[LK]1?n^a^`2
ojk4jP;oZ[oY1?nV^nP2oj6gj0;oW[KY0onJ/nT4oiJcj`?oUkK]0_nM_>h2oj70k`CoZ/G^00?o/lSZ
ok38jon`b>/00_n`b>/2ok?6j0;o[lGZ0_n_`^P2oj_2j`CoZKoY0_nW_>P2ojFok0CoYKk[0_nV_^/2
ojG2kPCoYl?]0_nY`nd2ojS6k`CoZLK^0_nZa^h2ojW8k`;oZLO_0_nXao04ojS6k`;oYlK_0onWa_02
ojO5kd?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`00C_ooool00ol0
003oooooooooo`0]ooooo`;oYl3[00?oZ<3[ojS1jonX`N/00_nX`N/2ojS1k0;oZL3[1_nY`>X2ojVn
j@CoZ;gY0_nW_>P2ojJlj@CoYK_Y0_nS^^X2oj>mj`CoXkk/0_nS`>h00onV`nkoZLG^ojW5kP02ojW5
kP03ojc8k_n]a^go[LK]00;o[LK]0_n^a^`2ojc2jPCoZ[oY0_nV^nP2oj>ij0CoW[KY0onJ/nT2oiJc
j`;oVKO]1?nK^nh3oj70k`;oZ/G^0_nZa^h2ok38j`?o[/O/0_n_aNX2ojc5k0CoZl;[0_nY_nT2ojK1
k0CoYKo/0_nU_^/2ojC2kPCoYL;^0_nW`nd00onVa_3oZ<K_ojS6k`03ojS6k`;oZLK^0_nYb?02ojW8
k`;oZ<S`1?nXao02ojS6k`?oYlO`0_nWa_17ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02_ooool004oooooo0_l0000^ooooo`?oZ<3[0_nX`N/6ojW0j`;oZL3Z0_nY_nX4ojVnj@;o
Z;gY0_nW_NT4ojJlj@;oYK_Y0_nT_>/4oj>mj`;oXkk/0_nU`Nd3ojK3kP;oZLG^0onZa^d2ojg6k@;o
[<C[1?n/`^X2ojZoj@;oYkcY1?nS^NP2oijfj@03oifgj_nK]^_oVkK[00;oVkK[1?nI]nd2oi^kkP03
oinnkonT`nooY<?_00;oY<?_1?nZa^h3ojk7k0;o[<K]1?n/aN`2oj_2j`;oZ<?]1?nV`N`2ojFok003
ojC1k_nT`^koY<;^00?oY<;^0_nU`^h00onUaO3oY/K`ojK6l002ojK6l0;oZ<K_0onXb?42ojW8l0;o
Z<Wa1?nXb?02ojS7l0CoYlO`C?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[o
oooo001Aooooo`03o`000?oooooooooo02cooooo0onX`>/6ojW0j`KoZKoZ0_nY_^T3ojNnj@?oYkgY
0_nV_>T3ojFmjP?oY;c[0_nS_N/2ojFok0;oYL7]0_nW`nd4ojS4kP;oZ/K]0_n[a>`4ojc4j`;o[<;Z
0onY_nT3ojNlj@;oXkWX00?oXKSYoifgj_nM]nX00_nM]nX4oi^fj`;oVKO]00?oW;_^oinnkonO_^l0
0_nO_^l2ojC3k`;oY/C_1?nZa^h00on^anco[<K]ojc6k@02ojc6k@;o[<G/00?oZLG]ojS3kOnX`nd0
0onX`nd2ojK1k003ojG2k_nT`NkoY<7^00;oY<7^0_nT`^h3ojC4l0?oYLG`0_nVa_03ojK8l@;oZ<Sa
0_nWbO84ojS9l@;oZ<S`0_nWb?42ojO7l4oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0:ooooo`00D_ooool00ol0003oooooooooo`0[ooooo`CoZ<3[0_nY`>/3ojW0jP;oZKoZ0_nX
_nX4ojRnjP;oYkkY0_nW_^X4ojJmjP;oYKgZ00?oYKk[ojFnk?nU_^`00_nU_^`2ojFok0;oY/7]1?nW
`nd2ojS4kP;oZLC]1?n[a>`2ojc4j`?oZ/7[0_nY_nT00onW_NWoY;_YojBkj@02ojBkj@?oXKSY0_nM
]nX2oijhj`CoW;W/0onL^nh2oinnk`?oX/7_0onVa>l5oj[6kP;o[<K]00?oZ/K^ojW5kOnYaNd00_nY
aNd2ojS3k@?oY/?^0onU`^h2ojC1kP?oXl?`0_nTa?02ojC6l@CoYLOa0_nVb?42ojK9lP;oYlWb0_nV
b_84ojO9lP;oYlSaDoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo001C
ooooo`03o`000?oooooooooo02_ooooo1OnX`>/2ojW0jP;oZ;o[1?nX_nX2ojRnjPKoYkkZ0_nV_NX0
0onV_^_oYKk[ojFnj`02ojFnj`;oYKk/0_nV`>`4ojK1k@;oYl?]0_nX`nd4ojW4k@;oZlC/0onZ`^/2
oj[1j`03ojRoj_nW_NWoYkgY00;oYkgY0_nT^nT2oj>jj@?oXKWZ1?nN^>/2oibik0;oW[_]1?nO_^h2
oj;1k`;oY<?_1?nWaNl2oj[6kP;oZLK_0onZa^h2ojW5k@?oZ<G^0_nV`nh2ojG4k`CoY<?_0_nS`o00
0onSaO7oY<KaojC6l@03ojC6l@;oYLOa0_nUb?84ojK9lPCoY/[b0_nWbO9Gooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02Oooool005Cooooo0_l0000]ooooo`CoZ<3[1?nX_n/2ojRo
jP;oYkoZ1_nW_^X5ojJnj`;oYKk[0_nV_n`4ojK0k0;oY/7]0onW`^d3ojS3k@;oZLC]0onZ`n`2oj[2
j`03ojW1jonX_n[oZ;oZ00;oZ;oZ0_nW_NT2ojFlj@CoXk[Y0onQ^NX2oijhj`;oWk[/1?nN^nd2oinn
kP;oX/3_1?nT`nl2ojO5k`;oZ<K_0_nYa^l2ojS6k`CoZLK^0_nXaNh2ojO5k`CoYLC_0_nT`nl2ojC5
l0?oXlGa0_nTa_43ojC7lP;oYLSb0_nUbO84ojK9lP;oY/[bF_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Wooooo001Fooooo`03o`000?oooooooooo02_ooooo1?nX`>/4ojRoj`Co
YkoZ0_nW_^X2ojNoj`GoY[k[1_nV_n`2ojK0k0?oYl7]0_nW`^d2ojS2k@CoZL?/0_nZ`n`5ojW1j`;o
Z;oZ0_nW_^X4ojFlj@;oXk[Y0_nR^n/4oj2jj`?oWk[/0_nN^nd00onQ_^koX/3_oj;0k`03oj;0k`;o
Y<?_0_nUa>l8ojS6k`;oZLK^0_nXa^l4ojO5k`;oYLC_0_nUaO02ojC5l0;oYLKa1?nTa_42ojC7lP?o
YLSb0onUbO82ojK9lUkooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`00
Eoooool00ol0003oooooooooo`0[ooooo`CoZ<3[1?nX_n/2ojNojPKoYko[00CoY[k[ojJojonV_n_o
Y[o[1OnV_n`3ojK1k0;oYl7]0_nW`^d4ojS2k@;oZL?/00?oZL;/ojW1jonY`N/01?nY`N/2ojRojPCo
YkkZ0_nU_>T2ojBljPCoX[_[0_nP^^/00onQ_>coX;c]oj2lk@02oj2lk@?oXKk^0_nR`>l3ojC2k`;o
YLC_0_nVaNl<ojS6k`;oYlG_0_nVaNl4ojG5l0CoYLKa0_nTa_42ojG7l@;oYLSbI_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Wooooo001Hooooo`03o`000?oooooooooo02cooooo
0onX`>/2ojRoj`GoYko[1onV_n/6ojK0k0;oY/7/0_nW`N`4ojO2k@;oZ<;]00?oZ<;/ojW2k?nY`^`0
0_nY`^`2ojW1j`?oZ<3[0onX_nX2ojNnjP?oYKgZ0onT_>X2oj:kj`03oj:ljonQ_>coXKc/00;oXKc/
0_nP_>d2oj:okPCoX/3^0_nT`^l2ojG4k`CoY/G_1_nXa^l2ojO6k`CoYlG_0_nVaNl2ojK5l0CoYLG`
0_nUa_42ojG6l0;oYLOaJ_ooool01Ol0003ooooooooooooooooo000000_ooooo001Iooooo`03o`00
0?oooooooooo02cooooo1?nW`>/3ojNoj`KoY[o[2?nV`>`6ojO1k0;oYl;]1OnX`^`2ojW2k0?oZ<7[
0_nX`>/2ojNoj`CoYkkZ0_nU_NX00onU_N_oXkc[oj>lj`02oj>lj`?oX[c[0_nQ_>`2oj:nk@CoX[o^
0_nR`>h2ojC2k`CoYLC_0_nVaNl2ojO6k`;oZ<K_1_nWa^l5ojO5k`?oY/G`0_nUaO02ojK6l0;oYLK`
KOooool01Ol0003ooooooooooooooooo000000_ooooo001Jooooo`;o0000;Oooool4ojO0j`?oYko[
0_nV_n/2ojJok0SoY/3/2?nW`N`2ojS2k0KoZ<7/0_nX`N/2ojS0j`CoYko[0_nW_^X00onV_^_oYKg[
ojFmj`02ojFmj`;oXkc[0_nS_N`4oj:mk0?oX[k]0_nR_nh3oj?1kP?oY<;_0_nUa>l2ojK5l0;oYlK_
0_nWa_09ojO6k`;oYlG_00?oYlK_ojK5l?nVaO000_nVaO02ojK6l77ooooo00Co0000oooooooooooo
00002oooool005cooooo00?o0000ooooooooool0:oooool4ojO0j`03ojNojonV_ncoY[o/00CoY[o/
2?nV`>`6ojO1k0SoZ<7/0_nX`N/4ojS0j`;oYko[00?oY[o[ojJnjonV_^/00_nV_^/2ojFmj`;oY;k/
1?nS_N`2oj:mk0;oXko]1?nS`>h2oj?1kP03ojC3konUa>ooYLC_00;oYLC_0_nVaO03ojK6l0?oYlK`
0_nWa^l3ojO6l0;oYlK_00?oYlK`ojO6konWa^l00_nWa^l2ojK5l7Gooooo00?o0000ooooool00000
2oooool005gooooo00?o0000ooooooooool0:oooool2ojO0j`;oY/3/0_nV_n`8ojK0k0;oYl3/1onW
`N`8ojS1k0CoZ<7[0_nX`>/00onW_n_oY[o[ojJoj`02ojJoj`;oY[k[0_nU_^/4ojBnk0;oXkg/0_nS
_^d4oj>ok@;oXl3^00?oXl;_ojC3konT`nl00_nT`nl2ojG4k`?oYLG`0onVa_0<ojO6l0;oYlK_N?oo
ool01?l0003oooooooooool0000:ooooo`00G_ooool00ol0003oooooooooo`0[ooooo`[oY/3/1_nW
`>`7ojO1k0SoZ<7/0_nX`N/2ojO0j`?oYko[0_nV_n/3ojJnj`?oYKk[1OnT_^`3oj>nk@;oXko]0_nS
`Nh3oj?2k`;oY<?_0onUa>l2ojG5l0GoY/K`2_nWa_1looooo`03o`000?oooooo000000[ooooo001O
ooooo`;o0000;?ooool6ojK0k0SoYl3/2_nW`N`2ojS1k0OoYl3[0_nW_n/4ojJoj`;oY[k[0_nU_n`4
ojFnk0;oY;k/00?oY;o]ojC0kOnT`>d00_nT`>d2oj?1kP;oY<;^1?nT`nl2ojG4k`03ojG5l?nVa_3o
Y/K`00OoY/K`0_nWa_23ooooo`;o00002_ooool0067ooooo00?o0000ooooooooool0:_ooool2ojK0
k0?oYl3[1onW`>`<ojO1k0OoYl3[1?nW_n/4ojJoj`CoYKo/0_nU_^`00onU_ncoY;o]ojBok@02ojBo
k@;oY<3]0_nT`Nh4ojC2kP;oY<?_0_nUa>l3ojG5l0OoY/K`QOooool3o`0000[ooooo001Rooooo`03
o`000?oooooooooo02_ooooo1?nW`>/7ojO0k0coYl7/1onW`>/5ojNoj`?oY[o[1onU_n`2ojBok@?o
YL7]0onT`Nh2ojC2kP?oYL?_00?oYLC_ojK5konVaNl01?nVaO02ojK6l8Cooooo1?l0000=ooooo`00
Hoooool00ol0003oooooooooo`0[ooooo`CoYl3[0_nW`>`00onW`>_oYl3/ojO0k002ojO0k0;oYl7/
0_nW`>/6ojO1k0OoYl3[1OnW_n/2ojJoj`?oY[o/0_nU_n`2ojK0k0CoYL3]1?nU`Nd4ojG2kP;oYL?_
00?oY/C_ojK5konVaNl00_nVaNl2ojK5l8?ooooo1?l0000Aooooo`00I?ooool2o`0002cooooo1onW
`>/2ojO0k0KoYl3[0_nW`N`:ojO0j`CoYko[1?nV_n/3ojJok0CoY/3/0_nU`>d2ojK1k@CoYL7]0_nU
`^h2ojK3kP?oY/C_0_nVaNn3ooooo`?o00005Oooool006Kooooo00?o0000ooooooooool0:ooooolH
ojO0j`KoYko[0onV_n/4ojJok0GoY/3/0onV`Nd2ojG1k@;oY/;]0_nV`nj5ooooo`Co00006?ooool0
06Oooooo00?o0000ooooooooool0:_ooool>ojO0j`03ojS0jonW`>_oYl3[00OoYl3[1onW_n/3ojJo
j`;oY[o/1OnV`>`00onW`NcoY/7]ojK1k@02ojK1k@;oY/;]Q?ooool4o`0001cooooo001Xooooo`03
o`000?oooooooooo02[ooooo2_nW`>/5ojS0j`OoYl3[2OnW_n/4ojO0j`;oY/3/00?oYl3/ojO1k?nW
`N`00_nW`N`2ojK1kH?ooooo1?l0000Pooooo`00JOooool2o`0002cooooo1OnW`>/6ojS0j`SoYl3[
2onW_n/3ojO0j`CoYl3/0_nW`Nb2ooooo`Co00009?ooool006_ooooo00?o0000ooooooooool0:_oo
ool;ojS0j`SoYl3[2OnW_n/5ojO0j`;oYl3/P_ooool3o`0002Sooooo001/ooooo`03o`000?oooooo
oooo02[ooooo3?nX`>/5ojO0j`[oYko[0_nW`>^3ooooo`Co0000:oooool006gooooo00?o0000oooo
ooooool0:oooool9ojS0j`GoYl3[2_nW_n^2ooooo`Co0000;oooool006kooooo00?o0000oooooooo
ool0:_ooool8ojS0j`GoYl3[2?nW_n^1ooooo`Co0000<oooool006oooooo0_l0000[ooooo`SoZ<3[
1?nW`>/5ojNojh3ooooo1?l0000gooooo`00LOooool00ol0003oooooooooo`0Zooooo`GoZ<3[1?nW
`>^2ooooo`Co0000>oooool007;ooooo00?o0000ooooooooool0:_ooool5ojO0jh;ooooo0ol0000o
ooooo`00Loooool00ol0003oooooooooo`0Zooooo`03ojO0jooooooooooo07oooooo1?l00012oooo
o`00M?ooool2o`0002[ooooo00?o0000ooooooooool0Noooool4o`0004Kooooo001fooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0N?ooool4o`0004[ooooo001gooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0M?ooool4o`0004kooooo001hooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0LOooool3o`0005;ooooo001iooooo`;o00009?ooool00ol0
003oooooooooo`1]ooooo`Co0000EOooool007_ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`1Yooooo`Co0000FOooool007cooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`1Uooooo`Co0000GOooool007gooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`1Qooooo`Co0000HOooool007kooooo0_l0000Oooooo`03o`000?oooooooooo05gooooo1?l0001U
ooooo`00P?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05[ooooo0ol0001Yoooo
o`00POooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Kooooo1?l0001/ooooo`00
P_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05;ooooo1?l0001`ooooo`00Pooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04kooooo1?l0001dooooo`00Q?ooool2
o`0001Wooooo00?o0000ooooooooool0B_ooool4o`0007Sooooo0026ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0A_ooool4o`0007cooooo0027ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0@oooool3o`00083ooooo0028ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0?oooool4o`0008?ooooo0029ooooo`;o00005?ooool00ol0003ooooooooo
o`0kooooo`Co0000Qoooool008_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0g
ooooo`Co0000Roooool008cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0coooo
o`Co0000Soooool008gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0`ooooo`?o
0000Toooool008kooooo0_l0000?ooooo`03o`000?oooooooooo02cooooo1?l0002Fooooo`00T?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Sooooo1?l0002Jooooo`00TOooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Cooooo1?l0002Nooooo`00T_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo1?l0002Rooooo`00Toooool2o`0000Wo
oooo00?o0000ooooooooool07Oooool4o`000:Kooooo002Eooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool06_ooool3o`000:[ooooo002Fooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool05_ooool4o`000:gooooo002Gooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool04_ooool4o`000;7ooooo002Hooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool03_ooool4o`000;Gooooo002Iooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co
0000^Oooool009_ooooo00Co0000oooooooooooo00002Oooool3o`000;gooooo002Looooo`03o`00
0?oooooo000000Gooooo1?l00030ooooo`00WOooool2o`000003ooooool0003o000000;o0000a?oo
ool009kooooo0_l00038ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z_ooool01OnHV9So0000
o`000?m4A4Co^[Zj00Wooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c02Cooooo`00Z_ooool01Ol@413o^[Zjonk^k_mgMgOo
410@00;ooooo1_l000001_ooooooV9RHob4Q8Oo^k^koooooodA4A0?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q09?ooooo002Zooooo`03
o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`00002Cooooo`00Z_ooool00ol0003oooooooooo`04oooo
o`Ko00000oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000002oooool0
1Olb<S;oV9RHoooooonHV9So<S8b09?ooooo002Zooooo`03o`000?oooooooooo00kooooo00?oMgMg
ofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000
olc<c02Cooooo`00Z?ooool00ol@413o0000o`000003o`0000kooooo00Go0000oooooooooooooooo
oa0@4003ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@402Cooooo`00
Z_ooool00ol0003oooooooooo`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00002Cooooo`00Z_ooool00ol0
003oooooooooo`0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2Cooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -20 0 ]
[.5 .82364 20 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(21.6) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69466 Mtetra
.4053 .69466 .41061 .69934 .41957 .69681 .41427 .69212 Mtetra
.41427 .69212 .41957 .69681 .42855 .69428 .42328 .68956 Mtetra
.656 .751 .919 r
.42328 .68956 .42855 .69428 .43756 .69174 .43231 .68699 Mtetra
.656 .75 .919 r
.43231 .68699 .43756 .69174 .4466 .68919 .44137 .68441 Mtetra
.657 .75 .918 r
.44137 .68441 .4466 .68919 .45567 .68663 .45046 .68183 Mtetra
.657 .749 .918 r
.45046 .68183 .45567 .68663 .46478 .68407 .45958 .67923 Mtetra
.45958 .67923 .46478 .68407 .47391 .68149 .46873 .67663 Mtetra
.656 .748 .917 r
.46873 .67663 .47391 .68149 .48307 .67891 .47792 .67402 Mtetra
.47792 .67402 .48307 .67891 .49227 .67632 .48713 .67142 Mtetra
.655 .748 .918 r
.48713 .67142 .49227 .67632 .50149 .67371 .49638 .66882 Mtetra
.654 .748 .919 r
.49638 .66882 .50149 .67371 .51075 .6711 .50565 .66623 Mtetra
.653 .749 .92 r
.50565 .66623 .51075 .6711 .52004 .66849 .51496 .66366 Mtetra
.651 .752 .923 r
.51496 .66366 .52004 .66849 .52936 .66586 .5243 .66112 Mtetra
.65 .755 .927 r
.5243 .66112 .52936 .66586 .53871 .66322 .53367 .65859 Mtetra
.648 .76 .931 r
.53367 .65859 .53871 .66322 .54809 .66058 .54308 .65608 Mtetra
.646 .766 .936 r
.54308 .65608 .54809 .66058 .55751 .65792 .55252 .65358 Mtetra
.644 .773 .941 r
.55252 .65358 .55751 .65792 .56695 .65526 .56199 .65107 Mtetra
.644 .78 .946 r
.56199 .65107 .56695 .65526 .57643 .65259 .5715 .64853 Mtetra
.645 .787 .95 r
.5715 .64853 .57643 .65259 .58595 .6499 .58103 .64593 Mtetra
.647 .792 .952 r
.58103 .64593 .58595 .6499 .59549 .64721 .5906 .64324 Mtetra
.652 .795 .951 r
.5906 .64324 .59549 .64721 .60507 .64451 .6002 .64045 Mtetra
.658 .793 .947 r
.6002 .64045 .60507 .64451 .61468 .6418 .60984 .63755 Mtetra
.663 .787 .94 r
.60984 .63755 .61468 .6418 .62432 .63908 .6195 .63455 Mtetra
.668 .776 .93 r
.6195 .63455 .62432 .63908 .634 .63636 .62919 .63146 Mtetra
.67 .763 .92 r
.62919 .63146 .634 .63636 .64371 .63362 .63891 .62835 Mtetra
.67 .748 .909 r
.63891 .62835 .64371 .63362 .65345 .63087 .64866 .62525 Mtetra
.667 .735 .901 r
.64866 .62525 .65345 .63087 .66323 .62811 .65845 .62221 Mtetra
.663 .724 .895 r
.65845 .62221 .66323 .62811 .67304 .62535 .66828 .61929 Mtetra
.657 .717 .893 r
.66828 .61929 .67304 .62535 .68289 .62257 .67815 .61649 Mtetra
.652 .715 .894 r
.67815 .61649 .68289 .62257 .69277 .61979 .68806 .61383 Mtetra
.648 .719 .9 r
.68806 .61383 .69277 .61979 .70269 .61699 .69801 .61127 Mtetra
.644 .727 .909 r
.69801 .61127 .70269 .61699 .71264 .61418 .708 .60879 Mtetra
.642 .739 .919 r
.708 .60879 .71264 .61418 .72262 .61137 .71803 .60632 Mtetra
.64 .753 .93 r
.71803 .60632 .72262 .61137 .73264 .60854 .72809 .60382 Mtetra
.641 .768 .94 r
.72809 .60382 .73264 .60854 .7427 .60571 .73819 .60123 Mtetra
.642 .78 .947 r
.73819 .60123 .7427 .60571 .75279 .60286 .74832 .59855 Mtetra
.646 .789 .951 r
.74832 .59855 .75279 .60286 .76291 .60001 .75848 .59575 Mtetra
.649 .794 .952 r
.75848 .59575 .76291 .60001 .77308 .59714 .76867 .59284 Mtetra
.653 .794 .95 r
.76867 .59284 .77308 .59714 .78328 .59427 .77889 .58985 Mtetra
.656 .791 .946 r
.77889 .58985 .78328 .59427 .79351 .59138 .78914 .5868 Mtetra
.659 .785 .941 r
.78914 .5868 .79351 .59138 .80378 .58849 .79943 .58371 Mtetra
.66 .778 .936 r
.79943 .58371 .80378 .58849 .81409 .58558 .80975 .58061 Mtetra
.66 .77 .931 r
.80975 .58061 .81409 .58558 .82443 .58267 .82011 .57752 Mtetra
.66 .764 .927 r
.82011 .57752 .82443 .58267 .83482 .57974 .8305 .57444 Mtetra
.659 .758 .923 r
.8305 .57444 .83482 .57974 .84523 .5768 .84094 .57139 Mtetra
.658 .754 .921 r
.84094 .57139 .84523 .5768 .85569 .57385 .85142 .56835 Mtetra
.657 .751 .919 r
.85142 .56835 .85569 .57385 .86618 .57089 .86194 .56533 Mtetra
.657 .749 .918 r
.86194 .56533 .86618 .57089 .87672 .56792 .87249 .56232 Mtetra
.656 .748 .917 r
.87249 .56232 .87672 .56792 .88729 .56494 .88309 .55932 Mtetra
.88309 .55932 .88729 .56494 .89789 .56195 .89373 .55631 Mtetra
.656 .748 .918 r
.89373 .55631 .89789 .56195 .90854 .55895 .9044 .5533 Mtetra
.9044 .5533 .90854 .55895 .91923 .55594 .91512 .55028 Mtetra
.655 .749 .918 r
.91512 .55028 .91923 .55594 .92995 .55292 .92587 .54725 Mtetra
.655 .749 .919 r
.92587 .54725 .92995 .55292 .94071 .54988 .93667 .54421 Mtetra
.655 .75 .919 r
.93667 .54421 .94071 .54988 .95152 .54684 .9475 .54116 Mtetra
.656 .75 .92 r
.9475 .54116 .95152 .54684 .96236 .54378 .95837 .53809 Mtetra
.656 .751 .92 r
.95837 .53809 .96236 .54378 .97324 .54071 .96928 .53501 Mtetra
.96928 .53501 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.656 .752 .92 r
.391 .69252 .39636 .6972 .4053 .69466 .39996 .68996 Mtetra
.656 .751 .92 r
.39996 .68996 .4053 .69466 .41427 .69212 .40895 .6874 Mtetra
.40895 .6874 .41427 .69212 .42328 .68956 .41797 .68482 Mtetra
.657 .751 .92 r
.41797 .68482 .42328 .68956 .43231 .68699 .42702 .68223 Mtetra
.657 .751 .919 r
.42702 .68223 .43231 .68699 .44137 .68441 .4361 .67963 Mtetra
.4361 .67963 .44137 .68441 .45046 .68183 .44521 .67701 Mtetra
.657 .75 .919 r
.44521 .67701 .45046 .68183 .45958 .67923 .45435 .67439 Mtetra
.657 .75 .918 r
.45435 .67439 .45958 .67923 .46873 .67663 .46353 .67176 Mtetra
.657 .749 .918 r
.46353 .67176 .46873 .67663 .47792 .67402 .47273 .66913 Mtetra
.656 .749 .918 r
.47273 .66913 .47792 .67402 .48713 .67142 .48196 .66651 Mtetra
.655 .748 .919 r
.48196 .66651 .48713 .67142 .49638 .66882 .49123 .66391 Mtetra
.653 .748 .92 r
.49123 .66391 .49638 .66882 .50565 .66623 .50053 .66134 Mtetra
.651 .749 .922 r
.50053 .66134 .50565 .66623 .51496 .66366 .50985 .65881 Mtetra
.648 .75 .924 r
.50985 .65881 .51496 .66366 .5243 .66112 .51922 .65632 Mtetra
.644 .753 .928 r
.51922 .65632 .5243 .66112 .53367 .65859 .52861 .6539 Mtetra
.641 .757 .932 r
.52861 .6539 .53367 .65859 .54308 .65608 .53804 .65151 Mtetra
.638 .762 .938 r
.53804 .65151 .54308 .65608 .55252 .65358 .5475 .64916 Mtetra
.637 .769 .943 r
.5475 .64916 .55252 .65358 .56199 .65107 .55699 .6468 Mtetra
.637 .776 .947 r
.55699 .6468 .56199 .65107 .5715 .64853 .56653 .6444 Mtetra
.64 .784 .951 r
.56653 .6444 .5715 .64853 .58103 .64593 .57609 .64188 Mtetra
.646 .79 .951 r
.57609 .64188 .58103 .64593 .5906 .64324 .58568 .63921 Mtetra
.656 .794 .949 r
.58568 .63921 .5906 .64324 .6002 .64045 .59531 .63634 Mtetra
.666 .794 .943 r
.59531 .63634 .6002 .64045 .60984 .63755 .60496 .63324 Mtetra
.676 .788 .934 r
.60496 .63324 .60984 .63755 .6195 .63455 .61464 .62994 Mtetra
.683 .778 .923 r
.61464 .62994 .6195 .63455 .62919 .63146 .62434 .62648 Mtetra
.685 .764 .912 r
.62434 .62648 .62919 .63146 .63891 .62835 .63408 .62297 Mtetra
.683 .749 .902 r
.63408 .62297 .63891 .62835 .64866 .62525 .64384 .61949 Mtetra
.676 .734 .894 r
.64384 .61949 .64866 .62525 .65845 .62221 .65364 .61617 Mtetra
.668 .722 .89 r
.65364 .61617 .65845 .62221 .66828 .61929 .66349 .61307 Mtetra
.657 .713 .889 r
.66349 .61307 .66828 .61929 .67815 .61649 .67337 .61026 Mtetra
.647 .71 .893 r
.67337 .61026 .67815 .61649 .68806 .61383 .68331 .60773 Mtetra
.638 .711 .9 r
.68331 .60773 .68806 .61383 .69801 .61127 .69329 .60543 Mtetra
.63 .718 .91 r
.69329 .60543 .69801 .61127 .708 .60879 .70333 .60328 Mtetra
.626 .73 .922 r
.70333 .60328 .708 .60879 .71803 .60632 .7134 .60117 Mtetra
.625 .745 .933 r
.7134 .60117 .71803 .60632 .72809 .60382 .72351 .59901 Mtetra
.628 .761 .943 r
.72351 .59901 .72809 .60382 .73819 .60123 .73365 .59669 Mtetra
.634 .776 .949 r
.73365 .59669 .73819 .60123 .74832 .59855 .74382 .59417 Mtetra
.643 .787 .951 r
.74382 .59417 .74832 .59855 .75848 .59575 .75401 .59143 Mtetra
.651 .793 .95 r
.75401 .59143 .75848 .59575 .76867 .59284 .76423 .58847 Mtetra
.658 .794 .947 r
.76423 .58847 .76867 .59284 .77889 .58985 .77447 .58536 Mtetra
.664 .791 .943 r
.77447 .58536 .77889 .58985 .78914 .5868 .78474 .58213 Mtetra
.666 .785 .937 r
.78474 .58213 .78914 .5868 .79943 .58371 .79504 .57885 Mtetra
.667 .778 .932 r
.79504 .57885 .79943 .58371 .80975 .58061 .80537 .57556 Mtetra
.666 .771 .928 r
.80537 .57556 .80975 .58061 .82011 .57752 .81575 .57231 Mtetra
.665 .764 .924 r
.81575 .57231 .82011 .57752 .8305 .57444 .82616 .56909 Mtetra
.663 .759 .921 r
.82616 .56909 .8305 .57444 .84094 .57139 .83662 .56593 Mtetra
.661 .754 .92 r
.83662 .56593 .84094 .57139 .85142 .56835 .84712 .56282 Mtetra
.659 .752 .919 r
.84712 .56282 .85142 .56835 .86194 .56533 .85766 .55975 Mtetra
.657 .75 .918 r
.85766 .55975 .86194 .56533 .87249 .56232 .86824 .55671 Mtetra
.656 .749 .918 r
.86824 .55671 .87249 .56232 .88309 .55932 .87887 .55368 Mtetra
.87887 .55368 .88309 .55932 .89373 .55631 .88953 .55066 Mtetra
.655 .749 .919 r
.88953 .55066 .89373 .55631 .9044 .5533 .90024 .54764 Mtetra
.90024 .54764 .9044 .5533 .91512 .55028 .91098 .54461 Mtetra
.91098 .54461 .91512 .55028 .92587 .54725 .92177 .54157 Mtetra
.655 .75 .92 r
.92177 .54157 .92587 .54725 .93667 .54421 .93259 .53852 Mtetra
.93259 .53852 .93667 .54421 .9475 .54116 .94345 .53545 Mtetra
.655 .751 .92 r
.94345 .53545 .9475 .54116 .95837 .53809 .95436 .53237 Mtetra
.95436 .53237 .95837 .53809 .96928 .53501 .9653 .52927 Mtetra
.9653 .52927 .96928 .53501 .98024 .53192 .97628 .52616 Mtetra
.656 .751 .92 r
.38561 .68781 .391 .69252 .39996 .68996 .39459 .68524 Mtetra
.656 .752 .92 r
.39459 .68524 .39996 .68996 .40895 .6874 .40359 .68266 Mtetra
.40359 .68266 .40895 .6874 .41797 .68482 .41263 .68006 Mtetra
.657 .752 .92 r
.41263 .68006 .41797 .68482 .42702 .68223 .4217 .67746 Mtetra
.4217 .67746 .42702 .68223 .4361 .67963 .4308 .67484 Mtetra
.4308 .67484 .4361 .67963 .44521 .67701 .43993 .6722 Mtetra
.657 .751 .919 r
.43993 .6722 .44521 .67701 .45435 .67439 .44909 .66955 Mtetra
.44909 .66955 .45435 .67439 .46353 .67176 .45829 .6669 Mtetra
.45829 .6669 .46353 .67176 .47273 .66913 .46751 .66425 Mtetra
.656 .75 .919 r
.46751 .66425 .47273 .66913 .48196 .66651 .47676 .66161 Mtetra
.654 .75 .92 r
.47676 .66161 .48196 .66651 .49123 .66391 .48605 .659 Mtetra
.652 .749 .921 r
.48605 .659 .49123 .66391 .50053 .66134 .49537 .65643 Mtetra
.649 .749 .923 r
.49537 .65643 .50053 .66134 .50985 .65881 .50471 .65392 Mtetra
.645 .75 .925 r
.50471 .65392 .50985 .65881 .51922 .65632 .5141 .65148 Mtetra
.64 .751 .929 r
.5141 .65148 .51922 .65632 .52861 .6539 .52351 .64913 Mtetra
.636 .753 .933 r
.52351 .64913 .52861 .6539 .53804 .65151 .53296 .64686 Mtetra
.631 .757 .938 r
.53296 .64686 .53804 .65151 .5475 .64916 .54244 .64464 Mtetra
.63 .763 .943 r
.54244 .64464 .5475 .64916 .55699 .6468 .55196 .64242 Mtetra
.63 .77 .947 r
.55196 .64242 .55699 .6468 .56653 .6444 .56152 .64014 Mtetra
.636 .778 .949 r
.56152 .64014 .56653 .6444 .57609 .64188 .57111 .63772 Mtetra
.645 .786 .949 r
.57111 .63772 .57609 .64188 .58568 .63921 .58073 .63507 Mtetra
.659 .791 .945 r
.58073 .63507 .58568 .63921 .59531 .63634 .59038 .63212 Mtetra
.675 .793 .937 r
.59038 .63212 .59531 .63634 .60496 .63324 .60005 .62882 Mtetra
.688 .788 .927 r
.60005 .62882 .60496 .63324 .61464 .62994 .60975 .62522 Mtetra
.697 .779 .914 r
.60975 .62522 .61464 .62994 .62434 .62648 .61947 .62136 Mtetra
.699 .764 .902 r
.61947 .62136 .62434 .62648 .63408 .62297 .62921 .61742 Mtetra
.696 .748 .892 r
.62921 .61742 .63408 .62297 .64384 .61949 .63899 .61353 Mtetra
.686 .732 .885 r
.63899 .61353 .64384 .61949 .65364 .61617 .6488 .60989 Mtetra
.673 .717 .882 r
.6488 .60989 .65364 .61617 .66349 .61307 .65865 .60661 Mtetra
.657 .706 .883 r
.65865 .60661 .66349 .61307 .67337 .61026 .66856 .60377 Mtetra
.641 .7 .889 r
.66856 .60377 .67337 .61026 .68331 .60773 .67852 .60139 Mtetra
.627 .7 .898 r
.67852 .60139 .68331 .60773 .69329 .60543 .68854 .59937 Mtetra
.615 .706 .91 r
.68854 .59937 .69329 .60543 .70333 .60328 .69862 .5976 Mtetra
.609 .718 .923 r
.69862 .5976 .70333 .60328 .7134 .60117 .70873 .59589 Mtetra
.608 .734 .935 r
.70873 .59589 .7134 .60117 .72351 .59901 .71889 .59409 Mtetra
.615 .753 .944 r
.71889 .59409 .72351 .59901 .73365 .59669 .72908 .59205 Mtetra
.626 .77 .949 r
.72908 .59205 .73365 .59669 .74382 .59417 .73928 .58969 Mtetra
.64 .783 .95 r
.73928 .58969 .74382 .59417 .75401 .59143 .74951 .58699 Mtetra
.654 .79 .947 r
.74951 .58699 .75401 .59143 .76423 .58847 .75975 .58398 Mtetra
.664 .792 .943 r
.75975 .58398 .76423 .58847 .77447 .58536 .77001 .58074 Mtetra
.671 .789 .937 r
.77001 .58074 .77447 .58536 .78474 .58213 .7803 .57734 Mtetra
.673 .784 .932 r
.7803 .57734 .78474 .58213 .79504 .57885 .79061 .57388 Mtetra
.674 .777 .928 r
.79061 .57388 .79504 .57885 .80537 .57556 .80097 .57042 Mtetra
.671 .77 .924 r
.80097 .57042 .80537 .57556 .81575 .57231 .81136 .56702 Mtetra
.669 .764 .922 r
.81136 .56702 .81575 .57231 .82616 .56909 .82179 .56369 Mtetra
.665 .759 .92 r
.82179 .56369 .82616 .56909 .83662 .56593 .83227 .56044 Mtetra
.662 .755 .919 r
.83227 .56044 .83662 .56593 .84712 .56282 .84279 .55727 Mtetra
.659 .753 .919 r
.84279 .55727 .84712 .56282 .85766 .55975 .85336 .55416 Mtetra
.657 .751 .919 r
.85336 .55416 .85766 .55975 .86824 .55671 .86397 .55109 Mtetra
.656 .75 .919 r
.86397 .55109 .86824 .55671 .87887 .55368 .87462 .54805 Mtetra
.655 .75 .92 r
.87462 .54805 .87887 .55368 .88953 .55066 .88532 .54501 Mtetra
.88532 .54501 .88953 .55066 .90024 .54764 .89605 .54198 Mtetra
.89605 .54198 .90024 .54764 .91098 .54461 .90682 .53894 Mtetra
.655 .751 .92 r
.90682 .53894 .91098 .54461 .92177 .54157 .91764 .53588 Mtetra
.91764 .53588 .92177 .54157 .93259 .53852 .92849 .53281 Mtetra
.92849 .53281 .93259 .53852 .94345 .53545 .93938 .52973 Mtetra
.93938 .52973 .94345 .53545 .95436 .53237 .95032 .52662 Mtetra
.95032 .52662 .95436 .53237 .9653 .52927 .96129 .5235 Mtetra
.96129 .5235 .9653 .52927 .97628 .52616 .9723 .52037 Mtetra
.656 .751 .92 r
.38018 .68308 .38561 .68781 .39459 .68524 .38918 .6805 Mtetra
.656 .752 .92 r
.38918 .6805 .39459 .68524 .40359 .68266 .3982 .6779 Mtetra
.3982 .6779 .40359 .68266 .41263 .68006 .40726 .6753 Mtetra
.656 .752 .921 r
.40726 .6753 .41263 .68006 .4217 .67746 .41635 .67268 Mtetra
.657 .753 .921 r
.41635 .67268 .4217 .67746 .4308 .67484 .42547 .67005 Mtetra
.42547 .67005 .4308 .67484 .43993 .6722 .43462 .6674 Mtetra
.43462 .6674 .43993 .6722 .44909 .66955 .4438 .66474 Mtetra
.4438 .66474 .44909 .66955 .45829 .6669 .45301 .66207 Mtetra
.45301 .66207 .45829 .6669 .46751 .66425 .46226 .65939 Mtetra
.656 .752 .921 r
.46226 .65939 .46751 .66425 .47676 .66161 .47153 .65674 Mtetra
.654 .752 .922 r
.47153 .65674 .47676 .66161 .48605 .659 .48084 .6541 Mtetra
.652 .751 .923 r
.48084 .6541 .48605 .659 .49537 .65643 .49017 .65152 Mtetra
.648 .75 .924 r
.49017 .65152 .49537 .65643 .50471 .65392 .49954 .64901 Mtetra
.643 .75 .926 r
.49954 .64901 .50471 .65392 .5141 .65148 .50894 .6466 Mtetra
.638 .749 .929 r
.50894 .6466 .5141 .65148 .52351 .64913 .51838 .64429 Mtetra
.632 .75 .933 r
.51838 .64429 .52351 .64913 .53296 .64686 .52785 .64208 Mtetra
.626 .752 .937 r
.52785 .64208 .53296 .64686 .54244 .64464 .53736 .63996 Mtetra
.624 .756 .941 r
.53736 .63996 .54244 .64464 .55196 .64242 .5469 .63786 Mtetra
.625 .762 .945 r
.5469 .63786 .55196 .64242 .56152 .64014 .55648 .63571 Mtetra
.632 .771 .947 r
.55648 .63571 .56152 .64014 .57111 .63772 .56609 .63338 Mtetra
.644 .779 .945 r
.56609 .63338 .57111 .63772 .58073 .63507 .57574 .63077 Mtetra
.663 .786 .94 r
.57574 .63077 .58073 .63507 .59038 .63212 .58541 .62775 Mtetra
.683 .789 .931 r
.58541 .62775 .59038 .63212 .60005 .62882 .5951 .62426 Mtetra
.699 .786 .918 r
.5951 .62426 .60005 .62882 .60975 .62522 .60482 .62034 Mtetra
.711 .777 .904 r
.60482 .62034 .60975 .62522 .61947 .62136 .61455 .61606 Mtetra
.713 .762 .891 r
.61455 .61606 .61947 .62136 .62921 .61742 .62431 .61164 Mtetra
.708 .745 .88 r
.62431 .61164 .62921 .61742 .63899 .61353 .63409 .60729 Mtetra
.696 .726 .874 r
.63409 .60729 .63899 .61353 .6488 .60989 .64391 .60328 Mtetra
.678 .71 .872 r
.64391 .60328 .6488 .60989 .65865 .60661 .65378 .59979 Mtetra
.657 .696 .875 r
.65378 .59979 .65865 .60661 .66856 .60377 .66371 .59693 Mtetra
.635 .687 .882 r
.66371 .59693 .66856 .60377 .67852 .60139 .6737 .59472 Mtetra
.614 .685 .893 r
.6737 .59472 .67852 .60139 .68854 .59937 .68375 .59303 Mtetra
.597 .69 .907 r
.68375 .59303 .68854 .59937 .69862 .5976 .69387 .59169 Mtetra
.59 .703 .921 r
.69387 .59169 .69862 .5976 .70873 .59589 .70403 .59042 Mtetra
.59 .721 .934 r
.70403 .59042 .70873 .59589 .71889 .59409 .71423 .58902 Mtetra
.602 .743 .943 r
.71423 .58902 .71889 .59409 .72908 .59205 .72446 .58725 Mtetra
.619 .762 .948 r
.72446 .58725 .72908 .59205 .73928 .58969 .7347 .58505 Mtetra
.639 .777 .947 r
.7347 .58505 .73928 .58969 .74951 .58699 .74496 .58238 Mtetra
.657 .785 .942 r
.74496 .58238 .74951 .58699 .75975 .58398 .75523 .5793 Mtetra
.67 .787 .937 r
.75523 .5793 .75975 .58398 .77001 .58074 .76551 .57593 Mtetra
.677 .785 .931 r
.76551 .57593 .77001 .58074 .7803 .57734 .77581 .57237 Mtetra
.679 .78 .926 r
.77581 .57237 .7803 .57734 .79061 .57388 .78615 .56875 Mtetra
.679 .774 .922 r
.78615 .56875 .79061 .57388 .80097 .57042 .79652 .56515 Mtetra
.675 .768 .92 r
.79652 .56515 .80097 .57042 .81136 .56702 .80693 .56164 Mtetra
.671 .763 .919 r
.80693 .56164 .81136 .56702 .82179 .56369 .81739 .55823 Mtetra
.666 .759 .919 r
.81739 .55823 .82179 .56369 .83227 .56044 .82789 .55493 Mtetra
.663 .756 .919 r
.82789 .55493 .83227 .56044 .84279 .55727 .83844 .55172 Mtetra
.659 .754 .92 r
.83844 .55172 .84279 .55727 .85336 .55416 .84903 .54858 Mtetra
.657 .753 .92 r
.84903 .54858 .85336 .55416 .86397 .55109 .85967 .54549 Mtetra
.656 .752 .921 r
.85967 .54549 .86397 .55109 .87462 .54805 .87035 .54243 Mtetra
.655 .752 .921 r
.87035 .54243 .87462 .54805 .88532 .54501 .88108 .53938 Mtetra
.654 .752 .922 r
.88108 .53938 .88532 .54501 .89605 .54198 .89184 .53633 Mtetra
.89184 .53633 .89605 .54198 .90682 .53894 .90264 .53327 Mtetra
.655 .752 .922 r
.90264 .53327 .90682 .53894 .91764 .53588 .91348 .53019 Mtetra
.655 .752 .921 r
.91348 .53019 .91764 .53588 .92849 .53281 .92437 .52709 Mtetra
.92437 .52709 .92849 .53281 .93938 .52973 .93529 .52398 Mtetra
.93529 .52398 .93938 .52973 .95032 .52662 .94625 .52085 Mtetra
.656 .752 .921 r
.94625 .52085 .95032 .52662 .96129 .5235 .95725 .5177 Mtetra
.656 .752 .92 r
.95725 .5177 .96129 .5235 .9723 .52037 .96829 .51454 Mtetra
.655 .751 .92 r
.37472 .67831 .38018 .68308 .38918 .6805 .38373 .67573 Mtetra
.655 .752 .921 r
.38373 .67573 .38918 .6805 .3982 .6779 .39278 .67313 Mtetra
.39278 .67313 .3982 .6779 .40726 .6753 .40186 .67053 Mtetra
.656 .753 .922 r
.40186 .67053 .40726 .6753 .41635 .67268 .41096 .66791 Mtetra
.656 .754 .922 r
.41096 .66791 .41635 .67268 .42547 .67005 .4201 .66527 Mtetra
.4201 .66527 .42547 .67005 .43462 .6674 .42927 .66262 Mtetra
.656 .755 .922 r
.42927 .66262 .43462 .6674 .4438 .66474 .43847 .65995 Mtetra
.656 .755 .923 r
.43847 .65995 .4438 .66474 .45301 .66207 .4477 .65727 Mtetra
.656 .756 .923 r
.4477 .65727 .45301 .66207 .46226 .65939 .45697 .65458 Mtetra
.656 .755 .923 r
.45697 .65458 .46226 .65939 .47153 .65674 .46626 .6519 Mtetra
.654 .755 .924 r
.46626 .6519 .47153 .65674 .48084 .6541 .47559 .64924 Mtetra
.652 .754 .924 r
.47559 .64924 .48084 .6541 .49017 .65152 .48495 .64663 Mtetra
.648 .752 .925 r
.48495 .64663 .49017 .65152 .49954 .64901 .49434 .64409 Mtetra
.643 .75 .927 r
.49434 .64409 .49954 .64901 .50894 .6466 .50376 .64165 Mtetra
.637 .748 .929 r
.50376 .64165 .50894 .6466 .51838 .64429 .51322 .63934 Mtetra
.631 .747 .931 r
.51322 .63934 .51838 .64429 .52785 .64208 .52271 .63716 Mtetra
.624 .746 .935 r
.52271 .63716 .52785 .64208 .53736 .63996 .53223 .6351 Mtetra
.62 .748 .938 r
.53223 .6351 .53736 .63996 .5469 .63786 .5418 .63309 Mtetra
.62 .753 .941 r
.5418 .63309 .5469 .63786 .55648 .63571 .5514 .63105 Mtetra
.628 .761 .942 r
.5514 .63105 .55648 .63571 .56609 .63338 .56104 .62881 Mtetra
.643 .77 .94 r
.56104 .62881 .56609 .63338 .57574 .63077 .57071 .62625 Mtetra
.665 .779 .934 r
.57071 .62625 .57574 .63077 .58541 .62775 .5804 .62318 Mtetra
.689 .784 .923 r
.5804 .62318 .58541 .62775 .5951 .62426 .59012 .61951 Mtetra
.71 .782 .908 r
.59012 .61951 .5951 .62426 .60482 .62034 .59985 .61526 Mtetra
.724 .773 .892 r
.59985 .61526 .60482 .62034 .61455 .61606 .6096 .61051 Mtetra
.727 .758 .877 r
.6096 .61051 .61455 .61606 .62431 .61164 .61937 .60556 Mtetra
.721 .74 .866 r
.61937 .60556 .62431 .61164 .63409 .60729 .62916 .60068 Mtetra
.705 .719 .86 r
.62916 .60068 .63409 .60729 .64391 .60328 .63899 .59624 Mtetra
.683 .7 .859 r
.63899 .59624 .64391 .60328 .65378 .59979 .64887 .5925 Mtetra
.656 .683 .864 r
.64887 .5925 .65378 .59979 .66371 .59693 .65881 .58962 Mtetra
.627 .671 .873 r
.65881 .58962 .66371 .59693 .6737 .59472 .66883 .58762 Mtetra
.6 .667 .886 r
.66883 .58762 .6737 .59472 .68375 .59303 .67892 .58632 Mtetra
.578 .67 .902 r
.67892 .58632 .68375 .59303 .69387 .59169 .68908 .58547 Mtetra
.569 .684 .918 r
.68908 .58547 .69387 .59169 .70403 .59042 .69929 .5847 Mtetra
.571 .704 .932 r
.69929 .5847 .70403 .59042 .71423 .58902 .70954 .58373 Mtetra
.589 .73 .941 r
.70954 .58373 .71423 .58902 .72446 .58725 .7198 .58227 Mtetra
.613 .753 .945 r
.7198 .58227 .72446 .58725 .7347 .58505 .73008 .58022 Mtetra
.64 .77 .942 r
.73008 .58022 .7347 .58505 .74496 .58238 .74037 .57756 Mtetra
.661 .779 .936 r
.74037 .57756 .74496 .58238 .75523 .5793 .75066 .57439 Mtetra
.675 .78 .929 r
.75066 .57439 .75523 .5793 .76551 .57593 .76096 .57088 Mtetra
.683 .778 .923 r
.76096 .57088 .76551 .57593 .77581 .57237 .77129 .56717 Mtetra
.684 .773 .919 r
.77129 .56717 .77581 .57237 .78615 .56875 .78164 .56343 Mtetra
.682 .768 .917 r
.78164 .56343 .78615 .56875 .79652 .56515 .79203 .55973 Mtetra
.677 .763 .916 r
.79203 .55973 .79652 .56515 .80693 .56164 .80247 .55615 Mtetra
.672 .76 .917 r
.80247 .55615 .80693 .56164 .81739 .55823 .81295 .55271 Mtetra
.666 .758 .918 r
.81295 .55271 .81739 .55823 .82789 .55493 .82348 .54939 Mtetra
.662 .756 .92 r
.82348 .54939 .82789 .55493 .83844 .55172 .83406 .54617 Mtetra
.659 .755 .921 r
.83406 .54617 .83844 .55172 .84903 .54858 .84468 .54303 Mtetra
.656 .755 .923 r
.84468 .54303 .84903 .54858 .85967 .54549 .85535 .53993 Mtetra
.655 .755 .923 r
.85535 .53993 .85967 .54549 .87035 .54243 .86606 .53686 Mtetra
.655 .755 .924 r
.86606 .53686 .87035 .54243 .88108 .53938 .87681 .53379 Mtetra
.654 .755 .924 r
.87681 .53379 .88108 .53938 .89184 .53633 .88761 .53071 Mtetra
.655 .755 .923 r
.88761 .53071 .89184 .53633 .90264 .53327 .89844 .52761 Mtetra
.655 .754 .923 r
.89844 .52761 .90264 .53327 .91348 .53019 .90931 .5245 Mtetra
.90931 .5245 .91348 .53019 .92437 .52709 .92022 .52137 Mtetra
.656 .754 .922 r
.92022 .52137 .92437 .52709 .93529 .52398 .93117 .51821 Mtetra
.656 .753 .921 r
.93117 .51821 .93529 .52398 .94625 .52085 .94216 .51505 Mtetra
.94216 .51505 .94625 .52085 .95725 .5177 .95319 .51186 Mtetra
.656 .752 .921 r
.95319 .51186 .95725 .5177 .96829 .51454 .96426 .50866 Mtetra
.655 .751 .921 r
.36922 .67351 .37472 .67831 .38373 .67573 .37826 .67093 Mtetra
.655 .752 .921 r
.37826 .67093 .38373 .67573 .39278 .67313 .38732 .66834 Mtetra
.655 .752 .922 r
.38732 .66834 .39278 .67313 .40186 .67053 .39641 .66574 Mtetra
.655 .753 .922 r
.39641 .66574 .40186 .67053 .41096 .66791 .40554 .66312 Mtetra
.655 .754 .923 r
.40554 .66312 .41096 .66791 .4201 .66527 .4147 .66049 Mtetra
.655 .755 .923 r
.4147 .66049 .4201 .66527 .42927 .66262 .42389 .65784 Mtetra
.655 .756 .924 r
.42389 .65784 .42927 .66262 .43847 .65995 .43311 .65518 Mtetra
.655 .757 .925 r
.43311 .65518 .43847 .65995 .4477 .65727 .44236 .6525 Mtetra
.656 .758 .925 r
.44236 .6525 .4477 .65727 .45697 .65458 .45164 .64981 Mtetra
.655 .758 .925 r
.45164 .64981 .45697 .65458 .46626 .6519 .46096 .64711 Mtetra
.655 .758 .926 r
.46096 .64711 .46626 .6519 .47559 .64924 .47031 .64442 Mtetra
.653 .757 .926 r
.47031 .64442 .47559 .64924 .48495 .64663 .47969 .64177 Mtetra
.65 .755 .926 r
.47969 .64177 .48495 .64663 .49434 .64409 .4891 .63917 Mtetra
.645 .752 .927 r
.4891 .63917 .49434 .64409 .50376 .64165 .49854 .63667 Mtetra
.639 .749 .928 r
.49854 .63667 .50376 .64165 .51322 .63934 .50802 .63431 Mtetra
.632 .745 .929 r
.50802 .63431 .51322 .63934 .52271 .63716 .51753 .63209 Mtetra
.624 .742 .931 r
.51753 .63209 .52271 .63716 .53223 .6351 .52708 .63003 Mtetra
.619 .741 .933 r
.52708 .63003 .53223 .6351 .5418 .63309 .53666 .62806 Mtetra
.618 .743 .935 r
.53666 .62806 .5418 .63309 .5514 .63105 .54629 .6261 Mtetra
.625 .749 .936 r
.54629 .6261 .5514 .63105 .56104 .62881 .55595 .62396 Mtetra
.641 .759 .934 r
.55595 .62396 .56104 .62881 .57071 .62625 .56564 .62146 Mtetra
.666 .77 .927 r
.56564 .62146 .57071 .62625 .5804 .62318 .57536 .61837 Mtetra
.695 .777 .915 r
.57536 .61837 .5804 .62318 .59012 .61951 .5851 .61455 Mtetra
.72 .777 .898 r
.5851 .61455 .59012 .61951 .59985 .61526 .59485 .60996 Mtetra
.737 .77 .879 r
.59485 .60996 .59985 .61526 .6096 .61051 .60462 .60471 Mtetra
.74 .754 .863 r
.60462 .60471 .6096 .61051 .61937 .60556 .61439 .59916 Mtetra
.734 .734 .851 r
.61439 .59916 .61937 .60556 .62916 .60068 .62419 .59366 Mtetra
.715 .712 .846 r
.62419 .59366 .62916 .60068 .63899 .59624 .63402 .58872 Mtetra
.688 .69 .846 r
.63402 .58872 .63899 .59624 .64887 .5925 .64391 .58468 Mtetra
.655 .67 .852 r
.64391 .58468 .64887 .5925 .65881 .58962 .65387 .58179 Mtetra
.618 .654 .863 r
.65387 .58179 .65881 .58962 .66883 .58762 .66392 .58004 Mtetra
.584 .646 .878 r
.66392 .58004 .66883 .58762 .67892 .58632 .67404 .5792 Mtetra
.555 .648 .896 r
.67404 .5792 .67892 .58632 .68908 .58547 .68424 .57893 Mtetra
.544 .663 .914 r
.68424 .57893 .68908 .58547 .69929 .5847 .6945 .57873 Mtetra
.549 .687 .93 r
.6945 .57873 .69929 .5847 .70954 .58373 .7048 .57823 Mtetra
.576 .717 .939 r
.7048 .57823 .70954 .58373 .7198 .58227 .71511 .57706 Mtetra
.609 .743 .941 r
.71511 .57706 .7198 .58227 .73008 .58022 .72542 .57513 Mtetra
.641 .762 .936 r
.72542 .57513 .73008 .58022 .74037 .57756 .73573 .57246 Mtetra
.666 .77 .928 r
.73573 .57246 .74037 .57756 .75066 .57439 .74604 .56918 Mtetra
.68 .771 .92 r
.74604 .56918 .75066 .57439 .76096 .57088 .75637 .56554 Mtetra
.687 .769 .914 r
.75637 .56554 .76096 .57088 .77129 .56717 .76671 .56171 Mtetra
.686 .765 .912 r
.76671 .56171 .77129 .56717 .78164 .56343 .77709 .55789 Mtetra
.682 .762 .911 r
.77709 .55789 .78164 .56343 .79203 .55973 .78751 .55415 Mtetra
.676 .759 .913 r
.78751 .55415 .79203 .55973 .80247 .55615 .79797 .55057 Mtetra
.67 .757 .916 r
.79797 .55057 .80247 .55615 .81295 .55271 .80849 .54714 Mtetra
.665 .757 .919 r
.80849 .54714 .81295 .55271 .82348 .54939 .81905 .54385 Mtetra
.66 .757 .922 r
.81905 .54385 .82348 .54939 .83406 .54617 .82966 .54065 Mtetra
.658 .757 .924 r
.82966 .54065 .83406 .54617 .84468 .54303 .84031 .53752 Mtetra
.656 .758 .925 r
.84031 .53752 .84468 .54303 .85535 .53993 .85101 .53441 Mtetra
.655 .758 .926 r
.85101 .53441 .85535 .53993 .86606 .53686 .86175 .53131 Mtetra
.86175 .53131 .86606 .53686 .87681 .53379 .87253 .52821 Mtetra
.655 .758 .925 r
.87253 .52821 .87681 .53379 .88761 .53071 .88335 .52509 Mtetra
.655 .757 .925 r
.88335 .52509 .88761 .53071 .89844 .52761 .89421 .52195 Mtetra
.656 .756 .924 r
.89421 .52195 .89844 .52761 .90931 .5245 .90511 .5188 Mtetra
.656 .755 .923 r
.90511 .5188 .90931 .5245 .92022 .52137 .91604 .51562 Mtetra
.656 .755 .922 r
.91604 .51562 .92022 .52137 .93117 .51821 .92702 .51242 Mtetra
.657 .754 .922 r
.92702 .51242 .93117 .51821 .94216 .51505 .93804 .50921 Mtetra
.657 .753 .921 r
.93804 .50921 .94216 .51505 .95319 .51186 .9491 .50599 Mtetra
.657 .753 .92 r
.9491 .50599 .95319 .51186 .96426 .50866 .9602 .50275 Mtetra
.654 .751 .921 r
.36369 .66869 .36922 .67351 .37826 .67093 .37274 .66611 Mtetra
.654 .752 .922 r
.37274 .66611 .37826 .67093 .38732 .66834 .38183 .66352 Mtetra
.38183 .66352 .38732 .66834 .39641 .66574 .39094 .66092 Mtetra
.653 .753 .923 r
.39094 .66092 .39641 .66574 .40554 .66312 .40008 .65832 Mtetra
.653 .754 .924 r
.40008 .65832 .40554 .66312 .4147 .66049 .40926 .6557 Mtetra
.653 .756 .925 r
.40926 .6557 .4147 .66049 .42389 .65784 .41847 .65307 Mtetra
.654 .757 .926 r
.41847 .65307 .42389 .65784 .43311 .65518 .42771 .65042 Mtetra
.654 .758 .926 r
.42771 .65042 .43311 .65518 .44236 .6525 .43698 .64776 Mtetra
.654 .76 .927 r
.43698 .64776 .44236 .6525 .45164 .64981 .44628 .64507 Mtetra
.655 .761 .928 r
.44628 .64507 .45164 .64981 .46096 .64711 .45562 .64237 Mtetra
.45562 .64237 .46096 .64711 .47031 .64442 .46499 .63965 Mtetra
.654 .761 .928 r
.46499 .63965 .47031 .64442 .47969 .64177 .47439 .63695 Mtetra
.652 .759 .928 r
.47439 .63695 .47969 .64177 .4891 .63917 .48382 .63427 Mtetra
.649 .755 .927 r
.48382 .63427 .4891 .63917 .49854 .63667 .49329 .63167 Mtetra
.643 .75 .927 r
.49329 .63167 .49854 .63667 .50802 .63431 .50279 .62919 Mtetra
.636 .744 .926 r
.50279 .62919 .50802 .63431 .51753 .63209 .51232 .62687 Mtetra
.628 .738 .927 r
.51232 .62687 .51753 .63209 .52708 .63003 .52189 .62473 Mtetra
.621 .734 .927 r
.52189 .62473 .52708 .63003 .53666 .62806 .53149 .62274 Mtetra
.617 .732 .928 r
.53149 .62274 .53666 .62806 .54629 .6261 .54114 .62082 Mtetra
.623 .736 .928 r
.54114 .62082 .54629 .6261 .55595 .62396 .55082 .61876 Mtetra
.638 .745 .926 r
.55082 .61876 .55595 .62396 .56564 .62146 .56054 .61636 Mtetra
.666 .758 .919 r
.56054 .61636 .56564 .62146 .57536 .61837 .57028 .61329 Mtetra
.698 .768 .906 r
.57028 .61329 .57536 .61837 .5851 .61455 .58004 .60933 Mtetra
.728 .771 .887 r
.58004 .60933 .5851 .61455 .59485 .60996 .58982 .60442 Mtetra
.748 .765 .866 r
.58982 .60442 .59485 .60996 .60462 .60471 .59959 .59862 Mtetra
.753 .749 .848 r
.59959 .59862 .60462 .60471 .61439 .59916 .60938 .59239 Mtetra
.746 .728 .835 r
.60938 .59239 .61439 .59916 .62419 .59366 .61918 .58616 Mtetra
.724 .703 .83 r
.61918 .58616 .62419 .59366 .63402 .58872 .62901 .58064 Mtetra
.693 .679 .831 r
.62901 .58064 .63402 .58872 .64391 .58468 .63891 .57625 Mtetra
.653 .655 .839 r
.63891 .57625 .64391 .58468 .65387 .58179 .64888 .57334 Mtetra
.608 .635 .852 r
.64888 .57334 .65387 .58179 .66392 .58004 .65895 .57189 Mtetra
.565 .623 .868 r
.65895 .57189 .66392 .58004 .67404 .5792 .66912 .5716 Mtetra
.529 .622 .888 r
.66912 .5716 .67404 .5792 .68424 .57893 .67937 .57202 Mtetra
.517 .638 .908 r
.67937 .57202 .68424 .57893 .6945 .57873 .68967 .57246 Mtetra
.526 .666 .925 r
.68967 .57246 .6945 .57873 .7048 .57823 .70002 .57247 Mtetra
.563 .703 .935 r
.70002 .57247 .7048 .57823 .71511 .57706 .71036 .5716 Mtetra
.606 .733 .935 r
.71036 .5716 .71511 .57706 .72542 .57513 .72071 .56976 Mtetra
.644 .752 .928 r
.72071 .56976 .72542 .57513 .73573 .57246 .73104 .56703 Mtetra
.671 .76 .917 r
.73104 .56703 .73573 .57246 .74604 .56918 .74137 .56362 Mtetra
.684 .76 .909 r
.74137 .56362 .74604 .56918 .75637 .56554 .75172 .55986 Mtetra
.688 .758 .905 r
.75172 .55986 .75637 .56554 .76671 .56171 .76208 .55595 Mtetra
.685 .755 .904 r
.76208 .55595 .76671 .56171 .77709 .55789 .77249 .55211 Mtetra
.68 .753 .907 r
.77249 .55211 .77709 .55789 .78751 .55415 .78294 .54841 Mtetra
.673 .753 .911 r
.78294 .54841 .78751 .55415 .79797 .55057 .79344 .5449 Mtetra
.667 .754 .916 r
.79344 .5449 .79797 .55057 .80849 .54714 .80399 .54155 Mtetra
.661 .756 .92 r
.80399 .54155 .80849 .54714 .81905 .54385 .81459 .53832 Mtetra
.658 .758 .924 r
.81459 .53832 .81905 .54385 .82966 .54065 .82523 .53517 Mtetra
.656 .76 .926 r
.82523 .53517 .82966 .54065 .84031 .53752 .83592 .53205 Mtetra
.655 .761 .928 r
.83592 .53205 .84031 .53752 .85101 .53441 .84665 .52894 Mtetra
.84665 .52894 .85101 .53441 .86175 .53131 .85742 .52581 Mtetra
.655 .761 .927 r
.85742 .52581 .86175 .53131 .87253 .52821 .86822 .52266 Mtetra
.656 .76 .927 r
.86822 .52266 .87253 .52821 .88335 .52509 .87907 .51948 Mtetra
.656 .759 .926 r
.87907 .51948 .88335 .52509 .89421 .52195 .88995 .51629 Mtetra
.657 .758 .924 r
.88995 .51629 .89421 .52195 .90511 .5188 .90088 .51308 Mtetra
.657 .757 .923 r
.90088 .51308 .90511 .5188 .91604 .51562 .91184 .50984 Mtetra
.657 .756 .922 r
.91184 .50984 .91604 .51562 .92702 .51242 .92284 .5066 Mtetra
.657 .755 .922 r
.92284 .5066 .92702 .51242 .93804 .50921 .93389 .50334 Mtetra
.658 .754 .921 r
.93389 .50334 .93804 .50921 .9491 .50599 .94498 .50008 Mtetra
.658 .753 .92 r
.94498 .50008 .9491 .50599 .9602 .50275 .9561 .4968 Mtetra
.653 .751 .921 r
.35813 .66383 .36369 .66869 .37274 .66611 .3672 .66125 Mtetra
.653 .751 .922 r
.3672 .66125 .37274 .66611 .38183 .66352 .3763 .65866 Mtetra
.653 .752 .922 r
.3763 .65866 .38183 .66352 .39094 .66092 .38543 .65607 Mtetra
.652 .753 .923 r
.38543 .65607 .39094 .66092 .40008 .65832 .39459 .65347 Mtetra
.652 .754 .924 r
.39459 .65347 .40008 .65832 .40926 .6557 .40379 .65087 Mtetra
.652 .755 .925 r
.40379 .65087 .40926 .6557 .41847 .65307 .41301 .64826 Mtetra
.652 .756 .926 r
.41301 .64826 .41847 .65307 .42771 .65042 .42227 .64564 Mtetra
.652 .758 .927 r
.42227 .64564 .42771 .65042 .43698 .64776 .43157 .643 Mtetra
.652 .76 .928 r
.43157 .643 .43698 .64776 .44628 .64507 .44089 .64034 Mtetra
.653 .762 .929 r
.44089 .64034 .44628 .64507 .45562 .64237 .45025 .63764 Mtetra
.654 .763 .929 r
.45025 .63764 .45562 .64237 .46499 .63965 .45964 .63491 Mtetra
.655 .763 .929 r
.45964 .63491 .46499 .63965 .47439 .63695 .46906 .63216 Mtetra
.655 .762 .928 r
.46906 .63216 .47439 .63695 .48382 .63427 .47852 .6294 Mtetra
.653 .759 .927 r
.47852 .6294 .48382 .63427 .49329 .63167 .488 .62668 Mtetra
.65 .754 .926 r
.488 .62668 .49329 .63167 .50279 .62919 .49753 .62404 Mtetra
.643 .746 .924 r
.49753 .62404 .50279 .62919 .51232 .62687 .50708 .62155 Mtetra
.635 .738 .923 r
.50708 .62155 .51232 .62687 .52189 .62473 .51667 .61925 Mtetra
.627 .73 .921 r
.51667 .61925 .52189 .62473 .53149 .62274 .52629 .61715 Mtetra
.62 .724 .921 r
.52629 .61715 .53149 .62274 .54114 .62082 .53596 .61521 Mtetra
.623 .725 .92 r
.53596 .61521 .54114 .62082 .55082 .61876 .54566 .6132 Mtetra
.634 .731 .918 r
.54566 .6132 .55082 .61876 .56054 .61636 .5554 .6109 Mtetra
.663 .745 .911 r
.5554 .6109 .56054 .61636 .57028 .61329 .56516 .60789 Mtetra
.699 .758 .898 r
.56516 .60789 .57028 .61329 .58004 .60933 .57495 .60387 Mtetra
.734 .765 .878 r
.57495 .60387 .58004 .60933 .58982 .60442 .58474 .59866 Mtetra
.759 .761 .854 r
.58474 .59866 .58982 .60442 .59959 .59862 .59454 .59231 Mtetra
.766 .746 .835 r
.59454 .59231 .59959 .59862 .60938 .59239 .60433 .58534 Mtetra
.759 .725 .821 r
.60433 .58534 .60938 .59239 .61918 .58616 .61413 .57828 Mtetra
.735 .698 .816 r
.61413 .57828 .61918 .58616 .62901 .58064 .62397 .57207 Mtetra
.699 .671 .819 r
.62397 .57207 .62901 .58064 .63891 .57625 .63387 .56727 Mtetra
.652 .643 .828 r
.63387 .56727 .63891 .57625 .64888 .57334 .64385 .56433 Mtetra
.596 .617 .843 r
.64385 .56433 .64888 .57334 .65895 .57189 .65395 .56326 Mtetra
.542 .6 .861 r
.65395 .56326 .65895 .57189 .66912 .5716 .66415 .56361 Mtetra
.496 .595 .882 r
.66415 .56361 .66912 .5716 .67937 .57202 .67445 .56482 Mtetra
.484 .614 .904 r
.67445 .56482 .67937 .57202 .68967 .57246 .68481 .56596 Mtetra
.501 .647 .923 r
.68481 .56596 .68967 .57246 .70002 .57247 .69519 .5665 Mtetra
.552 .691 .932 r
.69519 .5665 .70002 .57247 .71036 .5716 .70558 .56588 Mtetra
.606 .725 .929 r
.70558 .56588 .71036 .5716 .72071 .56976 .71595 .56407 Mtetra
.649 .743 .918 r
.71595 .56407 .72071 .56976 .73104 .56703 .7263 .56124 Mtetra
.676 .75 .906 r
.7263 .56124 .73104 .56703 .74137 .56362 .73665 .55769 Mtetra
.685 .748 .899 r
.73665 .55769 .74137 .56362 .75172 .55986 .74702 .55384 Mtetra
.687 .747 .897 r
.74702 .55384 .75172 .55986 .76208 .55595 .75741 .54991 Mtetra
.682 .745 .899 r
.75741 .54991 .76208 .55595 .77249 .55211 .76785 .54614 Mtetra
.675 .746 .904 r
.76785 .54614 .77249 .55211 .78294 .54841 .77834 .54256 Mtetra
.667 .748 .911 r
.77834 .54256 .78294 .54841 .79344 .5449 .78888 .53919 Mtetra
.661 .752 .917 r
.78888 .53919 .79344 .5449 .80399 .54155 .79947 .53597 Mtetra
.657 .756 .923 r
.79947 .53597 .80399 .54155 .81459 .53832 .8101 .53283 Mtetra
.655 .759 .927 r
.8101 .53283 .81459 .53832 .82523 .53517 .82078 .52972 Mtetra
.654 .762 .929 r
.82078 .52972 .82523 .53517 .83592 .53205 .8315 .52661 Mtetra
.655 .763 .929 r
.8315 .52661 .83592 .53205 .84665 .52894 .84226 .52347 Mtetra
.656 .764 .929 r
.84226 .52347 .84665 .52894 .85742 .52581 .85305 .52029 Mtetra
.657 .763 .928 r
.85305 .52029 .85742 .52581 .86822 .52266 .86389 .51708 Mtetra
.658 .761 .926 r
.86389 .51708 .86822 .52266 .87907 .51948 .87476 .51384 Mtetra
.658 .76 .925 r
.87476 .51384 .87907 .51948 .88995 .51629 .88567 .51058 Mtetra
.658 .758 .924 r
.88567 .51058 .88995 .51629 .90088 .51308 .89662 .5073 Mtetra
.658 .757 .923 r
.89662 .5073 .90088 .51308 .91184 .50984 .90761 .50402 Mtetra
.658 .756 .922 r
.90761 .50402 .91184 .50984 .92284 .5066 .91864 .50073 Mtetra
.658 .755 .921 r
.91864 .50073 .92284 .5066 .93389 .50334 .92971 .49743 Mtetra
.658 .754 .92 r
.92971 .49743 .93389 .50334 .94498 .50008 .94083 .49412 Mtetra
.658 .753 .92 r
.94083 .49412 .94498 .50008 .9561 .4968 .95198 .4908 Mtetra
.653 .751 .922 r
.35253 .65894 .35813 .66383 .3672 .66125 .36162 .65635 Mtetra
.36162 .65635 .3672 .66125 .3763 .65866 .37074 .65375 Mtetra
.652 .751 .922 r
.37074 .65375 .3763 .65866 .38543 .65607 .37989 .65116 Mtetra
.652 .751 .923 r
.37989 .65116 .38543 .65607 .39459 .65347 .38907 .64856 Mtetra
.651 .752 .924 r
.38907 .64856 .39459 .65347 .40379 .65087 .39828 .64597 Mtetra
.65 .753 .925 r
.39828 .64597 .40379 .65087 .41301 .64826 .40753 .64338 Mtetra
.65 .754 .926 r
.40753 .64338 .41301 .64826 .42227 .64564 .41681 .64079 Mtetra
.65 .756 .927 r
.41681 .64079 .42227 .64564 .43157 .643 .42612 .63819 Mtetra
.65 .758 .929 r
.42612 .63819 .43157 .643 .44089 .64034 .43546 .63557 Mtetra
.651 .761 .93 r
.43546 .63557 .44089 .64034 .45025 .63764 .44484 .63291 Mtetra
.653 .764 .931 r
.44484 .63291 .45025 .63764 .45964 .63491 .45425 .63019 Mtetra
.655 .765 .931 r
.45425 .63019 .45964 .63491 .46906 .63216 .46369 .62742 Mtetra
.657 .766 .93 r
.46369 .62742 .46906 .63216 .47852 .6294 .47317 .62459 Mtetra
.658 .764 .928 r
.47317 .62459 .47852 .6294 .488 .62668 .48268 .62173 Mtetra
.657 .759 .925 r
.48268 .62173 .488 .62668 .49753 .62404 .49223 .61889 Mtetra
.653 .75 .921 r
.49223 .61889 .49753 .62404 .50708 .62155 .5018 .61616 Mtetra
.645 .74 .918 r
.5018 .61616 .50708 .62155 .51667 .61925 .51141 .61361 Mtetra
.636 .728 .914 r
.51141 .61361 .51667 .61925 .52629 .61715 .52106 .6113 Mtetra
.625 .717 .912 r
.52106 .6113 .52629 .61715 .53596 .61521 .53074 .60924 Mtetra
.624 .713 .91 r
.53074 .60924 .53596 .61521 .54566 .6132 .54046 .60723 Mtetra
.63 .716 .908 r
.54046 .60723 .54566 .6132 .5554 .6109 .55022 .60504 Mtetra
.658 .73 .902 r
.55022 .60504 .5554 .6109 .56516 .60789 .56001 .60214 Mtetra
.696 .746 .89 r
.56001 .60214 .56516 .60789 .57495 .60387 .56982 .59815 Mtetra
.738 .758 .869 r
.56982 .59815 .57495 .60387 .58474 .59866 .57964 .59271 Mtetra
.768 .757 .843 r
.57964 .59271 .58474 .59866 .59454 .59231 .58944 .58579 Mtetra
.778 .744 .822 r
.58944 .58579 .59454 .59231 .60433 .58534 .59925 .57802 Mtetra
.773 .723 .807 r
.59925 .57802 .60433 .58534 .61413 .57828 .60905 .57002 Mtetra
.746 .695 .803 r
.60905 .57002 .61413 .57828 .62397 .57207 .61888 .56301 Mtetra
.706 .664 .807 r
.61888 .56301 .62397 .57207 .63387 .56727 .62878 .55772 Mtetra
.65 .631 .818 r
.62878 .55772 .63387 .56727 .64385 .56433 .63878 .55476 Mtetra
.582 .599 .834 r
.63878 .55476 .64385 .56433 .65395 .56326 .64891 .55413 Mtetra
.516 .575 .854 r
.64891 .55413 .65395 .56326 .66415 .56361 .65915 .55524 Mtetra
.457 .565 .876 r
.65915 .55524 .66415 .56361 .67445 .56482 .6695 .55735 Mtetra
.447 .587 .899 r
.6695 .55735 .67445 .56482 .68481 .56596 .6799 .55926 Mtetra
.475 .628 .92 r
.6799 .55926 .68481 .56596 .69519 .5665 .69033 .56032 Mtetra
.544 .681 .928 r
.69033 .56032 .69519 .5665 .70558 .56588 .70075 .5599 Mtetra
.61 .718 .922 r
.70075 .5599 .70558 .56588 .71595 .56407 .71114 .55803 Mtetra
.655 .734 .907 r
.71114 .55803 .71595 .56407 .7263 .56124 .72151 .55504 Mtetra
.68 .738 .895 r
.72151 .55504 .7263 .56124 .73665 .55769 .73188 .55133 Mtetra
.685 .735 .889 r
.73188 .55133 .73665 .55769 .74702 .55384 .74227 .54744 Mtetra
.683 .734 .889 r
.74227 .54744 .74702 .55384 .75741 .54991 .75269 .5436 Mtetra
.675 .734 .895 r
.75269 .5436 .75741 .54991 .76785 .54614 .76317 .54 Mtetra
.666 .738 .904 r
.76317 .54 .76785 .54614 .77834 .54256 .7737 .53665 Mtetra
.659 .744 .913 r
.7737 .53665 .77834 .54256 .78888 .53919 .78429 .53348 Mtetra
.654 .751 .921 r
.78429 .53348 .78888 .53919 .79947 .53597 .79492 .53042 Mtetra
.652 .757 .927 r
.79492 .53042 .79947 .53597 .8101 .53283 .80559 .52738 Mtetra
.652 .762 .93 r
.80559 .52738 .8101 .53283 .82078 .52972 .81631 .52431 Mtetra
.654 .765 .931 r
.81631 .52431 .82078 .52972 .8315 .52661 .82706 .52118 Mtetra
.656 .766 .93 r
.82706 .52118 .8315 .52661 .84226 .52347 .83784 .51799 Mtetra
.658 .765 .929 r
.83784 .51799 .84226 .52347 .85305 .52029 .84866 .51474 Mtetra
.659 .764 .927 r
.84866 .51474 .85305 .52029 .86389 .51708 .85952 .51144 Mtetra
.66 .762 .925 r
.85952 .51144 .86389 .51708 .87476 .51384 .87041 .50812 Mtetra
.66 .76 .924 r
.87041 .50812 .87476 .51384 .88567 .51058 .88135 .50479 Mtetra
.66 .758 .922 r
.88135 .50479 .88567 .51058 .89662 .5073 .89232 .50146 Mtetra
.66 .756 .921 r
.89232 .50146 .89662 .5073 .90761 .50402 .90334 .49812 Mtetra
.659 .755 .921 r
.90334 .49812 .90761 .50402 .91864 .50073 .9144 .49478 Mtetra
.659 .754 .92 r
.9144 .49478 .91864 .50073 .92971 .49743 .9255 .49145 Mtetra
.659 .753 .92 r
.9255 .49145 .92971 .49743 .94083 .49412 .93665 .48811 Mtetra
.658 .753 .92 r
.93665 .48811 .94083 .49412 .95198 .4908 .94784 .48476 Mtetra
.653 .751 .921 r
.34689 .65403 .35253 .65894 .36162 .65635 .356 .65141 Mtetra
.653 .75 .921 r
.356 .65141 .36162 .65635 .37074 .65375 .36514 .64879 Mtetra
.652 .75 .922 r
.36514 .64879 .37074 .65375 .37989 .65116 .37431 .64618 Mtetra
.651 .75 .922 r
.37431 .64618 .37989 .65116 .38907 .64856 .38351 .64357 Mtetra
.65 .75 .922 r
.38351 .64357 .38907 .64856 .39828 .64597 .39274 .64098 Mtetra
.649 .75 .923 r
.39274 .64098 .39828 .64597 .40753 .64338 .40201 .6384 Mtetra
.648 .751 .924 r
.40201 .6384 .40753 .64338 .41681 .64079 .4113 .63584 Mtetra
.648 .753 .926 r
.4113 .63584 .41681 .64079 .42612 .63819 .42063 .63327 Mtetra
.647 .755 .928 r
.42063 .63327 .42612 .63819 .43546 .63557 .43 .6307 Mtetra
.648 .758 .929 r
.43 .6307 .43546 .63557 .44484 .63291 .43939 .62809 Mtetra
.65 .761 .93 r
.43939 .62809 .44484 .63291 .45425 .63019 .44882 .62543 Mtetra
.653 .764 .931 r
.44882 .62543 .45425 .63019 .46369 .62742 .45829 .62267 Mtetra
.658 .767 .93 r
.45829 .62267 .46369 .62742 .47317 .62459 .46779 .61981 Mtetra
.661 .767 .928 r
.46779 .61981 .47317 .62459 .48268 .62173 .47733 .61685 Mtetra
.665 .765 .925 r
.47733 .61685 .48268 .62173 .49223 .61889 .48689 .61381 Mtetra
.663 .757 .92 r
.48689 .61381 .49223 .61889 .5018 .61616 .4965 .6108 Mtetra
.658 .746 .915 r
.4965 .6108 .5018 .61616 .51141 .61361 .50613 .60792 Mtetra
.648 .731 .91 r
.50613 .60792 .51141 .61361 .52106 .6113 .51579 .60529 Mtetra
.636 .716 .906 r
.51579 .60529 .52106 .6113 .53074 .60924 .52549 .60298 Mtetra
.628 .706 .902 r
.52549 .60298 .53074 .60924 .54046 .60723 .53523 .60087 Mtetra
.628 .703 .9 r
.53523 .60087 .54046 .60723 .55022 .60504 .54501 .59877 Mtetra
.652 .715 .894 r
.54501 .59877 .55022 .60504 .56001 .60214 .55482 .59603 Mtetra
.69 .733 .884 r
.55482 .59603 .56001 .60214 .56982 .59815 .56466 .59218 Mtetra
.738 .751 .863 r
.56466 .59218 .56982 .59815 .57964 .59271 .5745 .58663 Mtetra
.776 .756 .835 r
.5745 .58663 .57964 .59271 .58944 .58579 .58432 .57925 Mtetra
.791 .747 .812 r
.58432 .57925 .58944 .58579 .59925 .57802 .59414 .57068 Mtetra
.788 .727 .796 r
.59414 .57068 .59925 .57802 .60905 .57002 .60394 .56168 Mtetra
.759 .698 .794 r
.60394 .56168 .60905 .57002 .61888 .56301 .61378 .55379 Mtetra
.715 .666 .8 r
.61378 .55379 .61888 .56301 .62878 .55772 .62368 .54795 Mtetra
.649 .627 .814 r
.62368 .54795 .62878 .55772 .63878 .55476 .63369 .54496 Mtetra
.565 .586 .834 r
.63369 .54496 .63878 .55476 .64891 .55413 .64384 .54484 Mtetra
.481 .554 .854 r
.64384 .54484 .64891 .55413 .65915 .55524 .65412 .54678 Mtetra
.406 .536 .874 r
.65412 .54678 .65915 .55524 .6695 .55735 .66452 .54987 Mtetra
.401 .563 .899 r
.66452 .54987 .6695 .55735 .6799 .55926 .67497 .55254 Mtetra
.448 .615 .921 r
.67497 .55254 .6799 .55926 .69033 .56032 .68544 .55402 Mtetra
.541 .677 .927 r
.68544 .55402 .69033 .56032 .70075 .5599 .69588 .55367 Mtetra
.619 .714 .913 r
.69588 .55367 .70075 .5599 .71114 .55803 .70628 .55161 Mtetra
.662 .724 .896 r
.70628 .55161 .71114 .55803 .72151 .55504 .71667 .54842 Mtetra
.682 .726 .883 r
.71667 .54842 .72151 .55504 .73188 .55133 .72705 .54458 Mtetra
.681 .722 .881 r
.72705 .54458 .73188 .55133 .74227 .54744 .73747 .54075 Mtetra
.675 .723 .885 r
.73747 .54075 .74227 .54744 .75269 .5436 .74794 .53712 Mtetra
.664 .726 .895 r
.74794 .53712 .75269 .5436 .76317 .54 .75846 .53381 Mtetra
.655 .733 .907 r
.75846 .53381 .76317 .54 .7737 .53665 .76904 .53076 Mtetra
.649 .743 .918 r
.76904 .53076 .7737 .53665 .78429 .53348 .77967 .52783 Mtetra
.646 .752 .926 r
.77967 .52783 .78429 .53348 .79492 .53042 .79035 .52494 Mtetra
.648 .76 .931 r
.79035 .52494 .79492 .53042 .80559 .52738 .80106 .52196 Mtetra
.651 .764 .932 r
.80106 .52196 .80559 .52738 .81631 .52431 .8118 .51889 Mtetra
.655 .767 .931 r
.8118 .51889 .81631 .52431 .82706 .52118 .82258 .5157 Mtetra
.659 .766 .929 r
.82258 .5157 .82706 .52118 .83784 .51799 .83339 .51242 Mtetra
.661 .765 .927 r
.83339 .51242 .83784 .51799 .84866 .51474 .84423 .50907 Mtetra
.662 .762 .924 r
.84423 .50907 .84866 .51474 .85952 .51144 .85511 .50569 Mtetra
.662 .759 .922 r
.85511 .50569 .85952 .51144 .87041 .50812 .86603 .50229 Mtetra
.662 .757 .921 r
.86603 .50229 .87041 .50812 .88135 .50479 .87699 .49889 Mtetra
.661 .755 .92 r
.87699 .49889 .88135 .50479 .89232 .50146 .88799 .4955 Mtetra
.66 .754 .919 r
.88799 .4955 .89232 .50146 .90334 .49812 .89904 .49213 Mtetra
.66 .753 .919 r
.89904 .49213 .90334 .49812 .9144 .49478 .91013 .48876 Mtetra
.659 .752 .919 r
.91013 .48876 .9144 .49478 .9255 .49145 .92126 .4854 Mtetra
.658 .752 .919 r
.92126 .4854 .9255 .49145 .93665 .48811 .93244 .48205 Mtetra
.93244 .48205 .93665 .48811 .94784 .48476 .94366 .47868 Mtetra
.654 .751 .921 r
.34122 .64908 .34689 .65403 .356 .65141 .35035 .64643 Mtetra
.654 .75 .921 r
.35035 .64643 .356 .65141 .36514 .64879 .35951 .64377 Mtetra
.653 .749 .92 r
.35951 .64377 .36514 .64879 .37431 .64618 .3687 .64112 Mtetra
.652 .748 .92 r
.3687 .64112 .37431 .64618 .38351 .64357 .37792 .63849 Mtetra
.651 .747 .92 r
.37792 .63849 .38351 .64357 .39274 .64098 .38717 .63587 Mtetra
.649 .747 .921 r
.38717 .63587 .39274 .64098 .40201 .6384 .39646 .63328 Mtetra
.647 .747 .922 r
.39646 .63328 .40201 .6384 .4113 .63584 .40577 .63073 Mtetra
.646 .747 .923 r
.40577 .63073 .4113 .63584 .42063 .63327 .41512 .62819 Mtetra
.644 .749 .925 r
.41512 .62819 .42063 .63327 .43 .6307 .4245 .62568 Mtetra
.645 .752 .927 r
.4245 .62568 .43 .6307 .43939 .62809 .43391 .62315 Mtetra
.646 .756 .929 r
.43391 .62315 .43939 .62809 .44882 .62543 .44336 .62057 Mtetra
.649 .761 .931 r
.44336 .62057 .44882 .62543 .45829 .62267 .45285 .61789 Mtetra
.655 .766 .931 r
.45285 .61789 .45829 .62267 .46779 .61981 .46237 .61506 Mtetra
.662 .77 .93 r
.46237 .61506 .46779 .61981 .47733 .61685 .47193 .61206 Mtetra
.67 .771 .926 r
.47193 .61206 .47733 .61685 .48689 .61381 .48152 .60885 Mtetra
.674 .766 .92 r
.48152 .60885 .48689 .61381 .4965 .6108 .49115 .60556 Mtetra
.674 .756 .913 r
.49115 .60556 .4965 .6108 .50613 .60792 .50081 .60227 Mtetra
.665 .739 .905 r
.50081 .60227 .50613 .60792 .51579 .60529 .5105 .59919 Mtetra
.651 .72 .899 r
.5105 .59919 .51579 .60529 .52549 .60298 .52022 .59647 Mtetra
.637 .702 .893 r
.52022 .59647 .52549 .60298 .53523 .60087 .52997 .59413 Mtetra
.627 .691 .891 r
.52997 .59413 .53523 .60087 .54501 .59877 .53977 .59205 Mtetra
.643 .699 .886 r
.53977 .59205 .54501 .59877 .55482 .59603 .5496 .58952 Mtetra
.678 .718 .879 r
.5496 .58952 .55482 .59603 .56466 .59218 .55946 .58597 Mtetra
.734 .744 .86 r
.55946 .58597 .56466 .59218 .5745 .58663 .56933 .5805 Mtetra
.781 .757 .831 r
.56933 .5805 .5745 .58663 .58432 .57925 .57918 .5728 Mtetra
.803 .752 .806 r
.57918 .5728 .58432 .57925 .59414 .57068 .589 .56351 Mtetra
.804 .735 .788 r
.589 .56351 .59414 .57068 .60394 .56168 .59881 .55346 Mtetra
.775 .706 .787 r
.59881 .55346 .60394 .56168 .61378 .55379 .60865 .54463 Mtetra
.727 .672 .796 r
.60865 .54463 .61378 .55379 .62368 .54795 .61855 .53818 Mtetra
.649 .628 .815 r
.61855 .53818 .62368 .54795 .63369 .54496 .62857 .53517 Mtetra
.544 .576 .837 r
.62857 .53517 .63369 .54496 .64384 .54484 .63875 .53561 Mtetra
.435 .532 .857 r
.63875 .53561 .64384 .54484 .65412 .54678 .64907 .53845 Mtetra
.34 .503 .874 r
.64907 .53845 .65412 .54678 .66452 .54987 .65952 .54254 Mtetra
.347 .54 .901 r
.65952 .54254 .66452 .54987 .67497 .55254 .67001 .5459 Mtetra
.426 .608 .924 r
.67001 .5459 .67497 .55254 .68544 .55402 .68051 .54766 Mtetra
.546 .679 .925 r
.68051 .54766 .68544 .55402 .69588 .55367 .69097 .5472 Mtetra
.633 .712 .904 r
.69097 .5472 .69588 .55367 .70628 .55161 .70138 .54478 Mtetra
.669 .715 .883 r
.70138 .54478 .70628 .55161 .71667 .54842 .71177 .54134 Mtetra
.682 .713 .872 r
.71177 .54134 .71667 .54842 .72705 .54458 .72218 .53744 Mtetra
.673 .709 .874 r
.72218 .53744 .72705 .54458 .73747 .54075 .73263 .5338 Mtetra
.662 .711 .884 r
.73263 .5338 .73747 .54075 .74794 .53712 .74315 .53054 Mtetra
.649 .719 .899 r
.74315 .53054 .74794 .53712 .75846 .53381 .75373 .52765 Mtetra
.639 .73 .914 r
.75373 .52765 .75846 .53381 .76904 .53076 .76436 .52498 Mtetra
.637 .744 .926 r
.76436 .52498 .76904 .53076 .77967 .52783 .77504 .52231 Mtetra
.639 .755 .933 r
.77504 .52231 .77967 .52783 .79035 .52494 .78576 .51954 Mtetra
.646 .764 .935 r
.78576 .51954 .79035 .52494 .80106 .52196 .7965 .51658 Mtetra
.653 .768 .933 r
.7965 .51658 .80106 .52196 .8118 .51889 .80727 .51343 Mtetra
.659 .768 .93 r
.80727 .51343 .8118 .51889 .82258 .5157 .81807 .51012 Mtetra
.663 .766 .926 r
.81807 .51012 .82258 .5157 .83339 .51242 .82889 .5067 Mtetra
.665 .762 .922 r
.82889 .5067 .83339 .51242 .84423 .50907 .83976 .50324 Mtetra
.665 .758 .92 r
.83976 .50324 .84423 .50907 .85511 .50569 .85066 .49975 Mtetra
.664 .755 .918 r
.85066 .49975 .85511 .50569 .86603 .50229 .8616 .49628 Mtetra
.663 .753 .917 r
.8616 .49628 .86603 .50229 .87699 .49889 .87259 .49284 Mtetra
.662 .751 .917 r
.87259 .49284 .87699 .49889 .88799 .4955 .88362 .48942 Mtetra
.66 .75 .917 r
.88362 .48942 .88799 .4955 .89904 .49213 .8947 .48603 Mtetra
.659 .75 .917 r
.8947 .48603 .89904 .49213 .91013 .48876 .90582 .48265 Mtetra
.658 .75 .918 r
.90582 .48265 .91013 .48876 .92126 .4854 .91699 .47929 Mtetra
.658 .751 .919 r
.91699 .47929 .92126 .4854 .93244 .48205 .9282 .47593 Mtetra
.9282 .47593 .93244 .48205 .94366 .47868 .93945 .47256 Mtetra
.655 .751 .921 r
.33552 .6441 .34122 .64908 .35035 .64643 .34466 .6414 Mtetra
.655 .75 .92 r
.34466 .6414 .35035 .64643 .35951 .64377 .35384 .6387 Mtetra
.655 .749 .919 r
.35384 .6387 .35951 .64377 .3687 .64112 .36305 .636 Mtetra
.654 .747 .919 r
.36305 .636 .3687 .64112 .37792 .63849 .3723 .63332 Mtetra
.652 .746 .918 r
.3723 .63332 .37792 .63849 .38717 .63587 .38157 .63066 Mtetra
.65 .744 .918 r
.38157 .63066 .38717 .63587 .39646 .63328 .39087 .62804 Mtetra
.648 .743 .919 r
.39087 .62804 .39646 .63328 .40577 .63073 .40021 .62546 Mtetra
.646 .742 .92 r
.40021 .62546 .40577 .63073 .41512 .62819 .40957 .62293 Mtetra
.643 .742 .921 r
.40957 .62293 .41512 .62819 .4245 .62568 .41897 .62045 Mtetra
.641 .744 .923 r
.41897 .62045 .4245 .62568 .43391 .62315 .4284 .61799 Mtetra
.641 .747 .926 r
.4284 .61799 .43391 .62315 .44336 .62057 .43787 .61552 Mtetra
.644 .753 .929 r
.43787 .61552 .44336 .62057 .45285 .61789 .44738 .61297 Mtetra
.65 .76 .93 r
.44738 .61297 .45285 .61789 .46237 .61506 .45692 .61026 Mtetra
.659 .768 .93 r
.45692 .61026 .46237 .61506 .47193 .61206 .4665 .60731 Mtetra
.672 .775 .927 r
.4665 .60731 .47193 .61206 .48152 .60885 .47612 .60404 Mtetra
.682 .775 .922 r
.47612 .60404 .48152 .60885 .49115 .60556 .48577 .60053 Mtetra
.689 .769 .913 r
.48577 .60053 .49115 .60556 .50081 .60227 .49545 .59682 Mtetra
.684 .753 .904 r
.49545 .59682 .50081 .60227 .5105 .59919 .50517 .59321 Mtetra
.672 .732 .895 r
.50517 .59321 .5105 .59919 .52022 .59647 .51491 .5899 Mtetra
.652 .706 .887 r
.51491 .5899 .52022 .59647 .52997 .59413 .52468 .58713 Mtetra
.632 .686 .883 r
.52468 .58713 .52997 .59413 .53977 .59205 .53449 .58492 Mtetra
.636 .684 .879 r
.53449 .58492 .53977 .59205 .5496 .58952 .54435 .58258 Mtetra
.661 .7 .876 r
.54435 .58258 .5496 .58952 .55946 .58597 .55423 .57951 Mtetra
.723 .734 .86 r
.55423 .57951 .55946 .58597 .56933 .5805 .56412 .57439 Mtetra
.781 .758 .832 r
.56412 .57439 .56933 .5805 .57918 .5728 .574 .5667 Mtetra
.814 .763 .805 r
.574 .5667 .57918 .5728 .589 .56351 .58385 .55693 Mtetra
.823 .753 .785 r
.58385 .55693 .589 .56351 .59881 .55346 .59368 .54597 Mtetra
.796 .728 .788 r
.59368 .54597 .59881 .55346 .60865 .54463 .60352 .53625 Mtetra
.746 .695 .803 r
.60352 .53625 .60865 .54463 .61855 .53818 .61342 .52918 Mtetra
.652 .646 .831 r
.61342 .52918 .61855 .53818 .62857 .53517 .62346 .52615 Mtetra
.514 .579 .859 r
.62346 .52615 .62857 .53517 .63875 .53561 .63366 .52716 Mtetra
.365 .514 .874 r
.63366 .52716 .63875 .53561 .64907 .53845 .64403 .53085 Mtetra
.242 .469 .878 r
.64403 .53085 .64907 .53845 .65952 .54254 .65451 .53582 Mtetra
.282 .525 .908 r
.65451 .53582 .65952 .54254 .67001 .5459 .66504 .53961 Mtetra
.414 .617 .934 r
.66504 .53961 .67001 .5459 .68051 .54766 .67556 .54133 Mtetra
.564 .689 .924 r
.67556 .54133 .68051 .54766 .69097 .5472 .68601 .54046 Mtetra
.652 .712 .892 r
.68601 .54046 .69097 .5472 .70138 .54478 .69642 .53752 Mtetra
.674 .706 .871 r
.69642 .53752 .70138 .54478 .71177 .54134 .70682 .53384 Mtetra
.677 .7 .864 r
.70682 .53384 .71177 .54134 .72218 .53744 .71726 .53003 Mtetra
.66 .697 .873 r
.71726 .53003 .72218 .53744 .73263 .5338 .72776 .52679 Mtetra
.642 .702 .89 r
.72776 .52679 .73263 .5338 .74315 .53054 .73834 .52409 Mtetra
.629 .716 .909 r
.73834 .52409 .74315 .53054 .75373 .52765 .74897 .5217 Mtetra
.621 .732 .926 r
.74897 .5217 .75373 .52765 .76436 .52498 .75967 .51942 Mtetra
.627 .75 .935 r
.75967 .51942 .76436 .52498 .77504 .52231 .77039 .51693 Mtetra
.636 .761 .939 r
.77039 .51693 .77504 .52231 .78576 .51954 .78114 .51419 Mtetra
.649 .768 .936 r
.78114 .51419 .78576 .51954 .7965 .51658 .7919 .51112 Mtetra
.659 .769 .931 r
.7919 .51112 .7965 .51658 .80727 .51343 .80269 .50781 Mtetra
.665 .766 .925 r
.80269 .50781 .80727 .51343 .81807 .51012 .8135 .50433 Mtetra
.669 .761 .92 r
.8135 .50433 .81807 .51012 .82889 .5067 .82435 .50076 Mtetra
.669 .756 .916 r
.82435 .50076 .82889 .5067 .83976 .50324 .83523 .49718 Mtetra
.668 .753 .914 r
.83523 .49718 .83976 .50324 .85066 .49975 .84616 .49362 Mtetra
.665 .75 .913 r
.84616 .49362 .85066 .49975 .8616 .49628 .85713 .49011 Mtetra
.663 .748 .913 r
.85713 .49011 .8616 .49628 .87259 .49284 .86815 .48664 Mtetra
.661 .747 .914 r
.86815 .48664 .87259 .49284 .88362 .48942 .87921 .48322 Mtetra
.66 .747 .915 r
.87921 .48322 .88362 .48942 .8947 .48603 .89032 .47983 Mtetra
.658 .748 .916 r
.89032 .47983 .8947 .48603 .90582 .48265 .90148 .47646 Mtetra
.657 .749 .917 r
.90148 .47646 .90582 .48265 .91699 .47929 .91268 .47311 Mtetra
.657 .75 .918 r
.91268 .47311 .91699 .47929 .9282 .47593 .92392 .46975 Mtetra
.656 .751 .919 r
.92392 .46975 .9282 .47593 .93945 .47256 .93521 .46639 Mtetra
.657 .752 .92 r
.32977 .63908 .33552 .6441 .34466 .6414 .33894 .63634 Mtetra
.657 .75 .919 r
.33894 .63634 .34466 .6414 .35384 .6387 .34814 .63358 Mtetra
.656 .749 .918 r
.34814 .63358 .35384 .6387 .36305 .636 .35738 .63083 Mtetra
.656 .747 .917 r
.35738 .63083 .36305 .636 .3723 .63332 .36664 .62808 Mtetra
.655 .745 .916 r
.36664 .62808 .3723 .63332 .38157 .63066 .37593 .62535 Mtetra
.653 .742 .915 r
.37593 .62535 .38157 .63066 .39087 .62804 .38526 .62265 Mtetra
.65 .74 .915 r
.38526 .62265 .39087 .62804 .40021 .62546 .39461 .62001 Mtetra
.647 .737 .915 r
.39461 .62001 .40021 .62546 .40957 .62293 .404 .61744 Mtetra
.643 .735 .916 r
.404 .61744 .40957 .62293 .41897 .62045 .41342 .61496 Mtetra
.639 .735 .918 r
.41342 .61496 .41897 .62045 .4284 .61799 .42287 .61254 Mtetra
.636 .736 .921 r
.42287 .61254 .4284 .61799 .43787 .61552 .43235 .6102 Mtetra
.636 .741 .924 r
.43235 .6102 .43787 .61552 .44738 .61297 .44187 .60782 Mtetra
.64 .75 .929 r
.44187 .60782 .44738 .61297 .45692 .61026 .45143 .60533 Mtetra
.65 .762 .931 r
.45143 .60533 .45692 .61026 .4665 .60731 .46103 .60257 Mtetra
.667 .775 .93 r
.46103 .60257 .4665 .60731 .47612 .60404 .47067 .5994 Mtetra
.684 .784 .926 r
.47067 .5994 .47612 .60404 .48577 .60053 .48035 .59579 Mtetra
.702 .785 .915 r
.48035 .59579 .48577 .60053 .49545 .59682 .49006 .59172 Mtetra
.705 .772 .904 r
.49006 .59172 .49545 .59682 .50517 .59321 .4998 .5875 Mtetra
.699 .75 .891 r
.4998 .5875 .50517 .59321 .51491 .5899 .50957 .5834 Mtetra
.675 .718 .881 r
.50957 .5834 .51491 .5899 .52468 .58713 .51936 .57995 Mtetra
.644 .687 .875 r
.51936 .57995 .52468 .58713 .53449 .58492 .52919 .57737 Mtetra
.63 .672 .871 r
.52919 .57737 .53449 .58492 .54435 .58258 .53906 .57517 Mtetra
.637 .679 .873 r
.53906 .57517 .54435 .58258 .55423 .57951 .54896 .57278 Mtetra
.701 .721 .865 r
.54896 .57278 .55423 .57951 .56412 .57439 .55889 .56837 Mtetra
.773 .761 .842 r
.55889 .56837 .56412 .57439 .574 .5667 .5688 .56116 Mtetra
.823 .781 .813 r
.5688 .56116 .574 .5667 .58385 .55693 .57869 .55131 Mtetra
.844 .78 .789 r
.57869 .55131 .58385 .55693 .59368 .54597 .58853 .5397 Mtetra
.822 .762 .796 r
.58853 .5397 .59368 .54597 .60352 .53625 .59839 .52924 Mtetra
.771 .735 .82 r
.59839 .52924 .60352 .53625 .61342 .52918 .60831 .5216 Mtetra
.657 .684 .864 r
.60831 .5216 .61342 .52918 .62346 .52615 .61836 .51855 Mtetra
.462 .594 .898 r
.61836 .51855 .62346 .52615 .63366 .52716 .6286 .52008 Mtetra
.249 .493 .893 r
.6286 .52008 .63366 .52716 .64403 .53085 .63899 .52448 Mtetra
.098 .425 .869 r
.63899 .52448 .64403 .53085 .65451 .53582 .64952 .53006 Mtetra
.211 .523 .918 r
.64952 .53006 .65451 .53582 .66504 .53961 .66006 .53389 Mtetra
.425 .647 .951 r
.66006 .53389 .66504 .53961 .67556 .54133 .67057 .53508 Mtetra
.597 .708 .921 r
.67057 .53508 .67556 .54133 .68601 .54046 .68102 .53345 Mtetra
.674 .714 .878 r
.68102 .53345 .68601 .54046 .69642 .53752 .69141 .52979 Mtetra
.677 .695 .859 r
.69141 .52979 .69642 .53752 .70682 .53384 .70183 .52592 Mtetra
.665 .686 .859 r
.70183 .52592 .70682 .53384 .71726 .53003 .7123 .52244 Mtetra
.638 .684 .877 r
.7123 .52244 .71726 .53003 .72776 .52679 .72287 .51984 Mtetra
.613 .694 .901 r
.72287 .51984 .72776 .52679 .73834 .52409 .73351 .51791 Mtetra
.602 .716 .925 r
.73351 .51791 .73834 .52409 .74897 .5217 .74422 .5161 Mtetra
.602 .739 .941 r
.74422 .5161 .74897 .5217 .75967 .51942 .75496 .51415 Mtetra
.62 .761 .946 r
.75496 .51415 .75967 .51942 .77039 .51693 .76572 .51172 Mtetra
.639 .771 .943 r
.76572 .51172 .77039 .51693 .78114 .51419 .77649 .50884 Mtetra
.657 .773 .934 r
.77649 .50884 .78114 .51419 .7919 .51112 .78727 .50554 Mtetra
.669 .769 .925 r
.78727 .50554 .7919 .51112 .80269 .50781 .79806 .50196 Mtetra
.673 .761 .917 r
.79806 .50196 .80269 .50781 .8135 .50433 .80889 .49826 Mtetra
.674 .754 .911 r
.80889 .49826 .8135 .50433 .82435 .50076 .81975 .49452 Mtetra
.671 .748 .908 r
.81975 .49452 .82435 .50076 .83523 .49718 .83066 .49085 Mtetra
.668 .744 .907 r
.83066 .49085 .83523 .49718 .84616 .49362 .84161 .48724 Mtetra
.665 .742 .908 r
.84161 .48724 .84616 .49362 .85713 .49011 .85261 .48373 Mtetra
.662 .742 .91 r
.85261 .48373 .85713 .49011 .86815 .48664 .86367 .48029 Mtetra
.659 .743 .912 r
.86367 .48029 .86815 .48664 .87921 .48322 .87476 .4769 Mtetra
.658 .744 .914 r
.87476 .4769 .87921 .48322 .89032 .47983 .88591 .47354 Mtetra
.657 .746 .915 r
.88591 .47354 .89032 .47983 .90148 .47646 .8971 .4702 Mtetra
.656 .747 .917 r
.8971 .4702 .90148 .47646 .91268 .47311 .90834 .46687 Mtetra
.655 .748 .918 r
.90834 .46687 .91268 .47311 .92392 .46975 .91962 .46353 Mtetra
.655 .75 .919 r
.91962 .46353 .92392 .46975 .93521 .46639 .93095 .46018 Mtetra
.658 .752 .92 r
.32399 .63404 .32977 .63908 .33894 .63634 .33318 .63125 Mtetra
.658 .751 .919 r
.33318 .63125 .33894 .63634 .34814 .63358 .34241 .62845 Mtetra
.658 .75 .918 r
.34241 .62845 .34814 .63358 .35738 .63083 .35166 .62563 Mtetra
.658 .748 .917 r
.35166 .62563 .35738 .63083 .36664 .62808 .36094 .62282 Mtetra
.657 .746 .916 r
.36094 .62282 .36664 .62808 .37593 .62535 .37026 .62 Mtetra
.656 .744 .914 r
.37026 .62 .37593 .62535 .38526 .62265 .37961 .61721 Mtetra
.654 .74 .913 r
.37961 .61721 .38526 .62265 .39461 .62001 .38899 .61447 Mtetra
.65 .736 .912 r
.38899 .61447 .39461 .62001 .404 .61744 .3984 .6118 Mtetra
.645 .732 .912 r
.3984 .6118 .404 .61744 .41342 .61496 .40783 .60925 Mtetra
.64 .728 .912 r
.40783 .60925 .41342 .61496 .42287 .61254 .4173 .60682 Mtetra
.633 .726 .915 r
.4173 .60682 .42287 .61254 .43235 .6102 .4268 .60455 Mtetra
.63 .728 .919 r
.4268 .60455 .43235 .6102 .44187 .60782 .43634 .60233 Mtetra
.628 .735 .924 r
.43634 .60233 .44187 .60782 .45143 .60533 .44591 .6001 Mtetra
.637 .748 .929 r
.44591 .6001 .45143 .60533 .46103 .60257 .45552 .59765 Mtetra
.654 .766 .932 r
.45552 .59765 .46103 .60257 .47067 .5994 .46518 .59478 Mtetra
.679 .785 .93 r
.46518 .59478 .47067 .5994 .48035 .59579 .47488 .59129 Mtetra
.708 .796 .92 r
.47488 .59129 .48035 .59579 .49006 .59172 .48462 .58704 Mtetra
.724 .793 .907 r
.48462 .58704 .49006 .59172 .4998 .5875 .4944 .5823 Mtetra
.729 .775 .89 r
.4944 .5823 .4998 .5875 .50957 .5834 .50419 .5773 Mtetra
.705 .74 .879 r
.50419 .5773 .50957 .5834 .51936 .57995 .51401 .57291 Mtetra
.668 .701 .871 r
.51401 .57291 .51936 .57995 .52919 .57737 .52386 .56959 Mtetra
.633 .667 .865 r
.52386 .56959 .52919 .57737 .53906 .57517 .53374 .56731 Mtetra
.61 .656 .87 r
.53374 .56731 .53906 .57517 .54896 .57278 .54367 .56565 Mtetra
.667 .7 .871 r
.54367 .56565 .54896 .57278 .55889 .56837 .55362 .56234 Mtetra
.749 .757 .859 r
.55362 .56234 .55889 .56837 .5688 .56116 .56358 .55627 Mtetra
.823 .803 .833 r
.56358 .55627 .5688 .56116 .57869 .55131 .57351 .54706 Mtetra
.864 .82 .804 r
.57351 .54706 .57869 .55131 .58853 .5397 .5834 .5354 Mtetra
.854 .822 .817 r
.5834 .5354 .58853 .5397 .59839 .52924 .59328 .52461 Mtetra
.806 .815 .858 r
.59328 .52461 .59839 .52924 .60831 .5216 .60323 .5166 Mtetra
.656 .772 .935 r
.60323 .5166 .60831 .5216 .61836 .51855 .61331 .51352 Mtetra
.33 .626 .959 r
.61331 .51352 .61836 .51855 .6286 .52008 .62357 .5154 Mtetra
.012 .44 .866 r
.62357 .5154 .6286 .52008 .63899 .52448 .634 .52008 Mtetra
0 .358 .801 r
.634 .52008 .63899 .52448 .64952 .53006 .64454 .52567 Mtetra
.154 .551 .927 r
.64454 .52567 .64952 .53006 .66006 .53389 .65508 .52883 Mtetra
.481 .705 .968 r
.65508 .52883 .66006 .53389 .67057 .53508 .66556 .52882 Mtetra
.644 .727 .909 r
.66556 .52882 .67057 .53508 .68102 .53345 .67598 .52604 Mtetra
.695 .711 .86 r
.67598 .52604 .68102 .53345 .69141 .52979 .68636 .52158 Mtetra
.674 .682 .85 r
.68636 .52158 .69141 .52979 .70183 .52592 .6968 .51776 Mtetra
.643 .671 .862 r
.6968 .51776 .70183 .52592 .7123 .52244 .70733 .51498 Mtetra
.605 .675 .89 r
.70733 .51498 .7123 .52244 .72287 .51984 .71797 .5133 Mtetra
.571 .69 .922 r
.71797 .5133 .72287 .51984 .73351 .51791 .72869 .51224 Mtetra
.571 .724 .946 r
.72869 .51224 .73351 .51791 .74422 .5161 .73946 .51093 Mtetra
.588 .752 .956 r
.73946 .51093 .74422 .5161 .75496 .51415 .75024 .50911 Mtetra
.624 .773 .952 r
.75024 .50911 .75496 .51415 .76572 .51172 .76102 .50652 Mtetra
.653 .778 .94 r
.76102 .50652 .76572 .51172 .77649 .50884 .77179 .50329 Mtetra
.671 .772 .926 r
.77179 .50329 .77649 .50884 .78727 .50554 .78257 .49964 Mtetra
.68 .762 .914 r
.78257 .49964 .78727 .50554 .79806 .50196 .79338 .49574 Mtetra
.679 .752 .906 r
.79338 .49574 .79806 .50196 .80889 .49826 .80422 .49184 Mtetra
.677 .744 .902 r
.80422 .49184 .80889 .49826 .81975 .49452 .8151 .48798 Mtetra
.671 .739 .901 r
.8151 .48798 .81975 .49452 .83066 .49085 .82603 .48428 Mtetra
.666 .737 .903 r
.82603 .48428 .83066 .49085 .84161 .48724 .83702 .48071 Mtetra
.662 .737 .906 r
.83702 .48071 .84161 .48724 .85261 .48373 .84806 .47725 Mtetra
.659 .739 .909 r
.84806 .47725 .85261 .48373 .86367 .48029 .85915 .47388 Mtetra
.657 .741 .912 r
.85915 .47388 .86367 .48029 .87476 .4769 .87029 .47054 Mtetra
.655 .743 .915 r
.87029 .47054 .87476 .4769 .88591 .47354 .88147 .46723 Mtetra
.655 .745 .917 r
.88147 .46723 .88591 .47354 .8971 .4702 .8927 .46392 Mtetra
.654 .747 .918 r
.8927 .46392 .8971 .4702 .90834 .46687 .90397 .4606 Mtetra
.654 .749 .919 r
.90397 .4606 .90834 .46687 .91962 .46353 .91529 .45728 Mtetra
.654 .75 .92 r
.91529 .45728 .91962 .46353 .93095 .46018 .92665 .45393 Mtetra
.658 .752 .919 r
.31818 .62896 .32399 .63404 .33318 .63125 .32739 .62615 Mtetra
.32739 .62615 .33318 .63125 .34241 .62845 .33663 .62332 Mtetra
.659 .751 .918 r
.33663 .62332 .34241 .62845 .35166 .62563 .3459 .62046 Mtetra
.3459 .62046 .35166 .62563 .36094 .62282 .35521 .61759 Mtetra
.66 .749 .916 r
.35521 .61759 .36094 .62282 .37026 .62 .36455 .61469 Mtetra
.66 .747 .914 r
.36455 .61469 .37026 .62 .37961 .61721 .37392 .61179 Mtetra
.659 .743 .912 r
.37392 .61179 .37961 .61721 .38899 .61447 .38333 .6089 Mtetra
.656 .738 .91 r
.38333 .6089 .38899 .61447 .3984 .6118 .39276 .60608 Mtetra
.651 .732 .908 r
.39276 .60608 .3984 .6118 .40783 .60925 .40222 .60336 Mtetra
.644 .724 .907 r
.40222 .60336 .40783 .60925 .4173 .60682 .41171 .60082 Mtetra
.634 .718 .908 r
.41171 .60082 .4173 .60682 .4268 .60455 .42123 .59852 Mtetra
.626 .715 .91 r
.42123 .59852 .4268 .60455 .43634 .60233 .43078 .59639 Mtetra
.617 .716 .916 r
.43078 .59639 .43634 .60233 .44591 .6001 .44036 .59444 Mtetra
.62 .728 .924 r
.44036 .59444 .44591 .6001 .45552 .59765 .44999 .5924 Mtetra
.631 .747 .932 r
.44999 .5924 .45552 .59765 .46518 .59478 .45966 .59005 Mtetra
.66 .777 .936 r
.45966 .59005 .46518 .59478 .47488 .59129 .46938 .58697 Mtetra
.701 .804 .929 r
.46938 .58697 .47488 .59129 .48462 .58704 .47914 .58287 Mtetra
.736 .816 .914 r
.47914 .58287 .48462 .58704 .4944 .5823 .48895 .5778 Mtetra
.759 .807 .891 r
.48895 .5778 .4944 .5823 .50419 .5773 .49878 .57187 Mtetra
.743 .772 .876 r
.49878 .57187 .50419 .5773 .51401 .57291 .50863 .56626 Mtetra
.706 .725 .865 r
.50863 .56626 .51401 .57291 .52386 .56959 .5185 .56171 Mtetra
.646 .671 .859 r
.5185 .56171 .52386 .56959 .53374 .56731 .5284 .55899 Mtetra
.584 .634 .866 r
.5284 .55899 .53374 .56731 .54367 .56565 .53834 .55804 Mtetra
.614 .667 .877 r
.53834 .55804 .54367 .56565 .55362 .56234 .54832 .55623 Mtetra
.693 .742 .888 r
.54832 .55623 .55362 .56234 .56358 .55627 .55832 .55216 Mtetra
.803 .832 .873 r
.55832 .55216 .56358 .55627 .57351 .54706 .56831 .54453 Mtetra
.875 .882 .836 r
.56831 .54453 .57351 .54706 .5834 .5354 .57826 .5337 Mtetra
.878 .916 .849 r
.57826 .5337 .5834 .5354 .59328 .52461 .5882 .52323 Mtetra
.826 .945 .901 r
.5882 .52323 .59328 .52461 .60323 .5166 .59819 .51516 Mtetra
.552 .894 .981 r
.59819 .51516 .60323 .5166 .61331 .51352 .60831 .51207 Mtetra
0 .513 .773 r
.60831 .51207 .61331 .51352 .62357 .5154 .61861 .51397 Mtetra
.342 0 0 r
.61861 .51397 .62357 .5154 .634 .52008 .62905 .5183 Mtetra
.337 0 0 r
.62905 .5183 .634 .52008 .64454 .52567 .63958 .52301 Mtetra
.151 .629 .924 r
.63958 .52301 .64454 .52567 .65508 .52883 .65009 .52454 Mtetra
.589 .787 .974 r
.65009 .52454 .65508 .52883 .66556 .52882 .66052 .52248 Mtetra
.697 .744 .888 r
.66052 .52248 .66556 .52882 .67598 .52604 .67089 .51813 Mtetra
.711 .704 .842 r
.67089 .51813 .67598 .52604 .68636 .52158 .68125 .51291 Mtetra
.66 .666 .845 r
.68125 .51291 .68636 .52158 .6968 .51776 .69173 .50949 Mtetra
.603 .651 .871 r
.69173 .50949 .6968 .51776 .70733 .51498 .70235 .50792 Mtetra
.55 .663 .912 r
.70235 .50792 .70733 .51498 .71797 .5133 .71308 .50743 Mtetra
.51 .689 .948 r
.71308 .50743 .71797 .5133 .72869 .51224 .72388 .50728 Mtetra
.537 .741 .969 r
.72388 .50728 .72869 .51224 .73946 .51093 .7347 .50627 Mtetra
.586 .776 .97 r
.7347 .50627 .73946 .51093 .75024 .50911 .7455 .50427 Mtetra
.642 .79 .953 r
.7455 .50427 .75024 .50911 .76102 .50652 .75627 .50121 Mtetra
.676 .783 .931 r
.75627 .50121 .76102 .50652 .77179 .50329 .76704 .49741 Mtetra
.687 .766 .912 r
.76704 .49741 .77179 .50329 .78257 .49964 .77782 .49329 Mtetra
.689 .751 .899 r
.77782 .49329 .78257 .49964 .79338 .49574 .78863 .48907 Mtetra
.682 .739 .893 r
.78863 .48907 .79338 .49574 .80422 .49184 .79948 .48501 Mtetra
.676 .732 .893 r
.79948 .48501 .80422 .49184 .8151 .48798 .81039 .48115 Mtetra
.668 .729 .896 r
.81039 .48115 .8151 .48798 .82603 .48428 .82137 .47753 Mtetra
.661 .73 .9 r
.82137 .47753 .82603 .48428 .83702 .48071 .83239 .47408 Mtetra
.657 .733 .906 r
.83239 .47408 .83702 .48071 .84806 .47725 .84348 .47074 Mtetra
.654 .737 .91 r
.84348 .47074 .84806 .47725 .85915 .47388 .85461 .46747 Mtetra
.653 .741 .914 r
.85461 .46747 .85915 .47388 .87029 .47054 .86579 .4642 Mtetra
.652 .744 .917 r
.86579 .4642 .87029 .47054 .88147 .46723 .87701 .46094 Mtetra
.653 .747 .919 r
.87701 .46094 .88147 .46723 .8927 .46392 .88827 .45765 Mtetra
.653 .749 .92 r
.88827 .45765 .8927 .46392 .90397 .4606 .89958 .45433 Mtetra
.653 .75 .92 r
.89958 .45433 .90397 .4606 .91529 .45728 .91093 .45099 Mtetra
.654 .75 .921 r
.91093 .45099 .91529 .45728 .92665 .45393 .92232 .44763 Mtetra
.657 .752 .92 r
.31232 .62385 .31818 .62896 .32739 .62615 .32155 .62104 Mtetra
.658 .753 .92 r
.32155 .62104 .32739 .62615 .33663 .62332 .33081 .61821 Mtetra
.659 .753 .92 r
.33081 .61821 .33663 .62332 .3459 .62046 .34011 .61534 Mtetra
.66 .754 .92 r
.34011 .61534 .3459 .62046 .35521 .61759 .34943 .61244 Mtetra
.662 .754 .919 r
.34943 .61244 .35521 .61759 .36455 .61469 .3588 .60948 Mtetra
.663 .753 .917 r
.3588 .60948 .36455 .61469 .37392 .61179 .36819 .60648 Mtetra
.664 .75 .914 r
.36819 .60648 .37392 .61179 .38333 .6089 .37762 .60345 Mtetra
.663 .745 .912 r
.37762 .60345 .38333 .6089 .39276 .60608 .38708 .60045 Mtetra
.66 .739 .908 r
.38708 .60045 .39276 .60608 .40222 .60336 .39657 .5975 Mtetra
.652 .729 .905 r
.39657 .5975 .40222 .60336 .41171 .60082 .40609 .59474 Mtetra
.641 .719 .904 r
.40609 .59474 .41171 .60082 .42123 .59852 .41563 .59225 Mtetra
.629 .709 .904 r
.41563 .59225 .42123 .59852 .43078 .59639 .4252 .59006 Mtetra
.613 .702 .908 r
.4252 .59006 .43078 .59639 .44036 .59444 .43479 .58825 Mtetra
.605 .704 .914 r
.43479 .58825 .44036 .59444 .44999 .5924 .44443 .58656 Mtetra
.604 .718 .925 r
.44443 .58656 .44999 .5924 .45966 .59005 .4541 .58485 Mtetra
.63 .751 .935 r
.4541 .58485 .45966 .59005 .46938 .58697 .46383 .58246 Mtetra
.677 .792 .936 r
.46383 .58246 .46938 .58697 .47914 .58287 .47362 .57895 Mtetra
.733 .827 .923 r
.47362 .57895 .47914 .58287 .48895 .5778 .48345 .57397 Mtetra
.78 .835 .894 r
.48345 .57397 .48895 .5778 .49878 .57187 .49332 .56742 Mtetra
.783 .812 .876 r
.49332 .56742 .49878 .57187 .50863 .56626 .50321 .56054 Mtetra
.756 .767 .861 r
.50321 .56054 .50863 .56626 .5185 .56171 .51311 .55426 Mtetra
.678 .696 .859 r
.51311 .55426 .5185 .56171 .5284 .55899 .52302 .5505 Mtetra
.574 .626 .866 r
.52302 .5505 .5284 .55899 .53834 .55804 .53298 .54981 Mtetra
.552 .623 .876 r
.53298 .54981 .53834 .55804 .54832 .55623 .54298 .54959 Mtetra
.588 .688 .911 r
.54298 .54959 .54832 .55623 .55832 .55216 .55303 .54827 Mtetra
.726 .836 .932 r
.55303 .54827 .55832 .55216 .56831 .54453 .56309 .54336 Mtetra
.841 .947 .888 r
.56309 .54336 .56831 .54453 .57826 .5337 .57312 .53464 Mtetra
.81 .998 .847 r
.57312 .53464 .57826 .5337 .5882 .52323 .58314 .5255 Mtetra
.611 .942 .752 r
.58314 .5255 .5882 .52323 .59819 .51516 .59319 .51793 Mtetra
0 0 0 r
.59319 .51793 .59819 .51516 .60831 .51207 .60336 .51483 Mtetra
.394 0 0 r
.60336 .51483 .60831 .51207 .61861 .51397 .61369 .5162 Mtetra
.476 0 0 r
.61369 .5162 .61861 .51397 .62905 .5183 .62413 .51917 Mtetra
.372 0 0 r
.62413 .51917 .62905 .5183 .63958 .52301 .63463 .52173 Mtetra
.33 .791 .94 r
.63463 .52173 .63958 .52301 .65009 .52454 .64507 .52048 Mtetra
.72 .838 .937 r
.64507 .52048 .65009 .52454 .66052 .52248 .65542 .5156 Mtetra
.738 .741 .855 r
.65542 .5156 .66052 .52248 .67089 .51813 .66575 .50961 Mtetra
.713 .691 .828 r
.66575 .50961 .67089 .51813 .68125 .51291 .67612 .50408 Mtetra
.63 .65 .851 r
.67612 .50408 .68125 .51291 .69173 .50949 .68667 .50166 Mtetra
.53 .63 .895 r
.68667 .50166 .69173 .50949 .70235 .50792 .69739 .5018 Mtetra
.46 .656 .945 r
.69739 .5018 .70235 .50792 .71308 .50743 .70821 .50256 Mtetra
.434 .696 .975 r
.70821 .50256 .71308 .50743 .72388 .50728 .71908 .50301 Mtetra
.522 .767 .986 r
.71908 .50301 .72388 .50728 .7347 .50627 .72992 .50186 Mtetra
.615 .799 .97 r
.72992 .50186 .7347 .50627 .7455 .50427 .74071 .49922 Mtetra
.675 .794 .938 r
.74071 .49922 .7455 .50427 .75627 .50121 .75147 .49541 Mtetra
.7 .774 .909 r
.75147 .49541 .75627 .50121 .76704 .49741 .76222 .49091 Mtetra
.698 .75 .892 r
.76222 .49091 .76704 .49741 .77782 .49329 .77299 .48638 Mtetra
.692 .735 .884 r
.77299 .48638 .77782 .49329 .78863 .48907 .78382 .48197 Mtetra
.68 .726 .884 r
.78382 .48197 .78863 .48907 .79948 .48501 .7947 .47794 Mtetra
.67 .723 .889 r
.7947 .47794 .79948 .48501 .81039 .48115 .80566 .47422 Mtetra
.66 .725 .897 r
.80566 .47422 .81039 .48115 .82137 .47753 .81667 .47079 Mtetra
.654 .729 .905 r
.81667 .47079 .82137 .47753 .83239 .47408 .82775 .46753 Mtetra
.651 .735 .911 r
.82775 .46753 .83239 .47408 .84348 .47074 .83888 .46434 Mtetra
.649 .741 .916 r
.83888 .46434 .84348 .47074 .85461 .46747 .85005 .46118 Mtetra
.65 .746 .92 r
.85005 .46118 .85461 .46747 .86579 .4642 .86127 .45797 Mtetra
.65 .749 .922 r
.86127 .45797 .86579 .4642 .87701 .46094 .87252 .45473 Mtetra
.652 .751 .922 r
.87252 .45473 .87701 .46094 .88827 .45765 .88382 .45142 Mtetra
.653 .752 .922 r
.88382 .45142 .88827 .45765 .89958 .45433 .89516 .44808 Mtetra
.654 .752 .922 r
.89516 .44808 .89958 .45433 .91093 .45099 .90654 .44469 Mtetra
.655 .752 .921 r
.90654 .44469 .91093 .45099 .92232 .44763 .91796 .44128 Mtetra
.655 .751 .921 r
.30643 .61871 .31232 .62385 .32155 .62104 .31568 .61593 Mtetra
.655 .753 .922 r
.31568 .61593 .32155 .62104 .33081 .61821 .32495 .61313 Mtetra
.656 .755 .923 r
.32495 .61313 .33081 .61821 .34011 .61534 .33427 .61029 Mtetra
.658 .758 .923 r
.33427 .61029 .34011 .61534 .34943 .61244 .34361 .6074 Mtetra
.661 .76 .923 r
.34361 .6074 .34943 .61244 .3588 .60948 .35299 .60444 Mtetra
.664 .761 .922 r
.35299 .60444 .3588 .60948 .36819 .60648 .36241 .60139 Mtetra
.667 .76 .92 r
.36241 .60139 .36819 .60648 .37762 .60345 .37187 .59825 Mtetra
.669 .757 .916 r
.37187 .59825 .37762 .60345 .38708 .60045 .38136 .59506 Mtetra
.67 .751 .911 r
.38136 .59506 .38708 .60045 .39657 .5975 .39088 .59183 Mtetra
.665 .741 .906 r
.39088 .59183 .39657 .5975 .40609 .59474 .40042 .58873 Mtetra
.656 .727 .902 r
.40042 .58873 .40609 .59474 .41563 .59225 .41 .58586 Mtetra
.64 .71 .898 r
.41 .58586 .41563 .59225 .4252 .59006 .41959 .58338 Mtetra
.618 .693 .898 r
.41959 .58338 .4252 .59006 .43479 .58825 .42921 .58144 Mtetra
.599 .683 .901 r
.42921 .58144 .43479 .58825 .44443 .58656 .43885 .57997 Mtetra
.578 .682 .912 r
.43885 .57997 .44443 .58656 .4541 .58485 .44853 .57889 Mtetra
.59 .71 .927 r
.44853 .57889 .4541 .58485 .46383 .58246 .45826 .57745 Mtetra
.628 .76 .942 r
.45826 .57745 .46383 .58246 .47362 .57895 .46805 .57504 Mtetra
.705 .825 .939 r
.46805 .57504 .47362 .57895 .48345 .57397 .4779 .57079 Mtetra
.785 .863 .907 r
.4779 .57079 .48345 .57397 .49332 .56742 .48781 .56418 Mtetra
.818 .859 .878 r
.48781 .56418 .49332 .56742 .50321 .56054 .49774 .55618 Mtetra
.815 .818 .851 r
.49774 .55618 .50321 .56054 .51311 .55426 .50769 .5477 Mtetra
.731 .738 .856 r
.50769 .5477 .51311 .55426 .52302 .5505 .51763 .54217 Mtetra
.593 .639 .866 r
.51763 .54217 .52302 .5505 .53298 .54981 .52759 .54094 Mtetra
.495 .579 .869 r
.52759 .54094 .53298 .54981 .54298 .54959 .53761 .54211 Mtetra
.414 .579 .907 r
.53761 .54211 .54298 .54959 .55303 .54827 .5477 .54419 Mtetra
.512 .764 .987 r
.5477 .54419 .55303 .54827 .56309 .54336 .55783 .54322 Mtetra
.628 .953 .93 r
.55783 .54322 .56309 .54336 .57312 .53464 .56795 .53817 Mtetra
0 0 0 r
.56795 .53817 .57312 .53464 .58314 .5255 .57808 .53166 Mtetra
.57808 .53166 .58314 .5255 .59319 .51793 .58822 .52533 Mtetra
.292 0 .029 r
.58822 .52533 .59319 .51793 .60336 .51483 .59846 .52222 Mtetra
.454 .017 .118 r
.59846 .52222 .60336 .51483 .61369 .5162 .60881 .52233 Mtetra
.437 0 .053 r
.60881 .52233 .61369 .5162 .62413 .51917 .61923 .52263 Mtetra
.23 0 0 r
.61923 .52263 .62413 .51917 .63463 .52173 .62966 .52148 Mtetra
.631 .955 .927 r
.62966 .52148 .63463 .52173 .64507 .52048 .64001 .51622 Mtetra
.816 .842 .869 r
.64001 .51622 .64507 .52048 .65542 .5156 .65026 .50787 Mtetra
.759 .726 .822 r
.65026 .50787 .65542 .5156 .66575 .50961 .66055 .50042 Mtetra
.697 .672 .822 r
.66055 .50042 .66575 .50961 .67612 .50408 .67097 .49539 Mtetra
.569 .626 .869 r
.67097 .49539 .67612 .50408 .68667 .50166 .68161 .49473 Mtetra
.386 .586 .922 r
.68161 .49473 .68667 .50166 .69739 .5018 .69247 .49705 Mtetra
.307 .633 .964 r
.69247 .49705 .69739 .5018 .70821 .50256 .70338 .49893 Mtetra
.357 .715 .986 r
.70338 .49893 .70821 .50256 .71908 .50301 .71428 .49939 Mtetra
.549 .81 .994 r
.71428 .49939 .71908 .50301 .72992 .50186 .7251 .49746 Mtetra
.671 .821 .956 r
.7251 .49746 .72992 .50186 .74071 .49922 .73585 .49364 Mtetra
.71 .786 .911 r
.73585 .49364 .74071 .49922 .75147 .49541 .74658 .48883 Mtetra
.717 .754 .882 r
.74658 .48883 .75147 .49541 .76222 .49091 .75731 .48363 Mtetra
.701 .728 .871 r
.75731 .48363 .76222 .49091 .77299 .48638 .76809 .47883 Mtetra
.687 .716 .871 r
.76809 .47883 .77299 .48638 .78382 .48197 .77895 .47451 Mtetra
.67 .712 .88 r
.77895 .47451 .78382 .48197 .7947 .47794 .78988 .47074 Mtetra
.657 .716 .891 r
.78988 .47074 .7947 .47794 .80566 .47422 .80089 .46737 Mtetra
.649 .724 .903 r
.80089 .46737 .80566 .47422 .81667 .47079 .81197 .46424 Mtetra
.643 .733 .914 r
.81197 .46424 .81667 .47079 .82775 .46753 .8231 .46123 Mtetra
.643 .743 .921 r
.8231 .46123 .82775 .46753 .83888 .46434 .83427 .45819 Mtetra
.644 .749 .925 r
.83427 .45819 .83888 .46434 .85005 .46118 .84549 .4551 Mtetra
.648 .754 .927 r
.84549 .4551 .85005 .46118 .86127 .45797 .85674 .45191 Mtetra
.65 .757 .927 r
.85674 .45191 .86127 .45797 .87252 .45473 .86803 .44862 Mtetra
.653 .757 .926 r
.86803 .44862 .87252 .45473 .88382 .45142 .87935 .44526 Mtetra
.655 .757 .925 r
.87935 .44526 .88382 .45142 .89516 .44808 .89072 .44184 Mtetra
.656 .755 .923 r
.89072 .44184 .89516 .44808 .90654 .44469 .90212 .43838 Mtetra
.656 .754 .921 r
.90212 .43838 .90654 .44469 .91796 .44128 .91357 .43489 Mtetra
.652 .751 .922 r
.3005 .61354 .30643 .61871 .31568 .61593 .30976 .6108 Mtetra
.652 .753 .923 r
.30976 .6108 .31568 .61593 .32495 .61313 .31905 .60805 Mtetra
.653 .756 .925 r
.31905 .60805 .32495 .61313 .33427 .61029 .32838 .60527 Mtetra
.655 .759 .926 r
.32838 .60527 .33427 .61029 .34361 .6074 .33775 .60243 Mtetra
.657 .762 .927 r
.33775 .60243 .34361 .6074 .35299 .60444 .34715 .59952 Mtetra
.661 .766 .928 r
.34715 .59952 .35299 .60444 .36241 .60139 .35658 .59651 Mtetra
.667 .769 .926 r
.35658 .59651 .36241 .60139 .37187 .59825 .36606 .59334 Mtetra
.672 .77 .924 r
.36606 .59334 .37187 .59825 .38136 .59506 .37557 .59004 Mtetra
.678 .768 .919 r
.37557 .59004 .38136 .59506 .39088 .59183 .38513 .5866 Mtetra
.678 .761 .914 r
.38513 .5866 .39088 .59183 .40042 .58873 .39471 .58314 Mtetra
.674 .748 .906 r
.39471 .58314 .40042 .58873 .41 .58586 .40432 .57978 Mtetra
.66 .727 .9 r
.40432 .57978 .41 .58586 .41959 .58338 .41395 .57677 Mtetra
.637 .703 .894 r
.41395 .57677 .41959 .58338 .42921 .58144 .42359 .57435 Mtetra
.607 .678 .892 r
.42359 .57435 .42921 .58144 .43885 .57997 .43326 .57269 Mtetra
.568 .657 .897 r
.43326 .57269 .43885 .57997 .44853 .57889 .44294 .57192 Mtetra
.556 .663 .908 r
.44294 .57192 .44853 .57889 .45826 .57745 .45267 .57132 Mtetra
.566 .697 .929 r
.45267 .57132 .45826 .57745 .46805 .57504 .46245 .57033 Mtetra
.645 .779 .945 r
.46245 .57033 .46805 .57504 .4779 .57079 .47231 .56749 Mtetra
.753 .858 .927 r
.47231 .56749 .4779 .57079 .48781 .56418 .48224 .56188 Mtetra
.833 .895 .885 r
.48224 .56188 .48781 .56418 .49774 .55618 .49222 .55352 Mtetra
.867 .872 .839 r
.49222 .55352 .49774 .55618 .50769 .5477 .50222 .543 Mtetra
.802 .808 .856 r
.50222 .543 .50769 .5477 .51763 .54217 .51219 .53506 Mtetra
.657 .701 .879 r
.51219 .53506 .51763 .54217 .52759 .54094 .52218 .53198 Mtetra
.48 .57 .869 r
.52218 .53198 .52759 .54094 .53761 .54211 .53221 .53344 Mtetra
.248 .448 .86 r
.53221 .53344 .53761 .54211 .5477 .54419 .54232 .53855 Mtetra
.198 .53 .922 r
.54232 .53855 .5477 .54419 .55783 .54322 .5525 .54203 Mtetra
.176 .696 .881 r
.5525 .54203 .55783 .54322 .56795 .53817 .56272 .5419 Mtetra
.105 0 0 r
.56272 .5419 .56795 .53817 .57808 .53166 .57296 .5393 Mtetra
.227 0 0 r
.57296 .5393 .57808 .53166 .58822 .52533 .58322 .53504 Mtetra
.357 0 .142 r
.58322 .53504 .58822 .52533 .59846 .52222 .59353 .53192 Mtetra
.405 .006 .165 r
.59353 .53192 .59846 .52222 .60881 .52233 .6039 .52994 Mtetra
.268 0 .021 r
.6039 .52994 .60881 .52233 .61923 .52263 .61428 .5263 Mtetra
0 0 0 r
.61428 .5263 .61923 .52263 .62966 .52148 .62461 .52016 Mtetra
.861 .949 .87 r
.62461 .52016 .62966 .52148 .64001 .51622 .63485 .51038 Mtetra
.844 .791 .8 r
.63485 .51038 .64001 .51622 .65026 .50787 .64503 .49894 Mtetra
.753 .698 .8 r
.64503 .49894 .65026 .50787 .66055 .50042 .65533 .49114 Mtetra
.651 .651 .837 r
.65533 .49114 .66055 .50042 .67097 .49539 .66584 .48794 Mtetra
.437 .597 .911 r
.66584 .48794 .67097 .49539 .68161 .49473 .67662 .48967 Mtetra
.092 .484 .897 r
.67662 .48967 .68161 .49473 .69247 .49705 .6876 .49404 Mtetra
.111 .589 .912 r
.6876 .49404 .69247 .49705 .70338 .49893 .69855 .49625 Mtetra
.381 .773 .988 r
.69855 .49625 .70338 .49893 .71428 .49939 .70943 .49565 Mtetra
.641 .841 .977 r
.70943 .49565 .71428 .49939 .7251 .49746 .7202 .49223 Mtetra
.727 .804 .912 r
.7202 .49223 .7251 .49746 .73585 .49364 .73089 .48693 Mtetra
.73 .755 .872 r
.73089 .48693 .73585 .49364 .74658 .48883 .74159 .4812 Mtetra
.719 .725 .855 r
.74159 .4812 .74658 .48883 .75731 .48363 .75232 .47564 Mtetra
.693 .706 .858 r
.75232 .47564 .75731 .48363 .76809 .47883 .76314 .47099 Mtetra
.672 .702 .87 r
.76314 .47099 .76809 .47883 .77895 .47451 .77406 .46711 Mtetra
.654 .709 .888 r
.77406 .46711 .77895 .47451 .78988 .47074 .78506 .46384 Mtetra
.64 .72 .906 r
.78506 .46384 .78988 .47074 .80089 .46737 .79614 .46094 Mtetra
.635 .735 .92 r
.79614 .46094 .80089 .46737 .81197 .46424 .80727 .45813 Mtetra
.633 .746 .93 r
.80727 .45813 .81197 .46424 .8231 .46123 .81845 .45532 Mtetra
.638 .756 .934 r
.81845 .45532 .8231 .46123 .83427 .45819 .82967 .45234 Mtetra
.643 .761 .935 r
.82967 .45234 .83427 .45819 .84549 .4551 .84091 .44923 Mtetra
.648 .764 .933 r
.84091 .44923 .84549 .4551 .85674 .45191 .85219 .44596 Mtetra
.653 .764 .931 r
.85219 .44596 .85674 .45191 .86803 .44862 .8635 .44258 Mtetra
.655 .762 .928 r
.8635 .44258 .86803 .44862 .87935 .44526 .87485 .43912 Mtetra
.657 .76 .925 r
.87485 .43912 .87935 .44526 .89072 .44184 .88624 .43559 Mtetra
.658 .757 .923 r
.88624 .43559 .89072 .44184 .90212 .43838 .89767 .43203 Mtetra
.659 .755 .921 r
.89767 .43203 .90212 .43838 .91357 .43489 .90915 .42846 Mtetra
.65 .75 .923 r
.29453 .60833 .3005 .61354 .30976 .6108 .30381 .60563 Mtetra
.649 .752 .925 r
.30381 .60563 .30976 .6108 .31905 .60805 .31312 .60293 Mtetra
.649 .755 .927 r
.31312 .60293 .31905 .60805 .32838 .60527 .32246 .60022 Mtetra
.65 .758 .929 r
.32246 .60022 .32838 .60527 .33775 .60243 .33184 .59748 Mtetra
.651 .763 .931 r
.33184 .59748 .33775 .60243 .34715 .59952 .34125 .59469 Mtetra
.655 .769 .933 r
.34125 .59469 .34715 .59952 .35658 .59651 .3507 .59179 Mtetra
.661 .776 .935 r
.3507 .59179 .35658 .59651 .36606 .59334 .3602 .58874 Mtetra
.669 .783 .934 r
.3602 .58874 .36606 .59334 .37557 .59004 .36973 .58548 Mtetra
.68 .788 .931 r
.36973 .58548 .37557 .59004 .38513 .5866 .37931 .58195 Mtetra
.688 .787 .926 r
.37931 .58195 .38513 .5866 .39471 .58314 .38893 .57822 Mtetra
.694 .778 .916 r
.38893 .57822 .39471 .58314 .40432 .57978 .39858 .57431 Mtetra
.686 .757 .905 r
.39858 .57431 .40432 .57978 .41395 .57677 .40826 .57058 Mtetra
.67 .729 .894 r
.40826 .57058 .41395 .57677 .42359 .57435 .41795 .56726 Mtetra
.634 .69 .884 r
.41795 .56726 .42359 .57435 .43326 .57269 .42765 .56488 Mtetra
.583 .649 .881 r
.42765 .56488 .43326 .57269 .44294 .57192 .43735 .56384 Mtetra
.544 .624 .882 r
.43735 .56384 .44294 .57192 .45267 .57132 .44708 .56372 Mtetra
.507 .623 .9 r
.44708 .56372 .45267 .57132 .46245 .57033 .45684 .56419 Mtetra
.551 .693 .933 r
.45684 .56419 .46245 .57033 .47231 .56749 .46669 .56343 Mtetra
.659 .813 .957 r
.46669 .56343 .47231 .56749 .48224 .56188 .47662 .56015 Mtetra
.811 .922 .911 r
.47662 .56015 .48224 .56188 .49222 .55352 .48663 .55265 Mtetra
.9 .923 .826 r
.48663 .55265 .49222 .55352 .50222 .543 .49669 .54077 Mtetra
.874 .888 .84 r
.49669 .54077 .50222 .543 .51219 .53506 .50672 .53004 Mtetra
.768 .797 .877 r
.50672 .53004 .51219 .53506 .52218 .53198 .51674 .52351 Mtetra
.537 .613 .876 r
.51674 .52351 .52218 .53198 .53221 .53344 .52677 .5236 Mtetra
.173 .37 .817 r
.52677 .5236 .53221 .53344 .54232 .53855 .53689 .53051 Mtetra
0 .301 .796 r
.53689 .53051 .54232 .53855 .5525 .54203 .54711 .5382 Mtetra
0 .288 .715 r
.54711 .5382 .5525 .54203 .56272 .5419 .55741 .54386 Mtetra
.423 0 0 r
.55741 .54386 .56272 .5419 .57296 .5393 .56776 .54623 Mtetra
.367 0 .041 r
.56776 .54623 .57296 .5393 .58322 .53504 .57813 .54487 Mtetra
.356 0 .14 r
.57813 .54487 .58322 .53504 .59353 .53192 .58851 .54174 Mtetra
.274 0 .101 r
.58851 .54174 .59353 .53192 .6039 .52994 .5989 .53684 Mtetra
0 0 0 r
.5989 .53684 .6039 .52994 .61428 .5263 .60921 .52818 Mtetra
.853 .996 .769 r
.60921 .52818 .61428 .5263 .62461 .52016 .61944 .5162 Mtetra
.895 .839 .782 r
.61944 .5162 .62461 .52016 .63485 .51038 .62959 .50213 Mtetra
.832 .734 .756 r
.62959 .50213 .63485 .51038 .64503 .49894 .63973 .48882 Mtetra
.718 .663 .795 r
.63973 .48882 .64503 .49894 .65533 .49114 .6501 .48237 Mtetra
.532 .607 .874 r
.6501 .48237 .65533 .49114 .66584 .48794 .66078 .48261 Mtetra
.096 .477 .895 r
.66078 .48261 .66584 .48794 .67662 .48967 .6717 .48713 Mtetra
.325 0 0 r
.6717 .48713 .67662 .48967 .6876 .49404 .68277 .49285 Mtetra
0 .563 .791 r
.68277 .49285 .6876 .49404 .69855 .49625 .69372 .49413 Mtetra
.553 .879 .991 r
.69372 .49413 .69855 .49625 .70943 .49565 .7045 .49114 Mtetra
.738 .835 .925 r
.7045 .49114 .70943 .49565 .7202 .49223 .71518 .48555 Mtetra
.758 .764 .858 r
.71518 .48555 .7202 .49223 .73089 .48693 .72581 .47869 Mtetra
.73 .714 .836 r
.72581 .47869 .73089 .48693 .74159 .4812 .7365 .47243 Mtetra
.704 .692 .836 r
.7365 .47243 .74159 .4812 .75232 .47564 .74727 .4671 Mtetra
.671 .685 .854 r
.74727 .4671 .75232 .47564 .76314 .47099 .75817 .46314 Mtetra
.644 .692 .88 r
.75817 .46314 .76314 .47099 .77406 .46711 .76918 .46014 Mtetra
.627 .713 .908 r
.76918 .46014 .77406 .46711 .78506 .46384 .78026 .45758 Mtetra
.616 .733 .93 r
.78026 .45758 .78506 .46384 .79614 .46094 .79141 .4552 Mtetra
.619 .755 .943 r
.79141 .4552 .79614 .46094 .80727 .45813 .8026 .45263 Mtetra
.625 .768 .948 r
.8026 .45263 .80727 .45813 .81845 .45532 .81382 .44986 Mtetra
.637 .775 .947 r
.81382 .44986 .81845 .45532 .82967 .45234 .82506 .4468 Mtetra
.646 .777 .943 r
.82506 .4468 .82967 .45234 .84091 .44923 .83633 .44353 Mtetra
.653 .774 .938 r
.83633 .44353 .84091 .44923 .85219 .44596 .84762 .44009 Mtetra
.658 .77 .933 r
.84762 .44009 .85219 .44596 .8635 .44258 .85896 .43654 Mtetra
.66 .766 .928 r
.85896 .43654 .8635 .44258 .87485 .43912 .87033 .43294 Mtetra
.661 .762 .925 r
.87033 .43294 .87485 .43912 .88624 .43559 .88174 .42929 Mtetra
.661 .759 .922 r
.88174 .42929 .88624 .43559 .89767 .43203 .89319 .42563 Mtetra
.661 .756 .92 r
.89319 .42563 .89767 .43203 .90915 .42846 .90469 .42197 Mtetra
.649 .75 .923 r
.28853 .60308 .29453 .60833 .30381 .60563 .29782 .60038 Mtetra
.648 .75 .924 r
.29782 .60038 .30381 .60563 .31312 .60293 .30715 .5977 Mtetra
.647 .751 .925 r
.30715 .5977 .31312 .60293 .32246 .60022 .31651 .59503 Mtetra
.646 .753 .927 r
.31651 .59503 .32246 .60022 .33184 .59748 .3259 .59236 Mtetra
.645 .756 .93 r
.3259 .59236 .33184 .59748 .34125 .59469 .33532 .5897 Mtetra
.646 .762 .933 r
.33532 .5897 .34125 .59469 .3507 .59179 .34479 .58697 Mtetra
.65 .771 .937 r
.34479 .58697 .3507 .59179 .3602 .58874 .35429 .58414 Mtetra
.658 .782 .94 r
.35429 .58414 .3602 .58874 .36973 .58548 .36384 .5811 Mtetra
.671 .795 .94 r
.36384 .5811 .36973 .58548 .37931 .58195 .37344 .57773 Mtetra
.686 .805 .938 r
.37344 .57773 .37931 .58195 .38893 .57822 .38308 .57399 Mtetra
.705 .809 .93 r
.38308 .57399 .38893 .57822 .39858 .57431 .39277 .56979 Mtetra
.71 .799 .92 r
.39277 .56979 .39858 .57431 .40826 .57058 .40249 .56542 Mtetra
.708 .775 .905 r
.40249 .56542 .40826 .57058 .41795 .56726 .41224 .56106 Mtetra
.677 .732 .892 r
.41224 .56106 .41795 .56726 .42765 .56488 .42199 .55751 Mtetra
.625 .679 .882 r
.42199 .55751 .42765 .56488 .43735 .56384 .43174 .55536 Mtetra
.565 .624 .87 r
.43174 .55536 .43735 .56384 .44708 .56372 .44149 .5548 Mtetra
.491 .578 .87 r
.44149 .5548 .44708 .56372 .45684 .56419 .45125 .55594 Mtetra
.476 .59 .888 r
.45125 .55594 .45684 .56419 .46669 .56343 .46106 .55716 Mtetra
.51 .672 .937 r
.46106 .55716 .46669 .56343 .47662 .56015 .47096 .55711 Mtetra
.723 .87 .95 r
.47096 .55711 .47662 .56015 .48663 .55265 .48098 .5522 Mtetra
.889 .944 .841 r
.48098 .5522 .48663 .55265 .49669 .54077 .49108 .54109 Mtetra
.91 .954 .811 r
.49108 .54109 .49669 .54077 .50672 .53004 .50118 .52855 Mtetra
.882 .915 .844 r
.50118 .52855 .50672 .53004 .51674 .52351 .51126 .51772 Mtetra
.669 .751 .911 r
.51126 .51772 .51674 .52351 .52677 .5236 .52132 .51429 Mtetra
.226 .419 .843 r
.52132 .51429 .52677 .5236 .53689 .53051 .53143 .52002 Mtetra
.024 .257 .758 r
.53143 .52002 .53689 .53051 .54711 .5382 .54165 .52946 Mtetra
0 .175 .711 r
.54165 .52946 .54711 .5382 .55741 .54386 .55199 .53957 Mtetra
0 .216 .669 r
.55199 .53957 .55741 .54386 .56776 .54623 .56241 .54638 Mtetra
.211 0 0 r
.56241 .54638 .56776 .54623 .57813 .54487 .57286 .54794 Mtetra
0 0 0 r
.57286 .54794 .57813 .54487 .58851 .54174 .5833 .5448 Mtetra
.532 .89 .671 r
.5833 .5448 .58851 .54174 .5989 .53684 .59368 .53694 Mtetra
.914 .962 .8 r
.59368 .53694 .5989 .53684 .60921 .52818 .60394 .52379 Mtetra
.906 .82 .751 r
.60394 .52379 .60921 .52818 .61944 .5162 .61409 .50729 Mtetra
.845 .725 .73 r
.61409 .50729 .61944 .5162 .62959 .50213 .62422 .49141 Mtetra
.792 .683 .744 r
.62422 .49141 .62959 .50213 .63973 .48882 .63443 .47923 Mtetra
.642 .642 .835 r
.63443 .47923 .63973 .48882 .6501 .48237 .64495 .47629 Mtetra
.148 .481 .899 r
.64495 .47629 .6501 .48237 .66078 .48261 .65582 .48086 Mtetra
.453 0 0 r
.65582 .48086 .66078 .48261 .6717 .48713 .66685 .48718 Mtetra
.472 0 0 r
.66685 .48718 .6717 .48713 .68277 .49285 .67792 .49208 Mtetra
.267 .766 .887 r
.67792 .49208 .68277 .49285 .69372 .49413 .68877 .4907 Mtetra
.763 .884 .932 r
.68877 .4907 .69372 .49413 .7045 .49114 .69942 .48435 Mtetra
.773 .765 .846 r
.69942 .48435 .7045 .49114 .71518 .48555 .71001 .47669 Mtetra
.75 .707 .812 r
.71001 .47669 .71518 .48555 .72581 .47869 .72062 .4691 Mtetra
.71 .677 .816 r
.72062 .4691 .72581 .47869 .7365 .47243 .73136 .46324 Mtetra
.675 .671 .839 r
.73136 .46324 .7365 .47243 .74727 .4671 .74222 .459 Mtetra
.637 .683 .876 r
.74222 .459 .74727 .4671 .75817 .46314 .75323 .4562 Mtetra
.603 .704 .915 r
.75323 .4562 .75817 .46314 .76918 .46014 .76434 .45424 Mtetra
.593 .738 .945 r
.76434 .45424 .76918 .46014 .78026 .45758 .77551 .45229 Mtetra
.592 .763 .96 r
.77551 .45229 .78026 .45758 .79141 .4552 .78671 .45016 Mtetra
.611 .783 .963 r
.78671 .45016 .79141 .4552 .8026 .45263 .79793 .44756 Mtetra
.629 .789 .959 r
.79793 .44756 .8026 .45263 .81382 .44986 .80917 .44458 Mtetra
.645 .788 .95 r
.80917 .44458 .81382 .44986 .82506 .4468 .82042 .44126 Mtetra
.656 .782 .941 r
.82042 .44126 .82506 .4468 .83633 .44353 .8317 .43771 Mtetra
.661 .774 .933 r
.8317 .43771 .83633 .44353 .84762 .44009 .84301 .43405 Mtetra
.664 .768 .927 r
.84301 .43405 .84762 .44009 .85896 .43654 .85436 .43032 Mtetra
.664 .762 .923 r
.85436 .43032 .85896 .43654 .87033 .43294 .86575 .42659 Mtetra
.663 .758 .921 r
.86575 .42659 .87033 .43294 .88174 .42929 .87719 .42286 Mtetra
.663 .756 .92 r
.87719 .42286 .88174 .42929 .89319 .42563 .88867 .41914 Mtetra
.661 .754 .919 r
.88867 .41914 .89319 .42563 .90469 .42197 .90021 .41544 Mtetra
.651 .75 .922 r
.28248 .59781 .28853 .60308 .29782 .60038 .2918 .59504 Mtetra
.65 .748 .922 r
.2918 .59504 .29782 .60038 .30715 .5977 .30114 .5923 Mtetra
.648 .746 .921 r
.30114 .5923 .30715 .5977 .31651 .59503 .31052 .5896 Mtetra
.645 .745 .922 r
.31052 .5896 .31651 .59503 .3259 .59236 .31993 .58695 Mtetra
.641 .746 .925 r
.31993 .58695 .3259 .59236 .33532 .5897 .32937 .58438 Mtetra
.638 .749 .929 r
.32937 .58438 .33532 .5897 .34479 .58697 .33885 .58184 Mtetra
.636 .756 .935 r
.33885 .58184 .34479 .58697 .35429 .58414 .34835 .57932 Mtetra
.64 .77 .942 r
.34835 .57932 .35429 .58414 .36384 .5811 .35791 .57666 Mtetra
.649 .789 .949 r
.35791 .57666 .36384 .5811 .37344 .57773 .3675 .57375 Mtetra
.668 .813 .953 r
.3675 .57375 .37344 .57773 .38308 .57399 .37716 .57037 Mtetra
.697 .834 .948 r
.37716 .57037 .38308 .57399 .39277 .56979 .38687 .5663 Mtetra
.721 .843 .939 r
.38687 .5663 .39277 .56979 .40249 .56542 .39663 .56162 Mtetra
.743 .833 .92 r
.39663 .56162 .40249 .56542 .41224 .56106 .40645 .55631 Mtetra
.73 .796 .904 r
.40645 .55631 .41224 .56106 .42199 .55751 .41627 .55128 Mtetra
.694 .738 .885 r
.41627 .55128 .42199 .55751 .43174 .55536 .42609 .54718 Mtetra
.625 .659 .863 r
.42609 .54718 .43174 .55536 .44149 .5548 .43589 .545 Mtetra
.53 .577 .847 r
.43589 .545 .44149 .5548 .45125 .55594 .44567 .54547 Mtetra
.449 .52 .839 r
.44567 .54547 .45125 .55594 .46106 .55716 .45546 .54791 Mtetra
.359 .501 .864 r
.45546 .54791 .46106 .55716 .47096 .55711 .4653 .55146 Mtetra
.53 .707 .952 r
.4653 .55146 .47096 .55711 .48098 .5522 .47528 .55084 Mtetra
.804 .94 .917 r
.47528 .55084 .48098 .5522 .49108 .54109 .48539 .54341 Mtetra
.878 .993 .777 r
.48539 .54341 .49108 .54109 .50118 .52855 .49556 .53103 Mtetra
.927 .973 .741 r
.49556 .53103 .50118 .52855 .51126 .51772 .50572 .51589 Mtetra
.845 .919 .883 r
.50572 .51589 .51126 .51772 .52132 .51429 .51583 .50699 Mtetra
.48 .624 .914 r
.51583 .50699 .52132 .51429 .53143 .52002 .52594 .50777 Mtetra
.241 .361 .786 r
.52594 .50777 .53143 .52002 .54165 .52946 .53614 .5152 Mtetra
.093 .231 .716 r
.53614 .5152 .54165 .52946 .55199 .53957 .54647 .52683 Mtetra
.156 .299 .76 r
.54647 .52683 .55199 .53957 .56241 .54638 .55691 .53621 Mtetra
.38 .493 .849 r
.55691 .53621 .56241 .54638 .57286 .54794 .56739 .54002 Mtetra
.653 .687 .87 r
.56739 .54002 .57286 .54794 .5833 .5448 .57784 .53685 Mtetra
.798 .733 .791 r
.57784 .53685 .5833 .5448 .59368 .53694 .58821 .5267 Mtetra
.828 .701 .724 r
.58821 .5267 .59368 .53694 .60394 .52379 .59844 .51091 Mtetra
.819 .668 .696 r
.59844 .51091 .60394 .52379 .61409 .50729 .60858 .49282 Mtetra
.773 .634 .708 r
.60858 .49282 .61409 .50729 .62422 .49141 .61878 .47891 Mtetra
.712 .626 .76 r
.61878 .47891 .62422 .49141 .63443 .47923 .62916 .47168 Mtetra
.381 .567 .91 r
.62916 .47168 .63443 .47923 .64495 .47629 .6399 .47423 Mtetra
.593 .028 0 r
.6399 .47423 .64495 .47629 .65582 .48086 .65096 .48311 Mtetra
.607 .072 0 r
.65096 .48311 .65582 .48086 .66685 .48718 .66203 .48925 Mtetra
.314 0 0 r
.66203 .48925 .66685 .48718 .67792 .49208 .67297 .49038 Mtetra
.714 .945 .956 r
.67297 .49038 .67792 .49208 .68877 .4907 .68365 .48458 Mtetra
.824 .794 .824 r
.68365 .48458 .68877 .4907 .69942 .48435 .69414 .47451 Mtetra
.762 .693 .785 r
.69414 .47451 .69942 .48435 .71001 .47669 .70469 .46556 Mtetra
.718 .653 .784 r
.70469 .46556 .71001 .47669 .72062 .4691 .71536 .45861 Mtetra
.668 .642 .815 r
.71536 .45861 .72062 .4691 .73136 .46324 .72621 .45435 Mtetra
.62 .655 .863 r
.72621 .45435 .73136 .46324 .74222 .459 .73723 .45207 Mtetra
.575 .692 .921 r
.73723 .45207 .74222 .459 .75323 .4562 .74836 .45075 Mtetra
.536 .732 .965 r
.74836 .45075 .75323 .4562 .76434 .45424 .75957 .44972 Mtetra
.548 .778 .984 r
.75957 .44972 .76434 .45424 .77551 .45229 .77079 .44805 Mtetra
.577 .804 .986 r
.77079 .44805 .77551 .45229 .78671 .45016 .78202 .44576 Mtetra
.619 .815 .975 r
.78202 .44576 .78671 .45016 .79793 .44756 .79325 .44274 Mtetra
.649 .809 .96 r
.79325 .44274 .79793 .44756 .80917 .44458 .80448 .43924 Mtetra
.663 .794 .944 r
.80448 .43924 .80917 .44458 .82042 .44126 .81573 .43547 Mtetra
.67 .78 .932 r
.81573 .43547 .82042 .44126 .8317 .43771 .82701 .43156 Mtetra
.67 .767 .923 r
.82701 .43156 .8317 .43771 .84301 .43405 .83833 .42766 Mtetra
.669 .759 .918 r
.83833 .42766 .84301 .43405 .85436 .43032 .8497 .42379 Mtetra
.665 .753 .916 r
.8497 .42379 .85436 .43032 .86575 .42659 .86112 .42 Mtetra
.663 .751 .916 r
.86112 .42 .86575 .42659 .87719 .42286 .8726 .41625 Mtetra
.661 .751 .916 r
.8726 .41625 .87719 .42286 .88867 .41914 .88412 .41255 Mtetra
.66 .751 .918 r
.88412 .41255 .88867 .41914 .90021 .41544 .89569 .40886 Mtetra
.656 .751 .92 r
.27639 .59249 .28248 .59781 .2918 .59504 .28574 .58961 Mtetra
.655 .747 .918 r
.28574 .58961 .2918 .59504 .30114 .5923 .29511 .58674 Mtetra
.652 .743 .916 r
.29511 .58674 .30114 .5923 .31052 .5896 .30452 .58392 Mtetra
.648 .738 .915 r
.30452 .58392 .31052 .5896 .31993 .58695 .31395 .58119 Mtetra
.643 .734 .915 r
.31395 .58119 .31993 .58695 .32937 .58438 .32341 .57858 Mtetra
.637 .732 .917 r
.32341 .57858 .32937 .58438 .33885 .58184 .3329 .5761 Mtetra
.628 .732 .922 r
.3329 .5761 .33885 .58184 .34835 .57932 .34241 .57379 Mtetra
.625 .74 .929 r
.34241 .57379 .34835 .57932 .35791 .57666 .35196 .57151 Mtetra
.624 .755 .94 r
.35196 .57151 .35791 .57666 .3675 .57375 .36155 .56919 Mtetra
.638 .783 .951 r
.36155 .56919 .3675 .57375 .37716 .57037 .3712 .56648 Mtetra
.665 .818 .957 r
.3712 .56648 .37716 .57037 .38687 .5663 .38091 .56311 Mtetra
.702 .854 .955 r
.38091 .56311 .38687 .5663 .39663 .56162 .39069 .55882 Mtetra
.748 .876 .938 r
.39069 .55882 .39663 .56162 .40645 .55631 .40054 .55336 Mtetra
.767 .87 .924 r
.40054 .55336 .40645 .55631 .41627 .55128 .41043 .54734 Mtetra
.767 .832 .902 r
.41043 .54734 .41627 .55128 .42609 .54718 .42035 .54119 Mtetra
.711 .752 .884 r
.42035 .54119 .42609 .54718 .43589 .545 .43023 .53655 Mtetra
.617 .65 .86 r
.43023 .53655 .43589 .545 .44567 .54547 .44008 .53457 Mtetra
.494 .536 .829 r
.44008 .53457 .44567 .54547 .45546 .54791 .44989 .53611 Mtetra
.337 .429 .809 r
.44989 .53611 .45546 .54791 .4653 .55146 .4597 .54126 Mtetra
.384 .492 .846 r
.4597 .54126 .4653 .55146 .47528 .55084 .46961 .54482 Mtetra
.566 .71 .938 r
.46961 .54482 .47528 .55084 .48539 .54341 .47967 .54365 Mtetra
.817 .985 .884 r
.47967 .54365 .48539 .54341 .49556 .53103 .48985 .53504 Mtetra
.904 .977 .69 r
.48985 .53504 .49556 .53103 .50572 .51589 .50009 .51913 Mtetra
.871 .99 .729 r
.50009 .51913 .50572 .51589 .51583 .50699 .51028 .50568 Mtetra
.771 .948 .935 r
.51028 .50568 .51583 .50699 .52594 .50777 .52044 .49902 Mtetra
.487 .586 .879 r
.52044 .49902 .52594 .50777 .53614 .5152 .53062 .50012 Mtetra
.298 .353 .752 r
.53062 .50012 .53614 .5152 .54647 .52683 .54091 .50807 Mtetra
.375 .364 .719 r
.54091 .50807 .54647 .52683 .55691 .53621 .5513 .51577 Mtetra
.49 .426 .712 r
.5513 .51577 .55691 .53621 .56739 .54002 .56175 .51953 Mtetra
.615 .504 .705 r
.56175 .51953 .56739 .54002 .57784 .53685 .57218 .51633 Mtetra
.698 .554 .688 r
.57218 .51633 .57784 .53685 .58821 .5267 .58254 .50614 Mtetra
.733 .575 .677 r
.58254 .50614 .58821 .5267 .59844 .51091 .59281 .49199 Mtetra
.745 .59 .683 r
.59281 .49199 .59844 .51091 .60858 .49282 .60304 .47753 Mtetra
.698 .59 .731 r
.60304 .47753 .60858 .49282 .61878 .47891 .61342 .46994 Mtetra
.53 .605 .873 r
.61342 .46994 .61878 .47891 .62916 .47168 .62405 .47017 Mtetra
.533 0 0 r
.62405 .47017 .62916 .47168 .6399 .47423 .63498 .47728 Mtetra
.71 .222 .082 r
.63498 .47728 .6399 .47423 .65096 .48311 .64611 .48693 Mtetra
.464 0 0 r
.64611 .48693 .65096 .48311 .66203 .48925 .65706 .4892 Mtetra
.588 .944 .906 r
.65706 .4892 .66203 .48925 .67297 .49038 .66777 .48393 Mtetra
.82 .784 .819 r
.66777 .48393 .67297 .49038 .68365 .48458 .67829 .47383 Mtetra
.789 .688 .752 r
.67829 .47383 .68365 .48458 .69414 .47451 .68872 .46207 Mtetra
.725 .638 .761 r
.68872 .46207 .69414 .47451 .70469 .46556 .69933 .45399 Mtetra
.668 .624 .796 r
.69933 .45399 .70469 .46556 .71536 .45861 .71015 .44948 Mtetra
.603 .642 .862 r
.71015 .44948 .71536 .45861 .72621 .45435 .72117 .44771 Mtetra
.516 .676 .937 r
.72117 .44771 .72621 .45435 .73723 .45207 .73235 .44749 Mtetra
.462 .735 .986 r
.73235 .44749 .73723 .45207 .74836 .45075 .74358 .44714 Mtetra
.456 .777 .998 r
.74358 .44714 .74836 .45075 .75957 .44972 .75484 .44624 Mtetra
.538 .822 .998 r
.75484 .44624 .75957 .44972 .77079 .44805 .76607 .44412 Mtetra
.611 .833 .985 r
.76607 .44412 .77079 .44805 .78202 .44576 .77728 .44106 Mtetra
.658 .818 .96 r
.77728 .44106 .78202 .44576 .79325 .44274 .78848 .4373 Mtetra
.679 .796 .937 r
.78848 .4373 .79325 .44274 .80448 .43924 .79969 .43314 Mtetra
.681 .773 .92 r
.79969 .43314 .80448 .43924 .81573 .43547 .81094 .42894 Mtetra
.679 .758 .91 r
.81094 .42894 .81573 .43547 .82701 .43156 .82223 .42476 Mtetra
.673 .747 .906 r
.82223 .42476 .82701 .43156 .83833 .42766 .83358 .42075 Mtetra
.668 .742 .906 r
.83358 .42075 .83833 .42766 .8497 .42379 .84498 .41687 Mtetra
.663 .741 .908 r
.84498 .41687 .8497 .42379 .86112 .42 .85644 .41312 Mtetra
.66 .742 .911 r
.85644 .41312 .86112 .42 .8726 .41625 .86795 .40945 Mtetra
.657 .744 .914 r
.86795 .40945 .8726 .41625 .88412 .41255 .87952 .40584 Mtetra
.656 .748 .917 r
.87952 .40584 .88412 .41255 .89569 .40886 .89113 .40224 Mtetra
.662 .753 .918 r
.27027 .58715 .27639 .59249 .28574 .58961 .27964 .5841 Mtetra
.662 .748 .914 r
.27964 .5841 .28574 .58961 .29511 .58674 .28905 .58104 Mtetra
.66 .741 .91 r
.28905 .58104 .29511 .58674 .30452 .58392 .29848 .57802 Mtetra
.656 .734 .907 r
.29848 .57802 .30452 .58392 .31395 .58119 .30795 .57508 Mtetra
.651 .726 .904 r
.30795 .57508 .31395 .58119 .32341 .57858 .31744 .57227 Mtetra
.642 .717 .902 r
.31744 .57227 .32341 .57858 .3329 .5761 .32695 .56966 Mtetra
.63 .71 .904 r
.32695 .56966 .3329 .5761 .34241 .57379 .33648 .56735 Mtetra
.618 .707 .908 r
.33648 .56735 .34241 .57379 .35196 .57151 .34603 .56529 Mtetra
.603 .71 .919 r
.34603 .56529 .35196 .57151 .36155 .56919 .35561 .56352 Mtetra
.602 .73 .935 r
.35561 .56352 .36155 .56919 .3712 .56648 .36524 .56169 Mtetra
.608 .767 .956 r
.36524 .56169 .3712 .56648 .38091 .56311 .37492 .55954 Mtetra
.642 .828 .972 r
.37492 .55954 .38091 .56311 .39069 .55882 .38468 .55647 Mtetra
.7 .891 .967 r
.38468 .55647 .39069 .55882 .40054 .55336 .39453 .55195 Mtetra
.757 .933 .944 r
.39453 .55195 .40054 .55336 .41043 .54734 .40446 .54593 Mtetra
.814 .929 .909 r
.40446 .54593 .41043 .54734 .42035 .54119 .41446 .5383 Mtetra
.807 .874 .896 r
.41446 .5383 .42035 .54119 .43023 .53655 .42446 .53085 Mtetra
.748 .77 .871 r
.42446 .53085 .43023 .53655 .44008 .53457 .43444 .52487 Mtetra
.613 .621 .835 r
.43444 .52487 .44008 .53457 .44989 .53611 .44434 .52296 Mtetra
.436 .465 .791 r
.44434 .52296 .44989 .53611 .4597 .54126 .45416 .5265 Mtetra
.353 .392 .762 r
.45416 .5265 .4597 .54126 .46961 .54482 .46401 .53267 Mtetra
.277 .388 .797 r
.46401 .53267 .46961 .54482 .47967 .54365 .47396 .53907 Mtetra
.531 .757 .979 r
.47396 .53907 .47967 .54365 .48985 .53504 .48409 .53793 Mtetra
.824 .995 .76 r
.48409 .53793 .48985 .53504 .50009 .51913 .49436 .52639 Mtetra
.684 .876 .491 r
.49436 .52639 .50009 .51913 .51028 .50568 .50464 .5113 Mtetra
.787 .944 .597 r
.50464 .5113 .51028 .50568 .52044 .49902 .51489 .4965 Mtetra
.834 .899 .885 r
.51489 .4965 .52044 .49902 .53062 .50012 .5251 .48786 Mtetra
.585 .564 .797 r
.5251 .48786 .53062 .50012 .54091 .50807 .53534 .48685 Mtetra
.54 .452 .704 r
.53534 .48685 .54091 .50807 .5513 .51577 .54565 .48814 Mtetra
.55 .43 .668 r
.54565 .48814 .5513 .51577 .56175 .51953 .55602 .48907 Mtetra
.598 .453 .655 r
.55602 .48907 .56175 .51953 .57218 .51633 .56641 .48583 Mtetra
.637 .479 .652 r
.56641 .48583 .57218 .51633 .58254 .50614 .57676 .4784 Mtetra
.648 .494 .661 r
.57676 .4784 .58254 .50614 .59281 .49199 .58713 .47058 Mtetra
.642 .516 .694 r
.58713 .47058 .59281 .49199 .60304 .47753 .59755 .46508 Mtetra
.486 .509 .807 r
.59755 .46508 .60304 .47753 .61342 .46994 .6082 .46724 Mtetra
.541 0 0 r
.6082 .46724 .61342 .46994 .62405 .47017 .61909 .47566 Mtetra
.687 .233 .168 r
.61909 .47566 .62405 .47017 .63498 .47728 .63012 .48441 Mtetra
.603 .159 .168 r
.63012 .48441 .63498 .47728 .64611 .48693 .64114 .4896 Mtetra
0 0 0 r
.64114 .4896 .64611 .48693 .65706 .4892 .65186 .48426 Mtetra
.876 .828 .797 r
.65186 .48426 .65706 .4892 .66777 .48393 .66228 .47125 Mtetra
.781 .66 .729 r
.66228 .47125 .66777 .48393 .67829 .47383 .67269 .45843 Mtetra
.729 .608 .722 r
.67269 .45843 .67829 .47383 .68872 .46207 .68321 .44825 Mtetra
.658 .588 .765 r
.68321 .44825 .68872 .46207 .69933 .45399 .69401 .44364 Mtetra
.562 .594 .843 r
.69401 .44364 .69933 .45399 .71015 .44948 .70507 .44318 Mtetra
.43 .646 .948 r
.70507 .44318 .71015 .44948 .72117 .44771 .71629 .44424 Mtetra
.248 .666 .963 r
.71629 .44424 .72117 .44771 .73235 .44749 .72759 .44551 Mtetra
.276 .743 .945 r
.72759 .44551 .73235 .44749 .74358 .44714 .73887 .44513 Mtetra
.432 .832 .979 r
.73887 .44513 .74358 .44714 .75484 .44624 .7501 .4432 Mtetra
.604 .87 .992 r
.7501 .4432 .75484 .44624 .76607 .44412 .76127 .43979 Mtetra
.681 .842 .96 r
.76127 .43979 .76607 .44412 .77728 .44106 .77242 .43541 Mtetra
.699 .795 .925 r
.77242 .43541 .77728 .44106 .78848 .4373 .78359 .43071 Mtetra
.699 .763 .901 r
.78359 .43071 .78848 .4373 .79969 .43314 .79478 .42593 Mtetra
.687 .739 .891 r
.79478 .42593 .79969 .43314 .81094 .42894 .80603 .42145 Mtetra
.678 .728 .887 r
.80603 .42145 .81094 .42894 .82223 .42476 .81735 .41722 Mtetra
.668 .723 .89 r
.81735 .41722 .82223 .42476 .83358 .42075 .82874 .4133 Mtetra
.661 .724 .895 r
.82874 .4133 .83358 .42075 .84498 .41687 .84019 .40958 Mtetra
.656 .728 .902 r
.84019 .40958 .84498 .41687 .85644 .41312 .8517 .406 Mtetra
.653 .732 .908 r
.8517 .406 .85644 .41312 .86795 .40945 .86327 .4025 Mtetra
.651 .738 .913 r
.86327 .4025 .86795 .40945 .87952 .40584 .87488 .39904 Mtetra
.651 .744 .918 r
.87488 .39904 .87952 .40584 .89113 .40224 .88655 .39556 Mtetra
.666 .754 .916 r
.2641 .58177 .27027 .58715 .27964 .5841 .2735 .5786 Mtetra
.667 .75 .912 r
.2735 .5786 .27964 .5841 .28905 .58104 .28294 .57538 Mtetra
.667 .746 .909 r
.28294 .57538 .28905 .58104 .29848 .57802 .29241 .57215 Mtetra
.665 .739 .905 r
.29241 .57215 .29848 .57802 .30795 .57508 .3019 .56896 Mtetra
.662 .73 .9 r
.3019 .56896 .30795 .57508 .31744 .57227 .31143 .56583 Mtetra
.655 .718 .895 r
.31143 .56583 .31744 .57227 .32695 .56966 .32098 .56289 Mtetra
.643 .705 .892 r
.32098 .56289 .32695 .56966 .33648 .56735 .33054 .56025 Mtetra
.627 .69 .889 r
.33054 .56025 .33648 .56735 .34603 .56529 .34012 .558 Mtetra
.605 .677 .892 r
.34012 .558 .34603 .56529 .35561 .56352 .34971 .5563 Mtetra
.588 .673 .898 r
.34971 .5563 .35561 .56352 .36524 .56169 .35933 .55495 Mtetra
.57 .682 .916 r
.35933 .55495 .36524 .56169 .37492 .55954 .36898 .5539 Mtetra
.582 .727 .943 r
.36898 .5539 .37492 .55954 .38468 .55647 .37869 .55238 Mtetra
.618 .802 .97 r
.37869 .55238 .38468 .55647 .39453 .55195 .38849 .54982 Mtetra
.691 .9 .971 r
.38849 .54982 .39453 .55195 .40446 .54593 .39839 .54536 Mtetra
.784 .96 .924 r
.39839 .54536 .40446 .54593 .41446 .5383 .40842 .5383 Mtetra
.828 .972 .89 r
.40842 .5383 .41446 .5383 .42446 .53085 .41851 .52972 Mtetra
.854 .932 .877 r
.41851 .52972 .42446 .53085 .43444 .52487 .42862 .52044 Mtetra
.774 .819 .888 r
.42862 .52044 .43444 .52487 .44434 .52296 .43866 .51383 Mtetra
.608 .633 .85 r
.43866 .51383 .44434 .52296 .45416 .5265 .44861 .51205 Mtetra
.432 .445 .773 r
.44861 .51205 .45416 .5265 .46401 .53267 .45849 .51606 Mtetra
.254 .306 .724 r
.45849 .51606 .46401 .53267 .47396 .53907 .46835 .52543 Mtetra
.35 .408 .781 r
.46835 .52543 .47396 .53907 .48409 .53793 .47838 .53115 Mtetra
.625 .709 .907 r
.47838 .53115 .48409 .53793 .49436 .52639 .48859 .52878 Mtetra
.783 .996 .79 r
.48859 .52878 .49436 .52639 .50464 .5113 .49891 .51873 Mtetra
.731 .892 .5 r
.49891 .51873 .50464 .5113 .51489 .4965 .50925 .50235 Mtetra
.761 .931 .578 r
.50925 .50235 .51489 .4965 .5251 .48786 .51954 .48766 Mtetra
.859 .972 .864 r
.51954 .48766 .5251 .48786 .53534 .48685 .52981 .47771 Mtetra
.725 .685 .811 r
.52981 .47771 .53534 .48685 .54565 .48814 .54009 .47134 Mtetra
.626 .536 .733 r
.54009 .47134 .54565 .48814 .55602 .48907 .55041 .46795 Mtetra
.613 .499 .699 r
.55041 .46795 .55602 .48907 .56641 .48583 .56077 .46467 Mtetra
.611 .498 .7 r
.56077 .46467 .56641 .48583 .57676 .4784 .57117 .4615 Mtetra
.564 .5 .741 r
.57117 .4615 .57676 .4784 .58713 .47058 .58167 .46132 Mtetra
.371 .513 .87 r
.58167 .46132 .58713 .47058 .59755 .46508 .5923 .46475 Mtetra
.644 .086 0 r
.5923 .46475 .59755 .46508 .6082 .46724 .60312 .47299 Mtetra
.708 .264 .193 r
.60312 .47299 .6082 .46724 .61909 .47566 .61411 .48297 Mtetra
.56 .114 .148 r
.61411 .48297 .61909 .47566 .63012 .48441 .62504 .4866 Mtetra
0 0 0 r
.62504 .4866 .63012 .48441 .64114 .4896 .63579 .48246 Mtetra
.839 .768 .784 r
.63579 .48246 .64114 .4896 .65186 .48426 .64627 .47011 Mtetra
.797 .652 .702 r
.64627 .47011 .65186 .48426 .66228 .47125 .65659 .45402 Mtetra
.722 .59 .707 r
.65659 .45402 .66228 .47125 .67269 .45843 .6671 .44334 Mtetra
.655 .572 .75 r
.6671 .44334 .67269 .45843 .68321 .44825 .67788 .43853 Mtetra
.536 .595 .861 r
.67788 .43853 .68321 .44825 .69401 .44364 .68894 .43867 Mtetra
.212 .576 .942 r
.68894 .43867 .69401 .44364 .70507 .44318 .70021 .44155 Mtetra
0 .513 .783 r
.70021 .44155 .70507 .44318 .71629 .44424 .71154 .44373 Mtetra
0 .565 .74 r
.71154 .44373 .71629 .44424 .72759 .44551 .72285 .44438 Mtetra
.358 .817 .929 r
.72285 .44438 .72759 .44551 .73887 .44513 .73406 .44236 Mtetra
.63 .891 .987 r
.73406 .44236 .73887 .44513 .7501 .4432 .74519 .43837 Mtetra
.712 .83 .938 r
.74519 .43837 .7501 .4432 .76127 .43979 .75629 .43331 Mtetra
.723 .774 .893 r
.75629 .43331 .76127 .43979 .77242 .43541 .76739 .42775 Mtetra
.707 .733 .871 r
.76739 .42775 .77242 .43541 .78359 .43071 .77854 .42249 Mtetra
.694 .713 .863 r
.77854 .42249 .78359 .43071 .79478 .42593 .78975 .41759 Mtetra
.678 .704 .867 r
.78975 .41759 .79478 .42593 .80603 .42145 .80104 .41326 Mtetra
.666 .704 .875 r
.80104 .41326 .80603 .42145 .81735 .41722 .81242 .40933 Mtetra
.657 .709 .886 r
.81242 .40933 .81735 .41722 .82874 .4133 .82386 .40571 Mtetra
.651 .716 .896 r
.82386 .40571 .82874 .4133 .84019 .40958 .83537 .40228 Mtetra
.648 .725 .905 r
.83537 .40228 .84019 .40958 .8517 .406 .84694 .39891 Mtetra
.646 .732 .912 r
.84694 .39891 .8517 .406 .86327 .4025 .85855 .39558 Mtetra
.646 .738 .917 r
.85855 .39558 .86327 .4025 .87488 .39904 .87022 .39224 Mtetra
.647 .744 .92 r
.87022 .39224 .87488 .39904 .88655 .39556 .88193 .38884 Mtetra
.666 .754 .916 r
.25789 .57635 .2641 .58177 .2735 .5786 .26731 .57314 Mtetra
.669 .754 .914 r
.26731 .57314 .2735 .5786 .28294 .57538 .27677 .56986 Mtetra
.671 .753 .912 r
.27677 .56986 .28294 .57538 .29241 .57215 .28627 .56651 Mtetra
.673 .75 .908 r
.28627 .56651 .29241 .57215 .3019 .56896 .2958 .56309 Mtetra
.675 .743 .902 r
.2958 .56309 .3019 .56896 .31143 .56583 .30537 .5596 Mtetra
.672 .731 .894 r
.30537 .5596 .31143 .56583 .32098 .56289 .31497 .55617 Mtetra
.666 .714 .884 r
.31497 .55617 .32098 .56289 .33054 .56025 .32459 .55287 Mtetra
.65 .691 .875 r
.32459 .55287 .33054 .56025 .34012 .558 .33422 .54996 Mtetra
.627 .665 .867 r
.33422 .54996 .34012 .558 .34971 .5563 .34385 .54768 Mtetra
.599 .639 .862 r
.34385 .54768 .34971 .5563 .35933 .55495 .35349 .54615 Mtetra
.56 .619 .867 r
.35349 .54615 .35933 .55495 .36898 .5539 .36312 .54561 Mtetra
.537 .622 .884 r
.36312 .54561 .36898 .5539 .37869 .55238 .37278 .54548 Mtetra
.514 .656 .924 r
.37278 .54548 .37869 .55238 .38849 .54982 .38249 .54543 Mtetra
.553 .771 .979 r
.38249 .54543 .38849 .54982 .39839 .54536 .3923 .54394 Mtetra
.64 .918 .979 r
.3923 .54394 .39839 .54536 .40842 .5383 .40226 .53987 Mtetra
.694 .982 .858 r
.40226 .53987 .40842 .5383 .41851 .52972 .41236 .53273 Mtetra
.797 .996 .777 r
.41236 .53273 .41851 .52972 .42862 .52044 .42256 .52223 Mtetra
.865 .994 .817 r
.42256 .52223 .42862 .52044 .43866 .51383 .43278 .51109 Mtetra
.852 .876 .857 r
.43278 .51109 .43866 .51383 .44861 .51205 .44296 .5014 Mtetra
.645 .62 .81 r
.44296 .5014 .44861 .51205 .45849 .51606 .45299 .49822 Mtetra
.415 .397 .73 r
.45299 .49822 .45849 .51606 .46835 .52543 .46289 .50379 Mtetra
.354 .327 .69 r
.46289 .50379 .46835 .52543 .47838 .53115 .47283 .51286 Mtetra
.307 .325 .715 r
.47283 .51286 .47838 .53115 .48859 .52878 .48288 .52183 Mtetra
.429 .62 .931 r
.48288 .52183 .48859 .52878 .49891 .51873 .49312 .52309 Mtetra
.55 .879 .612 r
.49312 .52309 .49891 .51873 .50925 .50235 .50349 .51394 Mtetra
0 0 0 r
.50349 .51394 .50925 .50235 .51954 .48766 .51388 .50002 Mtetra
.51388 .50002 .51954 .48766 .52981 .47771 .52424 .48449 Mtetra
.559 .819 .454 r
.52424 .48449 .52981 .47771 .54009 .47134 .53457 .47173 Mtetra
.767 .991 .886 r
.53457 .47173 .54009 .47134 .55041 .46795 .54491 .46381 Mtetra
.645 .821 .967 r
.54491 .46381 .55041 .46795 .56077 .46467 .55531 .4605 Mtetra
.286 .658 .97 r
.55531 .4605 .56077 .46467 .57117 .4615 .5658 .46183 Mtetra
.578 .008 0 r
.5658 .46183 .57117 .4615 .58167 .46132 .57644 .46803 Mtetra
.688 .254 .213 r
.57644 .46803 .58167 .46132 .5923 .46475 .58723 .47706 Mtetra
.639 .258 .307 r
.58723 .47706 .5923 .46475 .60312 .47299 .5981 .48452 Mtetra
.547 .156 .251 r
.5981 .48452 .60312 .47299 .61411 .48297 .60897 .48719 Mtetra
0 0 0 r
.60897 .48719 .61411 .48297 .62504 .4866 .61962 .47934 Mtetra
.868 .767 .748 r
.61962 .47934 .62504 .4866 .63579 .48246 .63003 .46366 Mtetra
.759 .6 .681 r
.63003 .46366 .63579 .48246 .64627 .47011 .64039 .44784 Mtetra
.709 .554 .676 r
.64039 .44784 .64627 .47011 .65659 .45402 .65085 .43554 Mtetra
.62 .523 .722 r
.65085 .43554 .65659 .45402 .6671 .44334 .66166 .43211 Mtetra
.428 .503 .834 r
.66166 .43211 .6671 .44334 .67788 .43853 .67282 .43534 Mtetra
0 .382 .769 r
.67282 .43534 .67788 .43853 .68894 .43867 .68414 .44006 Mtetra
.469 0 0 r
.68414 .44006 .68894 .43867 .70021 .44155 .69553 .44416 Mtetra
.299 0 0 r
.69553 .44416 .70021 .44155 .71154 .44373 .70682 .44484 Mtetra
0 0 0 r
.70682 .44484 .71154 .44373 .72285 .44438 .718 .44238 Mtetra
.669 .932 .97 r
.718 .44238 .72285 .44438 .73406 .44236 .72906 .43725 Mtetra
.761 .832 .907 r
.72906 .43725 .73406 .44236 .74519 .43837 .74006 .43063 Mtetra
.739 .742 .854 r
.74006 .43063 .74519 .43837 .75629 .43331 .75108 .42408 Mtetra
.717 .698 .831 r
.75108 .42408 .75629 .43331 .76739 .42775 .76216 .41795 Mtetra
.69 .674 .83 r
.76216 .41795 .76739 .42775 .77854 .42249 .77334 .41282 Mtetra
.671 .669 .84 r
.77334 .41282 .77854 .42249 .78975 .41759 .78463 .40848 Mtetra
.656 .676 .857 r
.78463 .40848 .78975 .41759 .80104 .41326 .796 .40477 Mtetra
.646 .688 .876 r
.796 .40477 .80104 .41326 .81242 .40933 .80746 .40148 Mtetra
.641 .705 .893 r
.80746 .40148 .81242 .40933 .82386 .40571 .81897 .39832 Mtetra
.638 .719 .906 r
.81897 .39832 .82386 .40571 .83537 .40228 .83055 .39522 Mtetra
.64 .731 .915 r
.83055 .39522 .83537 .40228 .84694 .39891 .84216 .39204 Mtetra
.642 .739 .92 r
.84216 .39204 .84694 .39891 .85855 .39558 .85382 .3888 Mtetra
.643 .744 .922 r
.85382 .3888 .85855 .39558 .87022 .39224 .86553 .38548 Mtetra
.646 .747 .923 r
.86553 .38548 .87022 .39224 .88193 .38884 .87727 .38207 Mtetra
.661 .753 .918 r
.25164 .57089 .25789 .57635 .26731 .57314 .26108 .5678 Mtetra
.664 .758 .92 r
.26108 .5678 .26731 .57314 .27677 .56986 .27055 .56462 Mtetra
.668 .763 .922 r
.27055 .56462 .27677 .56986 .28627 .56651 .28006 .56133 Mtetra
.674 .768 .921 r
.28006 .56133 .28627 .56651 .2958 .56309 .28962 .55789 Mtetra
.682 .769 .917 r
.28962 .55789 .2958 .56309 .30537 .5596 .29922 .55423 Mtetra
.686 .765 .911 r
.29922 .55423 .30537 .5596 .31497 .55617 .30886 .55044 Mtetra
.69 .754 .901 r
.30886 .55044 .31497 .55617 .32459 .55287 .31854 .54652 Mtetra
.682 .732 .889 r
.31854 .54652 .32459 .55287 .33422 .54996 .32823 .54276 Mtetra
.666 .703 .874 r
.32823 .54276 .33422 .54996 .34385 .54768 .33794 .53936 Mtetra
.637 .663 .859 r
.33794 .53936 .34385 .54768 .35349 .54615 .34764 .53677 Mtetra
.594 .62 .848 r
.34764 .53677 .35349 .54615 .36312 .54561 .35732 .53539 Mtetra
.552 .583 .839 r
.35732 .53539 .36312 .54561 .37278 .54548 .36699 .53519 Mtetra
.499 .555 .845 r
.36699 .53519 .37278 .54548 .38249 .54543 .37665 .53627 Mtetra
.49 .578 .871 r
.37665 .53627 .38249 .54543 .3923 .54394 .38637 .53727 Mtetra
.51 .665 .932 r
.38637 .53727 .3923 .54394 .40226 .53987 .3962 .53717 Mtetra
.613 .864 .99 r
.3962 .53717 .40226 .53987 .41236 .53273 .40619 .53409 Mtetra
.722 .988 .869 r
.40619 .53409 .41236 .53273 .42256 .52223 .41636 .52667 Mtetra
.725 .961 .687 r
.41636 .52667 .42256 .52223 .43278 .51109 .42664 .51568 Mtetra
.835 .981 .691 r
.42664 .51568 .43278 .51109 .44296 .5014 .43698 .50204 Mtetra
.866 .98 .848 r
.43698 .50204 .44296 .5014 .45299 .49822 .44722 .4916 Mtetra
.682 .733 .889 r
.44722 .4916 .45299 .49822 .46289 .50379 .45732 .48769 Mtetra
.462 .444 .753 r
.45732 .48769 .46289 .50379 .47283 .51286 .46733 .49121 Mtetra
.314 .301 .685 r
.46733 .49121 .47283 .51286 .48288 .52183 .47732 .50154 Mtetra
.364 .345 .705 r
.47732 .50154 .48288 .52183 .49312 .52309 .48745 .50968 Mtetra
.501 .505 .792 r
.48745 .50968 .49312 .52309 .50349 .51394 .49775 .51138 Mtetra
.706 .9 .966 r
.49775 .51138 .50349 .51394 .51388 .50002 .50815 .50642 Mtetra
0 0 0 r
.50815 .50642 .51388 .50002 .52424 .48449 .51858 .49567 Mtetra
.51858 .49567 .52424 .48449 .53457 .47173 .52901 .4849 Mtetra
.2 0 .128 r
.52901 .4849 .53457 .47173 .54491 .46381 .53945 .47687 Mtetra
.388 .019 .212 r
.53945 .47687 .54491 .46381 .55531 .4605 .54993 .47357 Mtetra
.522 .147 .27 r
.54993 .47357 .55531 .4605 .5658 .46183 .5605 .47498 Mtetra
.581 .206 .296 r
.5605 .47498 .5658 .46183 .57644 .46803 .57118 .47918 Mtetra
.581 .186 .259 r
.57118 .47918 .57644 .46803 .58723 .47706 .58196 .48339 Mtetra
.315 0 0 r
.58196 .48339 .58723 .47706 .5981 .48452 .5927 .48178 Mtetra
.82 .911 .901 r
.5927 .48178 .5981 .48452 .60897 .48719 .60333 .47344 Mtetra
.79 .653 .711 r
.60333 .47344 .60897 .48719 .61962 .47934 .6138 .45858 Mtetra
.756 .588 .669 r
.6138 .45858 .61962 .47934 .63003 .46366 .62417 .44146 Mtetra
.69 .543 .681 r
.62417 .44146 .63003 .46366 .64039 .44784 .63471 .4312 Mtetra
.612 .534 .742 r
.63471 .4312 .64039 .44784 .65085 .43554 .64553 .42847 Mtetra
.25 .517 .91 r
.64553 .42847 .65085 .43554 .66166 .43211 .65667 .43239 Mtetra
.592 .022 0 r
.65667 .43239 .66166 .43211 .67282 .43534 .66805 .43961 Mtetra
.558 .048 0 r
.66805 .43961 .67282 .43534 .68414 .44006 .67941 .44416 Mtetra
.383 0 0 r
.67941 .44416 .68414 .44006 .69553 .44416 .69069 .44507 Mtetra
.288 .784 .759 r
.69069 .44507 .69553 .44416 .70682 .44484 .70181 .44155 Mtetra
.762 .903 .939 r
.70181 .44155 .70682 .44484 .718 .44238 .71279 .43496 Mtetra
.767 .759 .845 r
.71279 .43496 .718 .44238 .72906 .43725 .72372 .42723 Mtetra
.743 .691 .802 r
.72372 .42723 .72906 .43725 .74006 .43063 .73466 .41938 Mtetra
.708 .655 .795 r
.73466 .41938 .74006 .43063 .75108 .42408 .74571 .41285 Mtetra
.684 .645 .805 r
.74571 .41285 .75108 .42408 .76216 .41795 .75687 .40753 Mtetra
.661 .649 .828 r
.75687 .40753 .76216 .41795 .77334 .41282 .76815 .40346 Mtetra
.642 .664 .856 r
.76815 .40346 .77334 .41282 .78463 .40848 .77955 .40022 Mtetra
.631 .689 .885 r
.77955 .40022 .78463 .40848 .796 .40477 .79102 .39735 Mtetra
.624 .711 .909 r
.79102 .39735 .796 .40477 .80746 .40148 .80256 .39466 Mtetra
.626 .733 .924 r
.80256 .39466 .80746 .40148 .81897 .39832 .81414 .39182 Mtetra
.63 .747 .932 r
.81414 .39182 .81897 .39832 .83055 .39522 .82576 .38885 Mtetra
.637 .756 .934 r
.82576 .38885 .83055 .39522 .84216 .39204 .83741 .38565 Mtetra
.643 .758 .933 r
.83741 .38565 .84216 .39204 .85382 .3888 .8491 .38229 Mtetra
.647 .757 .929 r
.8491 .38229 .85382 .3888 .86553 .38548 .86082 .37881 Mtetra
.651 .754 .925 r
.86082 .37881 .86553 .38548 .87727 .38207 .87259 .37524 Mtetra
.65 .75 .923 r
.24535 .5654 .25164 .57089 .26108 .5678 .25479 .56254 Mtetra
.651 .76 .929 r
.25479 .56254 .26108 .5678 .27055 .56462 .26426 .55964 Mtetra
.655 .771 .935 r
.26426 .55964 .27055 .56462 .28006 .56133 .27377 .55661 Mtetra
.662 .784 .939 r
.27377 .55661 .28006 .56133 .28962 .55789 .28333 .55338 Mtetra
.674 .795 .939 r
.28333 .55338 .28962 .55789 .29922 .55423 .29295 .54987 Mtetra
.688 .804 .937 r
.29295 .54987 .29922 .55423 .30886 .55044 .30262 .54602 Mtetra
.705 .805 .928 r
.30262 .54602 .30886 .55044 .31854 .54652 .31234 .54173 Mtetra
.713 .794 .915 r
.31234 .54173 .31854 .54652 .32823 .54276 .32211 .5372 Mtetra
.715 .767 .893 r
.32211 .5372 .32823 .54276 .33794 .53936 .33192 .53246 Mtetra
.696 .722 .87 r
.33192 .53246 .33794 .53936 .34764 .53677 .34173 .52813 Mtetra
.663 .667 .844 r
.34173 .52813 .34764 .53677 .35732 .53539 .35153 .52462 Mtetra
.612 .602 .816 r
.35153 .52462 .35732 .53539 .36699 .53519 .36128 .52262 Mtetra
.548 .539 .797 r
.36128 .52262 .36699 .53519 .37665 .53627 .37098 .52275 Mtetra
.493 .495 .787 r
.37098 .52275 .37665 .53627 .38637 .53727 .38066 .52462 Mtetra
.423 .469 .803 r
.38066 .52462 .38637 .53727 .3962 .53717 .39035 .52802 Mtetra
.41 .54 .876 r
.39035 .52802 .3962 .53717 .40619 .53409 .40014 .53039 Mtetra
.436 .758 .995 r
.40014 .53039 .40619 .53409 .41636 .52667 .41011 .52988 Mtetra
.338 .788 .636 r
.41011 .52988 .41636 .52667 .42664 .51568 .42028 .52453 Mtetra
0 0 0 r
.42028 .52453 .42664 .51568 .43698 .50204 .43064 .51321 Mtetra
.43064 .51321 .43698 .50204 .44722 .4916 .44108 .49847 Mtetra
.78 .931 .568 r
.44108 .49847 .44722 .4916 .45732 .48769 .45151 .48266 Mtetra
.824 .807 .834 r
.45151 .48266 .45732 .48769 .46733 .49121 .46178 .47312 Mtetra
.557 .484 .729 r
.46178 .47312 .46733 .49121 .47732 .50154 .4719 .47315 Mtetra
.455 .361 .66 r
.4719 .47315 .47732 .50154 .48745 .50968 .48199 .47986 Mtetra
.38 .305 .646 r
.48199 .47986 .48745 .50968 .49775 .51138 .49213 .49099 Mtetra
.35 .336 .703 r
.49213 .49099 .49775 .51138 .50815 .50642 .50242 .49961 Mtetra
.265 .539 .921 r
.50242 .49961 .50815 .50642 .51858 .49567 .51284 .50285 Mtetra
.403 0 .047 r
.51284 .50285 .51858 .49567 .52901 .4849 .52335 .50247 Mtetra
.434 .097 .293 r
.52335 .50247 .52901 .4849 .53945 .47687 .53391 .49931 Mtetra
.459 .146 .346 r
.53391 .49931 .53945 .47687 .54993 .47357 .54451 .496 Mtetra
.456 .143 .346 r
.54451 .496 .54993 .47357 .5605 .47498 .55514 .49255 Mtetra
.355 .026 .263 r
.55514 .49255 .5605 .47498 .57118 .47918 .56579 .48631 Mtetra
0 0 0 r
.56579 .48631 .57118 .47918 .58196 .48339 .5764 .4764 Mtetra
.867 .77 .753 r
.5764 .4764 .58196 .48339 .5927 .48178 .5869 .46105 Mtetra
.761 .592 .667 r
.5869 .46105 .5927 .48178 .60333 .47344 .59731 .44313 Mtetra
.685 .511 .646 r
.59731 .44313 .60333 .47344 .6138 .45858 .60778 .42963 Mtetra
.633 .481 .659 r
.60778 .42963 .6138 .45858 .62417 .44146 .61842 .42286 Mtetra
.495 .446 .732 r
.61842 .42286 .62417 .44146 .63471 .4312 .62939 .42579 Mtetra
0 .131 .629 r
.62939 .42579 .63471 .4312 .64553 .42847 .64067 .43511 Mtetra
.666 .216 .174 r
.64067 .43511 .64553 .42847 .65667 .43239 .65204 .4434 Mtetra
.588 .185 .247 r
.65204 .4434 .65667 .43239 .66805 .43961 .66339 .44823 Mtetra
.393 0 .092 r
.66339 .44823 .66805 .43961 .67941 .44416 .67456 .44699 Mtetra
0 0 0 r
.67456 .44699 .67941 .44416 .69069 .44507 .68555 .4408 Mtetra
.829 .869 .875 r
.68555 .4408 .69069 .44507 .70181 .44155 .6964 .43163 Mtetra
.782 .707 .781 r
.6964 .43163 .70181 .44155 .71279 .43496 .7072 .42139 Mtetra
.725 .63 .752 r
.7072 .42139 .71279 .43496 .72372 .42723 .71809 .4127 Mtetra
.691 .602 .752 r
.71809 .4127 .72372 .42723 .73466 .41938 .7291 .40578 Mtetra
.659 .597 .774 r
.7291 .40578 .73466 .41938 .74571 .41285 .74028 .40105 Mtetra
.633 .611 .81 r
.74028 .40105 .74571 .41285 .75687 .40753 .75161 .39787 Mtetra
.614 .645 .857 r
.75161 .39787 .75687 .40753 .76815 .40346 .76304 .39556 Mtetra
.596 .684 .903 r
.76304 .39556 .76815 .40346 .77955 .40022 .77457 .39365 Mtetra
.594 .728 .938 r
.77457 .39365 .77955 .40022 .79102 .39735 .78614 .39155 Mtetra
.596 .759 .956 r
.78614 .39155 .79102 .39735 .80256 .39466 .79774 .38918 Mtetra
.613 .78 .961 r
.79774 .38918 .80256 .39466 .81414 .39182 .80936 .38637 Mtetra
.628 .788 .959 r
.80936 .38637 .81414 .39182 .82576 .38885 .821 .3832 Mtetra
.642 .787 .951 r
.821 .3832 .82576 .38885 .83741 .38565 .83267 .37973 Mtetra
.652 .782 .943 r
.83267 .37973 .83741 .38565 .8491 .38229 .84436 .37605 Mtetra
.658 .773 .934 r
.84436 .37605 .8491 .38229 .86082 .37881 .85609 .37223 Mtetra
.66 .763 .926 r
.85609 .37223 .86082 .37881 .87259 .37524 .86786 .36837 Mtetra
.639 .747 .927 r
.23902 .55988 .24535 .5654 .25479 .56254 .24845 .55725 Mtetra
.636 .756 .934 r
.24845 .55725 .25479 .56254 .26426 .55964 .25792 .55463 Mtetra
.637 .768 .942 r
.25792 .55463 .26426 .55964 .27377 .55661 .26743 .55195 Mtetra
.642 .783 .949 r
.26743 .55195 .27377 .55661 .28333 .55338 .27698 .54912 Mtetra
.649 .802 .956 r
.27698 .54912 .28333 .55338 .29295 .54987 .28659 .54607 Mtetra
.664 .824 .961 r
.28659 .54607 .29295 .54987 .30262 .54602 .29626 .54264 Mtetra
.686 .846 .959 r
.29626 .54264 .30262 .54602 .31234 .54173 .30599 .53866 Mtetra
.71 .862 .954 r
.30599 .53866 .31234 .54173 .32211 .5372 .31579 .53411 Mtetra
.739 .864 .939 r
.31579 .53411 .32211 .5372 .33192 .53246 .32566 .52884 Mtetra
.749 .845 .923 r
.32566 .52884 .33192 .53246 .34173 .52813 .33557 .52329 Mtetra
.745 .8 .897 r
.33557 .52329 .34173 .52813 .35153 .52462 .3455 .51768 Mtetra
.704 .726 .867 r
.3455 .51768 .35153 .52462 .36128 .52262 .35541 .51302 Mtetra
.642 .639 .832 r
.35541 .51302 .36128 .52262 .37098 .52275 .36526 .51008 Mtetra
.566 .548 .794 r
.36526 .51008 .37098 .52275 .38066 .52462 .37504 .50958 Mtetra
.478 .467 .767 r
.37504 .50958 .38066 .52462 .39035 .52802 .38474 .51215 Mtetra
.434 .43 .756 r
.38474 .51215 .39035 .52802 .40014 .53039 .39445 .51622 Mtetra
.399 .432 .779 r
.39445 .51622 .40014 .53039 .41011 .52988 .40423 .52066 Mtetra
.451 .562 .877 r
.40423 .52066 .41011 .52988 .42028 .52453 .41419 .52232 Mtetra
.608 .885 .99 r
.41419 .52232 .42028 .52453 .43064 .51321 .42436 .51894 Mtetra
.493 .825 .529 r
.42436 .51894 .43064 .51321 .44108 .49847 .43474 .50929 Mtetra
0 0 0 r
.43474 .50929 .44108 .49847 .45151 .48266 .44527 .49344 Mtetra
.44527 .49344 .45151 .48266 .46178 .47312 .45575 .47809 Mtetra
.657 .921 .622 r
.45575 .47809 .46178 .47312 .4719 .47315 .46612 .46706 Mtetra
.665 .75 .913 r
.46612 .46706 .4719 .47315 .48199 .47986 .47636 .46355 Mtetra
.42 .418 .752 r
.47636 .46355 .48199 .47986 .49213 .49099 .48655 .46834 Mtetra
.408 .358 .691 r
.48655 .46834 .49213 .49099 .50242 .49961 .4968 .47563 Mtetra
.428 .365 .684 r
.4968 .47563 .50242 .49961 .51284 .50285 .50716 .48248 Mtetra
.473 .417 .714 r
.50716 .48248 .51284 .50285 .52335 .50247 .51764 .48651 Mtetra
.556 .508 .757 r
.51764 .48651 .52335 .50247 .53391 .49931 .52819 .48646 Mtetra
.636 .59 .786 r
.52819 .48646 .53391 .49931 .54451 .496 .5388 .48312 Mtetra
.699 .621 .766 r
.5388 .48312 .54451 .496 .55514 .49255 .54942 .47649 Mtetra
.731 .604 .716 r
.54942 .47649 .55514 .49255 .56579 .48631 .56001 .46575 Mtetra
.729 .574 .68 r
.56001 .46575 .56579 .48631 .5764 .4764 .57056 .45214 Mtetra
.714 .549 .664 r
.57056 .45214 .5764 .4764 .5869 .46105 .58108 .43806 Mtetra
.699 .544 .674 r
.58108 .43806 .5869 .46105 .59731 .44313 .59161 .42647 Mtetra
.621 .539 .74 r
.59161 .42647 .59731 .44313 .60778 .42963 .60234 .42323 Mtetra
.154 .486 .901 r
.60234 .42323 .60778 .42963 .61842 .42286 .61331 .42762 Mtetra
.683 .209 .121 r
.61331 .42762 .61842 .42286 .62939 .42579 .62452 .43642 Mtetra
.668 .267 .275 r
.62452 .43642 .62939 .42579 .64067 .43511 .63587 .44577 Mtetra
.548 .139 .22 r
.63587 .44577 .64067 .43511 .65204 .4434 .64711 .44886 Mtetra
.162 0 0 r
.64711 .44886 .65204 .4434 .66339 .44823 .65819 .44556 Mtetra
.818 .927 .906 r
.65819 .44556 .66339 .44823 .67456 .44699 .66908 .43711 Mtetra
.796 .712 .772 r
.66908 .43711 .67456 .44699 .68555 .4408 .67985 .42578 Mtetra
.742 .623 .727 r
.67985 .42578 .68555 .4408 .6964 .43163 .69062 .41481 Mtetra
.711 .591 .72 r
.69062 .41481 .6964 .43163 .7072 .42139 .70147 .40536 Mtetra
.673 .577 .74 r
.70147 .40536 .7072 .42139 .71809 .4127 .7125 .39904 Mtetra
.64 .587 .779 r
.7125 .39904 .71809 .4127 .7291 .40578 .72372 .39523 Mtetra
.604 .62 .841 r
.72372 .39523 .7291 .40578 .74028 .40105 .73509 .3932 Mtetra
.56 .669 .91 r
.73509 .3932 .74028 .40105 .75161 .39787 .74659 .39215 Mtetra
.53 .731 .967 r
.74659 .39215 .75161 .39787 .76304 .39556 .75815 .39104 Mtetra
.512 .775 .991 r
.75815 .39104 .76304 .39556 .77457 .39365 .76976 .38965 Mtetra
.541 .811 .996 r
.76976 .38965 .77457 .39365 .78614 .39155 .78136 .38752 Mtetra
.578 .827 .992 r
.78136 .38752 .78614 .39155 .79774 .38918 .79298 .38479 Mtetra
.617 .829 .981 r
.79298 .38479 .79774 .38918 .80936 .38637 .8046 .3815 Mtetra
.644 .82 .968 r
.8046 .3815 .80936 .38637 .821 .3832 .81624 .3778 Mtetra
.659 .805 .953 r
.81624 .3778 .821 .3832 .83267 .37973 .8279 .37386 Mtetra
.667 .791 .941 r
.8279 .37386 .83267 .37973 .84436 .37605 .83959 .36977 Mtetra
.67 .778 .931 r
.83959 .36977 .84436 .37605 .85609 .37223 .85132 .3656 Mtetra
.67 .766 .923 r
.85132 .3656 .85609 .37223 .86786 .36837 .8631 .36144 Mtetra
.632 .745 .93 r
.23264 .55431 .23902 .55988 .24845 .55725 .24208 .55182 Mtetra
.626 .749 .936 r
.24208 .55182 .24845 .55725 .25792 .55463 .25155 .5494 Mtetra
.622 .757 .942 r
.25155 .5494 .25792 .55463 .26743 .55195 .26106 .54703 Mtetra
.619 .768 .951 r
.26106 .54703 .26743 .55195 .27698 .54912 .2706 .54465 Mtetra
.614 .785 .964 r
.2706 .54465 .27698 .54912 .28659 .54607 .28018 .54225 Mtetra
.617 .814 .976 r
.28018 .54225 .28659 .54607 .29626 .54264 .28982 .53962 Mtetra
.624 .849 .985 r
.28982 .53962 .29626 .54264 .30599 .53866 .29952 .5366 Mtetra
.643 .892 .985 r
.29952 .5366 .30599 .53866 .31579 .53411 .3093 .5329 Mtetra
.68 .929 .97 r
.3093 .5329 .31579 .53411 .32566 .52884 .31917 .52821 Mtetra
.722 .953 .95 r
.31917 .52821 .32566 .52884 .33557 .52329 .32913 .52252 Mtetra
.78 .951 .929 r
.32913 .52252 .33557 .52329 .3455 .51768 .33917 .51566 Mtetra
.801 .907 .914 r
.33917 .51566 .3455 .51768 .35541 .51302 .34925 .50842 Mtetra
.783 .813 .876 r
.34925 .50842 .35541 .51302 .36526 .51008 .35933 .50132 Mtetra
.709 .684 .824 r
.35933 .50132 .36526 .51008 .37504 .50958 .36935 .49587 Mtetra
.619 .563 .77 r
.36935 .49587 .37504 .50958 .38474 .51215 .37926 .49327 Mtetra
.536 .464 .722 r
.37926 .49327 .38474 .51215 .39445 .51622 .38908 .49421 Mtetra
.451 .388 .696 r
.38908 .49421 .39445 .51622 .40423 .52066 .39879 .49923 Mtetra
.4 .359 .697 r
.39879 .49923 .40423 .52066 .41419 .52232 .40854 .50605 Mtetra
.332 .364 .745 r
.40854 .50605 .41419 .52232 .42436 .51894 .41838 .51289 Mtetra
.2 .534 .924 r
.41838 .51289 .42436 .51894 .43474 .50929 .42842 .51609 Mtetra
.221 0 0 r
.42842 .51609 .43474 .50929 .44527 .49344 .4387 .51309 Mtetra
.233 0 .224 r
.4387 .51309 .44527 .49344 .45575 .47809 .4492 .50257 Mtetra
.106 0 .215 r
.4492 .50257 .45575 .47809 .46612 .46706 .45982 .48497 Mtetra
0 0 .043 r
.45982 .48497 .46612 .46706 .47636 .46355 .47041 .4671 Mtetra
.883 .986 .719 r
.47041 .4671 .47636 .46355 .48655 .46834 .48089 .45258 Mtetra
.707 .591 .724 r
.48089 .45258 .48655 .46834 .4968 .47563 .49128 .44403 Mtetra
.581 .437 .651 r
.49128 .44403 .4968 .47563 .50716 .48248 .50164 .44183 Mtetra
.557 .401 .626 r
.50164 .44183 .50716 .48248 .51764 .48651 .51203 .44155 Mtetra
.558 .396 .618 r
.51203 .44155 .51764 .48651 .52819 .48646 .52248 .44096 Mtetra
.58 .411 .617 r
.52248 .44096 .52819 .48646 .5388 .48312 .53299 .43757 Mtetra
.6 .426 .617 r
.53299 .43757 .5388 .48312 .54942 .47649 .54351 .43136 Mtetra
.603 .428 .618 r
.54351 .43136 .54942 .47649 .56001 .46575 .55406 .42483 Mtetra
.593 .427 .626 r
.55406 .42483 .56001 .46575 .57056 .45214 .56465 .42022 Mtetra
.534 .406 .652 r
.56465 .42022 .57056 .45214 .58108 .43806 .57538 .42201 Mtetra
.313 .358 .749 r
.57538 .42201 .58108 .43806 .59161 .42647 .58629 .42984 Mtetra
.735 .259 .115 r
.58629 .42984 .59161 .42647 .60234 .42323 .5974 .44111 Mtetra
.66 .308 .366 r
.5974 .44111 .60234 .42323 .61331 .42762 .60864 .45216 Mtetra
.565 .245 .385 r
.60864 .45216 .61331 .42762 .62452 .43642 .61982 .45606 Mtetra
.434 .106 .309 r
.61982 .45606 .62452 .43642 .63587 .44577 .63084 .45234 Mtetra
0 0 0 r
.63084 .45234 .63587 .44577 .64711 .44886 .64168 .4423 Mtetra
.865 .794 .779 r
.64168 .4423 .64711 .44886 .65819 .44556 .65237 .42852 Mtetra
.756 .613 .7 r
.65237 .42852 .65819 .44556 .66908 .43711 .66304 .41473 Mtetra
.706 .553 .678 r
.66304 .41473 .66908 .43711 .67985 .42578 .67376 .40273 Mtetra
.66 .522 .685 r
.67376 .40273 .67985 .42578 .69062 .41481 .68468 .3949 Mtetra
.625 .519 .713 r
.68468 .3949 .69062 .41481 .70147 .40536 .6958 .39069 Mtetra
.583 .543 .775 r
.6958 .39069 .70147 .40536 .7125 .39904 .70713 .38941 Mtetra
.515 .596 .873 r
.70713 .38941 .7125 .39904 .72372 .39523 .71862 .38983 Mtetra
.411 .685 .974 r
.71862 .38983 .72372 .39523 .73509 .3932 .7302 .39042 Mtetra
.275 .718 .962 r
.7302 .39042 .73509 .3932 .74659 .39215 .74182 .39062 Mtetra
.276 .76 .922 r
.74182 .39062 .74659 .39215 .75815 .39104 .75344 .38962 Mtetra
.368 .819 .94 r
.75344 .38962 .75815 .39104 .76976 .38965 .76505 .38759 Mtetra
.507 .874 .981 r
.76505 .38759 .76976 .38965 .78136 .38752 .77663 .38453 Mtetra
.604 .883 .991 r
.77663 .38453 .78136 .38752 .79298 .38479 .78821 .38076 Mtetra
.653 .859 .978 r
.78821 .38076 .79298 .38479 .8046 .3815 .7998 .37658 Mtetra
.675 .832 .959 r
.7998 .37658 .8046 .3815 .81624 .3778 .81141 .37216 Mtetra
.679 .805 .942 r
.81141 .37216 .81624 .3778 .8279 .37386 .82307 .36771 Mtetra
.68 .787 .931 r
.82307 .36771 .8279 .37386 .83959 .36977 .83477 .36324 Mtetra
.679 .775 .923 r
.83477 .36324 .83959 .36977 .85132 .3656 .84651 .35881 Mtetra
.675 .765 .918 r
.84651 .35881 .85132 .3656 .8631 .36144 .85831 .35446 Mtetra
.637 .747 .928 r
.22623 .54871 .23264 .55431 .24208 .55182 .23569 .54608 Mtetra
.632 .741 .927 r
.23569 .54608 .24208 .55182 .25155 .5494 .24519 .54357 Mtetra
.626 .736 .927 r
.24519 .54357 .25155 .5494 .26106 .54703 .25471 .54118 Mtetra
.618 .734 .929 r
.25471 .54118 .26106 .54703 .2706 .54465 .26426 .53894 Mtetra
.606 .736 .937 r
.26426 .53894 .2706 .54465 .28018 .54225 .27383 .53691 Mtetra
.598 .749 .949 r
.27383 .53691 .28018 .54225 .28982 .53962 .28344 .53494 Mtetra
.589 .773 .967 r
.28344 .53494 .28982 .53962 .29952 .5366 .29309 .53296 Mtetra
.593 .817 .985 r
.29309 .53296 .29952 .5366 .3093 .5329 .30281 .53058 Mtetra
.602 .874 .992 r
.30281 .53058 .3093 .5329 .31917 .52821 .31261 .5275 Mtetra
.619 .931 .967 r
.31261 .5275 .31917 .52821 .32913 .52252 .32252 .5233 Mtetra
.657 .967 .909 r
.32252 .5233 .32913 .52252 .33917 .51566 .33255 .51753 Mtetra
.69 .981 .854 r
.33255 .51753 .33917 .51566 .34925 .50842 .34268 .51034 Mtetra
.772 .997 .849 r
.34268 .51034 .34925 .50842 .35933 .50132 .35289 .50173 Mtetra
.823 .98 .886 r
.35289 .50173 .35933 .50132 .36935 .49587 .36311 .49303 Mtetra
.813 .879 .894 r
.36311 .49303 .36935 .49587 .37926 .49327 .3733 .4852 Mtetra
.705 .701 .844 r
.3733 .4852 .37926 .49327 .38908 .49421 .38337 .48016 Mtetra
.574 .536 .775 r
.38337 .48016 .38908 .49421 .39879 .49923 .39331 .47934 Mtetra
.484 .425 .715 r
.39331 .47934 .39879 .49923 .40854 .50605 .40314 .48252 Mtetra
.411 .354 .683 r
.40314 .48252 .40854 .50605 .41838 .51289 .41293 .48952 Mtetra
.39 .341 .683 r
.41293 .48952 .41838 .51289 .42842 .51609 .42279 .49732 Mtetra
.393 .378 .724 r
.42279 .49732 .42842 .51609 .4387 .51309 .43281 .50347 Mtetra
.536 .6 .865 r
.43281 .50347 .4387 .51309 .4492 .50257 .44307 .50339 Mtetra
.775 .993 .878 r
.44307 .50339 .4492 .50257 .45982 .48497 .45357 .49504 Mtetra
0 0 0 r
.45357 .49504 .45982 .48497 .47041 .4671 .46417 .48187 Mtetra
.46417 .48187 .47041 .4671 .48089 .45258 .47478 .46629 Mtetra
.47478 .46629 .48089 .45258 .49128 .44403 .48532 .45325 Mtetra
.48532 .45325 .49128 .44403 .50164 .44183 .49581 .44468 Mtetra
.379 .817 .664 r
.49581 .44468 .50164 .44183 .51203 .44155 .50628 .43895 Mtetra
.622 .883 .989 r
.50628 .43895 .51203 .44155 .52248 .44096 .51677 .43533 Mtetra
.656 .772 .935 r
.51677 .43533 .52248 .44096 .53299 .43757 .5273 .43191 Mtetra
.647 .769 .938 r
.5273 .43191 .53299 .43757 .54351 .43136 .53788 .4287 Mtetra
.409 .795 .99 r
.53788 .4287 .54351 .43136 .55406 .42483 .54851 .4276 Mtetra
.388 0 0 r
.54851 .4276 .55406 .42483 .56465 .42022 .55923 .42936 Mtetra
.622 .202 .225 r
.55923 .42936 .56465 .42022 .57538 .42201 .57008 .43566 Mtetra
.65 .274 .318 r
.57008 .43566 .57538 .42201 .58629 .42984 .58109 .44456 Mtetra
.611 .24 .315 r
.58109 .44456 .58629 .42984 .5974 .44111 .59217 .45106 Mtetra
.504 .085 .178 r
.59217 .45106 .5974 .44111 .60864 .45216 .60325 .4527 Mtetra
.643 .967 .873 r
.60325 .4527 .60864 .45216 .61982 .45606 .61418 .44598 Mtetra
.813 .713 .755 r
.61418 .44598 .61982 .45606 .63084 .45234 .62493 .43289 Mtetra
.748 .593 .684 r
.62493 .43289 .63084 .45234 .64168 .4423 .63561 .41809 Mtetra
.714 .55 .666 r
.63561 .41809 .64168 .4423 .65237 .42852 .64628 .40408 Mtetra
.679 .527 .673 r
.64628 .40408 .65237 .42852 .66304 .41473 .65708 .39392 Mtetra
.648 .527 .702 r
.65708 .39392 .66304 .41473 .67376 .40273 .66806 .38785 Mtetra
.593 .545 .771 r
.66806 .38785 .67376 .40273 .68468 .3949 .67927 .38608 Mtetra
.472 .596 .895 r
.67927 .38608 .68468 .3949 .6958 .39069 .69069 .38718 Mtetra
.154 .61 .931 r
.69069 .38718 .6958 .39069 .70713 .38941 .70224 .38921 Mtetra
.179 0 0 r
.70224 .38921 .70713 .38941 .71862 .38983 .71388 .39116 Mtetra
.178 0 0 r
.71388 .39116 .71862 .38983 .7302 .39042 .7255 .39165 Mtetra
.032 0 0 r
.7255 .39165 .7302 .39042 .74182 .39062 .73711 .39069 Mtetra
.265 .773 .815 r
.73711 .39069 .74182 .39062 .75344 .38962 .74867 .38811 Mtetra
.524 .898 .962 r
.74867 .38811 .75344 .38962 .76505 .38759 .7602 .38436 Mtetra
.652 .891 .983 r
.7602 .38436 .76505 .38759 .77663 .38453 .77173 .37989 Mtetra
.693 .848 .957 r
.77173 .37989 .77663 .38453 .78821 .38076 .78326 .37499 Mtetra
.697 .806 .933 r
.78326 .37499 .78821 .38076 .7998 .37658 .79483 .37007 Mtetra
.694 .78 .917 r
.79483 .37007 .7998 .37658 .81141 .37216 .80644 .36521 Mtetra
.686 .763 .91 r
.80644 .36521 .81141 .37216 .82307 .36771 .81811 .36056 Mtetra
.68 .755 .908 r
.81811 .36056 .82307 .36771 .83477 .36324 .82984 .35606 Mtetra
.675 .753 .909 r
.82984 .35606 .83477 .36324 .84651 .35881 .84163 .35169 Mtetra
.671 .754 .913 r
.84163 .35169 .84651 .35881 .85831 .35446 .85348 .34743 Mtetra
.654 .751 .921 r
.21976 .54307 .22623 .54871 .23569 .54608 .22928 .54005 Mtetra
.65 .737 .913 r
.22928 .54005 .23569 .54608 .24519 .54357 .23883 .53712 Mtetra
.643 .722 .906 r
.23883 .53712 .24519 .54357 .25471 .54118 .2484 .53435 Mtetra
.632 .707 .901 r
.2484 .53435 .25471 .54118 .26426 .53894 .25798 .53185 Mtetra
.616 .694 .9 r
.25798 .53185 .26426 .53894 .27383 .53691 .26758 .52973 Mtetra
.599 .686 .903 r
.26758 .52973 .27383 .53691 .28344 .53494 .27718 .52799 Mtetra
.574 .685 .916 r
.27718 .52799 .28344 .53494 .29309 .53296 .2868 .52672 Mtetra
.555 .704 .939 r
.2868 .52672 .29309 .53296 .30281 .53058 .29645 .52565 Mtetra
.525 .743 .975 r
.29645 .52565 .30281 .53058 .31261 .5275 .30614 .52463 Mtetra
.494 .817 1 r
.30614 .52463 .31261 .5275 .32252 .5233 .31591 .52305 Mtetra
.416 .857 .92 r
.31591 .52305 .32252 .5233 .33255 .51753 .3258 .5204 Mtetra
.293 .769 .659 r
.3258 .5204 .33255 .51753 .34268 .51034 .33582 .51602 Mtetra
0 0 0 r
.33582 .51602 .34268 .51034 .35289 .50173 .346 .50929 Mtetra
.346 .50929 .35289 .50173 .36311 .49303 .3563 .50043 Mtetra
.3563 .50043 .36311 .49303 .3733 .4852 .3667 .48953 Mtetra
.767 .979 .719 r
.3667 .48953 .3733 .4852 .38337 .48016 .37711 .47821 Mtetra
.868 .899 .853 r
.37711 .47821 .38337 .48016 .39331 .47934 .38748 .46774 Mtetra
.721 .643 .77 r
.38748 .46774 .39331 .47934 .40314 .48252 .39772 .46035 Mtetra
.599 .484 .693 r
.39772 .46035 .40314 .48252 .41293 .48952 .40781 .45765 Mtetra
.528 .399 .648 r
.40781 .45765 .41293 .48952 .42279 .49732 .41778 .45964 Mtetra
.473 .346 .626 r
.41778 .45964 .42279 .49732 .43281 .50347 .42769 .46636 Mtetra
.426 .315 .624 r
.42769 .46636 .43281 .50347 .44307 .50339 .43761 .47632 Mtetra
.334 .285 .653 r
.43761 .47632 .44307 .50339 .45357 .49504 .44762 .48775 Mtetra
0 .209 .723 r
.44762 .48775 .45357 .49504 .46417 .48187 .45782 .49591 Mtetra
.539 .165 .281 r
.45782 .49591 .46417 .48187 .47478 .46629 .46824 .49826 Mtetra
.473 .183 .392 r
.46824 .49826 .47478 .46629 .48532 .45325 .47882 .4945 Mtetra
.434 .168 .408 r
.47882 .4945 .48532 .45325 .49581 .44468 .48949 .48552 Mtetra
.428 .162 .406 r
.48949 .48552 .49581 .44468 .50628 .43895 .50018 .47604 Mtetra
.44 .166 .4 r
.50018 .47604 .50628 .43895 .51677 .43533 .51085 .46851 Mtetra
.481 .193 .399 r
.51085 .46851 .51677 .43533 .5273 .43191 .52154 .4651 Mtetra
.529 .235 .412 r
.52154 .4651 .5273 .43191 .53788 .4287 .53228 .46582 Mtetra
.549 .259 .428 r
.53228 .46582 .53788 .4287 .54851 .4276 .54309 .46853 Mtetra
.544 .261 .436 r
.54309 .46853 .54851 .4276 .55923 .42936 .55399 .47075 Mtetra
.498 .222 .426 r
.55399 .47075 .55923 .42936 .57008 .43566 .5649 .46773 Mtetra
.4 .122 .371 r
.5649 .46773 .57008 .43566 .58109 .44456 .57577 .45853 Mtetra
0 0 0 r
.57577 .45853 .58109 .44456 .59217 .45106 .58652 .44343 Mtetra
.884 .765 .725 r
.58652 .44343 .59217 .45106 .60325 .4527 .59717 .42498 Mtetra
.72 .541 .648 r
.59717 .42498 .60325 .4527 .61418 .44598 .6078 .40798 Mtetra
.663 .48 .627 r
.6078 .40798 .61418 .44598 .62493 .43289 .61847 .39421 Mtetra
.628 .455 .629 r
.61847 .39421 .62493 .43289 .63561 .41809 .62927 .38524 Mtetra
.597 .447 .648 r
.62927 .38524 .63561 .41809 .64628 .40408 .64025 .38102 Mtetra
.545 .45 .698 r
.64025 .38102 .64628 .40408 .65708 .39392 .65146 .38159 Mtetra
.41 .48 .821 r
.65146 .38159 .65708 .39392 .66806 .38785 .66288 .38534 Mtetra
0 .349 .704 r
.66288 .38534 .66806 .38785 .67927 .38608 .67443 .38997 Mtetra
.527 0 0 r
.67443 .38997 .67927 .38608 .69069 .38718 .68607 .39421 Mtetra
.489 .018 .063 r
.68607 .39421 .69069 .38718 .70224 .38921 .6977 .39637 Mtetra
.405 0 .025 r
.6977 .39637 .70224 .38921 .71388 .39116 .70929 .39635 Mtetra
.207 0 0 r
.70929 .39635 .71388 .39116 .7255 .39165 .72081 .39391 Mtetra
0 0 0 r
.72081 .39391 .7255 .39165 .73711 .39069 .73227 .38969 Mtetra
.608 .944 .939 r
.73227 .38969 .73711 .39069 .74867 .38811 .7437 .38435 Mtetra
.728 .892 .954 r
.7437 .38435 .74867 .38811 .7602 .38436 .75512 .37842 Mtetra
.729 .809 .914 r
.75512 .37842 .7602 .38436 .77173 .37989 .76658 .37253 Mtetra
.716 .76 .887 r
.76658 .37253 .77173 .37989 .78326 .37499 .77808 .36684 Mtetra
.698 .731 .876 r
.77808 .36684 .78326 .37499 .79483 .37007 .78966 .36163 Mtetra
.685 .718 .874 r
.78966 .36163 .79483 .37007 .80644 .36521 .80131 .35681 Mtetra
.674 .715 .88 r
.80131 .35681 .80644 .36521 .81811 .36056 .81303 .35238 Mtetra
.666 .719 .888 r
.81303 .35238 .81811 .36056 .82984 .35606 .82483 .34823 Mtetra
.661 .728 .899 r
.82483 .34823 .82984 .35606 .84163 .35169 .83669 .34425 Mtetra
.658 .74 .91 r
.83669 .34425 .84163 .35169 .85348 .34743 .84861 .34035 Mtetra
.673 .755 .913 r
.21326 .53739 .21976 .54307 .22928 .54005 .22284 .53388 Mtetra
.672 .739 .901 r
.22284 .53388 .22928 .54005 .23883 .53712 .23246 .53036 Mtetra
.666 .72 .889 r
.23246 .53036 .23883 .53712 .2484 .53435 .24209 .52697 Mtetra
.655 .699 .879 r
.24209 .52697 .2484 .53435 .25798 .53185 .25175 .52381 Mtetra
.641 .677 .869 r
.25175 .52381 .25798 .53185 .26758 .52973 .2614 .521 Mtetra
.623 .653 .859 r
.2614 .521 .26758 .52973 .27718 .52799 .27106 .51869 Mtetra
.598 .63 .854 r
.27106 .51869 .27718 .52799 .2868 .52672 .28071 .51705 Mtetra
.574 .611 .852 r
.28071 .51705 .2868 .52672 .29645 .52565 .29036 .51606 Mtetra
.543 .6 .86 r
.29036 .51606 .29645 .52565 .30614 .52463 .3 .5158 Mtetra
.524 .611 .881 r
.3 .5158 .30614 .52463 .31591 .52305 .30968 .51582 Mtetra
.502 .65 .924 r
.30968 .51582 .31591 .52305 .3258 .5204 .31942 .51584 Mtetra
.499 .752 .986 r
.31942 .51584 .3258 .5204 .33582 .51602 .32926 .51496 Mtetra
.467 .867 .965 r
.32926 .51496 .33582 .51602 .346 .50929 .33925 .51242 Mtetra
.324 .784 .654 r
.33925 .51242 .346 .50929 .3563 .50043 .34941 .50751 Mtetra
0 0 0 r
.34941 .50751 .3563 .50043 .3667 .48953 .35974 .49956 Mtetra
.35974 .49956 .3667 .48953 .37711 .47821 .3702 .48913 Mtetra
.3702 .48913 .37711 .47821 .38748 .46774 .38074 .47661 Mtetra
.38074 .47661 .38748 .46774 .39772 .46035 .39126 .46426 Mtetra
.738 .976 .728 r
.39126 .46426 .39772 .46035 .40781 .45765 .40169 .45372 Mtetra
.781 .849 .903 r
.40169 .45372 .40781 .45765 .41778 .45964 .41199 .44685 Mtetra
.599 .57 .792 r
.41199 .44685 .41778 .45964 .42769 .46636 .42215 .44501 Mtetra
.476 .411 .704 r
.42215 .44501 .42769 .46636 .43761 .47632 .4322 .44867 Mtetra
.4 .326 .658 r
.4322 .44867 .43761 .47632 .44762 .48775 .44221 .45733 Mtetra
.415 .326 .647 r
.44221 .45733 .44762 .48775 .45782 .49591 .45233 .46611 Mtetra
.461 .361 .655 r
.45233 .46611 .45782 .49591 .46824 .49826 .46262 .47218 Mtetra
.532 .425 .677 r
.46262 .47218 .46824 .49826 .47882 .4945 .47308 .47352 Mtetra
.616 .505 .704 r
.47308 .47352 .47882 .4945 .48949 .48552 .48368 .46977 Mtetra
.661 .571 .744 r
.48368 .46977 .48949 .48552 .50018 .47604 .49433 .46436 Mtetra
.683 .634 .794 r
.49433 .46436 .50018 .47604 .51085 .46851 .50501 .459 Mtetra
.649 .66 .848 r
.50501 .459 .51085 .46851 .52154 .4651 .51571 .45556 Mtetra
.586 .632 .864 r
.51571 .45556 .52154 .4651 .53228 .46582 .52646 .45406 Mtetra
.586 .587 .82 r
.52646 .45406 .53228 .46582 .54309 .46853 .53726 .45262 Mtetra
.618 .548 .753 r
.53726 .45262 .54309 .46853 .55399 .47075 .5481 .4495 Mtetra
.673 .539 .694 r
.5481 .4495 .55399 .47075 .5649 .46773 .55894 .44126 Mtetra
.696 .531 .66 r
.55894 .44126 .5649 .46773 .57577 .45853 .56972 .42822 Mtetra
.701 .522 .643 r
.56972 .42822 .57577 .45853 .58652 .44343 .58044 .41241 Mtetra
.698 .518 .641 r
.58044 .41241 .58652 .44343 .59717 .42498 .59111 .39668 Mtetra
.669 .506 .656 r
.59111 .39668 .59717 .42498 .6078 .40798 .60187 .38598 Mtetra
.631 .509 .696 r
.60187 .38598 .6078 .40798 .61847 .39421 .61277 .38085 Mtetra
.546 .54 .799 r
.61277 .38085 .61847 .39421 .62927 .38524 .62386 .38083 Mtetra
.045 .5 .887 r
.62386 .38083 .62927 .38524 .64025 .38102 .63515 .38457 Mtetra
.579 .053 0 r
.63515 .38457 .64025 .38102 .65146 .38159 .64661 .39018 Mtetra
.601 .162 .177 r
.64661 .39018 .65146 .38159 .66288 .38534 .65819 .39599 Mtetra
.554 .137 .206 r
.65819 .39599 .66288 .38534 .67443 .38997 .66978 .3997 Mtetra
.481 .053 .149 r
.66978 .3997 .67443 .38997 .68607 .39421 .68135 .40088 Mtetra
.297 0 0 r
.68135 .40088 .68607 .39421 .6977 .39637 .69284 .39896 Mtetra
0 0 0 r
.69284 .39896 .6977 .39637 .70929 .39635 .70425 .39458 Mtetra
.696 .952 .954 r
.70425 .39458 .70929 .39635 .72081 .39391 .7156 .38849 Mtetra
.766 .835 .905 r
.7156 .38849 .72081 .39391 .73227 .38969 .72693 .38145 Mtetra
.744 .743 .851 r
.72693 .38145 .73227 .38969 .7437 .38435 .73827 .37439 Mtetra
.722 .695 .824 r
.73827 .37439 .7437 .38435 .75512 .37842 .74966 .36762 Mtetra
.7 .67 .817 r
.74966 .36762 .75512 .37842 .76658 .37253 .76113 .36159 Mtetra
.684 .66 .82 r
.76113 .36159 .76658 .37253 .77808 .36684 .77268 .35623 Mtetra
.67 .661 .832 r
.77268 .35623 .77808 .36684 .78966 .36163 .78433 .35156 Mtetra
.659 .668 .847 r
.78433 .35156 .78966 .36163 .80131 .35681 .79606 .34741 Mtetra
.651 .681 .865 r
.79606 .34741 .80131 .35681 .81303 .35238 .80787 .34361 Mtetra
.645 .695 .882 r
.80787 .34361 .81303 .35238 .82483 .34823 .81975 .34006 Mtetra
.641 .711 .898 r
.81975 .34006 .82483 .34823 .83669 .34425 .8317 .33664 Mtetra
.641 .728 .912 r
.8317 .33664 .83669 .34425 .84861 .34035 .8437 .33321 Mtetra
.688 .759 .905 r
.20671 .53168 .21326 .53739 .22284 .53388 .21635 .52772 Mtetra
.69 .745 .894 r
.21635 .52772 .22284 .53388 .23246 .53036 .22603 .52367 Mtetra
.688 .729 .882 r
.22603 .52367 .23246 .53036 .24209 .52697 .23575 .5196 Mtetra
.682 .709 .868 r
.23575 .5196 .24209 .52697 .25175 .52381 .24548 .51561 Mtetra
.674 .685 .853 r
.24548 .51561 .25175 .52381 .2614 .521 .25524 .51174 Mtetra
.658 .655 .836 r
.25524 .51174 .2614 .521 .27106 .51869 .265 .50823 Mtetra
.637 .623 .819 r
.265 .50823 .27106 .51869 .28071 .51705 .27475 .50527 Mtetra
.611 .588 .803 r
.27475 .50527 .28071 .51705 .29036 .51606 .28448 .5031 Mtetra
.579 .554 .79 r
.28448 .5031 .29036 .51606 .3 .5158 .29418 .50199 Mtetra
.548 .526 .782 r
.29418 .50199 .3 .5158 .30968 .51582 .30385 .50195 Mtetra
.51 .504 .786 r
.30385 .50195 .30968 .51582 .31942 .51584 .31351 .5031 Mtetra
.478 .504 .807 r
.31351 .5031 .31942 .51584 .32926 .51496 .32319 .50489 Mtetra
.429 .534 .862 r
.32319 .50489 .32926 .51496 .33925 .51242 .33292 .50698 Mtetra
.338 .643 .966 r
.33292 .50698 .33925 .51242 .34941 .50751 .34276 .50825 Mtetra
.017 0 0 r
.34276 .50825 .34941 .50751 .35974 .49956 .35276 .5078 Mtetra
.258 0 0 r
.35276 .5078 .35974 .49956 .3702 .48913 .36294 .50478 Mtetra
.283 0 .178 r
.36294 .50478 .3702 .48913 .38074 .47661 .37331 .49841 Mtetra
.271 0 .247 r
.37331 .49841 .38074 .47661 .39126 .46426 .38384 .48865 Mtetra
.214 0 .244 r
.38384 .48865 .39126 .46426 .40169 .45372 .39451 .47556 Mtetra
.117 0 .181 r
.39451 .47556 .40169 .45372 .41199 .44685 .4052 .46111 Mtetra
0 0 0 r
.4052 .46111 .41199 .44685 .42215 .44501 .41587 .44654 Mtetra
.918 .969 .784 r
.41587 .44654 .42215 .44501 .4322 .44867 .42649 .43247 Mtetra
.748 .61 .705 r
.42649 .43247 .4322 .44867 .44221 .45733 .43704 .41988 Mtetra
.634 .46 .63 r
.43704 .41988 .44221 .45733 .45233 .46611 .4475 .41057 Mtetra
.581 .399 .6 r
.4475 .41057 .45233 .46611 .46262 .47218 .45787 .4055 Mtetra
.549 .367 .587 r
.45787 .4055 .46262 .47218 .47308 .47352 .46819 .40503 Mtetra
.527 .35 .584 r
.46819 .40503 .47308 .47352 .48368 .46977 .47851 .40831 Mtetra
.526 .354 .591 r
.47851 .40831 .48368 .46977 .49433 .46436 .48892 .41152 Mtetra
.541 .373 .602 r
.48892 .41152 .49433 .46436 .50501 .459 .49942 .41248 Mtetra
.577 .406 .614 r
.49942 .41248 .50501 .459 .51571 .45556 .51002 .40899 Mtetra
.608 .429 .613 r
.51002 .40899 .51571 .45556 .52646 .45406 .52067 .40102 Mtetra
.614 .426 .604 r
.52067 .40102 .52646 .45406 .53726 .45262 .53132 .39078 Mtetra
.605 .412 .594 r
.53132 .39078 .53726 .45262 .5481 .4495 .54197 .38046 Mtetra
.581 .39 .587 r
.54197 .38046 .5481 .4495 .55894 .44126 .55265 .37388 Mtetra
.557 .373 .588 r
.55265 .37388 .55894 .44126 .56972 .42822 .56341 .37194 Mtetra
.531 .363 .598 r
.56341 .37194 .56972 .42822 .58044 .41241 .57428 .37429 Mtetra
.488 .359 .63 r
.57428 .37429 .58044 .41241 .59111 .39668 .5853 .37998 Mtetra
.338 .37 .748 r
.5853 .37998 .59111 .39668 .60187 .38598 .59646 .38721 Mtetra
.632 .083 0 r
.59646 .38721 .60187 .38598 .61277 .38085 .60776 .39498 Mtetra
.626 .244 .3 r
.60776 .39498 .61277 .38085 .62386 .38083 .61917 .40267 Mtetra
.591 .252 .363 r
.61917 .40267 .62386 .38083 .63515 .38457 .63067 .40901 Mtetra
.547 .222 .368 r
.63067 .40901 .63515 .38457 .64661 .39018 .64216 .41199 Mtetra
.494 .164 .335 r
.64216 .41199 .64661 .39018 .65819 .39599 .6536 .4115 Mtetra
.387 .029 .23 r
.6536 .4115 .65819 .39599 .66978 .3997 .66496 .4076 Mtetra
.073 0 0 r
.66496 .4076 .66978 .3997 .68135 .40088 .67625 .40105 Mtetra
.729 .99 .868 r
.67625 .40105 .68135 .40088 .69284 .39896 .68747 .39271 Mtetra
.808 .814 .855 r
.68747 .39271 .69284 .39896 .70425 .39458 .69865 .38351 Mtetra
.751 .685 .788 r
.69865 .38351 .70425 .39458 .7156 .38849 .70986 .37459 Mtetra
.716 .629 .759 r
.70986 .37459 .7156 .38849 .72693 .38145 .72112 .36632 Mtetra
.688 .601 .752 r
.72112 .36632 .72693 .38145 .73827 .37439 .73248 .35927 Mtetra
.67 .591 .758 r
.73248 .35927 .73827 .37439 .74966 .36762 .74393 .35331 Mtetra
.655 .593 .774 r
.74393 .35331 .74966 .36762 .76113 .36159 .75549 .34845 Mtetra
.643 .604 .794 r
.75549 .34845 .76113 .36159 .77268 .35623 .76716 .34441 Mtetra
.635 .622 .819 r
.76716 .34441 .77268 .35623 .78433 .35156 .77892 .34093 Mtetra
.628 .642 .845 r
.77892 .34093 .78433 .35156 .79606 .34741 .79077 .33782 Mtetra
.626 .665 .868 r
.79077 .33782 .79606 .34741 .80787 .34361 .80268 .33485 Mtetra
.623 .686 .888 r
.80268 .33485 .80787 .34361 .81975 .34006 .81465 .33195 Mtetra
.622 .705 .905 r
.81465 .33195 .81975 .34006 .8317 .33664 .82668 .32903 Mtetra
.624 .723 .918 r
.82668 .32903 .8317 .33664 .8437 .33321 .83876 .32602 Mtetra
.69 .759 .905 r
.20012 .52592 .20671 .53168 .21635 .52772 .20978 .52191 Mtetra
.694 .759 .901 r
.20978 .52191 .21635 .52772 .22603 .52367 .2195 .51775 Mtetra
.699 .757 .897 r
.2195 .51775 .22603 .52367 .23575 .5196 .22925 .51344 Mtetra
.701 .75 .889 r
.22925 .51344 .23575 .5196 .24548 .51561 .23905 .50899 Mtetra
.704 .737 .877 r
.23905 .50899 .24548 .51561 .25524 .51174 .24888 .50437 Mtetra
.698 .715 .862 r
.24888 .50437 .25524 .51174 .265 .50823 .25874 .49979 Mtetra
.687 .686 .843 r
.25874 .49979 .265 .50823 .27475 .50527 .26862 .49535 Mtetra
.666 .647 .821 r
.26862 .49535 .27475 .50527 .28448 .5031 .27849 .49138 Mtetra
.638 .603 .798 r
.27849 .49138 .28448 .5031 .29418 .50199 .28834 .48819 Mtetra
.603 .556 .774 r
.28834 .48819 .29418 .50199 .30385 .50195 .29815 .48611 Mtetra
.565 .511 .754 r
.29815 .48611 .30385 .50195 .31351 .5031 .3079 .48548 Mtetra
.53 .473 .737 r
.3079 .48548 .31351 .5031 .32319 .50489 .31762 .4863 Mtetra
.492 .441 .728 r
.31762 .4863 .32319 .50489 .33292 .50698 .32731 .48865 Mtetra
.468 .429 .732 r
.32731 .48865 .33292 .50698 .34276 .50825 .33702 .49182 Mtetra
.446 .436 .754 r
.33702 .49182 .34276 .50825 .35276 .5078 .34679 .49528 Mtetra
.443 .492 .815 r
.34679 .49528 .35276 .5078 .36294 .50478 .35669 .49781 Mtetra
.453 .644 .939 r
.35669 .49781 .36294 .50478 .37331 .49841 .36676 .49839 Mtetra
.35 .824 .882 r
.36676 .49839 .37331 .49841 .38384 .48865 .37702 .49589 Mtetra
0 0 0 r
.37702 .49589 .38384 .48865 .39451 .47556 .38749 .48949 Mtetra
.076 0 .041 r
.38749 .48949 .39451 .47556 .4052 .46111 .39811 .4798 Mtetra
.103 0 .136 r
.39811 .4798 .4052 .46111 .41587 .44654 .40883 .46722 Mtetra
.073 0 .148 r
.40883 .46722 .41587 .44654 .42649 .43247 .41961 .45239 Mtetra
.013 0 .114 r
.41961 .45239 .42649 .43247 .43704 .41988 .43038 .43658 Mtetra
.028 0 .079 r
.43038 .43658 .43704 .41988 .4475 .41057 .44104 .42356 Mtetra
.129 0 .058 r
.44104 .42356 .4475 .41057 .45787 .4055 .45157 .41518 Mtetra
.291 0 .053 r
.45157 .41518 .45787 .4055 .46819 .40503 .46202 .41181 Mtetra
.444 0 .039 r
.46202 .41181 .46819 .40503 .47851 .40831 .47243 .41276 Mtetra
.419 0 0 r
.47243 .41276 .47851 .40831 .48892 .41152 .48291 .41417 Mtetra
.219 0 0 r
.48291 .41417 .48892 .41152 .49942 .41248 .49348 .41401 Mtetra
.271 .769 .728 r
.49348 .41401 .49942 .41248 .51002 .40899 .50413 .4105 Mtetra
.611 .954 .827 r
.50413 .4105 .51002 .40899 .52067 .40102 .51483 .40362 Mtetra
.635 .951 .753 r
.51483 .40362 .52067 .40102 .53132 .39078 .52556 .39516 Mtetra
0 0 0 r
.52556 .39516 .53132 .39078 .54197 .38046 .53629 .38714 Mtetra
.169 0 0 r
.53629 .38714 .54197 .38046 .55265 .37388 .54707 .38346 Mtetra
.487 .059 .153 r
.54707 .38346 .55265 .37388 .56341 .37194 .55794 .38483 Mtetra
.604 .214 .277 r
.55794 .38483 .56341 .37194 .57428 .37429 .56895 .39092 Mtetra
.636 .272 .335 r
.56895 .39092 .57428 .37429 .5853 .37998 .58012 .39986 Mtetra
.615 .266 .356 r
.58012 .39986 .5853 .37998 .59646 .38721 .5914 .40786 Mtetra
.585 .241 .352 r
.5914 .40786 .59646 .38721 .60776 .39498 .60275 .41361 Mtetra
.543 .19 .32 r
.60275 .41361 .60776 .39498 .61917 .40267 .61413 .41645 Mtetra
.459 .076 .225 r
.61413 .41645 .61917 .40267 .63067 .40901 .6255 .41595 Mtetra
.142 0 0 r
.6255 .41595 .63067 .40901 .64216 .41199 .6368 .41147 Mtetra
.734 .983 .907 r
.6368 .41147 .64216 .41199 .6536 .4115 .64801 .40383 Mtetra
.799 .77 .826 r
.64801 .40383 .6536 .4115 .66496 .4076 .65917 .39417 Mtetra
.753 .651 .748 r
.65917 .39417 .66496 .4076 .67625 .40105 .67028 .38354 Mtetra
.718 .593 .716 r
.67028 .38354 .67625 .40105 .68747 .39271 .6814 .37318 Mtetra
.695 .566 .705 r
.6814 .37318 .68747 .39271 .69865 .38351 .69257 .36363 Mtetra
.674 .552 .708 r
.69257 .36363 .69865 .38351 .70986 .37459 .70383 .35566 Mtetra
.659 .55 .719 r
.70383 .35566 .70986 .37459 .72112 .36632 .71519 .34916 Mtetra
.644 .556 .741 r
.71519 .34916 .72112 .36632 .73248 .35927 .72667 .34416 Mtetra
.632 .571 .768 r
.72667 .34416 .73248 .35927 .74393 .35331 .73828 .34029 Mtetra
.621 .594 .802 r
.73828 .34029 .74393 .35331 .75549 .34845 .74998 .33723 Mtetra
.612 .622 .837 r
.74998 .33723 .75549 .34845 .76716 .34441 .76178 .33467 Mtetra
.608 .653 .869 r
.76178 .33467 .76716 .34441 .77892 .34093 .77365 .33226 Mtetra
.605 .68 .895 r
.77365 .33226 .77892 .34093 .79077 .33782 .78558 .32988 Mtetra
.609 .704 .912 r
.78558 .32988 .79077 .33782 .80268 .33485 .79756 .32732 Mtetra
.612 .72 .922 r
.79756 .32732 .80268 .33485 .81465 .33195 .80959 .32463 Mtetra
.616 .73 .927 r
.80959 .32463 .81465 .33195 .82668 .32903 .82166 .32178 Mtetra
.622 .735 .928 r
.82166 .32178 .82668 .32903 .83876 .32602 .83378 .31877 Mtetra
.676 .756 .911 r
.19348 .52013 .20012 .52592 .20978 .52191 .20313 .51648 Mtetra
.682 .77 .918 r
.20313 .51648 .20978 .52191 .2195 .51775 .21283 .51266 Mtetra
.691 .785 .923 r
.21283 .51266 .2195 .51775 .22925 .51344 .22259 .50861 Mtetra
.703 .797 .924 r
.22259 .50861 .22925 .51344 .23905 .50899 .2324 .50425 Mtetra
.718 .803 .918 r
.2324 .50425 .23905 .50899 .24888 .50437 .24228 .49946 Mtetra
.728 .799 .908 r
.24228 .49946 .24888 .50437 .25874 .49979 .25221 .4943 Mtetra
.736 .781 .889 r
.25221 .4943 .25874 .49979 .26862 .49535 .2622 .48875 Mtetra
.731 .747 .865 r
.2622 .48875 .26862 .49535 .27849 .49138 .27222 .48308 Mtetra
.717 .7 .833 r
.27222 .48308 .27849 .49138 .28834 .48819 .28226 .47743 Mtetra
.688 .642 .799 r
.28226 .47743 .28834 .48819 .29815 .48611 .29229 .47226 Mtetra
.652 .582 .763 r
.29229 .47226 .29815 .48611 .3079 .48548 .30229 .46793 Mtetra
.613 .524 .729 r
.30229 .46793 .3079 .48548 .31762 .4863 .31224 .46488 Mtetra
.574 .473 .701 r
.31224 .46488 .31762 .4863 .32731 .48865 .32212 .46355 Mtetra
.541 .432 .678 r
.32212 .46355 .32731 .48865 .33702 .49182 .33194 .46404 Mtetra
.509 .399 .664 r
.33194 .46404 .33702 .49182 .34679 .49528 .34171 .46652 Mtetra
.487 .38 .659 r
.34171 .46652 .34679 .49528 .35669 .49781 .35148 .4704 Mtetra
.465 .371 .665 r
.35148 .4704 .35669 .49781 .36676 .49839 .36128 .47529 Mtetra
.437 .375 .69 r
.36128 .47529 .36676 .49839 .37702 .49589 .37115 .4806 Mtetra
.368 .405 .768 r
.37115 .4806 .37702 .49589 .38749 .48949 .38112 .48571 Mtetra
0 .434 .81 r
.38112 .48571 .38749 .48949 .39811 .4798 .39125 .48936 Mtetra
.491 .065 .158 r
.39125 .48936 .39811 .4798 .40883 .46722 .40154 .49079 Mtetra
.5 .177 .35 r
.40154 .49079 .40883 .46722 .41961 .45239 .41195 .49061 Mtetra
.501 .215 .412 r
.41195 .49061 .41961 .45239 .43038 .43658 .42247 .48902 Mtetra
.505 .236 .441 r
.42247 .48902 .43038 .43658 .44104 .42356 .43307 .48652 Mtetra
.504 .244 .454 r
.43307 .48652 .44104 .42356 .45157 .41518 .44374 .48307 Mtetra
.491 .236 .455 r
.44374 .48307 .45157 .41518 .46202 .41181 .45451 .47699 Mtetra
.472 .219 .448 r
.45451 .47699 .46202 .41181 .47243 .41276 .46535 .46842 Mtetra
.459 .201 .434 r
.46535 .46842 .47243 .41276 .48291 .41417 .47619 .45975 Mtetra
.455 .186 .416 r
.47619 .45975 .48291 .41417 .49348 .41401 .48703 .45251 Mtetra
.482 .198 .406 r
.48703 .45251 .49348 .41401 .50413 .4105 .49786 .44901 Mtetra
.52 .232 .417 r
.49786 .44901 .50413 .4105 .51483 .40362 .50871 .44926 Mtetra
.535 .254 .436 r
.50871 .44926 .51483 .40362 .52556 .39516 .51963 .45097 Mtetra
.535 .264 .452 r
.51963 .45097 .52556 .39516 .53629 .38714 .53062 .45259 Mtetra
.521 .26 .459 r
.53062 .45259 .53629 .38714 .54707 .38346 .54169 .45171 Mtetra
.507 .25 .459 r
.54169 .45171 .54707 .38346 .55794 .38483 .55279 .44819 Mtetra
.499 .24 .452 r
.55279 .44819 .55794 .38483 .56895 .39092 .56392 .44371 Mtetra
.484 .219 .436 r
.56392 .44371 .56895 .39092 .58012 .39986 .57508 .43831 Mtetra
.446 .168 .397 r
.57508 .43831 .58012 .39986 .5914 .40786 .58625 .43146 Mtetra
.346 .041 .296 r
.58625 .43146 .5914 .40786 .60275 .41361 .5974 .42296 Mtetra
0 0 0 r
.5974 .42296 .60275 .41361 .61413 .41645 .60851 .41218 Mtetra
.876 .869 .827 r
.60851 .41218 .61413 .41645 .6255 .41595 .61956 .39988 Mtetra
.752 .623 .716 r
.61956 .39988 .6255 .41595 .6368 .41147 .6306 .38735 Mtetra
.698 .542 .672 r
.6306 .38735 .6368 .41147 .64801 .40383 .64163 .37522 Mtetra
.67 .508 .656 r
.64163 .37522 .64801 .40383 .65917 .39417 .65269 .36409 Mtetra
.653 .492 .653 r
.65269 .36409 .65917 .39417 .67028 .38354 .6638 .35437 Mtetra
.636 .484 .659 r
.6638 .35437 .67028 .38354 .6814 .37318 .67501 .34668 Mtetra
.624 .486 .673 r
.67501 .34668 .6814 .37318 .69257 .36363 .68634 .34086 Mtetra
.611 .496 .697 r
.68634 .34086 .69257 .36363 .70383 .35566 .69779 .33679 Mtetra
.6 .516 .731 r
.69779 .33679 .70383 .35566 .71519 .34916 .70937 .33405 Mtetra
.589 .548 .776 r
.70937 .33405 .71519 .34916 .72667 .34416 .72105 .33218 Mtetra
.578 .589 .828 r
.72105 .33218 .72667 .34416 .73828 .34029 .73283 .3308 Mtetra
.57 .64 .881 r
.73283 .3308 .73828 .34029 .74998 .33723 .74469 .32947 Mtetra
.564 .688 .923 r
.74469 .32947 .74998 .33723 .76178 .33467 .7566 .328 Mtetra
.57 .729 .95 r
.7566 .328 .76178 .33467 .77365 .33226 .76855 .32613 Mtetra
.58 .755 .961 r
.76855 .32613 .77365 .33226 .78558 .32988 .78053 .32388 Mtetra
.598 .769 .961 r
.78053 .32388 .78558 .32988 .79756 .32732 .79254 .32119 Mtetra
.614 .772 .956 r
.79254 .32119 .79756 .32732 .80959 .32463 .80457 .31817 Mtetra
.627 .766 .946 r
.80457 .31817 .80959 .32463 .82166 .32178 .81665 .31491 Mtetra
.635 .756 .935 r
.81665 .31491 .82166 .32178 .83378 .31877 .82876 .31146 Mtetra
.647 .749 .924 r
.18679 .51429 .19348 .52013 .20313 .51648 .1964 .51133 Mtetra
.649 .775 .94 r
.1964 .51133 .20313 .51648 .21283 .51266 .20605 .50826 Mtetra
.654 .805 .955 r
.20605 .50826 .21283 .51266 .22259 .50861 .21576 .50497 Mtetra
.664 .837 .966 r
.21576 .50497 .22259 .50861 .2324 .50425 .22553 .50134 Mtetra
.679 .869 .971 r
.22553 .50134 .2324 .50425 .24228 .49946 .23538 .49724 Mtetra
.698 .898 .969 r
.23538 .49724 .24228 .49946 .25221 .4943 .24531 .49259 Mtetra
.723 .919 .96 r
.24531 .49259 .25221 .4943 .2622 .48875 .25532 .48726 Mtetra
.747 .928 .949 r
.25532 .48726 .2622 .48875 .27222 .48308 .26539 .48133 Mtetra
.773 .92 .935 r
.26539 .48133 .27222 .48308 .28226 .47743 .27554 .4748 Mtetra
.784 .889 .92 r
.27554 .4748 .28226 .47743 .29229 .47226 .28572 .468 Mtetra
.778 .83 .893 r
.28572 .468 .29229 .47226 .30229 .46793 .29593 .46114 Mtetra
.746 .749 .854 r
.29593 .46114 .30229 .46793 .31224 .46488 .30612 .45474 Mtetra
.698 .659 .808 r
.30612 .45474 .31224 .46488 .32212 .46355 .31627 .44925 Mtetra
.644 .574 .761 r
.31627 .44925 .32212 .46355 .33194 .46404 .32635 .44519 Mtetra
.592 .502 .721 r
.32635 .44519 .33194 .46404 .34171 .46652 .33636 .44304 Mtetra
.552 .447 .689 r
.33636 .44304 .34171 .46652 .35148 .4704 .34631 .44283 Mtetra
.519 .406 .666 r
.34631 .44283 .35148 .4704 .36128 .47529 .35621 .44468 Mtetra
.491 .377 .651 r
.35621 .44468 .36128 .47529 .37115 .4806 .36609 .44846 Mtetra
.467 .355 .643 r
.36609 .44846 .37115 .4806 .38112 .48571 .37597 .45397 Mtetra
.461 .353 .645 r
.37597 .45397 .38112 .48571 .39125 .48936 .38593 .45978 Mtetra
.464 .364 .656 r
.38593 .45978 .39125 .48936 .40154 .49079 .39601 .46505 Mtetra
.456 .375 .676 r
.39601 .46505 .40154 .49079 .41195 .49061 .4062 .47009 Mtetra
.446 .402 .716 r
.4062 .47009 .41195 .49061 .42247 .48902 .4165 .47446 Mtetra
.487 .491 .787 r
.4165 .47446 .42247 .48902 .43307 .48652 .42697 .47626 Mtetra
.595 .624 .851 r
.42697 .47626 .43307 .48652 .44374 .48307 .43761 .47445 Mtetra
.728 .714 .837 r
.43761 .47445 .44374 .48307 .45451 .47699 .44841 .46801 Mtetra
.79 .723 .789 r
.44841 .46801 .45451 .47699 .46535 .46842 .45931 .45763 Mtetra
.771 .687 .77 r
.45931 .45763 .46535 .46842 .47619 .45975 .47021 .4473 Mtetra
.724 .645 .769 r
.47021 .4473 .47619 .45975 .48703 .45251 .48107 .43923 Mtetra
.634 .591 .788 r
.48107 .43923 .48703 .45251 .49786 .44901 .4919 .4357 Mtetra
.507 .523 .807 r
.4919 .4357 .49786 .44901 .50871 .44926 .50275 .43672 Mtetra
.411 .482 .823 r
.50275 .43672 .50871 .44926 .51963 .45097 .51366 .44003 Mtetra
.378 .498 .853 r
.51366 .44003 .51963 .45097 .53062 .45259 .52466 .44341 Mtetra
.541 .629 .888 r
.52466 .44341 .53062 .45259 .54169 .45171 .53573 .44284 Mtetra
.696 .705 .854 r
.53573 .44284 .54169 .45171 .55279 .44819 .54685 .43761 Mtetra
.754 .691 .791 r
.54685 .43761 .55279 .44819 .56392 .44371 .55796 .42872 Mtetra
.749 .63 .729 r
.55796 .42872 .56392 .44371 .57508 .43831 .56904 .41721 Mtetra
.715 .567 .687 r
.56904 .41721 .57508 .43831 .58625 .43146 .5801 .40498 Mtetra
.691 .528 .662 r
.5801 .40498 .58625 .43146 .5974 .42296 .59114 .39249 Mtetra
.68 .508 .647 r
.59114 .39249 .5974 .42296 .60851 .41218 .60215 .37942 Mtetra
.67 .495 .641 r
.60215 .37942 .60851 .41218 .61956 .39988 .61314 .36662 Mtetra
.655 .484 .641 r
.61314 .36662 .61956 .39988 .6306 .38735 .62418 .35555 Mtetra
.642 .479 .647 r
.62418 .35555 .6306 .38735 .64163 .37522 .63527 .34644 Mtetra
.63 .481 .661 r
.63527 .34644 .64163 .37522 .65269 .36409 .64645 .33943 Mtetra
.619 .49 .684 r
.64645 .33943 .65269 .36409 .6638 .35437 .65774 .33439 Mtetra
.603 .508 .72 r
.65774 .33439 .6638 .35437 .67501 .34668 .66915 .33131 Mtetra
.583 .54 .773 r
.66915 .33131 .67501 .34668 .68634 .34086 .68069 .3297 Mtetra
.553 .592 .847 r
.68069 .3297 .68634 .34086 .69779 .33679 .69234 .32903 Mtetra
.504 .657 .928 r
.69234 .32903 .69779 .33679 .70937 .33405 .7041 .32885 Mtetra
.44 .721 .985 r
.7041 .32885 .70937 .33405 .72105 .33218 .71592 .32862 Mtetra
.377 .756 .99 r
.71592 .32862 .72105 .33218 .73283 .3308 .7278 .32811 Mtetra
.37 .786 .978 r
.7278 .32811 .73283 .3308 .74469 .32947 .73972 .32699 Mtetra
.406 .814 .979 r
.73972 .32699 .74469 .32947 .7566 .328 .75166 .32525 Mtetra
.48 .844 .991 r
.75166 .32525 .7566 .328 .76855 .32613 .76361 .32281 Mtetra
.548 .856 .997 r
.76361 .32281 .76855 .32613 .78053 .32388 .77559 .3198 Mtetra
.603 .85 .991 r
.77559 .3198 .78053 .32388 .79254 .32119 .78757 .31629 Mtetra
.637 .831 .975 r
.78757 .31629 .79254 .32119 .80457 .31817 .79958 .31242 Mtetra
.655 .806 .956 r
.79958 .31242 .80457 .31817 .81665 .31491 .81162 .30832 Mtetra
.663 .78 .936 r
.81162 .30832 .81665 .31491 .82876 .31146 .82371 .3041 Mtetra
.609 .739 .937 r
.18006 .50842 .18679 .51429 .1964 .51133 .18961 .50622 Mtetra
.601 .766 .958 r
.18961 .50622 .1964 .51133 .20605 .50826 .19919 .50403 Mtetra
.593 .798 .978 r
.19919 .50403 .20605 .50826 .21576 .50497 .20883 .50173 Mtetra
.584 .836 .993 r
.20883 .50173 .21576 .50497 .22553 .50134 .21853 .49921 Mtetra
.569 .873 .994 r
.21853 .49921 .22553 .50134 .23538 .49724 .2283 .49637 Mtetra
.546 .902 .971 r
.2283 .49637 .23538 .49724 .24531 .49259 .23815 .49304 Mtetra
.518 .913 .914 r
.23815 .49304 .24531 .49259 .25532 .48726 .24809 .48905 Mtetra
.484 .899 .829 r
.24809 .48905 .25532 .48726 .26539 .48133 .25812 .48427 Mtetra
.475 .884 .751 r
.25812 .48427 .26539 .48133 .27554 .4748 .26826 .47855 Mtetra
.486 .879 .702 r
.26826 .47855 .27554 .4748 .28572 .468 .27849 .47195 Mtetra
.554 .911 .713 r
.27849 .47195 .28572 .468 .29593 .46114 .28879 .46444 Mtetra
.657 .964 .778 r
.28879 .46444 .29593 .46114 .30612 .45474 .29916 .45632 Mtetra
.779 .995 .867 r
.29916 .45632 .30612 .45474 .31627 .44925 .30956 .44778 Mtetra
.827 .928 .899 r
.30956 .44778 .31627 .44925 .32635 .44519 .31996 .43932 Mtetra
.787 .784 .85 r
.31996 .43932 .32635 .44519 .33636 .44304 .33034 .43135 Mtetra
.715 .643 .776 r
.33034 .43135 .33636 .44304 .34631 .44283 .34067 .42432 Mtetra
.652 .541 .715 r
.34067 .42432 .34631 .44283 .35621 .44468 .35095 .41863 Mtetra
.609 .473 .671 r
.35095 .41863 .35621 .44468 .36609 .44846 .36118 .4143 Mtetra
.579 .427 .64 r
.36118 .4143 .36609 .44846 .37597 .45397 .37138 .41142 Mtetra
.56 .398 .618 r
.37138 .41142 .37597 .45397 .38593 .45978 .38157 .40973 Mtetra
.549 .379 .604 r
.38157 .40973 .38593 .45978 .39601 .46505 .39177 .40906 Mtetra
.541 .367 .595 r
.39177 .40906 .39601 .46505 .4062 .47009 .40198 .40928 Mtetra
.538 .361 .589 r
.40198 .40928 .4062 .47009 .4165 .47446 .41225 .40987 Mtetra
.549 .367 .587 r
.41225 .40987 .4165 .47446 .42697 .47626 .42265 .40865 Mtetra
.563 .375 .585 r
.42265 .40865 .42697 .47626 .43761 .47445 .43317 .40494 Mtetra
.567 .377 .584 r
.43317 .40494 .43761 .47445 .44841 .46801 .44375 .40034 Mtetra
.569 .38 .585 r
.44375 .40034 .44841 .46801 .45931 .45763 .45436 .39559 Mtetra
.568 .383 .591 r
.45436 .39559 .45931 .45763 .47021 .4473 .465 .39147 Mtetra
.566 .387 .598 r
.465 .39147 .47021 .4473 .48107 .43923 .47567 .38814 Mtetra
.57 .395 .604 r
.47567 .38814 .48107 .43923 .4919 .4357 .48638 .38454 Mtetra
.572 .396 .604 r
.48638 .38454 .4919 .4357 .50275 .43672 .49714 .38068 Mtetra
.564 .385 .598 r
.49714 .38068 .50275 .43672 .51366 .44003 .50793 .37761 Mtetra
.557 .375 .59 r
.50793 .37761 .51366 .44003 .52466 .44341 .51877 .37518 Mtetra
.556 .37 .585 r
.51877 .37518 .52466 .44341 .53573 .44284 .52966 .37259 Mtetra
.56 .372 .583 r
.52966 .37259 .53573 .44284 .54685 .43761 .54059 .36912 Mtetra
.574 .384 .585 r
.54059 .36912 .54685 .43761 .55796 .42872 .55155 .36312 Mtetra
.586 .394 .588 r
.55155 .36312 .55796 .42872 .56904 .41721 .56252 .35529 Mtetra
.586 .397 .592 r
.56252 .35529 .56904 .41721 .5801 .40498 .5735 .34781 Mtetra
.585 .4 .597 r
.5735 .34781 .5801 .40498 .59114 .39249 .58452 .34123 Mtetra
.583 .404 .605 r
.58452 .34123 .59114 .39249 .60215 .37942 .59559 .33567 Mtetra
.581 .413 .618 r
.59559 .33567 .60215 .37942 .61314 .36662 .60672 .33132 Mtetra
.576 .426 .64 r
.60672 .33132 .61314 .36662 .62418 .35555 .61794 .32844 Mtetra
.567 .446 .674 r
.61794 .32844 .62418 .35555 .63527 .34644 .62925 .32696 Mtetra
.548 .479 .729 r
.62925 .32696 .63527 .34644 .64645 .33943 .64068 .32685 Mtetra
.507 .539 .823 r
.64068 .32685 .64645 .33943 .65774 .33439 .65222 .32772 Mtetra
.382 .631 .952 r
.65222 .32772 .65774 .33439 .66915 .33131 .66386 .32911 Mtetra
.064 .597 .862 r
.66386 .32911 .66915 .33131 .68069 .3297 .6756 .3306 Mtetra
.185 0 0 r
.6756 .3306 .68069 .3297 .69234 .32903 .6874 .33167 Mtetra
.253 0 0 r
.6874 .33167 .69234 .32903 .7041 .32885 .69925 .33213 Mtetra
.221 0 0 r
.69925 .33213 .7041 .32885 .71592 .32862 .71113 .33166 Mtetra
.136 0 0 r
.71113 .33166 .71592 .32862 .7278 .32811 .72303 .33027 Mtetra
0 0 0 r
.72303 .33027 .7278 .32811 .73972 .32699 .73493 .32792 Mtetra
.218 .736 .726 r
.73493 .32792 .73972 .32699 .75166 .32525 .74683 .32475 Mtetra
.425 .868 .89 r
.74683 .32475 .75166 .32525 .76361 .32281 .75874 .32089 Mtetra
.569 .913 .969 r
.75874 .32089 .76361 .32281 .77559 .3198 .77066 .31651 Mtetra
.645 .898 .984 r
.77066 .31651 .77559 .3198 .78757 .31629 .7826 .31179 Mtetra
.679 .865 .97 r
.7826 .31179 .78757 .31629 .79958 .31242 .79457 .30684 Mtetra
.692 .828 .948 r
.79457 .30684 .79958 .31242 .81162 .30832 .80657 .30177 Mtetra
.693 .794 .928 r
.80657 .30177 .81162 .30832 .82371 .3041 .81861 .29669 Mtetra
.585 .731 .944 r
.17328 .5025 .18006 .50842 .18961 .50622 .1828 .50072 Mtetra
.574 .744 .957 r
.1828 .50072 .18961 .50622 .19919 .50403 .19236 .49903 Mtetra
.563 .76 .971 r
.19236 .49903 .19919 .50403 .20883 .50173 .20195 .49737 Mtetra
.549 .782 .985 r
.20195 .49737 .20883 .50173 .21853 .49921 .21159 .4957 Mtetra
.525 .808 .998 r
.21159 .4957 .21853 .49921 .2283 .49637 .22129 .49398 Mtetra
.493 .838 .997 r
.22129 .49398 .2283 .49637 .23815 .49304 .23104 .49203 Mtetra
.438 .854 .958 r
.23104 .49203 .23815 .49304 .24809 .48905 .24087 .48973 Mtetra
.354 .829 .85 r
.24087 .48973 .24809 .48905 .25812 .48427 .2508 .48685 Mtetra
.253 .749 .677 r
.2508 .48685 .25812 .48427 .26826 .47855 .26082 .48319 Mtetra
0 0 0 r
.26082 .48319 .26826 .47855 .27849 .47195 .27095 .4786 Mtetra
.27095 .4786 .27849 .47195 .28879 .46444 .28119 .4729 Mtetra
.28119 .4729 .28879 .46444 .29916 .45632 .29154 .46612 Mtetra
.29154 .46612 .29916 .45632 .30956 .44778 .30197 .45824 Mtetra
.30197 .45824 .30956 .44778 .31996 .43932 .31247 .44951 Mtetra
.31247 .44951 .31996 .43932 .33034 .43135 .32302 .44016 Mtetra
.32302 .44016 .33034 .43135 .34067 .42432 .33357 .43069 Mtetra
.33357 .43069 .34067 .42432 .35095 .41863 .34411 .42151 Mtetra
.709 .982 .795 r
.34411 .42151 .35095 .41863 .36118 .4143 .35463 .4127 Mtetra
.818 .933 .907 r
.35463 .4127 .36118 .4143 .37138 .41142 .36513 .40448 Mtetra
.757 .756 .851 r
.36513 .40448 .37138 .41142 .38157 .40973 .37558 .39747 Mtetra
.683 .623 .783 r
.37558 .39747 .38157 .40973 .39177 .40906 .38599 .39194 Mtetra
.639 .546 .733 r
.38599 .39194 .39177 .40906 .40198 .40928 .39638 .38738 Mtetra
.612 .496 .696 r
.39638 .38738 .40198 .40928 .41225 .40987 .40679 .38348 Mtetra
.602 .468 .671 r
.40679 .38348 .41225 .40987 .42265 .40865 .41723 .37956 Mtetra
.596 .454 .659 r
.41723 .37956 .42265 .40865 .43317 .40494 .4277 .37567 Mtetra
.569 .435 .659 r
.4277 .37567 .43317 .40494 .44375 .40034 .43816 .37395 Mtetra
.535 .424 .674 r
.43816 .37395 .44375 .40034 .45436 .39559 .44861 .37461 Mtetra
.525 .448 .712 r
.44861 .37461 .45436 .39559 .465 .39147 .45912 .37561 Mtetra
.544 .507 .764 r
.45912 .37561 .465 .39147 .47567 .38814 .46973 .37555 Mtetra
.638 .602 .797 r
.46973 .37555 .47567 .38814 .48638 .38454 .48045 .37192 Mtetra
.709 .636 .773 r
.48045 .37192 .48638 .38454 .49714 .38068 .49125 .36472 Mtetra
.702 .594 .732 r
.49125 .36472 .49714 .38068 .50793 .37761 .50207 .35644 Mtetra
.668 .537 .695 r
.50207 .35644 .50793 .37761 .51877 .37518 .51291 .34849 Mtetra
.62 .48 .67 r
.51291 .34849 .51877 .37518 .52966 .37259 .52376 .34292 Mtetra
.588 .448 .658 r
.52376 .34292 .52966 .37259 .54059 .36912 .53464 .33953 Mtetra
.588 .449 .659 r
.53464 .33953 .54059 .36912 .55155 .36312 .54557 .33618 Mtetra
.592 .461 .671 r
.54557 .33618 .55155 .36312 .56252 .35529 .55655 .3328 Mtetra
.591 .482 .699 r
.55655 .3328 .56252 .35529 .5735 .34781 .56758 .3301 Mtetra
.581 .512 .742 r
.56758 .3301 .5735 .34781 .58452 .34123 .57868 .32838 Mtetra
.542 .552 .814 r
.57868 .32838 .58452 .34123 .59559 .33567 .58987 .32817 Mtetra
.428 .625 .935 r
.58987 .32817 .59559 .33567 .60672 .33132 .60116 .32921 Mtetra
.029 .573 .84 r
.60116 .32921 .60672 .33132 .61794 .32844 .61255 .33086 Mtetra
.36 0 0 r
.61255 .33086 .61794 .32844 .62925 .32696 .62404 .33291 Mtetra
.469 0 0 r
.62404 .33291 .62925 .32696 .64068 .32685 .63562 .33527 Mtetra
.492 .035 .095 r
.63562 .33527 .64068 .32685 .65222 .32772 .6473 .33754 Mtetra
.482 .045 .131 r
.6473 .33754 .65222 .32772 .66386 .32911 .65904 .33918 Mtetra
.457 .024 .126 r
.65904 .33918 .66386 .32911 .6756 .3306 .67083 .33997 Mtetra
.411 0 .084 r
.67083 .33997 .6756 .3306 .6874 .33167 .68265 .33963 Mtetra
.34 0 0 r
.68265 .33963 .6874 .33167 .69925 .33213 .69448 .33819 Mtetra
.218 0 0 r
.69448 .33819 .69925 .33213 .71113 .33166 .70632 .33561 Mtetra
.026 0 0 r
.70632 .33561 .71113 .33166 .72303 .33027 .71816 .33206 Mtetra
.246 .743 .665 r
.71816 .33206 .72303 .33027 .73493 .32792 .72999 .32769 Mtetra
.497 .906 .883 r
.72999 .32769 .73493 .32792 .74683 .32475 .74184 .32271 Mtetra
.638 .936 .966 r
.74184 .32271 .74683 .32475 .75874 .32089 .7537 .31736 Mtetra
.694 .905 .97 r
.7537 .31736 .75874 .32089 .77066 .31651 .76558 .31177 Mtetra
.71 .865 .955 r
.76558 .31177 .77066 .31651 .7826 .31179 .77749 .30611 Mtetra
.714 .832 .938 r
.77749 .30611 .7826 .31179 .79457 .30684 .78944 .30043 Mtetra
.712 .807 .924 r
.78944 .30043 .79457 .30684 .80657 .30177 .80143 .29478 Mtetra
.707 .787 .914 r
.80143 .29478 .80657 .30177 .81861 .29669 .81347 .28921 Mtetra
.588 .732 .943 r
.16646 .49655 .17328 .5025 .1828 .50072 .176 .4947 Mtetra
.579 .728 .944 r
.176 .4947 .1828 .50072 .19236 .49903 .18557 .49299 Mtetra
.569 .725 .947 r
.18557 .49299 .19236 .49903 .20195 .49737 .19517 .49146 Mtetra
.555 .725 .953 r
.19517 .49146 .20195 .49737 .21159 .4957 .2048 .49011 Mtetra
.532 .73 .965 r
.2048 .49011 .21159 .4957 .22129 .49398 .21445 .48901 Mtetra
.506 .745 .981 r
.21445 .48901 .22129 .49398 .23104 .49203 .22413 .48805 Mtetra
.461 .767 .996 r
.22413 .48805 .23104 .49203 .24087 .48973 .23386 .48719 Mtetra
.389 .788 .985 r
.23386 .48719 .24087 .48973 .2508 .48685 .24365 .48621 Mtetra
.255 .759 .883 r
.24365 .48621 .2508 .48685 .26082 .48319 .25352 .48497 Mtetra
0 0 0 r
.25352 .48497 .26082 .48319 .27095 .4786 .26347 .48323 Mtetra
.09 0 0 r
.26347 .48323 .27095 .4786 .28119 .4729 .27352 .48075 Mtetra
.189 0 0 r
.27352 .48075 .28119 .4729 .29154 .46612 .28369 .47737 Mtetra
.239 0 .041 r
.28369 .47737 .29154 .46612 .30197 .45824 .29397 .47291 Mtetra
.268 0 .132 r
.29397 .47291 .30197 .45824 .31247 .44951 .30436 .46732 Mtetra
.279 0 .186 r
.30436 .46732 .31247 .44951 .32302 .44016 .31484 .46054 Mtetra
.29 0 .222 r
.31484 .46054 .32302 .44016 .33357 .43069 .32541 .45289 Mtetra
.295 0 .242 r
.32541 .45289 .33357 .43069 .34411 .42151 .33602 .44455 Mtetra
.288 0 .248 r
.33602 .44455 .34411 .42151 .35463 .4127 .34668 .43558 Mtetra
.275 0 .241 r
.34668 .43558 .35463 .4127 .36513 .40448 .35736 .42619 Mtetra
.277 0 .232 r
.35736 .42619 .36513 .40448 .37558 .39747 .36802 .41733 Mtetra
.283 0 .218 r
.36802 .41733 .37558 .39747 .38599 .39194 .37864 .40947 Mtetra
.253 0 .176 r
.37864 .40947 .38599 .39194 .39638 .38738 .38927 .40184 Mtetra
.199 0 .102 r
.38927 .40184 .39638 .38738 .40679 .38348 .3999 .39451 Mtetra
.194 0 .021 r
.3999 .39451 .40679 .38348 .41723 .37956 .41047 .38904 Mtetra
.296 0 .031 r
.41047 .38904 .41723 .37956 .4277 .37567 .42099 .38622 Mtetra
.466 .045 .157 r
.42099 .38622 .4277 .37567 .43816 .37395 .43146 .38696 Mtetra
.555 .163 .252 r
.43146 .38696 .43816 .37395 .44861 .37461 .44191 .39067 Mtetra
.545 .175 .289 r
.44191 .39067 .44861 .37461 .45912 .37561 .45247 .39386 Mtetra
.498 .142 .293 r
.45247 .39386 .45912 .37561 .46973 .37555 .46316 .39458 Mtetra
.403 .058 .263 r
.46316 .39458 .46973 .37555 .48045 .37192 .47399 .39095 Mtetra
.281 0 .213 r
.47399 .39095 .48045 .37192 .49125 .36472 .48492 .38295 Mtetra
.183 0 .163 r
.48492 .38295 .49125 .36472 .50207 .35644 .49589 .37246 Mtetra
.105 0 .097 r
.49589 .37246 .50207 .35644 .51291 .34849 .50685 .36143 Mtetra
.145 0 .055 r
.50685 .36143 .51291 .34849 .52376 .34292 .51781 .35336 Mtetra
.247 0 .039 r
.51781 .35336 .52376 .34292 .53464 .33953 .52878 .34887 Mtetra
.348 0 .055 r
.52878 .34887 .53464 .33953 .54557 .33618 .5398 .34705 Mtetra
.443 .023 .146 r
.5398 .34705 .54557 .33618 .55655 .3328 .55089 .34712 Mtetra
.476 .09 .229 r
.55089 .34712 .55655 .3328 .56758 .3301 .56207 .34751 Mtetra
.493 .129 .278 r
.56207 .34751 .56758 .3301 .57868 .32838 .57331 .34815 Mtetra
.516 .165 .31 r
.57331 .34815 .57868 .32838 .58987 .32817 .58466 .34982 Mtetra
.527 .183 .329 r
.58466 .34982 .58987 .32817 .60116 .32921 .5961 .35205 Mtetra
.521 .183 .335 r
.5961 .35205 .60116 .32921 .61255 .33086 .60763 .35386 Mtetra
.512 .175 .333 r
.60763 .35386 .61255 .33086 .62404 .33291 .61922 .35506 Mtetra
.5 .16 .322 r
.61922 .35506 .62404 .33291 .63562 .33527 .63087 .35556 Mtetra
.48 .133 .3 r
.63087 .35556 .63562 .33527 .6473 .33754 .64257 .35518 Mtetra
.445 .085 .259 r
.64257 .35518 .6473 .33754 .65904 .33918 .6543 .35358 Mtetra
.391 .011 .192 r
.6543 .35358 .65904 .33918 .67083 .33997 .66604 .35083 Mtetra
.299 0 .076 r
.66604 .35083 .67083 .33997 .68265 .33963 .67778 .34696 Mtetra
.137 0 0 r
.67778 .34696 .68265 .33963 .69448 .33819 .68953 .34215 Mtetra
0 0 0 r
.68953 .34215 .69448 .33819 .70632 .33561 .70127 .33658 Mtetra
.487 .897 .798 r
.70127 .33658 .70632 .33561 .71816 .33206 .71302 .33048 Mtetra
.68 .959 .945 r
.71302 .33048 .71816 .33206 .72999 .32769 .72479 .32409 Mtetra
.735 .912 .954 r
.72479 .32409 .72999 .32769 .74184 .32271 .73658 .31757 Mtetra
.74 .857 .935 r
.73658 .31757 .74184 .32271 .7537 .31736 .74841 .31114 Mtetra
.733 .818 .917 r
.74841 .31114 .7537 .31736 .76558 .31177 .76028 .30484 Mtetra
.722 .793 .907 r
.76028 .30484 .76558 .31177 .77749 .30611 .77221 .29879 Mtetra
.715 .778 .902 r
.77221 .29879 .77749 .30611 .78944 .30043 .78418 .29293 Mtetra
.709 .771 .901 r
.78418 .29293 .78944 .30043 .80143 .29478 .79621 .28723 Mtetra
.704 .769 .903 r
.79621 .28723 .80143 .29478 .81347 .28921 .8083 .28168 Mtetra
.622 .743 .933 r
.15958 .49055 .16646 .49655 .176 .4947 .16921 .48802 Mtetra
.618 .719 .918 r
.16921 .48802 .176 .4947 .18557 .49299 .17887 .48564 Mtetra
.61 .696 .905 r
.17887 .48564 .18557 .49299 .19517 .49146 .18855 .48346 Mtetra
.598 .673 .893 r
.18855 .48346 .19517 .49146 .2048 .49011 .19823 .48158 Mtetra
.582 .653 .885 r
.19823 .48158 .2048 .49011 .21445 .48901 .20793 .48009 Mtetra
.566 .636 .88 r
.20793 .48009 .21445 .48901 .22413 .48805 .21764 .47897 Mtetra
.547 .625 .881 r
.21764 .47897 .22413 .48805 .23386 .48719 .22736 .47828 Mtetra
.531 .623 .888 r
.22736 .47828 .23386 .48719 .24365 .48621 .2371 .47788 Mtetra
.513 .632 .905 r
.2371 .47788 .24365 .48621 .25352 .48497 .24689 .47771 Mtetra
.495 .659 .934 r
.24689 .47771 .25352 .48497 .26347 .48323 .25672 .47757 Mtetra
.468 .707 .972 r
.25672 .47757 .26347 .48323 .27352 .48075 .26663 .47726 Mtetra
.409 .766 .995 r
.26663 .47726 .27352 .48075 .28369 .47737 .27662 .47658 Mtetra
.266 .764 .893 r
.27662 .47658 .28369 .47737 .29397 .47291 .28671 .4753 Mtetra
0 0 0 r
.28671 .4753 .29397 .47291 .30436 .46732 .29691 .47323 Mtetra
.116 0 0 r
.29691 .47323 .30436 .46732 .31484 .46054 .30722 .47015 Mtetra
.214 0 0 r
.30722 .47015 .31484 .46054 .32541 .45289 .31764 .46613 Mtetra
.265 0 .1 r
.31764 .46613 .32541 .45289 .33602 .44455 .32814 .46115 Mtetra
.293 0 .174 r
.32814 .46115 .33602 .44455 .34668 .43558 .33873 .45526 Mtetra
.312 0 .222 r
.33873 .45526 .34668 .43558 .35736 .42619 .34939 .44858 Mtetra
.338 .015 .261 r
.34939 .44858 .35736 .42619 .36802 .41733 .36007 .44172 Mtetra
.361 .044 .287 r
.36007 .44172 .36802 .41733 .37864 .40947 .37077 .435 Mtetra
.359 .048 .295 r
.37077 .435 .37864 .40947 .38927 .40184 .38152 .42778 Mtetra
.356 .047 .297 r
.38152 .42778 .38927 .40184 .3999 .39451 .39229 .42025 Mtetra
.395 .081 .311 r
.39229 .42025 .3999 .39451 .41047 .38904 .40301 .41454 Mtetra
.444 .125 .329 r
.40301 .41454 .41047 .38904 .42099 .38622 .41367 .41142 Mtetra
.477 .154 .339 r
.41367 .41142 .42099 .38622 .43146 .38696 .42431 .41022 Mtetra
.494 .161 .332 r
.42431 .41022 .43146 .38696 .44191 .39067 .43498 .41025 Mtetra
.47 .121 .292 r
.43498 .41025 .44191 .39067 .45247 .39386 .44573 .40953 Mtetra
.409 .037 .218 r
.44573 .40953 .45247 .39386 .46316 .39458 .45658 .40725 Mtetra
.325 0 .124 r
.45658 .40725 .46316 .39458 .47399 .39095 .4675 .40361 Mtetra
.269 0 .097 r
.4675 .40361 .47399 .39095 .48492 .38295 .47849 .3986 Mtetra
.269 0 .156 r
.47849 .3986 .48492 .38295 .49589 .37246 .48953 .39202 Mtetra
.307 0 .226 r
.48953 .39202 .49589 .37246 .50685 .36143 .5006 .38468 Mtetra
.375 .055 .288 r
.5006 .38468 .50685 .36143 .51781 .35336 .51169 .37856 Mtetra
.426 .108 .32 r
.51169 .37856 .51781 .35336 .52878 .34887 .5228 .37438 Mtetra
.472 .149 .337 r
.5228 .37438 .52878 .34887 .5398 .34705 .53396 .37281 Mtetra
.501 .176 .347 r
.53396 .37281 .5398 .34705 .55089 .34712 .54519 .37309 Mtetra
.497 .172 .347 r
.54519 .37309 .55089 .34712 .56207 .34751 .5565 .37306 Mtetra
.488 .163 .341 r
.5565 .37306 .56207 .34751 .57331 .34815 .56787 .37255 Mtetra
.488 .158 .333 r
.56787 .37255 .57331 .34815 .58466 .34982 .57932 .37218 Mtetra
.481 .143 .316 r
.57932 .37218 .58466 .34982 .5961 .35205 .59083 .37165 Mtetra
.457 .107 .282 r
.59083 .37165 .5961 .35205 .60763 .35386 .60239 .37031 Mtetra
.419 .051 .231 r
.60239 .37031 .60763 .35386 .61922 .35506 .614 .36805 Mtetra
.354 0 .145 r
.614 .36805 .61922 .35506 .63087 .35556 .62563 .36481 Mtetra
.234 0 0 r
.62563 .36481 .63087 .35556 .64257 .35518 .63729 .3606 Mtetra
0 0 0 r
.63729 .3606 .64257 .35518 .6543 .35358 .64894 .35535 Mtetra
.428 .859 .737 r
.64894 .35535 .6543 .35358 .66604 .35083 .66061 .34927 Mtetra
.703 .962 .943 r
.66061 .34927 .66604 .35083 .67778 .34696 .67228 .34257 Mtetra
.763 .884 .932 r
.67228 .34257 .67778 .34696 .68953 .34215 .68395 .33546 Mtetra
.759 .805 .89 r
.68395 .33546 .68953 .34215 .70127 .33658 .69565 .32818 Mtetra
.745 .753 .859 r
.69565 .32818 .70127 .33658 .71302 .33048 .70737 .3209 Mtetra
.729 .719 .841 r
.70737 .3209 .71302 .33048 .72479 .32409 .71912 .31385 Mtetra
.717 .701 .833 r
.71912 .31385 .72479 .32409 .73658 .31757 .73093 .3071 Mtetra
.706 .692 .834 r
.73093 .3071 .73658 .31757 .74841 .31114 .74279 .30077 Mtetra
.698 .691 .84 r
.74279 .30077 .74841 .31114 .76028 .30484 .75472 .29482 Mtetra
.69 .696 .851 r
.75472 .29482 .76028 .30484 .77221 .29879 .76672 .28927 Mtetra
.685 .707 .864 r
.76672 .28927 .77221 .29879 .78418 .29293 .77878 .28402 Mtetra
.682 .722 .88 r
.77878 .28402 .78418 .29293 .79621 .28723 .7909 .27899 Mtetra
.68 .741 .897 r
.7909 .27899 .79621 .28723 .8083 .28168 .80308 .27409 Mtetra
.667 .754 .915 r
.15266 .48451 .15958 .49055 .16921 .48802 .16243 .48093 Mtetra
.662 .721 .892 r
.16243 .48093 .16921 .48802 .17887 .48564 .17221 .47744 Mtetra
.652 .687 .87 r
.17221 .47744 .17887 .48564 .18855 .48346 .18202 .47412 Mtetra
.639 .655 .85 r
.18202 .47412 .18855 .48346 .19823 .48158 .19183 .47109 Mtetra
.623 .625 .832 r
.19183 .47109 .19823 .48158 .20793 .48009 .20164 .46844 Mtetra
.606 .596 .815 r
.20164 .46844 .20793 .48009 .21764 .47897 .21145 .46625 Mtetra
.587 .569 .801 r
.21145 .46625 .21764 .47897 .22736 .47828 .22125 .46462 Mtetra
.57 .546 .789 r
.22125 .46462 .22736 .47828 .2371 .47788 .23105 .46352 Mtetra
.553 .528 .781 r
.23105 .46352 .2371 .47788 .24689 .47771 .24086 .46301 Mtetra
.539 .516 .779 r
.24086 .46301 .24689 .47771 .25672 .47757 .25067 .46296 Mtetra
.526 .511 .782 r
.25067 .46296 .25672 .47757 .26663 .47726 .26052 .46331 Mtetra
.516 .515 .793 r
.26052 .46331 .26663 .47726 .27662 .47658 .2704 .46389 Mtetra
.506 .531 .816 r
.2704 .46389 .27662 .47658 .28671 .4753 .28035 .46456 Mtetra
.498 .567 .856 r
.28035 .46456 .28671 .4753 .29691 .47323 .29036 .46511 Mtetra
.484 .631 .918 r
.29036 .46511 .29691 .47323 .30722 .47015 .30047 .46532 Mtetra
.429 .726 .988 r
.30047 .46532 .30722 .47015 .31764 .46613 .31066 .46505 Mtetra
.236 .741 .892 r
.31066 .46505 .31764 .46613 .32814 .46115 .32096 .46415 Mtetra
.083 0 0 r
.32096 .46415 .32814 .46115 .33873 .45526 .33135 .46268 Mtetra
.267 0 0 r
.33135 .46268 .33873 .45526 .34939 .44858 .34182 .46063 Mtetra
.343 0 .113 r
.34182 .46063 .34939 .44858 .36007 .44172 .35238 .45793 Mtetra
.373 .004 .204 r
.35238 .45793 .36007 .44172 .37077 .435 .36302 .4545 Mtetra
.377 .031 .247 r
.36302 .4545 .37077 .435 .38152 .42778 .37375 .45013 Mtetra
.378 .048 .274 r
.37375 .45013 .38152 .42778 .39229 .42025 .38455 .44489 Mtetra
.403 .081 .302 r
.38455 .44489 .39229 .42025 .40301 .41454 .39536 .44004 Mtetra
.419 .099 .315 r
.39536 .44004 .40301 .41454 .41367 .41142 .40619 .43573 Mtetra
.383 .062 .293 r
.40619 .43573 .41367 .41142 .42431 .41022 .41711 .43 Mtetra
.295 0 .216 r
.41711 .43 .42431 .41022 .43498 .41025 .42811 .42256 Mtetra
.108 0 .002 r
.42811 .42256 .43498 .41025 .44573 .40953 .43913 .41474 Mtetra
0 0 0 r
.43913 .41474 .44573 .40953 .45658 .40725 .45015 .4077 Mtetra
.396 .853 .857 r
.45015 .4077 .45658 .40725 .4675 .40361 .46113 .40403 Mtetra
.009 0 0 r
.46113 .40403 .4675 .40361 .47849 .3986 .4721 .40377 Mtetra
.361 0 0 r
.4721 .40377 .47849 .3986 .48953 .39202 .48312 .40428 Mtetra
.451 .043 .172 r
.48312 .40428 .48953 .39202 .5006 .38468 .49422 .40443 Mtetra
.45 .1 .28 r
.49422 .40443 .5006 .38468 .51169 .37856 .5054 .40288 Mtetra
.441 .115 .315 r
.5054 .40288 .51169 .37856 .5228 .37438 .51665 .39989 Mtetra
.455 .132 .327 r
.51665 .39989 .5228 .37438 .53396 .37281 .52795 .39745 Mtetra
.459 .132 .323 r
.52795 .39745 .53396 .37281 .54519 .37309 .53931 .39541 Mtetra
.435 .1 .297 r
.53931 .39541 .54519 .37309 .5565 .37306 .55072 .3925 Mtetra
.397 .05 .256 r
.55072 .3925 .5565 .37306 .56787 .37255 .56217 .38863 Mtetra
.346 0 .193 r
.56217 .38863 .56787 .37255 .57932 .37218 .57366 .38401 Mtetra
.246 0 .066 r
.57366 .38401 .57932 .37218 .59083 .37165 .58518 .37872 Mtetra
.024 0 0 r
.58518 .37872 .59083 .37165 .60239 .37031 .59672 .37284 Mtetra
.409 .838 .686 r
.59672 .37284 .60239 .37031 .614 .36805 .60828 .36636 Mtetra
.735 .962 .94 r
.60828 .36636 .614 .36805 .62563 .36481 .61985 .35923 Mtetra
.776 .84 .901 r
.61985 .35923 .62563 .36481 .63729 .3606 .63143 .35158 Mtetra
.754 .738 .837 r
.63143 .35158 .63729 .3606 .64894 .35535 .64302 .34358 Mtetra
.732 .675 .795 r
.64302 .34358 .64894 .35535 .66061 .34927 .65461 .33542 Mtetra
.713 .636 .77 r
.65461 .33542 .66061 .34927 .67228 .34257 .66624 .32735 Mtetra
.699 .612 .756 r
.66624 .32735 .67228 .34257 .68395 .33546 .67789 .3195 Mtetra
.688 .598 .751 r
.67789 .3195 .68395 .33546 .69565 .32818 .68958 .31205 Mtetra
.679 .592 .751 r
.68958 .31205 .69565 .32818 .70737 .3209 .70132 .30506 Mtetra
.671 .591 .758 r
.70132 .30506 .70737 .3209 .71912 .31385 .71313 .29867 Mtetra
.665 .596 .768 r
.71313 .29867 .71912 .31385 .73093 .3071 .725 .29283 Mtetra
.659 .605 .783 r
.725 .29283 .73093 .3071 .74279 .30077 .73696 .28755 Mtetra
.654 .619 .802 r
.73696 .28755 .74279 .30077 .75472 .29482 .74898 .28274 Mtetra
.651 .637 .823 r
.74898 .28274 .75472 .29482 .76672 .28927 .76109 .27834 Mtetra
.648 .659 .847 r
.76109 .27834 .76672 .28927 .77878 .28402 .77327 .27422 Mtetra
.646 .685 .872 r
.77327 .27422 .77878 .28402 .7909 .27899 .78551 .27029 Mtetra
.645 .714 .898 r
.78551 .27029 .7909 .27899 .80308 .27409 .79782 .26643 Mtetra
.704 .761 .897 r
.14569 .47843 .15266 .48451 .16243 .48093 .15559 .47381 Mtetra
.698 .73 .875 r
.15559 .47381 .16243 .48093 .17221 .47744 .16552 .46919 Mtetra
.688 .698 .854 r
.16552 .46919 .17221 .47744 .18202 .47412 .17547 .46466 Mtetra
.676 .667 .834 r
.17547 .46466 .18202 .47412 .19183 .47109 .18542 .46029 Mtetra
.662 .636 .814 r
.18542 .46029 .19183 .47109 .20164 .46844 .19539 .45618 Mtetra
.645 .604 .794 r
.19539 .45618 .20164 .46844 .21145 .46625 .20535 .45242 Mtetra
.627 .574 .775 r
.20535 .45242 .21145 .46625 .22125 .46462 .2153 .44911 Mtetra
.609 .545 .757 r
.2153 .44911 .22125 .46462 .23105 .46352 .22525 .44634 Mtetra
.591 .517 .74 r
.22525 .44634 .23105 .46352 .24086 .46301 .23517 .44419 Mtetra
.575 .494 .726 r
.23517 .44419 .24086 .46301 .25067 .46296 .24509 .44266 Mtetra
.56 .473 .714 r
.24509 .44266 .25067 .46296 .26052 .46331 .25501 .44176 Mtetra
.547 .457 .705 r
.25501 .44176 .26052 .46331 .2704 .46389 .26494 .44142 Mtetra
.537 .445 .698 r
.26494 .44142 .2704 .46389 .28035 .46456 .27488 .4416 Mtetra
.53 .438 .695 r
.27488 .4416 .28035 .46456 .29036 .46511 .28486 .44215 Mtetra
.525 .435 .696 r
.28486 .44215 .29036 .46511 .30047 .46532 .29489 .44294 Mtetra
.524 .439 .701 r
.29489 .44294 .30047 .46532 .31066 .46505 .30498 .44373 Mtetra
.527 .448 .71 r
.30498 .44373 .31066 .46505 .32096 .46415 .31515 .44435 Mtetra
.528 .461 .724 r
.31515 .44435 .32096 .46415 .33135 .46268 .3254 .44486 Mtetra
.53 .48 .745 r
.3254 .44486 .33135 .46268 .34182 .46063 .33571 .44521 Mtetra
.546 .517 .774 r
.33571 .44521 .34182 .46063 .35238 .45793 .34614 .44487 Mtetra
.572 .565 .808 r
.34614 .44487 .35238 .45793 .36302 .4545 .35667 .44359 Mtetra
.596 .617 .843 r
.35667 .44359 .36302 .4545 .37375 .45013 .3673 .44157 Mtetra
.622 .684 .888 r
.3673 .44157 .37375 .45013 .38455 .44489 .37801 .43881 Mtetra
.645 .77 .939 r
.37801 .43881 .38455 .44489 .39536 .44004 .38879 .43538 Mtetra
.684 .832 .954 r
.38879 .43538 .39536 .44004 .40619 .43573 .39967 .43089 Mtetra
.787 .84 .892 r
.39967 .43089 .40619 .43573 .41711 .43 .41069 .42316 Mtetra
.822 .783 .816 r
.41069 .42316 .41711 .43 .42811 .42256 .42183 .41228 Mtetra
.785 .705 .776 r
.42183 .41228 .42811 .42256 .43913 .41474 .43297 .4014 Mtetra
.729 .64 .759 r
.43297 .4014 .43913 .41474 .45015 .4077 .44405 .39253 Mtetra
.627 .567 .768 r
.44405 .39253 .45015 .4077 .46113 .40403 .45502 .38883 Mtetra
.49 .491 .785 r
.45502 .38883 .46113 .40403 .4721 .40377 .46595 .39032 Mtetra
.397 .465 .813 r
.46595 .39032 .4721 .40377 .48312 .40428 .47693 .39385 Mtetra
.336 .495 .869 r
.47693 .39385 .48312 .40428 .49422 .40443 .488 .3974 Mtetra
.442 .658 .953 r
.488 .3974 .49422 .40443 .5054 .40288 .49919 .3978 Mtetra
.598 .801 .977 r
.49919 .3978 .5054 .40288 .51665 .39989 .51047 .39495 Mtetra
.65 .824 .967 r
.51047 .39495 .51665 .39989 .52795 .39745 .52181 .39102 Mtetra
.683 .782 .925 r
.52181 .39102 .52795 .39745 .53931 .39541 .53319 .38641 Mtetra
.695 .712 .862 r
.53319 .38641 .53931 .39541 .55072 .3925 .54461 .38105 Mtetra
.696 .662 .812 r
.54461 .38105 .55072 .3925 .56217 .38863 .55605 .37493 Mtetra
.698 .628 .775 r
.55605 .37493 .56217 .38863 .57366 .38401 .56752 .36784 Mtetra
.692 .596 .744 r
.56752 .36784 .57366 .38401 .58518 .37872 .57899 .36004 Mtetra
.68 .567 .721 r
.57899 .36004 .58518 .37872 .59672 .37284 .59049 .35205 Mtetra
.67 .547 .705 r
.59049 .35205 .59672 .37284 .60828 .36636 .60199 .34394 Mtetra
.665 .533 .694 r
.60199 .34394 .60828 .36636 .61985 .35923 .61351 .33563 Mtetra
.66 .524 .687 r
.61351 .33563 .61985 .35923 .63143 .35158 .62505 .32731 Mtetra
.654 .517 .684 r
.62505 .32731 .63143 .35158 .64302 .34358 .63661 .31922 Mtetra
.649 .514 .684 r
.63661 .31922 .64302 .34358 .65461 .33542 .6482 .3115 Mtetra
.645 .513 .688 r
.6482 .3115 .65461 .33542 .66624 .32735 .65984 .30429 Mtetra
.641 .515 .695 r
.65984 .30429 .66624 .32735 .67789 .3195 .67153 .29765 Mtetra
.636 .52 .705 r
.67153 .29765 .67789 .3195 .68958 .31205 .68328 .29166 Mtetra
.633 .528 .718 r
.68328 .29166 .68958 .31205 .70132 .30506 .69511 .28629 Mtetra
.628 .539 .734 r
.69511 .28629 .70132 .30506 .71313 .29867 .70701 .28156 Mtetra
.625 .553 .754 r
.70701 .28156 .71313 .29867 .725 .29283 .71899 .27738 Mtetra
.621 .57 .776 r
.71899 .27738 .725 .29283 .73696 .28755 .73105 .27368 Mtetra
.618 .591 .8 r
.73105 .27368 .73696 .28755 .74898 .28274 .7432 .27034 Mtetra
.615 .614 .827 r
.7432 .27034 .74898 .28274 .76109 .27834 .75542 .26725 Mtetra
.613 .64 .853 r
.75542 .26725 .76109 .27834 .77327 .27422 .76772 .26435 Mtetra
.61 .667 .88 r
.76772 .26435 .77327 .27422 .78551 .27029 .78009 .26153 Mtetra
.608 .697 .907 r
.78009 .26153 .78551 .27029 .79782 .26643 .79252 .25872 Mtetra
.726 .765 .884 r
.13868 .4723 .14569 .47843 .15559 .47381 .14869 .4669 Mtetra
.722 .742 .868 r
.14869 .4669 .15559 .47381 .16552 .46919 .15873 .46143 Mtetra
.716 .719 .852 r
.15873 .46143 .16552 .46919 .17547 .46466 .1688 .45592 Mtetra
.708 .695 .835 r
.1688 .45592 .17547 .46466 .18542 .46029 .17889 .45043 Mtetra
.699 .668 .817 r
.17889 .45043 .18542 .46029 .19539 .45618 .189 .44497 Mtetra
.686 .64 .798 r
.189 .44497 .19539 .45618 .20535 .45242 .19912 .43966 Mtetra
.671 .61 .779 r
.19912 .43966 .20535 .45242 .2153 .44911 .20925 .43457 Mtetra
.654 .58 .759 r
.20925 .43457 .2153 .44911 .22525 .44634 .21937 .42983 Mtetra
.636 .549 .74 r
.21937 .42983 .22525 .44634 .23517 .44419 .22948 .42553 Mtetra
.618 .521 .722 r
.22948 .42553 .23517 .44419 .24509 .44266 .23958 .42176 Mtetra
.601 .495 .705 r
.23958 .42176 .24509 .44266 .25501 .44176 .24966 .41859 Mtetra
.585 .471 .69 r
.24966 .41859 .25501 .44176 .26494 .44142 .25973 .41604 Mtetra
.571 .451 .677 r
.25973 .41604 .26494 .44142 .27488 .4416 .2698 .41414 Mtetra
.559 .435 .666 r
.2698 .41414 .27488 .4416 .28486 .44215 .27986 .41283 Mtetra
.55 .421 .658 r
.27986 .41283 .28486 .44215 .29489 .44294 .28994 .4121 Mtetra
.544 .412 .651 r
.28994 .4121 .29489 .44294 .30498 .44373 .30005 .41172 Mtetra
.541 .406 .647 r
.30005 .41172 .30498 .44373 .31515 .44435 .31021 .41153 Mtetra
.537 .402 .644 r
.31021 .41153 .31515 .44435 .3254 .44486 .32041 .41162 Mtetra
.534 .399 .643 r
.32041 .41162 .3254 .44486 .33571 .44521 .33067 .41193 Mtetra
.539 .403 .643 r
.33067 .41193 .33571 .44521 .34614 .44487 .34101 .41182 Mtetra
.548 .41 .645 r
.34101 .41182 .34614 .44487 .35667 .44359 .35145 .41104 Mtetra
.55 .413 .647 r
.35145 .41104 .35667 .44359 .3673 .44157 .36196 .41015 Mtetra
.552 .418 .652 r
.36196 .41015 .3673 .44157 .37801 .43881 .37253 .40917 Mtetra
.567 .435 .66 r
.37253 .40917 .37801 .43881 .38879 .43538 .3832 .40712 Mtetra
.593 .457 .665 r
.3832 .40712 .38879 .43538 .39967 .43089 .39401 .4033 Mtetra
.634 .487 .665 r
.39401 .4033 .39967 .43089 .41069 .42316 .40497 .39615 Mtetra
.667 .511 .663 r
.40497 .39615 .41069 .42316 .42183 .41228 .41606 .38597 Mtetra
.668 .514 .667 r
.41606 .38597 .42183 .41228 .43297 .4014 .42715 .37599 Mtetra
.65 .506 .674 r
.42715 .37599 .43297 .4014 .44405 .39253 .43818 .36805 Mtetra
.599 .478 .686 r
.43818 .36805 .44405 .39253 .45502 .38883 .44913 .36431 Mtetra
.531 .434 .69 r
.44913 .36431 .45502 .38883 .46595 .39032 .46003 .36478 Mtetra
.494 .405 .684 r
.46003 .36478 .46595 .39032 .47693 .39385 .47097 .36731 Mtetra
.492 .399 .678 r
.47097 .36731 .47693 .39385 .488 .3974 .482 .37007 Mtetra
.543 .43 .674 r
.482 .37007 .488 .3974 .49919 .3978 .49315 .3698 Mtetra
.59 .458 .669 r
.49315 .3698 .49919 .3978 .51047 .39495 .50439 .36617 Mtetra
.61 .468 .664 r
.50439 .36617 .51047 .39495 .52181 .39102 .51568 .36075 Mtetra
.618 .468 .657 r
.51568 .36075 .52181 .39102 .53319 .38641 .52701 .35425 Mtetra
.615 .46 .649 r
.52701 .35425 .53319 .38641 .54461 .38105 .53837 .34763 Mtetra
.613 .455 .645 r
.53837 .34763 .54461 .38105 .55605 .37493 .54975 .34091 Mtetra
.618 .457 .642 r
.54975 .34091 .55605 .37493 .56752 .36784 .56115 .33348 Mtetra
.621 .459 .641 r
.56115 .33348 .56752 .36784 .57899 .36004 .57257 .32562 Mtetra
.619 .457 .641 r
.57257 .32562 .57899 .36004 .59049 .35205 .58401 .31796 Mtetra
.617 .457 .642 r
.58401 .31796 .59049 .35205 .60199 .34394 .59547 .31057 Mtetra
.617 .458 .645 r
.59547 .31057 .60199 .34394 .61351 .33563 .60697 .30338 Mtetra
.616 .461 .649 r
.60697 .30338 .61351 .33563 .62505 .32731 .61849 .29652 Mtetra
.613 .464 .655 r
.61849 .29652 .62505 .32731 .63661 .31922 .63007 .29025 Mtetra
.611 .469 .664 r
.63007 .29025 .63661 .31922 .6482 .3115 .6417 .28457 Mtetra
.608 .475 .675 r
.6417 .28457 .6482 .3115 .65984 .30429 .65339 .27957 Mtetra
.605 .484 .688 r
.65339 .27957 .65984 .30429 .67153 .29765 .66516 .27519 Mtetra
.601 .495 .705 r
.66516 .27519 .67153 .29765 .68328 .29166 .677 .27143 Mtetra
.598 .509 .725 r
.677 .27143 .68328 .29166 .69511 .28629 .68892 .2682 Mtetra
.594 .526 .747 r
.68892 .2682 .69511 .28629 .70701 .28156 .70093 .26545 Mtetra
.591 .545 .772 r
.70093 .26545 .70701 .28156 .71899 .27738 .71303 .26306 Mtetra
.588 .568 .799 r
.71303 .26306 .71899 .27738 .73105 .27368 .7252 .2609 Mtetra
.585 .592 .826 r
.7252 .2609 .73105 .27368 .7432 .27034 .73745 .25889 Mtetra
.583 .618 .852 r
.73745 .25889 .7432 .27034 .75542 .26725 .74978 .25693 Mtetra
.581 .642 .876 r
.74978 .25693 .75542 .26725 .76772 .26435 .76218 .25498 Mtetra
.579 .667 .898 r
.76218 .25498 .76772 .26435 .78009 .26153 .77465 .253 Mtetra
.577 .69 .919 r
.77465 .253 .78009 .26153 .79252 .25872 .78718 .25095 Mtetra
.728 .765 .882 r
.13161 .46613 .13868 .4723 .14869 .4669 .14165 .46062 Mtetra
.731 .763 .878 r
.14165 .46062 .14869 .4669 .15873 .46143 .15174 .45498 Mtetra
.732 .759 .874 r
.15174 .45498 .15873 .46143 .1688 .45592 .16186 .44922 Mtetra
.733 .753 .868 r
.16186 .44922 .1688 .45592 .17889 .45043 .17201 .44334 Mtetra
.733 .743 .859 r
.17201 .44334 .17889 .45043 .189 .44497 .18221 .43733 Mtetra
.73 .728 .849 r
.18221 .43733 .189 .44497 .19912 .43966 .19243 .43126 Mtetra
.723 .709 .836 r
.19243 .43126 .19912 .43966 .20925 .43457 .20267 .42519 Mtetra
.713 .685 .822 r
.20267 .42519 .20925 .43457 .21937 .42983 .21292 .41922 Mtetra
.699 .658 .806 r
.21292 .41922 .21937 .42983 .22948 .42553 .22318 .41347 Mtetra
.682 .627 .788 r
.22318 .41347 .22948 .42553 .23958 .42176 .23343 .40803 Mtetra
.663 .596 .769 r
.23343 .40803 .23958 .42176 .24966 .41859 .24367 .403 Mtetra
.645 .565 .75 r
.24367 .403 .24966 .41859 .25973 .41604 .25391 .39841 Mtetra
.627 .535 .731 r
.25391 .39841 .25973 .41604 .2698 .41414 .26413 .3943 Mtetra
.61 .508 .714 r
.26413 .3943 .2698 .41414 .27986 .41283 .27436 .39068 Mtetra
.596 .484 .697 r
.27436 .39068 .27986 .41283 .28994 .4121 .28458 .38756 Mtetra
.586 .465 .682 r
.28458 .38756 .28994 .4121 .30005 .41172 .29483 .38473 Mtetra
.579 .45 .669 r
.29483 .38473 .30005 .41172 .31021 .41153 .30511 .38209 Mtetra
.571 .435 .657 r
.30511 .38209 .31021 .41153 .32041 .41162 .31541 .37973 Mtetra
.565 .423 .647 r
.31541 .37973 .32041 .41162 .33067 .41193 .32575 .37766 Mtetra
.564 .416 .639 r
.32575 .37766 .33067 .41193 .34101 .41182 .33614 .37544 Mtetra
.565 .412 .632 r
.33614 .37544 .34101 .41182 .35145 .41104 .3466 .37297 Mtetra
.557 .402 .627 r
.3466 .37297 .35145 .41104 .36196 .41015 .35707 .37109 Mtetra
.548 .394 .624 r
.35707 .37109 .36196 .41015 .37253 .40917 .36757 .36994 Mtetra
.553 .398 .624 r
.36757 .36994 .37253 .40917 .3832 .40712 .37814 .3683 Mtetra
.566 .408 .626 r
.37814 .3683 .3832 .40712 .39401 .4033 .38882 .36552 Mtetra
.585 .424 .629 r
.38882 .36552 .39401 .4033 .40497 .39615 .39962 .36089 Mtetra
.606 .444 .636 r
.39962 .36089 .40497 .39615 .41606 .38597 .41051 .35457 Mtetra
.612 .459 .65 r
.41051 .35457 .41606 .38597 .42715 .37599 .42143 .34843 Mtetra
.61 .47 .667 r
.42143 .34843 .42715 .37599 .43818 .36805 .43234 .34327 Mtetra
.598 .475 .684 r
.43234 .34327 .43818 .36805 .44913 .36431 .44326 .33949 Mtetra
.577 .462 .685 r
.44326 .33949 .44913 .36431 .46003 .36478 .45418 .33708 Mtetra
.559 .437 .67 r
.45418 .33708 .46003 .36478 .47097 .36731 .46514 .33567 Mtetra
.553 .419 .652 r
.46514 .33567 .47097 .36731 .482 .37007 .47616 .33444 Mtetra
.57 .419 .637 r
.47616 .33444 .482 .37007 .49315 .3698 .48727 .33152 Mtetra
.585 .424 .629 r
.48727 .33152 .49315 .3698 .50439 .36617 .49844 .32674 Mtetra
.594 .427 .626 r
.49844 .32674 .50439 .36617 .51568 .36075 .50965 .3208 Mtetra
.597 .429 .624 r
.50965 .3208 .51568 .36075 .52701 .35425 .5209 .31435 Mtetra
.591 .425 .625 r
.5209 .31435 .52701 .35425 .53837 .34763 .53217 .30864 Mtetra
.587 .424 .627 r
.53217 .30864 .53837 .34763 .54975 .34091 .54349 .30352 Mtetra
.591 .43 .632 r
.54349 .30352 .54975 .34091 .56115 .33348 .55483 .29813 Mtetra
.596 .438 .638 r
.55483 .29813 .56115 .33348 .57257 .32562 .56622 .2926 Mtetra
.597 .446 .646 r
.56622 .2926 .57257 .32562 .58401 .31796 .57764 .28734 Mtetra
.599 .454 .656 r
.57764 .28734 .58401 .31796 .59547 .31057 .58911 .28237 Mtetra
.602 .465 .667 r
.58911 .28237 .59547 .31057 .60697 .30338 .60062 .27759 Mtetra
.603 .477 .681 r
.60062 .27759 .60697 .30338 .61849 .29652 .61219 .2731 Mtetra
.602 .489 .697 r
.61219 .2731 .61849 .29652 .63007 .29025 .62381 .26912 Mtetra
.6 .502 .715 r
.62381 .26912 .63007 .29025 .6417 .28457 .6355 .26563 Mtetra
.596 .518 .736 r
.6355 .26563 .6417 .28457 .65339 .27957 .64727 .26265 Mtetra
.592 .535 .76 r
.64727 .26265 .65339 .27957 .66516 .27519 .65911 .26013 Mtetra
.586 .555 .787 r
.65911 .26013 .66516 .27519 .677 .27143 .67104 .25802 Mtetra
.579 .576 .814 r
.67104 .25802 .677 .27143 .68892 .2682 .68305 .25624 Mtetra
.571 .599 .842 r
.68305 .25624 .68892 .2682 .70093 .26545 .69514 .25469 Mtetra
.565 .622 .868 r
.69514 .25469 .70093 .26545 .71303 .26306 .70732 .25325 Mtetra
.561 .644 .89 r
.70732 .25325 .71303 .26306 .7252 .2609 .71956 .25182 Mtetra
.558 .663 .907 r
.71956 .25182 .7252 .2609 .73745 .25889 .73188 .25033 Mtetra
.56 .68 .92 r
.73188 .25033 .73745 .25889 .74978 .25693 .74426 .24871 Mtetra
.561 .692 .928 r
.74426 .24871 .74978 .25693 .76218 .25498 .75671 .24697 Mtetra
.564 .701 .933 r
.75671 .24697 .76218 .25498 .77465 .253 .76922 .2451 Mtetra
.568 .708 .936 r
.76922 .2451 .77465 .253 .78718 .25095 .7818 .24311 Mtetra
.714 .763 .891 r
.12449 .45992 .13161 .46613 .14165 .46062 .1345 .45489 Mtetra
.72 .78 .899 r
.1345 .45489 .14165 .46062 .15174 .45498 .14456 .44971 Mtetra
.728 .797 .906 r
.14456 .44971 .15174 .45498 .16186 .44922 .15466 .44437 Mtetra
.736 .812 .912 r
.15466 .44437 .16186 .44922 .17201 .44334 .16481 .43882 Mtetra
.744 .825 .914 r
.16481 .43882 .17201 .44334 .18221 .43733 .17501 .43302 Mtetra
.751 .833 .914 r
.17501 .43302 .18221 .43733 .19243 .43126 .18525 .427 Mtetra
.757 .836 .912 r
.18525 .427 .19243 .43126 .20267 .42519 .19554 .42078 Mtetra
.76 .832 .908 r
.19554 .42078 .20267 .42519 .21292 .41922 .20586 .41445 Mtetra
.759 .821 .901 r
.20586 .41445 .21292 .41922 .22318 .41347 .21621 .40807 Mtetra
.754 .801 .891 r
.21621 .40807 .22318 .41347 .23343 .40803 .22657 .40172 Mtetra
.744 .773 .876 r
.22657 .40172 .23343 .40803 .24367 .403 .23695 .39549 Mtetra
.731 .738 .857 r
.23695 .39549 .24367 .403 .25391 .39841 .24733 .38938 Mtetra
.715 .698 .833 r
.24733 .38938 .25391 .39841 .26413 .3943 .25773 .38344 Mtetra
.696 .655 .806 r
.25773 .38344 .26413 .3943 .27436 .39068 .26813 .37769 Mtetra
.677 .614 .778 r
.26813 .37769 .27436 .39068 .28458 .38756 .27854 .37215 Mtetra
.661 .577 .75 r
.27854 .37215 .28458 .38756 .29483 .38473 .28898 .36668 Mtetra
.647 .545 .725 r
.28898 .36668 .29483 .38473 .30511 .38209 .29944 .36122 Mtetra
.633 .516 .703 r
.29944 .36122 .30511 .38209 .31541 .37973 .30992 .35592 Mtetra
.619 .491 .684 r
.30992 .35592 .31541 .37973 .32575 .37766 .32041 .35085 Mtetra
.61 .471 .668 r
.32041 .35085 .32575 .37766 .33614 .37544 .33093 .34587 Mtetra
.601 .455 .656 r
.33093 .34587 .33614 .37544 .3466 .37297 .34147 .34106 Mtetra
.583 .436 .647 r
.34147 .34106 .3466 .37297 .35707 .37109 .35199 .33736 Mtetra
.564 .417 .64 r
.35199 .33736 .35707 .37109 .36757 .36994 .36247 .33505 Mtetra
.558 .41 .637 r
.36247 .33505 .36757 .36994 .37814 .3683 .37298 .33317 Mtetra
.557 .409 .636 r
.37298 .33317 .37814 .3683 .38882 .36552 .38355 .33137 Mtetra
.554 .41 .64 r
.38355 .33137 .38882 .36552 .39962 .36089 .39415 .32983 Mtetra
.555 .42 .652 r
.39415 .32983 .39962 .36089 .41051 .35457 .40481 .32846 Mtetra
.558 .442 .677 r
.40481 .32846 .41051 .35457 .42143 .34843 .41553 .32714 Mtetra
.571 .478 .711 r
.41553 .32714 .42143 .34843 .43234 .34327 .42632 .32537 Mtetra
.617 .533 .737 r
.42632 .32537 .43234 .34327 .44326 .33949 .43722 .32155 Mtetra
.653 .554 .73 r
.43722 .32155 .44326 .33949 .45418 .33708 .44822 .31568 Mtetra
.644 .523 .701 r
.44822 .31568 .45418 .33708 .46514 .33567 .45926 .30934 Mtetra
.626 .486 .672 r
.45926 .30934 .46514 .33567 .47616 .33444 .47032 .30305 Mtetra
.61 .458 .65 r
.47032 .30305 .47616 .33444 .48727 .33152 .48141 .29692 Mtetra
.601 .442 .639 r
.48141 .29692 .48727 .33152 .49844 .32674 .49252 .29105 Mtetra
.598 .438 .635 r
.49252 .29105 .49844 .32674 .50965 .3208 .50367 .28525 Mtetra
.594 .435 .636 r
.50367 .28525 .50965 .3208 .5209 .31435 .51484 .27987 Mtetra
.581 .429 .64 r
.51484 .27987 .5209 .31435 .53217 .30864 .52606 .2759 Mtetra
.57 .427 .647 r
.52606 .2759 .53217 .30864 .54349 .30352 .53732 .27306 Mtetra
.571 .435 .657 r
.53732 .27306 .54349 .30352 .55483 .29813 .54864 .27039 Mtetra
.573 .447 .671 r
.54864 .27039 .55483 .29813 .56622 .2926 .56001 .26781 Mtetra
.574 .462 .688 r
.56001 .26781 .56622 .2926 .57764 .28734 .57145 .26548 Mtetra
.576 .481 .71 r
.57145 .26548 .57764 .28734 .58911 .28237 .58295 .26331 Mtetra
.58 .506 .736 r
.58295 .26331 .58911 .28237 .60062 .27759 .59451 .26115 Mtetra
.583 .534 .766 r
.59451 .26115 .60062 .27759 .61219 .2731 .60614 .25907 Mtetra
.58 .565 .801 r
.60614 .25907 .61219 .2731 .62381 .26912 .61784 .25721 Mtetra
.575 .6 .84 r
.61784 .25721 .62381 .26912 .6355 .26563 .62961 .25555 Mtetra
.565 .636 .88 r
.62961 .25555 .6355 .26563 .64727 .26265 .64145 .25406 Mtetra
.551 .67 .917 r
.64145 .25406 .64727 .26265 .65911 .26013 .65338 .25271 Mtetra
.531 .7 .947 r
.65338 .25271 .65911 .26013 .67104 .25802 .66538 .25149 Mtetra
.514 .723 .968 r
.66538 .25149 .67104 .25802 .68305 .25624 .67745 .2503 Mtetra
.502 .741 .98 r
.67745 .2503 .68305 .25624 .69514 .25469 .6896 .24908 Mtetra
.499 .753 .986 r
.6896 .24908 .69514 .25469 .70732 .25325 .70182 .24774 Mtetra
.508 .762 .988 r
.70182 .24774 .70732 .25325 .71956 .25182 .7141 .2462 Mtetra
.522 .766 .986 r
.7141 .2462 .71956 .25182 .73188 .25033 .72644 .24443 Mtetra
.542 .766 .98 r
.72644 .24443 .73188 .25033 .74426 .24871 .73884 .24241 Mtetra
.559 .76 .972 r
.73884 .24241 .74426 .24871 .75671 .24697 .75129 .24018 Mtetra
.574 .75 .96 r
.75129 .24018 .75671 .24697 .76922 .2451 .7638 .23777 Mtetra
.586 .737 .948 r
.7638 .23777 .76922 .2451 .7818 .24311 .77637 .23521 Mtetra
.678 .757 .91 r
.11732 .45366 .12449 .45992 .1345 .45489 .12723 .44967 Mtetra
.684 .793 .932 r
.12723 .44967 .1345 .45489 .14456 .44971 .13718 .44557 Mtetra
.688 .833 .953 r
.13718 .44557 .14456 .44971 .15466 .44437 .14719 .4413 Mtetra
.69 .872 .967 r
.14719 .4413 .15466 .44437 .16481 .43882 .15725 .4368 Mtetra
.688 .909 .972 r
.15725 .4368 .16481 .43882 .17501 .43302 .16738 .43203 Mtetra
.679 .938 .966 r
.16738 .43203 .17501 .43302 .18525 .427 .17756 .42696 Mtetra
.664 .956 .946 r
.17756 .42696 .18525 .427 .19554 .42078 .18781 .42157 Mtetra
.643 .962 .917 r
.18781 .42157 .19554 .42078 .20586 .41445 .19812 .41589 Mtetra
.624 .96 .886 r
.19812 .41589 .20586 .41445 .21621 .40807 .20847 .40992 Mtetra
.615 .957 .863 r
.20847 .40992 .21621 .40807 .22657 .40172 .21888 .4037 Mtetra
.622 .96 .856 r
.21888 .4037 .22657 .40172 .23695 .39549 .22932 .39726 Mtetra
.649 .969 .868 r
.22932 .39726 .23695 .39549 .24733 .38938 .23981 .3906 Mtetra
.691 .979 .893 r
.23981 .3906 .24733 .38938 .25773 .38344 .25033 .38376 Mtetra
.731 .977 .92 r
.25033 .38376 .25773 .38344 .26813 .37769 .26088 .37684 Mtetra
.759 .957 .936 r
.26088 .37684 .26813 .37769 .27854 .37215 .27145 .36994 Mtetra
.772 .918 .936 r
.27145 .36994 .27854 .37215 .28898 .36668 .28203 .36311 Mtetra
.77 .873 .923 r
.28203 .36311 .28898 .36668 .29944 .36122 .29261 .35642 Mtetra
.755 .831 .91 r
.29261 .35642 .29944 .36122 .30992 .35592 .3032 .35007 Mtetra
.735 .795 .9 r
.3032 .35007 .30992 .35592 .32041 .35085 .31377 .34422 Mtetra
.719 .768 .892 r
.31377 .34422 .32041 .35085 .33093 .34587 .32435 .33876 Mtetra
.702 .751 .89 r
.32435 .33876 .33093 .34587 .34147 .34106 .33493 .33376 Mtetra
.664 .735 .903 r
.33493 .33376 .34147 .34106 .35199 .33736 .34547 .32987 Mtetra
.611 .712 .917 r
.34547 .32987 .35199 .33736 .36247 .33505 .35599 .32731 Mtetra
.578 .692 .919 r
.35599 .32731 .36247 .33505 .37298 .33317 .36652 .32548 Mtetra
.544 .68 .927 r
.36652 .32548 .37298 .33317 .38355 .33137 .37707 .32431 Mtetra
.431 .65 .951 r
.37707 .32431 .38355 .33137 .39415 .32983 .38761 .32479 Mtetra
.203 .602 .947 r
.38761 .32479 .39415 .32983 .40481 .32846 .39816 .32674 Mtetra
0 .499 .753 r
.39816 .32674 .40481 .32846 .41553 .32714 .4088 .32866 Mtetra
.18 0 0 r
.4088 .32866 .41553 .32714 .42632 .32537 .41956 .32915 Mtetra
0 0 0 r
.41956 .32915 .42632 .32537 .43722 .32155 .43053 .32531 Mtetra
.525 .89 .68 r
.43053 .32531 .43722 .32155 .44822 .31568 .44166 .31713 Mtetra
.769 .997 .837 r
.44166 .31713 .44822 .31568 .45926 .30934 .45283 .3075 Mtetra
.84 .947 .89 r
.45283 .3075 .45926 .30934 .47032 .30305 .46402 .29782 Mtetra
.795 .841 .886 r
.46402 .29782 .47032 .30305 .48141 .29692 .47518 .2896 Mtetra
.739 .769 .877 r
.47518 .2896 .48141 .29692 .49252 .29105 .48633 .28303 Mtetra
.717 .744 .873 r
.48633 .28303 .49252 .29105 .50367 .28525 .49751 .27713 Mtetra
.696 .735 .881 r
.49751 .27713 .50367 .28525 .51484 .27987 .50872 .27194 Mtetra
.653 .726 .903 r
.50872 .27194 .51484 .27987 .52606 .2759 .51995 .26811 Mtetra
.609 .714 .919 r
.51995 .26811 .52606 .2759 .53732 .27306 .53124 .2654 Mtetra
.587 .71 .928 r
.53124 .2654 .53732 .27306 .54864 .27039 .54259 .26317 Mtetra
.565 .715 .943 r
.54259 .26317 .54864 .27039 .56001 .26781 .554 .26133 Mtetra
.526 .725 .964 r
.554 .26133 .56001 .26781 .57145 .26548 .56549 .26 Mtetra
.478 .742 .986 r
.56549 .26 .57145 .26548 .58295 .26331 .57704 .25903 Mtetra
.42 .76 .995 r
.57704 .25903 .58295 .26331 .59451 .26115 .58867 .25821 Mtetra
.333 .761 .972 r
.58867 .25821 .59451 .26115 .60614 .25907 .60038 .25747 Mtetra
.222 .727 .899 r
.60038 .25747 .60614 .25907 .61784 .25721 .61216 .25676 Mtetra
.122 .671 .796 r
.61216 .25676 .61784 .25721 .62961 .25555 .62402 .25599 Mtetra
.058 .623 .706 r
.62402 .25599 .62961 .25555 .64145 .25406 .63594 .25502 Mtetra
0 0 0 r
.63594 .25502 .64145 .25406 .65338 .25271 .64794 .25385 Mtetra
.64794 .25385 .65338 .25271 .66538 .25149 .65999 .25245 Mtetra
.65999 .25245 .66538 .25149 .67745 .2503 .67211 .25079 Mtetra
.145 .689 .74 r
.67211 .25079 .67745 .2503 .6896 .24908 .68429 .24885 Mtetra
.24 .756 .825 r
.68429 .24885 .6896 .24908 .70182 .24774 .69652 .2466 Mtetra
.35 .818 .909 r
.69652 .2466 .70182 .24774 .7141 .2462 .7088 .24402 Mtetra
.45 .854 .969 r
.7088 .24402 .7141 .2462 .72644 .24443 .72112 .24114 Mtetra
.53 .86 .995 r
.72112 .24114 .72644 .24443 .73884 .24241 .7335 .23796 Mtetra
.582 .842 .994 r
.7335 .23796 .73884 .24241 .75129 .24018 .74591 .23455 Mtetra
.613 .812 .977 r
.74591 .23455 .75129 .24018 .7638 .23777 .75838 .23096 Mtetra
.629 .777 .952 r
.75838 .23096 .7638 .23777 .77637 .23521 .7709 .22725 Mtetra
.623 .743 .933 r
.1101 .44736 .11732 .45366 .12723 .44967 .11987 .44467 Mtetra
.617 .787 .963 r
.11987 .44467 .12723 .44967 .13718 .44557 .12968 .44191 Mtetra
.604 .834 .987 r
.12968 .44191 .13718 .44557 .14719 .4413 .13956 .43902 Mtetra
.577 .876 .994 r
.13956 .43902 .14719 .4413 .15725 .4368 .14949 .43594 Mtetra
.529 .897 .967 r
.14949 .43594 .15725 .4368 .16738 .43203 .15949 .43263 Mtetra
.457 .884 .895 r
.15949 .43263 .16738 .43203 .17756 .42696 .16956 .429 Mtetra
.37 .835 .783 r
.16956 .429 .17756 .42696 .18781 .42157 .17971 .42502 Mtetra
.283 .762 .654 r
.17971 .42502 .18781 .42157 .19812 .41589 .18994 .42062 Mtetra
0 0 0 r
.18994 .42062 .19812 .41589 .20847 .40992 .20024 .41578 Mtetra
.20024 .41578 .20847 .40992 .21888 .4037 .21062 .41046 Mtetra
.21062 .41046 .21888 .4037 .22932 .39726 .22108 .40465 Mtetra
.22108 .40465 .22932 .39726 .23981 .3906 .2316 .39837 Mtetra
.2316 .39837 .23981 .3906 .25033 .38376 .24219 .39165 Mtetra
.24219 .39165 .25033 .38376 .26088 .37684 .25281 .38471 Mtetra
.25281 .38471 .26088 .37684 .27145 .36994 .26346 .37774 Mtetra
.26346 .37774 .27145 .36994 .28203 .36311 .27411 .37093 Mtetra
.27411 .37093 .28203 .36311 .29261 .35642 .28476 .36449 Mtetra
.28476 .36449 .29261 .35642 .3032 .35007 .29538 .35862 Mtetra
.062 0 0 r
.29538 .35862 .3032 .35007 .31377 .34422 .30599 .35346 Mtetra
.133 0 0 r
.30599 .35346 .31377 .34422 .32435 .33876 .31659 .34879 Mtetra
.194 0 0 r
.31659 .34879 .32435 .33876 .33493 .33376 .3272 .34456 Mtetra
.256 0 .016 r
.3272 .34456 .33493 .33376 .34547 .32987 .33781 .34098 Mtetra
.302 0 .051 r
.33781 .34098 .34547 .32987 .35599 .32731 .34843 .33813 Mtetra
.322 0 .055 r
.34843 .33813 .35599 .32731 .36652 .32548 .35906 .33581 Mtetra
.35 0 .057 r
.35906 .33581 .36652 .32548 .37707 .32431 .36971 .33427 Mtetra
.446 .004 .103 r
.36971 .33427 .37707 .32431 .38761 .32479 .3803 .33514 Mtetra
.525 .091 .159 r
.3803 .33514 .38761 .32479 .39816 .32674 .39087 .33835 Mtetra
.529 .108 .187 r
.39087 .33835 .39816 .32674 .4088 .32866 .40153 .34163 Mtetra
.484 .074 .187 r
.40153 .34163 .4088 .32866 .41956 .32915 .41235 .34314 Mtetra
.314 0 .121 r
.41235 .34314 .41956 .32915 .43053 .32531 .42342 .33929 Mtetra
.072 0 .005 r
.42342 .33929 .43053 .32531 .44166 .31713 .43469 .33006 Mtetra
0 0 0 r
.43469 .33006 .44166 .31713 .45283 .3075 .44601 .31903 Mtetra
.44601 .31903 .45283 .3075 .46402 .29782 .45732 .30806 Mtetra
.45732 .30806 .46402 .29782 .47518 .2896 .46859 .29942 Mtetra
.093 0 0 r
.46859 .29942 .47518 .2896 .48633 .28303 .47984 .2932 Mtetra
.155 0 0 r
.47984 .2932 .48633 .28303 .49751 .27713 .49111 .28775 Mtetra
.201 0 0 r
.49111 .28775 .49751 .27713 .50872 .27194 .50241 .28283 Mtetra
.247 0 .021 r
.50241 .28283 .50872 .27194 .51995 .26811 .51374 .27866 Mtetra
.27 0 .022 r
.51374 .27866 .51995 .26811 .53124 .2654 .52512 .27514 Mtetra
.273 0 0 r
.52512 .27514 .53124 .2654 .54259 .26317 .53656 .27206 Mtetra
.276 0 0 r
.53656 .27206 .54259 .26317 .554 .26133 .54805 .26949 Mtetra
.295 0 0 r
.54805 .26949 .554 .26133 .56549 .26 .55962 .26764 Mtetra
.312 0 0 r
.55962 .26764 .56549 .26 .57704 .25903 .57125 .26639 Mtetra
.324 0 0 r
.57125 .26639 .57704 .25903 .58867 .25821 .58296 .26551 Mtetra
.331 0 0 r
.58296 .26551 .58867 .25821 .60038 .25747 .59476 .26482 Mtetra
.33 0 0 r
.59476 .26482 .60038 .25747 .61216 .25676 .60662 .26409 Mtetra
.32 0 0 r
.60662 .26409 .61216 .25676 .62402 .25599 .61856 .26315 Mtetra
.293 0 0 r
.61856 .26315 .62402 .25599 .63594 .25502 .63056 .26177 Mtetra
.255 0 0 r
.63056 .26177 .63594 .25502 .64794 .25385 .64261 .25991 Mtetra
.2 0 0 r
.64261 .25991 .64794 .25385 .65999 .25245 .65471 .25754 Mtetra
.123 0 0 r
.65471 .25754 .65999 .25245 .67211 .25079 .66686 .25468 Mtetra
.016 0 0 r
.66686 .25468 .67211 .25079 .68429 .24885 .67905 .25136 Mtetra
0 0 0 r
.67905 .25136 .68429 .24885 .69652 .2466 .69127 .24761 Mtetra
.296 .788 .751 r
.69127 .24761 .69652 .2466 .7088 .24402 .70353 .24348 Mtetra
.456 .884 .892 r
.70353 .24348 .7088 .24402 .72112 .24114 .71583 .23903 Mtetra
.574 .916 .968 r
.71583 .23903 .72112 .24114 .7335 .23796 .72816 .23432 Mtetra
.641 .897 .984 r
.72816 .23432 .7335 .23796 .74591 .23455 .74052 .2294 Mtetra
.672 .855 .969 r
.74052 .2294 .74591 .23455 .75838 .23096 .75293 .22435 Mtetra
.682 .807 .942 r
.75293 .22435 .75838 .23096 .7709 .22725 .76539 .21923 Mtetra
.558 .722 .95 r
.10283 .44102 .1101 .44736 .11987 .44467 .11247 .43948 Mtetra
.539 .759 .978 r
.11247 .43948 .11987 .44467 .12968 .44191 .12215 .43794 Mtetra
.511 .795 .997 r
.12215 .43794 .12968 .44191 .13956 .43902 .13189 .43632 Mtetra
.468 .824 .996 r
.13189 .43632 .13956 .43902 .14949 .43594 .1417 .43457 Mtetra
.403 .831 .96 r
.1417 .43457 .14949 .43594 .15949 .43263 .15158 .43265 Mtetra
.32 .805 .876 r
.15158 .43265 .15949 .43263 .16956 .429 .16153 .43046 Mtetra
.229 .747 .753 r
.16153 .43046 .16956 .429 .17971 .42502 .17156 .42793 Mtetra
0 0 0 r
.17156 .42793 .17971 .42502 .18994 .42062 .18168 .42499 Mtetra
.18168 .42499 .18994 .42062 .20024 .41578 .1919 .42157 Mtetra
.1919 .42157 .20024 .41578 .21062 .41046 .2022 .41768 Mtetra
.028 0 0 r
.2022 .41768 .21062 .41046 .22108 .40465 .21259 .4133 Mtetra
.076 0 0 r
.21259 .4133 .22108 .40465 .2316 .39837 .22304 .40855 Mtetra
.125 0 0 r
.22304 .40855 .2316 .39837 .24219 .39165 .23356 .40351 Mtetra
.184 0 0 r
.23356 .40351 .24219 .39165 .25281 .38471 .24411 .39845 Mtetra
.244 0 .07 r
.24411 .39845 .25281 .38471 .26346 .37774 .25467 .39356 Mtetra
.296 0 .136 r
.25467 .39356 .26346 .37774 .27411 .37093 .26525 .38892 Mtetra
.338 0 .189 r
.26525 .38892 .27411 .37093 .28476 .36449 .27584 .38461 Mtetra
.366 .013 .228 r
.27584 .38461 .28476 .36449 .29538 .35862 .28645 .38053 Mtetra
.384 .04 .253 r
.28645 .38053 .29538 .35862 .30599 .35346 .29709 .37657 Mtetra
.385 .047 .264 r
.29709 .37657 .30599 .35346 .31659 .34879 .30778 .37232 Mtetra
.376 .04 .263 r
.30778 .37232 .31659 .34879 .3272 .34456 .31855 .36756 Mtetra
.361 .025 .253 r
.31855 .36756 .3272 .34456 .33781 .34098 .32939 .36236 Mtetra
.34 0 .229 r
.32939 .36236 .33781 .34098 .34843 .33813 .34027 .35683 Mtetra
.311 0 .187 r
.34027 .35683 .34843 .33813 .35906 .33581 .35119 .3513 Mtetra
.289 0 .13 r
.35119 .3513 .35906 .33581 .36971 .33427 .36211 .34638 Mtetra
.349 0 .096 r
.36211 .34638 .36971 .33427 .3803 .33514 .37293 .34425 Mtetra
.435 0 .067 r
.37293 .34425 .3803 .33514 .39087 .33835 .38367 .34514 Mtetra
.44 0 0 r
.38367 .34514 .39087 .33835 .40153 .34163 .39445 .3468 Mtetra
.354 0 0 r
.39445 .3468 .40153 .34163 .41235 .34314 .40536 .34749 Mtetra
0 0 0 r
.40536 .34749 .41235 .34314 .42342 .33929 .41649 .34361 Mtetra
.497 .867 .644 r
.41649 .34361 .42342 .33929 .43469 .33006 .42782 .33518 Mtetra
.503 .854 .596 r
.42782 .33518 .43469 .33006 .44601 .31903 .43918 .32574 Mtetra
0 0 0 r
.43918 .32574 .44601 .31903 .45732 .30806 .45054 .31707 Mtetra
.085 0 0 r
.45054 .31707 .45732 .30806 .46859 .29942 .46184 .31141 Mtetra
.322 0 .079 r
.46184 .31141 .46859 .29942 .47984 .2932 .47313 .30856 Mtetra
.387 0 .176 r
.47313 .30856 .47984 .2932 .49111 .28775 .48448 .30635 Mtetra
.412 .046 .231 r
.48448 .30635 .49111 .28775 .50241 .28283 .49588 .30413 Mtetra
.419 .069 .262 r
.49588 .30413 .50241 .28283 .51374 .27866 .50734 .30158 Mtetra
.418 .076 .276 r
.50734 .30158 .51374 .27866 .52512 .27514 .51886 .29859 Mtetra
.411 .072 .277 r
.51886 .29859 .52512 .27514 .53656 .27206 .53044 .29507 Mtetra
.403 .063 .271 r
.53044 .29507 .53656 .27206 .54805 .26949 .54207 .29127 Mtetra
.399 .053 .259 r
.54207 .29127 .54805 .26949 .55962 .26764 .55375 .28759 Mtetra
.392 .037 .238 r
.55375 .28759 .55962 .26764 .57125 .26639 .56549 .28414 Mtetra
.385 .016 .209 r
.56549 .28414 .57125 .26639 .58296 .26551 .57729 .28103 Mtetra
.372 0 .171 r
.57729 .28103 .58296 .26551 .59476 .26482 .58915 .27817 Mtetra
.353 0 .123 r
.58915 .27817 .59476 .26482 .60662 .26409 .60108 .2755 Mtetra
.324 0 .065 r
.60108 .2755 .60662 .26409 .61856 .26315 .61307 .2728 Mtetra
.276 0 0 r
.61307 .2728 .61856 .26315 .63056 .26177 .62512 .26981 Mtetra
.212 0 0 r
.62512 .26981 .63056 .26177 .64261 .25991 .63721 .26643 Mtetra
.123 0 0 r
.63721 .26643 .64261 .25991 .65471 .25754 .64934 .26255 Mtetra
.006 0 0 r
.64934 .26255 .65471 .25754 .66686 .25468 .6615 .25818 Mtetra
0 0 0 r
.6615 .25818 .66686 .25468 .67905 .25136 .6737 .25331 Mtetra
.315 .788 .687 r
.6737 .25331 .67905 .25136 .69127 .24761 .68592 .248 Mtetra
.48 .898 .837 r
.68592 .248 .69127 .24761 .70353 .24348 .69816 .24233 Mtetra
.604 .945 .929 r
.69816 .24233 .70353 .24348 .71583 .23903 .71043 .23637 Mtetra
.677 .939 .965 r
.71043 .23637 .71583 .23903 .72816 .23432 .72273 .23022 Mtetra
.712 .905 .964 r
.72273 .23022 .72816 .23432 .74052 .2294 .73506 .22392 Mtetra
.725 .862 .946 r
.73506 .22392 .74052 .2294 .75293 .22435 .74743 .21754 Mtetra
.725 .817 .922 r
.74743 .21754 .75293 .22435 .76539 .21923 .75983 .21113 Mtetra
.501 .701 .959 r
.09551 .43462 .10283 .44102 .11247 .43948 .10505 .43391 Mtetra
.478 .723 .978 r
.10505 .43391 .11247 .43948 .12215 .43794 .11464 .43323 Mtetra
.45 .745 .992 r
.11464 .43323 .12215 .43794 .13189 .43632 .12429 .43254 Mtetra
.414 .764 .995 r
.12429 .43254 .13189 .43632 .1417 .43457 .134 .43178 Mtetra
.367 .775 .982 r
.134 .43178 .1417 .43457 .15158 .43265 .14378 .43093 Mtetra
.311 .774 .943 r
.14378 .43093 .15158 .43265 .16153 .43046 .15363 .42989 Mtetra
.248 .755 .874 r
.15363 .42989 .16153 .43046 .17156 .42793 .16356 .42858 Mtetra
.177 .713 .774 r
.16356 .42858 .17156 .42793 .18168 .42499 .17358 .42695 Mtetra
0 0 0 r
.17358 .42695 .18168 .42499 .1919 .42157 .1837 .42491 Mtetra
.1837 .42491 .1919 .42157 .2022 .41768 .1939 .42255 Mtetra
.051 0 0 r
.1939 .42255 .2022 .41768 .21259 .4133 .20417 .41989 Mtetra
.14 0 0 r
.20417 .41989 .21259 .4133 .22304 .40855 .2145 .41713 Mtetra
.225 0 0 r
.2145 .41713 .22304 .40855 .23356 .40351 .22488 .41441 Mtetra
.301 0 .032 r
.22488 .41441 .23356 .40351 .24411 .39845 .23527 .41193 Mtetra
.362 0 .127 r
.23527 .41193 .24411 .39845 .25467 .39356 .24569 .40987 Mtetra
.399 .016 .193 r
.24569 .40987 .25467 .39356 .26525 .38892 .25613 .40803 Mtetra
.42 .056 .238 r
.25613 .40803 .26525 .38892 .27584 .38461 .26662 .40629 Mtetra
.425 .074 .265 r
.26662 .40629 .27584 .38461 .28645 .38053 .27719 .40421 Mtetra
.418 .077 .278 r
.27719 .40421 .28645 .38053 .29709 .37657 .28787 .4014 Mtetra
.396 .062 .277 r
.28787 .4014 .29709 .37657 .30778 .37232 .29868 .39735 Mtetra
.361 .031 .263 r
.29868 .39735 .30778 .37232 .31855 .36756 .30964 .39173 Mtetra
.316 0 .237 r
.30964 .39173 .31855 .36756 .32939 .36236 .32073 .38455 Mtetra
.254 0 .193 r
.32073 .38455 .32939 .36236 .34027 .35683 .33192 .376 Mtetra
.181 0 .126 r
.33192 .376 .34027 .35683 .35119 .3513 .34317 .36676 Mtetra
.101 0 .031 r
.34317 .36676 .35119 .3513 .36211 .34638 .35441 .35775 Mtetra
.115 0 0 r
.35441 .35775 .36211 .34638 .37293 .34425 .36552 .35145 Mtetra
.17 0 0 r
.36552 .35145 .37293 .34425 .38367 .34514 .37651 .34845 Mtetra
.102 0 0 r
.37651 .34845 .38367 .34514 .39445 .3468 .38748 .34705 Mtetra
.113 .666 .755 r
.38748 .34705 .39445 .3468 .40536 .34749 .3985 .34594 Mtetra
.551 .903 .972 r
.3985 .34594 .40536 .34749 .41649 .34361 .40968 .34204 Mtetra
.726 .953 .949 r
.40968 .34204 .41649 .34361 .42782 .33518 .42101 .33536 Mtetra
.642 .963 .908 r
.42101 .33536 .42782 .33518 .43918 .32574 .43235 .32894 Mtetra
0 0 0 r
.43235 .32894 .43918 .32574 .45054 .31707 .44368 .32414 Mtetra
.272 0 0 r
.44368 .32414 .45054 .31707 .46184 .31141 .45498 .32265 Mtetra
.459 .024 .125 r
.45498 .32265 .46184 .31141 .47313 .30856 .46629 .32391 Mtetra
.484 .088 .213 r
.46629 .32391 .47313 .30856 .48448 .30635 .47768 .32541 Mtetra
.479 .108 .257 r
.47768 .32541 .48448 .30635 .49588 .30413 .48917 .32625 Mtetra
.46 .107 .279 r
.48917 .32625 .49588 .30413 .50734 .30158 .50076 .32569 Mtetra
.437 .095 .287 r
.50076 .32569 .50734 .30158 .51886 .29859 .51242 .32357 Mtetra
.41 .076 .284 r
.51242 .32357 .51886 .29859 .53044 .29507 .52415 .31985 Mtetra
.385 .053 .274 r
.52415 .31985 .53044 .29507 .54207 .29127 .53593 .31487 Mtetra
.363 .028 .257 r
.53593 .31487 .54207 .29127 .55375 .28759 .54775 .30914 Mtetra
.339 0 .23 r
.54775 .30914 .55375 .28759 .56549 .28414 .5596 .30304 Mtetra
.315 0 .193 r
.5596 .30304 .56549 .28414 .57729 .28103 .57149 .29704 Mtetra
.285 0 .14 r
.57149 .29704 .57729 .28103 .58915 .27817 .58342 .29127 Mtetra
.248 0 .069 r
.58342 .29127 .58915 .27817 .60108 .2755 .5954 .28591 Mtetra
.192 0 0 r
.5954 .28591 .60108 .2755 .61307 .2728 .60743 .2808 Mtetra
.108 0 0 r
.60743 .2808 .61307 .2728 .62512 .26981 .6195 .27572 Mtetra
0 0 0 r
.6195 .27572 .62512 .26981 .63721 .26643 .63162 .27053 Mtetra
.63162 .27053 .63721 .26643 .64934 .26255 .64377 .26502 Mtetra
.325 .786 .658 r
.64377 .26502 .64934 .26255 .6615 .25818 .65595 .25917 Mtetra
.486 .897 .803 r
.65595 .25917 .6615 .25818 .6737 .25331 .66816 .25289 Mtetra
.608 .953 .896 r
.66816 .25289 .6737 .25331 .68592 .248 .68038 .24626 Mtetra
.687 .963 .94 r
.68038 .24626 .68592 .248 .69816 .24233 .69262 .23935 Mtetra
.73 .944 .952 r
.69262 .23935 .69816 .24233 .71043 .23637 .70489 .23222 Mtetra
.749 .912 .948 r
.70489 .23222 .71043 .23637 .72273 .23022 .71718 .22498 Mtetra
.755 .878 .935 r
.71718 .22498 .72273 .23022 .73506 .22392 .7295 .21766 Mtetra
.754 .845 .919 r
.7295 .21766 .73506 .22392 .74743 .21754 .74184 .21031 Mtetra
.749 .813 .903 r
.74184 .21031 .74743 .21754 .75983 .21113 .75422 .20298 Mtetra
.488 .696 .961 r
.08813 .42819 .09551 .43462 .10505 .43391 .09766 .42763 Mtetra
.48 .699 .965 r
.09766 .42763 .10505 .43391 .11464 .43323 .10725 .42713 Mtetra
.473 .703 .969 r
.10725 .42713 .11464 .43323 .12429 .43254 .11688 .42665 Mtetra
.466 .709 .974 r
.11688 .42665 .12429 .43254 .134 .43178 .12657 .42617 Mtetra
.46 .717 .98 r
.12657 .42617 .134 .43178 .14378 .43093 .13632 .42566 Mtetra
.456 .729 .985 r
.13632 .42566 .14378 .43093 .15363 .42989 .14614 .42506 Mtetra
.454 .746 .991 r
.14614 .42506 .15363 .42989 .16356 .42858 .15603 .42431 Mtetra
.447 .764 .996 r
.15603 .42431 .16356 .42858 .17358 .42695 .16599 .42337 Mtetra
.436 .785 .997 r
.16599 .42337 .17358 .42695 .1837 .42491 .17604 .42223 Mtetra
.399 .797 .985 r
.17604 .42223 .1837 .42491 .1939 .42255 .18615 .42096 Mtetra
.328 .788 .943 r
.18615 .42096 .1939 .42255 .20417 .41989 .19633 .41963 Mtetra
.204 .729 .837 r
.19633 .41963 .20417 .41989 .2145 .41713 .20655 .41836 Mtetra
0 0 0 r
.20655 .41836 .2145 .41713 .22488 .41441 .21682 .41726 Mtetra
.108 0 0 r
.21682 .41726 .22488 .41441 .23527 .41193 .22712 .41634 Mtetra
.215 0 0 r
.22712 .41634 .23527 .41193 .24569 .40987 .23747 .41559 Mtetra
.258 0 0 r
.23747 .41559 .24569 .40987 .25613 .40803 .24789 .41471 Mtetra
.265 0 0 r
.24789 .41471 .25613 .40803 .26662 .40629 .2584 .41346 Mtetra
.235 0 0 r
.2584 .41346 .26662 .40629 .27719 .40421 .26902 .41157 Mtetra
.177 0 0 r
.26902 .41157 .27719 .40421 .28787 .4014 .27977 .40877 Mtetra
.09 0 0 r
.27977 .40877 .28787 .4014 .29868 .39735 .29064 .40486 Mtetra
0 0 0 r
.29064 .40486 .29868 .39735 .30964 .39173 .30165 .39962 Mtetra
.30165 .39962 .30964 .39173 .32073 .38455 .3128 .39284 Mtetra
.3128 .39284 .32073 .38455 .33192 .376 .32407 .3845 Mtetra
.32407 .3845 .33192 .376 .34317 .36676 .33542 .37496 Mtetra
.33542 .37496 .34317 .36676 .35441 .35775 .34681 .36493 Mtetra
.34681 .36493 .35441 .35775 .36552 .35145 .3581 .35681 Mtetra
.3581 .35681 .36552 .35145 .37651 .34845 .36927 .35134 Mtetra
.36927 .35134 .37651 .34845 .38748 .34705 .3804 .34769 Mtetra
.259 .769 .8 r
.3804 .34769 .38748 .34705 .3985 .34594 .39153 .34505 Mtetra
.511 .9 .947 r
.39153 .34505 .3985 .34594 .40968 .34204 .40277 .34113 Mtetra
.613 .94 .951 r
.40277 .34113 .40968 .34204 .42101 .33536 .4141 .33593 Mtetra
.424 .869 .858 r
.4141 .33593 .42101 .33536 .43235 .32894 .42543 .33173 Mtetra
0 0 0 r
.42543 .33173 .43235 .32894 .44368 .32414 .43676 .32936 Mtetra
.322 0 0 r
.43676 .32936 .44368 .32414 .45498 .32265 .44808 .32967 Mtetra
.455 0 0 r
.44808 .32967 .45498 .32265 .46629 .32391 .45945 .33192 Mtetra
.446 0 .02 r
.45945 .33192 .46629 .32391 .47768 .32541 .47091 .3337 Mtetra
.399 0 0 r
.47091 .3337 .47768 .32541 .48917 .32625 .48248 .33428 Mtetra
.321 0 0 r
.48248 .33428 .48917 .32625 .50076 .32569 .49415 .33329 Mtetra
.224 0 0 r
.49415 .33329 .50076 .32569 .51242 .32357 .5059 .33075 Mtetra
.124 0 0 r
.5059 .33075 .51242 .32357 .52415 .31985 .51772 .32686 Mtetra
.039 0 0 r
.51772 .32686 .52415 .31985 .53593 .31487 .52959 .32183 Mtetra
0 0 0 r
.52959 .32183 .53593 .31487 .54775 .30914 .5415 .31586 Mtetra
.5415 .31586 .54775 .30914 .5596 .30304 .55344 .30923 Mtetra
.55344 .30923 .5596 .30304 .57149 .29704 .5654 .30221 Mtetra
.5654 .30221 .57149 .29704 .58342 .29127 .5774 .29505 Mtetra
.5774 .29505 .58342 .29127 .5954 .28591 .58943 .28805 Mtetra
.457 .872 .732 r
.58943 .28805 .5954 .28591 .60743 .2808 .60149 .28121 Mtetra
.575 .942 .861 r
.60149 .28121 .60743 .2808 .6195 .27572 .61359 .27454 Mtetra
.659 .961 .933 r
.61359 .27454 .6195 .27572 .63162 .27053 .62573 .26793 Mtetra
.709 .944 .958 r
.62573 .26793 .63162 .27053 .64377 .26502 .6379 .26124 Mtetra
.733 .916 .955 r
.6379 .26124 .64377 .26502 .65595 .25917 .6501 .25441 Mtetra
.748 .888 .943 r
.6501 .25441 .65595 .25917 .66816 .25289 .66232 .24734 Mtetra
.754 .864 .929 r
.66232 .24734 .66816 .25289 .68038 .24626 .67456 .24008 Mtetra
.758 .845 .917 r
.67456 .24008 .68038 .24626 .69262 .23935 .68683 .23265 Mtetra
.758 .829 .907 r
.68683 .23265 .69262 .23935 .70489 .23222 .69912 .2251 Mtetra
.756 .817 .9 r
.69912 .2251 .70489 .23222 .71718 .22498 .71144 .21751 Mtetra
.755 .807 .895 r
.71144 .21751 .71718 .22498 .7295 .21766 .72378 .2099 Mtetra
.752 .799 .891 r
.72378 .2099 .7295 .21766 .74184 .21031 .73616 .20231 Mtetra
.749 .792 .888 r
.73616 .20231 .74184 .21031 .75422 .20298 .74857 .19475 Mtetra
.518 .708 .957 r
.0807 .4217 .08813 .42819 .09766 .42763 .0903 .42071 Mtetra
.52 .694 .948 r
.0903 .42071 .09766 .42763 .10725 .42713 .09995 .41978 Mtetra
.522 .682 .938 r
.09995 .41978 .10725 .42713 .11688 .42665 .10964 .4189 Mtetra
.524 .67 .929 r
.10964 .4189 .11688 .42665 .12657 .42617 .11939 .41806 Mtetra
.525 .66 .921 r
.11939 .41806 .12657 .42617 .13632 .42566 .12918 .41726 Mtetra
.527 .653 .915 r
.12918 .41726 .13632 .42566 .14614 .42506 .13903 .41646 Mtetra
.531 .649 .91 r
.13903 .41646 .14614 .42506 .15603 .42431 .14893 .41563 Mtetra
.531 .648 .909 r
.14893 .41563 .15603 .42431 .16599 .42337 .1589 .4148 Mtetra
.53 .651 .912 r
.1589 .4148 .16599 .42337 .17604 .42223 .16892 .41395 Mtetra
.522 .658 .921 r
.16892 .41395 .17604 .42223 .18615 .42096 .17899 .41319 Mtetra
.506 .667 .935 r
.17899 .41319 .18615 .42096 .19633 .41963 .1891 .41259 Mtetra
.484 .683 .954 r
.1891 .41259 .19633 .41963 .20655 .41836 .19926 .41213 Mtetra
.452 .699 .972 r
.19926 .41213 .20655 .41836 .21682 .41726 .20946 .41182 Mtetra
.434 .72 .985 r
.20946 .41182 .21682 .41726 .22712 .41634 .21974 .41142 Mtetra
.438 .742 .992 r
.21974 .41142 .22712 .41634 .23747 .41559 .2301 .41076 Mtetra
.484 .766 .993 r
.2301 .41076 .23747 .41559 .24789 .41471 .24058 .4095 Mtetra
.553 .78 .983 r
.24058 .4095 .24789 .41471 .2584 .41346 .25118 .40742 Mtetra
.603 .768 .959 r
.25118 .40742 .2584 .41346 .26902 .41157 .26189 .40468 Mtetra
.635 .751 .932 r
.26189 .40468 .26902 .41157 .27977 .40877 .2727 .40134 Mtetra
.649 .739 .915 r
.2727 .40134 .27977 .40877 .29064 .40486 .28358 .39764 Mtetra
.661 .75 .916 r
.28358 .39764 .29064 .40486 .30165 .39962 .29454 .3936 Mtetra
.696 .798 .928 r
.29454 .3936 .30165 .39962 .3128 .39284 .30559 .38864 Mtetra
.739 .867 .94 r
.30559 .38864 .3128 .39284 .32407 .3845 .31677 .38246 Mtetra
.783 .937 .93 r
.31677 .38246 .32407 .3845 .33542 .37496 .32807 .37467 Mtetra
.804 .979 .899 r
.32807 .37467 .33542 .37496 .34681 .36493 .33946 .36559 Mtetra
.748 .989 .89 r
.33946 .36559 .34681 .36493 .3581 .35681 .35083 .35723 Mtetra
.666 .971 .906 r
.35083 .35723 .3581 .35681 .36927 .35134 .36213 .35044 Mtetra
.619 .94 .954 r
.36213 .35044 .36927 .35134 .3804 .34769 .37338 .34524 Mtetra
.584 .892 .989 r
.37338 .34524 .3804 .34769 .39153 .34505 .38461 .34139 Mtetra
.624 .868 .988 r
.38461 .34139 .39153 .34505 .40277 .34113 .39589 .33744 Mtetra
.629 .869 .987 r
.39589 .33744 .40277 .34113 .4141 .33593 .40722 .33339 Mtetra
.489 .854 .989 r
.40722 .33339 .4141 .33593 .42543 .33173 .41855 .3307 Mtetra
.216 .732 .871 r
.41855 .3307 .42543 .33173 .43676 .32936 .42988 .32961 Mtetra
.076 0 0 r
.42988 .32961 .43676 .32936 .44808 .32967 .44125 .33011 Mtetra
.166 0 0 r
.44125 .33011 .44808 .32967 .45945 .33192 .45268 .33136 Mtetra
.052 .618 .769 r
.45268 .33136 .45945 .33192 .47091 .3337 .46422 .33131 Mtetra
.373 .803 .967 r
.46422 .33131 .47091 .3337 .48248 .33428 .47587 .32966 Mtetra
.567 .823 .993 r
.47587 .32966 .48248 .33428 .49415 .33329 .4876 .32677 Mtetra
.639 .783 .95 r
.4876 .32677 .49415 .33329 .5059 .33075 .4994 .32294 Mtetra
.654 .748 .919 r
.4994 .32294 .5059 .33075 .51772 .32686 .51125 .31877 Mtetra
.666 .746 .909 r
.51125 .31877 .51772 .32686 .52959 .32183 .52315 .31423 Mtetra
.687 .768 .913 r
.52315 .31423 .52959 .32183 .5415 .31586 .5351 .30907 Mtetra
.711 .801 .921 r
.5351 .30907 .5415 .31586 .55344 .30923 .54708 .30324 Mtetra
.739 .835 .924 r
.54708 .30324 .55344 .30923 .5654 .30221 .5591 .29654 Mtetra
.758 .851 .92 r
.5591 .29654 .5654 .30221 .5774 .29505 .57114 .28923 Mtetra
.765 .849 .914 r
.57114 .28923 .5774 .29505 .58943 .28805 .58321 .28163 Mtetra
.765 .831 .903 r
.58321 .28163 .58943 .28805 .60149 .28121 .5953 .27392 Mtetra
.756 .804 .891 r
.5953 .27392 .60149 .28121 .61359 .27454 .60742 .26636 Mtetra
.746 .777 .878 r
.60742 .26636 .61359 .27454 .62573 .26793 .61957 .25893 Mtetra
.736 .753 .866 r
.61957 .25893 .62573 .26793 .6379 .26124 .63176 .25165 Mtetra
.729 .737 .857 r
.63176 .25165 .6379 .26124 .6501 .25441 .64398 .24444 Mtetra
.727 .728 .851 r
.64398 .24444 .6501 .25441 .66232 .24734 .65623 .23721 Mtetra
.726 .725 .849 r
.65623 .23721 .66232 .24734 .67456 .24008 .66851 .22997 Mtetra
.727 .726 .85 r
.66851 .22997 .67456 .24008 .68683 .23265 .68082 .22267 Mtetra
.728 .731 .853 r
.68082 .22267 .68683 .23265 .69912 .2251 .69316 .21537 Mtetra
.729 .738 .858 r
.69316 .21537 .69912 .2251 .71144 .21751 .70554 .20809 Mtetra
.731 .747 .865 r
.70554 .20809 .71144 .21751 .72378 .2099 .71795 .20084 Mtetra
.732 .758 .873 r
.71795 .20084 .72378 .2099 .73616 .20231 .73039 .19363 Mtetra
.734 .77 .882 r
.73039 .19363 .73616 .20231 .74857 .19475 .74288 .18646 Mtetra
.581 .73 .945 r
.07322 .41517 .0807 .4217 .0903 .42071 .08297 .41315 Mtetra
.585 .699 .921 r
.08297 .41315 .0903 .42071 .09995 .41978 .09276 .41118 Mtetra
.585 .669 .897 r
.09276 .41118 .09995 .41978 .10964 .4189 .1026 .40926 Mtetra
.583 .642 .875 r
.1026 .40926 .10964 .4189 .11939 .41806 .11247 .40741 Mtetra
.58 .618 .854 r
.11247 .40741 .11939 .41806 .12918 .41726 .12239 .40565 Mtetra
.577 .597 .836 r
.12239 .40565 .12918 .41726 .13903 .41646 .13234 .40396 Mtetra
.574 .579 .821 r
.13234 .40396 .13903 .41646 .14893 .41563 .14233 .40235 Mtetra
.569 .564 .808 r
.14233 .40235 .14893 .41563 .1589 .4148 .15237 .40086 Mtetra
.563 .551 .799 r
.15237 .40086 .1589 .4148 .16892 .41395 .16244 .39953 Mtetra
.557 .541 .793 r
.16244 .39953 .16892 .41395 .17899 .41319 .17254 .39838 Mtetra
.549 .532 .788 r
.17254 .39838 .17899 .41319 .1891 .41259 .18267 .39748 Mtetra
.546 .527 .785 r
.18267 .39748 .1891 .41259 .19926 .41213 .19285 .39668 Mtetra
.546 .523 .781 r
.19285 .39668 .19926 .41213 .20946 .41182 .20309 .39588 Mtetra
.556 .522 .773 r
.20309 .39588 .20946 .41182 .21974 .41142 .21342 .39471 Mtetra
.572 .523 .761 r
.21342 .39471 .21974 .41142 .2301 .41076 .22388 .39291 Mtetra
.588 .521 .746 r
.22388 .39291 .2301 .41076 .24058 .4095 .23446 .39032 Mtetra
.603 .517 .73 r
.23446 .39032 .24058 .4095 .25118 .40742 .24516 .38684 Mtetra
.604 .507 .717 r
.24516 .38684 .25118 .40742 .26189 .40468 .25594 .38308 Mtetra
.599 .497 .709 r
.25594 .38308 .26189 .40468 .2727 .40134 .26675 .37941 Mtetra
.588 .488 .708 r
.26675 .37941 .2727 .40134 .28358 .39764 .27756 .37631 Mtetra
.576 .485 .715 r
.27756 .37631 .28358 .39764 .29454 .3936 .28837 .37393 Mtetra
.584 .504 .73 r
.28837 .37393 .29454 .3936 .30559 .38864 .29925 .3713 Mtetra
.608 .54 .752 r
.29925 .3713 .30559 .38864 .31677 .38246 .31024 .36781 Mtetra
.658 .598 .776 r
.31024 .36781 .31677 .38246 .32807 .37467 .32139 .36249 Mtetra
.712 .659 .795 r
.32139 .36249 .32807 .37467 .33946 .36559 .33269 .35523 Mtetra
.733 .699 .819 r
.33269 .35523 .33946 .36559 .35083 .35723 .34404 .34767 Mtetra
.729 .715 .837 r
.34404 .34767 .35083 .35723 .36213 .35044 .35538 .34063 Mtetra
.701 .701 .847 r
.35538 .34063 .36213 .35044 .37338 .34524 .36669 .33476 Mtetra
.662 .673 .85 r
.36669 .33476 .37338 .34524 .38461 .34139 .37796 .33023 Mtetra
.643 .651 .843 r
.37796 .33023 .38461 .34139 .39589 .33744 .38926 .32625 Mtetra
.627 .644 .848 r
.38926 .32625 .39589 .33744 .40722 .33339 .40058 .32281 Mtetra
.582 .638 .872 r
.40058 .32281 .40722 .33339 .41855 .3307 .4119 .32073 Mtetra
.532 .63 .894 r
.4119 .32073 .41855 .3307 .42988 .32961 .42325 .31983 Mtetra
.506 .623 .901 r
.42325 .31983 .42988 .32961 .44125 .33011 .43465 .31946 Mtetra
.525 .611 .881 r
.43465 .31946 .44125 .33011 .45268 .33136 .44613 .31879 Mtetra
.597 .607 .833 r
.44613 .31879 .45268 .33136 .46422 .33131 .45773 .31618 Mtetra
.635 .587 .783 r
.45773 .31618 .46422 .33131 .47587 .32966 .46943 .31172 Mtetra
.639 .557 .746 r
.46943 .31172 .47587 .32966 .4876 .32677 .48118 .30638 Mtetra
.632 .532 .723 r
.48118 .30638 .4876 .32677 .4994 .32294 .49298 .30078 Mtetra
.614 .508 .71 r
.49298 .30078 .4994 .32294 .51125 .31877 .50481 .29592 Mtetra
.603 .497 .707 r
.50481 .29592 .51125 .31877 .52315 .31423 .51669 .29163 Mtetra
.602 .498 .709 r
.51669 .29163 .52315 .31423 .5351 .30907 .52862 .28743 Mtetra
.609 .51 .717 r
.52862 .28743 .5351 .30907 .54708 .30324 .5406 .28293 Mtetra
.629 .532 .726 r
.5406 .28293 .54708 .30324 .5591 .29654 .55262 .27752 Mtetra
.648 .554 .735 r
.55262 .27752 .5591 .29654 .57114 .28923 .56467 .2713 Mtetra
.664 .574 .744 r
.56467 .2713 .57114 .28923 .58321 .28163 .57675 .26441 Mtetra
.675 .587 .75 r
.57675 .26441 .58321 .28163 .5953 .27392 .58886 .25713 Mtetra
.677 .594 .755 r
.58886 .25713 .5953 .27392 .60742 .26636 .60099 .24985 Mtetra
.678 .597 .758 r
.60099 .24985 .60742 .26636 .61957 .25893 .61316 .24265 Mtetra
.675 .599 .763 r
.61316 .24265 .61957 .25893 .63176 .25165 .62536 .23569 Mtetra
.673 .602 .768 r
.62536 .23569 .63176 .25165 .64398 .24444 .63761 .22892 Mtetra
.673 .608 .774 r
.63761 .22892 .64398 .24444 .65623 .23721 .6499 .22229 Mtetra
.675 .617 .783 r
.6499 .22229 .65623 .23721 .66851 .22997 .66223 .21578 Mtetra
.678 .63 .794 r
.66223 .21578 .66851 .22997 .68082 .22267 .6746 .20934 Mtetra
.682 .646 .808 r
.6746 .20934 .68082 .22267 .69316 .21537 .68702 .20297 Mtetra
.686 .665 .823 r
.68702 .20297 .69316 .21537 .70554 .20809 .69948 .19667 Mtetra
.691 .687 .841 r
.69948 .19667 .70554 .20809 .71795 .20084 .71198 .19044 Mtetra
.697 .713 .861 r
.71198 .19044 .71795 .20084 .73039 .19363 .72453 .18425 Mtetra
.702 .741 .882 r
.72453 .18425 .73039 .19363 .74288 .18646 .73713 .1781 Mtetra
.647 .749 .924 r
.06568 .40859 .07322 .41517 .08297 .41315 .07563 .40521 Mtetra
.644 .709 .894 r
.07563 .40521 .08297 .41315 .09276 .41118 .08563 .40186 Mtetra
.638 .671 .866 r
.08563 .40186 .09276 .41118 .1026 .40926 .09565 .39857 Mtetra
.63 .638 .84 r
.09565 .39857 .1026 .40926 .11247 .40741 .10571 .39536 Mtetra
.621 .609 .817 r
.10571 .39536 .11247 .40741 .12239 .40565 .11579 .39225 Mtetra
.612 .583 .797 r
.11579 .39225 .12239 .40565 .13234 .40396 .12589 .38929 Mtetra
.604 .561 .78 r
.12589 .38929 .13234 .40396 .14233 .40235 .13602 .38648 Mtetra
.595 .542 .765 r
.13602 .38648 .14233 .40235 .15237 .40086 .14617 .38389 Mtetra
.585 .524 .753 r
.14617 .38389 .15237 .40086 .16244 .39953 .15634 .38155 Mtetra
.577 .51 .743 r
.15634 .38155 .16244 .39953 .17254 .39838 .16653 .37945 Mtetra
.569 .496 .734 r
.16653 .37945 .17254 .39838 .18267 .39748 .17674 .3776 Mtetra
.568 .488 .725 r
.17674 .3776 .18267 .39748 .19285 .39668 .187 .37575 Mtetra
.57 .481 .715 r
.187 .37575 .19285 .39668 .20309 .39588 .19734 .37369 Mtetra
.579 .478 .704 r
.19734 .37369 .20309 .39588 .21342 .39471 .20779 .37107 Mtetra
.591 .477 .692 r
.20779 .37107 .21342 .39471 .22388 .39291 .21837 .36756 Mtetra
.598 .473 .681 r
.21837 .36756 .22388 .39291 .23446 .39032 .22907 .36327 Mtetra
.604 .469 .67 r
.22907 .36327 .23446 .39032 .24516 .38684 .23987 .35827 Mtetra
.596 .458 .663 r
.23987 .35827 .24516 .38684 .25594 .38308 .25068 .35353 Mtetra
.582 .444 .659 r
.25068 .35353 .25594 .38308 .26675 .37941 .26146 .34969 Mtetra
.561 .43 .659 r
.26146 .34969 .26675 .37941 .27756 .37631 .27216 .34728 Mtetra
.536 .416 .663 r
.27216 .34728 .27756 .37631 .28837 .37393 .28279 .34652 Mtetra
.531 .42 .672 r
.28279 .34652 .28837 .37393 .29925 .3713 .29346 .34611 Mtetra
.542 .439 .687 r
.29346 .34611 .29925 .3713 .31024 .36781 .30424 .34518 Mtetra
.58 .48 .704 r
.30424 .34518 .31024 .36781 .32139 .36249 .3152 .34234 Mtetra
.629 .527 .72 r
.3152 .34234 .32139 .36249 .33269 .35523 .32637 .33712 Mtetra
.657 .561 .735 r
.32637 .33712 .33269 .35523 .34404 .34767 .33764 .33079 Mtetra
.67 .58 .745 r
.33764 .33079 .34404 .34767 .35538 .34063 .34896 .32408 Mtetra
.659 .578 .753 r
.34896 .32408 .35538 .34063 .36669 .33476 .36027 .31807 Mtetra
.637 .565 .757 r
.36027 .31807 .36669 .33476 .37796 .33023 .37156 .3132 Mtetra
.618 .551 .757 r
.37156 .3132 .37796 .33023 .38926 .32625 .38285 .30918 Mtetra
.6 .541 .76 r
.38285 .30918 .38926 .32625 .40058 .32281 .39416 .30601 Mtetra
.574 .53 .768 r
.39416 .30601 .40058 .32281 .4119 .32073 .40547 .30399 Mtetra
.556 .521 .772 r
.40547 .30399 .4119 .32073 .42325 .31983 .41682 .30267 Mtetra
.564 .522 .766 r
.41682 .30267 .42325 .31983 .43465 .31946 .42825 .30098 Mtetra
.587 .521 .748 r
.42825 .30098 .43465 .31946 .44613 .31879 .43977 .29818 Mtetra
.625 .525 .721 r
.43977 .29818 .44613 .31879 .45773 .31618 .45142 .29298 Mtetra
.643 .518 .696 r
.45142 .29298 .45773 .31618 .46943 .31172 .46314 .28584 Mtetra
.639 .502 .679 r
.46314 .28584 .46943 .31172 .48118 .30638 .4749 .27815 Mtetra
.627 .483 .667 r
.4749 .27815 .48118 .30638 .49298 .30078 .48667 .27081 Mtetra
.602 .46 .661 r
.48667 .27081 .49298 .30078 .50481 .29592 .49846 .26514 Mtetra
.582 .444 .658 r
.49846 .26514 .50481 .29592 .51669 .29163 .51029 .26092 Mtetra
.57 .436 .659 r
.51029 .26092 .51669 .29163 .52862 .28743 .52216 .25762 Mtetra
.568 .439 .664 r
.52216 .25762 .52862 .28743 .5406 .28293 .53409 .25457 Mtetra
.58 .453 .672 r
.53409 .25457 .5406 .28293 .55262 .27752 .54608 .25081 Mtetra
.595 .471 .681 r
.54608 .25081 .55262 .27752 .56467 .2713 .55812 .24624 Mtetra
.612 .49 .69 r
.55812 .24624 .56467 .2713 .57675 .26441 .57019 .24077 Mtetra
.625 .507 .699 r
.57019 .24077 .57675 .26441 .58886 .25713 .5823 .23469 Mtetra
.633 .519 .707 r
.5823 .23469 .58886 .25713 .60099 .24985 .59444 .2284 Mtetra
.637 .529 .715 r
.59444 .2284 .60099 .24985 .61316 .24265 .60662 .2221 Mtetra
.637 .536 .724 r
.60662 .2221 .61316 .24265 .62536 .23569 .61884 .21605 Mtetra
.637 .544 .733 r
.61884 .21605 .62536 .23569 .63761 .22892 .63112 .21023 Mtetra
.636 .553 .744 r
.63112 .21023 .63761 .22892 .6499 .22229 .64345 .20467 Mtetra
.637 .565 .757 r
.64345 .20467 .6499 .22229 .66223 .21578 .65583 .19933 Mtetra
.64 .58 .772 r
.65583 .19933 .66223 .21578 .6746 .20934 .66827 .19414 Mtetra
.643 .599 .789 r
.66827 .19414 .6746 .20934 .68702 .20297 .68077 .18909 Mtetra
.647 .621 .81 r
.68077 .18909 .68702 .20297 .69948 .19667 .69332 .18414 Mtetra
.651 .647 .834 r
.69332 .18414 .69948 .19667 .71198 .19044 .70594 .17928 Mtetra
.656 .679 .86 r
.70594 .17928 .71198 .19044 .72453 .18425 .71861 .17447 Mtetra
.66 .714 .888 r
.71861 .17447 .72453 .18425 .73713 .1781 .73134 .16968 Mtetra
.7 .761 .899 r
.05808 .40196 .06568 .40859 .07563 .40521 .06826 .39714 Mtetra
.691 .719 .871 r
.06826 .39714 .07563 .40521 .08563 .40186 .07847 .39233 Mtetra
.68 .682 .845 r
.07847 .39233 .08563 .40186 .09565 .39857 .0887 .38758 Mtetra
.669 .649 .821 r
.0887 .38758 .09565 .39857 .10571 .39536 .09895 .38292 Mtetra
.657 .619 .8 r
.09895 .38292 .10571 .39536 .11579 .39225 .10922 .37837 Mtetra
.645 .593 .781 r
.10922 .37837 .11579 .39225 .12589 .38929 .1195 .374 Mtetra
.633 .569 .765 r
.1195 .374 .12589 .38929 .13602 .38648 .12979 .36982 Mtetra
.622 .548 .75 r
.12979 .36982 .13602 .38648 .14617 .38389 .14009 .36589 Mtetra
.61 .528 .737 r
.14009 .36589 .14617 .38389 .15634 .38155 .15039 .36226 Mtetra
.601 .512 .726 r
.15039 .36226 .15634 .38155 .16653 .37945 .16071 .35887 Mtetra
.592 .497 .715 r
.16071 .35887 .16653 .37945 .17674 .3776 .17104 .35569 Mtetra
.59 .486 .704 r
.17104 .35569 .17674 .3776 .187 .37575 .18143 .35242 Mtetra
.592 .479 .693 r
.18143 .35242 .187 .37575 .19734 .37369 .19189 .34885 Mtetra
.598 .474 .683 r
.19189 .34885 .19734 .37369 .20779 .37107 .20246 .34466 Mtetra
.606 .472 .673 r
.20246 .34466 .20779 .37107 .21837 .36756 .21315 .33957 Mtetra
.61 .468 .664 r
.21315 .33957 .21837 .36756 .22907 .36327 .22394 .33391 Mtetra
.61 .463 .657 r
.22394 .33391 .22907 .36327 .23987 .35827 .23479 .32788 Mtetra
.598 .451 .653 r
.23479 .32788 .23987 .35827 .25068 .35353 .2456 .32259 Mtetra
.578 .436 .651 r
.2456 .32259 .25068 .35353 .26146 .34969 .25632 .31877 Mtetra
.551 .417 .652 r
.25632 .31877 .26146 .34969 .27216 .34728 .26692 .31689 Mtetra
.519 .397 .654 r
.26692 .31689 .27216 .34728 .28279 .34652 .27741 .31708 Mtetra
.508 .395 .659 r
.27741 .31708 .28279 .34652 .29346 .34611 .28793 .31788 Mtetra
.515 .405 .667 r
.28793 .31788 .29346 .34611 .30424 .34518 .29856 .31828 Mtetra
.55 .435 .675 r
.29856 .31828 .30424 .34518 .3152 .34234 .30939 .31674 Mtetra
.593 .47 .682 r
.30939 .31674 .3152 .34234 .32637 .33712 .32045 .31265 Mtetra
.619 .493 .687 r
.32045 .31265 .32637 .33712 .33764 .33079 .33165 .30701 Mtetra
.633 .506 .69 r
.33165 .30701 .33764 .33079 .34896 .32408 .34294 .30049 Mtetra
.628 .504 .692 r
.34294 .30049 .34896 .32408 .36027 .31807 .35423 .29437 Mtetra
.613 .494 .694 r
.35423 .29437 .36027 .31807 .37156 .3132 .36551 .28924 Mtetra
.596 .482 .694 r
.36551 .28924 .37156 .3132 .38285 .30918 .37677 .28518 Mtetra
.578 .471 .696 r
.37677 .28518 .38285 .30918 .39416 .30601 .38803 .28217 Mtetra
.561 .461 .698 r
.38803 .28217 .39416 .30601 .40547 .30399 .39931 .28017 Mtetra
.553 .457 .699 r
.39931 .28017 .40547 .30399 .41682 .30267 .41063 .27857 Mtetra
.568 .465 .697 r
.41063 .27857 .41682 .30267 .42825 .30098 .42205 .2761 Mtetra
.592 .476 .69 r
.42205 .2761 .42825 .30098 .43977 .29818 .43358 .27206 Mtetra
.625 .49 .678 r
.43358 .27206 .43977 .29818 .45142 .29298 .44522 .26545 Mtetra
.643 .496 .668 r
.44522 .26545 .45142 .29298 .46314 .28584 .45694 .25688 Mtetra
.643 .49 .66 r
.45694 .25688 .46314 .28584 .4749 .27815 .46868 .24787 Mtetra
.632 .477 .655 r
.46868 .24787 .4749 .27815 .48667 .27081 .48043 .23946 Mtetra
.605 .456 .653 r
.48043 .23946 .48667 .27081 .49846 .26514 .49217 .23316 Mtetra
.58 .437 .652 r
.49217 .23316 .49846 .26514 .51029 .26092 .50393 .22881 Mtetra
.561 .424 .652 r
.50393 .22881 .51029 .26092 .52216 .25762 .51574 .22596 Mtetra
.551 .42 .655 r
.51574 .22596 .52216 .25762 .53409 .25457 .52761 .22387 Mtetra
.557 .428 .66 r
.52761 .22387 .53409 .25457 .54608 .25081 .53955 .22141 Mtetra
.567 .44 .666 r
.53955 .22141 .54608 .25081 .55812 .24624 .55155 .21836 Mtetra
.582 .457 .674 r
.55155 .21836 .55812 .24624 .57019 .24077 .5636 .2144 Mtetra
.595 .472 .683 r
.5636 .2144 .57019 .24077 .5823 .23469 .5757 .20979 Mtetra
.603 .486 .692 r
.5757 .20979 .5823 .23469 .59444 .2284 .58784 .20487 Mtetra
.609 .498 .702 r
.58784 .20487 .59444 .2284 .60662 .2221 .60003 .19985 Mtetra
.609 .507 .713 r
.60003 .19985 .60662 .2221 .61884 .21605 .61228 .19505 Mtetra
.609 .517 .725 r
.61228 .19505 .61884 .21605 .63112 .21023 .62458 .19049 Mtetra
.608 .527 .738 r
.62458 .19049 .63112 .21023 .64345 .20467 .63695 .18623 Mtetra
.608 .54 .753 r
.63695 .18623 .64345 .20467 .65583 .19933 .64939 .18223 Mtetra
.608 .555 .77 r
.64939 .18223 .65583 .19933 .66827 .19414 .6619 .17843 Mtetra
.608 .574 .79 r
.6619 .17843 .66827 .19414 .68077 .18909 .67447 .1748 Mtetra
.609 .596 .812 r
.67447 .1748 .68077 .18909 .69332 .18414 .68712 .17129 Mtetra
.611 .623 .838 r
.68712 .17129 .69332 .18414 .70594 .17928 .69985 .16788 Mtetra
.612 .654 .867 r
.69985 .16788 .70594 .17928 .71861 .17447 .71264 .16452 Mtetra
.612 .69 .899 r
.71264 .16452 .71861 .17447 .73134 .16968 .7255 .16118 Mtetra
.736 .766 .877 r
.05043 .39529 .05808 .40196 .06826 .39714 .06082 .38916 Mtetra
.725 .731 .855 r
.06082 .38916 .06826 .39714 .07847 .39233 .07123 .38305 Mtetra
.714 .698 .834 r
.07123 .38305 .07847 .39233 .0887 .38758 .08166 .37699 Mtetra
.701 .669 .815 r
.08166 .37699 .0887 .38758 .09895 .38292 .0921 .37101 Mtetra
.689 .642 .798 r
.0921 .37101 .09895 .38292 .10922 .37837 .10254 .36517 Mtetra
.676 .617 .782 r
.10254 .36517 .10922 .37837 .1195 .374 .11299 .35949 Mtetra
.663 .594 .768 r
.11299 .35949 .1195 .374 .12979 .36982 .12344 .35404 Mtetra
.651 .573 .754 r
.12344 .35404 .12979 .36982 .14009 .36589 .13389 .34883 Mtetra
.639 .554 .742 r
.13389 .34883 .14009 .36589 .15039 .36226 .14434 .34391 Mtetra
.629 .536 .731 r
.14434 .34391 .15039 .36226 .16071 .35887 .15479 .33919 Mtetra
.621 .521 .719 r
.15479 .33919 .16071 .35887 .17104 .35569 .16526 .33462 Mtetra
.618 .509 .708 r
.16526 .33462 .17104 .35569 .18143 .35242 .17578 .32992 Mtetra
.618 .5 .696 r
.17578 .32992 .18143 .35242 .19189 .34885 .18638 .32485 Mtetra
.621 .494 .685 r
.18638 .32485 .19189 .34885 .20246 .34466 .19707 .31921 Mtetra
.627 .49 .676 r
.19707 .31921 .20246 .34466 .21315 .33957 .20786 .3128 Mtetra
.626 .484 .668 r
.20786 .3128 .21315 .33957 .22394 .33391 .21871 .30608 Mtetra
.622 .477 .663 r
.21871 .30608 .22394 .33391 .23479 .32788 .22958 .29939 Mtetra
.606 .463 .661 r
.22958 .29939 .23479 .32788 .2456 .32259 .24038 .29381 Mtetra
.58 .444 .661 r
.24038 .29381 .2456 .32259 .25632 .31877 .25104 .29009 Mtetra
.547 .422 .662 r
.25104 .29009 .25632 .31877 .26692 .31689 .26156 .28854 Mtetra
.509 .398 .664 r
.26156 .28854 .26692 .31689 .27741 .31708 .27196 .28922 Mtetra
.495 .392 .667 r
.27196 .28922 .27741 .31708 .28793 .31788 .28238 .29061 Mtetra
.501 .399 .671 r
.28238 .29061 .28793 .31788 .29856 .31828 .2929 .29167 Mtetra
.535 .426 .677 r
.2929 .29167 .29856 .31828 .30939 .31674 .30363 .29092 Mtetra
.578 .459 .681 r
.30363 .29092 .30939 .31674 .32045 .31265 .31459 .28769 Mtetra
.606 .482 .685 r
.31459 .28769 .32045 .31265 .33165 .30701 .32572 .28276 Mtetra
.624 .498 .688 r
.32572 .28276 .33165 .30701 .34294 .30049 .33695 .2767 Mtetra
.624 .5 .691 r
.33695 .2767 .34294 .30049 .35423 .29437 .34821 .27078 Mtetra
.613 .494 .694 r
.34821 .27078 .35423 .29437 .36551 .28924 .35945 .26563 Mtetra
.597 .484 .696 r
.35945 .26563 .36551 .28924 .37677 .28518 .37069 .26152 Mtetra
.579 .473 .698 r
.37069 .26152 .37677 .28518 .38803 .28217 .38192 .25845 Mtetra
.565 .464 .699 r
.38192 .25845 .38803 .28217 .39931 .28017 .39318 .25616 Mtetra
.562 .461 .697 r
.39318 .25616 .39931 .28017 .41063 .27857 .40449 .25401 Mtetra
.58 .469 .692 r
.40449 .25401 .41063 .27857 .42205 .2761 .4159 .25073 Mtetra
.604 .481 .685 r
.4159 .25073 .42205 .2761 .43358 .27206 .42742 .24573 Mtetra
.635 .495 .675 r
.42742 .24573 .43358 .27206 .44522 .26545 .43905 .23823 Mtetra
.653 .503 .667 r
.43905 .23823 .44522 .26545 .45694 .25688 .45076 .22888 Mtetra
.653 .5 .663 r
.45076 .22888 .45694 .25688 .46868 .24787 .46248 .21919 Mtetra
.643 .49 .661 r
.46248 .21919 .46868 .24787 .48043 .23946 .4742 .21021 Mtetra
.615 .47 .661 r
.4742 .21021 .48043 .23946 .49217 .23316 .4859 .20346 Mtetra
.586 .449 .661 r
.4859 .20346 .49217 .23316 .50393 .22881 .49761 .19891 Mtetra
.56 .431 .662 r
.49761 .19891 .50393 .22881 .51574 .22596 .50936 .19626 Mtetra
.544 .422 .664 r
.50936 .19626 .51574 .22596 .52761 .22387 .52118 .19475 Mtetra
.544 .425 .667 r
.52118 .19475 .52761 .22387 .53955 .22141 .53307 .19327 Mtetra
.549 .433 .673 r
.53307 .19327 .53955 .22141 .55155 .21836 .54503 .19148 Mtetra
.563 .448 .681 r
.54503 .19148 .55155 .21836 .5636 .2144 .55705 .18891 Mtetra
.574 .464 .69 r
.55705 .18891 .5636 .2144 .5757 .20979 .56914 .18575 Mtetra
.583 .478 .7 r
.56914 .18575 .5757 .20979 .58784 .20487 .58128 .18222 Mtetra
.589 .491 .711 r
.58128 .18222 .58784 .20487 .60003 .19985 .59348 .17854 Mtetra
.589 .502 .724 r
.59348 .17854 .60003 .19985 .61228 .19505 .60574 .17502 Mtetra
.589 .513 .737 r
.60574 .17502 .61228 .19505 .62458 .19049 .61807 .17171 Mtetra
.586 .524 .752 r
.61807 .17171 .62458 .19049 .63695 .18623 .63048 .16869 Mtetra
.583 .536 .768 r
.63048 .16869 .63695 .18623 .64939 .18223 .64297 .16594 Mtetra
.58 .55 .786 r
.64297 .16594 .64939 .18223 .6619 .17843 .65553 .1634 Mtetra
.577 .568 .806 r
.65553 .1634 .6619 .17843 .67447 .1748 .66818 .16105 Mtetra
.575 .588 .829 r
.66818 .16105 .67447 .1748 .68712 .17129 .68092 .15884 Mtetra
.572 .611 .854 r
.68092 .15884 .68712 .17129 .69985 .16788 .69373 .15672 Mtetra
.568 .638 .881 r
.69373 .15672 .69985 .16788 .71264 .16452 .70663 .15466 Mtetra
.562 .669 .91 r
.70663 .15466 .71264 .16452 .7255 .16118 .71961 .15261 Mtetra
.755 .768 .863 r
.04273 .38856 .05043 .39529 .06082 .38916 .05327 .38157 Mtetra
.747 .745 .85 r
.05327 .38157 .06082 .38916 .07123 .38305 .06382 .3746 Mtetra
.739 .724 .838 r
.06382 .3746 .07123 .38305 .08166 .37699 .07439 .36767 Mtetra
.729 .704 .826 r
.07439 .36767 .08166 .37699 .0921 .37101 .08497 .36084 Mtetra
.72 .684 .815 r
.08497 .36084 .0921 .37101 .10254 .36517 .09554 .35413 Mtetra
.709 .666 .805 r
.09554 .35413 .10254 .36517 .11299 .35949 .10612 .34759 Mtetra
.698 .648 .796 r
.10612 .34759 .11299 .35949 .12344 .35404 .11669 .34126 Mtetra
.687 .63 .786 r
.11669 .34126 .12344 .35404 .13389 .34883 .12726 .33515 Mtetra
.676 .613 .777 r
.12726 .33515 .13389 .34883 .14434 .34391 .13782 .3293 Mtetra
.667 .596 .767 r
.13782 .3293 .14434 .34391 .15479 .33919 .14839 .32358 Mtetra
.66 .581 .756 r
.14839 .32358 .15479 .33919 .16526 .33462 .15898 .31794 Mtetra
.657 .569 .744 r
.15898 .31794 .16526 .33462 .17578 .32992 .16962 .31211 Mtetra
.657 .558 .731 r
.16962 .31211 .17578 .32992 .18638 .32485 .18034 .30588 Mtetra
.659 .55 .72 r
.18034 .30588 .18638 .32485 .19707 .31921 .19113 .29915 Mtetra
.663 .544 .709 r
.19113 .29915 .19707 .31921 .20786 .3128 .20201 .2918 Mtetra
.659 .535 .702 r
.20201 .2918 .20786 .3128 .21871 .30608 .21291 .28439 Mtetra
.65 .525 .698 r
.21291 .28439 .21871 .30608 .22958 .29939 .2238 .27731 Mtetra
.628 .51 .699 r
.2238 .27731 .22958 .29939 .24038 .29381 .23459 .27161 Mtetra
.593 .487 .702 r
.23459 .27161 .24038 .29381 .25104 .29009 .24521 .268 Mtetra
.548 .46 .707 r
.24521 .268 .25104 .29009 .26156 .28854 .25568 .26668 Mtetra
.494 .428 .711 r
.25568 .26668 .26156 .28854 .27196 .28922 .26601 .26769 Mtetra
.469 .415 .714 r
.26601 .26769 .27196 .28922 .28238 .29061 .27635 .26964 Mtetra
.468 .42 .721 r
.27635 .26964 .28238 .29061 .2929 .29167 .28677 .27157 Mtetra
.505 .451 .73 r
.28677 .27157 .2929 .29167 .30363 .29092 .29738 .27209 Mtetra
.558 .496 .742 r
.29738 .27209 .30363 .29092 .31459 .28769 .30822 .2705 Mtetra
.6 .538 .757 r
.30822 .2705 .31459 .28769 .32572 .28276 .31922 .26724 Mtetra
.636 .578 .772 r
.31922 .26724 .32572 .28276 .33695 .2767 .33037 .26266 Mtetra
.65 .605 .791 r
.33037 .26266 .33695 .2767 .34821 .27078 .34157 .25778 Mtetra
.65 .622 .808 r
.34157 .25778 .34821 .27078 .35945 .26563 .3528 .25312 Mtetra
.639 .626 .821 r
.3528 .25312 .35945 .26563 .37069 .26152 .36405 .24897 Mtetra
.625 .619 .825 r
.36405 .24897 .37069 .26152 .38192 .25845 .37531 .24534 Mtetra
.616 .606 .817 r
.37531 .24534 .38192 .25845 .39318 .25616 .38662 .24193 Mtetra
.62 .59 .799 r
.38662 .24193 .39318 .25616 .40449 .25401 .398 .23822 Mtetra
.642 .581 .771 r
.398 .23822 .40449 .25401 .4159 .25073 .40947 .23318 Mtetra
.664 .574 .743 r
.40947 .23318 .4159 .25073 .42742 .24573 .42105 .22645 Mtetra
.686 .57 .719 r
.42105 .22645 .42742 .24573 .43905 .23823 .43272 .21759 Mtetra
.697 .566 .703 r
.43272 .21759 .43905 .23823 .45076 .22888 .44444 .20729 Mtetra
.691 .556 .697 r
.44444 .20729 .45076 .22888 .46248 .21919 .45617 .19694 Mtetra
.676 .543 .695 r
.45617 .19694 .46248 .21919 .4742 .21021 .46788 .18753 Mtetra
.643 .52 .699 r
.46788 .18753 .4742 .21021 .4859 .20346 .47957 .18046 Mtetra
.606 .496 .702 r
.47957 .18046 .4859 .20346 .49761 .19891 .49126 .17572 Mtetra
.569 .472 .705 r
.49126 .17572 .49761 .19891 .50936 .19626 .50298 .17311 Mtetra
.543 .456 .707 r
.50298 .17311 .50936 .19626 .52118 .19475 .51476 .1719 Mtetra
.536 .455 .711 r
.51476 .1719 .52118 .19475 .53307 .19327 .52662 .17104 Mtetra
.538 .461 .717 r
.52662 .17104 .53307 .19327 .54503 .19148 .53856 .17012 Mtetra
.551 .477 .725 r
.53856 .17012 .54503 .19148 .55705 .18891 .55057 .16858 Mtetra
.563 .493 .735 r
.55057 .16858 .55705 .18891 .56914 .18575 .56265 .16653 Mtetra
.573 .51 .746 r
.56265 .16653 .56914 .18575 .58128 .18222 .5748 .16407 Mtetra
.579 .525 .759 r
.5748 .16407 .58128 .18222 .59348 .17854 .58701 .16142 Mtetra
.579 .538 .772 r
.58701 .16142 .59348 .17854 .60574 .17502 .5993 .15885 Mtetra
.577 .549 .787 r
.5993 .15885 .60574 .17502 .61807 .17171 .61166 .15642 Mtetra
.572 .559 .801 r
.61166 .15642 .61807 .17171 .63048 .16869 .6241 .15426 Mtetra
.566 .57 .817 r
.6241 .15426 .63048 .16869 .64297 .16594 .63663 .15233 Mtetra
.559 .581 .833 r
.63663 .15233 .64297 .16594 .65553 .1634 .64924 .15063 Mtetra
.552 .594 .849 r
.64924 .15063 .65553 .1634 .66818 .16105 .66195 .1491 Mtetra
.545 .608 .867 r
.66195 .1491 .66818 .16105 .68092 .15884 .67474 .14771 Mtetra
.538 .625 .885 r
.67474 .14771 .68092 .15884 .69373 .15672 .68763 .14642 Mtetra
.531 .642 .904 r
.68763 .14642 .69373 .15672 .70663 .15466 .70061 .14518 Mtetra
.523 .662 .924 r
.70061 .14518 .70663 .15466 .71961 .15261 .71368 .14397 Mtetra
.763 .768 .857 r
.03496 .38178 .04273 .38856 .05327 .38157 .04559 .3744 Mtetra
.759 .758 .852 r
.04559 .3744 .05327 .38157 .06382 .3746 .05623 .36703 Mtetra
.754 .749 .848 r
.05623 .36703 .06382 .3746 .07439 .36767 .06688 .35973 Mtetra
.749 .74 .844 r
.06688 .35973 .07439 .36767 .08497 .36084 .07753 .3525 Mtetra
.743 .73 .84 r
.07753 .3525 .08497 .36084 .09554 .35413 .08818 .3454 Mtetra
.737 .721 .836 r
.08818 .3454 .09554 .35413 .10612 .34759 .09884 .33844 Mtetra
.729 .71 .833 r
.09884 .33844 .10612 .34759 .11669 .34126 .10949 .33167 Mtetra
.722 .7 .829 r
.10949 .33167 .11669 .34126 .12726 .33515 .12013 .32508 Mtetra
.714 .688 .824 r
.12013 .32508 .12726 .33515 .13782 .3293 .13078 .31869 Mtetra
.707 .676 .817 r
.13078 .31869 .13782 .3293 .14839 .32358 .14144 .31237 Mtetra
.702 .664 .809 r
.14144 .31237 .14839 .32358 .15898 .31794 .15212 .30608 Mtetra
.701 .653 .798 r
.15212 .30608 .15898 .31794 .16962 .31211 .16285 .29959 Mtetra
.703 .643 .787 r
.16285 .29959 .16962 .31211 .18034 .30588 .17364 .29274 Mtetra
.705 .635 .777 r
.17364 .29274 .18034 .30588 .19113 .29915 .1845 .2855 Mtetra
.708 .63 .768 r
.1845 .2855 .19113 .29915 .20201 .2918 .19542 .27785 Mtetra
.704 .625 .766 r
.19542 .27785 .20201 .2918 .21291 .28439 .20635 .2703 Mtetra
.694 .619 .768 r
.20635 .2703 .21291 .28439 .2238 .27731 .21724 .26326 Mtetra
.668 .608 .778 r
.21724 .26326 .2238 .27731 .23459 .27161 .22802 .25759 Mtetra
.623 .587 .792 r
.22802 .25759 .23459 .27161 .24521 .268 .23866 .2539 Mtetra
.563 .555 .803 r
.23866 .2539 .24521 .268 .25568 .26668 .24914 .25231 Mtetra
.489 .511 .806 r
.24914 .25231 .25568 .26668 .26601 .26769 .25951 .25284 Mtetra
.45 .481 .8 r
.25951 .25284 .26601 .26769 .27635 .26964 .26986 .2544 Mtetra
.443 .472 .795 r
.26986 .2544 .27635 .26964 .28677 .27157 .28027 .2562 Mtetra
.478 .491 .793 r
.28027 .2562 .28677 .27157 .29738 .27209 .29084 .25711 Mtetra
.53 .528 .797 r
.29084 .25711 .29738 .27209 .30822 .2705 .3016 .2565 Mtetra
.574 .567 .808 r
.3016 .2565 .30822 .2705 .31922 .26724 .31252 .25449 Mtetra
.614 .609 .823 r
.31252 .25449 .31922 .26724 .33037 .26266 .32359 .25123 Mtetra
.636 .645 .842 r
.32359 .25123 .33037 .26266 .34157 .25778 .33474 .24736 Mtetra
.648 .673 .86 r
.33474 .24736 .34157 .25778 .3528 .25312 .34596 .24322 Mtetra
.651 .687 .871 r
.34596 .24322 .3528 .25312 .36405 .24897 .35723 .23904 Mtetra
.652 .687 .87 r
.35723 .23904 .36405 .24897 .37531 .24534 .36854 .23482 Mtetra
.657 .676 .857 r
.36854 .23482 .37531 .24534 .38662 .24193 .37992 .23032 Mtetra
.667 .659 .832 r
.37992 .23032 .38662 .24193 .398 .23822 .39137 .22522 Mtetra
.687 .643 .8 r
.39137 .22522 .398 .23822 .40947 .23318 .40291 .21884 Mtetra
.704 .631 .773 r
.40291 .21884 .40947 .23318 .42105 .22645 .41453 .21106 Mtetra
.72 .626 .752 r
.41453 .21106 .42105 .22645 .43272 .21759 .42623 .20172 Mtetra
.729 .625 .742 r
.42623 .20172 .43272 .21759 .44444 .20729 .43797 .19147 Mtetra
.727 .625 .744 r
.43797 .19147 .44444 .20729 .45617 .19694 .4497 .18144 Mtetra
.714 .623 .754 r
.4497 .18144 .45617 .19694 .46788 .18753 .46142 .17244 Mtetra
.681 .612 .772 r
.46142 .17244 .46788 .18753 .47957 .18046 .47311 .16558 Mtetra
.639 .594 .787 r
.47311 .16558 .47957 .18046 .49126 .17572 .48481 .16085 Mtetra
.589 .568 .798 r
.48481 .16085 .49126 .17572 .50298 .17311 .49654 .15813 Mtetra
.55 .546 .803 r
.49654 .15813 .50298 .17311 .51476 .1719 .50832 .1568 Mtetra
.534 .536 .803 r
.50832 .1568 .51476 .1719 .52662 .17104 .52017 .156 Mtetra
.53 .535 .805 r
.52017 .156 .52662 .17104 .53856 .17012 .53211 .15532 Mtetra
.542 .547 .809 r
.53211 .15532 .53856 .17012 .55057 .16858 .54413 .15422 Mtetra
.553 .561 .816 r
.54413 .15422 .55057 .16858 .56265 .16653 .55622 .15273 Mtetra
.564 .577 .825 r
.55622 .15273 .56265 .16653 .5748 .16407 .56838 .15087 Mtetra
.57 .592 .836 r
.56838 .15087 .5748 .16407 .58701 .16142 .58062 .14882 Mtetra
.569 .603 .848 r
.58062 .14882 .58701 .16142 .5993 .15885 .59293 .14679 Mtetra
.565 .614 .86 r
.59293 .14679 .5993 .15885 .61166 .15642 .60532 .14485 Mtetra
.557 .621 .871 r
.60532 .14485 .61166 .15642 .6241 .15426 .6178 .14312 Mtetra
.548 .627 .882 r
.6178 .14312 .6241 .15426 .63663 .15233 .63036 .14157 Mtetra
.538 .632 .892 r
.63036 .14157 .63663 .15233 .64924 .15063 .64302 .14023 Mtetra
.529 .638 .902 r
.64302 .14023 .64924 .15063 .66195 .1491 .65576 .13904 Mtetra
.521 .644 .91 r
.65576 .13904 .66195 .1491 .67474 .14771 .6686 .13798 Mtetra
.514 .65 .919 r
.6686 .13798 .67474 .14771 .68763 .14642 .68153 .13702 Mtetra
.507 .657 .927 r
.68153 .13702 .68763 .14642 .70061 .14518 .69456 .13612 Mtetra
.501 .664 .935 r
.69456 .13612 .70061 .14518 .71368 .14397 .70769 .13525 Mtetra
.759 .768 .86 r
.02714 .37496 .03496 .38178 .04559 .3744 .03778 .36771 Mtetra
.759 .773 .864 r
.03778 .36771 .04559 .3744 .05623 .36703 .04842 .3605 Mtetra
.759 .778 .868 r
.04842 .3605 .05623 .36703 .06688 .35973 .05907 .35336 Mtetra
.759 .783 .873 r
.05907 .35336 .06688 .35973 .07753 .3525 .06973 .3463 Mtetra
.758 .789 .878 r
.06973 .3463 .07753 .3525 .08818 .3454 .08039 .33934 Mtetra
.756 .794 .884 r
.08039 .33934 .08818 .3454 .09884 .33844 .09106 .3325 Mtetra
.754 .798 .889 r
.09106 .3325 .09884 .33844 .10949 .33167 .10173 .3258 Mtetra
.751 .801 .893 r
.10173 .3258 .10949 .33167 .12013 .32508 .11241 .31923 Mtetra
.747 .803 .897 r
.11241 .31923 .12013 .32508 .13078 .31869 .12309 .31279 Mtetra
.745 .802 .898 r
.12309 .31279 .13078 .31869 .14144 .31237 .13379 .30641 Mtetra
.744 .801 .898 r
.13379 .30641 .14144 .31237 .15212 .30608 .14451 .30003 Mtetra
.747 .8 .895 r
.14451 .30003 .15212 .30608 .16285 .29959 .15527 .29354 Mtetra
.752 .801 .892 r
.15527 .29354 .16285 .29959 .17364 .29274 .16608 .28683 Mtetra
.758 .807 .892 r
.16608 .28683 .17364 .29274 .1845 .2855 .17693 .27992 Mtetra
.765 .818 .895 r
.17693 .27992 .1845 .2855 .19542 .27785 .18783 .27283 Mtetra
.763 .837 .908 r
.18783 .27283 .19542 .27785 .20635 .2703 .19873 .2659 Mtetra
.752 .858 .928 r
.19873 .2659 .20635 .2703 .21724 .26326 .20961 .25943 Mtetra
.715 .874 .956 r
.20961 .25943 .21724 .26326 .22802 .25759 .22041 .25394 Mtetra
.645 .868 .983 r
.22041 .25394 .22802 .25759 .23866 .2539 .23112 .24981 Mtetra
.56 .829 .996 r
.23112 .24981 .23866 .2539 .24914 .25231 .24174 .2471 Mtetra
.48 .759 .992 r
.24174 .2471 .24914 .25231 .25951 .25284 .25228 .24583 Mtetra
.464 .688 .963 r
.25228 .24583 .25951 .25284 .26986 .2544 .26282 .24534 Mtetra
.478 .629 .919 r
.26282 .24534 .26986 .2544 .28027 .2562 .2734 .24518 Mtetra
.514 .595 .873 r
.2734 .24518 .28027 .2562 .29084 .25711 .28408 .24466 Mtetra
.55 .583 .84 r
.28408 .24466 .29084 .25711 .3016 .2565 .29489 .24335 Mtetra
.578 .585 .823 r
.29489 .24335 .3016 .2565 .31252 .25449 .30582 .24121 Mtetra
.603 .595 .817 r
.30582 .24121 .31252 .25449 .32359 .25123 .31687 .23824 Mtetra
.619 .609 .819 r
.31687 .23824 .32359 .25123 .33474 .24736 .32801 .23473 Mtetra
.631 .622 .823 r
.32801 .23473 .33474 .24736 .34596 .24322 .33922 .23081 Mtetra
.64 .631 .825 r
.33922 .23081 .34596 .24322 .35723 .23904 .3505 .22659 Mtetra
.648 .634 .823 r
.3505 .22659 .35723 .23904 .36854 .23482 .36185 .22208 Mtetra
.656 .633 .815 r
.36185 .22208 .36854 .23482 .37992 .23032 .37325 .21715 Mtetra
.666 .631 .805 r
.37325 .21715 .37992 .23032 .39137 .22522 .38473 .21168 Mtetra
.682 .633 .794 r
.38473 .21168 .39137 .22522 .40291 .21884 .39628 .20536 Mtetra
.699 .642 .789 r
.39628 .20536 .40291 .21884 .41453 .21106 .4079 .1982 Mtetra
.718 .661 .792 r
.4079 .1982 .41453 .21106 .42623 .20172 .41957 .19024 Mtetra
.737 .693 .808 r
.41957 .19024 .42623 .20172 .43797 .19147 .43128 .18191 Mtetra
.749 .736 .84 r
.43128 .18191 .43797 .19147 .4497 .18144 .443 .17388 Mtetra
.748 .788 .885 r
.443 .17388 .4497 .18144 .46142 .17244 .45472 .16665 Mtetra
.711 .835 .941 r
.45472 .16665 .46142 .17244 .47311 .16558 .46644 .16086 Mtetra
.641 .853 .981 r
.46644 .16086 .47311 .16558 .48481 .16085 .47817 .15651 Mtetra
.551 .834 .998 r
.47817 .15651 .48481 .16085 .49654 .15813 .48994 .15354 Mtetra
.487 .798 .999 r
.48994 .15354 .49654 .15813 .50832 .1568 .50177 .15158 Mtetra
.472 .769 .996 r
.50177 .15158 .50832 .1568 .52017 .156 .51367 .15008 Mtetra
.479 .748 .988 r
.51367 .15008 .52017 .156 .53211 .15532 .52564 .14876 Mtetra
.504 .738 .978 r
.52564 .14876 .53211 .15532 .54413 .15422 .53769 .14726 Mtetra
.522 .734 .971 r
.53769 .14726 .54413 .15422 .55622 .15273 .54981 .14556 Mtetra
.536 .734 .966 r
.54981 .14556 .55622 .15273 .56838 .15087 .56201 .14364 Mtetra
.542 .736 .965 r
.56201 .14364 .56838 .15087 .58062 .14882 .57428 .14161 Mtetra
.54 .737 .966 r
.57428 .14161 .58062 .14882 .59293 .14679 .58663 .13958 Mtetra
.536 .736 .967 r
.58663 .13958 .59293 .14679 .60532 .14485 .59906 .13762 Mtetra
.527 .732 .968 r
.59906 .13762 .60532 .14485 .6178 .14312 .61157 .1358 Mtetra
.52 .727 .968 r
.61157 .1358 .6178 .14312 .63036 .14157 .62417 .13412 Mtetra
.513 .72 .966 r
.62417 .13412 .63036 .14157 .64302 .14023 .63685 .13259 Mtetra
.509 .712 .963 r
.63685 .13259 .64302 .14023 .65576 .13904 .64963 .13118 Mtetra
.505 .704 .96 r
.64963 .13118 .65576 .13904 .6686 .13798 .66249 .12988 Mtetra
.503 .696 .956 r
.66249 .12988 .6686 .13798 .68153 .13702 .67545 .12868 Mtetra
.502 .689 .951 r
.67545 .12868 .68153 .13702 .69456 .13612 .6885 .12754 Mtetra
.502 .682 .947 r
.6885 .12754 .69456 .13612 .70769 .13525 .70165 .12647 Mtetra
.742 .767 .873 r
.01926 .36808 .02714 .37496 .03778 .36771 .02981 .36158 Mtetra
.745 .789 .888 r
.02981 .36158 .03778 .36771 .04842 .3605 .04036 .35517 Mtetra
.748 .814 .904 r
.04036 .35517 .04842 .3605 .05907 .35336 .05092 .34883 Mtetra
.749 .84 .92 r
.05092 .34883 .05907 .35336 .06973 .3463 .0615 .34257 Mtetra
.747 .867 .935 r
.0615 .34257 .06973 .3463 .08039 .33934 .07209 .33639 Mtetra
.743 .893 .947 r
.07209 .33639 .08039 .33934 .09106 .3325 .08269 .33029 Mtetra
.733 .916 .955 r
.08269 .33029 .09106 .3325 .10173 .3258 .09331 .32426 Mtetra
.719 .934 .959 r
.09331 .32426 .10173 .3258 .11241 .31923 .10395 .31832 Mtetra
.701 .948 .957 r
.10395 .31832 .11241 .31923 .12309 .31279 .1146 .31245 Mtetra
.677 .955 .949 r
.1146 .31245 .12309 .31279 .13379 .30641 .12527 .30666 Mtetra
.647 .957 .934 r
.12527 .30666 .13379 .30641 .14451 .30003 .13596 .30095 Mtetra
.606 .951 .908 r
.13596 .30095 .14451 .30003 .15527 .29354 .14667 .29531 Mtetra
.544 .929 .859 r
.14667 .29531 .15527 .29354 .16608 .28683 .1574 .28975 Mtetra
.449 .875 .77 r
.1574 .28975 .16608 .28683 .17693 .27992 .16815 .28427 Mtetra
.322 .779 .637 r
.16815 .28427 .17693 .27992 .18783 .27283 .17893 .27887 Mtetra
0 0 0 r
.17893 .27887 .18783 .27283 .19873 .2659 .18973 .27354 Mtetra
.18973 .27354 .19873 .2659 .20961 .25943 .20056 .26829 Mtetra
.013 0 0 r
.20056 .26829 .20961 .25943 .22041 .25394 .21141 .26311 Mtetra
.037 0 0 r
.21141 .26311 .22041 .25394 .23112 .24981 .22229 .25802 Mtetra
0 0 0 r
.22229 .25802 .23112 .24981 .24174 .2471 .23321 .25299 Mtetra
.23321 .25299 .24174 .2471 .25228 .24583 .24415 .24805 Mtetra
.404 .853 .778 r
.24415 .24805 .25228 .24583 .26282 .24534 .25512 .24318 Mtetra
.642 .917 .979 r
.25512 .24318 .26282 .24534 .2734 .24518 .26612 .23838 Mtetra
.681 .779 .925 r
.26612 .23838 .2734 .24518 .28408 .24466 .27716 .23367 Mtetra
.66 .664 .843 r
.27716 .23367 .28408 .24466 .29489 .24335 .28824 .22903 Mtetra
.64 .597 .79 r
.28824 .22903 .29489 .24335 .30582 .24121 .29934 .22446 Mtetra
.626 .559 .76 r
.29934 .22446 .30582 .24121 .31687 .23824 .31049 .21997 Mtetra
.618 .539 .743 r
.31049 .21997 .31687 .23824 .32801 .23473 .32168 .21556 Mtetra
.612 .528 .735 r
.32168 .21556 .32801 .23473 .33922 .23081 .3329 .21123 Mtetra
.609 .522 .731 r
.3329 .21123 .33922 .23081 .3505 .22659 .34417 .20697 Mtetra
.607 .521 .731 r
.34417 .20697 .3505 .22659 .36185 .22208 .35548 .20278 Mtetra
.607 .524 .736 r
.35548 .20278 .36185 .22208 .37325 .21715 .36683 .19868 Mtetra
.608 .533 .745 r
.36683 .19868 .37325 .21715 .38473 .21168 .37823 .19465 Mtetra
.612 .551 .763 r
.37823 .19465 .38473 .21168 .39628 .20536 .38968 .1907 Mtetra
.619 .587 .796 r
.38968 .1907 .39628 .20536 .4079 .1982 .40117 .18682 Mtetra
.63 .651 .852 r
.40117 .18682 .4079 .1982 .41957 .19024 .41272 .18302 Mtetra
.632 .764 .942 r
.41272 .18302 .41957 .19024 .43128 .18191 .42431 .1793 Mtetra
.543 .883 .987 r
.42431 .1793 .43128 .18191 .443 .17388 .43596 .17566 Mtetra
.236 .746 .713 r
.43596 .17566 .443 .17388 .45472 .16665 .44766 .17209 Mtetra
.032 0 0 r
.44766 .17209 .45472 .16665 .46644 .16086 .45942 .1686 Mtetra
.145 0 0 r
.45942 .1686 .46644 .16086 .47817 .15651 .47123 .1652 Mtetra
.183 0 0 r
.47123 .1652 .47817 .15651 .48994 .15354 .4831 .16186 Mtetra
.177 0 0 r
.4831 .16186 .48994 .15354 .50177 .15158 .49503 .15861 Mtetra
.137 0 0 r
.49503 .15861 .50177 .15158 .51367 .15008 .50703 .15544 Mtetra
.068 0 0 r
.50703 .15544 .51367 .15008 .52564 .14876 .51909 .15235 Mtetra
0 0 0 r
.51909 .15235 .52564 .14876 .53769 .14726 .53121 .14933 Mtetra
.53121 .14933 .53769 .14726 .54981 .14556 .5434 .1464 Mtetra
.212 .735 .752 r
.5434 .1464 .54981 .14556 .56201 .14364 .55566 .14355 Mtetra
.275 .78 .831 r
.55566 .14355 .56201 .14364 .57428 .14161 .56799 .14077 Mtetra
.321 .805 .884 r
.56799 .14077 .57428 .14161 .58663 .13958 .58039 .13808 Mtetra
.359 .82 .923 r
.58039 .13808 .58663 .13958 .59906 .13762 .59286 .13547 Mtetra
.391 .827 .953 r
.59286 .13547 .59906 .13762 .61157 .1358 .60541 .13295 Mtetra
.423 .829 .977 r
.60541 .13295 .61157 .1358 .62417 .13412 .61804 .1305 Mtetra
.452 .824 .992 r
.61804 .1305 .62417 .13412 .63685 .13259 .63075 .12814 Mtetra
.478 .811 .999 r
.63075 .12814 .63685 .13259 .64963 .13118 .64354 .12587 Mtetra
.499 .792 .998 r
.64354 .12587 .64963 .13118 .66249 .12988 .65642 .12367 Mtetra
.515 .77 .989 r
.65642 .12367 .66249 .12988 .67545 .12868 .66938 .12157 Mtetra
.526 .745 .975 r
.66938 .12157 .67545 .12868 .6885 .12754 .68242 .11954 Mtetra
.534 .72 .959 r
.68242 .11954 .6885 .12754 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Nooooo`;oQ[ki1?n8^?D00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo057ooooo001Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool07Oooool3o`0000;ooooo00?o0000ooooooooool0F?oo
ool2oh?5o@GoQ[ki0on8^?D00ol0003oR;Seooooo`0Eooooo`03o`000?oooooooooo053ooooo001P
ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0001cooooo0_l0001Gooooo`?oN/oo1Omo
b_l4oh?5o@GoQ[ki0_n8^?D00ol0003oP:kbooooo`0Dooooo`03o`000?oooooo0000057ooooo001P
ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0000Jooooo`?o0000
EOooool4og?Bo@CoN/oo0_mob_l2oh6dm@CoP;;d1_n0/?<01?n0[_;o0000oh2^l_n0[_8Fooooo`03
o`000?oooooooooo04oooooo001Pooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgo
EEEEooooool0000Hooooo`;o0000D?ooool4ofCCl`CoK=Cj0_mcd_d2oh>hm`GoP[Kf1?n1]?D4oh2b
m0KoP;3c00Co0000oh2^l_n0[_;oP:kb5_ooool00ol0003oooooooooo`1>ooooo`00H?ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000005Oooool3o`0000;ooooo00?o0000
ooooooooool0BOooool4oe_Ak0;oI=?c0_n6^oL5ohFjm`CoPkSg1On2]_H4oh6dm@CoP;;d0on0/?<2
oh6Xk@04o`000?n0ZNooP:W_oh2YkaKooooo00?o0000ooooooooool0C_ooool0063ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000001?ooooo0_l0001=ooooo`CoD/kR0_mK
dN`3ohVlm`CoQ[_g1On5^_L4oh>hm`;oP[Kf0_n7XnH4ohFTj0CoPjK[1On1Z>d00ol0003oP:W_oh2Y
k`02oh2YkaKooooo00?o0000ooooooooool0COooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00oooooo0ol0001;ooooo`;oA/OD1on:_?L5ohVlm`CoQ[_g0_n5
^_L2ohbPh@CoRJ7T1On7XnH4ohFTj0CoPjK[1?n1Z>d00ol0003oP:W_oh2Yk`03oh2YkaKooooo00?o
0000ooooooooool0C?ooool008;ooooo0_l00019ooooo`03o`000?lf_<3oRK_g00CoRK_g2?n:_?L2
ohVlm`;oT9gL1?n>W]h5ohbPh@CoRJ7T1?n7XnH5ohFTj0CoPjK[0_n1Z>d00on7Y>Oo0000ohFYk004
ohFYk1Kooooo00?o0000ooooooooool0C?ooool007oooooo0ol00002ooooo`03o`000?oooooooooo
03kooooo0_lA0004o`000003oh6ln_n5^oSoQK_h00;oQK_h1On9^oL2ohZlm`03oi6Ge_nAV]WoTI[I
00;oTI[I1On@WM`4ohjNgPCoS:3Q1On9XN@4ohNSiP;oQJCX0_n;Vmd4ohVOhP?oQjCW00?o0000ohNT
ion5ZN`01?n5ZN`Dooooo`?o0000COooool007cooooo0ol0000oooooo`03obd00?lS003o8`0000;o
8`000olA00000ol0003oN[oloh6lnP04oh6lnPCoQK_h0_n9^oL2oi2Cd`CoTIOF1?nAV]T4oi2Mg0Go
SYkN1?n<X>42ohVQi0;oSiCE1?n=V=T5oh^Kg@CoRIoR0_n7Y>L00ol0003oQjCWohNTi`04ohFYk1Oo
oooo00?o0000ooooooooool0B_ooool007[ooooo0_l0000nooooo`;o;P000ol]0003ob<00003oa40
0?mha?koN<Cn00CoN[ol0_n1_?X2ohZ<c`CoSHo@1On@Tm<3oi6GePCoTI[I1On@WM`2ohjNgP;oTXo=
1?n@TM45ohnDe@CoSISI1?n;Vmd5ohVOhP;oQjCW00?o0000oi6ShOn?ZnP01?n?ZnPFooooo`03o`00
0?oooooooooo04[ooooo001gooooo`?o0000??ooool2obD000?o;P000ol]00000olS003oS8_=ohb;
c@04ohR9c@CoQhS>1On:S<l4ohf?d0CoT9?C1?nAUmH4oi6Jf@;oT9gL0_nCS<T5oi:?c@CoT97A1?n?
U=D5ohfHf@CoRi_M0_n9Wn82oi:LfP;oTJ?Q00?o0000oi6ShOnAXn401On?ZnPFooooo`03o`000?oo
oooooooo04Wooooo001eooooo`;o00000_ooool00ol0003oooooooooo`0gooooo`03o`P00?lU003o
9@0000;o9@000_l^00000ol]003oUY7<oiJAc002oiJAc0?oS8_=1?n8RLd4ohN8cPCoRXc?1?n=Sm05
oi2Cd`;oTIOF00?oU8K2oiB9aOnDRLD00_nDRLD5oi><b@CoTXo=1?n@TM45ohnDe@;oSISI0_nCTLh4
oi>Fe0GoTYcJ00?oTJ?Qo`000?nAXn400_nAXn42ohn[j0;oW;3V5oooool00ol0003oooooooooo`18
ooooo`00L_ooool3o`0000Gooooo00?o0000ooooooooool0=?ooool3o`P000?o9@0000Co;P00oj>H
bOnSV<WoXiS91?nFTL`4ohb;c@?oR8W=1?n7R<h4ohZ<c`GoSHo@0_n@Tm<2oi:2_PCoU8K21?nDRLD4
oi><b@CoTXo=1On@TM42ohnDe@;oU8c91OnCTLh4oi>Fe0CoTYcJ00GoTJ?Qo`000?nAXn7oTJ?QoibW
g@05oib`iQKooooo00?o0000ooooooooool0B?ooool0073ooooo0_l0000mooooo`07ocbn]_l8003o
2000o`P00?lU003o]]G`ojjLa@05oj>Hb@CoUY7<1?n<Rld3ohR9c@GoQhS>1?n:S<l2ohf?d0;oT7jl
1OnBP[h3oiB6`PCoU8W51?nCS<T5oi:?c@;oT97A0_nERL@5oiB<b@CoTi7>1?nCU]@5oi:LfP03o`00
0?nLYmgoW:OM00;oW:OM1OnL/>HFooooo`03o`000?oooooooooo04Oooooo000hooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000Pooooo`?o0000?_ooool00oll_[Ko2000
oko9hP02oko9hP04okKEl?n^W<Go[Yc5ojjLa@CoXiS91OnFTL`4ohb;c@?oR8W=0_n7R<h2ohUf]`Co
SGZi1On@O[`4oi:2_P?oU8K21?nDRLD5oi><b@;oTXo=0_nFQ/05oiF9a0CoU8c91?nCTLh5oi>Fe0;o
TYcJ0_nLWmH00ol0003oW:OMoibWg@02oibWg@CoW;3V00?oZ;KSooooooooool04oooool3o`0004So
oooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00Nooooo`;o00000oooool00ol0003oooooooooo`0iooooo`03ocbn]_nobN;o_lWR
00?o_lWR00?o]Yo1ojjLaOn^W<D00_n^W<D5oj>Hb@;oUY7<0_nAN;@4oh]d]0?oRGBf1?n9M[L5ohej
^@CoT7jl1?nBP[h4oiB6`PCoU8W50_nCS<T2oiJ3_0GoUXK01?nERL@4oiB<b@GoTi7>0_nCU]@2oi^H
c`CoW9oF00?o0000oibWgOnLYmd00onLYmd00onL/>KoZ;KSojRfh`02ojRfhaKooooo00?o0000oooo
ooooool01_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:Oooool003Sooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7o
k^k^01cooooo0ol0000nooooo`;oRn;l0ono_=L3oko9hP?o]Yo10on^W<D4oj>Hb@03oi]n/onAN;Co
TGRd00;oTGRd1?n;M;@3ohUd]PGoRGJg1?n=N[T4oi1n_0GoTX:n0onDQ/82oiB9a@;oUX2i1OnFPk`4
oiJ6`0CoUHW41OnDS<T2oi>AcP;oVi;:1OnKV<l3oibOeP04o`000?nLWmKoW:OMoibWg@;oYjgL1_nX
]^<Fooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1oooool00ol0003oooooooooo`0Zooooo`00>?ooool01Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h06?ooool3o`0003gooooo1?nQ`o400on;h_co_kcGoknle`03oknle`03oko9
h_nfWl7o]Yo100;o]Yo11?n^W<D01?nSV<WoVgjcoi]n/onKO[<5oi5h]0CoRgBd0on9M;H4ohUf]`Co
SGZi1On@O[`4oi:2_P;oU8K200?oUWffoiJ0^OnFP;T00onFP;T4oiJ3_0CoUXK01OnERL@2oiB<b@;o
Vhk51OnKT/X4oi^Hc`?oW9oF00?o0000ojJUeOnW[M`01?nW[M`4ojRfh`;o/kgQ5_ooool00ol0003o
ooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0002_ooooo000hooooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Eooooo`?o0000??ooool00onQ
Y][oXL?aoj73l@03oj73l@03okbac_no_=Oo_kcG00?o_kcG00?o^YnnokJO`OnfWl400onfWl43ojjL
a@03ojB5/_nKO[?oVgjc00?oVgjc1?nAN;@4oh]d]0?oRGBf1?n9M[L5ohej^@CoT7jl0_nBP[h2oiEj
/`CoUWff1?nFP;T4oiJ3_0GoUXK00_nERL@2oi^:`0GoVhk51?nKT/X5oi^Hc`03oibOe_nVYMGo0000
00;oYZGE1OnW[M`00onX]^?o/kgQok>mh@03ok>mhAGooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000;?ooool003Sooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo017ooooo0ol00003ooooo`03o`000?oo
oooooooo03Oooooo1?nQY]X3oj73l@?o_;7>0ono_=L3okZO_PGo]Yo100?o[Yc5ojB5/_nTQK801OnK
O[<4oi5h]0CoRgBd0on9M;H5ohUf]`CoSGZi0_n@O[`2oi9f/0CoUGZc1?nFOKH4oiJ0^@GoUX>l0onF
Q/000onKQ[coVh[0oi^:`003oi^:`0CoVhk51OnKT/X2oi^Hc`;oYIk?0_nVYMD00ol0003oYZGEojJU
e@04ojN]g003ok:fg?nc_N7o/kgQ00?o/kgQ00?o^lGQooooooooool05?ooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000/ooooo`00
>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Aoooo
o`;o0000?_ooool2oijFb`GoXJKJ00?oXL?aokbac_nl/Lh00onl/Lh00ono_=Oo^YnnokZO_P02okZO
_PCo]Yo100?o[H^aojB5/_nTQK800_nTQK84oi]n/`CoTGRd1On;M;@3ohUd]PCoRGJg0_n=N[T2oi1b
[PCoTWJ`1OnEN[<4oiIm]PCoUX2i1?nFPk`00onFQ/3oVhJloi^6_002oi^6_0CoVh[01?nKS/D4oi^B
bP03ojBIbOnUW/ooYIk?00?oYIk?00?oYZGEo`000?nVYMD00_nVYMD00onW[Mco/[KLok:fg002ok:f
g0?o/kgQ0onkaN4Fooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002cooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00kooooo0ol0000looooo`;oW8g31OnNU//3oj6VfP03okNYb_nl
/Lko_;7>00?o_;7>00?o^YnmokZO__njWkh00onjWkh3okJO`@;o[H^a1?nTQK85oi]n/`CoTGRd1?n;
M;@3ohUd]P;oRGJg0_n<KZ`4oi1b[PGoTWJ`1?nEN[<4oiIm]PCoUX2i0_nFPk`2oi^4^@GoVhJl1?nK
R/05oi^>a@03oi^Bb_nTVLWoY9W900;oY9W91?nUW/l01OnVYMGo0000ojJUeOnVYMGo/:oG00Ko/[KL
00?o/kgQok_5hOnkaN400onkaN4Dooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?ok^k^odA4A?l00000;?ooool005Wooooo0ol0000kooooo`03oi^8__nLSL?oW8g300?oW8g3
1OnNU//01?nQY][o]jW:okNYb_ngZLX3okbacP?o^Ynm1OnjWkh00onfWl7o[H^aojf;/@02ojf;/@?o
Y8Fb1OnKO[<4oi5h]0;oRgBd0_n;K:T3oh]/ZPCoS6j/1On@LZh4oi9f/0CoUGZc1?nFOKH3oiJ0^@03
oi^1]_nKQ;WoVhBi00?oVhBi1?nKQ[`5oi^:`0?oVhk500?oXiC5ojBIbOnTVLT00onTVLT5ojFNc`03
o`000?n`[mOo/:oG00;o/:oG1?nb]]`2ok_2g`Co^lGQ00?o_l[Sooooooooool04Oooool01?l0003o
ooooooooool00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0[
ooooo`00E_ooool3o`0000?ooooo00?o0000ooooooooool0=Oooool00onKQ[coVhRnoi^8_P02oi^8
_PCoW8g31?nNU//00onbY<Wo]jW:okNYbP03okNYbP03okbac_njWkgo^Ynm00;o^Ynm1?njWkh00on`
S[;o[H^aojf;/@03ojf;/@CoY8Fb0onKO[<00onFLZWoSfjYohm^Z@02ohm^Z@CoRfbY0on;K:X5oha^
[0CoT7:^1?nBM[05oiEj/`CoUWff00CoUX2ioi^1]_nKPKKoVh6f1?nKQ;T5oi^6_0CoVh[000?oVhk5
oj>DaOnSU<D00_nSU<D4ojBIb@CoYIk?00?o[j[Bo`000?n`[mL01?n`[mL00onb]]co^l;Ook_2g`03
ok_2g`03ok_5hOnob^?o_l[S00;o_l[S5_ooool00ol0003oooooooooo`10ooooo`00E?ooool2o`00
03cooooo1?nKQ[`3oi^8_PGoW8g300?oWYK;ok:TbOnbY<T00_nbY<T4okNYbPGo^Ynm0onjWkh2ok2>
/PGo[H^a1?nTQK801?nKO[?oUW:YoiIbZOnFLZT4ohm^Z@GoRfbY0on;K:X4oha^[0CoT7:^1?nBM[05
oiEj/`;oUWff0_nKOk<4oi^1]PCoVhBi1OnKQ[`2oi^:`0;oXi311OnSU<D5ojBIb@05ojFNcon_Z];o
[j[BojnZd_l000001?n`[mL00onk_mgo^l;Ook_2g`03ok_2g`03ol3<i?nob^?o_l[S00?o_l[S5_oo
ool00ol0003oooooooooo`10ooooo`00DOooool3o`0003_ooooo0_nKQK/5oi^6_0?oVhRn1?nLSL<0
0on^X/_o/ZC9ok:Tb@03ok:Tb@?o]jW:0_nhX<05okZO_@03okZO__n`S[;o/8jb00;o/8jb1On]Rk42
ojB5/P03oiehZOnFLZWoUW:Y00?oUW:Y1?n?KZT4oh]/Z@?oRfbZ1?n<KZ`4oi1b[PGoTWJ`0onEN[<0
0onJO;7oVgncoi]o/`02oi]o/`GoVh6f1?nKQ;T3oi^6_003oj:=__nST<7oXi3100?oXi311?nSU<D4
ojBIb@03ojjUc_n_Z];o[j[B00;o[j[B00?o0000ojnZd_n`[mL01?nk_md3ok_2g`?o`<cT0onob^<2
oko@iaKooooo00?o0000ooooooooool0?oooool004kooooo1Ol0000iooooo`KoVhFk1?nKQ[`4oi^8
_P03oib=`on^X/_o[Z;;00;o[Z;;1OnbY<T01?ngZL[o^:30okRP`?nhX<04okZO_@03ok:@/on`S[;o
/8jb00?o/8jb1On]Rk400onTQK;oWGRYoiehZ@05oiIbZ@CoSfjY1?n;K:T3oh]/ZPCoS6j/1On@LZh4
oi9f/004oiEj/onJO;7oVWbaoiYl/@GoVgnc1?nKPKH4oi^4^@03oi^6_?nRSKkoXXfn00;oXXfn1?nS
T<45oj>Da@03ojBIbOn^YLko[ZG>00;o[ZG>0on_Z]800ol0003o^[cKok^og@05ok^og@03ok_2goo0
c>Co`<cT00?o`<cT00?o_l[Soko@ionod>L00_nod>LFooooo`03o`000?oooooooooo03kooooo001<
ooooo`;o00001Oooool00ol0003oooooooooo`0cooooo`03oib7_?nKQK_oVhFk00KoVhFk1OnKQ[`2
oi^8_P03ojZQc_n^X/_o[Z;;00?o[Z;;1?nbY<T00ondXLGo^:30okRP`002okRP`0?o^Ynm0_nbT;<5
ok2>/PCo[H^a00?oY7fYoiehZOnMN:T00_nMN:T4oiIbZ@CoSfjY1?n;K:T3oh]/ZPCoS6j/1On@LZh2
oi9f/0;oV7R^1OnJO;44oi]o/`CoVh6f0onKQ;T00onSRk_oXXfnoj:=_P03oj:=_PCoXi311?nSU<D0
0on]XL_o[ZG>ojjUcP03ojjUcP?o[j[B00?o0000okZlfonj_=/01?nk_md2ol7>i@Co`<cT00?o`MS[
oko@ionod>L00_nod>L00onidNcoooooooooo`0Dooooo`03o`000?oooooooooo03kooooo0019oooo
o`?o0000>oooool4oib7_0OoVhFk1OnKQ[`01?nKR;koZZ7>ojZQc_nZXLh4ojjRb`?o/ZC90ondXLD4
okRP`003okZO_OnbT;?o/Y2c00;o/Y2c1On`S[82ojf;/@;oY7fY1?nMN:T4oiIbZ@CoSfjY1?n;K:T3
oh]/ZPGoS6j/0on@LZh00onDM:coV7R^oiQh[P02oiQh[PGoVWba1?nKOk<5oi^1]P04oi^4^OnSRk_o
Xh^koj>;^`CoXXfn1OnST<400onSU<Go[J7;ojfQb`02ojfQb`Go[ZG>00Co[j[BokZlfonj_=_o0000
0_nj_=/00onk_mgo`LkUol7>i@03ol7>i@03ol3<i?o1f>_o`MS[00;o`MS[00?o_m3WokWAk?nidN`0
0_nidN`Dooooo`?o0000?oooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Pooooo`;o0000
??ooool00onNRKkoW8Nloib7_003oib7_0SoVhFk0onKQ[`00onWX]3oZZ7>ojZQcP02ojZQcPGo[Z;;
00?o/ZC9okBQaOndXLD00_ndXLD4okRP`0Go/Y2c1On`S[800on]Rk7oY7fYojAmZ@02ojAmZ@?oWGRY
1?nFLZT4ohm^Z@GoRfbY0on;K:X4oha^[004oi1b[_nDM:coU7B/oiAd[0GoV7R^1?nJO;45oi]o/`?o
Vh6f00?oXhVioj>;^onSRk/00_nSRk/5oj:=_P?oXi3100?o[9g8ojfQbon]XL/00on]XL/4ojjUcP07
okZkf_nj_=_o^[cKokZlfol0003o^[cKol7AiP05ol7>i@03ol7Pkoo1f>_o`MS[00;o`MS[0_nig?85
okWAk1Gooooo00?o0000ooooooooool0?Oooool002;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0M
ooooo`?o00000_ooool00ol0003oooooooooo`0eooooo`;oX8o21?nNRKh4oib7_0SoVhFk00?oVhJl
ojNRd?nWX]000_nWX]03ojZQcPCo[Z;;00?o[jC<okBQaOndXLD00ondXLD3okRP`003ojnA^?nbT;?o
/Y2c00?o/Y2c1?n`S[800onWOjWoY7fYojAmZ@03ojAmZ@?oWGRY1OnFLZT4ohm^Z@CoRfbY0on;K:X2
oha^[0;oTG2Z1OnDM:`4oiQh[PCoVWba1OnKOk<00onKPKKoXhVioj>9^@02oj>9^@?oXh^k1OnRSKh0
0onST<7o[9g8ojbMb002ojbMb0Go[J7;00?o[ZG>okZkf_nj^mX00_nj^mX2okZlf`04o`000?o1dNKo
`M7Vol7AiP?o`LkU0oo1h>l00oo1f>_o^McbokWLlP03okWLlP;o^M7/0on^c_4Eooooo`03o`000?oo
oooooooo03cooooo000Rooooo`05oa0@4?ooooooooooooooool@41006oooool2o`0003[ooooo00?o
XiS:oj2?`_nPSl800onPSl83oij9_PGoW8Nl1OnKQK/2ojFRdPGoYj;@1?nZXLh00on^X/_o[jC<ojnT
c002ojnTc0Go]:7500Co^:30ojnA^?n_TKSo[i6h1OnbT;<2ok2>/P;oYgnY1OnTOJT3oiehZ@GoUW:Y
1?n?KZT2oh]/Z@;oSF^W0on>KJP4oi5`ZPGoU7B/1?nHN:h5oiYl/@?oVgnc00?oXhNgoj>9^OnSRKT0
0onSRKT4oj>;^`?oXXfn00?o[9_6ojbMb?n/WLP00on/WLP4ojfQb`03okZifOnj^m[o^[_J00Co^[_J
00?o^[cKo`000?o1dNH00oo1dNH01?o1c^Go`N3_ol7Pkoo1h>l2okKWmPCo^Mcb00?o[=[hojk>lOn^
c_401?n^c_4Eooooo`03o`000?oooooooooo03_ooooo000Rooooo`05o`000?ooooooooooooooool0
00006?ooool3o`0003_ooooo0onSV<X4oj2?`P?oWXVn1OnLQk`2oi^5^`03oj>QdonUX];oYJ;B00?o
YJ;B1OnWX]02ojZQcP03ojZXe?n_Y<co[jC<00?o[jC<1?ndXLD00onYT[ko[i6hojnA^002ojnA^0Go
/Y2c00?o/8jbojMoZOnWOjT00_nWOjT4ojAmZ@CoWGRY1?nFLZT2ohm^Z@;oSfbV1?n=JjL3ohi]Z0Go
TG2Z1?nDM:`4oiQh[PGoVWba00?oVgncoj>7]onSQkL00_nSQkL4oj>9^@CoXh^k00?oXXfnojbKa_n/
VlH00_n/VlH5ojbMb003ojfQbonj^MWo^[WI00;o^[WI1?nj^mX2ol;Dj004o`000?o1dNKo`M7Vol7A
iP;o_nWb00?o`N3_okKWm_nfioH00onfioH00onig?;o[=[hojcJn002ojcJn0Co[/ka00?oXLKcoooo
ooooool04oooool00ol0003oooooooooo`0kooooo`008_ooool01Ol0003ooooooooooooooooo0000
01Kooooo0ol0000jooooo`;oZ:WG1?nSV<X4oj2?`PCoWXVn0onLQk`00onQWm;oXj7Coj>Qd`02oj>Q
d`CoYJ;B1?nWX]000onX[M_oZZSDojZXe002ojZXe0Go[jC<00?o]:75ojVB__nYT[h00_nYT[h3ojnA
^0Co/Y2c00?oYh2ZojMoZOnWOjT00onWOjT4ojAmZ@CoWGRY0_nFLZT2oiA_YPCoSfbV1On=JjL3ohi]
Z0CoTG2Z1?nDM:`5oiQh[P?oVWba00?oXXBdoj>7]onSQkL00onSQkL5oj>9^@;oXh^k00?o[9[4ojbK
a_n/VlH00on/VlH4ojbMb003okVifOnj^MWo^[WI00Co^[WI00?o^[_Jol;Dj?o2e>P00_o2e>P00ol0
003o`M7VokoYlP02okoYlP;o[O3g1?nfioH2ojCUn`Go[=[h00?o[/kaoj76lonQa_<00_nQa_<Eoooo
o`03o`000?oooooooooo03[ooooo000Rooooo`05oa0@4?ooooooooooooooool@41004oooool3o`00
00;ooooo00?o0000ooooooooool0=Oooool00on^ancoZ:WGojRYe`03ojRYe`?oXiS:1OnPSl83oij9
_P03oib7_?nQWm;oXIoB00;oXIoB1?nSXM<4ojFRdP03ojNRd?nX[M_oZ:gK00;oZ:gK0onZZ=@4ojnT
c003ojBDaOnYT[koZI:n00?oZI:n1?n_TKP2ok:@/`;oYh2Z1OnWOjT5ojAmZ@;oWGRY00?oVWBWoiA_
Y_nDKjH00_nDKjH5ohm/YPCoSF^W0on>KJP4oi5`ZPCoU7B/1OnHN:h01?nJO;7oXXBdoj:4]?nRQ;@5
oj>7]`GoXhVi00CoXh^kojbJa?n/V/Co[9[41?n/VlH3ojbMb0?o^KWI1?nj^MT2ol;HjPCo`]CX00Co
0000ok[alonjlO?o_nWb1?n]l?L00onfioKoY>GkojCUn`03ojCUn`;o[=[h0_nLcoX5oj76laKooooo
00?o0000ooooooooool0>Oooool002;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`?o0000
??ooool3ojk7k0CoZ:WG1?nSV<X4oj2?`P;oWXVn00?oWY_Aoj6Od_nQWm800onQWm85oj>Qd`;oYJ;B
00?oYZoNojR]fonX[M/00onX[M/4ojZXe003ojnTc?nTU<GoY9C500;oY9C51?nYT[h4ojnA^003ok:@
/onWP:[oYh2Z00;oYh2Z1?nWOjT5ojAmZ@03oiehZOnJM:OoVWBW00GoU6nV1?n?K:H4ohe[Y`?oSVfX
1?nAL:X5oiAd[0?oV7R^00?oWh6boj:4]?nRQ;@00onRQ;@5oj>7]`?oXhVi00?o[9W3ojbJa?n/V/@0
0_n/V/@5ojbKaP03ojbMb?ni^MWo^KWI00?o^KWI00?o^[WIol;Hj_o2f>X00oo2f>X01Oo2e>So^_7c
ok[alol0003o^_7c00;oV_7]0_n]l?L4oi;Zm`;oY>Gk1?nDeoh3oic?nP;oXLKc0onF_?8Dooooo`;o
0000>oooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`;o0000??ooool3ojCZnP?o
[/O/1OnXZML3oj>HbP;oX8o20_nJV=44oijKd@GoXIoB0_nSXM<6ojJ_gPGoZ:gK0_nZZ=@00onNUlco
Y9C5ojBDa@03ojBDa@GoZI:n0_n_TKP00onROZcoYh2ZojN0ZP03ojN0ZPCoYgnY1?nTOJT00onQNZOo
VWBWoiYdY`02oiYdY`CoU6nV1?n?K:H4ohe[Y`?oSVfX1OnAL:X4oiAd[004oiQh[_nOPK;oWh6boin1
/PGoXXBd1OnSQkL00onSRKWo[9W3ojbI``02ojbI``?o[9[41?n/VlH00onj^]Wo^KWIokVif@03okVi
f@;o`Mg]1?o2f>X3ojofl004ok[alol0003oV_7]oi[ak@?oM>;T0_nBj_L4ohOLoP;oU=On0_n?`_P4
oi:om@GoU[cb5Oooool00ol0003oooooooooo`0hooooo`00<_ooool5o`0003Wooooo1?mWf/L3ojCZ
nP?o[/O/0_nXZML2ohbEe`?oTiGB1OnJV=43oijKd@CoXIoB00?oYJcLojJ_g_nV[mh01onV[mh2ojR]
f`;oWI_A1?nNUl`4ojBDa@GoZI:n00?o[i6hoj9n[?nROZ`01OnWP:X5ojMoZ@;oY7fY0_nQNZL4oiYd
Y`CoU6nV1?n?K:H4ohe[Y`?oSVfX1OnAL:X2oiAd[0;oW7f`1OnOPK84oj:4]0CoXhNg00?o[IS2ojbI
`on/VL<00on/VL<4ojbJa003ojbKa_nj^]Wo^[[I00;o^[[I0oni^MT4ol7Mk@03ol;Hj_n_m_3o[oK`
00;o[oK`00?oN^GFo`000?l000000omdh^@4og?Jn0;oQmcn0_n:a?X5oho2n0CoT[oe0_nF_?82oi6e
kaKooooo00?o0000ooooooooool0=oooool0033ooooo0_l0000mooooo`?oN/;m0_mf/?H3ogZQj`?o
PiSO1On<UML3oi>EdPCoVYSA1?nNVm400onQWm;oYJcLojF/g002ojF/g0OoYZoN00?oWikCoifKdOnM
Vm400onMVm44oijGc0CoY9C50onYT[h00onJNjooXWj/oj9n[002oj9n[0CoYh2Z1OnWOjT00onTOJWo
XGZWoj5jY`02oj5jY`?oVWBW1?nDKjH4ohm/YPGoSF^W0on>KJP3oi5`ZP03oiQh[_nLOK3oW7f`00;o
W7f`1OnOPK85oj:4]0;oXhNg0on]V<84ojbI``?o[9[400?o^[cKokZjfOnj^]T01?nj^]T00oni^MWo
`Mg]ol7Mk@02ol7Mk@?oVo?U00Oo[oK`o`000?l0003o0000ocg1dol0003oFM7X00;oP/?l1?n5a?`5
oh[4nPCoSl;h0_nB_oD2oi2ckPGoTKG_5Oooool00ol0003oooooooooo`0gooooo`00;Oooool3o`00
03cooooo00?o0000ohoDo_n?e?h01?mj`_d2ogJ`mP?oNZ7[0on3V=l4ohbEe`?oTiGB1OnJV=42oijK
d@;oXZGG1?nU[=`4ojJ_gP03oj>Pd_nOW]?oWikC00;oWikC1?nMVm44oijGc0CoY9C500CoZI:noiYk
[onJNjooVW^_1?nROZ`4ojN0ZPCoYgnY00?oY7fXoj5jYonQNZL00onQNZL3oiYdY`CoU6nV1On?K:H4
ohe[Y`?oSVfX00CoTG2ZoiQh[_nHN:koV7R^1OnLOK04oin1/PGoXXBd00?oXhNgojfH`_n]V<800_n]
V<85ojbI``04ojbJa?nj_=_o^[cKokZlf`Co^[[I0onoho401?o1gNgoVo?Uoi_ciOnKlnD3o`000003
oh2mn_mo`?coOl3l00;oOl3l00Co0000oh;3o?n2`ocoP/?l1?n5a?`2oh[4nP;oSjk[1On?/Nd4oi2c
kPGoTKG_5Oooool00ol0003oooooooooo`0fooooo`00;?ooool2o`0003[ooooo00Co2@00o`000?l0
003oYMkk0_n?e?h00on@S/goOH;>ogf2cP02ogf2cP?oLg_<0_mjXN/3oh>Hg`CoS9GG1?nCUM82oiZH
d@;oWI_B1OnRYML4ojF/g003ojJ_g_nSX=;oXj3B00;oXj3B0onOW]<4oifKd@GoWYO<0_nTU<D00onD
N;7oVW^_oiYk[`03oiYk[`?oXWj/1OnWP:X2ojMoZ@;oY7fX1OnQNZL3oiYdY`GoU6nV1?n?K:H4ohe[
Y`;oSVfX00?oU7>/oiQh[_nHN:h00onHN:h4oiam/0GoWh6b0onRQ;@00on]V<7o[IS2ojfH`P03ojfH
`PCo[9W300?o_<3MokZlfonj_=/00onj_=/00onj^]Wo_n?aokoSl@02okoSl@;oO>G=0ol00005oh2m
nPCoOl3l00?o0000oh;3o?n?Y><01On>ZNP4ohn^j`GoSk7]1?n@/nh2oi6ek`?oTk3[5Oooool00ol0
003oooooooooo`0eooooo`00;?ooool3o`0003Kooooo00Co0`00o`T00?l9003o00000_nUg_/00onO
U/[oT8k=oi2>c@02oi2>c@CoOH;>0_mcNl`3og5hb`?oPiSO1?n<UML2oi>EdP03oi:Ac_nMVm;oWI_B
00?oWI_B1OnRYML2ojF/g003ojJOc_nSX=;oXj3B00?oXj3B1?nOW]<4oifKd@;oWYO<0_n?M[83oiAh
/@GoVW^_0onROZ`5ojN0ZP03ojMoZOnTOJSoY7fX00;oY7fX1?nQNZL4oiYdY`CoU6nV1?n?K:H2ohe[
Y`;oTG2Y1?nDLj`4oiQh[PCoW7f`1OnOPK800onRQ;Co[IS1ojfH`@02ojfH`@Go[IS200?o[9W3okc0
gOnl`=d00_nl`=d3okZlf`?o^n[d00?o_n?aogcUcOl000000_l00004oh>im`;oP;gj0_nBVML4oi2O
gP04ohnThol0003oSjCSohnTh`GoSZWX1?n?[^/2ohnak@;oU:CP1OnDZ^D5oi>`jaCooooo00?o0000
ooooooooool0=Oooool002cooooo00Co0000ooooool0003o0000=?ooool01Ol3003o2@00okOOm?ng
goCoZi_700CoWiK:0on@S/d4ogf2cP?oLg_<0_maN</3ogYmb`CoQhO<1?nBTLh4oifKdPCoXZGG00?o
YY[:ojJOc_nVWlh00_nVWlh5oj>PdP;oWikC00?oU7Vboi1f/_n@M[800_n@M[84ohmf/PCoU7Ra1?nJ
Njl4oj9n[0?oYh2Z00?oY7j[ojAmZ?nTOJP00onTOJP4oj5jY`CoVWBW1?nDKjH2ohm/YP;oTFnX1?nA
L:T4oiAc[0CoV7R^1OnLOK03oin1/P03ojbF_on]V<7o[IS100?o[IS11?n]V<800onna^3o_<3Mokc0
g@04okc0g@04okZlfonkj_Co^n[dok_Zm0?o000000?oQk?boiJ>bOnFS/T01?nDTm05oi:Ie`CoT9oN
00Co0000ohnThon?Y>?oSjCS0_n>ZNP2oiFGd`CoUIkJ1OnDY>05oiBZi@;oTk3[0_nK/^PCooooo`03
o`000?oooooo000000Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^
k^ko<S8bo`000?l@413oc<c<01Wooooo000/ooooo`;o00000_ooool00ol0003oooooooooo`0_oooo
o`;o0`0000?o`=_]okOOm?n[VlL00on[VlL3oinFbP?oT8k=1?mmP/h3og=kc0?oLGS;0omjOL/4ohN7
c0?oTY7>1OnMVm800onRYMOoYY[:ojJJbP02ojJJbP?oYYo>1?nSX=801?nHNk;oU7VboiAi/_nDNK84
oi1f/PCoSgJb1?nDN;44oiYk[`CoXWj/00CoYh2ZojAnZonTOZ_oY7j[1OnTOJP5oj5jY`?oVWBW0_nD
KjH2oiAaZ0CoTFnX1OnAL:T3oiAc[0CoV7R^1OnLOK000onOPK;o[9JoojbF_`02ojbF_`Co[IS10on]
V<83okk6h0Co_<3M0_nelOD3o`000003ohf[j_nGR<;oUXk900CoUXk91?nDTm05oi:Ie`?oT9oN00Co
SjCSo`000?nFTLcoUY7<1OnEUm<4oiFNfPGoU:CP0_nDZ^D2oibZh@GoVk;X5Oooool00ol0003ooooo
ooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@0Iooooo`00:oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02co
oooo00Go0000o`<00?o0fngo`=_]ok6Na005oj^Ka`CoWiK:0on@S/d4ogf2cP;oLg_<0omaN</4ogYm
b`?oQhO<1?nBTLh2oifKdP;oXY?51OnVV/X4ojJOcP04oj>Pd_nHNk;oV7^boiQk/PCoU7Vb1?n@M[83
ohmf/PCoU7Ra1?nJNjl4oj9n[0GoY7j[1?nTOJP5oj5jY`;oVWBW00?oVWFYoiAaZ?nDLJP00_nDLJP5
oi5_Z0CoTG2Y1?nDLj`4oiQh[P?oW7f`00?oZI:nojbF_on/U[l00on/U[l5ojfH`@03ojfH`_nna^3o
_/KP00?o_/KP00?o_<3MokGamOnelOD00_l00002oiR4_0CoUhS21?nFS/T5oiBCd0;oTYWG0_nHQ[l3
oiN;a@;oUY7<00?o0000oiJAc?nFTL`01?nEUm<5oiFNfP;oU:CP0_nLXmX5oibZh@CoVk;X5Oooool0
0ol0003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000001Wooooo000[ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:Ooo
ool01Ol0003o`mKXol?Fj?o3e^So`=_]00?o/Ik41On[VlL2oinFbP04oiMl/on<MKCoS7Fdohae]0Co
OVff0omhJ[H3og5hb`?oNWg;1?n7Ql`2oi:AcP03oiV9`OnRTlGoXY?500?oXY?51OnVV/X2ojJOcP03
oian/OnHNk;oV7^b00?oV7^b0onDNK84oi1f/PCoSgJb0onDN;45oiYk[`;oXWj/00?oWgf]ojAnZonT
OZ/00onTOZ/4ojAmZ0GoXGZW00?oVWBWoiYeZOnJMJT01OnDLJP4oi5_Z0CoTG2Y1?nDLj`4oiQh[P03
oiam/?nYT[koZI:n00;oZI:n1?n/U[l4ojfH`@;o`LgT1?nna^001?nXm^ko0000o`000?l00004oiR4
_0CoUhS21OnFS/T2oiBCd0;oVH:i1?nHQ[l4oiN;a@04oiJAc?l0003oUY7<oiJAc0GoUIOC0_nEW]X2
oifMd`GoW:?J1?nLZ^42oi^bj0?oYKKU5Oooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q01Wooooo000[ooooo`?o00001Ooo
ool00ol0003oooooooooo`0Wooooo`Co`mKX00?o]9o4ok6Na?naW/@00_naW/@4oj^Ka`04oj22/_nG
O;?oUgbcoiMl/`?oS7Fd1?mnKKH3ogQZ]P?oMf^h0on1LkX01?mjOL_oQhO<ohN7c?n>O[d4oiV9`@Co
XY?51?nVV/X01?nOOk3oW7jaoian/OnLO[45oiQk/P?oU7Vb1?n@M[84ohmf/PCoU7Ra1?nJNjl01?nR
OZcoWgf]oimm[OnOOJd4ojAnZ`GoY7fX0onQNZL00onPNj[oVWFYoiYeZ@02oiYeZ@CoU76X1?nAKjP4
oi5`Z@CoU7>/0onHN:h00onUSKcoZI:nojVB_P03ojVB_PGo[9Jo00?o[IS1ol7=i?o1cN@00oo1cN@0
1Onna^3o0000o`000?l0003oZ?K^00?oVH2g1?nHQ;`3oiN8`PCoUXk900?oVGjdoiV2^OnIP[T00onI
P[T3oiR6_`CoUh_50_nFTL`00ol0003oUY7<oiJAc002oiFGd`;oWYO<1OnMWM<4oibSfP;oW:[Q0_nU
[ml6ojFfiAGooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000oeEEEOl0003o410@olc<c00Iooooo`00:oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo02Cooooo0oo3dND00oo3e^So]9o4okBOa002okBOa0Co/Ik400CoZi_7oj22/_nPP[;o
X8:b1?nGO;<3ohae]0CoOVff0omhJ[H2ogM[^0CoPG>j1?n>O[d4oiV9`@CoXY?500CoYY[:oimo/?nO
Ok3oWgn`1?nLO[44oiQk/P?oU7Vb1On@M[83ohmf/PCoU7Ra0_nJNjl2oiMi/0CoWgf]1?nTOZ/5ojAm
Z0;oXGZW0_nPNjX4oiYeZ@CoU76X1?nAKjP4oi5`Z@GoU7>/00CoV7R^ojF=_?nUSKcoYHfl1?nYT[h4
ojbF_`;o`mCW0oo1cN@3o`000003oi?ag?nXm^koVWfb00CoVH2g1?nHQ;`4oiN8`P04oiJ>bOnIO[Co
VGjdoiUn]0GoVH:i1?nHQ[l4oiN;a@;oUY7<00?o0000oijAa_nNUl`01?nNUl`4oifMd`?oW:?J00?o
YJSHojF_gonU[ml00onU[ml4ojFfi@03ojjmiOoooooooooo01?ooooo00?o0000ooooooooool00ooo
ool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool06oooool002_ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`03oe;7Xoo3dNGo`m7U00;o`m7U1Ond
Wl@3ok6Na003ojJ6/_nPP[;oX8:b00;oX8:b1?nGO;<3ohae]0CoOVff0omhJ[H3ogM[^0CoPG>j0on>
O[d4oiV9`@?oXY?51_nOOk03oian/@CoV7^b1?nDNK84oi1f/P?oSgJb0_nDN;42oi5g/PCoUgV`1?nO
OJd4ojAnZ`GoY7fX00?oXGZWoj1kZ_nPNjX00_nPNjX3oiYeZ@CoU76X1?nAKjP5oi5`Z@?oU7>/00?o
XHRiojF=_?nUSK`00_nUSK`5ojVB_P;o[9Jo0oo3e>L3o`0000;oTo7L1?nJOK84oiV0]`CoV8Bl0_nG
R<82oiYk/0GoVGjd1?nIP[T4oiR6_`?oUh_500KoWhg1oijAa_nNTLKoWY76o`000?nNTLH4oijGc0Go
WIgC00CoW:?JojFXf?nUZ=SoYJSH1OnU[ml00onU]^Go[[gUojjmi@02ojjmiA?ooooo0ol00004oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00Kooooo`004?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo00?oD/NSol;>i?o2c^@00oo3dND2
okFQa0Go]9o400?o/Ik4ojJ6/_nVQ[801OnPP[83oiMl/`?oS7Fd1?mnKKH3ogQZ]P?oMf^h1?n1LkX3
ohin_@GoVHW100?oXY?5oimo/?nOOk001OnOOk03oian/@GoV7^b0onDNK82oi1f/P;oSgJb0on=M;84
oi5g/PGoUgV`0onOOJd5ojAnZ`?oY7fX00?oXh2]oj1kZ_nPNjX00onPNjX3oiYeZ@CoU76X1OnAKjP4
oi5`Z@03oiAc[?nQR;WoXHRi00;oXHRi0onUSK`5ojVB_P03ojbF_oo3e>Oo000000;o00000_mdgk/3
oiYj[PCoVWfb1OnIP;L2oiR4_003oi]i[?nJNk3oVW^`00;oVW^`1OnIO[@5oiV2^@?oV8Jo00?oUh_5
oin=`OnOSL400_nOSL42oijAaP03o`000?nNTLKoWYO<00CoWYO<0_nMWM<2ojJSdPGoYJSH0_nU[ml3
ojjhh@Go[[gU5Oooool02Ol0003oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04
olc<c?m4A4Co0000oa0@41Wooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Oooooo00?o0000ooooooooool01?ooool3o`0000[ooooo00?o0000ooooooooool06oooool00omb
glGo`/kTol;>i003ol;>i004ol?AiOneXLCo]J74okFQa0Co]9o400?oZ8RcojJ6/_nVQ[800_nVQ[84
oj22/PCoUgbc0on<MK@4ogi]]P?oN6Zf0_mgJkP4oh5c^PCoSWjm0onIRL400onKNjooWgn`oimo/006
oimo/0CoW7ja1?nHNk82oiAi/P03oi=h/_n?M[;oSgJb00;oSgJb0on=M;85oi5g/PCoUgV`0onOOJd5
ojAnZ`04ojAmZ?nSP:goXh2]oj>0[@GoX7^Z0onJMJT5oiAaZ0CoTFnX0_nAL:T2oi^2]`GoXHRi1?nU
SK`3ojVB_P?o00000_o3e>L00omdgk_oVWNZoiYgZP03oiYj[PGoVWfb1?nIP;L01?nHQ;coVgV/oi]i
[?nKNJ`4oiYk/0CoVGjd1OnIP[T2oiR6_`03oj29^onOSL7oWhg100?oWhg10onNTLH01?l0003oWY76
oijGc?nNUl`2ojNNc@GoYZ?B0onUZ=P00on_]=go[[SQojjhh@04ojjhh@;o[[gU0_nda>LEooooo`03
o`000?oooooooooo02oooooo0008ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00_o
oooo1Ol00005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06?ooool00ombglGo
`<gTol3=i004ol;>i003okBRa_neXLCo]J7400;o]J740ondWl@2ojR8/`CoYXJb1?nPP[84oiMl/`?o
S7Fd1?mnKKH3ogQZ]P?oMf^h1?n1LkX3ohin_@04oiV9`OnKNjooVg^_oi]k[`SoWgn`1?nLO[42oiQk
/P;oV7^a0onCN;85ohmf/P?oSGBb1?nAMk84oiMi/0CoWgf]0onTOZ/00onTQ;;oXh2]oj>0[@03oj>0
[@CoX7^Z1?nJMJT4oiAaZ0?oTFnX00?oVWneoi^2]onKP[L00onKP[L4oj68^@CoYHfl00?oZI:no`00
0?l000000oo3fNT00oo3e>OoVWNZoiYgZP02oiYgZP?oVWZ^1OnJOK82oiV0]`;oW7RY1?nKNJ`4oiYk
/0GoVGjd0onIP[T00onRQkOoX8Vkoj29^`02oj29^`CoWhg11?nNTLH00ol0003oYik=ojNNc@03ojNN
c@CoYZ?B00?oYJSHojndgOn_]=d00_n_]=d4ojjhh@03okG5i_nda>Oo]<CW00?o]<CW5Oooool00ol0
003oooooooooo`0^ooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgM
gOoooooo00001_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Gooooo00?oRngK
ol3=i?o0cN@00oo0cN@00oo2c^Co]:;6okBRaP02okBRaPCo]J7400?o]9o4ojR8/onXR;<00_nXR;<3
ojJ6/PCoX8:b0_nGO;<2oiAaZ@?oS6bY1?n2IJT3ogiTZP?oP6J[1?n1LkX2ohin_@03oi=e[_nKNjoo
Vg^_00;oVg^_2OnOOk03oian/@CoV7^a1?nCN;84ohmf/P?oSGBb1?nAMk84oiMi/0CoWgf]00CoY7j[
ojB4/_nTQ;;oY8Bb1OnSP:d4oj1kZPCoVWFY1?nDLJP01?nAKjSoVWneoiYo]OnJOkD5oi^2]`GoXHRi
00CoYHflo`000?l0003o00001?o3fNT2oiUdY`CoVWNZ1?nJNZh3oiYm/P03oiafYonLN:WoW7RY00;o
W7RY1?nKNJ`4oiYk/0GoVGjd00?oVH:ioj:7]onRQkL00_nRQkL3oj29^`GoWhg100GoWY76ojRJb?nX
V/So0000ojRJb004ojNNc@?oYZ?B00?o/;;IojndgOn_]=d01?n_]=d00on^^>7o]LGVokG5iP02okG5
iP?o]<CW0_ndbNTEooooo`03o`000?oooooooooo02gooooo000@ooooo`05o`000?oooooooooooooo
ool000002oooool01?oMgMgoEEEEooooool00006ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool04oooool3oko<i@?o`<gT00?o/jC9okBRa_ndX/H00ondX/H3okFQa003ojV;]OnXR;?o
Z8Rc00?oZ8Rc1?nVQ[82oj22/P03oi]fZOnDLJWoU76Y00;oU76Y0on<K:T4oh9UZ@?oOVBZ0on0IZ/4
ohQ][@?oTgF^1?nKNjl9oimo/0?oW7ja1OnHNk43oi=h/PCoSgJb0on=M;84oi5g/PGoUgV`0_nOOJd0
0onOQ[SoY8BbojB4/P03ojB4/PCoXh2]1OnPNjX3oiYeZ@;oU76X0_nJOk@5oiYo]@CoVh:g0onQR;T3
o`0000Co`]W[00?o`mWYoiUdYonIM:L00_nIM:L4oiYgZPCoVWZ^00CoVWfboiafYonLMZOoW7JW1OnL
N:T4oi]i[0CoVW^`0onIO[@00onRQKCoXXNgoj:7]`03oj:7]`?oX8Vk1?nOSL400onZV<CoZ9[8ojRJ
b002ojRJb003o`000?nWW/goYik=00?oYik=00CoYZ?Bok2bfOn`/]Wo/;;I1?n_]=d00onganKo]LGV
okG5iP03okG5iP03okC4iondbNWo]<WY00?o]<WY5?ooool00ol0003oooooooooo`0]ooooo`004?oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool2o`0000oooooo
0_l0000Aooooo`03oi_cj?noc>Go_lcU00?o_lcU00Co`<gTok>TbOncY<Wo/jC91OndX/H01?neXLCo
ZH^eojV;]OnYRkD4ojR8/`CoYXJb00?oX8:boi]fZOnKMZT01OnDLJT3oha/Z@?oPVFY1?mnI:X2oh1V
Z`CoR6f]1?nCMJh4oi]k[`OoWgn`00?oX86aoian/OnLO[400_nLO[44oiQk/@?oTgRb1?n?M[84ohed
/PCoTGNb1?nGNK000onOOJgoWhJhoin6^005ojB4/PCoXh2]1OnPNjX2oiYeZ@03oif2]OnJOkCoVWnd
00;oVWnd1OnJOkD4oi^2]`?o000000?oXHRiokgEk?nmeN`00oo2fN/2oiQbY@CoVGBW1?nJMjX4oiYj
[PGoW7JW1?nLN:T4oi]i[0CoVW^`00?oVGjdoj:5]?nRQK@00_nRQK@4oj:7]`CoX8Vk00?oWhg1ojZH
a?nZV<@00_nZV<@4ojRJb005o`000?nWW/goYik=ojNNcOnb/=L01On`/]T00on_]=go]lOVokO7iP02
okO7iP?o]LGV0_nfc^`4okC9j@03ok7;kOoooooooooo01?ooooo00?o0000ooooooooool0;?ooool0
013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`04oi_cj?nncNGo_/gUokk=i@?o_lcU00?o
/jO<ok>TbOncY<T00_ncY<T4okBRaP03ojR<^?nYRkGoZH^e00;oZH^e1OnXR;<2ojJ6/P03oimjZOnK
MZWoVgJY00;oVgJY1?nDLJT3oha/Z@?oPVFY1?mnI:X3oh1VZ`?oR6f]1?nCMJh4oi]k[`GoWgn`0onP
PK44oian/@CoV7^a1?nCN;84ohmf/P?oSGBb1?nAMk82oiMi/0;oUXFo1?nOQ[P4ojB4/PGoXh2]1?nP
NjX00onJMJWoWH:eoif2]@05oiYo]0CoVWne00KoVh:go`000?l0003o0000oi^2]onQR;T5okgEk004
ol;IjonHLZGoV7:UoiQbY@CoVGBW1OnJMjX2oiYj[P03oiefY_nLMZOoW7JW00?oW7JW1?nLN:T4oi]i
[0?oVW^`00?oY8>aoj:5]?nRQK@00onRQK@5oj:7]`;oX8Vk00?oZiO2ojZHa?nZV<@00onZV<@5ojRJ
b003o`000?nb/=Oo/[3G00;o/[3G0on`/]T2okS;j0Go]lOV00?o]LGVokK>k?nfc^`00_nfc^`00ond
bNWo/L_]ok7;k@02ok7;kA?ooooo0_l0000^ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00gooooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00Wooooo0_nUm>l5okk=i@04oko<iOncYlco/jO<ok>Wc0Co/jC900Co]:;6ojR<^?nXS;SoZ8bh1?nY
RkD5ojR8/`03ojJ6/_nONZWoWgZY00CoVgJY1?nDLJT3oha/Z@CoPVFY0omnI:X3oh1VZ`?oR6f]1?nC
MJh4oi]k[`?oWgn`00?oXX6`oj21/OnPPK400onPPK43oian/@GoV7^a0onCN;84ohmf/P;oSGBb00?o
SXG5oi25a?n@QL@00_n@QL@5oiJ5_`?oWhJh1?nTQ;85oj>0[@;oX7^Z0_nQR;T4oif2]@CoVWnd0_nJ
OkD3o`0000?oVh:g0_nfcN/4okgEk0;oV72S0onHLZD4oiUdY`GoVWNZ00CoVWZ^oiefY_nMMZKoWGJV
1?nLMZL4oiahZ@GoVgV/00?oVW^`ojB3/OnTPk401OnRQK@5oj:7]`04oj29^on[Ul;oZiO2oj^G`PCo
ZYS41?nXV/P00ond/MGo0000ok:`e`03ok:`e`03ok2bfOnhbnSo^<_X00?o^<_X0_nganH2okKDl0Co
]/k/0_nado84ok7;kAGooooo00?o0000ooooooooool0:oooool002Wooooo0_l0000Dooooo`03o`00
0?oooooooooo00Oooooo00?oYOC_okk=iOnncND01?nncND00oncZLoo/jO<ok>Wc002ok>Wc0?o/jC9
00?oZ8jkojR<^?nXS;P00onXS;P4ojV;]@?oZ8Rc00?oX7^[oimjZOnONZT00_nONZT3oi]fZ@CoU76Y
0on<K:T4oh9UZ@?oOVBZ0on0IZ/4ohQ][@CoTgF^0onKNjl01?nOOk3oXX6`oj:1/?nRPK05oj21/@?o
W7ja1OnHNk42oi=h/P03oiV:`_nBQlCoTXO400;oTXO41?n>QLD4oi25a0CoUXFo0onOQ[P5ojB4/P?o
Xh2]00?oXhjnoj68^OnQR;T00_nQR;T4oif2]@?oVWnd0ol00003oiYo]@03oi^2]onfcN_o]/g[00?o
]/g[00?o_MG/oiQ`XonHL:<00_nHL:<3oiQbY@GoVGBW0onJMjX00onMMJGoWGJVoiefYP02oiefYPCo
W7JW1OnLN:T3oi]i[003ojF3/?nTPk7oY8>a00;oY8>a1OnRQK@3oj:7]`03ojfG`?n[Ul;oZiO200;o
ZiO21OnZV<@00onXV/So];7EokBae@02okBae@03o`000?nb/=Oo/[3G00;o^m7Z1?nhbnP00onegOCo
]]C`okKDl003okKDl003okK>k?nado;o/M?b00?o/M?b0_nabnd2ojW7kaGooooo00?o0000oooooooo
ool0:_ooool002Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`03ojgd
l_nncNGo_/gU00Co_/gU1?ncZLl4ok>Wc004ok>TbOnXS[_oZ8jkojR>^`CoZ8bh1?nYRkD01?nXR;?o
X7^[oj1kZonPNj/4oimjZ@?oVgJY1?nDLJT3oha/Z@CoPVFY0omnI:X3oh1VZ`CoR6f]1?nCMJh2oi]k
[`03oiin[onRPK3oXX6`00?oXX6`1?nPPK44oian/@?oV7^a00?oWXg1oiV:`_nIR/800_nIR/84oi:7
a0?oSXG51?n@QL@4oiJ5_`?oWhJh1OnTQ;801?nSP:goXhjnoj>>__nSS[h5oj68^@?oWH:e00?oVWnd
o`000?l000000_nJOk@3oiYo]@;o[lCY1?nfcN/2oiM^X@CoV72S1?nHLZD4oiUdY`04oiYgZ_nMMJGo
WGFUoieeY@CoWGJV1?nLMZL5oiahZ@04oi]i[?nUPk3oYH>`ojF3/0CoY8>a1OnRQK@00onRQkOo[IO0
ojfG`002ojfG`0?oZiO21?nZV<@00ong/mGo];7EokBae@04okBae@03o`000?nkdN[o^m7Z00;o^m7Z
00?o^<_XokGMm?negO@00_negO@2okKDl0Co[Mgh0_nado82ojO>m0GoZLO_5?ooool00ol0003ooooo
ooooo`0Zooooo`00:Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?o/o;d0_no
cND3okk=i@03okB]dOncZLoo/jW?00?o/jW?0oncYl`00onXTKkoZ8jkojR>^`02ojR>^`CoZ8bh1?nY
RkD4oj1kZ`CoWgZY0onKMZT5oiAaZ@?oS6bY0on2IJT4ogiTZP?oP6J[0on8KJd3oi=e[P04oiMh[_nN
OZooWWj_oiin[`GoXX6`1OnPPK43oian/@03oiQk/OnNSL7oWXg100;oWXg10onIR/84oi:7a0?oSXG5
1?n@QL@5oiJ5_`?oWhJh0onTQ;800onRU/SoXhjnoj>>_P03oj>>_PCoXHRi00CoWH:eo`000?l0003o
00001?nJOk@00onJOkGo[lCYojo4j@03ojo4j@03okK=jonGKZ7oUfjQ00;oUfjQ1?nHL:<4oiQbY@?o
VGBW00?oWGBToieeYOnMMJD00onMMJD3oiefYPGoW7JW0onLN:T00onVPjooYH>`ojF3/003ojF3/0?o
Y8>a1?nRQK@00on`VL3o[IO0ojfG`003ojfG`0CoZiO200?oZYS4okNceOng/mD00_ng/mD4okBae@03
okgKkonkdN[o000000;o^m7Z0_naioP3okGMm0;oYNGk1?n]gOP00onSe?WoYlkdojO>m003ojO>m0;o
ZLO_0onR`NlDooooo`03o`000?oooooooooo02Wooooo000Yooooo`03o`000?oooooooooo01Kooooo
1?ncl_@4oko=i@04okk=iOnd[M7o]:gAokB]d@Go/jW?00Co/jO<ojRA__nXTKkoZ96n0onXS[/5ojR<
^0;oZH^e00?oX7f]oj1kZonPNj/00_nPNj/4oimjZ@CoVgJY1?nDLJT3oha/Z@?oPVFY1?mnI:X3oh1V
Z`?oR6f]00CoTgF^oiMh[_nGN:koUgR^1?nNOZl4oj:1/0GoX86a0_nLO[400onST<7oWXg1oij=`@03
oij=`@?oVH[21?nBQl@4ohj5a@CoT8G41?nFQKl3oin6^003ojB4/_nRU/SoXYK800;oXYK81?nSS[h2
oj68^@?o00000onMP[D2oiYo]0?oZ[kX1?n_a>T3oiI/X0?oUfjQ1?nHL:<4oiQbY@04oiUdYonMM:Co
WGBToiedY0GoWGFU0onMMZH5oiafY`;oW7RY0_nVPjl5ojF3/0CoY8>a0_nRQK@3ok2I`0Co[IO00on[
Ul800onj^=Oo]k?EokNce@04okNce@03okBaeOnmfnoo_M__00;o_M__00?o0000ok7Wn?naioP00ona
ioP00onegOCoYNGkojGUn`02ojGUn`03ojgMn?nSe?WoXmCi00;oXmCi0_nWc_@3oj34lPGoX/7_5?oo
ool00ol0003oooooooooo`0Xooooo`00:Oooool3o`0001Cooooo1?nhkoD00oncl_Co_lgUoko=i@02
oko=i@03okJ`d_nd[M7o]:gA00;o]:gA1?ncZLl00onXU<7oZ96nojRA_P02ojRA_PCoZ8jk1?nXS;P0
1?nYRkGoX7f]oj1m[OnPOJd4oj1kZ`?oWgZY1?nKMZT3oiAaZ@04oi=_Y_n=JZKoSFZVoheZYP?oQ6FW
1?n2IJP3oh=WZP?oS6n/1OnGN:h3oiin[`GoXX6`0onPPK400onXTl3oXi31oj>@`@02oj>@`@CoWXg1
1?nIR/84oi:7a0?oSXG51?n@QL@2oiJ5_`;oQYcQ0onHVmD5oj:Fb0?oXhjn0ol00003oj68^@;oWH:e
00?oYko[ojZnj?nZ_^P01?nZ_^P00on_a>WoUfbOoiI/X003oiI/X0?oUfjQ1OnHL:<3oiQbY@GoWGBT
1?nMMJD4oiefYPCoW7JW00?oW7RYojJ3[onVPjl00_nVPjl4ojF3/0CoY8>a00?oXXFdok2I`?n`VL00
0_n`VL05ojfG`004oj^G`_nj^=Oo^[SGokZhe`Co]k?E0_nljO@3okgKk`;oXnog00?o0000ok7Wn?na
ioP00onAjOP2ojGUn`CoV]Wm0_nSe?T2oig5m0GoX<Cb0_nR`Nl2oinlkA?ooooo0_l0000Zooooo`00
:Oooool00ol0003oooooooooo`0Cooooo`Co^>oe0oo0cN@00onocNGo][3BokJ`dP02okJ`dPCo]:gA
00?o/jW?ojRD`OnXU<400_nXU<43ojRA_PCoZ8jk0_nXS;P2oiin[`CoX7f]1?nPNj/4oimjZ@?oVgJY
00CoU76Yoi=_Y_nCKjKoTfnV0on=JZH3ohAUY`CoPVFX0on3IjX3oha_[0GoUgR^0onNOZl5oj:1/003
oj21/OnXTl3oZ9?000;oZ9?00onST<45oij=`@?oVH[20_nBQl@2oiBSg`CoR:7T0on1WnH5ohJLh@?o
V9_E1?nRU/P3o`0000;oXhjn1?nQR;T01?nMP[GoYko[ojNojonW_n/4ojZnj0?oUfbO1?nFK:03oiM^
X@GoV72S0_nHLZD00onNM:CoWGBToiedY003oiedY0CoWGFU1?nMMZH3oiafY`03ojN4[onVPjooYX>_
00?oYX>_1OnUPk02ojB3/@03ok:L`On`VL3o/9W000?o/9W01?n]Ul000onn`=_o^[SGokZhe`03okZh
e`03okNceOnljOCo_>Wd00?o_>Wd00?o_M__oj?_monSkoL00_m/g^<00ol0003oTNWhoi7Yn004ohcK
o`;oV]Wm0_nIa?H5oig5m0;oX<Cb0_nM^^d5oinlkACooooo00?o0000ooooooooool09oooool000ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000oooo
ooooool04_ooool4ok_Zm005okS_mOo0cNCo`<gTol3=i?nh/m@01Onf/=83okB]d@03ojZHa?nXU<7o
Z9C100?oZ9C11?nXTKh2ojR>^`03oiio/_nNOZooWWj_00;oWWj_1?nPOJd4oj1kZ`CoWgZY0_nKMZT0
0onILjOoTfnVoi=_YP02oi=_YPCoSFZV0on4IJL3oh9UZ0CoPfNZ0on<Kj`4oiMh[PCoWWj_0onRPK00
0on[U;koZ9?0ojRC`003ojRC`0?oXi311OnNSL42oiV:`P03oj2TfOnDXmooU:?O00?oU:?O1?n8XN@3
oh6OiPCoQYcQ0onHVmD01OnRU/So0000o`000?l0003oXYK800CoXhjn0_nQR;T3oj?8l`CoYko[00?o
Z[kXoiQ]WonGK9l00onGK9l4oiI/X0CoUfjQ1?nHL:<01?nHLZGoWWBToiidY?nNM:@4oiedY0CoWGFU
1?nMMZH01?nLMZOoYhB_ojN4[onWQ:l5ojJ3[`GoYH>`00CoY8>aok:L`OnbW<7o/Yc11On`VL000on]
Ul3o_/3Kokk0f`02okk0f`?o^[SG0on^mO42okcYm003ogoWh_lg_;Wo=kbi00?oIm3j00CoN]Smo`00
0?mjf?goN]Sm0_n<fol2oiC1mPGoVLCf0_nMaO@2oibhk0GoWK[]1?nO_>dEooooo`03o`000?oooooo
oooo02Kooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo013ooooo1Onkj_@3ol7<h`04ol3=i?nh
/mCo^;?DokRce0Go][3B00Co]:gAojZHa?nZV<CoZYS41?nXU<44ojRA_P03ojR>^onNOk;oWWnb00Co
WWj_1?nPOJd4oj1kZ`?oWgZY00CoW7JXoiUcYonILjOoVG>W1?nCKjH4oheZYP?oQ6FW0on2IJP4oh=W
ZP?oS6n/1?nGN:h4oiin[`03oj:1/?n[U;koZiBn00;oZiBn1?nXTl04oj>@`@;oWXg10_nTY]L4oj2T
f@GoU:?O1?n8XN@3oh6OiPCoQYcQ0ol00004oj:Fb0;oXhjn0onAd_h5oj?8l`;oYko[0onHKIl4oiM/
W`CoUVbP1?nGKZ43oiQ`X`03oiieY?nNM:CoWWBT00;oWWBT1?nMM:@5oieeY@?oWGJV1OnWQ:l4ojJ3
[`CoYH>`00?o]Z;5ok:L`OnbW<400_nbW<44ok2I`003ol;>honn`=_o_/3K00?o_/3K00?o^[SGojke
lOn^mO400_n^mO400oln_Z[oH<7moek9nP02oek9nP;oIm3j0on@/>`01?nA^_?o0000oi6jlonA^_<4
oiC1mP;oVLCf0onK]>T4oibhk0CoWK[]0_nO_>d3oinijaCooooo00?o0000ooooooooool09_ooool0
00Kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP06
ooooo`;o00003oooool4okkTlP03ok_Zm?o1c>?o`LcS00?o`LcS1Onh/m@3okJ`dP03ojfLa_nZV<Co
ZYS400;oZYS41OnXU<42ojRA_P03oij2]OnNOk;oWWnb00;oWWnb0onNOZl4oj1m[@CoX7^[00CoWgZY
oiafZ?nLMZSoW7JX1?nILjL3oi=_YPCoSFZV0on4IJL4oh9UZ0?oPfNZ0on<Kj`5oiMh[P;oWWj_00?o
Z8nloj^D__n[U;h00on[U;h5ojRC`0;oXi3100?oZJcIojBVeonTY]L00onTY]L4oj2Tf@;oU:?O0omm
f_d2ofcNf`;oY?KX0_nMR;`2ojN=^P;o000000?oY8FcobX00?l=W/@00ol=W/@3oeo=m`CoTM;n0_nS
b?<4oiQ]X0?oV6fO1?nGK9l5oiI/X0?oUfjQ00CoV72SoiieY?nNMJCoWWFT1?nNM:@4oiedY0GoWGFU
0_nMMZH2ojR6[`CoYhB_1OnVPjl2ojF3/0;o]Z;51?nbW<43ok2I`0?o`/kS0onn`=/3ogcUc003ojke
lOmP`OgoH<7m00;oTiKC1?nAXn45oi2`k004oi6jlol0003oTK[coi6jl`;oU<7f0_nJ[^D5oi^dj@Co
W;S/0_nM^^d2oindi`GoWkW[5?ooool00ol0003oooooooooo`0Uooooo`003_ooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`0=ooooo`Co
_^Cb0oo1bn83ol7<h`;o^[GE1Onh/m@01?nf/=;o[Ic6ojfLa_n]W<H3ojZHa0CoZ9C100CoWXFhoij2
]OnNP[GoWX:e1?nNOk84oiin[`CoX7f]0_nPNj/00onLMjWoW7JXoiafZ002oiafZ0CoVG>W1?nCKjH3
oheZYP?oQ6FW1?n2IJP3oh=WZP?oS6n/1OnGN:h01?nNOZooZ8nlojR?_?nXSk`4oj^D_PCoZ9?000?o
/k?HojV/fOnY[=T00_nY[=T5ojBVe`;oX:CI1?nQg_`00ommf_goK=kKofcNf`02ojCfj0;oWHRl0ol0
0002ojN=^PCoY8Fc0_nPO:`00on=JjKoTF^Soi5[X`02oi5[X`?oUFbQ1OnHKJ03oiQ]W`CoUfbO1OnF
K:02oiM^X@03oiidY?nNMJCoWWFT00?oWWFT1?nNM:@4oiedY0CoWGFU00CoWGJVojR6[onXQZooZ8J_
1?nWQ:l5ojJ3[`03ojF3/?nfX/Go]Z;500;o]Z;51?nbW<400on`VL3o`/kSol;>h`03ol;>h`03okk0
fomliLcoO>G<00?oUXc61OnCU]<4oi6Sh@;oT;3/0_nLWmH2oi^WgP03o`000?nKYmkoVZkU00CoVZkU
0_nK]>T2oj2ZgPCoWjoS1OnO]>L2oinij`;oY;[Y5Oooool00ol0003oooooooooo`0Tooooo`003_oo
ool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01?ooool00ol0003ooooo
ooooo`0;ooooo`Co_mg_00?o_^Cbol7;h_o1bn800oo1bn801?o1c>?o^[GEokZeeOnj]MD4okRce003
ojnQbOn]W<Ko[Ic600;o[Ic61?nZV<@01?nXU<7oWXFhoij5^?nNQKP4oij2]@?oWWnb1?nNOZl4oj1m
[@03oj1kZonLMjWoW7NY00CoW7JX1?nILjL4oi=_YP?oSFZV0on4IJL4oh9UZ0?oPfNZ1?n<Kj`3oiMh
[P03oj66^?nXSkcoZ8nl00;oZ8nl1On[U;h00onXTl3o/k?Hok>cf002ok>cf0?oZJcI1?nTY]L3oioN
o0;oXMkl0onLl?<2okWclP04ogoMY?l0003o0000o`0000;oWHRl0_nWSKX00onCMZooSfn[ohm_Z`02
ohm_Z`?oSF^V1?nAJj<4oiE/X@CoV6fP0onHKIl4oiM/W`GoUVbP00?oUfjQoiidY?nNM:@01OnNMJ@4
oiidY0CoWGBT0onMMJD00onZR;7oZ8J_ojR6[`02ojR6[`GoYhB_0onVPjl00onk[<_o]Z;5okJRa@03
okJRa@?o/Yc10_o3h^h4ol;>h`04o`000?nIQ;_oVHBkoiV4^`CoUXc61?nCU]<2oi6Sh@;oWYS=1OnL
WmH01?nKYmko0000oi^Wg_nKYmh2oiZ^i@;oX:CH1OnPZ]h4oin_h`;oWkCW0onT]^D4ojBjjA?ooooo
0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0
003o8B4Qolc<c009ooooo`003_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool00oooool2o`0000_ooooo1?nogNl2ol;9h0Co`L_R00?o_;SFokZeeOnj]MD00onj]MD00onh
/mCo[j79ojnQb@02ojnQb@Co[Ic60_nZV<@00onQRK_oWXFhoij5^003oij5^0?oWX:e0onNOk84oiin
[`?oX7f]00?oVgR/oiagZOnLMjT00_nLMjT3oiafZ0CoVG>W1?nCKjH4oheZYP?oQ6FW0on2IJP4oh=W
ZP?oS6n/00?oUgR^oj66^?nQQ[P00_nQQ[P3ojR?_0CoZiBn00?o^[OFok>cf?nc/mP00onc/mP4ojV/
f@03ojBVeonOg_coWmkl00;oWmkl0on2i_800onLl??o^O?bokWclP03o`000003oi9j]_nMR;coWHRl
00;oVGV_0onCMZl4ohm_Z`?oSF^V1OnAJj<3oiE/X@CoV6fP0onHKIl5oiM/W`?oUVbP00CoW7BUoiid
Y?nNM:CoWWBT1OnNMJ@4oiidY0CoWGBT00CoWGFUojZ8/OnZR;7oZXRa1OnXQZl4ojN4[`03ojJ3[onk
[<_o^jc;00;o^jc;1?nfX/D00onbW<7o`n;^ol?RkP03ol?RkP03ol;>honLO[;oW7jb00CoVHBk1OnF
S<H2oi>Fd`03oj6Ba?nNV<goWYS=00?oWYS=1?nLWmH2oi^WgP03o`000?nRWm7oX:CH00CoX:CH1?nP
Z]h2oin_h`;oYK7Q1_nT]^D2ojBjj@;oZ;gX5?ooool00ol0003oooooooooo`05ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@09ooooo`00
3_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004oooo
o`;o00002_ooool3okoGj`03okoMkoo2bN3o`/WP00?o`/WP00?o`L_Rokbhe_nl^=H00_nl^=H3okZe
e@03ok:Ubon_XLWo[j7900?o[j790on]W<H00onSSKgoXHVkoj69^`02oj69^`CoWXFh0onNP[D4oiio
/P?oWWj_00CoX7f]oi]h[?nKN:coVgR/1?nLMjT4oiafZ0?oVG>W1?nCKjH4oheZYP?oQ6FW0on2IJP4
oh=WZP;oS6n/00?oU7Zdoj66^?nQQ[P00onQQ[P4ojR?_0;oZiBn0onj]mH5ok>cf0;oZJcI0onEi?d0
0onOg_coP^Kboh;VlP02oh;VlP05ohgWn?l0003o0000o`000?n>LJd00_nBN[H00onLN:[oVGV_oiUi
[`02oiUi[`CoTgJ_1?n?Kj/3ohe[YPCoTF^S0onEK:44oiQ]X0?oV6fO1OnGK9l2oiI/X0;oW7BU1?nN
M:@4oiieY0CoWWBT1?nMM:@5ojZ8/@CoZ8J_1?nWQ:l5ok^/b`?o]Z;50oncm_42ol?RkP03oiml[?nL
O[;oW7jb00;oW7jb1?nIQ;/4oiJ<aP03ojB>_OnQT/CoXI;400;oXI;41?nNV<d5oibOeP04oi^Wg_nR
Wm7o0000oj:Od@GoX:CH0_nPZ]h00onV[]goYK7QojFah@03ojFah@CoY;KU00?oZK[VojRmj?nX_NP0
0onX_NPDooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05
o`000?ooooooooooooooool000002Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool00ol0003oooooooooo`07ooooo`Co_mO[0oo2b=l3
ol;9h0;o_[[G1Onl^=H01?nj]MGo/ZG;ok:UbonbYL/5ojnQb@04ojfLa_nSSKgoXhfmoj>=_@?oXHVk
1?nNQKP4oij2]@?oWWnb0_nNOZl00onINJkoVgR/oi]h[003oi]h[0?oW7NY1?nLMZP4oiUcY`?oTfnV
0_n=JZH2ohm^Z0?oRFZY0on7Jj`4ohY`[`CoU7Zd1?nQQ[P4ojR?_003oj^D__nj]mKo^[OF00?o^[OF
0_nc/mP4oik`m0;oUNCm0on=J:<01?n>JjKo0000o`000?l00004ohia[@03oi9j]_nLN:[oW7RZ00Go
VGV_0onCMZl4ohm_Z`?oSF^V1?nAJj<3oiE/X@CoV6fP1?nHKIl4oiM/W`04oiI/X?nLM:GoW7BUoiad
Y@CoWWBT1?nNMJ@5oiidY0;oWGBT00?oZhbdojZ8/OnZR;400onZR;44ojR6[`?oYhB_0_o1_=H5ok^/
b`04okJRaOncm_7o/oKaok?fl@GoWgb/1?nLO[84oiV4^`03oiJ<a_nTS[goY8jm00;oY8jm0onQT/@5
oijHc@;oW9oF0_nTV//3oj:Od@03o`000?nPY=SoX:CH00;oX:CH00?oZ:_HojJ^gOnV[]d00_nV[]d5
ojFah@03ojBfiOnY^^KoZK[V00;oZK[V0onX_NP00on[`NWoooooooooo`0Booooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80
2Oooool002Oooooo00?o0000ooooooooool01Oooool4oko@i`03okoGjoo2b=oo`/SO00?o`/SO00?o
`/WPokjjeonn^]L00_nn^]L3okbheP03okFZc_nbYL_o/ZG;00;o/ZG;1?n_XLT00onVT/7oXhfmoj>=
_@02oj>=_@?oXHVk1OnNQKP3oij2]@;oWWnb00CoUgZaoiUi[_nINJkoVGV^1OnKN:`3oiagZ@CoW7JX
1?nILjL2oi=_YP03oiAaZ?n?KZSoSfjX00;oSfjX0on9JZT3ohM[[0CoRW2_1?nDN[@5oj66^0;oZ8nl
0_nk/]45okZgeP;oZ_SW0_nNl?@01On>J:?oSVRRohiXX_n>J:;oSFRS00?o00000on>JjH3ohia[@03
oiaeY_nLN:[oW7RZ00;oW7RZ1?nINJl3oi=f[`CoSfn[0on=JjH4oi5[X`?oUFbQ1?nHKJ04oiQ]W`?o
UfbO00?oWGFVoiadYOnLM:D00onLM:D3oiidY0GoWWFT1?nNM:@01?nMM:CoZhbdoj^<]?n[S;@4ojZ8
/@GoZ8J_00CoYhB_ol6le_o1_=Ko`KcF1?nk[</2ofgK_003ok?flOnJP[SoXW^X00GoWgb/1?nLO[83
oiV4^`03ojR<^?nTS[goY8jm00?oY8jm1?nQT/@2oijHc@;oYiO61OnTV//2oj:Od@03o`000?nRWm7o
X:CH00CoZ:_H1?nV[]d2ojFah@;oZ[SS1OnY^^H00onX_NSoZl7Yoj_1j@02oj_1jACooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000
olc<c009ooooo`009oooool2o`0000Gooooo1Onod>L00oo2amko`/SOol;8g`02ol;8g`03oknmf?nn
^]Oo_[[G00Co_[[G00Co_;SFokFZc_neZ/ko]J[>1?nbYL/00on_XLWoYY;1ojJB`@02ojJB`@?oXhfm
1?nQRK/4oij5^0;oWX:e00CoUgbdoiMj/OnGN[7oUgZa1?nINJh4oi]h[0?oW7NY1?nLMZP3oiUcY`04
oiQeZOnDLJSoU76XoiAaZ0CoSfjX1?n9JZT3ohM[[0CoRW2_0onDN[@5oj66^003ojR?_?nk/]7o^k;A
00;o^k;A0onj]mH2oj[hi`CoSVRS0_n>J:82o`0000?oSFRS0on>JjH01?n>LJgoW7FVoiaeY_nLMJH4
oiahZPCoVGV_0onCMZl4ohm_Z`?oSF^V1?nAJj<3oiE/X@GoV6fP0onHKIl01?nGK9ooWGFVoieeY_nM
MJH5oiadY@?oWWBT1OnNMJ@3oiidY003ojjA^?n[S;CoZhbd00;oZhbd1OnZR;43ojR6[`03olKGi_o1
_=Ko`KcF00?o`KcF00?o^jc;oiim[onNOJl00_nNOJl01?nJP[SoXW^Xoj9kZ?nRNjP4oiml[0CoW7jb
00?oVHBkojR<^?nXS;P00_nXS;P4ojB>_@?oXI;400?oZiO2ojNGa_nWUlH00onWUlH4ojBJb`;oXYoA
00?oZjWDo`000?nXZmP01?nXZmP2ojJ^g@;o[;OQ1OnZ^><2ojVjiP?o[<3X1?n[`NTEooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj
^_l@41002Oooool002Oooooo00?o0000ooooooooool00_ooool3okk9h`?o_m3W0oo2amh00oo2b=oo
_kgHoknmf002oknmf0Co_[[G00?o^:o@okFZc_neZ/h00oneZ/h2ok:Ub`03ojVHa?nVT/7oYY;100?o
YY;11?nSSKd3oj69^`;oWXFh0_nGOkL3oiMl]0CoUgZa0onINJh4oi]h[0CoW7NY0onLMZP01?nILjOo
V7FYoiQeZOnHMJT4oiAaZ0?oSfjX1?n9JZT3ohM[[0CoRW2_1?nDN[@3oj66^003okJXbonk/]7o^k;A
00Co^k;A00Co^[OFo`000?n@JZ?oT6ZS0on>J:<3o`0000;oSVRR0on=J:<2ohi[YP03oi]aX_nLMJKo
W7FV00?oW7FV0onLN:X4oiUi[`?oTgJ_1?n?Kj/3ohe[YPCoTF^S1?nEK:44oiQ]X0;oV6fO00?oWWNX
oieeY_nMMJH00onMMJH4oiadY@?oWWBT1OnNMJ@01?nNM:Co[Y6hojjA^?n^TKP4oj^<]0GoZXRa00?o
Z8J_olKGi_o6enH00_o6enH3ol6leP03oj5kZOnNOJooWWf_00;oWWf_00?oYgfWoj9kZ?nRNjP00_nR
NjP4oiml[0CoW7jb1OnXS;P5ojB>_@04oj6Ba?n[Ul;oZiO2oj^G`PCoYiO60onTV//00on_Z=7oZjWD
oj^Ye002oj^Ye005o`000?nXZmSoZ:_HojR[f?n_]ml01On/]n43ojZhh`;o[/7X1On/`>P2oj_1j@;o
[<?[4_ooool3o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
okZj^_l000002Oooool002Oooooo00Co0000oooooooooooooooo1OnnbN<00onod>Oo`/ONol;7gP02
ol;7gP03ol6ofOno_MSo_kgH00?o_kgH00?o_[[GokR_d?nh[m000_nh[m03okFZcP03ojfMb?nYV<Co
ZIS400;oZIS41?nVT/44oj>=_@;oXHVk00?oVH>ioiMo]onGOkL00_nGOkL4oiMl]0?oUgZa0onINJh4
oi]h[0CoW7NY0_nLMZP00onJN:_oV7FYoiQeZ@02oiQeZ@CoU76X0on?KZP4ohUZZ@?oQf^/1?n:L:l4
oiAj]003oj66^?nfZ<_o]ZS;00;o]ZS;1?nk/]400onooN?oUFnUoi1ZX`02oi1ZX`?o000000?oSVRS
ohiXX_n>J:800_n>J:83oheXX`03ohi[Y_nKLJ;oVg6R00GoW7FV0onLN:X5oiUi[`?oTgJ_1?n?Kj/2
ohe[YPCoTF^S1?nEK:44oiQ]X003oiQ]WonNMjSoWWNX00GoWGFV1?nLM:D4oiidY0?oWWFT00?o/IRn
ojjA^?n^TKP00_n^TKP5oj^<]0?oZXRa0_nlm_04olKGiP03ol6le_nQNjWoXG^Y00;oXG^Y0_nNOJl2
ojMmY`CoXW^X1OnOO:`2oian/P;o[8fe1?nXS;P4ojB>_@03ok2I`?n[Ul;oZiO200;oZiO21OnWUlH0
1?nTV/_o[jSAojnXdOn_Z=43oj^Ye003o`000?n[ZMCoZ:_H00?o[kOO1On/]n400onZ^>?o[/7Xojk1
j002ojk1j0;o[<3X0_n]a^`5ojc3jaCooooo00Wo0000ooooooooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Wooooo000Vooooo`?o00000_nma=l4okk9
h`;o`/GM0oo2amh3ol6of@?o_kgH00?o^[CCokR_d?nh[m001?nh[m001?neZ/ko[Ig8ojfMb?n]WLP3
ojVHa0GoYY;10_nSSKd01?nLQkcoVH>ioiV3^OnIPkT4oiMo]`CoUgbd0onGN[43oiUi[PGoVgR/0_nL
MjT01?nINJkoVWR[oiYhZonJN:/4oiQeZ@CoU76X1?n?KZP3ohUZZ@?oQf^/1On:L:l2oiAj]003ojRI
a_nfZ<_o]ZS;00Co]ZS;00?o^k;AokomhonooN<00_nEKjD3o`000004oi1ZXon>J:?oSVRSohiXX`Co
SVRR0_n=J:<00onEK:7oVg6Roi]aXP02oi]aXPCoW7FV1?nLN:X4oiUi[`?oTgJ_1?n?Kj/3ohe[YPCo
TF^S0onEK:42oiQ]X0;oW7NY1?nNMjP4oieeYPCoW7BU1?nNM:@2oiieY0?o/IRn1?n^TKP4oj^<]003
ojZ8/Onlm_3o_?K`00?o_?K`0_o6enH2ojAjY@CoXG^Y00?oWWf_ojMmYonWOJL00_nWOJL3oj9kZ0Go
Wgb/00CoW7jbojb=]On/SKGo[8fe1OnXS;P01?nTS[go/9W0ok2I`?n`VL04oj^G`PCoYiO600?o/j_A
ojnXdOn_Z=400_n_Z=44oj^Ye003o`000?n_]moo[kOO00?o[kOO0_n/]n42ojo3j0Co[/7X00?o[/W^
ojg6k?n]a^`00on]a^`2ojc3j`;oZlC/5Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0
003o_LCOokg4g`03okg4g`03okk9hoo2aMgo`/GM00?o`/GM00?o`/ONol6ofOo1_mT00oo1_mT01?no
_MSo^[CCokZddonj]=<4okR_d003ok2Tc?n]WLSo[Ig800;o[Ig80onYV<@4ojJB`@03oin<_onLQkco
W8Nl00;oW8Nl0onIPkT4oiMo]`?oUgbd0onGN[44oiUi[PCoVgR/00?oW7NYoiUi[_nINJh01?nJN:/3
oiQeZ@CoU76X1?n?KZP3ohUZZ@CoQf^/1?n:L:l01?nDN[CoZ9W6ojRIa_nXVLH4okJXb`?ocO[V0ol0
0004oi1ZX`?oSVRS0_n>J:82oi1XX0?oUFbQ1?nKLJ84oiaeYPCoW7RZ0_nINJl2oiUj[`?oQfn`0omn
Ijl01?n?Kj_oSF^Vohe[Y_n=JjH4oi5[X`;oUFbQ00?oUgF[oiagZOnLMjT00_nLMjT4oiigZ0CoWGFV
1OnLM:D3oiidY003oiieY?naV;ko/IRn00;o/IRn1?n^TKP3oj^<]0?oJ=J_0_nlm_02ojMkY0CoY7ZU
1?nQNjT5ojMmY`?oXW^X1?nOO:`00onaT;Co[8feojb=]@02ojb=]@CoZ8bh00?o]j72ok2I`?n`VL00
0on`VL04oj^G`P03ojNGa_ncZm7o/j_A00;o/j_A1?n_Z=401On[ZMCo/[_Pok:kh?nb^n3o000000?o
[kOO0_naanX4ojo3j003ojk1j?n^bNko[/W^00;o[/W^0on]a^`2oj_7kPCoZlC/5?ooool00ol0003o
ooooooooo`0Nooooo`006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooonm
a=l00_nma=l3ol;4g0?o`/GM0_o2`]X4ol6of@03okfie_nj]=?o^[CC00?o^[CC00?o^:o@ok2Tc?n`
Y<`00_n`Y<`3ojfMb0CoZIS400?oYY;1oin<_onOS;l00_nOS;l3oib7_0?oVH>i1?nGOkL4oiMl]0?o
UgZa0onINJh2oi]h[0;oUgZa1?nINJh3oiYhZ`CoV7FY0onDLJP4ohm^Z0CoRFZY0on7Jj`2ohY`[`;o
Vh[01?nXVLH3okJXb`04olgji_l0003o0000o`0000?oUFnU1?n@JZ<2ohiXX`03oheUWon@J:3oT6RP
00;oT6RP0onEK:44oi]aXPCoW7FV1?nLN:X4oiUj[`?oQfn`1?mnIjl3ogeV[@CoTF^S00?oUFbQoiMe
ZonGMJ/01OnLMjT3oiigZ0CoWGFV1OnLM:D2oiidY003ok:Pa_naV;ko/IRn00?o/IRn1?n^TKP2oj^<
]0;oJ=J_0_nDJIh4ojMkY0GoY7ZU0_nQNjT00on[PZOoYgfWojMmY`03ojMmY`CoXW^X0_nOO:`3ok6@
]0Co[8fe0_nXS;P3okNQ`PCo/9W00on[Ul800onh/M;o/j_Aok>[d@03ok>[d@;o[jSA0ong`^<4ok:k
h003o`000?naan[o/LOZ00?o/LOZ0_n_`nP2ojg>l@Go[/W^00?o[LK/oj_7k_n[anh00_n[anh2oj_4
k0;oZ<?]5?ooool00ol0003oooooooooo`0Mooooo`006oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Kooooo00Co0000oooooooooooo_LCO1Oo2a=`00oo2aMgo`/;Jol;2fP02ol;2fP03ol6ofOnm^MKo
_KWF00;o_KWF0onj]=<00oncZm3o/:C<ok2Tc003ok2Tc0Co[Ig80_nYV<@00onRTL?oWhbooin<_`03
oin<_`?oW8Nl0onIPkT4oiMo]`CoUgbd0onGN[42oiUi[P03oiAj]?nGN[7oUgZa00;oUgZa1?nINJh3
oiYhZ`CoV7FY1?nDLJP3ohm^Z0CoRFZY0_n7Jj`00onEPK[oVh[0oi^:`003oi^:`0CoZ9W60ol00000
0oo=n^KoVGBWoiUdY`02oiE_Y@03ohiVX?n<I9ooS6BO00;oS6BO0on=IIl4oi1XX0CoUFbQ0onKLJ85
oiaeYP;oW7RZ00?oYX6/oiUj[onINZl00onINZl3ohM_/0?oOVN_0ommIZd4oh]^[0CoUgF[1?nLMjT3
oiigZ0GoWGFV1?nLM:D01?nNM:Co/Z36ok:Pa_nbX<H5ok6H_P?o[Y6h00?oZhbdoiEWV_nDJIh00_nD
JIh00on[OZCoYg^TojMkY002ojMkY0GoY7ZU00CoXG^Yoj^2Yon[PZOoZh:W1?nWOJL4oj9kZ003oiml
[?naT;Co/I2d00;o/I2d1?n/SKD00onXS;So]j72okNQ`P02okNQ`PCo/9W000?oZiO2okRad_nh/M80
0_nh/M83ok>[d@03ok[?jOng`^?o]l;S00Co]l;S0_nb^n000onbc^ko0000ok77jP03ok77jP03ojcD
mOn]c_7o[Lka00?o[Lka0_n^bNh2oj[:l0CoZlO^00?oZ<G_ojS3kOnX`nd00onX`ndCooooo`;o0000
7_ooool001_ooooo00Go410@oooooooooooooooooa0@4006ooooo`;o00000_ooool4ol;4g0;o`lCK
0oo2`]X2oknnf@Go_KWF00Co^[CCok>[d?ncZm3o/j_@1On`Y<`2ojfMb003ojFGaonRTL?oXY7300;o
XY731?nOS;l4oib7_0?oVH>i0onGOkL2oiMl]0;oTGbi0onANkL3oiAj]0CoUgZa1?nINJh3oiYhZ`Co
V7FY1?nDLJP3ohm^Z0;oRFZY0_nCO;L4oiF1^PCoVh[000CoZ9W6o`000?l0003o00000_o8knh01?l0
003oT6VQoi1YXOn@JJ43ohiVX0CoS6BO0on=IIl4oi1XX0CoUFbQ0onKLJ85oiaeYP04oiahZ_nVPJco
YX6/ojJ1[0CoVGZ_0on7Kk04ogiW[`;oOFJ]1?n;KZ`4oiMeZ`CoW7NY0onNMjP5oieeYP?oW7BU00?o
/ZW?ok:Pa_nbX<H00_nbX<H5ok6H_P;o[Y6h0onEIiX2oiAYWP?oZgjT0onWNj@5ojAjY@CoZh:W1?nW
OJL4oj9kZ0Go/I2d1?n/SKD5okNQ`P?o/9W000?o_[kIokRad_nh/M801?nh/M801?ncZm7o^/oYok[?
jOnjcnT4okO2h`03ok7Im?nbc^ko//k^00;o//k^00?o0000ok77j_n/e?D00on/e?D2ojg>l@;oZ<kc
1OnZb_000on[ankoZ<G_ojS5k`02ojS5k`;oZ<?]0_nV`N`Booooo`03o`000?oooooo000001kooooo
000Kooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03ol;4
g?o3a=_o`lCK00?o`lCK00?o`/;JoknnfOno_]T00_no_]T3okfieP03okJbeOncZm3o/j_@00?o/j_@
0on`Y<`00onXW/coYIO7ojFGa`02ojFGa`?oXY731OnOS;l3oib7_0?oVH>i0_nGOkL00onAO[_oTGbi
oi5l^@02oi5l^@?oTG^g1?nDN[@3oiMj/@CoVGV^0onJN:/4oiQeZ@CoU76X0_n?KZP00onFO;GoTgbg
oi=l]`03oi=l]`?oUH6j0onKR/02o`0000;oZ9W60_o8knh2oi1ZX`?oT6VQ0on>IZ04ohaTW`CoSFFO
0on@J:04oiE/X@CoVg6R0onLMJH00on[Pj[oYX6/ojJ1[002ojJ1[0CoVGZ_0on7Kk04ogiW[`?oOFJ]
1?n;KZ`3oiMeZ`CoW7NY1?nNMjP4oieeYP03oiadYOnbZLoo/ZW?00;o/ZW?0onbX<H4ok6H_P;oUFJH
1?nEIiX00onDJIkoZgjToj]nY002oj]nY0CoYg^T0onTNZD00onbRZcoZh:Woj^2Y`02oj^2Y`GoYgfW
0_nRNjP2okNG]`Go/I2d0_n/SKD2ol2_b@Go]j7200Co/9W0okjnfOnn_]Wo_[kI1?nh/M800onji?Co
^/oYok[?j@03ok[?j@03okO2honafOCo/MWd00;o/MWd0_nbc^h2ojOKnP03o`000?n/e?Go[=Ce00?o
Y=7g1?nXc_<2oj[:l0?oY/Sa0onXaNl00onU`NgoY/7/ojK1k003ojK1k1Cooooo00?o0000oooooooo
ool06oooool001_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?o
oooo1Oo3a=/00oo1a=co_kkIoknnf@03oknnf@04okfie_nf/]Go][;EokJbe@Go/j_@00Co/:C<ojRN
c?nXW/coZ9k<0onUUlL3oj:A``GoWhbo0_nLQk`01?nEQ/3oTh:noi>2__nCP[h4oi5n^`?oTGbi1?nA
NkL3oiAj]0CoUgZa0onINJh4oiYhZ`?oV7FY0_nDLJP2oiUo]@CoUWbe1?nCO;L3oiF1^P?o00000_nK
R/000onXVLKob>o^olS_kP03oi1ZX`?oT6VQ1?n>IZ03ohaTW`CoSFFO0on@J:04oiE/X@CoVg6R0_nL
MJH2oj^3ZPCoYX6/1?nINZl3ohM_/0CoOVN_0ommIZd4oh]^[0?oUgF[1?nLMjT4oiigZ0?oWGFV00?o
/KKLok:YconbZLl00onbZLl4ok:PaP03ok6H__nEIYSoUFJH00?oUFJH0onEIiX5oj]nY0CoYg^T0_nT
NZD3ok::[0?oZh:W1OnWOJL01?nRNjSo]iNgokNG]ongUkL5ok6@]004ojb=]Oo0[lWo`:o9ol2_b@Co
]j7200?oa=GWokjnfOnn_]T00onn_]T00onh/M;o^^Cdok[Tm002ok[Tm0;o^/oY1?nVi?/2ok7Im0?o
V^;m0_nWfoX00ol0003oWMCkojCAm`04ojCAm`;oZ<kc0_nTbO<5ojK8l@04ojS5konU`NgoYL7]ojG1
k@?oY/7/00?oYKo/ooooooooool04oooool00ol0003oooooooooo`0Jooooo`006oooool01Ol@413o
oooooooooooooooo410@00Gooooo00?o0000ooooooooool01Oooool3ol?4f`?o`LCL0ono_]T00oni
^m[o][;EokJbe@03okJbe@;o/j_@0_n[Y]84ojRNc0?oYIO71?nRTL<2oin<_`;oV8[31?nEQ/03oi>2
_P?oTGjk1?nAO;T3oi5k]`?oU7Zd1?nGN[44oiUi[P?oVWR[0_nHMJT00onJPKOoVGneoiUo]@02oiUo
]@CoUWbe1?nCO;L3o`000004oiF1^_nKR/3oVh[0oi^:`0;o_Mg`0_n@K:D3oi1ZX`CoT6VQ0on>IZ03
ohaTW`CoSFFO1?n@J:03oiE/X@CoVg6R00?oW7FVoj^3Z_n[PjX00_n[PjX3ojJ1[0GoVGZ_0on7Kk03
ogiW[`?oOFJ]1?n;KZ`3oiMeZ`GoW7NY0onNMjP00onMMJKo/KKLok6fg002ok6fg0Co/ZW?0onbX<H2
oiIUU`GoUFJH0onEIiX5oj]nY0CoYg^T00?oY7ZUok::[?nbRZ`00_nbRZ`3oj^2Y`CoYgfW00?o`:Jo
okNG]ongUkL00_ngUkL4ok6@]003olk@f_o0[lWo`:o900?o`:o900?o]j72olCEioo4eNL00_o4eNL3
okjnf@?oVo7`0_nji?@3ohKUmP;oY^Ck0on1go/2oi[Ro@;oTm?m0onMe?/01?l0003oWMCkojCAmonT
dOL2oj39m@GoY<Wc0_nVb?42ojC2kPGoYL7]00CoY/7/ojFok?nU_ncoYKo/5?ooool00ol0003ooooo
ooooo`0Jooooo`006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00007ooooo`03ol?4
foo1a=co`LCL00?o`LCL00Co_kkIokVkf_ni^m[o^K_J0onf/]D00on^[]SoZjKBoj^VdP03oj^VdP?o
Z9k<1?nUUlL2oj:A``03oiZ?aonHR/?oV8[300?oV8[30onEQ/03oi>2_P?oTGjk1?nAO;T3oi5k]`Co
U7Zd0onGN[44oiUi[P;oVWR[00CoVXBjoiZ1]onJPKOoVX6g1OnIOkD3oiIl]@05oi=l]ol0003o0000
o`000?nCO;L00onEPKX01?nKR/3o_Mg`okgMl?nmgO03oi1/Y@?oT6ZS1?n@JJ43ohiVX0?oS6BO1?n=
IIl4oi1XX0CoUFbQ0onKLJ85oj^3ZPCoYX6/1?nINZl3ohM_/0CoOVN_0_mmIZd4oh]^[0CoUgF[1?nL
MjT2oiigZ003ojk8k?na]]co/KKL00?o/KKL1OnbZLl01?nbX<KoUVFGoiIUUonFIIL5oiEVV0;oUFNJ
0_n^PZD4oj]nY0CoYg^T1OnbRZ`4oj^2Y`;oYgfW0oo0Y[l4okNG]`;o/I2d0oo>d=X3ol2_b@;o/_?d
1?o4eNL01?nn_]WoVo7`oi_al?nKlO03od?5d0;oQ^Gf0omNdO02oh7On`CoR/on0onCdod2oigDn`03
oic7m_l0003oX<We00CoX<We0_nTbO<2oj?1k`GoY<;^0_nU`Nd2ojBnk0GoYKo/5?ooool00ol0003o
ooooooooo`0Iooooo`006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooooooo
ool01oooool4ol74g0;o_<CP1?ni^mX01?nf/]Go[ZkHojj^f?n^[]P4oj^VdPCoZ9k<0_nUUlL00onL
ULcoVXo7oiZ?a`02oiZ?a`CoV8[30onEQ/03oi>2_PCoTGjk0onAO;T4oi5k]`?oU7Zd0onGN[42oiUi
[P;oUXFn1?nJQ;X3oiZ1]`CoVGne00CoUWbeo`000?l0003o00001?nCO;L2oiF1^P?o//c]00?o_Mg`
oi9_Z?n@K:D00_n@K:D3oi1ZX`CoT6VQ0on>IZ04ohaTW`?oSFFO1?n@J:04oiE/X@;oVg6R00?oZX:Y
oj^3Z_n[PjX00on[PjX4ojJ1[0;oVGZ_0_nPTL@3ogemb0?oIGO@00CoOVN_ogeV[OmmIZgoOFJ]1?n;
KZ`3oiMeZ`?oW7NY0_nVd_L3ojk8k0Go/KKL0_nbZLl3oiITUPCoUVFG1?nEIYP01?nEIi[o[X:Uojj2
YOn^PZD5oj]nY0?oYg^T1OnbRZ`4oj^2Y`03ojMmYoo0Y[oo`:Jo00;o`:Jo1?ngUkL00onaT;Coc]3J
olk@fP03olk@fP03ol2_bOnbloCo/_?d00;o/_?d0_o4eNL2ofV_n@CoA[Of0_m6`^`2ohNkm`GoPlKm
0_n:coh2oiRjl0GoV<;d0_nLaoH00ol0003oX<Weoj39m@03oj6okPCoXl7_0_nT`^h3ojBmj`CoY;k/
0_nU_n`2ojFnjaCooooo00?o0000ooooooooool06Oooool002Gooooo00?o0000ooooooooool02?oo
ool00oo1a=co_<CPokc4h003okc4h0;o^K_J00?o/;SNojj^f?n^[]P00on^[]P4oj^VdP;oZ9k<00?o
WY_AoibEc?nLUL`00_nLUL`3oiZ?a`CoV8[31?nEQ/03oi>2_P?oTGjk0onAO;T4oi5k]`;oU7Zd00Co
SXG5oi:5`_nBQL;oTXG21OnFQKh3oiZ4^P?oVX6g0_nIOkD3o`0000?oUWbe0_nCO;L3ojVojP?o//c]
0onBKjP4oi1/Y@?oT6ZS0on@JJ43ohiVX0CoS6BO0on=IIl4oi1XX0CoUFbQ00CoVg6RojZ2ZOnZPZWo
ZX:Y1?n[PjX4ojJ1[0CoX9741?mmOLP3ofEgd0?oEWkN1?n;KZ`3oiMeZ`03oiagZOnVd_OoY];g00?o
Y];g0on^b>`2ok6fg0?oTV:E1?nFI9H4oiIUU`CoUFJH1?n^PZD5oj]nY0;oYg^T0_o0WkL4ok::[0Co
Zh:W1Oo0Y[l3okNG]`;o^_gN1?o>d=X2o`0000;o/_?d0on3V=l2ofV_n@;oVYkG1On?ZnP3ohNkm`;o
PlKm0_nH[nL5oiRjl0;oV<;d0_nO]^P2oj2kk003o`000?nP^ncoXKo^00CoXKo^0_nS`Nl2oj>kjPGo
Y;g[0_nT_^`2ojFljPCoYKk[4_ooool00ol0003oooooo`00000Jooooo`009Oooool00ol0003ooooo
ooooo`0:ooooo`?o_<CP00?o/l;Vok2hg_n`^=h00_n`^=h5ojj^f0;oZjKB00?oXJ?GoijKdOnNVm40
0_nNVm43oibEc0?oVXo71OnHR/<3oiF6`0?oTh:n0_nAO[/01?n<R<WoRhK8oh^6b?n;Q/P4oh^5a`Co
SXG50onBQL84oiJ5_P?oVXBj0_nJPKL3o`0000?oVGne0_nFO;D00onV_N[oZKoZojVojP04ojVojP03
ok;<kOnDLj_oTVnX00;oTVnX1?n@K:D3oi1ZX`?oT6VQ0on>IZ04ohaTW`CoSFFO0on@J:03oiE/X@03
oj9lZ_nZPZWoZX:Y00;oZX:Y1On[PjX2ojJ1[0;o^Z?21?nPTL@3ogemb0?oIGO@0omFO]h5og6Xl`Co
VLgj0_nVd_L3ohiNU@CoSenE0onBHYD4oiITUPCoUVFG0onEIYP00on`QjWo[X:Uojj2Y@02ojj2Y@Go
ZgjT00CoYg^Tol2O]oo0WkOo`9ng1OnbRZ`2oj^2Y`;oc<GC1Oo0Y[l00ongUkOo^_gNok[mgP02ok[m
gP03olk@f_nOQ;KoUH_600?oUH_60_n3V=l2oj>Fa`GoVYkG0_n?ZnP2oj:Lc`CoWJGK1?nH[nL2oiRj
l0;oXK3R1OnO]^P2oj2kk004o`000?nP^ncoXKo^oj6okP;oXkSW1OnS^nX2ojBmj`;oYK_Y1OnU_>X2
ojFnj`;oY[k[5?ooool00ol0003oooooooooo`0Gooooo`009Oooool2o`0000cooooo00Co_<CPok?2
i_nc`^Ko/l;V1?n`^=h2ojj^f0;oXj_M1?nQXmL3oijKd@CoW9G<0onJSlL2oiR:``;oTI3>0on@SL`3
ohj:b`CoS8S90on;Q/P4oh^5a`?oSXG50onBQL84oiJ5_P?oVXBj0_l00002oiZ1]`CoVGne00CoUWbe
ojJmj_nV_N[oY[gZ1?nY_nX3oiAcZ`?oTVnX1?n@K:D3oi1ZX`?oT6VQ1?n>IZ03ohaTW`CoSFFO0on@
J:001?nEK:7oXWbZoj9lZ_nRO:X4ojZ2Z@GoZh>Z00CoYX6/okZS`_njXl;o^Z?21?nPTL@4ogemb0?o
IGO@0omFO]h5og6Xl`;oVLgj0on>GiL3ohiNU@CoSenE0onBHYD4oiITUPCoUVFG0_nEIYP3ok27Z@?o
[X:U1On[OZ@4ol2O]`Go/XZ/00CoZh:Wolc5doo<aM?oc<GC1?o0Y[l01?nGRlGoZ8F_ojR5[onXQJl4
oin4]P?oUH_600?o[9>moj>FaonSU/L00onSU/L3oiZNe`03ojRHa_nRW<ooXYc?00;oXYc?1OnMYM/2
oiR_i`03ojBYfonQ/>;oXK3R00?oXK3R1?nO]^P2oj2kk003ojBdi?l0003oY;CT00CoXkSW0_nS^nX2
ojFii`GoYK_Y0_nU_>X2ojJlj@GoY[k[4oooool00ol0003oooooooooo`0Gooooo`009?ooool00ol0
003oooooooooo`0=ooooo`Co/l;V0_n`^=h2ojBei0CoXj_M1?nQXmL3oijKd@;oW9G<00CoTiSFoi:D
d_nBU=;oTYCB1OnAT<h3oi2=c0?oSX[;0on<R<T3oh^6b0CoRhG70on>QLD3oi:5`PCoUXFn0ol00000
1?nJQ;[oVX6goiZ1]onJPKL2oiUo]@?oX/3^1?nV_NX00onY_n[oUWN^oiIg[P04oiAcZ`?oTVnX0on@
K:D3oi1ZX`CoT6VQ0on>IZ03ohaTW`CoSFFO0_n@J:000onGM:[oXWbZoj9lZP03oj9lZP?oZX:Y1?n[
PjX00oo8]<Ko^Z?2okZS`P02okZS`P?oX9740_mUf]/00onAHYOoT6>Ioi1SV@02oi1SV@03oi5UV_mF
O]koEWkN00;oEWkN0_maZ?<3oi1RV@CoSUnG0on>GYD4ohmOU@?oTV:E1OnFI9H3oiIUU`03oiEVV?n`
QjWo/8NY00;o/8NY1?n^PZD3oj]nY0;oh=kC0oo0WkL4ok::[003ok_kj?o<aM?oc<GC00;oc<GC0oo0
Y[l00onUQ[?oZ8F_ojR5[`02ojR5[`GoWhBf00CoUH_6ojbC_On/Tkgo[9>m1?nSU/L00onJW]OoZ9S6
ojRHaP02ojRHaPCoXYc?0onMYM/00onYY]?oY:WKojBYf`02ojBYf`GoXK3R0_nO]^P2ojF`h0?oY;CT
00Co0000ojBdi?nS^>OoXkSW0_nV]nD4ojFii`;oYK_Y0onW^nP4ojJlj@;oY[k[0_nW_nXDooooo`03
o`000?oooooooooo01Kooooo000Tooooo`03o`000?oooooooooo00kooooo0_nc`^H3ojFok0?oY;GT
1?nSZmd2oj6Se`04oiFTgonDW][oU9kJoiBNfPCoTiSF0onBU=84oi6@cP?oT8g<0on>R//3ohb8b@?o
RhK81?n;QLL4ohj5a@?oTXG20ol000000onFQKkoVXBjoiZ4^P02ohg7n`CoV/Ce1?nR`>h2ojJmjP04
oiQk/_nFMjkoUWN^oiIg[PCoU7>[0onBKjP3oi1/Y@?oT6ZS1?n@JJ43ohiVX0?oS6BO0_n=IIl2oi5_
Z0?oUgBZ1OnRO:X4ojZ2Z@;oZh>Z0oo8]<H4okZS`P03oj2Aa?nAHYOoTF:G00;oTF:G1?n@HiT3oi5U
VPCoTVFJ0on@HYT4ohiOU`?oSUjE1?n?GiD3oi9RU@GoUVBF0onFIIL5ok27Z@Co[X:U0_n[OZ@3on3N
d`Co`9ng0_nbRZ`3ok_kj0Coc<GC00?o`:JoojF6/onUQ[<01?nXQJl4oin4]P03okJG^?n/Tkgo[9>m
00;o[9>m0onSU/L00on`V/3oZ9S6ojRHaP03ojRHaPCoXYc?00?oWJGKojVVdonYY]<00_nYY]<4ojBY
f`;oXK3R0_nW[M/5ojF`h0;oY;CT00?o0000ojReh_nV]nD01?nV]nD2ojFii`;oYk[V1OnW^nP2ojJl
j@;oZ;kY1?nW_nXDooooo`03o`000?oooooooooo01Gooooo000Tooooo`?o00003oooool5ojFok0?o
Y;GT0_nSZmd00onEZnGoUJCOoiFTg`02oiFTg`?oU9kJ0onCV=H3oi:DdPCoTI3>0on@SL`4ohj:b`?o
S8S90on;Q/P4oh^5a`?oSXG50ol00002oiJ5_P?oNlCn1?n=ao/4oi[4m@;oX/3^00CoW8:foiQk/_nH
Nk;oV7^b0onFMjh4oiAcZ`?oTVnX0on@K:D3oi1ZX`CoT6VQ0_n>IZ001?n<JJGoSF^Vohe[Y_n=JjH4
oi5_Z0CoUgBZ1?nRO:X4ojZ2Z@03oj^3Z_o8]<Kob;C600;ob;C60onjXl82oi5QU@CoTF:G1?n@HiT4
oi5UVP?oTVFJ0on@HYT4ohiOU`?oSUjE1?n?GiD3oi9RU@GoUVBF0onFIIL5ok27Z@Co[X:U00?oZgjT
on3NdooPg]<00_oPg]<4ol2O]`03ok::[?nknnSo^o_X00?o^o_X0_o<aM<00on]QZcoYHJcojF6/`02
okB=[@CoZ8F_0_nOQ;H3okJG^0Co[9>m00CoXiK7ok2J`?n`V/3o/9[01OnXV<H2oj:Lc`03ojnUc_nY
Y]?oZJKC00CoZJKC0_nTZM/00on[ZmOoYjgKojN]f`03ojN]f`;oYK3P0_nZ]=l3ojRehP04o`000?nX
]N;oY[OUojJgi@;oZKWU1OnW^^H2ojNkj0;oZ;gY1OnX_^T2ojNojP;oZ<3[4_ooool2o`0000Wooooo
1?l000000ol@413oooooooooo`07ooooo`009?ooool00ol0003oooooooooo`0@ooooo`;oYKo/0_nD
^_44oiFbj`?oUJ_U0onEY=l3oiBNfPCoTiSF0onBU=84oi6@cP?oT8g<0_n>R//00on5Z>_oPJ[_oh6Z
k`03oh6Zk`?oNjkd0_mc/_P3o`0000;oKkSl1?m`_Od3og_4oP;oSLOk0_nUT;l3oj28^`;oW8:f00Co
SfnZoha[Z?n<JjSoS6^X0on;JJH4ohYWY@?oRFJT0on8IZ@3ohUWY0CoS6RU0on<JJD3ohe[YPGoTFnX
0onGM:X4oj9lZPCoZX:Y1_o8]<H00onjXl;oTF6Eoi5QU@02oi5QU@?oTF:G1?n@HiT4oi5UVP?oTVFJ
0on@HYT4ohiOU`?oSUjE1?n?GiD4oi9RU@CoUVBF0_nFIIL2okNA[`Co/8NY1?n^PZD00onYNZ3o0000
on3Nd`03on3Nd`;o`9ng00?oX7BQoiQbYOnfS:X00_nfS:X5ojf6[004ojF6/ondSJgo]8f]okB=[@Co
Z8F_00?oWhBfokJG^?nfUkP00_nfUkP4ojbC_@Co/9[01?nXV<H00oneYl_o[jG>ojnUcP02ojnUcPCo
ZJKC00?o/:cDoj^[eon[ZmL00_n[ZmL3ojN]f`03ojfdgOnZ]=ooZ[CO00?oZ[CO0onX]N800ol0003o
ZKWUojVii@03ojVii@;oYk[V0_nY_NP5ojRmj@;oZ;kY0_nY`>X5ojS0ja?ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`09ooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`0Booooo`?oU;[a1?nE/^/3oiF[i@?o
UJCO0onDW]X2oi>HeP;oQZOZ0on7Y^P3ohNUj0CoQjKY0on5Z>/5oh6Zk`04og^^m?l0003o0000o`00
00;oLk;h0_m_^?`01?nbZ<ko[Z39ojjPbOn^X<T4ojVHa0;oYI2o0_nEN;03oi9c[@?oSfnZ0on<JjP3
oh]YYPCoRVNU0on9IZ@3ohQVY0?oRFNT1?n<J:D4ohaYY@?oSF^V1?nAKjP3oiMdZPGoXWbZ0_nZPZT2
om;8d0Cob;C60_nAH9D4oi5QU@?oTF:G1?n@HiT4oi5UVP?oTVFJ0on@HYT4ohiOU`?oSUjE1?n?GiD4
oi9RU@CoUVBF00CoUVFGokNA[ongTJoo]i6_1On`QjT2ojj2Y@03okR:YOnYNZ3oZGZP00;oZGZP1OnP
M:401?nHLZGo]XbZokJ<Z_nfS:X5ojf6[0Co]8f]1?nXQJl5okJG^0?o[9>m0_niXL04ok2J`004ojRH
a_neYl_o]JO;okFWb`Go[jG>00?oZJKCok2/e?n`[=@00_n`[=@4oj^[e`04ojN]fon]]=go[KCMojfd
g@CoZ[CO00GoZ;GRoj^ihon[^N?o0000oj^ih`03ojVii@03oj^mionY_NSoZKgX00?oZKgX0_nX_NT7
ojW0jP;oZ<3[0_nY`N/Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool0
00Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Kooooo00?o0000ooooooooool04oooool3oiBjl@;oUK;[00CoQK7bohF^l?n5[_3oQJk`
1?n6Znd3ohJXj`CoQZOZ0on7Y^P3ohNUj0CoQjKY0on5Z>/2oh6Zk`?o00000oo2e>P00onf[m;o/ZS>
ok:XcP02ok:XcPCo[Z390_nYV<@00onIO[CoUGR`oiEh/002oiEh/0?oTW>]1?n?KjX3oha[Z0?oRfVV
0on:IjD3ohUVY0CoR6JT0on9Ij@3ohaXY@CoS6VU0on=JjH4oi5_Z0?oUgBZ1OnRO:X00onZPZWod/S@
om;8d002om;8d003olRda_n@GiGoTF2E00;oTF2E1?nAHID4oi5RU`?oT6>I1?nAIIX3oi9UVP?oT6:I
1?n>GiL3ohiNU@GoSenE0onBHYD3oiITUP03oknQ^_ngTJoo]i6_00;o]i6_1On`QjT01?n^PZGo^8ZU
okR:YOnhRZD3ojUjX0GoX7BQ1?nfS:X4ojf6[003ol6L/ondSJgo]8f]00?o]8f]0_nXQJl2okfO^PGo
]YNh00Co[9>mokVQ`?niXL3o^J701?n`V/05okFWb`?o[jG>00?o]k;Dok2/e?n`[=@00on`[=@2oj^[
e`;o/KKL1On]]=d2ojZdg`;o[K[S0on[^N<00ol0003oZkWSojVii@03oj^mi`?oZKgX00?oZ/3ZojW0
j_nY`>X01OnY`>X7ojW1ja?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09oooo
o`002Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0
003oooooooooo`0Eooooo`?oQ;Gd0on5/O83ohF^l0CoQZ_]0on6Z>/4ohJWjP?oQjKX0on7YNP2ohNV
j@CoKlSo0_l00004ol7Fj@04ol;Dj?nf[m;o]ZoBokJ_dPCo/ZS>0_n^X<T01?nNQKSoVGjdoiUn]?nI
O[@4oiEh/0?oTW>]1?n?KjX3oha[Z0?oRfVV0on:IjD3ohUVY0CoR6JT0on9Ij@3ohaXY@CoS6VU0on=
JjH4oi5_Z0?oUgBZ1?nRO:X00oo9enCod/S@om;8d003om;8d0;oT5nE0onAH9D4oi5QU@CoTF:G0on@
HiT4oi5UVPCoTVFJ0_n@HYT4ohiOU`?oSUjE1On?GiD3oi9RU@;oUVBF0onoXKX3okNA[`Co/8NY00?o
/XBToj^1YonhRZD00_nhRZD3ojUjX0GoX7BQ1OnfS:X2ojf6[0;o`Ibc1OndSJd01?nXQJoo_InjokfO
^_nmWkX4okJG^003olRdaoniXL3o^J7000;o^J700on`V/02okj`c@Co]JO;00?o[jG>okNbe?ng/]@0
0_ng/]@3ok2/e003okBkg_na]]co/KKL00?o/KKL0_n]]=d2ojnmi0Go[K[S0_n[^N<00on/_nOo0000
oj^mi`04oj^mi`04ojVmj?nZ`>[oZ/3Zoj[0jP?oZL3Z0_nY`^/9ojW1ja?ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`09ooooo`002Oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01Oooool3o`0001Kooooo0on4]O@3ohFalP?oQJk`0_n6Znd3ogNen@?o
MKOj0omd^_`4ogBno@?oL/?n00GoKlSoo`000?l0003o0000ojWdlP04ol7Fj@03okVee_nf[m;o]ZoB
00;o]ZoB0onbZ<h01?nRS;goWXFhoij5^?nNQKP4oiUn]0?oUGR`0onBLjd4ohm_ZP?oS6^X0on;JJH3
ohYWY@?oRFJT1?n8IZ@3ohUWY0?oS6RU1?n<JJD3ohe[YPCoTFnX1?nGM:X2oj9lZP?obMOT0ooBb=03
oi1OU@?oTF2E1?nAHID4oi5RU`?oT6>I1?nAIIX4oi9UVP?oT6:I1?n>GiL3ohiNU@CoSenE0onBHYD0
0onFI9Ko_j6joknQ^P02oknQ^PCo]i6_0_n`QjT2ok:4Y0Co^8ZU1?nYNZ03oj1dX@;o_iN_1?nfS:X0
0on]QZco`Ibcol6L/`02ol6L/`Co]8f]1?nmWkX3okJG^0;ob;C71OniXL001?n`V/3o_[3=okj`cOnn
/<d3okFWb`03okfmf_ng/]Co]k;D00Co]k;D00Co/:cDokBkg_nd^mko];_N0ona]]`00onb`nKo[kgT
ojnmi003ojnmi0;o[K[S0on]`^P3ojboi`03o`000?n[_NOoZkgW00;oZl;[1OnZ`>X00onY`>[oZL;[
ojW2j`02ojW2j`;oZL7[0_nY`^`5ojW1ja7ooooo0ol00007ooooo`03o`000?oooooooooo00Wooooo
0009ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`04ooooo`03o`00
0?oooooooooo01Sooooo0oml/_H3ogZbm`CoNK?h0omg]OT3ogFgnP?oM;[l0_md__d2oco1g`?o0000
0_n]l?L3ol3Ej@03ol7FjOni]MKo^KGF00;o^KGF1?nf[m801?nbZ<koXXbmoj:<_OnRS;d3oij5^0?o
VGjd1?nEN;03oi9c[@?oSfnZ0on<JjP3oh]YYPCoRVNU0on9IZ@3ohQVY0?oRFNT1?n<J:D3ohaYY@?o
SF^V1OnAKjP3oiMdZP03oj9lZ_o9enCobMOT00?obMOT00?od/S@ohaMU_n@GiD00_n@GiD3oi5PU@Co
TF6E1?nAHYL4oi1SV@?oTFFJ1?nBIIX3oi1RV@CoSUnG0on>GYD4ohmOU@?oTV:E1OnoXKX4okNA[`04
ok27ZOnbQ:Co/XBTok:4Y0Co^8ZU1?nYNZ02oj1dX@?o_iN_1?nfS:X5ol6L/`?o]8f]0_o;]/D4okfO
^P03okJG^?o8]<Oob;C700;ob;C70oniXL000oo4`]So_[3=okj`c@03okj`c@04okFWbonm_M[o_KgJ
okfmfPCo]k;D00?o^LKTokBkg_nd^mh00ond^mh01?na]]co//?Vok;3i_nb`nH3ojnmi0;o[/G[1On]
`^P2ojboi`03o`000?n[a>coZl;[00?oZl;[0_nZ`>X2ojW3k0CoZL;[00?oZL?/ojW2k?nY`^`00onY
`^`2ojW1j`;oZ<7[3_ooool4o`000003ooooool0003ooooo00Kooooo00?o0000ooooooooool02Ooo
ool000Wooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool06Oooool3ogbbmP?oN[;g0_mi/oP2og>no@CoJL?n0omMa_/2odo6l@?o00000on`
j?P01On]l?Oo`=GYol3EjOo0eNWo^[[I00Ko^KGF0_nf[m800onWU<;oXXbmoj:<_@02oj:<_@?oWXFh
0onIO[@4oiEh/0?oTW>]0on?KjX3oha[Z0?oRfVV1?n:IjD3ohUVY0?oR6JT0on9Ij@4ohaXY@CoS6VU
0on=JjH4oi5_Z0;oUgBZ0on_e?@2olWGi0CoS5fF0on@GiD3oi5PU@CoTF6E1?nAHYL4oi1SV@?oTFFJ
1?nBIIX3oi1RV@CoSUnG0on>GYD4ohmOU@;oTV:E0_o1/<X5oknQ^P;o]i6_1?nbQ:@2on;3^@?o^8ZU
1?nYNZ000onPM:7o_iN_oknG[`02oknG[`Co]XbZ00?ogL_7ol6L/oo1W;<00_o1W;<2okB=[@?obkK5
1?nmWkX5olRda`03okVQ`?o4`]Soa<;H00;oa<;H0onn/<d2ol;Dj0Co_KgJ00?o]k;DokW6i?nia^@0
0_nia^@2okBkgP;o//_/1Onb`nH00on__NCo[/G[ojk5j`02ojk5j`;o[L;X0_n[anh3oj_4k004o`00
0?n[a>coZl;[oj_2j`;oZLC]1?nY`n`00onY`^_oZL?/ojW3k002ojW3k0;oZL;/0_nX`N`5ojS1j`[o
oooo0ol00005ooooo`03o`000?oooooooooo00?ooooo00?oEEEEofIVI_l000002oooool000Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool2o`00
01_ooooo0on0/oD4ogZinP?oLkkm0_mY`oh3ogOBoP?o000000?oQnGgok3Xn?n`j?P00_n`j?P3okkC
j@04ol3EjOnj^]Wo^[[IokZjf@Co^KGF00?oZic7ojND`_nWU<800_nWU<83oj:<_@?oWXFh1?nIO[@3
oiEh/0?oTW>]1?n?KjX3oha[Z0?oRfVV0on:IjD3ohUVY0CoR6JT0on9Ij@3ohaXY@CoS6VU0on=JjH2
oi5_Z0?oYLG`0on_e?@3ohULUPCoS5fF0on@GiD4oi5PU@?oTF6E1?nAHYL4oi1SV@;oTFFJ00GoXYO9
oh65c_n1QLkoPHG>oi9UVP03oi1RV@CoSUnG0on>GYD4ohmOU@04oi9RUOo1/<[o`K3:ol6`bPGo_j6j
00?o]i6_ok>5Y?ncQJ@00_nbQ:@3on;3^@?o^8ZU1?nYNZ05oknG[`?o]XbZ0_oMblL4ol6L/`03okB=
[Oo;]/GobkK500;obkK50onmWkX2omCNg`?ob;C700?o`nO`olC2f?o4`]P00oo4`]P00onn/<go`]CX
ol;Dj003ol;Dj0;o_KgJ0_nfe?03okW6i0;o[]Oe1?nbbn`2ok;3iP;o[L__1?n^aN/00onYbo7oZlO^
oj_7kP03oj_7kP;oZlC/00?oZLK^o`000?nYa>d01?nYa>d2ojW3k0;oZ<C]0onY`n`2ojS2k0CoZ<7/
0_nX`N/2ojO1j`Kooooo1?l00008ooooo`03o`000?oooooooooo017ooooo0009ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000oooooooo
ool06oooool3oh2cm@;oN[Wj0on9`_X3oh;;o`?o00000_nCh?h3ok3Om`;o_<oY0onndnT2ok^nf`Co
^[[I00?o^KGFoj^Laon[W<L00_n[W<L3ojND`PCoXXbm0onNQKP3oiUn]0?oUGR`0onBLjd4ohm_ZP?o
S6^X0on;JJH3ohYWY@?oRFJT1?n8IZ@3ohUWY0?oS6RU1?n<JJD2ohe[YP;oWjoS1OnUaO000on_e?Co
RUfHohYMV002ohULUPCoS5fF0on@GiD4oi5PU@?oTF6E1?nAHYL4oi1SV@04oi5UV_nRUlWoXYO9oj:G
b@?oPHG>0omYNm84ohiOU`?oSUjE0on?GiD00onb]=[o`K3:ol6`bP02ol6`bPCo_j6j1?ncQJ@2ok:4
Y0?oh/>i1?nhRZD3ojUjX003om2f`OnoUjoo_iN_00?o_iN_00Co]XbZomg;aooMblOogL_71?o1W;<6
ol^fa@03okfO^_oDg]ooe=kO00;oe=kO00Cob;C7ol?Wl?o3io3o`nO`0oo4`]P2oj_^n0Co`]CX00?o
XNClokKDl?nfe?000onfe?000onia^Co[]OeojkGm@02ojkGm@;o//_/0_nXdOD4ojg;k`03ojk5jonY
bo7oZL_a00;oZL_a0_n[anh2ojO8l0?oZLK^00Co0000ojW6k_nYa>goZLC]0_nXaNh5ojS4k@03ojW3
k?nX`^coZ<;/00;oZ<;/0_nX`N`2ojO1k0CoYl7[0_ooool3o`0000cooooo00?o0000ooooooooool0
4Oooool002;ooooo00?o0000ooooooooool07Oooool4ohjhl`;oRL;j00CoWLWfo`000?l0003o0000
0_nJeO`3ok3El`03ok3OmonlcnWo_<oY00?o_<oY00?o_]?Yok^nfonk_]/00_nk_]/2okZjf@03ojnS
c?n[W<OoZic700?oZic70onWU<84oj:<_@?oWXFh0_nIO[@01?n?NKKoS7Bdohad]?n<M;@3ohUa/P?o
Qg2a00CoSfnZoha[Z?n<JjSoS6^X0on;JJH3ohYWY@?oRFJT1?n8IZ@3ohUWY0?oS6RU0_n<JJD2oiRM
e`GoWjoS0_nUaO02ohaQVP?oRUfH0on9G9H3ohaMUPCoT5nE0onAH9D4oi5QU@?oTF:G0on@HiT00oni
YLCoXYO9oj:Gb@02oj:Gb@CoPHG>0_mYNm83of1ofP05ohiOUon>GYGoSUjEohiNUOn?GiD01?nb]=X4
ol6`bP03oknQ^_nbQjSo/XNX00Co/hFT00?o/XBTon;3^OoR`kT00_oR`kT4okR:Y@;oZGZP0_o@]/45
oknG[`03okJ<Z_oMblOogL_700;ogL_70_o1W;<2om7]i`CobkK50_l00002omCNg`?oBLS21?o3io00
0oo4`]SoZnkhoj_^n002oj_^n003ol;Dj?nQi?coXNCl00;oXNCl0_nfe?03oi[No@;o[]Oe0_nLeO`5
ojSAm@;o[L__0onVcoD2ojW;l@;oYLWc1?nWb?02ojW6kP03ojO6l?l0003oYlK`00CoZ<G^0_nXa>d2
ojO3k@CoZ<;/1_nW`N`2ojO1j`;oYl3[00?o0000ooooooooool03_ooool00ol0003oooooooooo`0@
ooooo`008_ooool00ol0003oooooooooo`0Nooooo`;oS[Sc0_nO_^h2o`0000?oWLWf00CoV]Glok3E
lon`eO?o/=Gc0onjc>L3okc?j@;o^l3N0onk_]/00onbZm7o[j?<ojnSc002ojnSc0CoZic71?nWU<82
oj:<_@04oiN4_OnCO[WoTgjioi=n^@?oSgVf0on<M;@3ohUa/PCoQg2a0on6Kk83ohI`/`?oQW:e0on7
M[T4ohMj_P?oRhC60onBT<h5oiRMe`?oWjoS00?oSfFNohaQV_n<HIX00_n<HIX3ohYMV0?oREbF0on<
GIH4oi1OU@?oTF2E1?nAHID3oi5RU`03oi1SVOniYLCo^JG400;o^JG40onRUlT4oh65cP?oJG_B0omP
OmX3ohZQh`Ko/[CJ0_o1/<X4ok:7Z0Co/hFT00?o/X^/on;3^OoR`kT00_oR`kT4okR:Y@04ojUjX?o@
]/7od;K1om2f`@Co_iN_00?o0000omg;aooMblL00ooMblL00oo1W;?odNgWom7]i`02om7]i`03ol^f
aOnWT[ooYi:o00;oRISL00?oZ9K3ohnHeon?V=L00_n?V=L5ofjUlP04ocnZm_l0T;goFm7]oe_Ak@?o
A[ka1?m^e?X2oi[No@?oRM;o0onLeO`2ojSAm@?oW]3i0_nVcoD2oj79m@GoYLWc0_nWb?02ojG6l@?o
YlK`00Co0000ojO6l?nXaNkoZ<G^0_nW`nh4ojO3k@03ojS2k?nW`NcoYl7/00CoYl7/0_nW`>`5ojO0
ja3ooooo00?o0000ooooooooool04?ooool002;ooooo0_l0000Pooooo`?o00000_nO_^h2oig9mP?o
[l_^00?o/=Gcok[<ionjc>L00onjc>L00onlcnWo^l3Nok_0gP02ok_0gP04ok^nfonbZm7o/Z_Aok:[
d@?o[j?<1On[W<L2ojND`P03oi^;`OnGQ;goUhBm00;oUhBm0onCO[T3ohmi]P?oS7Bd0on9LK83ohM`
/@?oQVnb0on6L;<4ohIb]@?oQgJi1?n7N[h3oh^4aP?oTY3>1OnHWML01?nO[n?oSfFNohmUW_n?IIh3
ohaQVP?oRUfH0on9G9H3ohaMUPCoT5nE0onAH9D4oi5QU@?oTF:G1OniYL@4oj:Gb@CoPHG>0omYNm83
of1ofP?oRZ7S1?nb]=X3ojb9/@Co/XNX1?ncQJ@2ok:;[0Coh/>i0_nhRZD00onTmmood;K1om2f`@03
om2f`@;o_iN_00?o/8^^okF=[OneSJd00_oMblL00oneSJgoWXFhoij5^003okRG]0CoYi:o1?nXU/<4
ohnHe`;oKZGb0onJY=`3ohB]k`GoM[cl0omda_l2ohWBo`;oS<Ok1OnCcO`2oik@n@;oW<Sf1?nQbOD2
ojG9l`;oXlKb1OnUa_42ojO6l003ojG3k_l0003oYl?^00CoYl?^0_nW`nd3ojO1k@;oYl7/1_nW`>`2
ojO0j`;oYko[4?ooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0Loooo
o`?o000000?ooooooinnk_nO_^h00on]`NP3ojo;kP;o^<OV1?njc>L2ok_2g`?o^l3N00?o]K7Eok:[
dOnbZm400_nbZm44ojnSc0;oZic70_nPT/H4oi^;`@?oUhBm0onCO[T3ohmi]P?oS7Bd0on9LK83ohM`
/@CoQVnb0on6L;<3ohIb]@?oQgJi1?n7N[h3oh^4aPCoTY3>0_nHWML2ogMJY0CoSfFN0on<HIX3ohYM
V0?oREbF0on<GIH4oi1OU@?oTF2E1?nAHID2oi5RU`;oaJo51OniYL@2oj:Gb@?oRUnJ1?nCIid3oi]]
W003oie]V_mPOm[oRZ7S00;oRZ7S00?o/[CJoij<`?n/RK400on/RK45ok:7Z0;o/hFT00Co]XbYok:;
[?nbRjco/X^/0_o2UjX00ooR`kWo^8ZUojCgg`02ojCgg`Cod;K100?o_iN_ok2;[_n`Rjh01OneSJd0
0onNQKSo^9NdokRG]002okRG]0CoYi:o00?o^Y^hojRF`onXU/<00_nXU/<2ohnHe`03oj^ObonJY=co
VZCL00CoVZCL0on4[Nl2ogJlo0;oTk7[1On9^oL3ohc7n`;oTlgl0_nG`oD5oic8mP;oXLWe0_nOa?84
oj?6lP;oYLKa0_nT`^l3ojG3kP04o`000?nU`nkoYl?^ojO3kP;oY/7]1?nW`Nd00onV`>coYl3/ojO0
k005ojO0k0KoYko[3oooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0I
ooooo`?o00001_ooool4ojg1j003ojo;k_nhanKo^<OV00;o^<OV00?o^/cWok_2gonk`]l00onk`]l0
1?nk`=ko]K7EokFaeOne/MD4ok:[d@;o[j?<00?oYI[;oj2Ba_nPT/H00_nPT/H4oi^;`@?oUhBm0onC
O[T3ohmi]P?oS7Bd0on9LK84ohM`/@?oQVnb0on6L;<3ohIb]@?oQgJi1?n7N[h3oh^4aP?oTY3>0_mm
H:H3ogMJY0;oMUZU0_n?IIh3ohaQVP?oRUfH0on9G9H3ohaMUPCoT5nE0onAH9D4oi5QU@04oi5RUoo5
[lGoaJo5olF_a@Co^JG40on6FYL3ohYOVPCoTfNM0_nKKI`00onFXMgoUYKAoiJFd@02oiJFd@?oWXc0
1On/RK44ok:7Z003ok>5Y?nfS:Wo]XbY00;o/X^/0oo2UjX4ojn2Y@04oj9kZ?nTmmood;K1om2f`@?o
/8^^0_o2VJh4okF=[@Go^9Nd0onWT[l2okZK^0CoZ9K31?n[Wl/4oiZTg003oj^Td?nNYmcoWZOL00;o
WZOL1?nC/N/2ohVkm`;oV[CZ1OnG_?43oiO3m@;oW<Sf0_nN`O45oio4lP;oXlKb0_nS`Nl4ojC2k`;o
YL?^00?oYL7]o`000?nV`Nd01?nV`Nd00onW`NgoY/3/ojK0k002ojK0k0;oYl3/2_nW_n/?ooooo`03
o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo01Kooooo0ol0000:ooooo`;o[L7X
0onf`n@2okS7iP?o^l?P0onk`]l00ong^=[o]K7EokFae@03okFae@;o/Z_A00?oZJ;@ojFJbonUV//0
0_nUV//4oj2BaP?oVh_11?nGQ;d3oi=n^@?oSgVf0on<M;@2ohUa/PCoQg2a0on6Kk83ohI`/`CoQW:e
0on7M[T4ohMj_P?oRhC600?oTY3>ohAWZ_mmH:H00_mmH:H2ogMJY0CoMUZU0on<HIX3ohYMV0?oREbF
0on<GIH4oi1OU@?oTF2E1?nAHID5olF_a@03okVUa?n6FIGoQUVE00?oQUZG0on:GiX2oi=WW@;oYZSI
1?nFXMd3oiJFd@CoWXc01?n/RK44ok:7Z003ok>5Y?nfS:Wo]XbY00;o/X^/0oo2UjX4ojn2Y@03oj9k
Z?o1UZ_o`IJ[00;o`IJ[00Co/8^^ol:I[_o2VJko`YV^1?neSJd00oo<Y[?o^9NdokRG]003okRG]004
ojNB_onjVkSo^Y^hokZK^0?oZ9K30_niXl84oj^Ob`03oiZTg?n[Y=3oZjC@00;oZjC@1?nNYm`2oi>a
j`;oXjkP1?nJ]>X2oiNll@;oX;KX1OnM^nh3oik1l@;oWlCb0_nR_^h5oj?1k`;oY<;_0_nT_n`3ojG1
k@03o`000?nV`NgoY/7]00?oY[o/0_nV`>`?ojNoj`kooooo00?o0000ooooooooool04?ooool002;o
oooo0_l0000Dooooo`?o00003_ooool3okK3i0;o^/?Q1Onk`n001?nk`]oo]kSJokNhf_ng^=X3okFa
e@03ojfZeOnYX]3oZJ;@00;oZJ;@0onUV//4oj2BaPCoVh_10onGQ;d3oi=n^@?oSgVf0on<M;@3ohUa
/P?oQg2a1?n6Kk83ohI`/`?oQW:e0on7M[T2ohMj_P;oUh2h0_n=L[03ohAWZP?oOF2V0omgFZ@3ogIJ
Y@;oMUfW00CoS66JohYMV?n:GISoRUfH0on9G9H4ohaMUP?oT5nE0onAH9D3oi5QU@;ob[W91?o5[lD3
ohIIU@?oQUZG0_n:GiX00on^X/_oYZSIojJXf@03ojJXf@?oUZ7M1?nFU]43oij<`0Co[8Va0onbQjP4
okJ<Z@03ok:;[?o2Uj[o`YNZ00;o`YNZ1?n_PZD5ol6FZ`04ok2;[_o2VJko`YV^ol:I[P?o]Hf]0_o<
Y[<5okRG]0Go^Y^h00CoZ9K3okVS`_niXl;o^J?20on[Wl/00ongYlSoZjC@oj^Td003oj^Td0;oWZOL
0_n/ZmH5oj>^h0;oV[CZ0_nT/N44oj2fj0;oWK_^0_nS^>L4oj:lj`CoX[k^0_nS`Nl2ojBnj`GoY;o/
0_nU`Nd00onV_^_o0000ojJok002ojJok0;oY[kZ4OnW_n/=ooooo`03o`000?oooooooooo013ooooo
000Qooooo`;o00004_ooool3o`0001;ooooo00?o]/?Tok[3hOnj`n400_nj`n42ok_3h0?o^;gN1?ng
^=X01?ne/MGo[J[EojfZeOn]Z]D3ojVRd0CoYI[;0onPT/H2oi^;`@;oTH_90on=QlL3ohV4a`?oQX;8
0on4Pl/3oh67d0?oQg2a1?n6Kk83ohI`/`;oQW:e0_ll_N@3ohY^[@?oPVJY0on=L[02ohAWZP?oOF2V
0omgFZ@3ogIJY@?oMUfW0on:GIP3ohULUPCoS5fF0on@GiD3oi5PU@;oTF6E0oo:^LT3olF_a@CoQUVE
0on6FYL01?n:Gi[o[Z;;ojjRbon^X//5ojJXf@?oUZ7M0onFU]43oij<`0Co[8Va0_nbQjP00onjTZko
]XbYokJ<Z@02okJ<Z@Go`YNZ1?n_PZD00oo:YkKo`IJ[ol6FZ`02ol6FZ`Go`YV^00Co]Hf]olbV/oo<
Y[?oc:Jc1?nhUk@00oo7Z;[o^Y^hokZK^003okZK^0Go^J?200CoZio;okNWb?ngYlSo]jO80on[Y=00
0one[M3o[:_Fojb[eP03ojb[eP;oXjkP0_n[[mX5ojBah@;oX;KX00?oYkGSoj>hionS^>L00onS^>L4
oj:lj`;oX[k^0_nT^nT4ojBnj`;oY;o/0_nV_NX3ojJnj`03o`000?nV_^_oY[o/00CoY[kZ0_nW_n/2
ojNnjPgoYko[3?ooool00ol0003oooooooooo`0@ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool00oooool00ol0003oooooooooo`0?
ooooo`;o00005_ooool3ok[3h@;o^L?R1Onh_Mh2okNhfP03ok2bf_n]Z]Go[J[E00;o[J[E1?nYX]02
ojFJb`04oi^Hd?nFTLgoUY7=oiJAc@CoTH_91?n=QlL3ohV4a`?oQX;80on4Pl/2oh67d0CoOi7K1Omk
XN/2offio0;oTWVc1?n:KZd3oh9VZ@?oO66X0on4IjX2ogePYP?oMeZT0omfFZD3ogIMY`?oM5n]0on9
G9H4ohaMUP?oT5nE0onAH9D00onAHIGob[W9olZib@03olZib@03olF_aOn<GIKoQUVE00?oQUVE0_n6
FYL00onYT[ko[Z;;ojjRb`03ojjRb`;oYZSI0on>IIh3oiAYW@;oVFfM1?nNS<03ojb9/@03ok:7Z?nj
TZko^Y:^00Co]XbY00?ogLG0ol:GZ_o2UjX00oo2UjX2ojn2Y@;obZNf1?o1UZ/00ooNa;oo`YV^ol:I
[P02ol:I[P03okF=[Oo<Y[?oc:Jc00;oc:Jc0_nhUk@3olNX^P?o^Y^h00?obK30okVS`_niXl800_ni
Xl800oo3/LSo]jO8okNWb003okNWb004oj^Td?ne[M3o]Jg@okF]d0?o[:_F00?o];7Foj^_f_n[[mX0
0on[[mX3ojBah@03ojbcg_nW]N?oYkGS00;oYkGS1?nS^>L2oj:lj`;oY[WW1OnT^nT2ojBnj`;oY[cY
1?nV_NX2ojJnj`03ojNmjOl0003oY[kZ00?oY[kZ1_nW_^X2ojNoj`;oYkoZ1_nW_n/2ojO0j`gooooo
00?o0000ooooooooool03oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo0ol0000Iooooo`03ok[3
hOni`n;o^L?R00;o^L?R0onh_Mh00onb^]oo/;;Jok2bfP02ok2bfPCo[J[E0_nYX]000onOWmCoViS@
oi^Hd002oi^Hd0?oUY7=1?nARlT3ohf7a`?oRHC70on6P/P3ohB3b`?oPHO@1?moTM/2og^Qj`?oW8Jj
1?nBNK<3ohY^[@?oPVJY0omlHJP2ogMNZP03ohAWZ_mmH:KoOF2V00?oMeZT0omfFZD3ogIMY`?oM5n]
0_mbI[L00on9G9KoS5fFohaMUP02ohaMUP?oT5nE0_nAH9D00onj]]Kob[W9olZib@03olZib@?oS5fF
0_n6FID2oif1]0CoZI:n0on^X//3ohiVX0?oSVFN0onDJId4oiU]W@04oiY]W_nNS<3o[8Vaojb9/@Go
^Y:^0_nfS:T2omg5`0Go`YNZ00Co[h:UolZW]_o:YkKobZNf0oo1UZ/2omk4_`Co`YV^1Oo<Y[<00onh
UkCoajRjolNX^P02olNX^P;o^Y^h0oo9/<02okVS`P?o`k780ongYlP00ono]<oo]Jg@okF]d003okF]
d004ojb[e_nd/MKo];7FokBaePCoZjoJ00?oY;7Qojbcg_n//mh00_n//mh4ojNeh`;oXkSW0_nX]n@4
ojJii`;oY;_Y0_nW^^L5ojJlj@;oY[gZ0_nW_>P3ojNmj@03o`000?nV_^[oYkkZ00GoYkkZ0_nX_^X5
ojNojP;oYko[0_nX_n/4ojO0j`cooooo00?o0000ooooooooool03oooool000Oooooo00Go410@oooo
oooooooooooooa0@400;ooooo`Go00001Oooool2o`0000[ooooo0ol0000Mooooo`Go^L?R00Co^;gN
ok:jgonb^]oo/[[O1?n`/]X2ojfZe@03oj>WfOnOWmCoWioD00;oWioD0onKV=03oiJAc@CoTH_90on=
QlL3ohV4a`?oQX;81?n4Pl/3oh67d0;oOi7K1?nVU<<3oib6^P?oTWVc0on:KZd3oh9VZ@?oO66X0omg
GZX3ogePYP;oMeZT1?mfFZD3ogIMY`;oM5n]0ombI[L4ohaMUP?oT5nE00CoTF2EokZfe_nj]]Ko^[KF
0oo:^LT01?mfG:OoR6b]ohQ/[On8K:d4oif1]0GoZI:n00?o[Z;;oiA_Y_n>IZ000_n>IZ03ohiUWPCo
U6VM0onIKId00onJKIko^iZgok^J]`02ok^J]`Co^Y:^00Co]XbYomg5`?oMaL3ogLG01?o2UjX00ooA
jNKobZNfolZW]P03olZW]P04ol6FZooNa;oog/Boomk4_`Co`YV^00?oe/C8olbV/oo<Y[<00_o<Y[<5
olNX^P03okZK^?o9/<3obK3000;obK3000?o^J?2ol>ab?o3/LP00_o3/LP00ongYlSo_kC?okndc`02
okndc`?o]Jg@00?o^[KFokBae_nd/MH00ond/MH2oj^_fP;o/KCK1?n//mh2ojNeh`;oZkKQ1OnX]n@2
ojJii`;oZ;WU1?nW^^L2ojJlj@;oZ;_W1OnW_>P2ojNmj@03o`000?nX_NWoYkkZ00;oYkkZ0_nX_^T4
ojRnjP;oYkoZ0_nX_nX5ojRoj`;oYl3[0_nX`>/;ooooo`03o`000?oooooooooo00oooooo0007oooo
o`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00006ooooo`03o`000?oo
oooooooo00Kooooo0ol0000Qooooo`;o^L?R0ond`^D4ok:jg`;o/;;J00?oYZoNoj>WfOnSYmT00_nS
YmT3oinOe0CoViS@0onFTLd3oi6;b@CoSHO70on9Q<L3ohJ2b0;oQ8?;0omXa?h01?m4`nCo/:C<ok2T
c?n`Y<`3ojJD``?oW8Jj0onBNK<4ohY^[@;oPVJY0omlHJP3ogMNZP;oKen`00CoOF2VogMJY?mgFZCo
MeZT0omfFZD3ogIMY`?oM5n]0_mbI[L4ogamb@CoV9oI1?nj]]H00oo:^LWoMUbWogILY`03ohQ/[@Go
WH6d0onYT[h2ofeM[`04oiA_Y_n>IZ3oSVJPohiVX0CoSVFN0onDJId3oiU]W@Go^iZg1?njTZh5omg5
`0;o`YNZ0_oAjNH5olZW]P03ol6FZooNa;oog/Bo00;og/Bo0_o2VJh2omK4b0Coc:Jc00?oh=?<olNX
^_o7Z;X00_o7Z;X5olV``0Go`k781Ono]<l00one[M3o^[KFokZfeP02okZfeP?o];7F00?o^;WJok6d
fona]=/00ona]=/2ojbcgP;o[kON1?n[]^42ojRgi0;oZkWS1OnX^ND2ojNji`;oZK[V1?nX^nL2ojNl
j0;oZ;gX0onX_NT00ol0003oZ;gYojNnjP04ojRnj@;oZ;kZ1_nX_nX2ojRoj`OoZ<3[2_ooool00ol0
003oooooooooo`0?ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEE
EOoooooo00001_ooool00ol0003oooooooooo`03ooooo`?o00009_ooool4okC2i@;o/[[O0_nY^>@3
ojJ_gPCoXjOI0onOWm@2oi^Hd004oi2RhOn<Wn7oS9oQohbOh@GoQioS0on3XNL3ogjXk`CoMkCh0_mX
a?h00ong/mGo/:C<ok2Tc002ok2Tc0?oYYC30onLQ[X3oi9i/`CoRVj]0on2IZT2ogaQZ0?oMejZ0om_
Gk03ogMJY0?oMUZU0omfGJL3ogAO[@?oLVJg1?mlOLT4oiROf@;o^[KF00?oJU>UogILYomfG:L00_mf
G:L3ohQ/[@CoWH6d0_nYT[h01?mXFk3oKEf_ofeM[om]GJl3ohiVX0CoSVFN0onDJId2oiU]W@;o/Yk4
1?nkV[L4okZB[P03o`000?oMaL3ogLG000;ogLG000?o`YNZom7Yi_oAjNH00_oAjNH3olZW]P03o`00
0?oNa;oog/Bo00?og/Bo00Co`YV^omK4b?oFa<Soe/C80oo<Y[<2on3Cc0?oajRj0_oAb=43olV``0;o
d/_B0oo3/LP2olG3f0?o_kC?00?o`/?KokZfe_nj]]H00onj]]H00ond/MKo^;WJokRifP02okRifP?o
/KCK00?o/k[Nojngg_n_]mh00on_]mh2oj^fh@;o[[WR1?n[^N<2ojRii@;oZk[U1OnY^^H2ojRki`;o
ZKcW1?nX_NP2ojRmj@03ojRnjOl0003oZ;kY00?oZ;kY2?nX_nX00onX_n_oZ<3[ojS0j`07ojS0j`[o
oooo00?o0000ooooooooool03oooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
ogMgMoo<c<co000000Gooooo00Co0000oooooooooooooooo0ol0000Zooooo`;o]<;U0_nZ`NX4ojVh
i0?oYZoN0_nSYmT00onI[>CoU:ORoiBWhP02oiBWhP?oT:;Q0on<Wn45ohNOh`?oPj7W0omnZ>l2ogNd
n003ok^ogOng/mGo]k?E00;o]k?E1?n`Y<`3ojJD``?oW8Jj0onBNK<3ohY^[@?oPVJY0omlHJP3ogMN
ZP;oKen`0omNIl@3ogIJY@?oMUfW0omdGjd3og9V]`CoO7g90onHWmT00omEB:OoIU>XofYCY@02ofYC
Y@?oMUbW0on8K:d4oif1]004ojVB__mXFk3oJ5^`ofQK/0;oKEf_0_miJ[H00on>IZ3oSVFNohiUWP02
ohiUWP?oU6VM00CoVFfMok:Na?nbW/Co/Yk41OnkV[L2okZB[P03oj=jY_nUOZWoYGjY00;ogLG00onT
Q;43om7YiP;obZNf00?o/YNkolFR]Ol000000ooNa;l00ol0003oe/C8omK4b003omK4b003olbV/ooP
dlcoh=?<00;oh=?<00?oajRjom78dOoAb=400_oAb=400oo9/<3od/_Bom;;dP02om;;dP03ol>ab?o5
`mSoaL?H00;oaL?H00Co_kC?ol;3foo2`m_o`/?K0onj]]H2ok[1g`Co^;WJ00?o/KCKok>jg_nc^]h0
0_nc^]h3ojnggP03ok6lh_n^^N;o[[WR00?o[[WR0_n[^N<2ojfki0CoZk[U0_nY^^H2ojZli`GoZKcW
0_nX_NP2ojVmj0?oZ;kY00?o0000ojRnjOnX_nX01onX_nX4ojRoj`WoZ<3[2Oooool00ol0003ooooo
ooooo`0?ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
1Oooool4o`0002kooooo1?nZ`NX2ojVhi003oijhjonL/^OoW;;W00;oW;;W0onI[>@4oiBWhP?oT:;Q
0on<Wn42ohNOh`CoHlWl0_m1`^82oko]lPCo^koM1?ng/mD2ok2Tc004oiZ>a_n@P/7oT8;1oi22`@?o
QgVl0onBNK<3ohY^[@?oPVJY0omlHJP3ogMNZP?oKen`0omNIl@2o`1_c`CoMUfW0omdGjd3og9V]`Co
O7g900CoV9oIofe@WomEB:OoEDRW0omZDjD3ogILY`?oR6b]1?nMPK@01?m[Jl3oJ5^`ofQK/?mXFk02
ofeM[`?oNFZf1?n>IIh2oiAYW@03oj:GbOnbW/Co/Yk400;o/Yk41OnkV[L01?njTZkoXgZVoj=jY_nS
NZH4ojEnZ@;oY8Ba0onnUjh01oo:YkKo/YNkolFR]Oo5X[Go]Z32omk4_onfX<800_o:[[h01?l0003o
e/C8omK4b?oFa<P3o`0000;oh=?<0_nFlNL3om78d@;o]_7d0ooBbm82ol?RkP?oaL?H0_nleN`4ol;3
f`03okZfe_nj`Moo^/7O00;o^/7O0_nh^MX2okO1h@Co/k[N00?o[kONok6lh_na_>800_na_>82ojji
hP;o[[gT1On]^n@2oj^ji@;oZkgV1?nZ_>L2ojVli`;oZ[gX1OnY_NP2ojRnj@03o`000?nX_n[oZ;oZ
00SoZ;oZ0_nX_n/:ojS0j`Wooooo00?o0000ooooooooool03oooool000Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Cooooo0_l0000aooooo`;oZ/7Z0_nO_^h3oijh
j`CoW;;W0onI[>@2oiBWhP;oR;[g1On1__/3ogK4oP;oHlWl00?oQ>WYokW[mOnijoD00_nlan<5ok^o
g@;o]k?E00?oXi[<oiZ>a_nJS/H00_nJS/H3oi22`@;oQgVl0ommL;X3ogM]^`?oPVJY0omlHJP3ogMN
ZP?oKen`1?mNIl@01Ol0KlooTXW6oi:9a_mkK;OoMUfW00?oM5n]0_mbI[L01?n7IZGoNERPogUHX?mi
F:03ofe@W`?oEDRW0_mZDjD3ogILY`CoR6b]0_nMPK@2of5>Y@?oJ5^`0om]GJl2ogUZ]PCoSX;11?nR
UlT4ok:Na0;o^iZg0_nILjL4oj=jYPCoYGjY00?oY8BaokjG[_nnUjh00_nnUjh00onbUk_oaJ:eolFR
]@02olFR]@03okJP`_o:[[kobZjn00;obZjn00?o]jW;omK4b?ngZL/00_ngZL/2ohRKg`;oYZKF00?o
KiSYoiKaiooAb=401?nflO@00ooBbm;o`n;^ol?RkP02ol?RkP03olG3f?nleNco_=G/00;o_=G/0_o2
`m/2ok[=j@?o^/7O0_nebNT4okO1h@;o/k[N0_nb_n@3ok6lhP03ok30i_n^_NCo[[gT00?o[[gT0_n]
^n@2ojfniPGoZkgV0_nZ_>L2oj^nj0CoZ[gX0_nY_NP5ojVoj@03o`000?nX_n[oZ;oZ00GoZ;oZ3onX
`>/8ooooo`03o`000?oooooooooo00oooooo000Rooooo`03o`000?oooooooooo02oooooo1?nO_^h3
oijhj`;oW;;W0_nA^O84ohjil`?oR;[g0_n1__/4ogkFo`03og3JmOn4jNWoQ>WY00;o^N_e1?nlan<2
ok^og@;oZZGB1?nSV/`3oiZ>aP?oT8;10on7NK`3oge`^P;oMffk0ombKl43ogaQZ0CoMejZ0_m_Gk03
oeiWa0;o];?H0_nBRLH3og]/]`;oJEZ^0_mSEjh01?n7IZGoNERPogUHX?miF:03ofe@W`CoEDRW00?o
JU>UogILYomfG:L00_mfG:L3ohQ/[@04oif1]?mdG:SoHDjUof5>Y@;oFEJc00CoJ5^`ofeM[om]GJoo
KEf_0omiJ[H4ohj2`@?oXYO90onbW/@2oha^Z`CoVG>W0onSNZH4ojEnZ@Go_YN^00?o/YNkolFR]Oo5
X[D00_o5X[D5olZ^_P03omBk`OngZL_o]jW;00;o]jW;1OnVY]H3ofnHj@04oaMkiOm4a>?oA<CSodC4
h`;o`n;^0on=hOd2okcEk0;oY=Oj1OnjcNT00onj`Moo]LWYokG9j@02okG9j@;o]l7Q0_nca^P4ok:o
i004ok6lh_n``>Ko/<3Vok30iP?o[[gT0_n]`>L4ojfniP;oZkgV0_n[_nP5oj^nj0;oZ[gX00?oZ[oY
ojVojOnY_nT01OnY_nT00onY`>[o0000ojW0jP02ojRojP;oZ<7[1_nX`>/2ojS1j`SoZ<3[2Oooool0
0ol0003oooooooooo`0>ooooo`008oooool00ol0003oooooooooo`0_ooooo`;oWkk^0_nF^o43oiBj
l@CoTKWb0_n>^O<3ohc8o0CoQ/ko0_mne_l2oh_Vn0;o/^Gh0_njc>P3okc7h`03ojn_eonZYM;oZZGB
00;oZZGB1?nSV/`3oiZ>aP?oT8;10on7NK`3oge`^P?oMffk0_mbKl43og5md0CoMejZ0om_Gk001?mN
IlCoRGJhohUf^?n9M[P2og=S/P03oi:9a_mkK;OoNfbg00;oJEZ^0omSEjh4ogUHX0;oKE2O1?mEB:L0
0oo6o^3oMUbWogILY`02ogILY`;oR6b]00?oSW^jogALZ?mdG:P00omQCZD2oeUF/`03ofQK/?m]GJoo
KEf_00?oNFZf1?n>P/44oj:Gb@04ok:Na?n<KZ_oS6j[oha^Z`CoVG>W0onSNZH4ojEnZ@03ok^C[Onn
Ujko_YN^00;o_YN^1Oo5X[D01?oH^K[obZjnolZ^__o:[[h2omBk`@?o]jW;0_o0//`3ojJVeP03ok:/
d_nAX=koTJ3N00;oTJ3N0_mRU^`00olGNnGo79KYo`2@bP02ohgQo@;oHLGl1?nTeoX2ok[=j@;oZm;d
1?nebNT00on/bo3o/lKXok?6j003ok?6j0;o/[oT00?o[lCYok30i_n``>H00on``>H00on^_NCo[L3W
ojg0i`02ojg0i`;o[KkV0_n/`NT4oj^oj0;oZkkX0_n[`>T4ojZoj@;oZKoY1OnY`>X00ol0003oZL7[
ojS1j`04ojS1j`;oZ<3[1_nX`N/2ojS0j`;oZ<7[1?nX`>/8ooooo`03o`000?oooooooooo00kooooo
000Tooooo`03o`000?oooooooooo02oooooo1?nF^o43oiBjl@;oTKWb0on@`_P4ohc8o0;oQ/ko0_nA
goh3ojgNn003ok;Un?njc>So^/cX00;o^/cX00Co_<OSojn_eon_[mOo[joG1?nZYM84oj>Jc0?oVXk6
0on@P/42ohMi_0?oOG2j0omgKK/3og9_`@?oLGg@1?mcY?03oij@a@?oRGJh0omcHk82og]/]`?oJEZ^
0_mSEjh2ofAP^@;oNERP0om]D9l2oeE8Y`03olKnh?mZIK[oJVFj00?oMW700om@CJl2ogALZ0?oHDjU
0omIE[<3ofeM[`;oNFZf1On>P/42oj:Gb@;oRW>d0on<KZ/4oiUcY`?oXgZV0onUOZT2ok^C[@Co_YN^
00CodJ^bolFR]Oo5X[GoaJ:e0_oH^KX2olZ^_PCoe;_100?o]jW;ol2bc?o0//`00_o0//`01?nVY]Ko
/ZcBok:/d_nb[=84oi6PgP?oHYK/0_m>X_H4of75o0;oY=Oj0on<coh3oj_Bm003okG9jOn/bo3o[<_`
00;o[<_`0_nca^P2ojg8kPCo[lCY0_n``>H3ojk3j@;o[L3W0_n/`^X5ojc1j@;oZkoX0_n[`NX4oj_0
j@;oZ[oY0_nY`N/5ojW0jP;oZL7[00?o0000ojW1jonX`N/04?nX`N/4ojS0j`Oooooo00?o0000oooo
ooooool03_ooool002Gooooo0_l0000`ooooo`;oU[_a0_nE^o44oi:nm0;oT<;h1?nGc?X2oiGFoP?o
ZMKg0_n]g_P3okO=j`;o^/cX0_nb]m`3ojn_e`CoZZGB0_nSV/`2oiB=bP?oS8K80on2PLT3ohMi_0?o
OG2j0_mgKK/3og9_`@CoLGg@00?oLjC`okF_d_ne[m800onNT<D3ohUf^0?oLf>b0_mVFk800omkK;Oo
JEZ^ofUJ[P03of=G[P?oI62i0om]D9l01?mEB:Ooa_kPolKnh?nUW/l2ofYU^P;oMW700om@CJl00omM
F;CoM5bXogALZ002of5>Y@?oFEJc0om3RN/3ogUZ]P;oSX;100CoO9KQodaJ`?m<F/3oUI3<0_n:Lk@3
oha^Z`CoVG>W1?nSNZH01?nUOZWo^i>]ok^C[OnkTjd3okjG[P;odJ^b0_o5X[D4omRi^P03olZ^__oD
^l7oe;_100;oe;_11?o0//`00oo2^M;o/ZcBok:/dP03ok:/dP;oTJ3N00?oXJKIohNQiOn7XND00_n7
XND2ogFWl@04odjRm_mK]ocoFkOloe^go0;oS<on0_n5a?`5oig<n0;o[<_`0_nTb_<4ojg8kP;o[lCY
0_n[aNd3ojk3j@;oZlC/1?n/`^X2ojc1j@;oZl;[1On[`NX2oj_0j@03oj[2jonY`N_oZL7[00?oZL7[
0_nY`>X5ojW1j`03o`000?nX`^coZ<7[00GoZ<7[0_nX`N`8ojS1j`GoZ<3[1_ooool00ol0003ooooo
ooooo`0>ooooo`009oooool00ol0003oooooooooo`0^ooooo`CoUK_a0_nB__@4oiW4m@;oUlcj0_nW
c_@3ojWFm`;o/lc/0ongcN/00ond_>3o/[OLok:gg003ok:gg0?o[joG0_nZYM800onLU/goU8g:oiB=
bP02oiB=bP?oS8K80on2PLT3ogZ1cP?oKHSL0omgKK/3og9_`@;oLGg@00Cob=3PokF_d_ne[m;o]JoB
1?nNT<D3ohUf^0;oLf>b0omVFk82ofUJ[P?oHeN^0omTH;T4ohVIg@?oYIk?0_mZIKX00omJDk3oMW70
oe1=[`02oe1=[`;oGERd00CoM5bXof5>YOmQCZGoHDjU0omIE[<00om3RN_o]>KgolGbk`03olGbk`;o
O9KQ0om<F/02ohYc]0CoS6j[0onILjL4oj=jYP03ojEnZOnkTjgo^i>]00;o^i>]00?o_YN^om6[/_oA
Zk800_oAZk800oo5X[Gof;VjomRi^P02omRi^P04onGFb?oD^l7oe;_1omBk`@;of<[<00?o`;;<ol:i
d_o2^M800_o2^M83ok:/dP03okJ`donQY]WoXJKI00;oXJKI1?n7XND3ogFWl@CoKk;i0on5a?`2oig<
n0;oU/Kh1OnTb_<2ojg8kP;oYlO`1?n[aNd00on^`nWoZlC/oj_4k002oj_4k0;o[<;Z0_nZa>`4oj_2
j`;oZl7Z0_nZ`n`4oj[2j`;oZL7[0onY`^`2ojW1j`GoZ<;/00Co0000ojS2k?nX`N_oZ<7[1_nX`N`2
ojS1j`;oZ<7/1?nX`N/4ojS0j`Kooooo00?o0000ooooooooool03_ooool002Sooooo00?o0000oooo
ooooool0;_ooool2oiFkl@CoVkg_0_nIa?D2ojK6l0CoYlkd00?oZMKgok?<k?ncc>`00_ncc>`01?ng
cN_o];cPokBlh?nd_>03ok:gg004ojRWe_nSWm7oXioAoj>Od@CoW9K=1?nDSLX3ohb6b0?oPX790omj
PLh3off8g0?oEZCg00?oD/RWolGofOo8d>000oo8d>03okF_dP?oWY350on9M[P2og=S/P?oIU^b0_mD
GKh00omYFZkoHeN^of=G[P04ofAP^@;oRIWM00Cof^3KojFNconUW/ooYIk?0_mZIKX2oeYC/003ogIa
`?m@CJooD4f_00?oGERd0omQCZD2oeUF/`;o]>Kg0_oNoKX01?oHjn;oNYoYogZOjOlmG<T2ogbFh@;o
C5[000?oGefhohYc]?n<KZ/00on<KZ/4oiUcY`?oXgZV1OnkTjd00onnUjkodJ^bom6[/P02om6[/PGo
f;Vj0_oUe/P01?oD^l7of<[<omS:c?oHb/`5ol:idP03ok:/d_nf/=?o][3C00;o][3C1?nQY]T2ohNQ
i@03oiZVg_n<ZNWoS:WY00;oS:WY0on2/?85ohVmn0?oU/Kh0_nTb_<2oio5l`GoYlO`0_n[aNd2ojS5
k`;oZlC/0_nXa>h5oj[4k0;oZl;[0_nYa>d4oj[3k0;oZ/;[0onY`n`2ojW2k0;oZ<?/1_nX`^`00ol0
003oZ<;/ojS1k00<ojS1k0;oZ<7[1_nX`>/5ooooo`03o`000?oooooooooo00kooooo000Yooooo`03
o`000?oooooooooo02oooooo0_nK_Nl3ojFok0CoY/K`0_nWc_@3ok38k0;o/lc/0_nc_n<4okBlh004
ok:gg?nXYmKoZ:OFojRWeP?oXioA0onLU/d4oiB=bP?oS8K80on2PLT3ogZ1cPCoKHSL00?oEZCgok3k
f_o=j>T00_o=j>T2olS@h004ojBSe?n@S<_oT8c;oi2<b`?oNWO40on9M[P3og=S/P?oIU^b0_mDGKh3
of=G[P?oI62i00CoRIWMom[PfooJh=_of^3K0onUW/l2ofYU^P;oFU>`0om@CJl2oeeH]0GoP87:00?o
]>KgojoPOOoNoKX00ooHjn82ogZOj@03oceLbOmlU^7oC5[000;oC5[000?oGefhohYc]?n<KZ/00_n<
KZ/4oiUcY`;oXgZV0_nbSK04ok^C[@GodJ^b00Coim70omRi^_oH^K[of;Vj0_oUe/P01?oLl]kof<[<
omS:c?oHb/`2om3GgP?o`[WB00?o_;gJokJ`donf/=<00onf/=<2oj6Vf@;oZ:[H1?nJY]h4ohbYj@?o
P[3b0_n9_OP2oi:ilPGoU/3d0onOaO<2ojO7l0?oXlGa0_nXaNl2ojK4k`CoZ<C^0_nZa>`2ojS4kPGo
ZLC]0_nZ`n`00onY`ngoZL?/ojW3k002ojW3k003ojS3kOnX`ncoZ<?/00?oZ<?/1_nX`^`00ol0003o
Z<;/ojS1k00;ojS1k0OoZ<3[0_nW`>/4ooooo`03o`000?oooooooooo00kooooo000Zooooo`;o0000
<Oooool4ojFok0;oY/K`0on^aN/2ok38k0;o//7U1?nc_n<2okBlh003ojb_f_nXYmKoZ:OF00;oZ:OF
1?nSWm43oibFc@?oU8g:0on<Q/P4oh:1b@?oNX7>0_m]R=`00omggOOo/?_JolgXj@02olgXj@03okBi
gOnTXmCoY:?D00;oY:?D0on@S</2ogYga0?oKfk10omcHk83ofIK/P?oE5fn0_lcR>`2ofAP^@03olKA
honKX]WoVj;I00;oVj;I0om^LLD2ofYU^P;oFU>`00?oCU>goe1=[om@CJl00omMF;@4oh21bP04ojoP
OOoNoK[of>_RomS[hP;oZl3Y0_liJmL2oceLb@?oC5[00_mOGKP3oha^Z`CoVG>W00CoXgZVok:=/?nb
SK3o/Xf`1?nkTjd01?oC/kWodJ^bom6[/_oAZk83onOA`003omRi^_oUe/SoiMK800?og?;N00?of<[<
om3Gg_o@emh00_o@emh01?o2^M;o_;gJokbmf_nl_MX3okJ`d`03okJdeonXZ]SoZ:[H00?oZ:[H1?nJ
Y]h2ohbYj@;oVZcS0onB/>`4oi:ilP;oU/3d0_nJ_O05oik2lP;oXlGa00?oX/;`ojK4konVa>l00onV
a>l2ojS4kP;oYlC^1?nXa>h2ojW4k@;oZ<C]1?nY`nd00onY`ncoZ<?]ojS3k@02ojS3k@;oZ<?/0_nX
`^d7ojS2k003o`000?nX`NcoZ<7/00GoZ<7/0_nW`N`4ojS1k0;oZ<3[1onW`>/3ooooo`03o`000?oo
oooooooo00kooooo000/ooooo`03o`000?oooooooooo02oooooo0_nU_n`2ojg1j@?o[/G[0_na`^H4
ok;1i@;o/koS0_n^]Mh3ojb_fPCoZ:OF0_nSWm401?nIXM[oTYcJoi:Lf_nBW=X3oh^Ig0CoQYcQ1On0
Y^`2ogo0o004ojSgj?o7lngoao?]okk<i@Co];WM0onTXm@3oi2<b`?oNWO40_m_K/43ofI^a`?oIU^b
1?mDGKh00olcR>coVn;molKAh`02olKAh`?oVj;I0om^LLD00om1C[WoJVFjoeYC/002oeYC/003odiC
]om@CJooGERd00;oGERd0on0PLX01?n_h7goioZ`ongi_OoQj]P4oj_0j@;o>F_G00Co?Ec9oaLk]olG
>kOoC5[00_mOGKP3oge]]P;oVG>W0_nMPK@4ok:=/0?o^i>]0_oC/kT2om6[/PCoim7000?of_k4onGF
b?oLl]h00_oLl]h3oj7dk@;od=ON0_nhe^l4okbmfP04okJ`donf]=Oo][CGokJde`?oZ:[H00?o[:kI
ojB[g?nTZm`00_nTZm`5oiZ/h`?oT[3/0_nB^O82oiZgk0CoV[g`0_nN`_82oj2ok`CoX/;`0_nVa>l2
ojG3k`GoYlC^0_nXa>h2ojO4kPCoZ<C]0_nY`nd7ojS3k@CoZ<;]0_nX`^`2ojO2k@?oZ<;/00?o0000
ojS1k?nX`N`01onW`N`2ojS1k0_oYl3[0oooool00ol0003oooooooooo`0=ooooo`00;Oooool00ol0
003oooooooooo`0_ooooo`Co[L7Y00?o[/G[ok72i_na`^H00_na`^H2ok;1i@;o/;[Q1?n^]Mh3ojb_
fP;oZ:OF00?oWjOKoiVQf_nIXMX00_nIXMX3oi:LfP?oRiWL1?n6W>42oh2Vk0;oJ]_[0_nXmnP2olOc
k@?o_/cU1?nd^Md3ojBSe0;oT8c;0omjMl@3ofm^`@;oIVk70omcSn000omVFk;oE5fnoeAM_P02oi_R
o@03om[^h?o6dN?oa]7S00;oa]7S0onKX]T2ofiaa@;o@Dji00?oJVFjoeYC/?mJDk000_m>DkL4oeeH
]005oh21b_n_h7goioZ`onOj/?o]nKd00_oQj]P3oj_0j@;o>F_G00Go1T72oceLbOlG>kOo5c^godaJ
`002oemM^0;oOFff1?nMPK@5ok:=/003ok^C[OoC/kWodk>i00;odk>i00GodJ^bonOA`?oWdL3oim70
om[na003o`000005omcbg_nQm>goXOC]oj7dkOmDb_001Onhe^l2okbmfP;o/[kS1?nf]=L01?nXZ]So
[:kIojb^fOn/[]T4ojB[g0;oVZcS0_nS[n04oibaiPCoV[O/0_nJ_O02oijkk@CoX;o_0_nR`_02oj?1
kPCoYL?_0_nWa>h2ojK3kPGoYlC^0_nXa>d2ojO4kP;oZ<?]0_nW`nd5ojS3k@;oZ<;]1_nW`^d2ojS2
k003o`000?nW`NcoYl7/00SoYl7/3?nW`>/3ooooo`03o`000?oooooooooo00gooooo000^ooooo`03
o`000?oooooooooo02oooooo0_n]`NT2ok32i`?o/L;V0_n`_^@4ok2jh@;o[[GN00?oYk;QojB]g_nT
[Mh00_nT[Mh3oinWf`CoVJ7J0onBW=X3oh^Ig0;oQYcQ0omndOl2oik^m`;o^??c0_nof>`4okk<i@;o
];WM00CoW9[@ohb9c?n<RLcoS8W<0omnO/T2ogYga0?oKfk10omVK/L5og>?h004oi_RoOoJk^3of^kP
om[^h0;oa]7S00CoW9kEofmgb_m_Ml[oKgO:0om^LLD2od5>^@;oFU>`0om>DkL3offNkP04olSnb_oB
o/;oioZ`ongi_@;ohN[H00Coa<cPohVLh?n9W>3oRIcP0_l/G]400oliJmOo1T72oaLk]`02oaLk]`;o
Gefh0_mmKKH5oif1]0Co/Xf`00?o^i>]om>c^OoC/kT00_oC/kT3onOA`003om[na?nX[mgoZ:oM00?o
MYSU0_loO^@2o`1Kc@03obJQk?nhe^oo^=K_00;oU/Wi1Onb_^<2okJde`;o/KKL1?n/[]T2ojB[g0;o
ZZoK1?nS[n02oibaiP03ojBchonQ]nSoXKOX00;oXKOX1OnN^nd2oj2ok`;oXkk]1?nS`Nh2ojG3k`;o
YL;^1?nV`nh2ojO4kP?oYl?^0_nWa>h6ojO3k@;oZ<?]2?nW`^d5ojO1k003o`000?nW`NcoYl7/00Go
Yl7/3onW`>/2ooooo`03o`000?oooooooooo00gooooo000_ooooo`03o`000?oooooooooo02oooooo
1?n``^L00ona`^Ko/;kTok2ni002ok2ni0;o/;[Q00?oZ[SSojNbhOnW/^400_nW/^44ojB]gP?oWjOK
0_nIXMX2oi:_jP?oS[C`1?n6__T00omndOooW^kgoik^m`03okScl`Co_mS/0_nnc>D00onYZ]SoW9[@
oibJd002oibJd0?oS8W<0_mnO/T3ofahc@?oKfk10omVK/L2og>?h003okSlg_o<o/Kof^kP00;of^kP
00?o_lGNoibNeOnLW]D00_nLW]D2ofmgbP;oFVC300?oKW75od5>^Om1C[T00_mIJ<L02OmJDk3oCU>g
odiC]om>DkOoKIk^oinej?oBo/;oioZ`ongi_@02on7Zf0?oa<cP0on9W>02obaNd@;o1T720_lG>kL0
0olWC<;oGefhoge]]P02oge]]PCoWH6d1?nbSK05om>c^@03onWfc?oWdL3oaKcA00;oZ:oM00CoYZGD
oh>Dfon3U=_oPiCK0_mMPml00oloO^Co6FcNoaU/gP02obN=k@?oU/Wi0_nb_^<2ojBjj0Go/KKL0_n/
[]T00on]/M_oZZoKojZ_f`03ojZ_f`;oXjoP00?oZ;;OojBchonT/n<00_nT/n<4oj6gj0;oW[_]0_nS
^^T5oj>nk@;oXl7^00?oYL3]ojG2k_nU`^h00onU`^h5ojK3kP;oYl?^2?nW`nd8ojO2k@;oYl;/1onW
`N`01?l0003oYl7/ojO1k?nW`N`BojO0j`;ooooo00?o0000ooooooooool03Oooool0033ooooo0_l0
000`ooooo`Co/<;W0on`_^@00on/_NKoZ[SSojZhh`02ojZhh`CoYk;Q0_nT[Mh00onM/NKoVJoWoiV_
i`02oiV_i`CoTZoZ0on>]?02ohJnn@;oV]om0on^kOP3okgMl0;o_mS/00?o/[SNojVZf?nYZ]P00_nY
Z]P3oibJd0?oS8W<0omnO/T2ofahc@CoJ8[P0om_`_h01Onho=ko/O_Kom?hhooCn>?of^kP00?o_lGN
0onLW]D3ofmgbP;oFVC30om1C[T2oeUXa`;oCU>g0onO]NP01OoWn[3oh?k6onSdcooXm<oogn?G00Co
a<cP0on9W>02obaNd@03o`I1`_l0;;Ko5c^g00;o9dc200?oGefhoge]]_mmKKH01?nMPK@4ok:=/004
olbkb_oC/kWodk>iom>c^@;ojOK<00?oaKcAokjacOnVYM@00onVYM@3oh>Df`?oGH?O0_lIK=h00olf
QN_o9hg]og^dm`02og^dm`CoY;[X0_na]]`2ojbfh0Co[K7K0onZ[m/00on]/mgoZ;;OojRbg`02ojRb
g`CoY;?S0_nQ]nP2ojJhiPCoXk[Y0_nS_^d3ojJnj`?oYL3]0_nU`^h3ojK1k@;oY/?^0_nW`^d6ojO3
k@[oYl;]1OnW`^`6ojO1k003o`000?nW`>coYl3[01CoYl3[00?oooooo`000?ooool03_ooool003;o
oooo00?o0000ooooooooool0;_ooool4ok32i`04ok2ni?n/_NKo[;gVojbmiPCoZ[SS0_nW/^42oj6d
iP?oWK7V1?nI[nL2oi:_jP?oU/Gg0_nGdO`3ojCTo003ojk]n?nmgO3o_Mg`00;o_Mg`00?o]lCTok:h
g_nb^=h00_nb^=h4ojVZf0?oW9[@0on<RL`2oginb@?oK7S=1?mXR^000om_`_koW=gmok7kf`02om?h
h`?oc]oU0onoaMh3oibNe@;oKgO:0_mJI<<2odISc004od5>^OmIJ<OoFFS7oeUXa`?oWkGX00?od_k2
on3na_oPo/H00_oXm<l2omoSe`;oa<cP00CoZ;?QogZAg_mjTMkoNY7N0_loL]`2o`1=b`04o`0/]_lG
>kOo9dc2obM<`P;oOFff1OnMPK@2ok:=/0;oc;_:0_oC/kT2onWfc004olFldOnn/Lgo_[7=okjac@Co
YZGD0on3U=/2oef3g`?o?GSP0_lfQN/3og^dm`;oY;[X00?oV;G[ojbfh?n/]^000on/]^03ojfaf`03
ojZ_fon]/mgo[K?M00;o[K?M1?nX/]l2ojBch`03ojVfh_nV^>KoY[SV00?oY[SV0_nS^^T3ojNkj0;o
Y[k[00?oZ;kYojO0jonW`>/00onW`>/2ojK1k@;oZ<7/1?nW`^d2ojO3k@koYl;]0_nW`^`5ojO1k0Co
Yl3/00?o0000ojO0k?nW`>/04onW`>/00ooooooo0000ooooo`0>ooooo`00<oooool00ol0003ooooo
ooooo`0^ooooo`;o/<;W0_n/`NT4ojbmiP;oZ[SS0_nT^>L4oj6diP?oWK7V0_nI[nL3oiVolP;oU/Gg
0onOfO`2ojCTo0?o]Mcd00?o_Mg`okO4i?nga>@00_nga>@4ok:hgP;oZJ[H00CoV9kIohfEe_n=UMKo
SIGF0omoS]P3ogfCgP?oK7S=0_mXR^02oicMo@03ok7kfooCn>?odoSS00?oc]oU00Co]/3RoifVg?nM
Y]coWJKL0omnRM@2oeI]c`?oFVC30om6Hl`3oeUXa`04oinej?oAo>;odOcRon3naP;oj?C?0_oOhmL0
0oo=c]_oZ;?QojRch@02ojRch@?oNY7N0_loL]`2o`1=b`03o`0/]_lWC<;o9dc200;oHGkI00?oOFff
oif1]?nMPK@00_nMPK@00onbSK3oc;_:olbkbP02olbkbP03om>c^OoYm/cod/?;00Co_[7=0_nVYM@2
ojJPd0?oRi?F0om_R=/2ocehh0?oB8KX0om/YO<3oiRej`Co[;KP0_n]/M/2ojbdgPCo[K?M0_nX/]l2
ojbeg`CoZKKR0_nV^>H2ojVii@CoYk_X00?oZ[cWojRnjOnX_^T00_nX_^T2ojO0j`;oZL3Z1OnX`N`2
ojO2k@03ojS2k?nW`^goYl;]00GoYl;]0_nW`^`6ojO2k@GoYl7/2?nW`>`00ol0003oYl3[ojO0j`05
ojO0j`;oYko[3?nW`>/00ol0003oooooooooo`0=ooooo`00=?ooool00ol0003oooooooooo`0^oooo
o`Co[<7Y0_n/_NH2ojJlj@CoY;SW0_nQ]>H2oijkk@CoVkc_0_nI_o83oig@n@;oWmWl0on_f?D2okGL
m0?o]/_Z0_nga>@00onZ/mooXjWKoj>Yf`02oj>Yf`CoV9kI0on=UMH3ogn>f0?oOI?N1?n2Z^h00onL
gOgob?G/olSek003om3]j004olkOiOnf`>;o]/3RokK0hP?oWJKL0omnRM@2oeI]c`;oFVC30om6Hl`3
ohO1nP;odOcR00?oh?k6onSdcooXm<l00_oOhmL3olg>f`CoZ;?Q0omjTMh2ocmbg0;o<XO/00?o04Vg
o`0gZolWC<800_mQO]T2oif1]0;oYjoN1?o<^lX00on8hj_od/?;om;3b`02ol^jb@;o_[7=00?o^Zc;
ojJPd?nVX=000onVX=03oh^CeP;oKhSK0omGP=l3odR6j0;oJIg_00CoK:GcoiRejonH]N_oV;G[0_n/
]^02ojJfi0Co[;CN0_n]/md2ojjfg`Co[;GO0_nY]^82ojbihPCoZKWU00?oYk_XojZlionZ_>L00_nZ
_>L2ojRnj@;oZ[oY1?nY`>X2ojS1k0;oZL7[1?nX`^`2ojO2k@;oZ<7/1OnW`^`2ojO2k@CoYl7/0_nW
`>/6ojO0k0;oYko[0onW`>/01?l0003oYl3[ojO0jonW`>/6ojNoj`;oYl3[00?oYko[ojO0jonW`>/0
1OnW`>/00ooooooo0000ooooo`0>ooooo`00=Oooool2o`0002oooooo0_n/`NT3ojO0j`?oY[cY0_nT
^>L2oj2lk@CoW[_]0_nK_>l3oig8mP;oWM3i0onYd_H2ojoHm@;o]<k]0onfbnX00on^^n?oZ[?OojZc
g`02ojZcg`CoXjWK0onHW]T3ohfEePCoOhkH0ommTmh2oh:ZkP03oj?[n_o8mNcob?G/00?od>gX00?o
a=CVokK0h_nf`>800_nf`>84oifVg0;oOXWD0_mFKLl3of9mf0?oAV?<00CoQl7jom7lh_oAo>;ocO3Z
0_oSlML2onK/d`?ocLkK00?o^kcKoiNSgOnGXmd00_nGXmd3ogjDgP?oJICX0olbQn`01?l0=j_oHGkI
of5nfOmQO]T4ojN_gP05olbkb_oMdLgof<O9omS7bOoB`l/00oo;^/T01?nn/Lgo^Zc;okZ/bonj[</4
ojJPd0?oRi?F0om_R=/2oeN0g`?oF8[V00?oB8KXofVMkomYWNl00on@/>`5ojJfi0;o[;CN0_n[]n84
ojjfg`;o[;GO0_n^^>44ojbihP;oZKWU0on/^nD2ojZli`;o[;kW1?nZ_nT2ojW0jP;oZ/7Z1?nY`N/2
ojS2k0KoZ<7/0_nW`^`5ojO1k0KoYl3[0_nW`>`6ojNoj`;oYl3[00?o0000ojNojonW_n/02onW_n/2
ojO0j`Kooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0;_ooool2ojO0
j`;oXko]0onQ_Nd4oj2lk@;oW[_]0onNa?<2oig8mP;oY/gd0onYd_H2ok3=k`Co]<k]00Co]/_Zojjk
hon^^n?o[[_S1?nZ/ml2oj>Yf`04oiVSg?n?W]goSikMohnNg@CoRIoR0on3Yn`4ohg5nP;o/>Kh0_o1
k_400oo@kNSoa=CVolCDiP02olCDiP;o]/3R00?oWjSLohNCf?n7TmP00_n7TmP3og:5eP;oEVg?0omR
OMP3oi2el0;ocO3Z0ooSlML01?oVk=?ogMoFomgOe_o=c]/3ok^lf`CoUj?M0omnU=h4ofVDj0;oPl?l
00Co^MK^of5nfOmQO]WoHGkI0_nW[mh2omgAc@?of<O91?o;^/T5okZ/b`?oYZ3@0on@U]D3og^=fP03
ofn8fomGP=ooEh3O00?oF8[V0om]Vn`3oi2`k0;oY[KT0_nR]^L5oj^ghP;o[[KO00?o[[WRojjhhOn^
^>400on^^>42ojbihP03ojjkhon/^nGo[;_U00;o[;_U00?o[[kVojbnion/_^L00on/_^L2ojZoj@03
ojc0jOnZ`N[oZ/7Z00?oZ/7Z0_nY`N/00onZ`N_oZ<7/ojS1k005ojS1k0?oZ<7[0_nW`N`00onX`>_o
Yl3[ojO0j`05ojO0j`coYko[00?o0000ojNojonW_n/02OnW_n/9ooooo`03o`000?oooooooooo00co
oooo000hooooo`03o`000?oooooooooo02kooooo1?nS_nd3oj6mk@;oX;c]0onO`O42oik4l`;oY<Sb
1?nVcO@00onYd_Ko/<g_ok3=k`02ok3=k`;o]<k]0_n``NH4ojjkh`;oZ[?O00?oX:[MoiVSg?nIXm`0
0_nIXm`3ohnNg@CoRIoR0on3Yn`00on=aO[o/>Khok3Vn003ol7^l@?oa=k/0_o4e>H2ok6lhP?oWjSL
0on7TmP3og:5eP?oFh3M0omROMP00on@]O3ocO3Zolg`jP03on?ae`05onK/dooMgmKogMoFomgOe_o@
dMT01?nk_=/3oiNSg@?oOYCN0_mYU>P3oiJ`j@03okWFk_o=e=oocMCO00;ocMCO0_oBcMD01?oMdLgo
f<O9omS7bOoHalT2om;0b0;obk[90_o6]<T3okZ/b`03okNZc?nVX=3oYZ3@00;oYZ3@0on@U]D3og^=
fP?oIhWO0omHR^H3offKk0?oRjg/1?nR]^L2oj^ghP;oZKWU1?n^^N82ojjhh@;o[kcS1?n^^n<00on/
^nGo[[kVojjniP02ojjniP;o[;kW0_n^`>P4ojc0j@;oZ/7Z0_n[`NX4oj[1j`;oZ<7/0onY`N/4ojS1
j`CoZ<3[0_nW`>/AojNoj`03o`000?nW_n_oYko[00GoYko[3?ooool00ol0003oooooooooo`0<oooo
o`00>Oooool00ol0003oooooooooo`0^ooooo`;oXko]0_nQ_^h4oj2ok`;oWl7a0_nSa?44ojC8lP;o
Y/gd0on/bo02ok3=k`;o[l?Y1?n``NH2ojjkh`;oY[3O0onPZ]d4oiVSg0?oSikM0_n9Wn82oiBjl@?o
W/gh0onci?L01?o1k_7oa=k/olCNk?o4g^`2ok[;i`Co/KcR0onOZ=`3ohNCf0?oLXGF0omKP=d3ohNd
l`?o^Mkc00?oho7GonK/dooMgmH00_oMgmH3om3Af@;o^kcK00?o[K;Koi:PgOnBX=d00_nBX=d3ohfO
h0?oU[3Y0_na_N<3olgDg`?od/gE0ooHalT3om;0b003ol^jbOo6]<Woa[C900;oa[C900Co^Zc;okNZ
c?ngZ/co]j[<1?nVX=03oi2Fe@?oNhgJ0omWRMl2ofJ@iPCoKI_/0on;[N`2oj:fi`;oW[KY1?nY^ND2
ojjihP;o[[cU1?n__><2ojjkh`;o[koU0on^_^H2ojo1i`Co[/3X0_n/`>T2ojg2j@CoZl7Z0_nZ`N/3
oj[2j`CoZL7[1?nX`N/4ojS0ja?oYko[00?o0000ojNojonW_n/04?ooool00ol0003oooooooooo`0<
ooooo`00>_ooool2o`0002oooooo1?nQ_^h2oj2ok`;oX/7_1?nSa?42ojC8lP?oZLS`0_n/bo02ojk4
jPCo[l?Y0_n``NH2ojZfhPCoY[3O0onPZ]d2oiVSg0;oUZcU0onA[^X4oiBjl@04oik=n?nci?Oo/nCg
ok?Tm`?o_n3`00?oa=k/ok[;ionjbnL00_njbnL2ok6lhP04oin]hOn@WmkoT9oNoi2OgP?oOI?N0omb
QMH4oe^0g@05ohNdlonig_?o^MkcokWNloo?k>T00ooEiN801?oMgmKod=7Iom3AfOo@dMT2ol74g0?o
[K;K1?nBX=d3ohfOh003oiJ`jOna_N?o/KgS00;o/KgS00CocMCOom;=eOoBcMGod/gE0_oBam000ooH
alWod/38om;0b002om;0b005olflbOo6]<Woa[C9olJdbOo2///01OngZ/`2ojJPd004ojJQdOnDVMGo
U9WEoiBIe@?oQ9?J0omdT>000omWRMooIY3VofJ@iP03og:Mj`?oRZg]1OnN]^T2ojVii@;oYk_X1?n^
_>D2ojnlh`;o[koV1?n__nD00on^_^Ko[l7Wojo1i`02ojo1i`;o[/3X00?o[/?Yojg2jOn]`^T00on]
`^T2oj_1jP;o[<;Z1?nZ`^/5ojW1j`;oZ<7[1_nX`>/BojNoj`03o`000?oooooooooo013ooooo00?o
0000ooooooooool03?ooool003cooooo00?o0000ooooooooool0;Oooool2oj6nkP;oXko]1?nR`Nl2
oj?4l@?oYlG_0_nYb?02ojc4j`Co[/CZ0_n_`nT2ojbki0CoZ[KR0_nV/=l00onP/>?oVZgToiZ]i002
oiZ]i0CoUZcU0onA[^X2oiBjl@?oY=?h00Co/nCgokoPl?noh?3o_n3`0onneN/2ok[;i`;o[K_T0onO
[N43oi2OgP?oOI?N0omiUn<4oh:/k`03okWNloo?k>WocncY00?oeNGR0ooAfn000oo@dMWo`LCLol74
g002ol74g0?o[K;K0_nBX=d00onEX]goWJ[PoifZh002oifZh0?o/KgS0ono`M/01OoBcMGod/O@om;7
d?oBam3od<?>00?od/380oo=_<T01?o6]<Wo`[;;ol:bboo2///3okNZc003okBYc_nVXM7oYZ7A00;o
YZ7A0onDVMD3ohBCfP?oM93P0ombU^H3og:Mj`?oRZg]0_nN]^T2oibgk0GoYk_X0_n^_>D00on]_nOo
[koVojnoiP03ojnoiP;o[koU0_n``^L2ojo1i`;o[l?Y1?n^`nT2ojg2j@?o[L?Z0_n/`^X2oj_3j`Co
Z/;[1?nY`N/6ojS0j`;oZ;o[1_nW_n/2ojNojPKoYko[1Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00cooooo000mooooo`03o`000?oooooooooo02gooooo1?nS_nd2oj;1k`?oY/;]
0_nWaNl2oj_3k0Co[<C[0_n^a>X2ojbniPCo[;_T0_nZ]^82ojBdi0?oX;3S1?nJ[N@2oiJ/i@;oV[[_
1?nKa?@2ojCCn0;o/m[d0_nheo03okkEj`;o]LKW1?n]^n@3oin]h@?oT9oN0ommTmh3ogVGh`;oPZc_
0_nXd?@3ol3Kk@04omGUh_oAfn3odM_Pom7Kh0;ob<oP0oo1a=`00ond^MgoYJ_KojF[f`02ojF[f`?o
UJ;M1?nMZ^000ona_N?o_l7Koko1f`02oko1f`?od/O@0oo@`lh00ooB`<SocKc9olflb@02olflb@Go
`[;;00Co]j[<okBYc_ndZLko]:W>0onVXM44oiBIe@?oQ9?J0omdT>02og:FiPCoNJ3[0on;[^d4oibg
k0;oYk_X0_nV_^/4ojfoi`;o[koV0_n_`^P3ok32i`;o[lCY1?n_`nT2ojk3j@;o[/CZ0on]`nX2ojc4
j`CoZl?[1?nZ`^/4ojW1j`CoZ<3[1?nX_n/2ojNoj`KoYkoZ0_nW_n/9ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03?ooool003kooooo00?o0000ooooooooool0;Oooool2oj>ok@?o
Y[o/0_nV`^d2ojW2j`CoZl?/0_n/a>/2ojboj0Co[;kV0_n/^n@2ojNgi@CoY;CT0onP/><2oiZ]i0;o
V[G[1?nJ^^l2oi_4m0?oZ]7d00?o/m[dokSGl?nheo000_nheo000onneN_o]LKWokG6i`02okG6i`;o
[K_T00CoX[3RoiFVhOnEY^7oUJKQ1?n;Wn43oh6OiPCoSK7^00CoZ=3dol3KkOo0fngo`=_]0oo8g>P0
0ooAfn3ob<oPolS?h002olS?h004ol74g?nd^Mgo];WMokBig@CoYJ_K0onEX]d2oifZh0;oZ[?N0ono
`M/2olG2e`03om;7d?o@`lkod<?>00;od<?>00CocL3>olflbOo=_<WocKc90_o9^//3ol:bb`03okja
cOndZLko]:W>00;o]:W>0_nVXM400onVY=?oV9gGoiRMe`02oiRMe`?oRYWL0omnV>43og^Mi`CoNJ3[
0on;[^d2oibgk0;oVkW]1?nV_^/2ojfoi`;oZl;Z1?n_`^P00on``^Oo[lCYojo4j@02ojo4j@;o[l?Y
0_n_aN/4ojk4jP03ojg3j_n/a>_o[<C[00;o[<C[0_n[`n/00on[`ncoZ/;[oj[2j`03oj[2j`?oZL7[
1OnX`>/4ojRoj`;oYkoZ4?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo
000oooooo`;o0000;oooool2ojJok0;oZL3[1?nY`^/2oj_3k0;oZl3Y1?n/_nP2ojbniP;oZK[V1?nW
]nD2ojBdi0;oXKGW0onN]>P4oiZej`;oV[[_0onSb?<2oj[Am0?o/]Gb0_nheo03okG<j`;o]LKW0_n[
^^@3oj:`hP?oUJKQ1?n;Wn43oh6OiP;oSK7^0onUao401Oo0fngob=cXolSLj?o8g>SoamGT00Cob<oP
00?o_/GPokBigOnd^Md00_nd^Md2ojF[f`;oXZ[M0onLYmh5ojZcgP03oko1foo5`]OoaL;G00;oal;D
0oo@`lh3olg0cP05olflbOo9^/_obK[;olVjboo2///01?nn/Ld2okBYcP03ok:[dOnVY=?oYZCC00;o
YZCC1?nHWML3ohZIg0?oOYSQ0omkWNL3oh2Uk0CoSK3^1?nK^Nd2ojJnj`;oY<3]1?n[`^X2ojo2j0?o
[/G[0_n_a>T00on^anco[lG[ojo5j`03ojo5j`;o[/CZ0_n]a^`2ojc4j`;oZlG/1?n[`n`2oj[2j`;o
ZL;[1?nY`N/5ojS0j`;oZ;o[5?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_o
oooo0011ooooo`03o`000?oooooooooo02gooooo1?nY`>/2ojW2j`;oZl7Y1?n[`>T2ojboj0;oZ[gW
1?nY^^H2ojNgi@;oY;OV1?nQ]NL3oijdj0;oV[G[0onO`O02oj?8l`?oZm3c0_nbeO83okC?kP;o]Lc[
0_n_`NL4oj^ji0?oX[3R0onEY^42oh^Oh@;oSZWX0on@/^d3ojG7l@?o]=?`00Gob=cXolOEi?o7eNCo
amGTolS?h004okk5h0;o];WM0_n[/mh4oj:Zg@?oW:ON0_nZ/mh3ok>hg@03olG2eoo7`]Coal;D00;o
al;D00?od<?>olg0c_o=`<h00_o=`<h4olVjb`Go_[7=00Co]:W>ok:[dOnbZm7o/Z_A1?nVY=<3oiRM
e`?oRYWL1?mnV>43og^Mi`?oP:G/1?n=/>h2oi^ik@03oi^kkonT`>goY<3]00?oY<3]0_n[`^X2oj[5
k@;o[/G[0_n/and4ojk7k0;o[lG[0on]and2ojg6k0;o[<K]1?n[aN`2oj_3k0?oZ/?/0onY`^/2ojW1
j`?oZ<7[0_nX`>/Hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool004;o
oooo00?o0000ooooooooool0;Oooool2ojW0j`;oZ/7Z1?n[`NT2oj_0j@;oZ[kX1?nZ_NL2ojVjiP;o
Y[WW1?nT]nH2oj6ei`;oX;_/1?nO_Nd2oio1l0;oY/Wb0on[d?<2ojo>l0?o]<o^00?o/LOZojo1ion_
`NL00on_`NL2oj^ji004oj>ci?nK[NCoVjgToi^]i0CoTJSU1?n>ZNP3oi2bk@05ojG7lOnddo3o]=?`
okCCl?nkdn`00oo7eN@3ol;>i0;o_/GP0_nd_N44oj^cgP?oXZ[M0_nLYmh2oj>]g`?o/kSM0_ni^m`3
olO2e0;oal7D0oo=`<h2olZoc`;obK[;0_o5^Lh3okjac@;o_;;@1?nbZm42ojJTd`03ojNWe_nKX][o
Vj;J00;oVj;J0on@Wmh3ohNOh`CoQ:?X0on6Z^`4oi2ck`?oVk__0_nT`>d3ojC3k`;oZ/G]0_nYanl4
ojc7k@;o[/O/0on]b>h2ojg7k@03ojc8k_n/a^go[<K]00?o[<K]0_n[aN`2oj[5k@;oZ/?/0_nX`nd4
ojS2k0;oZ<7[7Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0013oooo
o`03o`000?oooooooooo02gooooo1?nZ`NX2oj_1j@;oZ[oY1?nZ_^P2ojZmi`;oYk_X1?nV^NL2ojBg
iP;oXk_Z1?nP^n`2oinmk@;oXlGa1?nVbO800on[d??o[lk`ojo>l002ojo>l004okC?k_naan[o/LOZ
ok77jP;o[l7W0_nX^^H4oj>ci0?oVjgT1?nAZ>D2ohjYj003oiNekOnP`_7oX<;a00;oX<;a00?o]=?`
ok_Ck?nkdn`00_nkdn`01?o7eNCo`/kTol;>i?o2c^@2ok[6h`Co];gQ0_n[/mh00onT[mooXJcNoj6/
gP02oj6/gPCoXjgO00?o/kSMokVkg?ni^m`00_ni^m`00oo7`]Coal7DolO1e002olO1e005olg0c_o:
_loob[o?olZocoo9^//01?o5^Lh00onn/Lgo_;;@okbbd002okbbd0;o/Z_A00?o/JgDojNWe_nWYmH0
0_nWYmH4oi^RfP?oT9oN0on7Wn<4ohBSj0?oQZ[/0_n@/nl2oi>gl0CoVkk`0_nT`nl2oj?5l@CoZLO_
0_n/and2oj_9k`;o[LS^0_n[bNl4ojc8kP;o[<K]0onZanh2oj[5k@;oZ<G^1?nX`nd2ojS2k23ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`00A?ooool00ol0003ooooooooo
o`0]ooooo`CoZ/7Z1?nZ_nT2ojZnj0?oZ;gX0onW^nP2ojJii`;oY;_Z1?nS^nX2oj2kk0;oX/7_1?nS
aO42ojK9lP?oZl_`0_n_c_02ok39k@;o/LOZ0_n/_nL4ojRjiP?oXk?T0_nK[N@2oiV^iP?oTjkY1?nG
]Nd2oj32l@?o[L[_0_nkdn`3okc@j@03ol;>i?nja^?o^/KS00;o^/KS0_nd_N42ojbgh@?oY:oO1?nQ
[=h2oj>]g`;oZK?P0oni^m`00onk_]coal7DolO1e002olO1e004olK1eOo:_loob[o?olZoc`;oakkB
0oo5^Lh2ol:idP?o_;;@00?o^K?Dok6]e?na[M@00_na[M@4ojNWeP;oVj;J00?oWZOLoiFUh?nEYN00
0_nEYN03ohjUi@?oRjWY1?n<[nh4oi>gl0;oVkk`00?oW<3aoj?5lOnSaO400onSaO42ojW7k`;oZ<Sa
0_n[bNl2ojW:l@CoZlW_0_n/b>h3oj[8k`;oZ/O^00?oZ<O_ojS5k_nXaNh00onXaNh2ojS3kBCooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`00AOooool2o`0002oooooo0onZ
`NX2ojZoj@?oZKoY0_nX_NP2ojJnjPCoYKcZ0onT^nX2oj>kjP?oXko]0onR`Nl2oj?5l@?oZ<S`0_n[
bo02ojk9kP;o/<W]0_n]`^T4ojboi`;oZ;[V0_nS]ND3oijai@CoVJkV0onC[^T2oiNek@?oXL3_0_n]
b^l3ok?=k@;o_=3Y0_nibnP3ok[6h`;o/[oT1?n/]n43ojB_g`;oXJcN0_nR[n44ojVch005okVkg?nk
_]co^kkLok^ng?o7`M@01?o6`MD00oo:_looakkBolNndP02olNndP03olFic_o2^M;o`[WB00;o`[WB
00Co_;;@okVce?ni/mCo^K?D0ona[M@2ojNWeP;oYj_J1?nNYm`4oiFUh0?oSZGU0on;ZNT2ohb_kP;o
T[C^0onF^_04oic0l@;oXlGa0onSa_82ojS8l@;oYl[b1?nYb_42oj_9k`?oZL[a0_nZb>l00onXb?3o
Z<O_ojS7k`02ojS7k`;oZ<G^:Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_o
oooo0017ooooo`03o`000?oooooooooo02gooooo1?nY`>/2ojVoj@;oYko[1?nV_^X2ojFljP;oYKk/
1?nT_^`2oj>ok@03ojG3k_nVaNooY/G_00;oY/G_0_nXb?03oj_8k`;o[/W^0_n]a>/4ojg2j@;o[;oW
0_nW^^H4oj>ei@?oW[7U0_nI[^H2oiZdj@CoV[O/0_nQ`>l2ojS6k`?o/lg]0_nebn/4okW;j003ok[6
honb_nCo/[oT00;o/[oT0_n/]n401?nV]>?oXJoRoj6_h_nQ[n85oj:_h@;oZK?P00Co[KOQok^ng?nk
_]co^kkL0_nl`=`3olK1e@;oa<7G0oo7_]82olBne@?o`[WB00?o_[[EokVce?ni/m@00_ni/m@2ok6]
e0;o/;3H1?nWZmX3oijWg0;oUJGP0_nIZ^83oi>[iPCoTJo[1?nB]>h3oiJjl0;oW<3a0onN`o82oj?6
lP03oj?8lonWb_;oYl[b00?oYl[b0_nYb_42ojS;lP;oZL[a0_nWb_84ojS8l0;oZ<O_;?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo0018ooooo`03o`000?oooooooooo02go
oooo0_nY`>/2ojO0j`CoYko[0_nV_^X2ojFnj`CoYKk/0_nT_^`00onU`NkoYL?^ojG3kP02ojG3kP;o
Y/G_0onYa^l2oj_8k`;o[<G/1?n]a>/2ojg2j@;oZ[gW1?nW^^H2oj>ei@;oXKGW0onL/nP4oiZdj@;o
V[O/0_nQ_nh4ojS6k`03ok?=kOnebn_o]L_[00;o]L_[0_nibnP2okC5i`;o/[oT0_n/^nD4ojJdh`?o
XJoR0_nR[n42ojBbhPCo[KOQ00?o^kkLokc0g?nl`=`00_nl`=`00oo6`MGoa<7GolC1e`02olC1e`03
olNnd_o4_]Goa;kE00;oa;kE00Co`[WBokjjeOnn^]Go_[[E0_ni/m@2okNff0Co/;3H0_nWZmX00onW
[]goX:_Ooj2[g`02oj2[g`CoVJ[R0onCZnH4oi6_j`;oT[C^00?oUkS_oiZnlOnJ__400_nJ__42oik3
lP;oX<Gb1?nSb?<2ojO:lP?oY/_c0_nXbo82ojO;l`CoYl[b0_nXb?0`ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02oooool004Wooooo00?o0000ooooooooool0;Oooool4ojO0j`;o
Yko[0_nV_n`4ojFnj`;oYKk/00?oYL3]ojG1k_nU`Nh00_nU`Nh2ojG3kP?oYlC^0_nYa^l2oj[4k@Co
[<G/0_n]a>/2oj_0j@CoZ[gW0_nW^^H2ojBhi`CoXKGW0onL/nP2oiZdj@;oW[[/1?nQ_nh2ojS6k`?o
[LS^0_nebn/01?ncb>[o]<GWokC5iondaNL2ojo0i`Co[;_U0onV]><2oj6_hP;oX;3T1?nT/^82ojfg
h@;o/;_R0onl`=`2okc2gP?oa<7G00?o`/;JolBneOo4_]D00_o4_]D00oo0_mWo_[[Eokjje@02okjj
e@03okVce?ng]]So]kKH00;o]kKH0_n`/=P00on^/m_oYjkMojN^g@02ojN^g@CoX:_O0_nIZ^82oif_
i0?oV;3X1?nG/n/3oiNhk`;oV[ka0_nM`?44oj35lP;oXlSc0onTbO<3ojK;l`GoYl_c0_nWb_8doooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool004[ooooo0_l0000^ooooo`;o
Yl3[1_nV_n`2ojFnj`;oYL3/0onU`>d2ojG1kP?oY/?^0_nWa>h2ojW4k@CoZ/C]0_n/aN`2oj_1jPCo
Zl3Y0_nZ_NL2ojJji`CoY;SW0_nQ]NL2oj2gj0?oWKOZ1?nN^^`2oj6okP?oYlC^0_n]b>h00on_b>go
/lSZok?8jP02ok?8jP03okC5ion_`>Oo[l3W00;o[l3W0_n/^nD00onV^>KoXk?Toj>ci002oj>ci0Co
X;3T0_nT/^82ojJgi0Co/;_R00?o_<3Lokc2g_nl`]h00_nl`]h01Oo4`MOo`/;Jol;2f_o2`][oa;kE
00Co`;oI0_nn^]D2ok^kf@?o]kKH00?o];SLojjcfon^/m/00_n^/m/4ojN^g@;oX:_O00?oXZoQoif_
i?nM[n@00onM[n@3oiR`j0;oUk?[0_nK]n`4oi^kk`?oWL3a0_nPaO83oj;6lP;oY<Wc00?oYLWcojK;
lonVbo<00_nVbo<2ojO;lcWooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:oooo
o`00C?ooool00ol0003oooooooooo`0/ooooo`KoY[o/0_nU_n`4ojG0k004ojG0kOnV`^goY/;]ojK2
k@;oY/?^0_nX`nd4ojW4k@;oZ/C]0_nZ`^/4oj_1jP;oZl3Y0_nX_NP4ojJji`;oY;SW0_nR]nP4oj2g
j0?oWKOZ0_nN^^`2oj>ok@;oYlC^0_nZa^h4ojo8k@;o/lSZ0on`a>T2ojo0i`;oZ[gW0onV^>H4oj>c
i0;oX;3T0_nP/nH4ojJgi0;o/;_R0_nb_^<3okc2gP04ok_3h?o2`][o`/;Jol;2fP;o_l?M0oo0_mT2
okg1g0Co^k_I00Co]kKHokBhg?nd^=co];SL1?n^/m/2ojN^g@03ojRbgonR[n7oXZoQ00;oXZoQ0_nM
[n@2oj2ci@?oWKCX1OnK]n`2oi^kk`03oinnk_nP`_7oX<;a00;oX<;a0_nRa_83ojC7lP?oYLWc0_nV
bo<looooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool004gooooo00?o0000
ooooooooool0;?ooool5ojJok0?oYKo/0_nU`>`2ojK1k@;oY/;]0_nW`^d4ojS3k@;oZLC]0_nY`^`4
oj[2j`;oZl7Z0_nY_^T4ojRmj0;oY[[W0_nT^NP4oj:gj0;oX;OX00?oXK[[oj2lk?nP_>`00_nP_>`2
oj>ok@;oY/?^1?nZa^h2ojo8k@?o[/K/0_n`a>T2ojc1j@CoZ[gW0onV^>H2oj>ci0;oX;CV1?nP/nH2
ojJgi003ojRji_nb_^?o/[kS00?o/[kS00Go_<;Nok_3h?nk`n3o^l?Pol;2fP04oko3g@03ol2ofOnm
`Mco_L7L00;o_L7L0_nk^mT00onh_Mgo];SLokBhg002okBhg0;o[[?K0_n]]Ml4ojRbg`;oXZoQ0_nT
/n<4oj2ci@?oWKCX0_nK]n`2oj2jk0CoWkk^0_nP`_43ojC4l0;oY<Ob@oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00[ooooo001>ooooo`03o`000?oooooooooo02gooooo0onV_n`4
ojK0k0;oY/7]0_nW`N`4ojO2k@;oZ<?]1_nY`^`2oj[2j`?oZKoY0onY_^T2ojRmj0;oY[_X1?nT^NP2
oj:gj003oj:ij_nQ^^_oXK[[00;oXK[[0_nP_>`2oj>ok@CoY/?^0_nZa^h3ojc6k@;o[/K/0_n/a>/4
ojc1j@;oZ[gW0_nU^nP3oj:gi`CoX;CV0_nP/nH00onQ]nSoZ;[VojRjiP02ojRjiP;o/[kS0_nb`^D3
ok_3h0;o^/GS0ono`md2okc5h@?o_L7L00?o^/;PokRmgOnh_Md00_nh_Md2okBhg0;o/[WO1?n]]Ml2
ojRbg`;oZ;CR1?nT/n<2oj2ci@;oXkKV1?nQ]nP3oj2jk0;oWkk^0onS`>h2ojC4l4Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`00Coooool2o`0002kooooo0onV_n`4ojK0
k0CoYl7/0_nW`^d2ojS2k0KoZL;/0onY`>X2ojVoj@;oZ;kY1?nW_>P3ojJkj0;oY;WX00?oXk[Yoj:i
j_nR^NX00_nR^NX2oj6jj`;oX[g/1?nS_nd2ojK3kP?oZ<C^0_n/a^d2oj_5k@Co[<C[0_n/`NT00onX
_^[oYK_XojFkj003ojFkj0?oX[OW0_nP]>H00onO]^SoXKOXoj6gj002oj6gj0;oZ;[V0_nY_^T4ok;2
i@03ok_3h?njaN?o^/GS00;o^/GS00?o_l?Mokc5hOnlaN400_nlaN401?nm`Mco^/;Pok[2h?nj`^02
okRmg@;o]KkQ1?nb^Ml2ojfeg`;o[;OQ1?nX]>82ojBch`03ojFei?nS]^KoXkKV00?oXkKV0_nQ]nP0
0onT^^SoY;g[ojBmj`02ojBmj`;oXl3^C?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00[ooooo001Aooooo`03o`000?oooooooooo02cooooo00?oY[o/ojK0k?nV`>`01?nV`>`5ojO1
k0?oZ<;/0_nY`^`3ojW1j`;oZL3Z0_nX_nT4ojRnj@;oYkcX00?oY[cYojFkjOnU^nT00_nU^nT3oj>j
j@;oX[WZ0onR_>/3oj:mk0;oXko]0onV`^h2ojS4kP;oZLG^1?n[aNd2ojc4j`03ojW1jonX_^[oZ;kZ
00;oZ;kZ0_nU^nP2oj:jj@CoWkOY0onO]^P2oj6gj0;oX[_[1?nY_^T2ok;2i@?o//CW0_njaN<2okS6
i@;o_<GQ0_niaN@3ok[2h0;o]/?T1?ne_^42ok:ig`;o[k_R1?n/]n42ojRdhP03ojRfhonU]NCoYKGT
00;oYKGT0_nS]^H2ojFhiPCoY;[X0_nT_N]?ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02_ooool005;ooooo00?o0000ooooooooool0:oooool6ojK0k0?oYl3/0_nW`N`2ojS0j`Co
Z<7[0_nY`N/2ojRojPCoZ;oY0_nX_^T00onW_NWoY[cYojJlj@02ojJlj@;oYK_Y0_nT_>X4oj>lj`;o
X[c[0_nT_nd4ojC0k@;oY/;^0_nWa>h4ojW5kP;oZlG]00?oZ/?/ojW1jonY`N/00_nY`N/2ojRnjP;o
YKg[1?nR^^T2oingj@;oW[W[0onO^N/4oj:kj`;oZKkY0onZ`^/2ok;4i`04ok76j_nha^Go^<KUokS6
i@;o]LSX1?niaN@00onj`^3o]/?TokK3i002okK3i0;o]KkQ00?o/[oTojnkh_n_^n800on_^n82ojbg
h@03oj^hhonX]^?oZ;KS00;oZ;KS0_nU]N@2ojJgi0CoYKSV0_nT^^QCooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02_ooool005?ooooo00?o0000ooooooooool0:oooool2ojK0k0?o
Yl3[0_nW`>`6ojS0j`;oZ<7[0_nX`>/4ojRojP;oZ;oY00?oYkkYojNmjOnW_NT00_nW_NT2ojJlj@;o
YKcZ1?nT_>X2oj>lj`;oY;k/1?nT_nd2ojC0k@;oY/;^1?nWa>h2ojW5kP;oZLC]0onZ`n`2ojW1j`?o
Yko[0onU_N/2oj:jj@;oX;[[1?nN^N/3oinij`;oX[_[0onS_^d2oj[2j`03oj[5kOnaa^[o/LKZ00;o
/LKZ00?o^<KUokG8j?neb>P00_neb>P2okW5i0?o]/KW0_nf`n@00onb`nKo/[oTok:oi002ok:oi0;o
[k_R0_n]^n@4oj^hh`;oZ;KS0_nX]n@4ojJgi0;oYKSVEoooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Wooooo001Dooooo`;o0000;Oooool2ojO0j`koZ<3[0_nX_nX00onX_^[oYkkY
ojNnj@02ojNnj@;oYkgY0_nV_NX4ojFljP;oY;cZ0_nT_N/4ojBnk0;oY;o]0_nU`Nd4ojK2kP;oYlC^
0_nXa>h2ojW4k@;oZ<?]1?nX`^`2ojNoj`;oY;k/1?nR_>`3oj2jj`;oW[W[0_nM^nd4oinlk@;oXkk]
00?oY<;_oj[5kOnZaNd00_nZaNd2ok76jP?o/<S/0_neb>P2ok;9j`?o]/KW00?o//OYok;3i_nb`nH0
0_nb`nH2ok:oi0;o[[oV1?n]^n@2oj^hh`;oZKWU1?nX]n@2ojJgi5[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`09ooooo`00E_ooool00ol0003oooooooooo`0[ooooo`koZ<3[0onX
_nX2ojRnjP;oYkkY0onW_NX3ojJmjP;oYKcZ0_nU_N/4ojBmj`;oY;k/0onU`>d3ojG1k@;oY/;^0_nW
`nh4ojS4kPCoZ<?]0_nX`^`2ojK1k@CoY;k/0_nR_>`00onP_>goW[_]oijkk@02oijkk@CoWK_]0_nO
_>d00onO_nooY<;_ojC2k`02ojC2k`;oZ/G]0onZanl2ok38k0;o[/W^1?nbbN/01?nfa^Oo//OYok;7
jOnbanT2ok;3iP;o[l?Y1?n^_nH2ojfki0?oZ[cV0onY^ND2ojRgi5kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`09ooooo`00Eoooool00ol0003oooooooooo`0[ooooo`[oZ<3[0onX
_n/2ojRojP03ojNoj_nW_^[oYkkZ00;oYkkZ0_nW_NX2ojJnj`CoYKk[0onU_N/2ojBmj`?oY;o/0_nU
`>d00onU`^goY/;^ojK2kP02ojK2kPCoYl?^1?nXa>h2ojS3k@;oYl;]1?nV`Nd2ojBnk003oj:nkOnP
_>goX;c]00;oX;c]0_nN^nd2oijmkPCoW[k_0onO_nl2ojC2k`?oY<G`0_nZanl00onYbO3o[/W^ojk9
kP03ojk9kP;o//W[0_n`bNd2ok;7j@;o[/O/1?n_`nT2ojjoiP;oZkoX0_nZ_>IVooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02Oooool005Sooooo00?o0000ooooooooool0;?ooool8
ojS0j`;oZ;o[00?oYko[ojNoj_nW_nX00_nW_nX2ojNnjPKoY[k[0_nU_^/6ojFok0;oY;o/00?oYL7]
ojG2kOnU`^d00_nU`^d2ojK2kPKoYl?^0_nXa>h3ojO3k@?oYl;]0_nV`Nd2ojBok@?oX[k]0_nP_>d2
oinmkPCoW[g^0_nN_^l2oik0l0CoX<;a0_nTaO000onTao7oZLW`ojW9l002ojW9l0;o[/W^0on/bnl2
ok39k@;o[LW_1?n^an`2ojo3j@;oZl?[0_n[_nQZooooo`05o`000?ooooooooooooooool000002ooo
ool005Wooooo00?o0000ooooooooool0;?ooool6ojS0j`03ojRojonW_n_oYko[00;oYko[0_nW_nX2
ojNoj`KoY[k[0_nV_n/6ojFok003ojG0kOnU`NgoYL7]00;oYL7]0_nU`^d2ojK2kPKoYl?^1OnW`nd0
0onV`^goY/7]ojK1k@02ojK1k@;oY;o]0_nS_nd4oj6nk@?oWkg^0_nN_Nh2oijol0CoW/3`0_nP`_40
0onQaO;oY<OaojC7l@02ojC7l@;oZLW`0onXb_42ojc;k`?oZ/_a0on]bNl2ojk7k0;oZlK^0_n[`n]]
ooooo`05o`000?ooooooooooooooool000002oooool005[ooooo0_l0000]ooooo`CoZ<3[0onX_n/8
ojNoj`;oY[k[1_nV_n/2ojFok003ojG0k?nU`>goYL3]00;oYL3]0_nU`Nd3ojK2k@?oY/;^0_nW`nh5
ojO3k@03ojO2kOnV`^goY/;]00;oY/;]0_nV`Nd2ojG0k@CoXko]0_nQ_^d2oj6okPCoWkk_0onN_o02
oik0l0;oWl?a0onQaO82ojC7l@?oYLWb0_nXb_43ojO;lP;oZ/_a00?oZ<_bojW9l?nYbO000_nYbO02
oj_6kW7ooooo00Co0000oooooooooooo00002oooool005cooooo00?o0000ooooooooool0:oooool4
ojS0j`03ojRojonW_n_oYko[00KoYko[2?nV_n/2ojJok0?oYL3/0_nU`>d3ojK1k@CoY/;]1_nW`nd5
ojO2k@;oY/;]0_nV`Nd4ojG0k@CoXko]1?nQ_nh2oinnk`03oj30konO`O3oWl7`00;oWl7`0_nO`o42
oj75lPCoX/Ob0_nUbO83ojG:l`;oYl_b00?oY/_cojS;l_nXbo800_nXbo82ojW9l7Gooooo00?o0000
ooooool000002oooool005gooooo00?o0000ooooooooool0:oooool2ojS0j`;oYl3[2?nW_n/2ojJo
j`OoY[o/0_nV`>`6ojK1k@KoY/;]0_nW`nd7ojO2k@?oYl7]0onV`Nd2ojG0k@?oY;o]0onS_nd4oj6o
kP?oX<3_0_nO`O03oj73l@?oXLGb0_nRao83oj?8l`?oYL[c1?nVbo<2ojS;lWSooooo00Co0000oooo
oooooooo00002_ooool005kooooo00?o0000ooooooooool0:oooool4ojO0j`KoYko[2?nV_n`5ojK0
k0CoY/7]1_nV`^d:ojO2k@;oYl7]0_nV`N`4ojG0k0?oY;o]1?nS_nd2oj6okP;oX/3^1?nQ`O02oj73
l@03oj?4lOnSa_;oXlKb00;oXlKb0_nSb?<3ojG9l`?oYL[c0_nVbo=looooo`03o`000?oooooo0000
00[ooooo001Oooooo`;o0000;?ooool4ojO0j`CoYko[1_nV_n`7ojK0k0?oY/7/0onV`Nd2ojK2k@Co
Yl;]1_nW`^`2ojO2k@;oYl7/1?nV`N`2ojG0k003ojFok?nT_ngoY;o]00;oY;o]0_nS_nd2oj?0k@Co
X/3^0_nQ`O000onS`o3oXlCaoj?4l@02oj?4l@;oXlKb0onTao82ojG9lh?ooooo0_l0000:ooooo`00
HOooool00ol0003oooooooooo`0Zooooo`GoYl3[0onW_n/2ojJok0OoY/3/1OnV`N`2ojO1k0CoYl7]
0_nW`^d00onW`NcoYl;/ojO2k004ojO2k0KoYl7/0_nV`N`2ojK0k0?oYKo/0_nT_nd3ojFok0?oXl3]
0_nR`>h2ojC1kP?oXl?`0_nSa?43ojC5l0;oY<ObQOooool3o`0000[ooooo001Rooooo`03o`000?oo
oooooooo02_ooooo0_nW`>/6ojO0k003ojK0k?nW`>coYl3/00CoY/3/0_nV`N`6ojO1k0;oYl7]1OnW
`N`2ojO2k0SoYl7/0_nW`>`2ojK0k0;oY[o[1?nV_n`4ojFok0CoY<3]00?oY<7^ojG2k_nU`^h01?nU
a>l2ojC5l8Cooooo1?l0000=ooooo`00Hoooool00ol0003oooooooooo`0[ooooo`_oYl3/0_nV`>`2
ojO0k1;oYl7/0_nX`>/3ojO0j`;oYl3/0_nW_n/4ojJoj`CoY[o/1?nU_n`2ojC0k@03ojK1kOnU`^ko
YL;^00;oYL;^0_nUa>n3ooooo`Co00004Oooool006Cooooo0_l0000/ooooo`;oYl3/00?oYl3[ojO0
k?nW`>`02_nW`>`>ojO1k0KoZ<3[00?oYl3[ojNojonW_n/01?nW_n/2ojJoj`;oYko[1?nV_n`2ojFo
k0;oY/3/0onV`Nd2ojG2kX?ooooo0ol0000Eooooo`00I_ooool00ol0003oooooooooo`0[ooooo`;o
Yl3[3OnW`>`9ojO1k0[oZ<3[2onW_n/2ojJok0;oYko[0_nV`>b5ooooo`Co00006?ooool006Oooooo
00?o0000ooooooooool0:_ooool4ojO0j`;oYl3/0_nW`>/7ojO0k0KoYl7/3?nX`>/2ojRoj`goYko[
Q?ooool4o`0001cooooo001Xooooo`03o`000?oooooooooo02[ooooo2?nW`>/2ojO0k0;oYl3[0onW
`>`2ojO1k0coZ<3[1_nX_n/2ojNoj`03ojNoj_nW_n_oYko[00CoYko[Poooool4o`00023ooooo001Y
ooooo`;o0000;?ooool?ojO0j`WoZ<3[2?nX_n/5ojNojP;oYko[P_ooool4o`0002Cooooo001[oooo
o`03o`000?oooooooooo02[ooooo3OnW`>/9ojS0j`WoZ;o[1?nW_nZ2ooooo`?o0000:?ooool006co
oooo00?o0000ooooooooool0:_ooool<ojO0j`[oZ<3[1onX_n^3ooooo`Co0000:oooool006gooooo
00?o0000ooooooooool0:oooool:ojO0j`KoZ<3[0_nW_n/6ojRojh;ooooo1?l0000_ooooo`00K_oo
ool00ol0003oooooooooo`0Zooooo`_oYl3[0_nX`>/2ojO0j`CoYko[0_nX_n^1ooooo`Co0000<ooo
ool006oooooo0_l0000[ooooo`ooYl3[0_nW_n^0ooooo`Co0000=oooool0077ooooo00?o0000oooo
ooooool0:_ooool9ojO0jh;ooooo1?l0000kooooo`00L_ooool00ol0003oooooooooo`0Zooooo`Go
Yl3[P_ooool3o`0003oooooo001cooooo`03o`000?oooooooooo02[ooooo00?oYl3[ooooooooool0
Ooooool4o`0004;ooooo001dooooo`;o0000:_ooool00ol0003oooooooooo`1kooooo`Co0000A_oo
ool007Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1hooooo`Co0000B_ooool0
07Oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1dooooo`Co0000C_ooool007So
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1aooooo`?o0000D_ooool007Wooooo
0_l0000Tooooo`03o`000?oooooooooo06gooooo1?l0001Eooooo`00Noooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo06Wooooo1?l0001Iooooo`00O?ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo06Gooooo1?l0001Mooooo`00OOooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo067ooooo1?l0001Qooooo`00O_ooool2o`0001oooooo00?o0000oooooooo
ool0GOooool4o`0006Gooooo0020ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
F_ooool3o`0006Wooooo0021ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0E_oo
ool4o`0006cooooo0022ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0D_ooool4
o`00073ooooo0023ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0C_ooool4o`00
07Cooooo0024ooooo`;o00006Oooool00ol0003oooooooooo`1:ooooo`Co0000N?ooool008Kooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`16ooooo`Co0000O?ooool008Oooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`13ooooo`?o0000P?ooool008Sooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0oooooo`Co0000Poooool008Wooooo0_l0000Doooo
o`03o`000?oooooooooo03_ooooo1?l00027ooooo`00Roooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo03Oooooo1?l0002;ooooo`00S?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo03?ooooo1?l0002?ooooo`00SOooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo033ooooo0ol0002Cooooo`00S_ooool2o`0000oooooo00?o0000ooooooooool0;?ooool4
o`0009Kooooo002@ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:?ooool4o`00
09[ooooo002Aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09?ooool4o`0009ko
oooo002Booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool4o`000:;ooooo
002Cooooo`;o00002Oooool00ol0003oooooooooo`0Mooooo`Co0000Y_ooool009Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Jooooo`?o0000Z_ooool009Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Fooooo`Co0000[Oooool009Oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Booooo`Co0000/Oooool009Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0>ooooo`Co0000]Oooool009Wooooo0_l00003ooooo`03o`000?oo
oooooooo00[ooooo1?l0002iooooo`00Voooool01?l0003oooooooooool00009ooooo`?o0000_Ooo
ool009cooooo00?o0000ooooool000001Oooool4o`000<3ooooo002Mooooo`;o000000?oooooo`00
0?l000000_l00034ooooo`00W_ooool2o`000<Sooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Z
ooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool5o`0000Cooooo1?l000000ol@413ooooooooo
o`02ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<09?ooooo002Zooooo`05oa0@4?nj
^[[ok^k^ogMgMol@41000_ooool6o`000006oooooonHV9So8B4Qonk^k_ooooooA4A41_ooool00ol0
003oooooooooo`04ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q09?ooooo002Zoooo
o`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`0:oooo
o`05o`000?ooooooooooooooool00000Toooool00:[ooooo00?o0000ooooooooool01?ooool6o`00
00?ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0:ooooo`05o`000?nHV9Sooooo
oiRHV?lQ8B40Toooool00:[ooooo00?o0000ooooooooool03_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo00[ooooo00Go0000oeEEEOl0003o410@olc<c02Cooooo`00Z?ooool00ol@
413o0000o`000003o`0000kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:oooo
o`03oeEEEOn7QhOooooo09Gooooo002Zooooo`03o`000?oooooooooo00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4006ooooo`03o`000?oooooooooo00[ooooo00?ogMgMoa0@4?nHV9P0UOooool00:[o
oooo00?o0000ooooooooool02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo00?oEEEEofIV
I_l000003Oooool01?o<c<coA4A4o`000?l@412Cooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -20 0 ]
[.5 .82364 20 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(22.4) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.655 .751 .921 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69469 Mtetra
.655 .752 .921 r
.4053 .69469 .41061 .69934 .41957 .69681 .41427 .69217 Mtetra
.655 .753 .922 r
.41427 .69217 .41957 .69681 .42855 .69428 .42327 .68964 Mtetra
.655 .754 .923 r
.42327 .68964 .42855 .69428 .43756 .69174 .4323 .68711 Mtetra
.4323 .68711 .43756 .69174 .4466 .68919 .44136 .68456 Mtetra
.655 .755 .924 r
.44136 .68456 .4466 .68919 .45567 .68663 .45046 .682 Mtetra
.655 .756 .924 r
.45046 .682 .45567 .68663 .46478 .68407 .45958 .67943 Mtetra
.45958 .67943 .46478 .68407 .47391 .68149 .46873 .67685 Mtetra
.655 .757 .925 r
.46873 .67685 .47391 .68149 .48307 .67891 .47791 .67425 Mtetra
.47791 .67425 .48307 .67891 .49227 .67632 .48713 .67164 Mtetra
.656 .757 .924 r
.48713 .67164 .49227 .67632 .50149 .67371 .49638 .66902 Mtetra
.49638 .66902 .50149 .67371 .51075 .6711 .50565 .66638 Mtetra
.656 .756 .924 r
.50565 .66638 .51075 .6711 .52004 .66849 .51496 .66372 Mtetra
.656 .755 .923 r
.51496 .66372 .52004 .66849 .52936 .66586 .5243 .66106 Mtetra
.656 .755 .922 r
.5243 .66106 .52936 .66586 .53871 .66322 .53367 .6584 Mtetra
.656 .754 .922 r
.53367 .6584 .53871 .66322 .54809 .66058 .54308 .65572 Mtetra
.54308 .65572 .54809 .66058 .55751 .65792 .55251 .65304 Mtetra
.656 .753 .921 r
.55251 .65304 .55751 .65792 .56695 .65526 .56198 .65035 Mtetra
.657 .753 .921 r
.56198 .65035 .56695 .65526 .57643 .65259 .57148 .64763 Mtetra
.658 .752 .92 r
.57148 .64763 .57643 .65259 .58595 .6499 .58102 .64488 Mtetra
.66 .751 .917 r
.58102 .64488 .58595 .6499 .59549 .64721 .59058 .64208 Mtetra
.663 .748 .913 r
.59058 .64208 .59549 .64721 .60507 .64451 .60018 .6392 Mtetra
.666 .743 .908 r
.60018 .6392 .60507 .64451 .61468 .6418 .6098 .63624 Mtetra
.669 .735 .899 r
.6098 .63624 .61468 .6418 .62432 .63908 .61946 .63319 Mtetra
.671 .724 .889 r
.61946 .63319 .62432 .63908 .634 .63636 .62915 .63006 Mtetra
.671 .712 .879 r
.62915 .63006 .634 .63636 .64371 .63362 .63886 .6269 Mtetra
.669 .699 .868 r
.63886 .6269 .64371 .63362 .65345 .63087 .64861 .62375 Mtetra
.665 .686 .86 r
.64861 .62375 .65345 .63087 .66323 .62811 .65839 .62068 Mtetra
.661 .676 .854 r
.65839 .62068 .66323 .62811 .67304 .62535 .66822 .61773 Mtetra
.655 .67 .852 r
.66822 .61773 .67304 .62535 .68289 .62257 .67808 .61494 Mtetra
.65 .668 .853 r
.67808 .61494 .68289 .62257 .69277 .61979 .68798 .61229 Mtetra
.647 .67 .859 r
.68798 .61229 .69277 .61979 .70269 .61699 .69793 .60977 Mtetra
.644 .678 .867 r
.69793 .60977 .70269 .61699 .71264 .61418 .70792 .60733 Mtetra
.644 .689 .877 r
.70792 .60733 .71264 .61418 .72262 .61137 .71795 .6049 Mtetra
.644 .702 .888 r
.71795 .6049 .72262 .61137 .73264 .60854 .72801 .60244 Mtetra
.646 .716 .899 r
.72801 .60244 .73264 .60854 .7427 .60571 .73811 .59991 Mtetra
.648 .728 .907 r
.73811 .59991 .7427 .60571 .75279 .60286 .74824 .59728 Mtetra
.65 .738 .913 r
.74824 .59728 .75279 .60286 .76291 .60001 .7584 .59457 Mtetra
.652 .745 .917 r
.7584 .59457 .76291 .60001 .77308 .59714 .76859 .59178 Mtetra
.654 .749 .92 r
.76859 .59178 .77308 .59714 .78328 .59427 .77882 .58894 Mtetra
.655 .751 .921 r
.77882 .58894 .78328 .59427 .79351 .59138 .78908 .58606 Mtetra
.655 .752 .921 r
.78908 .58606 .79351 .59138 .80378 .58849 .79938 .58316 Mtetra
.655 .753 .922 r
.79938 .58316 .80378 .58849 .81409 .58558 .80972 .58024 Mtetra
.80972 .58024 .81409 .58558 .82443 .58267 .82009 .57732 Mtetra
.655 .754 .922 r
.82009 .57732 .82443 .58267 .83482 .57974 .8305 .57439 Mtetra
.655 .754 .923 r
.8305 .57439 .83482 .57974 .84523 .5768 .84095 .57145 Mtetra
.655 .755 .924 r
.84095 .57145 .84523 .5768 .85569 .57385 .85143 .5685 Mtetra
.655 .756 .924 r
.85143 .5685 .85569 .57385 .86618 .57089 .86196 .56554 Mtetra
.86196 .56554 .86618 .57089 .87672 .56792 .87252 .56256 Mtetra
.655 .757 .925 r
.87252 .56256 .87672 .56792 .88729 .56494 .88312 .55956 Mtetra
.88312 .55956 .88729 .56494 .89789 .56195 .89375 .55655 Mtetra
.656 .757 .924 r
.89375 .55655 .89789 .56195 .90854 .55895 .90443 .55351 Mtetra
.90443 .55351 .90854 .55895 .91923 .55594 .91514 .55047 Mtetra
.656 .756 .924 r
.91514 .55047 .91923 .55594 .92995 .55292 .92589 .54741 Mtetra
.656 .756 .923 r
.92589 .54741 .92995 .55292 .94071 .54988 .93668 .54434 Mtetra
.656 .755 .923 r
.93668 .54434 .94071 .54988 .95152 .54684 .94751 .54125 Mtetra
.656 .754 .922 r
.94751 .54125 .95152 .54684 .96236 .54378 .95838 .53815 Mtetra
.656 .753 .921 r
.95838 .53815 .96236 .54378 .97324 .54071 .96929 .53504 Mtetra
.657 .753 .921 r
.96929 .53504 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.654 .751 .921 r
.391 .69252 .39636 .6972 .4053 .69469 .39996 .69002 Mtetra
.654 .752 .922 r
.39996 .69002 .4053 .69469 .41427 .69217 .40895 .6875 Mtetra
.40895 .6875 .41427 .69217 .42327 .68964 .41797 .68498 Mtetra
.654 .753 .923 r
.41797 .68498 .42327 .68964 .4323 .68711 .42702 .68244 Mtetra
.654 .754 .923 r
.42702 .68244 .4323 .68711 .44136 .68456 .43609 .6799 Mtetra
.654 .755 .924 r
.43609 .6799 .44136 .68456 .45046 .682 .44521 .67734 Mtetra
.654 .756 .924 r
.44521 .67734 .45046 .682 .45958 .67943 .45435 .67477 Mtetra
.654 .756 .925 r
.45435 .67477 .45958 .67943 .46873 .67685 .46352 .67219 Mtetra
.655 .757 .925 r
.46352 .67219 .46873 .67685 .47791 .67425 .47272 .66958 Mtetra
.47272 .66958 .47791 .67425 .48713 .67164 .48196 .66696 Mtetra
.656 .758 .925 r
.48196 .66696 .48713 .67164 .49638 .66902 .49123 .66431 Mtetra
.49123 .66431 .49638 .66902 .50565 .66638 .50052 .66165 Mtetra
.657 .757 .924 r
.50052 .66165 .50565 .66638 .51496 .66372 .50985 .65896 Mtetra
.50985 .65896 .51496 .66372 .5243 .66106 .51922 .65627 Mtetra
.657 .756 .923 r
.51922 .65627 .5243 .66106 .53367 .6584 .52861 .65356 Mtetra
.657 .755 .922 r
.52861 .65356 .53367 .6584 .54308 .65572 .53803 .65085 Mtetra
.657 .754 .922 r
.53803 .65085 .54308 .65572 .55251 .65304 .54749 .64813 Mtetra
.657 .754 .921 r
.54749 .64813 .55251 .65304 .56198 .65035 .55698 .6454 Mtetra
.658 .753 .92 r
.55698 .6454 .56198 .65035 .57148 .64763 .5665 .64264 Mtetra
.66 .752 .918 r
.5665 .64264 .57148 .64763 .58102 .64488 .57606 .63981 Mtetra
.664 .751 .915 r
.57606 .63981 .58102 .64488 .59058 .64208 .58564 .63689 Mtetra
.669 .749 .91 r
.58564 .63689 .59058 .64208 .60018 .6392 .59526 .63383 Mtetra
.675 .744 .903 r
.59526 .63383 .60018 .6392 .6098 .63624 .6049 .6306 Mtetra
.68 .737 .893 r
.6049 .6306 .6098 .63624 .61946 .63319 .61457 .62721 Mtetra
.684 .727 .882 r
.61457 .62721 .61946 .63319 .62915 .63006 .62426 .62367 Mtetra
.684 .714 .871 r
.62426 .62367 .62915 .63006 .63886 .6269 .63399 .62007 Mtetra
.681 .7 .861 r
.63399 .62007 .63886 .6269 .64861 .62375 .64374 .6165 Mtetra
.674 .687 .854 r
.64374 .6165 .64861 .62375 .65839 .62068 .65353 .6131 Mtetra
.665 .675 .849 r
.65353 .6131 .65839 .62068 .66822 .61773 .66336 .60995 Mtetra
.655 .666 .849 r
.66336 .60995 .66822 .61773 .67808 .61494 .67324 .60714 Mtetra
.645 .662 .852 r
.67324 .60714 .67808 .61494 .68798 .61229 .68317 .60465 Mtetra
.637 .663 .859 r
.68317 .60465 .68798 .61229 .69793 .60977 .69315 .60242 Mtetra
.631 .669 .868 r
.69315 .60242 .69793 .60977 .70792 .60733 .70317 .60036 Mtetra
.629 .68 .88 r
.70317 .60036 .70792 .60733 .71795 .6049 .71324 .59833 Mtetra
.63 .694 .891 r
.71324 .59833 .71795 .6049 .72801 .60244 .72335 .59625 Mtetra
.634 .709 .901 r
.72335 .59625 .72801 .60244 .73811 .59991 .73349 .59402 Mtetra
.639 .723 .909 r
.73349 .59402 .73811 .59991 .74824 .59728 .74366 .59163 Mtetra
.644 .734 .914 r
.74366 .59163 .74824 .59728 .7584 .59457 .75385 .58907 Mtetra
.648 .742 .918 r
.75385 .58907 .7584 .59457 .76859 .59178 .76408 .58636 Mtetra
.652 .747 .92 r
.76408 .58636 .76859 .59178 .77882 .58894 .77434 .58356 Mtetra
.654 .75 .921 r
.77434 .58356 .77882 .58894 .78908 .58606 .78463 .5807 Mtetra
.654 .752 .922 r
.78463 .5807 .78908 .58606 .79938 .58316 .79496 .5778 Mtetra
.654 .753 .922 r
.79496 .5778 .79938 .58316 .80972 .58024 .80532 .57488 Mtetra
.654 .754 .923 r
.80532 .57488 .80972 .58024 .82009 .57732 .81572 .57196 Mtetra
.81572 .57196 .82009 .57732 .8305 .57439 .82616 .56903 Mtetra
.654 .755 .924 r
.82616 .56903 .8305 .57439 .84095 .57145 .83663 .56609 Mtetra
.654 .756 .925 r
.83663 .56609 .84095 .57145 .85143 .5685 .84715 .56314 Mtetra
.654 .757 .925 r
.84715 .56314 .85143 .5685 .86196 .56554 .8577 .56016 Mtetra
.655 .757 .925 r
.8577 .56016 .86196 .56554 .87252 .56256 .86829 .55717 Mtetra
.655 .758 .925 r
.86829 .55717 .87252 .56256 .88312 .55956 .87892 .55415 Mtetra
.656 .758 .925 r
.87892 .55415 .88312 .55956 .89375 .55655 .88958 .55111 Mtetra
.656 .757 .924 r
.88958 .55111 .89375 .55655 .90443 .55351 .90028 .54804 Mtetra
.90028 .54804 .90443 .55351 .91514 .55047 .91102 .54496 Mtetra
.657 .756 .923 r
.91102 .54496 .91514 .55047 .92589 .54741 .9218 .54186 Mtetra
.9218 .54186 .92589 .54741 .93668 .54434 .93262 .53875 Mtetra
.657 .755 .922 r
.93262 .53875 .93668 .54434 .94751 .54125 .94347 .53562 Mtetra
.657 .754 .922 r
.94347 .53562 .94751 .54125 .95838 .53815 .95437 .53248 Mtetra
.657 .754 .921 r
.95437 .53248 .95838 .53815 .96929 .53504 .96531 .52933 Mtetra
.657 .753 .92 r
.96531 .52933 .96929 .53504 .98024 .53192 .97628 .52616 Mtetra
.653 .751 .921 r
.38561 .68781 .391 .69252 .39996 .69002 .39458 .68531 Mtetra
.653 .751 .922 r
.39458 .68531 .39996 .69002 .40895 .6875 .40359 .68279 Mtetra
.653 .752 .922 r
.40359 .68279 .40895 .6875 .41797 .68498 .41263 .68027 Mtetra
.653 .753 .923 r
.41263 .68027 .41797 .68498 .42702 .68244 .42169 .67774 Mtetra
.42169 .67774 .42702 .68244 .43609 .6799 .43079 .6752 Mtetra
.653 .754 .924 r
.43079 .6752 .43609 .6799 .44521 .67734 .43992 .67264 Mtetra
.653 .755 .924 r
.43992 .67264 .44521 .67734 .45435 .67477 .44908 .67008 Mtetra
.654 .756 .925 r
.44908 .67008 .45435 .67477 .46352 .67219 .45828 .66749 Mtetra
.654 .757 .925 r
.45828 .66749 .46352 .67219 .47272 .66958 .4675 .66489 Mtetra
.655 .758 .925 r
.4675 .66489 .47272 .66958 .48196 .66696 .47676 .66226 Mtetra
.47676 .66226 .48196 .66696 .49123 .66431 .48604 .6596 Mtetra
.656 .759 .925 r
.48604 .6596 .49123 .66431 .50052 .66165 .49536 .65692 Mtetra
.657 .759 .925 r
.49536 .65692 .50052 .66165 .50985 .65896 .50471 .65421 Mtetra
.50471 .65421 .50985 .65896 .51922 .65627 .5141 .65149 Mtetra
.658 .758 .924 r
.5141 .65149 .51922 .65627 .52861 .65356 .52351 .64874 Mtetra
.658 .757 .923 r
.52351 .64874 .52861 .65356 .53803 .65085 .53296 .64598 Mtetra
.658 .756 .922 r
.53296 .64598 .53803 .65085 .54749 .64813 .54244 .64321 Mtetra
.659 .755 .921 r
.54244 .64321 .54749 .64813 .55698 .6454 .55195 .64042 Mtetra
.66 .754 .919 r
.55195 .64042 .55698 .6454 .5665 .64264 .56149 .63758 Mtetra
.664 .752 .916 r
.56149 .63758 .5665 .64264 .57606 .63981 .57107 .63465 Mtetra
.669 .751 .912 r
.57107 .63465 .57606 .63981 .58564 .63689 .58067 .63159 Mtetra
.676 .748 .905 r
.58067 .63159 .58564 .63689 .59526 .63383 .5903 .62833 Mtetra
.684 .744 .896 r
.5903 .62833 .59526 .63383 .6049 .6306 .59996 .62484 Mtetra
.691 .737 .886 r
.59996 .62484 .6049 .6306 .61457 .62721 .60964 .62109 Mtetra
.696 .727 .874 r
.60964 .62109 .61457 .62721 .62426 .62367 .61935 .61714 Mtetra
.696 .715 .863 r
.61935 .61714 .62426 .62367 .63399 .62007 .62908 .61309 Mtetra
.692 .701 .854 r
.62908 .61309 .63399 .62007 .64374 .6165 .63884 .6091 Mtetra
.682 .687 .848 r
.63884 .6091 .64374 .6165 .65353 .6131 .64863 .60536 Mtetra
.67 .674 .845 r
.64863 .60536 .65353 .6131 .66336 .60995 .65848 .60201 Mtetra
.655 .663 .846 r
.65848 .60201 .66336 .60995 .67324 .60714 .66837 .59918 Mtetra
.639 .657 .851 r
.66837 .59918 .67324 .60714 .68317 .60465 .67832 .59685 Mtetra
.626 .656 .859 r
.67832 .59685 .68317 .60465 .69315 .60242 .68833 .59491 Mtetra
.617 .66 .87 r
.68833 .59491 .69315 .60242 .70317 .60036 .6984 .59325 Mtetra
.614 .671 .881 r
.6984 .59325 .70317 .60036 .71324 .59833 .70851 .59163 Mtetra
.615 .685 .892 r
.70851 .59163 .71324 .59833 .72335 .59625 .71865 .58993 Mtetra
.621 .701 .902 r
.71865 .58993 .72335 .59625 .73349 .59402 .72883 .58801 Mtetra
.629 .715 .909 r
.72883 .58801 .73349 .59402 .74366 .59163 .73904 .58585 Mtetra
.637 .728 .914 r
.73904 .58585 .74366 .59163 .75385 .58907 .74927 .58345 Mtetra
.644 .737 .917 r
.74927 .58345 .75385 .58907 .76408 .58636 .75953 .58085 Mtetra
.648 .744 .919 r
.75953 .58085 .76408 .58636 .77434 .58356 .76982 .57812 Mtetra
.651 .748 .921 r
.76982 .57812 .77434 .58356 .78463 .5807 .78014 .57529 Mtetra
.652 .751 .922 r
.78014 .57529 .78463 .5807 .79496 .5778 .7905 .57242 Mtetra
.653 .753 .923 r
.7905 .57242 .79496 .5778 .80532 .57488 .80089 .56952 Mtetra
.653 .754 .924 r
.80089 .56952 .80532 .57488 .81572 .57196 .81132 .56661 Mtetra
.653 .756 .925 r
.81132 .56661 .81572 .57196 .82616 .56903 .82179 .56369 Mtetra
.653 .757 .926 r
.82179 .56369 .82616 .56903 .83663 .56609 .8323 .56075 Mtetra
.8323 .56075 .83663 .56609 .84715 .56314 .84284 .55778 Mtetra
.654 .758 .926 r
.84284 .55778 .84715 .56314 .8577 .56016 .85342 .55478 Mtetra
.655 .758 .926 r
.85342 .55478 .8577 .56016 .86829 .55717 .86404 .55176 Mtetra
.656 .758 .925 r
.86404 .55176 .86829 .55717 .87892 .55415 .87469 .54871 Mtetra
.87469 .54871 .87892 .55415 .88958 .55111 .88538 .54563 Mtetra
.657 .758 .924 r
.88538 .54563 .88958 .55111 .90028 .54804 .89611 .54253 Mtetra
.657 .757 .924 r
.89611 .54253 .90028 .54804 .91102 .54496 .90688 .5394 Mtetra
.657 .756 .923 r
.90688 .5394 .91102 .54496 .9218 .54186 .91768 .53626 Mtetra
.658 .756 .922 r
.91768 .53626 .9218 .54186 .93262 .53875 .92853 .53311 Mtetra
.658 .755 .922 r
.92853 .53311 .93262 .53875 .94347 .53562 .93941 .52994 Mtetra
.658 .754 .921 r
.93941 .52994 .94347 .53562 .95437 .53248 .95033 .52676 Mtetra
.95033 .52676 .95437 .53248 .96531 .52933 .9613 .52357 Mtetra
.658 .753 .92 r
.9613 .52357 .96531 .52933 .97628 .52616 .9723 .52037 Mtetra
.653 .751 .921 r
.38018 .68308 .38561 .68781 .39458 .68531 .38917 .68056 Mtetra
.653 .751 .922 r
.38917 .68056 .39458 .68531 .40359 .68279 .3982 .67805 Mtetra
.653 .752 .922 r
.3982 .67805 .40359 .68279 .41263 .68027 .40725 .67552 Mtetra
.652 .752 .923 r
.40725 .67552 .41263 .68027 .42169 .67774 .41634 .67299 Mtetra
.652 .753 .923 r
.41634 .67299 .42169 .67774 .43079 .6752 .42546 .67045 Mtetra
.652 .753 .924 r
.42546 .67045 .43079 .6752 .43992 .67264 .43461 .6679 Mtetra
.652 .754 .924 r
.43461 .6679 .43992 .67264 .44908 .67008 .44379 .66534 Mtetra
.652 .755 .925 r
.44379 .66534 .44908 .67008 .45828 .66749 .453 .66276 Mtetra
.653 .756 .925 r
.453 .66276 .45828 .66749 .4675 .66489 .46224 .66017 Mtetra
.653 .757 .926 r
.46224 .66017 .4675 .66489 .47676 .66226 .47152 .65755 Mtetra
.654 .759 .926 r
.47152 .65755 .47676 .66226 .48604 .6596 .48083 .6549 Mtetra
.655 .76 .927 r
.48083 .6549 .48604 .6596 .49536 .65692 .49017 .65221 Mtetra
.656 .761 .927 r
.49017 .65221 .49536 .65692 .50471 .65421 .49954 .64949 Mtetra
.657 .761 .926 r
.49954 .64949 .50471 .65421 .5141 .65149 .50894 .64674 Mtetra
.659 .761 .926 r
.50894 .64674 .5141 .65149 .52351 .64874 .51838 .64395 Mtetra
.66 .76 .924 r
.51838 .64395 .52351 .64874 .53296 .64598 .52785 .64113 Mtetra
.66 .759 .923 r
.52785 .64113 .53296 .64598 .54244 .64321 .53735 .63828 Mtetra
.662 .757 .92 r
.53735 .63828 .54244 .64321 .55195 .64042 .54688 .63539 Mtetra
.664 .754 .917 r
.54688 .63539 .55195 .64042 .56149 .63758 .55645 .63244 Mtetra
.669 .752 .913 r
.55645 .63244 .56149 .63758 .57107 .63465 .56604 .62938 Mtetra
.675 .749 .907 r
.56604 .62938 .57107 .63465 .58067 .63159 .57567 .62615 Mtetra
.683 .746 .899 r
.57567 .62615 .58067 .63159 .5903 .62833 .58532 .62267 Mtetra
.692 .741 .889 r
.58532 .62267 .5903 .62833 .59996 .62484 .59499 .6189 Mtetra
.701 .735 .877 r
.59499 .6189 .59996 .62484 .60964 .62109 .60469 .61481 Mtetra
.706 .726 .866 r
.60469 .61481 .60964 .62109 .61935 .61714 .61441 .61044 Mtetra
.707 .715 .855 r
.61441 .61044 .61935 .61714 .62908 .61309 .62414 .60596 Mtetra
.702 .701 .846 r
.62414 .60596 .62908 .61309 .63884 .6091 .63391 .60153 Mtetra
.69 .686 .842 r
.63391 .60153 .63884 .6091 .64863 .60536 .64371 .59746 Mtetra
.674 .672 .84 r
.64371 .59746 .64863 .60536 .65848 .60201 .65356 .59391 Mtetra
.654 .66 .843 r
.65356 .59391 .65848 .60201 .66837 .59918 .66347 .59105 Mtetra
.634 .651 .85 r
.66347 .59105 .66837 .59918 .67832 .59685 .67345 .58888 Mtetra
.616 .648 .859 r
.67345 .58888 .67832 .59685 .68833 .59491 .68348 .58725 Mtetra
.603 .65 .87 r
.68348 .58725 .68833 .59491 .6984 .59325 .69358 .58597 Mtetra
.598 .66 .881 r
.69358 .58597 .6984 .59325 .70851 .59163 .70373 .58475 Mtetra
.6 .674 .892 r
.70373 .58475 .70851 .59163 .71865 .58993 .71392 .58343 Mtetra
.608 .691 .901 r
.71392 .58343 .71865 .58993 .72883 .58801 .72414 .58182 Mtetra
.619 .706 .908 r
.72414 .58182 .72883 .58801 .73904 .58585 .73439 .57991 Mtetra
.629 .72 .912 r
.73439 .57991 .73904 .58585 .74927 .58345 .74466 .57769 Mtetra
.638 .731 .915 r
.74466 .57769 .74927 .58345 .75953 .58085 .75495 .57523 Mtetra
.644 .739 .918 r
.75495 .57523 .75953 .58085 .76982 .57812 .76527 .57259 Mtetra
.648 .745 .921 r
.76527 .57259 .76982 .57812 .78014 .57529 .77563 .56985 Mtetra
.649 .75 .923 r
.77563 .56985 .78014 .57529 .7905 .57242 .78602 .56703 Mtetra
.65 .753 .925 r
.78602 .56703 .7905 .57242 .80089 .56952 .79644 .56418 Mtetra
.651 .756 .926 r
.79644 .56418 .80089 .56952 .81132 .56661 .8069 .56129 Mtetra
.651 .758 .927 r
.8069 .56129 .81132 .56661 .82179 .56369 .8174 .55837 Mtetra
.652 .759 .928 r
.8174 .55837 .82179 .56369 .8323 .56075 .82793 .55542 Mtetra
.653 .76 .928 r
.82793 .55542 .8323 .56075 .84284 .55778 .83851 .55243 Mtetra
.654 .76 .927 r
.83851 .55243 .84284 .55778 .85342 .55478 .84911 .5494 Mtetra
.655 .76 .927 r
.84911 .5494 .85342 .55478 .86404 .55176 .85976 .54633 Mtetra
.656 .759 .926 r
.85976 .54633 .86404 .55176 .87469 .54871 .87044 .54323 Mtetra
.657 .759 .925 r
.87044 .54323 .87469 .54871 .88538 .54563 .88115 .54011 Mtetra
.658 .758 .924 r
.88115 .54011 .88538 .54563 .89611 .54253 .89191 .53696 Mtetra
.658 .757 .923 r
.89191 .53696 .89611 .54253 .90688 .5394 .9027 .53379 Mtetra
.658 .756 .922 r
.9027 .53379 .90688 .5394 .91768 .53626 .91353 .53061 Mtetra
.658 .755 .922 r
.91353 .53061 .91768 .53626 .92853 .53311 .92441 .52741 Mtetra
.658 .755 .921 r
.92441 .52741 .92853 .53311 .93941 .52994 .93532 .52421 Mtetra
.658 .754 .921 r
.93532 .52421 .93941 .52994 .95033 .52676 .94627 .521 Mtetra
.658 .753 .92 r
.94627 .521 .95033 .52676 .9613 .52357 .95726 .51777 Mtetra
.95726 .51777 .9613 .52357 .9723 .52037 .96829 .51454 Mtetra
.653 .751 .922 r
.37472 .67831 .38018 .68308 .38917 .68056 .38373 .67579 Mtetra
.38373 .67579 .38917 .68056 .3982 .67805 .39277 .67326 Mtetra
.652 .751 .922 r
.39277 .67326 .3982 .67805 .40725 .67552 .40185 .67072 Mtetra
.40185 .67072 .40725 .67552 .41634 .67299 .41095 .66818 Mtetra
.652 .751 .923 r
.41095 .66818 .41634 .67299 .42546 .67045 .42009 .66564 Mtetra
.651 .752 .923 r
.42009 .66564 .42546 .67045 .43461 .6679 .42926 .6631 Mtetra
.651 .753 .924 r
.42926 .6631 .43461 .6679 .44379 .66534 .43846 .66055 Mtetra
.651 .754 .925 r
.43846 .66055 .44379 .66534 .453 .66276 .44769 .65799 Mtetra
.651 .755 .926 r
.44769 .65799 .453 .66276 .46224 .66017 .45695 .65542 Mtetra
.652 .757 .927 r
.45695 .65542 .46224 .66017 .47152 .65755 .46625 .65282 Mtetra
.652 .759 .928 r
.46625 .65282 .47152 .65755 .48083 .6549 .47558 .6502 Mtetra
.654 .761 .928 r
.47558 .6502 .48083 .6549 .49017 .65221 .48494 .64753 Mtetra
.655 .763 .929 r
.48494 .64753 .49017 .65221 .49954 .64949 .49433 .64481 Mtetra
.657 .764 .929 r
.49433 .64481 .49954 .64949 .50894 .64674 .50376 .64204 Mtetra
.659 .765 .928 r
.50376 .64204 .50894 .64674 .51838 .64395 .51322 .63921 Mtetra
.662 .764 .926 r
.51322 .63921 .51838 .64395 .52785 .64113 .52271 .63631 Mtetra
.664 .763 .923 r
.52271 .63631 .52785 .64113 .53735 .63828 .53223 .63336 Mtetra
.667 .76 .919 r
.53223 .63336 .53735 .63828 .54688 .63539 .54178 .63033 Mtetra
.67 .756 .915 r
.54178 .63033 .54688 .63539 .55645 .63244 .55137 .62721 Mtetra
.675 .751 .908 r
.55137 .62721 .55645 .63244 .56604 .62938 .56099 .62395 Mtetra
.682 .747 .9 r
.56099 .62395 .56604 .62938 .57567 .62615 .57063 .62051 Mtetra
.69 .742 .891 r
.57063 .62051 .57567 .62615 .58532 .62267 .5803 .61679 Mtetra
.7 .737 .88 r
.5803 .61679 .58532 .62267 .59499 .6189 .58999 .61273 Mtetra
.709 .731 .868 r
.58999 .61273 .59499 .6189 .60469 .61481 .5997 .60829 Mtetra
.715 .723 .856 r
.5997 .60829 .60469 .61481 .61441 .61044 .60943 .60353 Mtetra
.716 .712 .846 r
.60943 .60353 .61441 .61044 .62414 .60596 .61918 .59861 Mtetra
.711 .7 .838 r
.61918 .59861 .62414 .60596 .63391 .60153 .62895 .59376 Mtetra
.697 .685 .834 r
.62895 .59376 .63391 .60153 .64371 .59746 .63876 .58935 Mtetra
.678 .67 .835 r
.63876 .58935 .64371 .59746 .65356 .59391 .64862 .5856 Mtetra
.654 .655 .839 r
.64862 .5856 .65356 .59391 .66347 .59105 .65854 .58272 Mtetra
.628 .644 .847 r
.65854 .58272 .66347 .59105 .67345 .58888 .66854 .58071 Mtetra
.606 .639 .857 r
.66854 .58071 .67345 .58888 .68348 .58725 .67861 .57937 Mtetra
.588 .639 .869 r
.67861 .57937 .68348 .58725 .69358 .58597 .68874 .57848 Mtetra
.583 .648 .88 r
.68874 .57848 .69358 .58597 .70373 .58475 .69893 .57766 Mtetra
.586 .662 .891 r
.69893 .57766 .70373 .58475 .71392 .58343 .70915 .57669 Mtetra
.596 .679 .899 r
.70915 .57669 .71392 .58343 .72414 .58182 .71941 .5754 Mtetra
.609 .696 .905 r
.71941 .5754 .72414 .58182 .73439 .57991 .72969 .57373 Mtetra
.621 .71 .909 r
.72969 .57373 .73439 .57991 .74466 .57769 .74 .57173 Mtetra
.631 .722 .913 r
.74 .57173 .74466 .57769 .75495 .57523 .75033 .56944 Mtetra
.637 .732 .917 r
.75033 .56944 .75495 .57523 .76527 .57259 .76069 .56697 Mtetra
.642 .74 .92 r
.76069 .56697 .76527 .57259 .77563 .56985 .77108 .56435 Mtetra
.644 .747 .924 r
.77108 .56435 .77563 .56985 .78602 .56703 .7815 .56164 Mtetra
.646 .753 .927 r
.7815 .56164 .78602 .56703 .79644 .56418 .79196 .55886 Mtetra
.648 .757 .929 r
.79196 .55886 .79644 .56418 .8069 .56129 .80246 .55602 Mtetra
.65 .761 .93 r
.80246 .55602 .8069 .56129 .8174 .55837 .81299 .55311 Mtetra
.652 .762 .93 r
.81299 .55311 .8174 .55837 .82793 .55542 .82355 .55013 Mtetra
.654 .763 .93 r
.82355 .55013 .82793 .55542 .83851 .55243 .83415 .5471 Mtetra
.656 .763 .929 r
.83415 .5471 .83851 .55243 .84911 .5494 .84478 .54402 Mtetra
.657 .762 .927 r
.84478 .54402 .84911 .5494 .85976 .54633 .85545 .54089 Mtetra
.658 .761 .926 r
.85545 .54089 .85976 .54633 .87044 .54323 .86615 .53773 Mtetra
.659 .759 .924 r
.86615 .53773 .87044 .54323 .88115 .54011 .87689 .53454 Mtetra
.659 .758 .923 r
.87689 .53454 .88115 .54011 .89191 .53696 .88767 .53133 Mtetra
.659 .757 .922 r
.88767 .53133 .89191 .53696 .9027 .53379 .89849 .52811 Mtetra
.659 .755 .921 r
.89849 .52811 .9027 .53379 .91353 .53061 .90935 .52489 Mtetra
.659 .754 .921 r
.90935 .52489 .91353 .53061 .92441 .52741 .92025 .52166 Mtetra
.659 .754 .92 r
.92025 .52166 .92441 .52741 .93532 .52421 .93119 .51842 Mtetra
.659 .753 .92 r
.93119 .51842 .93532 .52421 .94627 .521 .94217 .51518 Mtetra
.94217 .51518 .94627 .521 .95726 .51777 .9532 .51192 Mtetra
.9532 .51192 .95726 .51777 .96829 .51454 .96426 .50866 Mtetra
.653 .751 .922 r
.36922 .67351 .37472 .67831 .38373 .67579 .37825 .67097 Mtetra
.653 .75 .921 r
.37825 .67097 .38373 .67579 .39277 .67326 .38732 .66842 Mtetra
.652 .75 .922 r
.38732 .66842 .39277 .67326 .40185 .67072 .39641 .66587 Mtetra
.39641 .66587 .40185 .67072 .41095 .66818 .40553 .66332 Mtetra
.651 .75 .922 r
.40553 .66332 .41095 .66818 .42009 .66564 .41469 .66077 Mtetra
.651 .751 .923 r
.41469 .66077 .42009 .66564 .42926 .6631 .42388 .65823 Mtetra
.65 .751 .923 r
.42388 .65823 .42926 .6631 .43846 .66055 .43309 .65569 Mtetra
.65 .752 .924 r
.43309 .65569 .43846 .66055 .44769 .65799 .44234 .65316 Mtetra
.649 .753 .926 r
.44234 .65316 .44769 .65799 .45695 .65542 .45163 .65062 Mtetra
.649 .755 .927 r
.45163 .65062 .45695 .65542 .46625 .65282 .46094 .64806 Mtetra
.65 .758 .928 r
.46094 .64806 .46625 .65282 .47558 .6502 .47029 .64548 Mtetra
.651 .761 .93 r
.47029 .64548 .47558 .6502 .48494 .64753 .47967 .64285 Mtetra
.653 .764 .93 r
.47967 .64285 .48494 .64753 .49433 .64481 .48909 .64016 Mtetra
.656 .766 .931 r
.48909 .64016 .49433 .64481 .50376 .64204 .49854 .63739 Mtetra
.66 .768 .93 r
.49854 .63739 .50376 .64204 .51322 .63921 .50802 .63452 Mtetra
.664 .768 .927 r
.50802 .63452 .51322 .63921 .52271 .63631 .51753 .63154 Mtetra
.669 .767 .923 r
.51753 .63154 .52271 .63631 .53223 .63336 .52708 .62845 Mtetra
.674 .763 .918 r
.52708 .62845 .53223 .63336 .54178 .63033 .53665 .62523 Mtetra
.679 .758 .911 r
.53665 .62523 .54178 .63033 .55137 .62721 .54626 .62188 Mtetra
.684 .751 .902 r
.54626 .62188 .55137 .62721 .56099 .62395 .5559 .61837 Mtetra
.69 .744 .893 r
.5559 .61837 .56099 .62395 .57063 .62051 .56556 .61466 Mtetra
.698 .738 .882 r
.56556 .61466 .57063 .62051 .5803 .61679 .57525 .61065 Mtetra
.706 .732 .871 r
.57525 .61065 .5803 .61679 .58999 .61273 .58496 .60631 Mtetra
.715 .726 .859 r
.58496 .60631 .58999 .61273 .5997 .60829 .59468 .60156 Mtetra
.722 .72 .848 r
.59468 .60156 .5997 .60829 .60943 .60353 .60442 .59644 Mtetra
.723 .711 .839 r
.60442 .59644 .60943 .60353 .61918 .59861 .61418 .59115 Mtetra
.718 .7 .832 r
.61418 .59115 .61918 .59861 .62895 .59376 .62396 .58592 Mtetra
.704 .686 .831 r
.62396 .58592 .62895 .59376 .63876 .58935 .63378 .5812 Mtetra
.682 .672 .833 r
.63378 .5812 .63876 .58935 .64862 .5856 .64365 .57726 Mtetra
.654 .656 .84 r
.64365 .57726 .64862 .5856 .65854 .58272 .65359 .57436 Mtetra
.622 .642 .849 r
.65359 .57436 .65854 .58272 .66854 .58071 .66361 .5725 Mtetra
.596 .634 .859 r
.66361 .5725 .66854 .58071 .67861 .57937 .6737 .57143 Mtetra
.575 .632 .871 r
.6737 .57143 .67861 .57937 .68874 .57848 .68387 .57087 Mtetra
.569 .64 .881 r
.68387 .57087 .68874 .57848 .69893 .57766 .69409 .57039 Mtetra
.573 .652 .889 r
.69409 .57039 .69893 .57766 .70915 .57669 .70435 .56974 Mtetra
.585 .668 .896 r
.70435 .56974 .70915 .57669 .71941 .5754 .71464 .56872 Mtetra
.6 .684 .901 r
.71464 .56872 .71941 .5754 .72969 .57373 .72496 .5673 Mtetra
.612 .698 .906 r
.72496 .5673 .72969 .57373 .74 .57173 .7353 .56554 Mtetra
.622 .712 .91 r
.7353 .56554 .74 .57173 .75033 .56944 .74567 .56349 Mtetra
.628 .724 .916 r
.74567 .56349 .75033 .56944 .76069 .56697 .75607 .56124 Mtetra
.633 .735 .921 r
.75607 .56124 .76069 .56697 .77108 .56435 .7665 .55882 Mtetra
.637 .745 .926 r
.7665 .55882 .77108 .56435 .7815 .56164 .77697 .55626 Mtetra
.641 .753 .93 r
.77697 .55626 .7815 .56164 .79196 .55886 .78746 .55359 Mtetra
.645 .759 .932 r
.78746 .55359 .79196 .55886 .80246 .55602 .79799 .55079 Mtetra
.648 .763 .933 r
.79799 .55079 .80246 .55602 .81299 .55311 .80855 .54788 Mtetra
.652 .766 .932 r
.80855 .54788 .81299 .55311 .82355 .55013 .81914 .54487 Mtetra
.655 .766 .931 r
.81914 .54487 .82355 .55013 .83415 .5471 .82976 .54177 Mtetra
.658 .765 .929 r
.82976 .54177 .83415 .5471 .84478 .54402 .84042 .53861 Mtetra
.659 .763 .927 r
.84042 .53861 .84478 .54402 .85545 .54089 .85111 .5354 Mtetra
.66 .761 .925 r
.85111 .5354 .85545 .54089 .86615 .53773 .86184 .53215 Mtetra
.661 .759 .923 r
.86184 .53215 .86615 .53773 .87689 .53454 .8726 .52889 Mtetra
.661 .757 .922 r
.8726 .52889 .87689 .53454 .88767 .53133 .88341 .52563 Mtetra
.661 .756 .92 r
.88341 .52563 .88767 .53133 .89849 .52811 .89425 .52236 Mtetra
.66 .754 .92 r
.89425 .52236 .89849 .52811 .90935 .52489 .90514 .51909 Mtetra
.66 .753 .919 r
.90514 .51909 .90935 .52489 .92025 .52166 .91607 .51583 Mtetra
.659 .753 .919 r
.91607 .51583 .92025 .52166 .93119 .51842 .92704 .51257 Mtetra
.659 .752 .919 r
.92704 .51257 .93119 .51842 .94217 .51518 .93805 .5093 Mtetra
.93805 .5093 .94217 .51518 .9532 .51192 .9491 .50603 Mtetra
.658 .752 .919 r
.9491 .50603 .9532 .51192 .96426 .50866 .9602 .50275 Mtetra
.653 .751 .921 r
.36369 .66869 .36922 .67351 .37825 .67097 .37274 .66612 Mtetra
.653 .75 .921 r
.37274 .66612 .37825 .67097 .38732 .66842 .38183 .66354 Mtetra
.38183 .66354 .38732 .66842 .39641 .66587 .39094 .66096 Mtetra
.652 .749 .921 r
.39094 .66096 .39641 .66587 .40553 .66332 .40008 .65839 Mtetra
.651 .749 .921 r
.40008 .65839 .40553 .66332 .41469 .66077 .40926 .65583 Mtetra
.65 .749 .922 r
.40926 .65583 .41469 .66077 .42388 .65823 .41846 .65329 Mtetra
.649 .749 .922 r
.41846 .65329 .42388 .65823 .43309 .65569 .4277 .65076 Mtetra
.648 .75 .924 r
.4277 .65076 .43309 .65569 .44234 .65316 .43697 .64824 Mtetra
.647 .751 .925 r
.43697 .64824 .44234 .65316 .45163 .65062 .44627 .64574 Mtetra
.646 .753 .927 r
.44627 .64574 .45163 .65062 .46094 .64806 .4556 .64324 Mtetra
.646 .756 .929 r
.4556 .64324 .46094 .64806 .47029 .64548 .46497 .64072 Mtetra
.647 .759 .931 r
.46497 .64072 .47029 .64548 .47967 .64285 .47437 .63816 Mtetra
.65 .764 .932 r
.47437 .63816 .47967 .64285 .48909 .64016 .48381 .63553 Mtetra
.654 .768 .933 r
.48381 .63553 .48909 .64016 .49854 .63739 .49328 .63278 Mtetra
.66 .771 .932 r
.49328 .63278 .49854 .63739 .50802 .63452 .50278 .62989 Mtetra
.667 .773 .929 r
.50278 .62989 .50802 .63452 .51753 .63154 .51232 .62682 Mtetra
.675 .772 .923 r
.51232 .62682 .51753 .63154 .52708 .62845 .52189 .62356 Mtetra
.682 .768 .916 r
.52189 .62356 .52708 .62845 .53665 .62523 .53149 .6201 Mtetra
.689 .761 .906 r
.53149 .6201 .53665 .62523 .54626 .62188 .54112 .61645 Mtetra
.695 .752 .895 r
.54112 .61645 .54626 .62188 .5559 .61837 .55077 .6126 Mtetra
.7 .742 .884 r
.55077 .6126 .5559 .61837 .56556 .61466 .56045 .60854 Mtetra
.706 .733 .872 r
.56045 .60854 .56556 .61466 .57525 .61065 .57016 .60422 Mtetra
.712 .725 .861 r
.57016 .60422 .57525 .61065 .58496 .60631 .57989 .59959 Mtetra
.72 .72 .85 r
.57989 .59959 .58496 .60631 .59468 .60156 .58963 .59457 Mtetra
.726 .715 .84 r
.58963 .59457 .59468 .60156 .60442 .59644 .59939 .58919 Mtetra
.728 .709 .833 r
.59939 .58919 .60442 .59644 .61418 .59115 .60916 .5836 Mtetra
.724 .701 .828 r
.60916 .5836 .61418 .59115 .62396 .58592 .61895 .57806 Mtetra
.709 .689 .829 r
.61895 .57806 .62396 .58592 .63378 .5812 .62878 .57308 Mtetra
.686 .675 .833 r
.62878 .57308 .63378 .5812 .64365 .57726 .63866 .56897 Mtetra
.654 .658 .842 r
.63866 .56897 .64365 .57726 .65359 .57436 .64862 .56605 Mtetra
.618 .642 .852 r
.64862 .56605 .65359 .57436 .66361 .5725 .65865 .56431 Mtetra
.587 .632 .863 r
.65865 .56431 .66361 .5725 .6737 .57143 .66877 .56346 Mtetra
.563 .627 .873 r
.66877 .56346 .6737 .57143 .68387 .57087 .67896 .56317 Mtetra
.558 .633 .881 r
.67896 .56317 .68387 .57087 .69409 .57039 .68921 .56294 Mtetra
.564 .644 .888 r
.68921 .56294 .69409 .57039 .70435 .56974 .6995 .56253 Mtetra
.577 .657 .892 r
.6995 .56253 .70435 .56974 .71464 .56872 .70983 .56174 Mtetra
.591 .672 .896 r
.70983 .56174 .71464 .56872 .72496 .5673 .72018 .56057 Mtetra
.601 .685 .901 r
.72018 .56057 .72496 .5673 .7353 .56554 .73056 .55909 Mtetra
.61 .699 .907 r
.73056 .55909 .7353 .56554 .74567 .56349 .74097 .55735 Mtetra
.616 .713 .915 r
.74097 .55735 .74567 .56349 .75607 .56124 .75142 .5554 Mtetra
.621 .727 .922 r
.75142 .5554 .75607 .56124 .7665 .55882 .7619 .55325 Mtetra
.627 .741 .929 r
.7619 .55325 .7665 .55882 .77697 .55626 .7724 .55091 Mtetra
.634 .752 .934 r
.7724 .55091 .77697 .55626 .78746 .55359 .78294 .54836 Mtetra
.641 .761 .936 r
.78294 .54836 .78746 .55359 .79799 .55079 .7935 .54562 Mtetra
.648 .767 .936 r
.7935 .54562 .79799 .55079 .80855 .54788 .80409 .5427 Mtetra
.653 .769 .934 r
.80409 .5427 .80855 .54788 .81914 .54487 .8147 .53962 Mtetra
.658 .769 .932 r
.8147 .53962 .81914 .54487 .82976 .54177 .82535 .53643 Mtetra
.661 .767 .929 r
.82535 .53643 .82976 .54177 .84042 .53861 .83602 .53316 Mtetra
.663 .765 .926 r
.83602 .53316 .84042 .53861 .85111 .5354 .84674 .52984 Mtetra
.663 .761 .923 r
.84674 .52984 .85111 .5354 .86184 .53215 .85749 .5265 Mtetra
.663 .759 .921 r
.85749 .5265 .86184 .53215 .8726 .52889 .86827 .52316 Mtetra
.662 .756 .92 r
.86827 .52316 .8726 .52889 .88341 .52563 .87911 .51983 Mtetra
.662 .754 .919 r
.87911 .51983 .88341 .52563 .89425 .52236 .88998 .51652 Mtetra
.661 .753 .918 r
.88998 .51652 .89425 .52236 .90514 .51909 .90089 .51322 Mtetra
.66 .752 .918 r
.90089 .51322 .90514 .51909 .91607 .51583 .91185 .50993 Mtetra
.659 .751 .918 r
.91185 .50993 .91607 .51583 .92704 .51257 .92285 .50664 Mtetra
.659 .751 .919 r
.92285 .50664 .92704 .51257 .93805 .5093 .93389 .50337 Mtetra
.658 .751 .919 r
.93389 .50337 .93805 .5093 .9491 .50603 .94498 .50008 Mtetra
.658 .752 .919 r
.94498 .50008 .9491 .50603 .9602 .50275 .9561 .4968 Mtetra
.654 .751 .921 r
.35813 .66383 .36369 .66869 .37274 .66612 .3672 .66123 Mtetra
.654 .75 .921 r
.3672 .66123 .37274 .66612 .38183 .66354 .3763 .65862 Mtetra
.654 .749 .92 r
.3763 .65862 .38183 .66354 .39094 .66096 .38543 .65601 Mtetra
.653 .749 .92 r
.38543 .65601 .39094 .66096 .40008 .65839 .3946 .65341 Mtetra
.652 .748 .92 r
.3946 .65341 .40008 .65839 .40926 .65583 .40379 .65083 Mtetra
.65 .747 .921 r
.40379 .65083 .40926 .65583 .41846 .65329 .41301 .64827 Mtetra
.649 .747 .921 r
.41301 .64827 .41846 .65329 .4277 .65076 .42227 .64573 Mtetra
.647 .747 .922 r
.42227 .64573 .4277 .65076 .43697 .64824 .43156 .64323 Mtetra
.645 .748 .924 r
.43156 .64323 .43697 .64824 .44627 .64574 .44088 .64077 Mtetra
.643 .749 .926 r
.44088 .64077 .44627 .64574 .4556 .64324 .45023 .63832 Mtetra
.642 .752 .929 r
.45023 .63832 .4556 .64324 .46497 .64072 .45962 .63588 Mtetra
.643 .756 .931 r
.45962 .63588 .46497 .64072 .47437 .63816 .46904 .6334 Mtetra
.645 .761 .933 r
.46904 .6334 .47437 .63816 .48381 .63553 .4785 .63086 Mtetra
.65 .766 .934 r
.4785 .63086 .48381 .63553 .49328 .63278 .48799 .62817 Mtetra
.659 .772 .933 r
.48799 .62817 .49328 .63278 .50278 .62989 .49752 .62528 Mtetra
.669 .775 .929 r
.49752 .62528 .50278 .62989 .51232 .62682 .50708 .62215 Mtetra
.681 .776 .923 r
.50708 .62215 .51232 .62682 .52189 .62356 .51667 .61871 Mtetra
.692 .773 .913 r
.51667 .61871 .52189 .62356 .53149 .6201 .52629 .61497 Mtetra
.702 .765 .901 r
.52629 .61497 .53149 .6201 .54112 .61645 .53594 .61095 Mtetra
.708 .754 .888 r
.53594 .61095 .54112 .61645 .55077 .6126 .54562 .60668 Mtetra
.711 .741 .875 r
.54562 .60668 .55077 .6126 .56045 .60854 .55532 .6022 Mtetra
.714 .729 .862 r
.55532 .6022 .56045 .60854 .57016 .60422 .56504 .59751 Mtetra
.716 .72 .852 r
.56504 .59751 .57016 .60422 .57989 .59959 .57479 .59262 Mtetra
.722 .714 .843 r
.57479 .59262 .57989 .59959 .58963 .59457 .58455 .58741 Mtetra
.727 .712 .836 r
.58455 .58741 .58963 .59457 .59939 .58919 .59432 .5819 Mtetra
.73 .71 .832 r
.59432 .5819 .59939 .58919 .60916 .5836 .60411 .57618 Mtetra
.728 .707 .83 r
.60411 .57618 .60916 .5836 .61895 .57806 .61392 .57049 Mtetra
.715 .699 .834 r
.61392 .57049 .61895 .57806 .62878 .57308 .62377 .56537 Mtetra
.691 .688 .842 r
.62377 .56537 .62878 .57308 .63866 .56897 .63367 .56115 Mtetra
.656 .671 .853 r
.63367 .56115 .63866 .56897 .64862 .56605 .64364 .55821 Mtetra
.614 .654 .866 r
.64364 .55821 .64862 .56605 .65865 .56431 .65369 .55654 Mtetra
.58 .641 .876 r
.65369 .55654 .65865 .56431 .66877 .56346 .66383 .55578 Mtetra
.555 .633 .883 r
.66383 .55578 .66877 .56346 .67896 .56317 .67404 .55561 Mtetra
.552 .635 .887 r
.67404 .55561 .67896 .56317 .68921 .56294 .68431 .55547 Mtetra
.559 .642 .889 r
.68431 .55547 .68921 .56294 .6995 .56253 .69462 .55513 Mtetra
.571 .65 .889 r
.69462 .55513 .6995 .56253 .70983 .56174 .70497 .5545 Mtetra
.582 .661 .892 r
.70497 .5545 .70983 .56174 .72018 .56057 .71536 .55355 Mtetra
.588 .671 .897 r
.71536 .55355 .72018 .56057 .73056 .55909 .72578 .5524 Mtetra
.594 .685 .905 r
.72578 .5524 .73056 .55909 .74097 .55735 .73624 .55105 Mtetra
.599 .702 .915 r
.73624 .55105 .74097 .55735 .75142 .5554 .74673 .54949 Mtetra
.606 .72 .925 r
.74673 .54949 .75142 .5554 .7619 .55325 .75726 .54768 Mtetra
.616 .738 .933 r
.75726 .54768 .7619 .55325 .7724 .55091 .76781 .54558 Mtetra
.626 .752 .938 r
.76781 .54558 .7724 .55091 .78294 .54836 .77838 .54318 Mtetra
.638 .763 .939 r
.77838 .54318 .78294 .54836 .7935 .54562 .78898 .54047 Mtetra
.648 .77 .937 r
.78898 .54047 .7935 .54562 .80409 .5427 .79959 .5375 Mtetra
.657 .771 .934 r
.79959 .5375 .80409 .5427 .8147 .53962 .81023 .53433 Mtetra
.662 .77 .93 r
.81023 .53433 .8147 .53962 .82535 .53643 .8209 .53101 Mtetra
.665 .767 .926 r
.8209 .53101 .82535 .53643 .83602 .53316 .83159 .52761 Mtetra
.667 .764 .923 r
.83159 .52761 .83602 .53316 .84674 .52984 .84233 .52417 Mtetra
.666 .76 .92 r
.84233 .52417 .84674 .52984 .85749 .5265 .8531 .52074 Mtetra
.665 .757 .918 r
.8531 .52074 .85749 .5265 .86827 .52316 .86391 .51732 Mtetra
.664 .754 .917 r
.86391 .51732 .86827 .52316 .87911 .51983 .87477 .51394 Mtetra
.662 .752 .917 r
.87477 .51394 .87911 .51983 .88998 .51652 .88567 .51059 Mtetra
.661 .751 .917 r
.88567 .51059 .88998 .51652 .90089 .51322 .89661 .50726 Mtetra
.66 .75 .917 r
.89661 .50726 .90089 .51322 .91185 .50993 .9076 .50395 Mtetra
.659 .75 .918 r
.9076 .50395 .91185 .50993 .92285 .50664 .91863 .50066 Mtetra
.658 .75 .918 r
.91863 .50066 .92285 .50664 .93389 .50337 .92971 .49738 Mtetra
.658 .751 .919 r
.92971 .49738 .93389 .50337 .94498 .50008 .94082 .49409 Mtetra
.657 .751 .919 r
.94082 .49409 .94498 .50008 .9561 .4968 .95198 .4908 Mtetra
.655 .751 .921 r
.35253 .65894 .35813 .66383 .3672 .66123 .36162 .6563 Mtetra
.655 .75 .92 r
.36162 .6563 .3672 .66123 .3763 .65862 .37074 .65365 Mtetra
.655 .749 .92 r
.37074 .65365 .3763 .65862 .38543 .65601 .37989 .651 Mtetra
.654 .748 .919 r
.37989 .651 .38543 .65601 .3946 .65341 .38908 .64837 Mtetra
.653 .747 .919 r
.38908 .64837 .3946 .65341 .40379 .65083 .39829 .64575 Mtetra
.651 .746 .919 r
.39829 .64575 .40379 .65083 .41301 .64827 .40754 .64316 Mtetra
.649 .745 .92 r
.40754 .64316 .41301 .64827 .42227 .64573 .41681 .64061 Mtetra
.646 .744 .921 r
.41681 .64061 .42227 .64573 .43156 .64323 .42612 .63811 Mtetra
.643 .744 .922 r
.42612 .63811 .43156 .64323 .44088 .64077 .43546 .63566 Mtetra
.641 .745 .924 r
.43546 .63566 .44088 .64077 .45023 .63832 .44483 .63326 Mtetra
.638 .747 .927 r
.44483 .63326 .45023 .63832 .45962 .63588 .45423 .6309 Mtetra
.638 .75 .93 r
.45423 .6309 .45962 .63588 .46904 .6334 .46367 .62853 Mtetra
.639 .756 .933 r
.46367 .62853 .46904 .6334 .4785 .63086 .47315 .6261 Mtetra
.645 .763 .934 r
.47315 .6261 .4785 .63086 .48799 .62817 .48266 .62351 Mtetra
.655 .77 .934 r
.48266 .62351 .48799 .62817 .49752 .62528 .49221 .62068 Mtetra
.67 .777 .93 r
.49221 .62068 .49752 .62528 .50708 .62215 .5018 .61751 Mtetra
.687 .78 .922 r
.5018 .61751 .50708 .62215 .51667 .61871 .51141 .6139 Mtetra
.702 .778 .91 r
.51141 .6139 .51667 .61871 .52629 .61497 .52106 .60987 Mtetra
.716 .77 .895 r
.52106 .60987 .52629 .61497 .53594 .61095 .53073 .6054 Mtetra
.722 .757 .88 r
.53073 .6054 .53594 .61095 .54562 .60668 .54043 .60062 Mtetra
.724 .741 .865 r
.54043 .60062 .54562 .60668 .55532 .6022 .55015 .59562 Mtetra
.722 .725 .853 r
.55015 .59562 .55532 .6022 .56504 .59751 .55989 .59052 Mtetra
.72 .714 .844 r
.55989 .59052 .56504 .59751 .57479 .59262 .56965 .58539 Mtetra
.721 .708 .838 r
.56965 .58539 .57479 .59262 .58455 .58741 .57943 .58011 Mtetra
.724 .708 .835 r
.57943 .58011 .58455 .58741 .59432 .5819 .58923 .57467 Mtetra
.728 .712 .835 r
.58923 .57467 .59432 .5819 .60411 .57618 .59905 .56906 Mtetra
.73 .716 .837 r
.59905 .56906 .60411 .57618 .61392 .57049 .60888 .56343 Mtetra
.718 .714 .846 r
.60888 .56343 .61392 .57049 .62377 .56537 .61875 .55833 Mtetra
.696 .708 .858 r
.61875 .55833 .62377 .56537 .63367 .56115 .62867 .55409 Mtetra
.658 .694 .873 r
.62867 .55409 .63367 .56115 .64364 .55821 .63866 .55113 Mtetra
.612 .676 .887 r
.63866 .55113 .64364 .55821 .65369 .55654 .64874 .54944 Mtetra
.576 .661 .895 r
.64874 .54944 .65369 .55654 .66383 .55578 .65889 .54862 Mtetra
.553 .648 .898 r
.65889 .54862 .66383 .55578 .67404 .55561 .66911 .54834 Mtetra
.554 .646 .895 r
.66911 .54834 .67404 .55561 .68431 .55547 .67939 .54805 Mtetra
.562 .646 .891 r
.67939 .54805 .68431 .55547 .69462 .55513 .68971 .5476 Mtetra
.57 .647 .887 r
.68971 .5476 .69462 .55513 .70497 .5545 .70008 .54699 Mtetra
.575 .651 .887 r
.70008 .54699 .70497 .5545 .71536 .55355 .71049 .54624 Mtetra
.574 .657 .893 r
.71049 .54624 .71536 .55355 .72578 .5524 .72096 .54547 Mtetra
.574 .67 .904 r
.72096 .54547 .72578 .5524 .73624 .55105 .73147 .54461 Mtetra
.578 .689 .917 r
.73147 .54461 .73624 .55105 .74673 .54949 .74202 .54352 Mtetra
.586 .711 .929 r
.74202 .54352 .74673 .54949 .75726 .54768 .75259 .54213 Mtetra
.602 .734 .938 r
.75259 .54213 .75726 .54768 .76781 .54558 .76319 .5403 Mtetra
.619 .753 .942 r
.76319 .5403 .76781 .54558 .77838 .54318 .77381 .53803 Mtetra
.637 .766 .941 r
.77381 .53803 .77838 .54318 .78898 .54047 .78443 .53532 Mtetra
.651 .772 .937 r
.78443 .53532 .78898 .54047 .79959 .5375 .79507 .53225 Mtetra
.662 .773 .932 r
.79507 .53225 .79959 .5375 .81023 .53433 .80573 .52894 Mtetra
.668 .77 .926 r
.80573 .52894 .81023 .53433 .8209 .53101 .81641 .52546 Mtetra
.67 .766 .922 r
.81641 .52546 .8209 .53101 .83159 .52761 .82712 .52192 Mtetra
.671 .761 .918 r
.82712 .52192 .83159 .52761 .84233 .52417 .83788 .51836 Mtetra
.669 .757 .916 r
.83788 .51836 .84233 .52417 .8531 .52074 .84867 .51483 Mtetra
.667 .753 .915 r
.84867 .51483 .8531 .52074 .86391 .51732 .85951 .51135 Mtetra
.665 .751 .915 r
.85951 .51135 .86391 .51732 .87477 .51394 .87039 .50793 Mtetra
.662 .749 .915 r
.87039 .50793 .87477 .51394 .88567 .51059 .88132 .50456 Mtetra
.661 .749 .915 r
.88132 .50456 .88567 .51059 .89661 .50726 .8923 .50122 Mtetra
.659 .749 .916 r
.8923 .50122 .89661 .50726 .9076 .50395 .90332 .49792 Mtetra
.658 .749 .917 r
.90332 .49792 .9076 .50395 .91863 .50066 .91438 .49462 Mtetra
.657 .749 .918 r
.91438 .49462 .91863 .50066 .92971 .49738 .92549 .49134 Mtetra
.657 .75 .919 r
.92549 .49134 .92971 .49738 .94082 .49409 .93664 .48805 Mtetra
.656 .751 .919 r
.93664 .48805 .94082 .49409 .95198 .4908 .94784 .48476 Mtetra
.656 .751 .92 r
.34689 .65403 .35253 .65894 .36162 .6563 .356 .65135 Mtetra
.356 .65135 .36162 .6563 .37074 .65365 .36515 .64866 Mtetra
.656 .75 .919 r
.36515 .64866 .37074 .65365 .37989 .651 .37432 .64597 Mtetra
.655 .749 .919 r
.37432 .64597 .37989 .651 .38908 .64837 .38352 .64329 Mtetra
.654 .747 .918 r
.38352 .64329 .38908 .64837 .39829 .64575 .39276 .64063 Mtetra
.652 .746 .918 r
.39276 .64063 .39829 .64575 .40754 .64316 .40202 .63799 Mtetra
.65 .744 .918 r
.40202 .63799 .40754 .64316 .41681 .64061 .41132 .6354 Mtetra
.647 .743 .919 r
.41132 .6354 .41681 .64061 .42612 .63811 .42064 .63287 Mtetra
.643 .741 .92 r
.42064 .63287 .42612 .63811 .43546 .63566 .43 .63042 Mtetra
.64 .74 .922 r
.43 .63042 .43546 .63566 .44483 .63326 .43939 .62804 Mtetra
.636 .741 .924 r
.43939 .62804 .44483 .63326 .45423 .6309 .44882 .62574 Mtetra
.634 .743 .927 r
.44882 .62574 .45423 .6309 .46367 .62853 .45827 .62346 Mtetra
.633 .747 .93 r
.45827 .62346 .46367 .62853 .47315 .6261 .46777 .62116 Mtetra
.639 .755 .932 r
.46777 .62116 .47315 .6261 .48266 .62351 .4773 .6187 Mtetra
.65 .764 .933 r
.4773 .6187 .48266 .62351 .49221 .62068 .48687 .61599 Mtetra
.668 .774 .929 r
.48687 .61599 .49221 .62068 .5018 .61751 .49648 .61285 Mtetra
.69 .782 .921 r
.49648 .61285 .5018 .61751 .51141 .6139 .50612 .60914 Mtetra
.711 .783 .908 r
.50612 .60914 .51141 .6139 .52106 .60987 .51579 .60484 Mtetra
.73 .777 .891 r
.51579 .60484 .52106 .60987 .53073 .6054 .52549 .59991 Mtetra
.738 .763 .873 r
.52549 .59991 .53073 .6054 .54043 .60062 .53521 .59455 Mtetra
.739 .745 .857 r
.53521 .59455 .54043 .60062 .55015 .59562 .54495 .58893 Mtetra
.733 .726 .845 r
.54495 .58893 .55015 .59562 .55989 .59052 .55471 .58335 Mtetra
.723 .711 .838 r
.55471 .58335 .55989 .59052 .56965 .58539 .56449 .57799 Mtetra
.718 .704 .836 r
.56449 .57799 .56965 .58539 .57943 .58011 .5743 .57279 Mtetra
.715 .706 .84 r
.5743 .57279 .57943 .58011 .58923 .57467 .58412 .56771 Mtetra
.72 .717 .847 r
.58412 .56771 .58923 .57467 .59905 .56906 .59397 .56254 Mtetra
.725 .732 .857 r
.59397 .56254 .59905 .56906 .60888 .56343 .60384 .55733 Mtetra
.717 .744 .873 r
.60384 .55733 .60888 .56343 .61875 .55833 .61374 .55253 Mtetra
.698 .749 .891 r
.61374 .55253 .61875 .55833 .62867 .55409 .62369 .54841 Mtetra
.658 .742 .912 r
.62369 .54841 .62867 .55409 .63866 .55113 .6337 .54543 Mtetra
.61 .724 .927 r
.6337 .54543 .63866 .55113 .64874 .54944 .64379 .54357 Mtetra
.577 .706 .93 r
.64379 .54357 .64874 .54944 .65889 .54862 .65395 .54242 Mtetra
.561 .687 .924 r
.65395 .54242 .65889 .54862 .66911 .54834 .66418 .54167 Mtetra
.568 .674 .91 r
.66418 .54167 .66911 .54834 .67939 .54805 .67445 .5409 Mtetra
.576 .662 .896 r
.67445 .5409 .67939 .54805 .68971 .5476 .68477 .54004 Mtetra
.573 .649 .887 r
.68477 .54004 .68971 .5476 .70008 .54699 .69515 .53932 Mtetra
.567 .643 .885 r
.69515 .53932 .70008 .54699 .71049 .54624 .70559 .53875 Mtetra
.556 .644 .892 r
.70559 .53875 .71049 .54624 .72096 .54547 .7161 .53842 Mtetra
.548 .655 .906 r
.7161 .53842 .72096 .54547 .73147 .54461 .72667 .53815 Mtetra
.551 .678 .922 r
.72667 .53815 .73147 .54461 .74202 .54352 .73727 .53762 Mtetra
.563 .704 .936 r
.73727 .53762 .74202 .54352 .75259 .54213 .74791 .53666 Mtetra
.588 .733 .944 r
.74791 .53666 .75259 .54213 .76319 .5403 .75855 .53506 Mtetra
.614 .754 .945 r
.75855 .53506 .76319 .5403 .77381 .53803 .7692 .53285 Mtetra
.639 .767 .941 r
.7692 .53285 .77381 .53803 .78443 .53532 .77984 .53007 Mtetra
.657 .772 .934 r
.77984 .53007 .78443 .53532 .79507 .53225 .7905 .52685 Mtetra
.668 .77 .926 r
.7905 .52685 .79507 .53225 .80573 .52894 .80118 .52335 Mtetra
.674 .766 .92 r
.80118 .52335 .80573 .52894 .81641 .52546 .81187 .5197 Mtetra
.675 .761 .916 r
.81187 .5197 .81641 .52546 .82712 .52192 .82261 .51602 Mtetra
.674 .756 .913 r
.82261 .51602 .82712 .52192 .83788 .51836 .83338 .51236 Mtetra
.67 .752 .912 r
.83338 .51236 .83788 .51836 .84867 .51483 .8442 .50878 Mtetra
.667 .75 .912 r
.8442 .50878 .84867 .51483 .85951 .51135 .85507 .50527 Mtetra
.664 .748 .913 r
.85507 .50527 .85951 .51135 .87039 .50793 .86598 .50184 Mtetra
.662 .747 .914 r
.86598 .50184 .87039 .50793 .88132 .50456 .87694 .49846 Mtetra
.66 .747 .915 r
.87694 .49846 .88132 .50456 .8923 .50122 .88795 .49513 Mtetra
.658 .748 .916 r
.88795 .49513 .8923 .50122 .90332 .49792 .89901 .49183 Mtetra
.657 .748 .917 r
.89901 .49183 .90332 .49792 .91438 .49462 .9101 .48854 Mtetra
.656 .749 .918 r
.9101 .48854 .91438 .49462 .92549 .49134 .92124 .48526 Mtetra
.656 .75 .919 r
.92124 .48526 .92549 .49134 .93664 .48805 .93243 .48198 Mtetra
.656 .751 .92 r
.93243 .48198 .93664 .48805 .94784 .48476 .94366 .47868 Mtetra
.656 .752 .92 r
.34122 .64908 .34689 .65403 .356 .65135 .35035 .64637 Mtetra
.657 .751 .92 r
.35035 .64637 .356 .65135 .36515 .64866 .35951 .64365 Mtetra
.656 .75 .919 r
.35951 .64365 .36515 .64866 .37432 .64597 .36871 .64092 Mtetra
.36871 .64092 .37432 .64597 .38352 .64329 .37793 .6382 Mtetra
.655 .748 .918 r
.37793 .6382 .38352 .64329 .39276 .64063 .38719 .63548 Mtetra
.654 .747 .918 r
.38719 .63548 .39276 .64063 .40202 .63799 .39647 .63279 Mtetra
.652 .745 .917 r
.39647 .63279 .40202 .63799 .41132 .6354 .40579 .63013 Mtetra
.649 .742 .917 r
.40579 .63013 .41132 .6354 .42064 .63287 .41514 .62754 Mtetra
.645 .739 .917 r
.41514 .62754 .42064 .63287 .43 .63042 .42452 .62503 Mtetra
.641 .736 .918 r
.42452 .62503 .43 .63042 .43939 .62804 .43393 .62262 Mtetra
.635 .734 .92 r
.43393 .62262 .43939 .62804 .44882 .62574 .44337 .62034 Mtetra
.631 .734 .922 r
.44337 .62034 .44882 .62574 .45827 .62346 .45284 .61812 Mtetra
.628 .737 .925 r
.45284 .61812 .45827 .62346 .46777 .62116 .46236 .61595 Mtetra
.632 .744 .928 r
.46236 .61595 .46777 .62116 .4773 .6187 .47191 .61367 Mtetra
.642 .754 .93 r
.47191 .61367 .4773 .6187 .48687 .61599 .4815 .61114 Mtetra
.662 .768 .928 r
.4815 .61114 .48687 .61599 .49648 .61285 .49113 .60813 Mtetra
.689 .78 .921 r
.49113 .60813 .49648 .61285 .50612 .60914 .50079 .60443 Mtetra
.718 .787 .907 r
.50079 .60443 .50612 .60914 .51579 .60484 .51049 .59993 Mtetra
.743 .785 .887 r
.51049 .59993 .51579 .60484 .52549 .59991 .52022 .59455 Mtetra
.754 .772 .867 r
.52022 .59455 .52549 .59991 .53521 .59455 .52996 .58856 Mtetra
.757 .753 .849 r
.52996 .58856 .53521 .59455 .54495 .58893 .53973 .58221 Mtetra
.744 .729 .838 r
.53973 .58221 .54495 .58893 .55471 .58335 .5495 .57607 Mtetra
.727 .71 .835 r
.5495 .57607 .55471 .58335 .56449 .57799 .5593 .5705 Mtetra
.711 .7 .838 r
.5593 .5705 .56449 .57799 .5743 .57279 .56913 .56554 Mtetra
.698 .703 .851 r
.56913 .56554 .5743 .57279 .58412 .56771 .57899 .56117 Mtetra
.7 .725 .87 r
.57899 .56117 .58412 .56771 .59397 .56254 .58888 .5569 Mtetra
.705 .757 .892 r
.58888 .5569 .59397 .56254 .60384 .55733 .59879 .55258 Mtetra
.701 .79 .92 r
.59879 .55258 .60384 .55733 .61374 .55253 .60874 .54845 Mtetra
.685 .815 .945 r
.60874 .54845 .61374 .55253 .62369 .54841 .61873 .54466 Mtetra
.643 .82 .968 r
.61873 .54466 .62369 .54841 .6337 .54543 .62877 .54166 Mtetra
.597 .805 .979 r
.62877 .54166 .6337 .54543 .64379 .54357 .63888 .53944 Mtetra
.584 .784 .975 r
.63888 .53944 .64379 .54357 .65395 .54242 .64904 .53757 Mtetra
.587 .754 .957 r
.64904 .53757 .65395 .54242 .66418 .54167 .65925 .53589 Mtetra
.601 .722 .929 r
.65925 .53589 .66418 .54167 .67445 .5409 .66951 .53417 Mtetra
.604 .69 .903 r
.66951 .53417 .67445 .5409 .68477 .54004 .67981 .53255 Mtetra
.584 .657 .888 r
.67981 .53255 .68477 .54004 .69515 .53932 .6902 .53154 Mtetra
.56 .638 .885 r
.6902 .53154 .69515 .53932 .70559 .53875 .70066 .53115 Mtetra
.532 .63 .894 r
.70066 .53115 .70559 .53875 .7161 .53842 .71122 .53135 Mtetra
.513 .638 .91 r
.71122 .53135 .7161 .53842 .72667 .53815 .72184 .53178 Mtetra
.518 .666 .929 r
.72184 .53178 .72667 .53815 .73727 .53762 .73251 .53184 Mtetra
.537 .699 .944 r
.73251 .53184 .73727 .53762 .74791 .53666 .7432 .5313 Mtetra
.576 .734 .95 r
.7432 .5313 .74791 .53666 .75855 .53506 .75388 .52987 Mtetra
.614 .758 .947 r
.75388 .52987 .75855 .53506 .7692 .53285 .76455 .52762 Mtetra
.646 .769 .938 r
.76455 .52762 .7692 .53285 .77984 .53007 .77522 .52466 Mtetra
.666 .77 .927 r
.77522 .52466 .77984 .53007 .7905 .52685 .78589 .5212 Mtetra
.676 .765 .918 r
.78589 .5212 .7905 .52685 .80118 .52335 .79657 .51749 Mtetra
.68 .759 .911 r
.79657 .51749 .80118 .52335 .81187 .5197 .80729 .51366 Mtetra
.678 .753 .908 r
.80729 .51366 .81187 .5197 .82261 .51602 .81804 .50988 Mtetra
.675 .749 .907 r
.81804 .50988 .82261 .51602 .83338 .51236 .82884 .50616 Mtetra
.67 .746 .907 r
.82884 .50616 .83338 .51236 .8442 .50878 .83969 .50256 Mtetra
.666 .745 .909 r
.83969 .50256 .8442 .50878 .85507 .50527 .85059 .49907 Mtetra
.663 .745 .911 r
.85059 .49907 .85507 .50527 .86598 .50184 .86154 .49566 Mtetra
.66 .745 .913 r
.86154 .49566 .86598 .50184 .87694 .49846 .87254 .49232 Mtetra
.658 .746 .915 r
.87254 .49232 .87694 .49846 .88795 .49513 .88358 .48901 Mtetra
.657 .747 .917 r
.88358 .48901 .88795 .49513 .89901 .49183 .89466 .48572 Mtetra
.656 .749 .918 r
.89466 .48572 .89901 .49183 .9101 .48854 .9058 .48244 Mtetra
.655 .749 .919 r
.9058 .48244 .9101 .48854 .92124 .48526 .91697 .47916 Mtetra
.655 .75 .92 r
.91697 .47916 .92124 .48526 .93243 .48198 .92819 .47586 Mtetra
.655 .751 .92 r
.92819 .47586 .93243 .48198 .94366 .47868 .93945 .47256 Mtetra
.656 .752 .92 r
.33552 .6441 .34122 .64908 .35035 .64637 .34467 .64137 Mtetra
.657 .752 .92 r
.34467 .64137 .35035 .64637 .35951 .64365 .35385 .63863 Mtetra
.35385 .63863 .35951 .64365 .36871 .64092 .36306 .63588 Mtetra
.657 .751 .92 r
.36306 .63588 .36871 .64092 .37793 .6382 .3723 .63312 Mtetra
.657 .75 .919 r
.3723 .63312 .37793 .6382 .38719 .63548 .38158 .63035 Mtetra
.656 .749 .918 r
.38158 .63035 .38719 .63548 .39647 .63279 .39089 .62759 Mtetra
.655 .747 .917 r
.39089 .62759 .39647 .63279 .40579 .63013 .40023 .62485 Mtetra
.652 .744 .917 r
.40023 .62485 .40579 .63013 .41514 .62754 .4096 .62216 Mtetra
.649 .74 .916 r
.4096 .62216 .41514 .62754 .42452 .62503 .419 .61955 Mtetra
.644 .735 .915 r
.419 .61955 .42452 .62503 .43393 .62262 .42843 .61706 Mtetra
.637 .731 .916 r
.42843 .61706 .43393 .62262 .44337 .62034 .43789 .61472 Mtetra
.631 .727 .917 r
.43789 .61472 .44337 .62034 .45284 .61812 .44739 .6125 Mtetra
.625 .726 .92 r
.44739 .6125 .45284 .61812 .46236 .61595 .45691 .61042 Mtetra
.626 .73 .922 r
.45691 .61042 .46236 .61595 .47191 .61367 .46648 .6083 Mtetra
.631 .739 .925 r
.46648 .6083 .47191 .61367 .4815 .61114 .47609 .60601 Mtetra
.652 .755 .925 r
.47609 .60601 .4815 .61114 .49113 .60813 .48574 .60324 Mtetra
.682 .773 .92 r
.48574 .60324 .49113 .60813 .50079 .60443 .49543 .5997 Mtetra
.718 .788 .907 r
.49543 .5997 .50079 .60443 .51049 .59993 .50515 .59516 Mtetra
.752 .792 .886 r
.50515 .59516 .51049 .59993 .52022 .59455 .51491 .58946 Mtetra
.771 .784 .864 r
.51491 .58946 .52022 .59455 .52996 .58856 .52468 .58288 Mtetra
.776 .766 .844 r
.52468 .58288 .52996 .58856 .53973 .58221 .53447 .57571 Mtetra
.76 .74 .834 r
.53447 .57571 .53973 .58221 .5495 .57607 .54427 .56891 Mtetra
.734 .717 .835 r
.54427 .56891 .5495 .57607 .5593 .5705 .55409 .56305 Mtetra
.702 .7 .845 r
.55409 .56305 .5593 .5705 .56913 .56554 .56394 .55846 Mtetra
.667 .698 .87 r
.56394 .55846 .56913 .56554 .57899 .56117 .57384 .55518 Mtetra
.653 .729 .905 r
.57384 .55518 .57899 .56117 .58888 .5569 .58377 .55233 Mtetra
.644 .783 .948 r
.58377 .55233 .58888 .5569 .59879 .55258 .59375 .54952 Mtetra
.626 .847 .984 r
.59375 .54952 .59879 .55258 .60874 .54845 .60376 .54656 Mtetra
.592 .89 .99 r
.60376 .54656 .60874 .54845 .61873 .54466 .6138 .5434 Mtetra
.537 .893 .977 r
.6138 .5434 .61873 .54466 .62877 .54166 .62388 .54038 Mtetra
.522 .887 .976 r
.62388 .54038 .62877 .54166 .63888 .53944 .634 .5375 Mtetra
.583 .886 .991 r
.634 .5375 .63888 .53944 .64904 .53757 .64415 .53442 Mtetra
.639 .851 .981 r
.64415 .53442 .64904 .53757 .65925 .53589 .65434 .53119 Mtetra
.659 .787 .943 r
.65434 .53119 .65925 .53589 .66951 .53417 .66456 .52799 Mtetra
.646 .726 .907 r
.66456 .52799 .66951 .53417 .67981 .53255 .67484 .52524 Mtetra
.598 .67 .89 r
.67484 .52524 .67981 .53255 .6902 .53154 .68522 .5238 Mtetra
.548 .635 .889 r
.68522 .5238 .6902 .53154 .70066 .53115 .69571 .52366 Mtetra
.499 .619 .901 r
.69571 .52366 .70066 .53115 .71122 .53135 .70632 .52449 Mtetra
.464 .623 .92 r
.70632 .52449 .71122 .53135 .72184 .53178 .71701 .52571 Mtetra
.476 .659 .941 r
.71701 .52571 .72184 .53178 .73251 .53184 .72773 .52634 Mtetra
.513 .701 .955 r
.72773 .52634 .73251 .53184 .7432 .5313 .73846 .52608 Mtetra
.572 .74 .956 r
.73846 .52608 .7432 .5313 .75388 .52987 .74917 .52465 Mtetra
.623 .761 .945 r
.74917 .52465 .75388 .52987 .76455 .52762 .75986 .52219 Mtetra
.657 .767 .93 r
.75986 .52219 .76455 .52762 .77522 .52466 .77054 .51895 Mtetra
.677 .764 .916 r
.77054 .51895 .77522 .52466 .78589 .5212 .78121 .51521 Mtetra
.682 .756 .907 r
.78121 .51521 .78589 .5212 .79657 .51749 .79192 .51129 Mtetra
.683 .75 .902 r
.79192 .51129 .79657 .51749 .80729 .51366 .80265 .50733 Mtetra
.678 .744 .901 r
.80265 .50733 .80729 .51366 .81804 .50988 .81343 .5035 Mtetra
.673 .742 .902 r
.81343 .5035 .81804 .50988 .82884 .50616 .82426 .4998 Mtetra
.668 .741 .905 r
.82426 .4998 .82884 .50616 .83969 .50256 .83515 .49625 Mtetra
.663 .742 .908 r
.83515 .49625 .83969 .50256 .85059 .49907 .84608 .49282 Mtetra
.66 .743 .912 r
.84608 .49282 .85059 .49907 .86154 .49566 .85707 .48947 Mtetra
.657 .745 .915 r
.85707 .48947 .86154 .49566 .87254 .49232 .8681 .48617 Mtetra
.656 .747 .917 r
.8681 .48617 .87254 .49232 .88358 .48901 .87918 .48289 Mtetra
.655 .749 .919 r
.87918 .48289 .88358 .48901 .89466 .48572 .8903 .47962 Mtetra
.655 .75 .92 r
.8903 .47962 .89466 .48572 .9058 .48244 .90146 .47633 Mtetra
.655 .751 .92 r
.90146 .47633 .9058 .48244 .91697 .47916 .91267 .47303 Mtetra
.91267 .47303 .91697 .47916 .92819 .47586 .92392 .46972 Mtetra
.92392 .46972 .92819 .47586 .93945 .47256 .93521 .46639 Mtetra
.656 .751 .92 r
.32977 .63908 .33552 .6441 .34467 .64137 .33894 .63636 Mtetra
.656 .752 .921 r
.33894 .63636 .34467 .64137 .35385 .63863 .34814 .63362 Mtetra
.656 .753 .921 r
.34814 .63362 .35385 .63863 .36306 .63588 .35737 .63086 Mtetra
.657 .753 .921 r
.35737 .63086 .36306 .63588 .3723 .63312 .36664 .62808 Mtetra
.36664 .62808 .3723 .63312 .38158 .63035 .37594 .62527 Mtetra
.658 .753 .92 r
.37594 .62527 .38158 .63035 .39089 .62759 .38527 .62245 Mtetra
.658 .751 .919 r
.38527 .62245 .39089 .62759 .40023 .62485 .39463 .61961 Mtetra
.657 .748 .917 r
.39463 .61961 .40023 .62485 .4096 .62216 .40402 .6168 Mtetra
.654 .743 .915 r
.40402 .6168 .4096 .62216 .419 .61955 .41345 .61404 Mtetra
.65 .737 .913 r
.41345 .61404 .419 .61955 .42843 .61706 .4229 .61138 Mtetra
.643 .73 .911 r
.4229 .61138 .42843 .61706 .43789 .61472 .43239 .60888 Mtetra
.635 .722 .91 r
.43239 .60888 .43789 .61472 .44739 .6125 .4419 .60657 Mtetra
.626 .716 .912 r
.4419 .60657 .44739 .6125 .45691 .61042 .45145 .60448 Mtetra
.621 .715 .913 r
.45145 .60448 .45691 .61042 .46648 .6083 .46103 .60249 Mtetra
.62 .72 .918 r
.46103 .60249 .46648 .6083 .47609 .60601 .47065 .60049 Mtetra
.637 .737 .92 r
.47065 .60049 .47609 .60601 .48574 .60324 .48032 .59806 Mtetra
.667 .76 .92 r
.48032 .59806 .48574 .60324 .49543 .5997 .49003 .5949 Mtetra
.711 .785 .91 r
.49003 .5949 .49543 .5997 .50515 .59516 .49978 .59056 Mtetra
.756 .801 .889 r
.49978 .59056 .50515 .59516 .51491 .58946 .50956 .58476 Mtetra
.785 .8 .865 r
.50956 .58476 .51491 .58946 .52468 .58288 .51937 .57768 Mtetra
.798 .785 .841 r
.51937 .57768 .52468 .58288 .53447 .57571 .52918 .56965 Mtetra
.78 .757 .832 r
.52918 .56965 .53447 .57571 .54427 .56891 .539 .56205 Mtetra
.746 .729 .836 r
.539 .56205 .54427 .56891 .55409 .56305 .54884 .55577 Mtetra
.691 .702 .855 r
.54884 .55577 .55409 .56305 .56394 .55846 .55872 .55164 Mtetra
.613 .687 .896 r
.55872 .55164 .56394 .55846 .57384 .55518 .56866 .54984 Mtetra
.546 .716 .951 r
.56866 .54984 .57384 .55518 .58377 .55233 .57865 .54906 Mtetra
.444 .767 .997 r
.57865 .54906 .58377 .55233 .59375 .54952 .5887 .54852 Mtetra
.298 .778 .92 r
.5887 .54852 .59375 .54952 .60376 .54656 .59879 .54738 Mtetra
.184 .715 .733 r
.59879 .54738 .60376 .54656 .6138 .5434 .6089 .54521 Mtetra
0 0 0 r
.6089 .54521 .6138 .5434 .62388 .54038 .61903 .54218 Mtetra
.264 .754 .671 r
.61903 .54218 .62388 .54038 .634 .5375 .62916 .53828 Mtetra
.518 .917 .849 r
.62916 .53828 .634 .5375 .64415 .53442 .6393 .53334 Mtetra
.708 .954 .951 r
.6393 .53334 .64415 .53442 .65434 .53119 .64943 .52779 Mtetra
.739 .864 .939 r
.64943 .52779 .65434 .53119 .66456 .52799 .6596 .52248 Mtetra
.701 .77 .905 r
.6596 .52248 .66456 .52799 .67484 .52524 .66984 .51819 Mtetra
.616 .687 .894 r
.66984 .51819 .67484 .52524 .68522 .5238 .68022 .51625 Mtetra
.527 .631 .897 r
.68022 .51625 .68522 .5238 .69571 .52366 .69075 .51648 Mtetra
.449 .604 .912 r
.69075 .51648 .69571 .52366 .70632 .52449 .70142 .51808 Mtetra
.395 .604 .932 r
.70142 .51808 .70632 .52449 .71701 .52571 .71217 .52013 Mtetra
.426 .656 .955 r
.71217 .52013 .71701 .52571 .72773 .52634 .72295 .52122 Mtetra
.495 .711 .967 r
.72295 .52122 .72773 .52634 .73846 .52608 .73371 .52103 Mtetra
.58 .753 .959 r
.73371 .52103 .73846 .52608 .74917 .52465 .74443 .51936 Mtetra
.641 .767 .939 r
.74443 .51936 .74917 .52465 .75986 .52219 .75512 .51647 Mtetra
.673 .763 .918 r
.75512 .51647 .75986 .52219 .77054 .51895 .7658 .51283 Mtetra
.687 .754 .902 r
.7658 .51283 .77054 .51895 .78121 .51521 .77648 .50876 Mtetra
.686 .743 .894 r
.77648 .50876 .78121 .51521 .79192 .51129 .7872 .50467 Mtetra
.683 .737 .892 r
.7872 .50467 .79192 .51129 .80265 .50733 .79796 .50067 Mtetra
.675 .733 .894 r
.79796 .50067 .80265 .50733 .81343 .5035 .80877 .4969 Mtetra
.668 .733 .899 r
.80877 .4969 .81343 .5035 .82426 .4998 .81964 .49331 Mtetra
.662 .736 .904 r
.81964 .49331 .82426 .4998 .83515 .49625 .83057 .48989 Mtetra
.658 .739 .91 r
.83057 .48989 .83515 .49625 .84608 .49282 .84155 .48658 Mtetra
.656 .743 .914 r
.84155 .48658 .84608 .49282 .85707 .48947 .85257 .48331 Mtetra
.654 .747 .918 r
.85257 .48331 .85707 .48947 .8681 .48617 .86364 .48007 Mtetra
.654 .75 .92 r
.86364 .48007 .8681 .48617 .87918 .48289 .87476 .47682 Mtetra
.654 .751 .921 r
.87476 .47682 .87918 .48289 .8903 .47962 .88591 .47354 Mtetra
.655 .752 .922 r
.88591 .47354 .8903 .47962 .90146 .47633 .89711 .47024 Mtetra
.655 .753 .922 r
.89711 .47024 .90146 .47633 .91267 .47303 .90834 .46691 Mtetra
.656 .753 .921 r
.90834 .46691 .91267 .47303 .92392 .46972 .91962 .46355 Mtetra
.656 .752 .921 r
.91962 .46355 .92392 .46972 .93521 .46639 .93095 .46018 Mtetra
.654 .751 .921 r
.32399 .63404 .32977 .63908 .33894 .63636 .33318 .63133 Mtetra
.654 .752 .922 r
.33318 .63133 .33894 .63636 .34814 .63362 .3424 .6286 Mtetra
.655 .754 .922 r
.3424 .6286 .34814 .63362 .35737 .63086 .35165 .62585 Mtetra
.656 .755 .923 r
.35165 .62585 .35737 .63086 .36664 .62808 .36093 .62307 Mtetra
.657 .756 .923 r
.36093 .62307 .36664 .62808 .37594 .62527 .37025 .62025 Mtetra
.658 .756 .922 r
.37025 .62025 .37594 .62527 .38527 .62245 .3796 .61738 Mtetra
.66 .756 .921 r
.3796 .61738 .38527 .62245 .39463 .61961 .38899 .61447 Mtetra
.661 .754 .919 r
.38899 .61447 .39463 .61961 .40402 .6168 .3984 .61154 Mtetra
.661 .75 .916 r
.3984 .61154 .40402 .6168 .41345 .61404 .40786 .60861 Mtetra
.658 .743 .913 r
.40786 .60861 .41345 .61404 .4229 .61138 .41734 .60574 Mtetra
.653 .735 .91 r
.41734 .60574 .4229 .61138 .43239 .60888 .42685 .603 Mtetra
.644 .724 .907 r
.42685 .603 .43239 .60888 .4419 .60657 .43638 .60047 Mtetra
.632 .713 .906 r
.43638 .60047 .4419 .60657 .45145 .60448 .44595 .59824 Mtetra
.621 .706 .906 r
.44595 .59824 .45145 .60448 .46103 .60249 .45555 .59625 Mtetra
.612 .703 .909 r
.45555 .59625 .46103 .60249 .47065 .60049 .46519 .59446 Mtetra
.621 .714 .913 r
.46519 .59446 .47065 .60049 .48032 .59806 .47486 .59243 Mtetra
.644 .737 .917 r
.47486 .59243 .48032 .59806 .49003 .5949 .48459 .58983 Mtetra
.692 .772 .913 r
.48459 .58983 .49003 .5949 .49978 .59056 .49436 .58599 Mtetra
.748 .802 .896 r
.49436 .58599 .49978 .59056 .50956 .58476 .50417 .58046 Mtetra
.794 .816 .87 r
.50417 .58046 .50956 .58476 .51937 .57768 .51401 .57318 Mtetra
.82 .809 .841 r
.51401 .57318 .51937 .57768 .52918 .56965 .52386 .56438 Mtetra
.805 .785 .834 r
.52386 .56438 .52918 .56965 .539 .56205 .53371 .55587 Mtetra
.767 .753 .841 r
.53371 .55587 .539 .56205 .54884 .55577 .54357 .5489 Mtetra
.683 .712 .87 r
.54357 .5489 .54884 .55577 .55872 .55164 .55347 .5451 Mtetra
.532 .664 .921 r
.55347 .5451 .55872 .55164 .56866 .54984 .56345 .54495 Mtetra
.328 .631 .961 r
.56345 .54495 .56866 .54984 .57865 .54906 .5735 .54671 Mtetra
0 .515 .831 r
.5735 .54671 .57865 .54906 .5887 .54852 .58364 .5492 Mtetra
.252 0 0 r
.58364 .5492 .5887 .54852 .59879 .54738 .59381 .55056 Mtetra
.253 0 0 r
.59381 .55056 .59879 .54738 .6089 .54521 .60401 .54983 Mtetra
.153 0 0 r
.60401 .54983 .6089 .54521 .61903 .54218 .61419 .54678 Mtetra
0 0 0 r
.61419 .54678 .61903 .54218 .62916 .53828 .62434 .54142 Mtetra
.475 .851 .624 r
.62434 .54142 .62916 .53828 .6393 .53334 .63445 .53395 Mtetra
.791 .997 .857 r
.63445 .53395 .6393 .53334 .64943 .52779 .64453 .52532 Mtetra
.821 .909 .9 r
.64453 .52532 .64943 .52779 .6596 .52248 .65464 .5174 Mtetra
.754 .8 .89 r
.65464 .5174 .6596 .52248 .66984 .51819 .66483 .51141 Mtetra
.628 .702 .899 r
.66483 .51141 .66984 .51819 .68022 .51625 .67521 .50909 Mtetra
.485 .625 .913 r
.67521 .50909 .68022 .51625 .69075 .51648 .6858 .50999 Mtetra
.366 .586 .928 r
.6858 .50999 .69075 .51648 .70142 .51808 .69652 .51246 Mtetra
.295 .582 .941 r
.69652 .51246 .70142 .51808 .71217 .52013 .70734 .51526 Mtetra
.377 .662 .969 r
.70734 .51526 .71217 .52013 .72295 .52122 .71815 .51652 Mtetra
.5 .733 .977 r
.71815 .51652 .72295 .52122 .73371 .52103 .72892 .51601 Mtetra
.607 .766 .956 r
.72892 .51601 .73371 .52103 .74443 .51936 .73964 .51378 Mtetra
.667 .767 .925 r
.73964 .51378 .74443 .51936 .75512 .51647 .75032 .51029 Mtetra
.687 .752 .901 r
.75032 .51029 .75512 .51647 .7658 .51283 .76099 .50619 Mtetra
.693 .74 .887 r
.76099 .50619 .7658 .51283 .77648 .50876 .77168 .50185 Mtetra
.686 .729 .884 r
.77168 .50185 .77648 .50876 .7872 .50467 .78243 .49772 Mtetra
.678 .726 .886 r
.78243 .49772 .7872 .50467 .79796 .50067 .79322 .49382 Mtetra
.668 .726 .893 r
.79322 .49382 .79796 .50067 .80877 .4969 .80408 .49023 Mtetra
.66 .73 .901 r
.80408 .49023 .80877 .4969 .81964 .49331 .815 .48686 Mtetra
.655 .736 .909 r
.815 .48686 .81964 .49331 .83057 .48989 .82597 .48362 Mtetra
.652 .741 .915 r
.82597 .48362 .83057 .48989 .84155 .48658 .837 .48044 Mtetra
.651 .747 .92 r
.837 .48044 .84155 .48658 .85257 .48331 .84806 .47726 Mtetra
.651 .751 .922 r
.84806 .47726 .85257 .48331 .86364 .48007 .85917 .47405 Mtetra
.653 .754 .924 r
.85917 .47405 .86364 .48007 .87476 .47682 .87031 .4708 Mtetra
.654 .755 .924 r
.87031 .4708 .87476 .47682 .88591 .47354 .8815 .4675 Mtetra
.655 .755 .924 r
.8815 .4675 .88591 .47354 .89711 .47024 .89273 .46415 Mtetra
.656 .755 .923 r
.89273 .46415 .89711 .47024 .90834 .46691 .90399 .46077 Mtetra
.657 .754 .922 r
.90399 .46077 .90834 .46691 .91962 .46355 .9153 .45736 Mtetra
.657 .753 .921 r
.9153 .45736 .91962 .46355 .93095 .46018 .92665 .45393 Mtetra
.652 .751 .922 r
.31818 .62896 .32399 .63404 .33318 .63133 .32738 .62628 Mtetra
.652 .752 .923 r
.32738 .62628 .33318 .63133 .3424 .6286 .33661 .62358 Mtetra
.653 .754 .924 r
.33661 .62358 .3424 .6286 .35165 .62585 .34588 .62086 Mtetra
.654 .756 .925 r
.34588 .62086 .35165 .62585 .36093 .62307 .35518 .61811 Mtetra
.655 .758 .926 r
.35518 .61811 .36093 .62307 .37025 .62025 .36452 .61531 Mtetra
.657 .76 .926 r
.36452 .61531 .37025 .62025 .3796 .61738 .37389 .61244 Mtetra
.661 .762 .925 r
.37389 .61244 .3796 .61738 .38899 .61447 .3833 .60949 Mtetra
.663 .762 .923 r
.3833 .60949 .38899 .61447 .3984 .61154 .39274 .60647 Mtetra
.666 .76 .92 r
.39274 .60647 .3984 .61154 .40786 .60861 .40222 .60337 Mtetra
.667 .754 .916 r
.40222 .60337 .40786 .60861 .41734 .60574 .41173 .60026 Mtetra
.665 .746 .91 r
.41173 .60026 .41734 .60574 .42685 .603 .42127 .59718 Mtetra
.657 .732 .905 r
.42127 .59718 .42685 .603 .43638 .60047 .43084 .5943 Mtetra
.645 .717 .9 r
.43084 .5943 .43638 .60047 .44595 .59824 .44043 .59173 Mtetra
.629 .701 .897 r
.44043 .59173 .44595 .59824 .45555 .59625 .45005 .58955 Mtetra
.61 .689 .898 r
.45005 .58955 .45555 .59625 .46519 .59446 .4597 .58783 Mtetra
.606 .69 .902 r
.4597 .58783 .46519 .59446 .47486 .59243 .46939 .58619 Mtetra
.614 .706 .911 r
.46939 .58619 .47486 .59243 .48459 .58983 .47912 .58433 Mtetra
.658 .748 .916 r
.47912 .58433 .48459 .58983 .49436 .58599 .48891 .58134 Mtetra
.723 .796 .91 r
.48891 .58134 .49436 .58599 .50417 .58046 .49874 .57659 Mtetra
.792 .834 .884 r
.49874 .57659 .50417 .58046 .51401 .57318 .50862 .56954 Mtetra
.839 .839 .846 r
.50862 .56954 .51401 .57318 .52386 .56438 .5185 .5602 Mtetra
.835 .821 .836 r
.5185 .5602 .52386 .56438 .53371 .55587 .52839 .5507 Mtetra
.799 .79 .844 r
.52839 .5507 .53371 .55587 .54357 .5489 .53828 .54265 Mtetra
.684 .733 .887 r
.53828 .54265 .54357 .5489 .55347 .5451 .5482 .53886 Mtetra
.418 .622 .937 r
.5482 .53886 .55347 .5451 .56345 .54495 .55821 .54033 Mtetra
0 .42 .849 r
.55821 .54033 .56345 .54495 .5735 .54671 .56832 .54503 Mtetra
.51 0 0 r
.56832 .54503 .5735 .54671 .58364 .5492 .57854 .55131 Mtetra
.57 .032 0 r
.57854 .55131 .58364 .5492 .59381 .55056 .58882 .55592 Mtetra
.469 0 .041 r
.58882 .55592 .59381 .55056 .60401 .54983 .59911 .55711 Mtetra
.297 0 .032 r
.59911 .55711 .60401 .54983 .61419 .54678 .60936 .55406 Mtetra
.001 0 0 r
.60936 .55406 .61419 .54678 .62434 .54142 .61953 .54675 Mtetra
0 0 0 r
.61953 .54675 .62434 .54142 .63445 .53395 .6296 .53598 Mtetra
.865 .994 .752 r
.6296 .53598 .63445 .53395 .64453 .52532 .6396 .52352 Mtetra
.884 .922 .843 r
.6396 .52352 .64453 .52532 .65464 .5174 .64964 .51262 Mtetra
.797 .818 .868 r
.64964 .51262 .65464 .5174 .66483 .51141 .65981 .50494 Mtetra
.629 .714 .908 r
.65981 .50494 .66483 .51141 .67521 .50909 .67021 .50256 Mtetra
.4 .605 .93 r
.67021 .50256 .67521 .50909 .6858 .50999 .68086 .50451 Mtetra
.225 .547 .929 r
.68086 .50451 .6858 .50999 .69652 .51246 .69166 .50795 Mtetra
.158 .548 .927 r
.69166 .50795 .69652 .51246 .70734 .51526 .70253 .51126 Mtetra
.341 .685 .98 r
.70253 .51126 .70734 .51526 .71815 .51652 .71335 .51225 Mtetra
.538 .772 .984 r
.71335 .51225 .71815 .51652 .72892 .51601 .7241 .5109 Mtetra
.649 .78 .943 r
.7241 .5109 .72892 .51601 .73964 .51378 .73479 .50776 Mtetra
.694 .761 .903 r
.73479 .50776 .73964 .51378 .75032 .51029 .74544 .50347 Mtetra
.698 .736 .881 r
.74544 .50347 .75032 .51029 .76099 .50619 .75612 .49894 Mtetra
.693 .722 .872 r
.75612 .49894 .76099 .50619 .77168 .50185 .76683 .49448 Mtetra
.679 .714 .875 r
.76683 .49448 .77168 .50185 .78243 .49772 .77761 .49049 Mtetra
.667 .714 .884 r
.77761 .49049 .78243 .49772 .79322 .49382 .78845 .4869 Mtetra
.656 .72 .896 r
.78845 .4869 .79322 .49382 .80408 .49023 .79937 .48364 Mtetra
.649 .729 .907 r
.79937 .48364 .80408 .49023 .815 .48686 .81034 .48057 Mtetra
.646 .739 .917 r
.81034 .48057 .815 .48686 .82597 .48362 .82137 .47753 Mtetra
.646 .747 .923 r
.82137 .47753 .82597 .48362 .837 .48044 .83243 .47449 Mtetra
.648 .754 .927 r
.83243 .47449 .837 .48044 .84806 .47726 .84354 .47136 Mtetra
.65 .758 .928 r
.84354 .47136 .84806 .47726 .85917 .47405 .85468 .46815 Mtetra
.653 .76 .928 r
.85468 .46815 .85917 .47405 .87031 .4708 .86585 .46485 Mtetra
.655 .76 .927 r
.86585 .46485 .87031 .4708 .8815 .4675 .87707 .46149 Mtetra
.657 .759 .925 r
.87707 .46149 .8815 .4675 .89273 .46415 .88832 .45807 Mtetra
.658 .758 .924 r
.88832 .45807 .89273 .46415 .90399 .46077 .89961 .45461 Mtetra
.659 .756 .922 r
.89961 .45461 .90399 .46077 .9153 .45736 .91094 .45113 Mtetra
.659 .754 .921 r
.91094 .45113 .9153 .45736 .92665 .45393 .92232 .44763 Mtetra
.651 .75 .922 r
.31232 .62385 .31818 .62896 .32738 .62628 .32154 .62119 Mtetra
.65 .751 .924 r
.32154 .62119 .32738 .62628 .33661 .62358 .33079 .61852 Mtetra
.65 .753 .925 r
.33079 .61852 .33661 .62358 .34588 .62086 .34008 .61584 Mtetra
.651 .755 .926 r
.34008 .61584 .34588 .62086 .35518 .61811 .3494 .61312 Mtetra
.652 .758 .927 r
.3494 .61312 .35518 .61811 .36452 .61531 .35875 .61037 Mtetra
.655 .761 .928 r
.35875 .61037 .36452 .61531 .37389 .61244 .36814 .60755 Mtetra
.658 .764 .928 r
.36814 .60755 .37389 .61244 .3833 .60949 .37757 .60463 Mtetra
.663 .767 .928 r
.37757 .60463 .3833 .60949 .39274 .60647 .38703 .60159 Mtetra
.669 .769 .925 r
.38703 .60159 .39274 .60647 .40222 .60337 .39654 .5984 Mtetra
.673 .767 .921 r
.39654 .5984 .40222 .60337 .41173 .60026 .40607 .59509 Mtetra
.677 .761 .915 r
.40607 .59509 .41173 .60026 .42127 .59718 .41565 .59168 Mtetra
.673 .749 .908 r
.41565 .59168 .42127 .59718 .43084 .5943 .42525 .58837 Mtetra
.663 .732 .901 r
.42525 .58837 .43084 .5943 .44043 .59173 .43487 .5853 Mtetra
.645 .71 .895 r
.43487 .5853 .44043 .59173 .45005 .58955 .44452 .5827 Mtetra
.62 .688 .892 r
.44452 .5827 .45005 .58955 .4597 .58783 .45419 .58075 Mtetra
.601 .674 .892 r
.45419 .58075 .4597 .58783 .46939 .58619 .46389 .57927 Mtetra
.586 .674 .901 r
.46389 .57927 .46939 .58619 .47912 .58433 .47363 .57808 Mtetra
.614 .708 .912 r
.47363 .57808 .47912 .58433 .48891 .58134 .48342 .57616 Mtetra
.674 .767 .92 r
.48342 .57616 .48891 .58134 .49874 .57659 .49327 .57274 Mtetra
.769 .835 .903 r
.49327 .57274 .49874 .57659 .50862 .56954 .50317 .56659 Mtetra
.845 .866 .858 r
.50317 .56659 .50862 .56954 .5185 .5602 .5131 .55733 Mtetra
.863 .865 .839 r
.5131 .55733 .5185 .5602 .52839 .5507 .52303 .54701 Mtetra
.842 .841 .843 r
.52303 .54701 .52839 .5507 .53828 .54265 .53295 .53745 Mtetra
.709 .777 .906 r
.53295 .53745 .53828 .54265 .5482 .53886 .54289 .53303 Mtetra
.321 .589 .94 r
.54289 .53303 .5482 .53886 .55821 .54033 .55293 .53543 Mtetra
0 .204 .684 r
.55293 .53543 .55821 .54033 .56832 .54503 .56308 .54274 Mtetra
.692 .151 0 r
.56308 .54274 .56832 .54503 .57854 .55131 .57338 .55298 Mtetra
.694 .186 .024 r
.57338 .55298 .57854 .55131 .58882 .55592 .58376 .56119 Mtetra
.56 .09 .096 r
.58376 .56119 .58882 .55592 .59911 .55711 .59415 .56464 Mtetra
.302 0 .04 r
.59415 .56464 .59911 .55711 .60936 .55406 .60446 .56158 Mtetra
0 0 0 r
.60446 .56158 .60936 .55406 .61953 .54675 .61464 .55199 Mtetra
.738 .916 .554 r
.61464 .55199 .61953 .54675 .6296 .53598 .62468 .53759 Mtetra
.945 .959 .721 r
.62468 .53759 .6296 .53598 .6396 .52352 .63461 .52111 Mtetra
.911 .885 .795 r
.63461 .52111 .6396 .52352 .64964 .51262 .6446 .50753 Mtetra
.813 .81 .848 r
.6446 .50753 .64964 .51262 .65981 .50494 .65476 .49887 Mtetra
.599 .719 .928 r
.65476 .49887 .65981 .50494 .67021 .50256 .66522 .4971 Mtetra
.219 .545 .929 r
.66522 .4971 .67021 .50256 .68086 .50451 .67596 .50054 Mtetra
0 .462 .864 r
.67596 .50054 .68086 .50451 .69166 .50795 .68682 .50477 Mtetra
.024 .517 .875 r
.68682 .50477 .69166 .50795 .70253 .51126 .69771 .50795 Mtetra
.375 .739 .99 r
.69771 .50795 .70253 .51126 .71335 .51225 .70851 .50799 Mtetra
.619 .806 .972 r
.70851 .50799 .71335 .51225 .7241 .5109 .71921 .50525 Mtetra
.694 .775 .914 r
.71921 .50525 .7241 .5109 .73479 .50776 .72986 .50097 Mtetra
.712 .743 .876 r
.72986 .50097 .73479 .50776 .74544 .50347 .7405 .49594 Mtetra
.699 .717 .863 r
.7405 .49594 .74544 .50347 .75612 .49894 .75118 .4912 Mtetra
.685 .707 .864 r
.75118 .4912 .75612 .49894 .76683 .49448 .76193 .48694 Mtetra
.666 .705 .876 r
.76193 .48694 .76683 .49448 .77761 .49049 .77277 .48334 Mtetra
.651 .711 .892 r
.77277 .48334 .77761 .49049 .78845 .4869 .78368 .48022 Mtetra
.641 .724 .908 r
.78368 .48022 .78845 .4869 .79937 .48364 .79466 .47736 Mtetra
.635 .736 .921 r
.79466 .47736 .79937 .48364 .81034 .48057 .80569 .47459 Mtetra
.638 .749 .929 r
.80569 .47459 .81034 .48057 .82137 .47753 .81675 .47172 Mtetra
.641 .757 .933 r
.81675 .47172 .82137 .47753 .83243 .47449 .82786 .46872 Mtetra
.647 .762 .933 r
.82786 .46872 .83243 .47449 .84354 .47136 .83899 .46557 Mtetra
.651 .764 .932 r
.83899 .46557 .84354 .47136 .85468 .46815 .85016 .46229 Mtetra
.655 .764 .93 r
.85016 .46229 .85468 .46815 .86585 .46485 .86136 .4589 Mtetra
.658 .762 .927 r
.86136 .4589 .86585 .46485 .87707 .46149 .8726 .45545 Mtetra
.659 .76 .925 r
.8726 .45545 .87707 .46149 .88832 .45807 .88388 .45194 Mtetra
.66 .758 .923 r
.88388 .45194 .88832 .45807 .89961 .45461 .8952 .4484 Mtetra
.66 .757 .921 r
.8952 .4484 .89961 .45461 .91094 .45113 .90656 .44485 Mtetra
.66 .755 .92 r
.90656 .44485 .91094 .45113 .92232 .44763 .91796 .44128 Mtetra
.65 .75 .923 r
.30643 .61871 .31232 .62385 .32154 .62119 .31567 .61605 Mtetra
.649 .75 .924 r
.31567 .61605 .32154 .62119 .33079 .61852 .32494 .61339 Mtetra
.649 .751 .925 r
.32494 .61339 .33079 .61852 .34008 .61584 .33424 .61073 Mtetra
.648 .753 .926 r
.33424 .61073 .34008 .61584 .3494 .61312 .34358 .60806 Mtetra
.648 .755 .928 r
.34358 .60806 .3494 .61312 .35875 .61037 .35295 .60538 Mtetra
.65 .759 .929 r
.35295 .60538 .35875 .61037 .36814 .60755 .36235 .60265 Mtetra
.652 .764 .931 r
.36235 .60265 .36814 .60755 .37757 .60463 .3718 .59984 Mtetra
.658 .771 .933 r
.3718 .59984 .37757 .60463 .38703 .60159 .38128 .59689 Mtetra
.666 .777 .932 r
.38128 .59689 .38703 .60159 .39654 .5984 .3908 .59374 Mtetra
.675 .781 .93 r
.3908 .59374 .39654 .5984 .40607 .59509 .40036 .59035 Mtetra
.686 .781 .923 r
.40036 .59035 .40607 .59509 .41565 .59168 .40997 .58669 Mtetra
.689 .773 .915 r
.40997 .58669 .41565 .59168 .42525 .58837 .4196 .58293 Mtetra
.687 .757 .905 r
.4196 .58293 .42525 .58837 .43487 .5853 .42927 .57921 Mtetra
.67 .73 .895 r
.42927 .57921 .43487 .5853 .44452 .5827 .43895 .57591 Mtetra
.643 .7 .887 r
.43895 .57591 .44452 .5827 .45419 .58075 .44865 .57332 Mtetra
.61 .669 .882 r
.44865 .57332 .45419 .58075 .46389 .57927 .45837 .57162 Mtetra
.571 .647 .886 r
.45837 .57162 .46389 .57927 .47363 .57808 .46812 .57087 Mtetra
.567 .659 .899 r
.46812 .57087 .47363 .57808 .48342 .57616 .47791 .57012 Mtetra
.594 .71 .924 r
.47791 .57012 .48342 .57616 .49327 .57274 .48776 .56856 Mtetra
.711 .817 .931 r
.48776 .56856 .49327 .57274 .50317 .56659 .49768 .56414 Mtetra
.829 .891 .886 r
.49768 .56414 .50317 .56659 .5131 .55733 .50764 .5559 Mtetra
.882 .915 .844 r
.50764 .5559 .5131 .55733 .52303 .54701 .51762 .54517 Mtetra
.889 .896 .828 r
.51762 .54517 .52303 .54701 .53295 .53745 .52758 .53371 Mtetra
.763 .845 .913 r
.52758 .53371 .53295 .53745 .54289 .53303 .53756 .52774 Mtetra
.309 .607 .952 r
.53756 .52774 .54289 .53303 .55293 .53543 .5476 .52987 Mtetra
0 .102 .608 r
.5476 .52987 .55293 .53543 .56308 .54274 .55778 .53888 Mtetra
.755 .252 0 r
.55778 .53888 .56308 .54274 .57338 .55298 .56814 .55271 Mtetra
.767 .265 .01 r
.56814 .55271 .57338 .55298 .58376 .56119 .5786 .56449 Mtetra
.627 .128 .045 r
.5786 .56449 .58376 .56119 .59415 .56464 .58907 .57034 Mtetra
.213 0 0 r
.58907 .57034 .59415 .56464 .60446 .56158 .59945 .56726 Mtetra
.563 .832 .48 r
.59945 .56726 .60446 .56158 .61464 .55199 .60964 .55525 Mtetra
.935 .962 .667 r
.60964 .55525 .61464 .55199 .62468 .53759 .61964 .53724 Mtetra
.965 .891 .705 r
.61964 .53724 .62468 .53759 .63461 .52111 .62953 .51711 Mtetra
.905 .832 .764 r
.62953 .51711 .63461 .52111 .6446 .50753 .63951 .50178 Mtetra
.8 .788 .841 r
.63951 .50178 .6446 .50753 .65476 .49887 .64971 .49336 Mtetra
.506 .701 .958 r
.64971 .49336 .65476 .49887 .66522 .4971 .66025 .49311 Mtetra
0 .368 .795 r
.66025 .49311 .66522 .4971 .67596 .50054 .6711 .49844 Mtetra
0 .311 .657 r
.6711 .49844 .67596 .50054 .68682 .50477 .68201 .50305 Mtetra
0 .525 .802 r
.68201 .50305 .68682 .50477 .69771 .50795 .69288 .50516 Mtetra
.499 .825 1 r
.69288 .50516 .69771 .50795 .70851 .50799 .70362 .50339 Mtetra
.709 .821 .935 r
.70362 .50339 .70851 .50799 .71921 .50525 .71424 .49871 Mtetra
.727 .756 .876 r
.71424 .49871 .71921 .50525 .72986 .50097 .72484 .49319 Mtetra
.718 .718 .849 r
.72484 .49319 .72986 .50097 .7405 .49594 .73547 .48766 Mtetra
.69 .695 .85 r
.73547 .48766 .7405 .49594 .75118 .4912 .74619 .48311 Mtetra
.666 .69 .863 r
.74619 .48311 .75118 .4912 .76193 .48694 .75701 .47945 Mtetra
.644 .699 .886 r
.75701 .47945 .76193 .48694 .77277 .48334 .76792 .47654 Mtetra
.627 .714 .909 r
.76792 .47654 .77277 .48334 .78368 .48022 .77891 .47405 Mtetra
.622 .735 .928 r
.77891 .47405 .78368 .48022 .79466 .47736 .78995 .4716 Mtetra
.622 .751 .939 r
.78995 .4716 .79466 .47736 .80569 .47459 .80104 .46905 Mtetra
.632 .765 .943 r
.80104 .46905 .80569 .47459 .81675 .47172 .81214 .46621 Mtetra
.641 .771 .942 r
.81214 .46621 .81675 .47172 .82786 .46872 .82327 .46314 Mtetra
.65 .772 .938 r
.82327 .46314 .82786 .46872 .83899 .46557 .83443 .45985 Mtetra
.656 .771 .934 r
.83443 .45985 .83899 .46557 .85016 .46229 .84562 .45641 Mtetra
.659 .767 .929 r
.84562 .45641 .85016 .46229 .86136 .4589 .85684 .45289 Mtetra
.661 .763 .925 r
.85684 .45289 .86136 .4589 .8726 .45545 .8681 .44932 Mtetra
.662 .76 .923 r
.8681 .44932 .8726 .45545 .88388 .45194 .8794 .44572 Mtetra
.662 .757 .921 r
.8794 .44572 .88388 .45194 .8952 .4484 .89075 .44212 Mtetra
.662 .756 .92 r
.89075 .44212 .8952 .4484 .90656 .44485 .90214 .4385 Mtetra
.661 .754 .919 r
.90214 .4385 .90656 .44485 .91796 .44128 .91357 .43489 Mtetra
.651 .75 .922 r
.3005 .61354 .30643 .61871 .31567 .61605 .30976 .61084 Mtetra
.65 .749 .922 r
.30976 .61084 .31567 .61605 .32494 .61339 .31905 .60815 Mtetra
.649 .749 .923 r
.31905 .60815 .32494 .61339 .33424 .61073 .32837 .60548 Mtetra
.647 .749 .923 r
.32837 .60548 .33424 .61073 .34358 .60806 .33772 .60283 Mtetra
.646 .749 .925 r
.33772 .60283 .34358 .60806 .35295 .60538 .34711 .6002 Mtetra
.645 .752 .927 r
.34711 .6002 .35295 .60538 .36235 .60265 .35653 .59756 Mtetra
.645 .756 .93 r
.35653 .59756 .36235 .60265 .3718 .59984 .36599 .59491 Mtetra
.649 .764 .933 r
.36599 .59491 .3718 .59984 .38128 .59689 .37548 .59214 Mtetra
.657 .774 .935 r
.37548 .59214 .38128 .59689 .3908 .59374 .38502 .58917 Mtetra
.669 .785 .936 r
.38502 .58917 .3908 .59374 .40036 .59035 .3946 .58591 Mtetra
.686 .794 .932 r
.3946 .58591 .40036 .59035 .40997 .58669 .40423 .58222 Mtetra
.698 .796 .925 r
.40423 .58222 .40997 .58669 .4196 .58293 .4139 .5782 Mtetra
.708 .789 .914 r
.4139 .5782 .4196 .58293 .42927 .57921 .42361 .57391 Mtetra
.7 .767 .903 r
.42361 .57391 .42927 .57921 .43895 .57591 .43334 .56979 Mtetra
.68 .734 .891 r
.43334 .56979 .43895 .57591 .44865 .57332 .44308 .56618 Mtetra
.638 .689 .881 r
.44308 .56618 .44865 .57332 .45837 .57162 .45283 .5637 Mtetra
.58 .644 .878 r
.45283 .5637 .45837 .57162 .46812 .57087 .46259 .56274 Mtetra
.54 .621 .881 r
.46259 .56274 .46812 .57087 .47791 .57012 .47238 .56274 Mtetra
.511 .631 .905 r
.47238 .56274 .47791 .57012 .48776 .56856 .48223 .56309 Mtetra
.609 .739 .938 r
.48223 .56309 .48776 .56856 .49768 .56414 .49215 .5611 Mtetra
.76 .872 .929 r
.49215 .5611 .49768 .56414 .50764 .5559 .50213 .55525 Mtetra
.871 .948 .86 r
.50213 .55525 .50764 .5559 .51762 .54517 .51216 .54519 Mtetra
.918 .941 .802 r
.51216 .54519 .51762 .54517 .52758 .53371 .52218 .53212 Mtetra
.833 .929 .895 r
.52218 .53212 .52758 .53371 .53756 .52774 .53218 .52379 Mtetra
.432 .734 .99 r
.53218 .52379 .53756 .52774 .5476 .52987 .54224 .52371 Mtetra
0 .167 .681 r
.54224 .52371 .5476 .52987 .55778 .53888 .55242 .53228 Mtetra
.685 .221 0 r
.55242 .53228 .55778 .53888 .56814 .55271 .56279 .5478 Mtetra
.711 .214 0 r
.56279 .5478 .56814 .55271 .5786 .56449 .57329 .5618 Mtetra
.521 0 0 r
.57329 .5618 .5786 .56449 .58907 .57034 .58382 .56947 Mtetra
.492 .887 .954 r
.58382 .56947 .58907 .57034 .59945 .56726 .59423 .56638 Mtetra
.923 .926 .795 r
.59423 .56638 .59945 .56726 .60964 .55525 .60443 .5525 Mtetra
.942 .839 .714 r
.60443 .5525 .60964 .55525 .61964 .53724 .61443 .53223 Mtetra
.922 .791 .698 r
.61443 .53223 .61964 .53724 .62953 .51711 .62432 .51035 Mtetra
.864 .765 .751 r
.62432 .51035 .62953 .51711 .63951 .50178 .63436 .49543 Mtetra
.748 .761 .863 r
.63436 .49543 .63951 .50178 .64971 .49336 .64467 .48919 Mtetra
.235 .618 .956 r
.64467 .48919 .64971 .49336 .66025 .49311 .65534 .49129 Mtetra
.495 0 0 r
.65534 .49129 .66025 .49311 .6711 .49844 .66628 .49821 Mtetra
.385 0 0 r
.66628 .49821 .6711 .49844 .68201 .50305 .67719 .50211 Mtetra
.167 .696 .86 r
.67719 .50211 .68201 .50305 .69288 .50516 .68798 .50176 Mtetra
.681 .866 .969 r
.68798 .50176 .69288 .50516 .70362 .50339 .69862 .49748 Mtetra
.761 .786 .873 r
.69862 .49748 .70362 .50339 .71424 .49871 .70916 .4908 Mtetra
.735 .721 .838 r
.70916 .4908 .71424 .49871 .72484 .49319 .71974 .48448 Mtetra
.706 .691 .833 r
.71974 .48448 .72484 .49319 .73547 .48766 .73041 .47911 Mtetra
.668 .68 .852 r
.73041 .47911 .73547 .48766 .74619 .48311 .7412 .47531 Mtetra
.634 .686 .881 r
.7412 .47531 .74619 .48311 .75701 .47945 .75211 .47265 Mtetra
.612 .708 .914 r
.75211 .47265 .75701 .47945 .76792 .47654 .76311 .47053 Mtetra
.597 .732 .939 r
.76311 .47053 .76792 .47654 .77891 .47405 .77417 .46859 Mtetra
.603 .757 .952 r
.77417 .46859 .77891 .47405 .78995 .4716 .78526 .46637 Mtetra
.615 .772 .955 r
.78526 .46637 .78995 .4716 .80104 .46905 .79638 .46381 Mtetra
.635 .78 .951 r
.79638 .46381 .80104 .46905 .81214 .46621 .8075 .46081 Mtetra
.649 .78 .943 r
.8075 .46081 .81214 .46621 .82327 .46314 .81865 .45749 Mtetra
.658 .775 .935 r
.81865 .45749 .82327 .46314 .83443 .45985 .82982 .45398 Mtetra
.663 .769 .928 r
.82982 .45398 .83443 .45985 .84562 .45641 .84102 .45033 Mtetra
.664 .762 .923 r
.84102 .45033 .84562 .45641 .85684 .45289 .85226 .44667 Mtetra
.664 .758 .92 r
.85226 .44667 .85684 .45289 .8681 .44932 .86355 .44299 Mtetra
.663 .755 .918 r
.86355 .44299 .8681 .44932 .8794 .44572 .87488 .43934 Mtetra
.662 .753 .918 r
.87488 .43934 .8794 .44572 .89075 .44212 .88626 .4357 Mtetra
.661 .753 .918 r
.88626 .4357 .89075 .44212 .90214 .4385 .89768 .43207 Mtetra
.66 .753 .918 r
.89768 .43207 .90214 .4385 .91357 .43489 .90915 .42846 Mtetra
.653 .751 .921 r
.29453 .60833 .3005 .61354 .30976 .61084 .30381 .60555 Mtetra
.653 .748 .92 r
.30381 .60555 .30976 .61084 .31905 .60815 .31313 .60278 Mtetra
.651 .746 .919 r
.31313 .60278 .31905 .60815 .32837 .60548 .32247 .60004 Mtetra
.649 .743 .918 r
.32247 .60004 .32837 .60548 .33772 .60283 .33185 .59735 Mtetra
.645 .741 .919 r
.33185 .59735 .33772 .60283 .34711 .6002 .34125 .59472 Mtetra
.642 .741 .921 r
.34125 .59472 .34711 .6002 .35653 .59756 .35069 .59216 Mtetra
.638 .744 .925 r
.35069 .59216 .35653 .59756 .36599 .59491 .36015 .58967 Mtetra
.638 .751 .93 r
.36015 .58967 .36599 .59491 .37548 .59214 .36966 .58715 Mtetra
.641 .762 .936 r
.36966 .58715 .37548 .59214 .38502 .58917 .3792 .58453 Mtetra
.652 .779 .941 r
.3792 .58453 .38502 .58917 .3946 .58591 .38879 .58162 Mtetra
.671 .799 .943 r
.38879 .58162 .3946 .58591 .40423 .58222 .39844 .57823 Mtetra
.694 .817 .941 r
.39844 .57823 .40423 .58222 .4139 .5782 .40813 .57429 Mtetra
.72 .824 .93 r
.40813 .57429 .4139 .5782 .42361 .57391 .41787 .56967 Mtetra
.73 .813 .917 r
.41787 .56967 .42361 .57391 .43334 .56979 .42765 .56476 Mtetra
.727 .784 .898 r
.42765 .56476 .43334 .56979 .44308 .56618 .43745 .55982 Mtetra
.687 .73 .883 r
.43745 .55982 .44308 .56618 .45283 .5637 .44726 .55594 Mtetra
.622 .667 .872 r
.44726 .55594 .45283 .5637 .46259 .56274 .45705 .55388 Mtetra
.547 .606 .863 r
.45705 .55388 .46259 .56274 .47238 .56274 .46685 .55382 Mtetra
.456 .559 .872 r
.46685 .55382 .47238 .56274 .48223 .56309 .47668 .55567 Mtetra
.478 .616 .909 r
.47668 .55567 .48223 .56309 .49215 .5611 .48658 .55659 Mtetra
.59 .775 .968 r
.48658 .55659 .49215 .5611 .50213 .55525 .49657 .55465 Mtetra
.81 .965 .907 r
.49657 .55465 .50213 .55525 .51216 .54519 .50663 .54681 Mtetra
.919 .973 .774 r
.50663 .54681 .51216 .54519 .52218 .53212 .51671 .53304 Mtetra
.881 .984 .823 r
.51671 .53304 .52218 .53212 .53218 .52379 .52677 .52179 Mtetra
.687 .911 .972 r
.52677 .52179 .53218 .52379 .54224 .52371 .53684 .51722 Mtetra
.092 .428 .871 r
.53684 .51722 .54224 .52371 .55242 .53228 .547 .52241 Mtetra
0 0 .563 r
.547 .52241 .55242 .53228 .56279 .5478 .55734 .53659 Mtetra
0 .066 .63 r
.55734 .53659 .56279 .5478 .57329 .5618 .56782 .55048 Mtetra
.169 .335 .788 r
.56782 .55048 .57329 .5618 .58382 .56947 .57835 .55877 Mtetra
.644 .62 .811 r
.57835 .55877 .58382 .56947 .59423 .56638 .58878 .55566 Mtetra
.812 .688 .728 r
.58878 .55566 .59423 .56638 .60443 .5525 .59899 .5411 Mtetra
.845 .69 .691 r
.59899 .5411 .60443 .5525 .61443 .53223 .60903 .52089 Mtetra
.848 .692 .689 r
.60903 .52089 .61443 .53223 .62432 .51035 .61899 .50031 Mtetra
.792 .691 .753 r
.61899 .50031 .62432 .51035 .63436 .49543 .62916 .48874 Mtetra
.6 .701 .914 r
.62916 .48874 .63436 .49543 .64467 .48919 .63966 .48699 Mtetra
.311 0 0 r
.63966 .48699 .64467 .48919 .65534 .49129 .65047 .49201 Mtetra
.64 .09 0 r
.65047 .49201 .65534 .49129 .66628 .49821 .66147 .49961 Mtetra
.315 0 0 r
.66147 .49961 .66628 .49821 .67719 .50211 .67233 .50123 Mtetra
.586 .93 .952 r
.67233 .50123 .67719 .50211 .68798 .50176 .68296 .49686 Mtetra
.785 .826 .884 r
.68296 .49686 .68798 .50176 .69862 .49748 .69349 .48957 Mtetra
.772 .733 .817 r
.69349 .48957 .69862 .49748 .70916 .4908 .70397 .48132 Mtetra
.72 .681 .811 r
.70397 .48132 .70916 .4908 .71974 .48448 .71458 .47499 Mtetra
.675 .662 .83 r
.71458 .47499 .71974 .48448 .73041 .47911 .72533 .47072 Mtetra
.626 .667 .87 r
.72533 .47072 .73041 .47911 .7412 .47531 .73623 .4683 Mtetra
.579 .688 .916 r
.73623 .4683 .7412 .47531 .75211 .47265 .74726 .46698 Mtetra
.562 .73 .954 r
.74726 .46698 .75211 .47265 .76311 .47053 .75834 .46563 Mtetra
.562 .763 .972 r
.75834 .46563 .76311 .47053 .77417 .46859 .76946 .46397 Mtetra
.593 .79 .974 r
.76946 .46397 .77417 .46859 .78526 .46637 .78058 .46163 Mtetra
.624 .798 .966 r
.78058 .46163 .78526 .46637 .79638 .46381 .7917 .45872 Mtetra
.65 .794 .951 r
.7917 .45872 .79638 .46381 .8075 .46081 .80283 .45531 Mtetra
.665 .784 .937 r
.80283 .45531 .8075 .46081 .81865 .45749 .81397 .45159 Mtetra
.67 .771 .926 r
.81397 .45159 .81865 .45749 .82982 .45398 .82515 .44777 Mtetra
.671 .761 .918 r
.82515 .44777 .82982 .45398 .84102 .45033 .83636 .44391 Mtetra
.668 .753 .914 r
.83636 .44391 .84102 .45033 .85226 .44667 .84763 .44013 Mtetra
.665 .749 .913 r
.84763 .44013 .85226 .44667 .86355 .44299 .85894 .43641 Mtetra
.663 .747 .913 r
.85894 .43641 .86355 .44299 .87488 .43934 .87031 .43275 Mtetra
.66 .747 .914 r
.87031 .43275 .87488 .43934 .88626 .4357 .88172 .42914 Mtetra
.659 .748 .916 r
.88172 .42914 .88626 .4357 .89768 .43207 .89318 .42555 Mtetra
.658 .75 .918 r
.89318 .42555 .89768 .43207 .90915 .42846 .90469 .42197 Mtetra
.657 .752 .92 r
.28853 .60308 .29453 .60833 .30381 .60555 .29783 .6002 Mtetra
.657 .748 .917 r
.29783 .6002 .30381 .60555 .31313 .60278 .30717 .59731 Mtetra
.655 .744 .915 r
.30717 .59731 .31313 .60278 .32247 .60004 .31654 .59445 Mtetra
.653 .74 .914 r
.31654 .59445 .32247 .60004 .33185 .59735 .32594 .59165 Mtetra
.649 .736 .913 r
.32594 .59165 .33185 .59735 .34125 .59472 .33537 .58894 Mtetra
.643 .732 .913 r
.33537 .58894 .34125 .59472 .35069 .59216 .34482 .58635 Mtetra
.636 .729 .915 r
.34482 .58635 .35069 .59216 .36015 .58967 .3543 .58391 Mtetra
.631 .731 .919 r
.3543 .58391 .36015 .58967 .36966 .58715 .36382 .58158 Mtetra
.626 .737 .927 r
.36382 .58158 .36966 .58715 .3792 .58453 .37336 .57932 Mtetra
.631 .752 .935 r
.37336 .57932 .3792 .58453 .38879 .58162 .38296 .57689 Mtetra
.644 .776 .943 r
.38296 .57689 .38879 .58162 .39844 .57823 .3926 .57412 Mtetra
.67 .808 .949 r
.3926 .57412 .39844 .57823 .40813 .57429 .4023 .57069 Mtetra
.708 .837 .944 r
.4023 .57069 .40813 .57429 .41787 .56967 .41207 .56634 Mtetra
.741 .852 .932 r
.41207 .56634 .41787 .56967 .42765 .56476 .42188 .56113 Mtetra
.766 .842 .909 r
.42188 .56113 .42765 .56476 .43745 .55982 .43175 .5551 Mtetra
.745 .799 .896 r
.43175 .5551 .43745 .55982 .44726 .55594 .44162 .54959 Mtetra
.691 .734 .883 r
.44162 .54959 .44726 .55594 .45705 .55388 .45147 .54555 Mtetra
.598 .643 .867 r
.45147 .54555 .45705 .55388 .46685 .55382 .46131 .54413 Mtetra
.47 .548 .854 r
.46131 .54413 .46685 .55382 .47668 .55567 .47114 .54594 Mtetra
.403 .511 .854 r
.47114 .54594 .47668 .55567 .48658 .55659 .48102 .54905 Mtetra
.366 .556 .907 r
.48102 .54905 .48658 .55659 .49657 .55465 .49097 .55169 Mtetra
.665 .865 .975 r
.49097 .55169 .49657 .55465 .50663 .54681 .50105 .5479 Mtetra
.893 .981 .811 r
.50105 .5479 .50663 .54681 .51671 .53304 .51118 .53597 Mtetra
.872 .991 .742 r
.51118 .53597 .51671 .53304 .52677 .52179 .52131 .5229 Mtetra
.844 .996 .835 r
.52131 .5229 .52677 .52179 .53684 .51722 .53141 .51275 Mtetra
.524 .755 .98 r
.53141 .51275 .53684 .51722 .547 .52241 .54156 .51174 Mtetra
.088 .295 .776 r
.54156 .51174 .547 .52241 .55734 .53659 .55184 .52053 Mtetra
.237 .301 .727 r
.55184 .52053 .55734 .53659 .56782 .55048 .56224 .53072 Mtetra
.418 .384 .714 r
.56224 .53072 .56782 .55048 .57835 .55877 .57271 .53751 Mtetra
.613 .499 .699 r
.57271 .53751 .57835 .55877 .58878 .55566 .58312 .53436 Mtetra
.72 .564 .676 r
.58312 .53436 .58878 .55566 .59899 .5411 .59336 .52124 Mtetra
.755 .59 .673 r
.59336 .52124 .59899 .5411 .60903 .52089 .60349 .50467 Mtetra
.77 .619 .692 r
.60349 .50467 .60903 .52089 .61899 .50031 .61362 .48945 Mtetra
.692 .64 .793 r
.61362 .48945 .61899 .50031 .62916 .48874 .624 .48408 Mtetra
.086 .502 .901 r
.624 .48408 .62916 .48874 .63966 .48699 .63471 .48793 Mtetra
.616 .062 0 r
.63471 .48793 .63966 .48699 .65047 .49201 .64562 .49475 Mtetra
.601 .076 0 r
.64562 .49475 .65047 .49201 .66147 .49961 .65659 .50047 Mtetra
.2 .725 .732 r
.65659 .50047 .66147 .49961 .67233 .50123 .66731 .49795 Mtetra
.838 .889 .877 r
.66731 .49795 .67233 .50123 .68296 .49686 .67777 .48888 Mtetra
.792 .737 .801 r
.67777 .48888 .68296 .49686 .69349 .48957 .68821 .4793 Mtetra
.747 .677 .783 r
.68821 .4793 .69349 .48957 .70397 .48132 .69871 .47104 Mtetra
.686 .652 .81 r
.69871 .47104 .70397 .48132 .71458 .47499 .70942 .46606 Mtetra
.622 .652 .859 r
.70942 .46606 .71458 .47499 .72533 .47072 .72031 .46376 Mtetra
.554 .679 .922 r
.72031 .46376 .72533 .47072 .73623 .4683 .73134 .46297 Mtetra
.489 .711 .969 r
.73134 .46297 .73623 .4683 .74726 .46698 .74247 .46272 Mtetra
.505 .768 .99 r
.74247 .46272 .74726 .46698 .75834 .46563 .75361 .46164 Mtetra
.553 .802 .991 r
.75361 .46164 .75834 .46563 .76946 .46397 .76474 .45968 Mtetra
.616 .815 .977 r
.76474 .45968 .76946 .46397 .78058 .46163 .77585 .45676 Mtetra
.656 .806 .955 r
.77585 .45676 .78058 .46163 .7917 .45872 .78695 .45317 Mtetra
.674 .786 .933 r
.78695 .45317 .7917 .45872 .80283 .45531 .79807 .44921 Mtetra
.681 .769 .917 r
.79807 .44921 .80283 .45531 .81397 .45159 .80921 .44508 Mtetra
.678 .754 .908 r
.80921 .44508 .81397 .45159 .82515 .44777 .8204 .44102 Mtetra
.674 .745 .904 r
.8204 .44102 .82515 .44777 .83636 .44391 .83164 .43706 Mtetra
.668 .74 .904 r
.83164 .43706 .83636 .44391 .84763 .44013 .84293 .43326 Mtetra
.663 .738 .906 r
.84293 .43326 .84763 .44013 .85894 .43641 .85428 .42958 Mtetra
.659 .739 .909 r
.85428 .42958 .85894 .43641 .87031 .43275 .86569 .42599 Mtetra
.657 .741 .912 r
.86569 .42599 .87031 .43275 .88172 .42914 .87715 .42246 Mtetra
.655 .744 .915 r
.87715 .42246 .88172 .42914 .89318 .42555 .88865 .41895 Mtetra
.655 .748 .918 r
.88865 .41895 .89318 .42555 .90469 .42197 .90021 .41544 Mtetra
.661 .753 .918 r
.28248 .59781 .28853 .60308 .29783 .6002 .29181 .5948 Mtetra
.662 .749 .915 r
.29181 .5948 .29783 .6002 .30717 .59731 .30118 .59177 Mtetra
.661 .745 .912 r
.30118 .59177 .30717 .59731 .31654 .59445 .31058 .58875 Mtetra
.659 .739 .909 r
.31058 .58875 .31654 .59445 .32594 .59165 .32 .58578 Mtetra
.656 .733 .906 r
.32 .58578 .32594 .59165 .33537 .58894 .32946 .58287 Mtetra
.65 .725 .904 r
.32946 .58287 .33537 .58894 .34482 .58635 .33894 .58011 Mtetra
.641 .718 .903 r
.33894 .58011 .34482 .58635 .3543 .58391 .34845 .57757 Mtetra
.631 .711 .904 r
.34845 .57757 .3543 .58391 .36382 .58158 .35797 .57526 Mtetra
.618 .708 .91 r
.35797 .57526 .36382 .58158 .37336 .57932 .36753 .57324 Mtetra
.611 .715 .919 r
.36753 .57324 .37336 .57932 .38296 .57689 .37712 .57132 Mtetra
.607 .733 .934 r
.37712 .57132 .38296 .57689 .3926 .57412 .38674 .5694 Mtetra
.625 .773 .951 r
.38674 .5694 .3926 .57412 .4023 .57069 .39643 .56696 Mtetra
.662 .824 .962 r
.39643 .56696 .4023 .57069 .41207 .56634 .40619 .5636 Mtetra
.717 .876 .955 r
.40619 .5636 .41207 .56634 .42188 .56113 .41603 .55887 Mtetra
.781 .899 .925 r
.41603 .55887 .42188 .56113 .43175 .5551 .42594 .55241 Mtetra
.797 .881 .908 r
.42594 .55241 .43175 .5551 .44162 .54959 .43588 .54541 Mtetra
.779 .825 .888 r
.43588 .54541 .44162 .54959 .45147 .54555 .44583 .53874 Mtetra
.694 .722 .872 r
.44583 .53874 .45147 .54555 .46131 .54413 .45574 .53452 Mtetra
.562 .598 .847 r
.45574 .53452 .46131 .54413 .47114 .54594 .46561 .53414 Mtetra
.414 .474 .813 r
.46561 .53414 .47114 .54594 .48102 .54905 .47547 .53784 Mtetra
.218 .368 .801 r
.47547 .53784 .48102 .54905 .49097 .55169 .48538 .54477 Mtetra
.398 .597 .926 r
.48538 .54477 .49097 .55169 .50105 .5479 .49542 .54661 Mtetra
.778 .946 .932 r
.49542 .54661 .50105 .5479 .51118 .53597 .50558 .53981 Mtetra
.811 .981 .699 r
.50558 .53981 .51118 .53597 .52131 .5229 .51577 .52723 Mtetra
.88 .974 .668 r
.51577 .52723 .52131 .5229 .53141 .51275 .52594 .51164 Mtetra
.854 .946 .878 r
.52594 .51164 .53141 .51275 .54156 .51174 .5361 .50231 Mtetra
.569 .608 .852 r
.5361 .50231 .54156 .51174 .55184 .52053 .54631 .50167 Mtetra
.509 .448 .723 r
.54631 .50167 .55184 .52053 .56224 .53072 .5566 .50435 Mtetra
.524 .417 .674 r
.5566 .50435 .56224 .53072 .57271 .53751 .56697 .50719 Mtetra
.599 .454 .656 r
.56697 .50719 .57271 .53751 .58312 .53436 .57733 .50399 Mtetra
.654 .491 .651 r
.57733 .50399 .58312 .53436 .59336 .52124 .5876 .49475 Mtetra
.664 .508 .664 r
.5876 .49475 .59336 .52124 .60349 .50467 .59789 .48564 Mtetra
.655 .537 .707 r
.59789 .48564 .60349 .50467 .61362 .48945 .60825 .47985 Mtetra
.414 .525 .861 r
.60825 .47985 .61362 .48945 .624 .48408 .61889 .48282 Mtetra
.656 .1 0 r
.61889 .48282 .624 .48408 .63471 .48793 .62981 .49212 Mtetra
.632 .143 .074 r
.62981 .49212 .63471 .48793 .64562 .49475 .64075 .49843 Mtetra
.356 0 0 r
.64075 .49843 .64562 .49475 .65659 .50047 .65156 .49891 Mtetra
.817 .955 .906 r
.65156 .49891 .65659 .50047 .66731 .49795 .66208 .49063 Mtetra
.848 .762 .767 r
.66208 .49063 .66731 .49795 .67777 .48888 .67238 .47715 Mtetra
.761 .661 .752 r
.67238 .47715 .67777 .48888 .68821 .4793 .68281 .46693 Mtetra
.693 .622 .772 r
.68281 .46693 .68821 .4793 .69871 .47104 .69344 .46085 Mtetra
.616 .622 .833 r
.69344 .46085 .69871 .47104 .70942 .46606 .70431 .45868 Mtetra
.503 .641 .917 r
.70431 .45868 .70942 .46606 .72031 .46376 .71538 .45903 Mtetra
.395 .69 .979 r
.71538 .45903 .72031 .46376 .73134 .46297 .72654 .45972 Mtetra
.343 .731 .985 r
.72654 .45972 .73134 .46297 .74247 .46272 .73773 .45987 Mtetra
.472 .817 .998 r
.73773 .45987 .74247 .46272 .75361 .46164 .74887 .45826 Mtetra
.598 .85 .992 r
.74887 .45826 .75361 .46164 .76474 .45968 .75997 .45524 Mtetra
.669 .829 .961 r
.75997 .45524 .76474 .45968 .77585 .45676 .77104 .45126 Mtetra
.695 .795 .927 r
.77104 .45126 .77585 .45676 .78695 .45317 .7821 .44674 Mtetra
.693 .762 .904 r
.7821 .44674 .78695 .45317 .79807 .44921 .7932 .44221 Mtetra
.688 .742 .892 r
.7932 .44221 .79807 .44921 .80921 .44508 .80435 .43778 Mtetra
.678 .729 .889 r
.80435 .43778 .80921 .44508 .8204 .44102 .81557 .43365 Mtetra
.669 .725 .891 r
.81557 .43365 .8204 .44102 .83164 .43706 .82684 .42975 Mtetra
.662 .725 .896 r
.82684 .42975 .83164 .43706 .84293 .43326 .83818 .42608 Mtetra
.657 .727 .901 r
.83818 .42608 .84293 .43326 .85428 .42958 .84958 .42256 Mtetra
.654 .732 .907 r
.84958 .42256 .85428 .42958 .86569 .42599 .86103 .4191 Mtetra
.652 .736 .911 r
.86103 .4191 .86569 .42599 .87715 .42246 .87254 .4157 Mtetra
.651 .741 .916 r
.87254 .4157 .87715 .42246 .88865 .41895 .88409 .4123 Mtetra
.651 .746 .919 r
.88409 .4123 .88865 .41895 .90021 .41544 .89569 .40886 Mtetra
.664 .753 .917 r
.27639 .59249 .28248 .59781 .29181 .5948 .28575 .58942 Mtetra
.665 .752 .915 r
.28575 .58942 .29181 .5948 .30118 .59177 .29514 .58629 Mtetra
.666 .749 .912 r
.29514 .58629 .30118 .59177 .31058 .58875 .30457 .58314 Mtetra
.665 .745 .91 r
.30457 .58314 .31058 .58875 .32 .58578 .31402 .57999 Mtetra
.665 .739 .906 r
.31402 .57999 .32 .58578 .32946 .58287 .32351 .57685 Mtetra
.66 .731 .902 r
.32351 .57685 .32946 .58287 .33894 .58011 .33303 .57381 Mtetra
.653 .72 .898 r
.33303 .57381 .33894 .58011 .34845 .57757 .34256 .57094 Mtetra
.641 .707 .894 r
.34256 .57094 .34845 .57757 .35797 .57526 .35212 .56838 Mtetra
.624 .694 .894 r
.35212 .56838 .35797 .57526 .36753 .57324 .3617 .56625 Mtetra
.607 .685 .897 r
.3617 .56625 .36753 .57324 .37712 .57132 .37129 .56451 Mtetra
.586 .683 .908 r
.37129 .56451 .37712 .57132 .38674 .5694 .38091 .56321 Mtetra
.585 .705 .925 r
.38091 .56321 .38674 .5694 .39643 .56696 .39057 .5618 Mtetra
.598 .749 .949 r
.39057 .5618 .39643 .56696 .40619 .5636 .4003 .55991 Mtetra
.657 .827 .965 r
.4003 .55991 .40619 .5636 .41603 .55887 .41012 .55659 Mtetra
.744 .899 .948 r
.41012 .55659 .41603 .55887 .42594 .55241 .42004 .5511 Mtetra
.8 .936 .92 r
.42004 .5511 .42594 .55241 .43588 .54541 .43003 .54389 Mtetra
.839 .922 .889 r
.43003 .54389 .43588 .54541 .44583 .53874 .44006 .53532 Mtetra
.803 .855 .888 r
.44006 .53532 .44583 .53874 .45574 .53452 .45008 .52787 Mtetra
.703 .731 .872 r
.45008 .52787 .45574 .53452 .46561 .53414 .46004 .52333 Mtetra
.504 .544 .83 r
.46004 .52333 .46561 .53414 .47547 .53784 .46994 .52461 Mtetra
.241 .344 .769 r
.46994 .52461 .47547 .53784 .48538 .54477 .47982 .53238 Mtetra
.29 .39 .793 r
.47982 .53238 .48538 .54477 .49542 .54661 .48981 .53879 Mtetra
.488 .614 .903 r
.48981 .53879 .49542 .54661 .50558 .53981 .49994 .53957 Mtetra
.8 .977 .903 r
.49994 .53957 .50558 .53981 .51577 .52723 .51017 .53161 Mtetra
.898 .972 .667 r
.51017 .53161 .51577 .52723 .52594 .51164 .52042 .51513 Mtetra
.899 .981 .703 r
.52042 .51513 .52594 .51164 .5361 .50231 .53062 .49991 Mtetra
.867 .896 .852 r
.53062 .49991 .5361 .50231 .54631 .50167 .54082 .48961 Mtetra
.696 .622 .77 r
.54082 .48961 .54631 .50167 .5566 .50435 .55104 .48359 Mtetra
.603 .494 .702 r
.55104 .48359 .5566 .50435 .56697 .50719 .56132 .48112 Mtetra
.605 .471 .672 r
.56132 .48112 .56697 .50719 .57733 .50399 .57164 .47788 Mtetra
.613 .476 .671 r
.57164 .47788 .57733 .50399 .5876 .49475 .58198 .47388 Mtetra
.571 .474 .705 r
.58198 .47388 .5876 .49475 .59789 .48564 .59243 .47344 Mtetra
.419 .473 .81 r
.59243 .47344 .59789 .48564 .60825 .47985 .60303 .47732 Mtetra
.582 .02 0 r
.60303 .47732 .60825 .47985 .61889 .48282 .61386 .48618 Mtetra
.723 .247 .115 r
.61386 .48618 .61889 .48282 .62981 .49212 .62484 .49635 Mtetra
.442 0 0 r
.62484 .49635 .62981 .49212 .64075 .49843 .63567 .49797 Mtetra
.748 .981 .913 r
.63567 .49797 .64075 .49843 .65156 .49891 .64624 .49073 Mtetra
.832 .742 .765 r
.64624 .49073 .65156 .49891 .66208 .49063 .65661 .47776 Mtetra
.794 .662 .717 r
.65661 .47776 .66208 .49063 .67238 .47715 .66688 .46337 Mtetra
.711 .614 .747 r
.66688 .46337 .67238 .47715 .68281 .46693 .67744 .45555 Mtetra
.607 .595 .813 r
.67744 .45555 .68281 .46693 .69344 .46085 .6883 .45367 Mtetra
.457 .625 .924 r
.6883 .45367 .69344 .46085 .70431 .45868 .69937 .45476 Mtetra
.191 .607 .945 r
.69937 .45476 .70431 .45868 .71538 .45903 .71058 .45701 Mtetra
.144 .653 .901 r
.71058 .45701 .71538 .45903 .72654 .45972 .72178 .45788 Mtetra
.317 .772 .952 r
.72178 .45788 .72654 .45972 .73773 .45987 .73295 .457 Mtetra
.583 .866 .995 r
.73295 .457 .73773 .45987 .74887 .45826 .74403 .4539 Mtetra
.694 .841 .953 r
.74403 .4539 .74887 .45826 .75997 .45524 .75506 .44931 Mtetra
.713 .786 .909 r
.75506 .44931 .75997 .45524 .77104 .45126 .76608 .44422 Mtetra
.711 .749 .882 r
.76608 .44422 .77104 .45126 .7821 .44674 .77712 .43901 Mtetra
.694 .723 .872 r
.77712 .43901 .7821 .44674 .7932 .44221 .78823 .43425 Mtetra
.682 .712 .872 r
.78823 .43425 .7932 .44221 .80435 .43778 .79942 .42989 Mtetra
.668 .71 .879 r
.79942 .42989 .80435 .43778 .81557 .43365 .81068 .42597 Mtetra
.659 .713 .888 r
.81068 .42597 .81557 .43365 .82684 .42975 .82201 .42237 Mtetra
.653 .72 .897 r
.82201 .42237 .82684 .42975 .83818 .42608 .8334 .41894 Mtetra
.649 .726 .906 r
.8334 .41894 .83818 .42608 .84958 .42256 .84485 .41562 Mtetra
.648 .734 .912 r
.84485 .41562 .84958 .42256 .86103 .4191 .85635 .4123 Mtetra
.647 .739 .916 r
.85635 .4123 .86103 .4191 .87254 .4157 .8679 .40899 Mtetra
.648 .743 .919 r
.8679 .40899 .87254 .4157 .88409 .4123 .8795 .40564 Mtetra
.649 .746 .921 r
.8795 .40564 .88409 .4123 .89569 .40886 .89113 .40224 Mtetra
.663 .753 .917 r
.27027 .58715 .27639 .59249 .28575 .58942 .27964 .58408 Mtetra
.665 .754 .917 r
.27964 .58408 .28575 .58942 .29514 .58629 .28905 .58094 Mtetra
.667 .755 .916 r
.28905 .58094 .29514 .58629 .30457 .58314 .2985 .57774 Mtetra
.669 .755 .914 r
.2985 .57774 .30457 .58314 .31402 .57999 .30799 .57447 Mtetra
.673 .752 .91 r
.30799 .57447 .31402 .57999 .32351 .57685 .31751 .57109 Mtetra
.673 .745 .905 r
.31751 .57109 .32351 .57685 .33303 .57381 .32706 .56771 Mtetra
.671 .733 .897 r
.32706 .56771 .33303 .57381 .34256 .57094 .33664 .56435 Mtetra
.661 .715 .889 r
.33664 .56435 .34256 .57094 .35212 .56838 .34625 .56124 Mtetra
.645 .694 .881 r
.34625 .56124 .35212 .56838 .3617 .56625 .35586 .55853 Mtetra
.621 .67 .875 r
.35586 .55853 .3617 .56625 .37129 .56451 .36549 .55646 Mtetra
.587 .647 .877 r
.36549 .55646 .37129 .56451 .38091 .56321 .37511 .55525 Mtetra
.563 .64 .885 r
.37511 .55525 .38091 .56321 .39057 .5618 .38476 .55458 Mtetra
.535 .652 .91 r
.38476 .55458 .39057 .5618 .4003 .55991 .39444 .55431 Mtetra
.56 .72 .948 r
.39444 .55431 .4003 .55991 .41012 .55659 .4042 .55316 Mtetra
.629 .834 .979 r
.4042 .55316 .41012 .55659 .42004 .5511 .41407 .55021 Mtetra
.721 .949 .952 r
.41407 .55021 .42004 .5511 .43003 .54389 .42405 .54459 Mtetra
.822 .988 .875 r
.42405 .54459 .43003 .54389 .44006 .53532 .43415 .53576 Mtetra
.866 .974 .855 r
.43415 .53576 .44006 .53532 .45008 .52787 .44427 .52557 Mtetra
.86 .888 .856 r
.44427 .52557 .45008 .52787 .46004 .52333 .45439 .51564 Mtetra
.689 .7 .855 r
.45439 .51564 .46004 .52333 .46994 .52461 .4644 .51137 Mtetra
.426 .458 .79 r
.4644 .51137 .46994 .52461 .47982 .53238 .47432 .51522 Mtetra
.325 .346 .728 r
.47432 .51522 .47982 .53238 .48981 .53879 .48426 .52329 Mtetra
.246 .315 .737 r
.48426 .52329 .48981 .53879 .49994 .53957 .4943 .53236 Mtetra
.48 .632 .921 r
.4943 .53236 .49994 .53957 .51017 .53161 .50451 .53303 Mtetra
.856 .996 .818 r
.50451 .53303 .51017 .53161 .52042 .51513 .51481 .52207 Mtetra
.738 .901 .516 r
.51481 .52207 .52042 .51513 .53062 .49991 .5251 .50607 Mtetra
.836 .94 .573 r
.5251 .50607 .53062 .49991 .54082 .48961 .53535 .48866 Mtetra
.921 .919 .796 r
.53535 .48866 .54082 .48961 .55104 .48359 .54557 .47488 Mtetra
.758 .704 .801 r
.54557 .47488 .55104 .48359 .56132 .48112 .55581 .46688 Mtetra
.633 .564 .76 r
.55581 .46688 .56132 .48112 .57164 .47788 .56613 .46362 Mtetra
.519 .5 .775 r
.56613 .46362 .57164 .47788 .58198 .47388 .57655 .4651 Mtetra
.084 .347 .819 r
.57655 .4651 .58198 .47388 .59243 .47344 .58716 .4724 Mtetra
.724 .193 0 r
.58716 .4724 .59243 .47344 .60303 .47732 .59796 .4834 Mtetra
.702 .263 .204 r
.59796 .4834 .60303 .47732 .61386 .48618 .60885 .49302 Mtetra
.588 .139 .152 r
.60885 .49302 .61386 .48618 .62484 .49635 .61972 .4976 Mtetra
.634 .962 .825 r
.61972 .4976 .62484 .49635 .63567 .49797 .63031 .49045 Mtetra
.864 .759 .745 r
.63031 .49045 .63567 .49797 .64624 .49073 .64062 .47476 Mtetra
.77 .623 .698 r
.64062 .47476 .64624 .49073 .65661 .47776 .65093 .46004 Mtetra
.717 .583 .704 r
.65093 .46004 .65661 .47776 .66688 .46337 .66138 .44957 Mtetra
.611 .562 .775 r
.66138 .44957 .66688 .46337 .67744 .45555 .67219 .44736 Mtetra
.339 .527 .893 r
.67219 .44736 .67744 .45555 .6883 .45367 .68334 .45093 Mtetra
0 .434 .789 r
.68334 .45093 .6883 .45367 .69937 .45476 .69459 .45477 Mtetra
.262 0 0 r
.69459 .45477 .69937 .45476 .71058 .45701 .70585 .45726 Mtetra
.061 .626 .718 r
.70585 .45726 .71058 .45701 .72178 .45788 .71701 .45647 Mtetra
.53 .898 .967 r
.71701 .45647 .72178 .45788 .73295 .457 .72806 .45295 Mtetra
.724 .861 .946 r
.72806 .45295 .73295 .457 .74403 .4539 .73903 .44755 Mtetra
.745 .781 .882 r
.73903 .44755 .74403 .4539 .75506 .44931 .74996 .44126 Mtetra
.722 .724 .852 r
.74996 .44126 .75506 .44931 .76608 .44422 .76095 .43535 Mtetra
.702 .697 .842 r
.76095 .43535 .76608 .44422 .77712 .43901 .77201 .43 Mtetra
.679 .685 .848 r
.77201 .43 .77712 .43901 .78823 .43425 .78318 .42554 Mtetra
.662 .685 .861 r
.78318 .42554 .78823 .43425 .79942 .42989 .79443 .42172 Mtetra
.651 .696 .878 r
.79443 .42172 .79942 .42989 .81068 .42597 .80576 .41833 Mtetra
.643 .708 .894 r
.80576 .41833 .81068 .42597 .82201 .42237 .81717 .41519 Mtetra
.641 .723 .907 r
.81717 .41519 .82201 .42237 .8334 .41894 .82862 .41207 Mtetra
.64 .734 .916 r
.82862 .41207 .8334 .41894 .84485 .41562 .84013 .40895 Mtetra
.643 .742 .921 r
.84013 .40895 .84485 .41562 .85635 .4123 .85167 .40571 Mtetra
.645 .747 .923 r
.85167 .40571 .85635 .4123 .8679 .40899 .86325 .4024 Mtetra
.647 .749 .924 r
.86325 .4024 .8679 .40899 .8795 .40564 .87488 .39902 Mtetra
.65 .75 .923 r
.87488 .39902 .8795 .40564 .89113 .40224 .88655 .39556 Mtetra
.657 .752 .92 r
.2641 .58177 .27027 .58715 .27964 .58408 .27349 .5788 Mtetra
.659 .757 .922 r
.27349 .5788 .27964 .58408 .28905 .58094 .28291 .57577 Mtetra
.662 .762 .924 r
.28291 .57577 .28905 .58094 .2985 .57774 .29237 .57265 Mtetra
.667 .767 .925 r
.29237 .57265 .2985 .57774 .30799 .57447 .30187 .5694 Mtetra
.675 .77 .923 r
.30187 .5694 .30799 .57447 .31751 .57109 .31142 .56597 Mtetra
.68 .77 .919 r
.31142 .56597 .31751 .57109 .32706 .56771 .32101 .56238 Mtetra
.686 .765 .911 r
.32101 .56238 .32706 .56771 .33664 .56435 .33064 .55861 Mtetra
.684 .75 .902 r
.33064 .55861 .33664 .56435 .34625 .56124 .34029 .55489 Mtetra
.676 .729 .89 r
.34029 .55489 .34625 .56124 .35586 .55853 .34997 .55133 Mtetra
.653 .697 .878 r
.34997 .55133 .35586 .55853 .36549 .55646 .35965 .54835 Mtetra
.619 .66 .868 r
.35965 .54835 .36549 .55646 .37511 .55525 .36933 .54631 Mtetra
.58 .623 .859 r
.36933 .54631 .37511 .55525 .38476 .55458 .37899 .54533 Mtetra
.528 .592 .862 r
.37899 .54533 .38476 .55458 .39444 .55431 .38866 .54562 Mtetra
.51 .598 .878 r
.38866 .54562 .39444 .55431 .4042 .55316 .39836 .54616 Mtetra
.511 .651 .921 r
.39836 .54616 .4042 .55316 .41407 .55021 .40815 .54622 Mtetra
.603 .804 .977 r
.40815 .54622 .41407 .55021 .42405 .54459 .41806 .54384 Mtetra
.745 .957 .941 r
.41806 .54384 .42405 .54459 .43415 .53576 .42812 .53764 Mtetra
.816 1 .828 r
.42812 .53764 .43415 .53576 .44427 .52557 .4383 .52787 Mtetra
.892 .989 .782 r
.4383 .52787 .44427 .52557 .45439 .51564 .44854 .51512 Mtetra
.869 .951 .863 r
.44854 .51512 .45439 .51564 .4644 .51137 .45871 .50506 Mtetra
.691 .743 .891 r
.45871 .50506 .4644 .51137 .47432 .51522 .46877 .50093 Mtetra
.445 .455 .775 r
.46877 .50093 .47432 .51522 .48426 .52329 .47875 .50457 Mtetra
.247 .279 .699 r
.47875 .50457 .48426 .52329 .4943 .53236 .48874 .51546 Mtetra
.343 .362 .736 r
.48874 .51546 .4943 .53236 .50451 .53303 .49887 .52292 Mtetra
.575 .6 .841 r
.49887 .52292 .50451 .53303 .51481 .52207 .50915 .52209 Mtetra
.823 .983 .882 r
.50915 .52209 .51481 .52207 .5251 .50607 .5195 .51319 Mtetra
.693 .878 .491 r
.5195 .51319 .5251 .50607 .53535 .48866 .52984 .49775 Mtetra
0 0 0 r
.52984 .49775 .53535 .48866 .54557 .47488 .54014 .4833 Mtetra
.54014 .4833 .54557 .47488 .55581 .46688 .55045 .47339 Mtetra
.219 0 0 r
.55045 .47339 .55581 .46688 .56613 .46362 .56083 .47012 Mtetra
.553 .097 .123 r
.56083 .47012 .56613 .46362 .57655 .4651 .57134 .47349 Mtetra
.664 .249 .248 r
.57134 .47349 .57655 .4651 .58716 .4724 .58202 .48144 Mtetra
.678 .271 .269 r
.58202 .48144 .58716 .4724 .59796 .4834 .59282 .49044 Mtetra
.522 .07 .119 r
.59282 .49044 .59796 .4834 .60885 .49302 .6036 .49289 Mtetra
.638 .96 .918 r
.6036 .49289 .60885 .49302 .61972 .4976 .61423 .4872 Mtetra
.816 .7 .738 r
.61423 .4872 .61972 .4976 .63031 .49045 .62463 .47312 Mtetra
.782 .62 .68 r
.62463 .47312 .63031 .49045 .64062 .47476 .63488 .45552 Mtetra
.706 .567 .696 r
.63488 .45552 .64062 .47476 .65093 .46004 .64536 .44524 Mtetra
.612 .551 .762 r
.64536 .44524 .65093 .46004 .66138 .44957 .65614 .44283 Mtetra
.262 .533 .917 r
.65614 .44283 .66138 .44957 .67219 .44736 .66724 .44647 Mtetra
.501 0 0 r
.66724 .44647 .67219 .44736 .68334 .45093 .67855 .45287 Mtetra
.454 0 0 r
.67855 .45287 .68334 .45093 .69459 .45477 .68982 .45626 Mtetra
.135 0 0 r
.68982 .45626 .69459 .45477 .70585 .45726 .70099 .45602 Mtetra
.569 .919 .961 r
.70099 .45602 .70585 .45726 .71701 .45647 .712 .45187 Mtetra
.766 .849 .913 r
.712 .45187 .71701 .45647 .72806 .45295 .7229 .4452 Mtetra
.753 .743 .843 r
.7229 .4452 .72806 .45295 .73903 .44755 .73378 .43803 Mtetra
.731 .694 .815 r
.73378 .43803 .73903 .44755 .74996 .44126 .7447 .43109 Mtetra
.699 .669 .817 r
.7447 .43109 .74996 .44126 .76095 .43535 .75573 .42546 Mtetra
.676 .664 .831 r
.75573 .42546 .76095 .43535 .77201 .43 .76688 .42091 Mtetra
.654 .673 .856 r
.76688 .42091 .77201 .43 .78318 .42554 .77813 .41734 Mtetra
.637 .689 .882 r
.77813 .41734 .78318 .42554 .79443 .42172 .78948 .41436 Mtetra
.63 .712 .906 r
.78948 .41436 .79443 .42172 .80576 .41833 .8009 .41156 Mtetra
.626 .731 .922 r
.8009 .41156 .80576 .41833 .81717 .41519 .81237 .4088 Mtetra
.631 .747 .932 r
.81237 .4088 .81717 .41519 .82862 .41207 .82387 .40585 Mtetra
.636 .757 .935 r
.82387 .40585 .82862 .41207 .84013 .40895 .83542 .40274 Mtetra
.643 .761 .934 r
.83542 .40274 .84013 .40895 .85167 .40571 .84699 .39944 Mtetra
.648 .761 .932 r
.84699 .39944 .85167 .40571 .86325 .4024 .85859 .39599 Mtetra
.652 .759 .928 r
.85859 .39599 .86325 .4024 .87488 .39902 .87024 .39245 Mtetra
.654 .755 .924 r
.87024 .39245 .87488 .39902 .88655 .39556 .88193 .38884 Mtetra
.649 .75 .923 r
.25789 .57635 .2641 .58177 .27349 .5788 .26728 .57356 Mtetra
.649 .757 .928 r
.26728 .57356 .27349 .5788 .28291 .57577 .27671 .57074 Mtetra
.651 .766 .933 r
.27671 .57074 .28291 .57577 .29237 .57265 .28618 .56785 Mtetra
.657 .777 .937 r
.28618 .56785 .29237 .57265 .30187 .5694 .29569 .5648 Mtetra
.665 .787 .939 r
.29569 .5648 .30187 .5694 .31142 .56597 .30525 .56154 Mtetra
.677 .797 .939 r
.30525 .56154 .31142 .56597 .32101 .56238 .31486 .55799 Mtetra
.692 .802 .933 r
.31486 .55799 .32101 .56238 .33064 .55861 .32452 .55406 Mtetra
.703 .799 .924 r
.32452 .55406 .33064 .55861 .34029 .55489 .33423 .54985 Mtetra
.711 .783 .908 r
.33423 .54985 .34029 .55489 .34997 .55133 .34398 .54537 Mtetra
.7 .75 .89 r
.34398 .54537 .34997 .55133 .35965 .54835 .35374 .54109 Mtetra
.677 .705 .868 r
.35374 .54109 .35965 .54835 .36933 .54631 .36351 .53735 Mtetra
.633 .646 .845 r
.36351 .53735 .36933 .54631 .37899 .54533 .37326 .53483 Mtetra
.573 .586 .829 r
.37326 .53483 .37899 .54533 .38866 .54562 .38296 .53413 Mtetra
.516 .539 .818 r
.38296 .53413 .38866 .54562 .39836 .54616 .39265 .53508 Mtetra
.443 .508 .831 r
.39265 .53508 .39836 .54616 .40815 .54622 .40235 .53762 Mtetra
.443 .57 .887 r
.40235 .53762 .40815 .54622 .41806 .54384 .41214 .53933 Mtetra
.509 .751 .983 r
.41214 .53933 .41806 .54384 .42812 .53764 .42207 .53846 Mtetra
.61 .955 .891 r
.42207 .53846 .42812 .53764 .4383 .52787 .43218 .53296 Mtetra
.678 .93 .629 r
.43218 .53296 .4383 .52787 .44854 .51512 .44245 .52175 Mtetra
.71 .91 .554 r
.44245 .52175 .44854 .51512 .45871 .50506 .45278 .50779 Mtetra
.906 .984 .753 r
.45278 .50779 .45871 .50506 .46877 .50093 .46308 .49371 Mtetra
.744 .732 .84 r
.46308 .49371 .46877 .50093 .47875 .50457 .47323 .48726 Mtetra
.453 .426 .738 r
.47323 .48726 .47875 .50457 .48874 .51546 .48326 .49147 Mtetra
.38 .33 .677 r
.48326 .49147 .48874 .51546 .49887 .52292 .49333 .50062 Mtetra
.325 .305 .682 r
.49333 .50062 .49887 .52292 .50915 .52209 .50351 .51113 Mtetra
.345 .458 .833 r
.50351 .51113 .50915 .52209 .5195 .51319 .51383 .51569 Mtetra
0 0 0 r
.51383 .51569 .5195 .51319 .52984 .49775 .52424 .51211 Mtetra
.293 0 .194 r
.52424 .51211 .52984 .49775 .54014 .4833 .53467 .50552 Mtetra
.388 .086 .326 r
.53467 .50552 .54014 .4833 .55045 .47339 .54513 .49854 Mtetra
.474 .173 .375 r
.54513 .49854 .55045 .47339 .56083 .47012 .55563 .49526 Mtetra
.528 .221 .391 r
.55563 .49526 .56083 .47012 .57134 .47349 .56622 .49571 Mtetra
.519 .202 .369 r
.56622 .49571 .57134 .47349 .58202 .48144 .57687 .49578 Mtetra
.418 .06 .249 r
.57687 .49578 .58202 .48144 .59282 .49044 .58752 .49284 Mtetra
.79 .991 .754 r
.58752 .49284 .59282 .49044 .6036 .49289 .59804 .48168 Mtetra
.832 .694 .712 r
.59804 .48168 .6036 .49289 .61423 .4872 .6084 .46449 Mtetra
.735 .567 .665 r
.6084 .46449 .61423 .4872 .62463 .47312 .61874 .44862 Mtetra
.686 .53 .669 r
.61874 .44862 .62463 .47312 .63488 .45552 .6292 .43772 Mtetra
.562 .493 .735 r
.6292 .43772 .63488 .45552 .64536 .44524 .64003 .43761 Mtetra
0 .324 .811 r
.64003 .43761 .64536 .44524 .65614 .44283 .65123 .44528 Mtetra
.647 .123 0 r
.65123 .44528 .65614 .44283 .66724 .44647 .66254 .45285 Mtetra
.585 .121 .117 r
.66254 .45285 .66724 .44647 .67855 .45287 .67384 .45767 Mtetra
.297 0 0 r
.67384 .45767 .67855 .45287 .68982 .45626 .68495 .45666 Mtetra
.566 .938 .866 r
.68495 .45666 .68982 .45626 .70099 .45602 .69588 .45093 Mtetra
.806 .835 .873 r
.69588 .45093 .70099 .45602 .712 .45187 .70669 .44253 Mtetra
.774 .713 .796 r
.70669 .44253 .712 .45187 .7229 .4452 .71746 .43326 Mtetra
.722 .649 .775 r
.71746 .43326 .7229 .4452 .73378 .43803 .72833 .42561 Mtetra
.69 .626 .78 r
.72833 .42561 .73378 .43803 .7447 .43109 .73933 .41964 Mtetra
.657 .626 .807 r
.73933 .41964 .7447 .43109 .75573 .42546 .75049 .41554 Mtetra
.631 .644 .845 r
.75049 .41554 .75573 .42546 .76688 .42091 .76178 .41271 Mtetra
.613 .679 .889 r
.76178 .41271 .76688 .42091 .77813 .41734 .77316 .41043 Mtetra
.599 .714 .925 r
.77316 .41043 .77813 .41734 .78948 .41436 .78462 .40836 Mtetra
.602 .75 .948 r
.78462 .40836 .78948 .41436 .8009 .41156 .7961 .40602 Mtetra
.609 .771 .958 r
.7961 .40602 .8009 .41156 .81237 .4088 .80762 .40338 Mtetra
.626 .784 .958 r
.80762 .40338 .81237 .4088 .82387 .40585 .81916 .40034 Mtetra
.639 .787 .953 r
.81916 .40034 .82387 .40585 .83542 .40274 .83072 .39701 Mtetra
.65 .783 .945 r
.83072 .39701 .83542 .40274 .84699 .39944 .8423 .39345 Mtetra
.657 .777 .938 r
.8423 .39345 .84699 .39944 .85859 .39599 .85392 .38972 Mtetra
.66 .77 .93 r
.85392 .38972 .85859 .39599 .87024 .39245 .86557 .38591 Mtetra
.661 .761 .924 r
.86557 .38591 .87024 .39245 .88193 .38884 .87727 .38207 Mtetra
.641 .748 .926 r
.25164 .57089 .25789 .57635 .26728 .57356 .26104 .56825 Mtetra
.639 .753 .931 r
.26104 .56825 .26728 .57356 .27671 .57074 .27047 .56563 Mtetra
.639 .761 .937 r
.27047 .56563 .27671 .57074 .28618 .56785 .27994 .56298 Mtetra
.642 .772 .942 r
.27994 .56298 .28618 .56785 .29569 .5648 .28945 .56023 Mtetra
.646 .786 .949 r
.28945 .56023 .29569 .5648 .30525 .56154 .29901 .55734 Mtetra
.657 .804 .954 r
.29901 .55734 .30525 .56154 .31486 .55799 .30862 .55416 Mtetra
.674 .823 .955 r
.30862 .55416 .31486 .55799 .32452 .55406 .31829 .55056 Mtetra
.695 .841 .953 r
.31829 .55056 .32452 .55406 .33423 .54985 .32802 .54645 Mtetra
.722 .849 .941 r
.32802 .54645 .33423 .54985 .34398 .54537 .33782 .54167 Mtetra
.736 .839 .928 r
.33782 .54167 .34398 .54537 .35374 .54109 .34766 .53654 Mtetra
.74 .807 .906 r
.34766 .53654 .35374 .54109 .36351 .53735 .35753 .53119 Mtetra
.709 .748 .882 r
.35753 .53119 .36351 .53735 .37326 .53483 .36739 .52655 Mtetra
.656 .673 .854 r
.36739 .52655 .37326 .53483 .38296 .53413 .37722 .52334 Mtetra
.582 .586 .822 r
.37722 .52334 .38296 .53413 .39265 .53508 .38699 .52235 Mtetra
.488 .503 .799 r
.38699 .52235 .39265 .53508 .40235 .53762 .3967 .52425 Mtetra
.441 .467 .79 r
.3967 .52425 .40235 .53762 .41214 .53933 .40642 .52753 Mtetra
.405 .474 .818 r
.40642 .52753 .41214 .53933 .42207 .53846 .41621 .5311 Mtetra
.486 .632 .918 r
.41621 .5311 .42207 .53846 .43218 .53296 .42617 .53162 Mtetra
.676 .931 .969 r
.42617 .53162 .43218 .53296 .44245 .52175 .43632 .52684 Mtetra
.649 .917 .62 r
.43632 .52684 .44245 .52175 .45278 .50779 .44665 .51597 Mtetra
.714 .882 .488 r
.44665 .51597 .45278 .50779 .46308 .49371 .45708 .49955 Mtetra
.753 .938 .6 r
.45708 .49955 .46308 .49371 .47323 .48726 .46743 .48568 Mtetra
.791 .937 .925 r
.46743 .48568 .47323 .48726 .48326 .49147 .47765 .47856 Mtetra
.51 .515 .797 r
.47765 .47856 .48326 .49147 .49333 .50062 .48779 .47993 Mtetra
.327 .317 .695 r
.48779 .47993 .49333 .50062 .50351 .51113 .49793 .48949 Mtetra
.34 .32 .69 r
.49793 .48949 .50351 .51113 .51383 .51569 .50818 .49913 Mtetra
.384 .394 .747 r
.50818 .49913 .51383 .51569 .52424 .51211 .51857 .50525 Mtetra
.358 .589 .932 r
.51857 .50525 .52424 .51211 .53467 .50552 .52904 .50743 Mtetra
0 0 0 r
.52904 .50743 .53467 .50552 .54513 .49854 .53958 .50555 Mtetra
.234 0 0 r
.53958 .50555 .54513 .49854 .55563 .49526 .55015 .50227 Mtetra
.137 0 0 r
.55015 .50227 .55563 .49526 .56622 .49571 .56075 .49758 Mtetra
.711 .983 .8 r
.56075 .49758 .56622 .49571 .57687 .49578 .57132 .4888 Mtetra
.843 .768 .779 r
.57132 .4888 .57687 .49578 .58752 .49284 .58183 .47604 Mtetra
.776 .621 .688 r
.58183 .47604 .58752 .49284 .59804 .48168 .59225 .45971 Mtetra
.742 .575 .667 r
.59225 .45971 .59804 .48168 .6084 .46449 .60262 .4434 Mtetra
.672 .537 .692 r
.60262 .4434 .6084 .46449 .61874 .44862 .61317 .43533 Mtetra
.539 .53 .794 r
.61317 .43533 .61874 .44862 .6292 .43772 .62399 .43585 Mtetra
.517 0 0 r
.62399 .43585 .6292 .43772 .64003 .43761 .63512 .44324 Mtetra
.704 .25 .171 r
.63512 .44324 .64003 .43761 .65123 .44528 .64645 .45325 Mtetra
.578 .138 .168 r
.64645 .45325 .65123 .44528 .66254 .45285 .6577 .45766 Mtetra
.241 0 0 r
.6577 .45766 .66254 .45285 .67384 .45767 .66876 .45588 Mtetra
.77 .955 .933 r
.66876 .45588 .67384 .45767 .68495 .45666 .67963 .44869 Mtetra
.805 .751 .803 r
.67963 .44869 .68495 .45666 .69588 .45093 .69035 .43835 Mtetra
.752 .653 .752 r
.69035 .43835 .69588 .45093 .70669 .44253 .70109 .42829 Mtetra
.719 .618 .744 r
.70109 .42829 .70669 .44253 .71746 .43326 .7119 .41961 Mtetra
.677 .604 .766 r
.7119 .41961 .71746 .43326 .72833 .42561 .72291 .4139 Mtetra
.641 .614 .808 r
.72291 .4139 .72833 .42561 .73933 .41964 .73409 .41047 Mtetra
.604 .649 .868 r
.73409 .41047 .73933 .41964 .75049 .41554 .74541 .40851 Mtetra
.562 .693 .928 r
.74541 .40851 .75049 .41554 .76178 .41271 .75685 .40729 Mtetra
.546 .748 .97 r
.75685 .40729 .76178 .41271 .77316 .41043 .76833 .40585 Mtetra
.545 .784 .987 r
.76833 .40585 .77316 .41043 .78462 .40836 .77985 .40405 Mtetra
.577 .811 .988 r
.77985 .40405 .78462 .40836 .7961 .40602 .79137 .40156 Mtetra
.609 .819 .981 r
.79137 .40156 .7961 .40602 .80762 .40338 .80289 .39854 Mtetra
.637 .814 .968 r
.80289 .39854 .80762 .40338 .81916 .40034 .81443 .39507 Mtetra
.654 .804 .955 r
.81443 .39507 .81916 .40034 .83072 .39701 .82599 .3913 Mtetra
.663 .791 .943 r
.82599 .3913 .83072 .39701 .8423 .39345 .83758 .38738 Mtetra
.667 .78 .934 r
.83758 .38738 .8423 .39345 .85392 .38972 .8492 .38335 Mtetra
.669 .771 .926 r
.8492 .38335 .85392 .38972 .86557 .38591 .86087 .37928 Mtetra
.668 .762 .921 r
.86087 .37928 .86557 .38591 .87727 .38207 .87259 .37524 Mtetra
.639 .747 .927 r
.24535 .5654 .25164 .57089 .26104 .56825 .25476 .5628 Mtetra
.634 .748 .93 r
.25476 .5628 .26104 .56825 .27047 .56563 .26421 .56028 Mtetra
.631 .751 .935 r
.26421 .56028 .27047 .56563 .27994 .56298 .27368 .5578 Mtetra
.628 .758 .941 r
.27368 .5578 .27994 .56298 .28945 .56023 .28319 .55535 Mtetra
.622 .769 .95 r
.28319 .55535 .28945 .56023 .29901 .55734 .29274 .55294 Mtetra
.624 .789 .961 r
.29274 .55294 .29901 .55734 .30862 .55416 .30233 .55038 Mtetra
.63 .817 .972 r
.30233 .55038 .30862 .55416 .31829 .55056 .31197 .54757 Mtetra
.648 .855 .979 r
.31197 .54757 .31829 .55056 .32802 .54645 .32169 .5442 Mtetra
.681 .892 .974 r
.32169 .5442 .32802 .54645 .33782 .54167 .33149 .54001 Mtetra
.718 .919 .962 r
.33149 .54001 .33782 .54167 .34766 .53654 .34136 .53489 Mtetra
.768 .922 .938 r
.34136 .53489 .34766 .53654 .35753 .53119 .35132 .52865 Mtetra
.784 .888 .919 r
.35132 .52865 .35753 .53119 .36739 .52655 .36131 .52202 Mtetra
.772 .813 .885 r
.36131 .52202 .36739 .52655 .37722 .52334 .37132 .51545 Mtetra
.705 .701 .843 r
.37132 .51545 .37722 .52334 .38699 .52235 .38127 .5105 Mtetra
.614 .585 .798 r
.38127 .5105 .38699 .52235 .3967 .52425 .39114 .50836 Mtetra
.524 .483 .753 r
.39114 .50836 .3967 .52425 .40642 .52753 .40092 .50961 Mtetra
.424 .402 .731 r
.40092 .50961 .40642 .52753 .41621 .5311 .41063 .51468 Mtetra
.376 .388 .745 r
.41063 .51468 .41621 .5311 .42617 .53162 .4204 .52063 Mtetra
.326 .447 .831 r
.4204 .52063 .42617 .53162 .43632 .52684 .4303 .52526 Mtetra
.318 .777 .947 r
.4303 .52526 .43632 .52684 .44665 .51597 .44043 .52431 Mtetra
0 0 0 r
.44043 .52431 .44665 .51597 .45708 .49955 .45078 .51543 Mtetra
0 0 .035 r
.45078 .51543 .45708 .49955 .46743 .48568 .46126 .50042 Mtetra
0 0 0 r
.46126 .50042 .46743 .48568 .47765 .47856 .47176 .48164 Mtetra
.876 .991 .742 r
.47176 .48164 .47765 .47856 .48779 .47993 .48214 .46816 Mtetra
.666 .615 .788 r
.48214 .46816 .48779 .47993 .49793 .48949 .4924 .46376 Mtetra
.513 .412 .677 r
.4924 .46376 .49793 .48949 .50818 .49913 .50264 .46667 Mtetra
.446 .342 .644 r
.50264 .46667 .50818 .49913 .51857 .50525 .51294 .475 Mtetra
.455 .356 .654 r
.51294 .475 .51857 .50525 .52904 .50743 .52336 .48223 Mtetra
.514 .416 .682 r
.52336 .48223 .52904 .50743 .53958 .50555 .53387 .48506 Mtetra
.613 .505 .707 r
.53387 .48506 .53958 .50555 .55015 .50227 .54442 .48174 Mtetra
.691 .551 .691 r
.54442 .48174 .55015 .50227 .56075 .49758 .55496 .47225 Mtetra
.708 .541 .661 r
.55496 .47225 .56075 .49758 .57132 .4888 .56544 .45832 Mtetra
.695 .518 .643 r
.56544 .45832 .57132 .4888 .58183 .47604 .57588 .44326 Mtetra
.648 .481 .643 r
.57588 .44326 .58183 .47604 .59225 .45971 .58638 .43361 Mtetra
.589 .462 .675 r
.58638 .43361 .59225 .45971 .60262 .4434 .59705 .43132 Mtetra
.263 .387 .801 r
.59705 .43132 .60262 .4434 .61317 .43533 .608 .43822 Mtetra
.754 .278 .113 r
.608 .43822 .61317 .43533 .62399 .43585 .61922 .45052 Mtetra
.643 .274 .33 r
.61922 .45052 .62399 .43585 .63512 .44324 .63046 .45905 Mtetra
.543 .184 .309 r
.63046 .45905 .63512 .44324 .64645 .45325 .64161 .4614 Mtetra
.148 0 0 r
.64161 .4614 .64645 .45325 .6577 .45766 .65252 .45568 Mtetra
.884 .937 .847 r
.65252 .45568 .6577 .45766 .66876 .45588 .66322 .44425 Mtetra
.793 .682 .742 r
.66322 .44425 .66876 .45588 .67963 .44869 .67385 .43145 Mtetra
.736 .6 .705 r
.67385 .43145 .67963 .44869 .69035 .43835 .6845 .41951 Mtetra
.682 .559 .709 r
.6845 .41951 .69035 .43835 .70109 .42829 .69534 .41145 Mtetra
.642 .552 .737 r
.69534 .41145 .70109 .42829 .7119 .41961 .70639 .40687 Mtetra
.596 .574 .8 r
.70639 .40687 .7119 .41961 .72291 .4139 .71764 .40518 Mtetra
.527 .624 .891 r
.71764 .40518 .72291 .4139 .73409 .41047 .72906 .40515 Mtetra
.45 .705 .976 r
.72906 .40515 .73409 .41047 .74541 .40851 .74056 .40521 Mtetra
.373 .753 .989 r
.74056 .40521 .74541 .40851 .75685 .40729 .7521 .40487 Mtetra
.409 .81 .983 r
.7521 .40487 .75685 .40729 .76833 .40585 .76362 .40338 Mtetra
.493 .851 .992 r
.76362 .40338 .76833 .40585 .77985 .40405 .77514 .40093 Mtetra
.586 .868 .995 r
.77514 .40093 .77985 .40405 .79137 .40156 .78663 .39762 Mtetra
.642 .855 .981 r
.78663 .39762 .79137 .40156 .80289 .39854 .79813 .39374 Mtetra
.666 .829 .961 r
.79813 .39374 .80289 .39854 .81443 .39507 .80965 .38958 Mtetra
.677 .806 .944 r
.80965 .38958 .81443 .39507 .82599 .3913 .82119 .38526 Mtetra
.676 .786 .932 r
.82119 .38526 .82599 .3913 .83758 .38738 .83279 .38098 Mtetra
.675 .773 .924 r
.83279 .38098 .83758 .38738 .8492 .38335 .84443 .37672 Mtetra
.673 .765 .92 r
.84443 .37672 .8492 .38335 .86087 .37928 .85612 .37251 Mtetra
.67 .76 .918 r
.85612 .37251 .86087 .37928 .87259 .37524 .86786 .36837 Mtetra
.645 .749 .925 r
.23902 .55988 .24535 .5654 .25476 .5628 .24846 .55712 Mtetra
.641 .743 .923 r
.24846 .55712 .25476 .5628 .26421 .56028 .25793 .55445 Mtetra
.636 .737 .921 r
.25793 .55445 .26421 .56028 .27368 .5578 .26743 .5519 Mtetra
.629 .733 .922 r
.26743 .5519 .27368 .5578 .28319 .55535 .27696 .54949 Mtetra
.617 .732 .928 r
.27696 .54949 .28319 .55535 .29274 .55294 .2865 .5473 Mtetra
.61 .738 .936 r
.2865 .5473 .29274 .55294 .30233 .55038 .29608 .54521 Mtetra
.601 .754 .951 r
.29608 .54521 .30233 .55038 .31197 .54757 .3057 .54319 Mtetra
.606 .788 .968 r
.3057 .54319 .31197 .54757 .32169 .5442 .31537 .54089 Mtetra
.619 .837 .983 r
.31537 .54089 .32169 .5442 .33149 .54001 .32512 .53804 Mtetra
.648 .898 .983 r
.32512 .53804 .33149 .54001 .34136 .53489 .33495 .53419 Mtetra
.699 .949 .956 r
.33495 .53419 .34136 .53489 .35132 .52865 .3449 .5289 Mtetra
.741 .977 .921 r
.3449 .5289 .35132 .52865 .36131 .52202 .35494 .52227 Mtetra
.804 .978 .9 r
.35494 .52227 .36131 .52202 .37132 .51545 .36506 .51426 Mtetra
.82 .936 .905 r
.36506 .51426 .37132 .51545 .38127 .5105 .37519 .50628 Mtetra
.783 .828 .888 r
.37519 .50628 .38127 .5105 .39114 .50836 .38528 .49936 Mtetra
.668 .664 .837 r
.38528 .49936 .39114 .50836 .40092 .50961 .39526 .49552 Mtetra
.533 .511 .777 r
.39526 .49552 .40092 .50961 .41063 .51468 .40512 .49624 Mtetra
.446 .412 .727 r
.40512 .49624 .41063 .51468 .4204 .52063 .41491 .50066 Mtetra
.371 .351 .707 r
.41491 .50066 .4204 .52063 .4303 .52526 .42469 .50807 Mtetra
.38 .384 .738 r
.42469 .50807 .4303 .52526 .44043 .52431 .43461 .51418 Mtetra
.462 .546 .857 r
.43461 .51418 .44043 .52431 .45078 .51543 .44473 .51594 Mtetra
.663 .97 .905 r
.44473 .51594 .45078 .51543 .46126 .50042 .45509 .50984 Mtetra
0 0 0 r
.45509 .50984 .46126 .50042 .47176 .48164 .46562 .49513 Mtetra
.46562 .49513 .47176 .48164 .48214 .46816 .47613 .47898 Mtetra
.47613 .47898 .48214 .46816 .4924 .46376 .48658 .46523 Mtetra
.695 .982 .843 r
.48658 .46523 .4924 .46376 .50264 .46667 .49696 .45762 Mtetra
.564 .624 .87 r
.49696 .45762 .50264 .46667 .51294 .475 .5073 .45684 Mtetra
.535 .472 .732 r
.5073 .45684 .51294 .475 .52336 .48223 .5177 .45787 Mtetra
.553 .445 .685 r
.5177 .45787 .52336 .48223 .53387 .48506 .52816 .45819 Mtetra
.601 .466 .67 r
.52816 .45819 .53387 .48506 .54442 .48174 .53868 .45483 Mtetra
.641 .492 .666 r
.53868 .45483 .54442 .48174 .55496 .47225 .5492 .44777 Mtetra
.656 .511 .675 r
.5492 .44777 .55496 .47225 .56544 .45832 .55974 .44 Mtetra
.658 .546 .716 r
.55974 .44 .56544 .45832 .57588 .44326 .57031 .43402 Mtetra
.492 .587 .877 r
.57031 .43402 .57588 .44326 .58638 .43361 .58102 .43493 Mtetra
.627 .081 0 r
.58102 .43493 .58638 .43361 .59705 .43132 .59193 .44204 Mtetra
.673 .276 .285 r
.59193 .44204 .59705 .43132 .608 .43822 .60302 .45162 Mtetra
.641 .263 .312 r
.60302 .45162 .608 .43822 .61922 .45052 .61419 .4598 Mtetra
.429 .005 .129 r
.61419 .4598 .61922 .45052 .63046 .45905 .62522 .45927 Mtetra
.766 .994 .873 r
.62522 .45927 .63046 .45905 .64161 .4614 .63604 .45075 Mtetra
.805 .7 .749 r
.63604 .45075 .64161 .4614 .65252 .45568 .6467 .43778 Mtetra
.754 .605 .692 r
.6467 .43778 .65252 .45568 .66322 .44425 .65729 .42344 Mtetra
.707 .561 .687 r
.65729 .42344 .66322 .44425 .67385 .43145 .66798 .41213 Mtetra
.673 .55 .707 r
.66798 .41213 .67385 .43145 .6845 .41951 .67883 .40458 Mtetra
.618 .558 .764 r
.67883 .40458 .6845 .41951 .69534 .41145 .68995 .40169 Mtetra
.524 .595 .867 r
.68995 .40169 .69534 .41145 .70639 .40687 .70128 .40197 Mtetra
.327 .657 .971 r
.70128 .40197 .70639 .40687 .71764 .40518 .71275 .40335 Mtetra
.05 .592 .847 r
.71275 .40335 .71764 .40518 .72906 .40515 .72431 .40478 Mtetra
.041 .609 .757 r
.72431 .40478 .72906 .40515 .74056 .40521 .73585 .40479 Mtetra
.196 .724 .829 r
.73585 .40479 .74056 .40521 .7521 .40487 .74737 .40344 Mtetra
.449 .862 .955 r
.74737 .40344 .7521 .40487 .76362 .40338 .75885 .40058 Mtetra
.609 .89 .989 r
.75885 .40058 .76362 .40338 .77514 .40093 .77029 .39669 Mtetra
.674 .854 .968 r
.77029 .39669 .77514 .40093 .78663 .39762 .78174 .39223 Mtetra
.694 .815 .94 r
.78174 .39223 .78663 .39762 .79813 .39374 .7932 .38747 Mtetra
.691 .783 .921 r
.7932 .38747 .79813 .39374 .80965 .38958 .80471 .38278 Mtetra
.687 .763 .91 r
.80471 .38278 .80965 .38958 .82119 .38526 .81627 .37818 Mtetra
.679 .752 .906 r
.81627 .37818 .82119 .38526 .83279 .38098 .82789 .3738 Mtetra
.673 .747 .907 r
.82789 .3738 .83279 .38098 .84443 .37672 .83957 .36958 Mtetra
.669 .748 .91 r
.83957 .36958 .84443 .37672 .85612 .37251 .85131 .36547 Mtetra
.665 .751 .914 r
.85131 .36547 .85612 .37251 .86786 .36837 .8631 .36144 Mtetra
.659 .752 .919 r
.23264 .55431 .23902 .55988 .24846 .55712 .24213 .55122 Mtetra
.656 .74 .912 r
.24213 .55122 .24846 .55712 .25793 .55445 .25165 .54817 Mtetra
.651 .727 .905 r
.25165 .54817 .25793 .55445 .26743 .5519 .2612 .54526 Mtetra
.641 .713 .9 r
.2612 .54526 .26743 .5519 .27696 .54949 .27076 .54257 Mtetra
.628 .701 .898 r
.27076 .54257 .27696 .54949 .2865 .5473 .28033 .54021 Mtetra
.612 .691 .899 r
.28033 .54021 .2865 .5473 .29608 .54521 .28992 .53821 Mtetra
.59 .687 .908 r
.28992 .53821 .29608 .54521 .3057 .54319 .29951 .53668 Mtetra
.575 .698 .925 r
.29951 .53668 .3057 .54319 .31537 .54089 .30914 .53538 Mtetra
.552 .727 .956 r
.30914 .53538 .31537 .54089 .32512 .53804 .3188 .53421 Mtetra
.545 .795 .991 r
.3188 .53421 .32512 .53804 .33495 .53419 .32854 .53255 Mtetra
.531 .875 .989 r
.32854 .53255 .33495 .53419 .3449 .5289 .33838 .5299 Mtetra
.5 .908 .871 r
.33838 .5299 .3449 .5289 .35494 .52227 .34834 .52554 Mtetra
.521 .899 .723 r
.34834 .52554 .35494 .52227 .36506 .51426 .35846 .51881 Mtetra
.577 .904 .656 r
.35846 .51881 .36506 .51426 .37519 .50628 .36868 .51008 Mtetra
.763 .985 .746 r
.36868 .51008 .37519 .50628 .38528 .49936 .37899 .49953 Mtetra
.865 .966 .862 r
.37899 .49953 .38528 .49936 .39526 .49552 .38927 .48941 Mtetra
.786 .769 .838 r
.38927 .48941 .39526 .49552 .40512 .49624 .39947 .48136 Mtetra
.639 .561 .751 r
.39947 .48136 .40512 .49624 .41491 .50066 .40953 .47757 Mtetra
.522 .429 .691 r
.40953 .47757 .41491 .50066 .42469 .50807 .41944 .47952 Mtetra
.45 .356 .658 r
.41944 .47952 .42469 .50807 .43461 .51418 .42928 .48617 Mtetra
.375 .307 .652 r
.42928 .48617 .43461 .51418 .44473 .51594 .43913 .4964 Mtetra
.314 .32 .706 r
.43913 .4964 .44473 .51594 .45509 .50984 .44913 .50533 Mtetra
0 .433 .842 r
.44913 .50533 .45509 .50984 .46562 .49513 .45934 .50951 Mtetra
.362 .001 .21 r
.45934 .50951 .46562 .49513 .47613 .47898 .46977 .50527 Mtetra
.264 0 .295 r
.46977 .50527 .47613 .47898 .48658 .46523 .48036 .49186 Mtetra
.185 0 .267 r
.48036 .49186 .48658 .46523 .49696 .45762 .49096 .47508 Mtetra
0 0 .066 r
.49096 .47508 .49696 .45762 .5073 .45684 .50152 .45826 Mtetra
.903 .982 .786 r
.50152 .45826 .5073 .45684 .5177 .45787 .51202 .44494 Mtetra
.721 .629 .754 r
.51202 .44494 .5177 .45787 .52816 .45819 .52249 .43683 Mtetra
.611 .498 .7 r
.52249 .43683 .52816 .45819 .53868 .45483 .53298 .43343 Mtetra
.532 .448 .706 r
.53298 .43343 .53868 .45483 .5492 .44777 .54353 .43476 Mtetra
.291 .389 .791 r
.54353 .43476 .5492 .44777 .55974 .44 .55421 .44133 Mtetra
.719 .208 .01 r
.55421 .44133 .55974 .44 .57031 .43402 .56504 .45147 Mtetra
.653 .301 .364 r
.56504 .45147 .57031 .43402 .58102 .43493 .57599 .46161 Mtetra
.595 .28 .406 r
.57599 .46161 .58102 .43493 .59193 .44204 .58702 .46839 Mtetra
.483 .179 .373 r
.58702 .46839 .59193 .44204 .60302 .45162 .59795 .46594 Mtetra
.115 0 .111 r
.59795 .46594 .60302 .45162 .61419 .4598 .60871 .45495 Mtetra
.902 .829 .765 r
.60871 .45495 .61419 .4598 .62522 .45927 .61933 .43911 Mtetra
.761 .596 .672 r
.61933 .43911 .62522 .45927 .63604 .45075 .62986 .4219 Mtetra
.691 .519 .65 r
.62986 .4219 .63604 .45075 .6467 .43778 .64047 .4083 Mtetra
.649 .491 .655 r
.64047 .4083 .6467 .43778 .65729 .42344 .65123 .39945 Mtetra
.599 .479 .687 r
.65123 .39945 .65729 .42344 .66798 .41213 .66226 .39646 Mtetra
.52 .493 .767 r
.66226 .39646 .66798 .41213 .67883 .40458 .67354 .39782 Mtetra
.261 .541 .922 r
.67354 .39782 .67883 .40458 .68995 .40169 .685 .40132 Mtetra
.347 0 0 r
.685 .40132 .68995 .40169 .70128 .40197 .69657 .40529 Mtetra
.415 0 0 r
.69657 .40529 .70128 .40197 .71275 .40335 .70815 .40742 Mtetra
.321 0 0 r
.70815 .40742 .71275 .40335 .72431 .40478 .71968 .4075 Mtetra
.042 0 0 r
.71968 .4075 .72431 .40478 .73585 .40479 .73114 .40514 Mtetra
.396 .853 .831 r
.73114 .40514 .73585 .40479 .74737 .40344 .74252 .40101 Mtetra
.67 .924 .973 r
.74252 .40101 .74737 .40344 .75885 .40058 .75388 .39585 Mtetra
.727 .85 .939 r
.75388 .39585 .75885 .40058 .77029 .39669 .76524 .39016 Mtetra
.718 .782 .903 r
.76524 .39016 .77029 .39669 .78174 .39223 .77664 .38461 Mtetra
.706 .744 .882 r
.77664 .38461 .78174 .39223 .7932 .38747 .78809 .37929 Mtetra
.689 .723 .876 r
.78809 .37929 .7932 .38747 .80471 .38278 .79962 .37445 Mtetra
.677 .715 .877 r
.79962 .37445 .80471 .38278 .81627 .37818 .81122 .36998 Mtetra
.667 .715 .884 r
.81122 .36998 .81627 .37818 .82789 .3738 .82289 .36585 Mtetra
.66 .72 .893 r
.82289 .36585 .82789 .3738 .83957 .36958 .83464 .36194 Mtetra
.656 .728 .903 r
.83464 .36194 .83957 .36958 .85131 .36547 .84645 .35818 Mtetra
.654 .739 .913 r
.84645 .35818 .85131 .36547 .8631 .36144 .85831 .35446 Mtetra
.673 .755 .913 r
.22623 .54871 .23264 .55431 .24213 .55122 .23577 .54524 Mtetra
.673 .743 .904 r
.23577 .54524 .24213 .55122 .25165 .54817 .24534 .54175 Mtetra
.669 .729 .894 r
.24534 .54175 .25165 .54817 .2612 .54526 .25494 .53833 Mtetra
.661 .711 .885 r
.25494 .53833 .2612 .54526 .27076 .54257 .26456 .53509 Mtetra
.65 .693 .877 r
.26456 .53509 .27076 .54257 .28033 .54021 .27419 .53212 Mtetra
.633 .671 .868 r
.27419 .53212 .28033 .54021 .28992 .53821 .28383 .52958 Mtetra
.61 .649 .863 r
.28383 .52958 .28992 .53821 .29951 .53668 .29346 .52765 Mtetra
.587 .63 .861 r
.29346 .52765 .29951 .53668 .30914 .53538 .30309 .52635 Mtetra
.556 .616 .868 r
.30309 .52635 .30914 .53538 .3188 .53421 .31272 .52579 Mtetra
.537 .625 .886 r
.31272 .52579 .3188 .53421 .32854 .53255 .32239 .52553 Mtetra
.518 .661 .925 r
.32239 .52553 .32854 .53255 .33838 .5299 .3321 .5253 Mtetra
.53 .759 .981 r
.3321 .5253 .33838 .5299 .34834 .52554 .34192 .52408 Mtetra
.548 .889 .984 r
.34192 .52408 .34834 .52554 .35846 .51881 .35189 .52107 Mtetra
.496 .9 .784 r
.35189 .52107 .35846 .51881 .36868 .51008 .36201 .51552 Mtetra
.482 .833 .564 r
.36201 .51552 .36868 .51008 .37899 .49953 .37231 .50678 Mtetra
0 0 0 r
.37231 .50678 .37899 .49953 .38927 .48941 .3827 .49594 Mtetra
.642 .894 .562 r
.3827 .49594 .38927 .48941 .39947 .48136 .39313 .48379 Mtetra
.821 1 .807 r
.39313 .48379 .39947 .48136 .40953 .47757 .40348 .47329 Mtetra
.777 .833 .895 r
.40348 .47329 .40953 .47757 .41944 .47952 .41371 .4665 Mtetra
.589 .559 .788 r
.41371 .4665 .41944 .47952 .42928 .48617 .42378 .46509 Mtetra
.451 .396 .705 r
.42378 .46509 .42928 .48617 .43913 .4964 .43373 .4699 Mtetra
.401 .332 .664 r
.43373 .4699 .43913 .4964 .44913 .50533 .44369 .47835 Mtetra
.376 .314 .66 r
.44369 .47835 .44913 .50533 .45934 .50951 .45372 .48809 Mtetra
.455 .398 .705 r
.45372 .48809 .45934 .50951 .46977 .50527 .46397 .49288 Mtetra
.628 .592 .795 r
.46397 .49288 .46977 .50527 .48036 .49186 .47442 .48997 Mtetra
.827 .929 .9 r
.47442 .48997 .48036 .49186 .49096 .47508 .48498 .4814 Mtetra
.597 .861 .518 r
.48498 .4814 .49096 .47508 .50152 .45826 .49559 .46904 Mtetra
0 0 0 r
.49559 .46904 .50152 .45826 .51202 .44494 .50617 .45771 Mtetra
.175 0 .093 r
.50617 .45771 .51202 .44494 .52249 .43683 .51674 .44979 Mtetra
.372 0 .189 r
.51674 .44979 .52249 .43683 .53298 .43343 .52731 .44639 Mtetra
.507 .125 .25 r
.52731 .44639 .53298 .43343 .54353 .43476 .53795 .44751 Mtetra
.583 .199 .28 r
.53795 .44751 .54353 .43476 .55421 .44133 .54869 .45207 Mtetra
.606 .202 .252 r
.54869 .45207 .55421 .44133 .56504 .45147 .55952 .4577 Mtetra
.477 0 .039 r
.55952 .4577 .56504 .45147 .57599 .46161 .57041 .45953 Mtetra
.602 .902 .985 r
.57041 .45953 .57599 .46161 .58702 .46839 .58128 .45568 Mtetra
.769 .658 .74 r
.58128 .45568 .58702 .46839 .59795 .46594 .59203 .44402 Mtetra
.747 .579 .668 r
.59203 .44402 .59795 .46594 .60871 .45495 .60264 .42733 Mtetra
.709 .535 .651 r
.60264 .42733 .60871 .45495 .61933 .43911 .61325 .41189 Mtetra
.682 .519 .658 r
.61325 .41189 .61933 .43911 .62986 .4219 .62393 .40012 Mtetra
.637 .513 .696 r
.62393 .40012 .62986 .4219 .64047 .4083 .63481 .39465 Mtetra
.549 .536 .793 r
.63481 .39465 .64047 .4083 .65123 .39945 .64592 .39466 Mtetra
.083 .507 .901 r
.64592 .39466 .65123 .39945 .66226 .39646 .65726 .39847 Mtetra
.552 0 0 r
.65726 .39847 .66226 .39646 .67354 .39782 .66878 .404 Mtetra
.554 .075 .072 r
.66878 .404 .67354 .39782 .685 .40132 .68034 .40822 Mtetra
.487 .016 .062 r
.68034 .40822 .685 .40132 .69657 .40529 .69189 .4103 Mtetra
.281 0 0 r
.69189 .4103 .69657 .40529 .70815 .40742 .70334 .40912 Mtetra
0 0 0 r
.70334 .40912 .70815 .40742 .71968 .4075 .71471 .40533 Mtetra
.69 .937 .965 r
.71471 .40533 .71968 .4075 .73114 .40514 .726 .39968 Mtetra
.757 .829 .908 r
.726 .39968 .73114 .40514 .74252 .40101 .73726 .393 Mtetra
.737 .744 .857 r
.73726 .393 .74252 .40101 .75388 .39585 .74855 .38634 Mtetra
.718 .7 .832 r
.74855 .38634 .75388 .39585 .76524 .39016 .75988 .37997 Mtetra
.696 .677 .828 r
.75988 .37997 .76524 .39016 .77664 .38461 .7713 .37436 Mtetra
.68 .669 .833 r
.7713 .37436 .77664 .38461 .78809 .37929 .78281 .3694 Mtetra
.666 .671 .845 r
.78281 .3694 .78809 .37929 .79962 .37445 .7944 .36507 Mtetra
.656 .679 .86 r
.7944 .36507 .79962 .37445 .81122 .36998 .80608 .36118 Mtetra
.649 .692 .876 r
.80608 .36118 .81122 .36998 .82289 .36585 .81784 .35758 Mtetra
.644 .705 .891 r
.81784 .35758 .82289 .36585 .83464 .36194 .82966 .35415 Mtetra
.641 .718 .904 r
.82966 .35415 .83464 .36194 .84645 .35818 .84154 .35081 Mtetra
.641 .732 .915 r
.84154 .35081 .84645 .35818 .85831 .35446 .85348 .34743 Mtetra
.683 .757 .908 r
.21976 .54307 .22623 .54871 .23577 .54524 .22935 .53933 Mtetra
.685 .749 .9 r
.22935 .53933 .23577 .54524 .24534 .54175 .23897 .53547 Mtetra
.685 .738 .891 r
.23897 .53547 .24534 .54175 .25494 .53833 .24863 .53156 Mtetra
.683 .723 .881 r
.24863 .53156 .25494 .53833 .26456 .53509 .25832 .52767 Mtetra
.678 .704 .867 r
.25832 .52767 .26456 .53509 .27419 .53212 .26803 .52382 Mtetra
.665 .678 .852 r
.26803 .52382 .27419 .53212 .28383 .52958 .27775 .52025 Mtetra
.647 .648 .837 r
.27775 .52025 .28383 .52958 .29346 .52765 .28748 .51713 Mtetra
.622 .613 .821 r
.28748 .51713 .29346 .52765 .30309 .52635 .29719 .51475 Mtetra
.589 .579 .81 r
.29719 .51475 .30309 .52635 .31272 .52579 .30687 .5134 Mtetra
.555 .549 .802 r
.30687 .5134 .31272 .52579 .32239 .52553 .31653 .51312 Mtetra
.512 .526 .808 r
.31653 .51312 .32239 .52553 .3321 .5253 .32617 .51407 Mtetra
.48 .531 .833 r
.32617 .51407 .3321 .5253 .34192 .52408 .33584 .51558 Mtetra
.429 .574 .896 r
.33584 .51558 .34192 .52408 .35189 .52107 .34557 .5172 Mtetra
.347 .711 .985 r
.34557 .5172 .35189 .52107 .36201 .51552 .35543 .51755 Mtetra
0 0 0 r
.35543 .51755 .36201 .51552 .37231 .50678 .36546 .51547 Mtetra
.112 0 0 r
.36546 .51547 .37231 .50678 .3827 .49594 .37569 .51 Mtetra
.09 0 .059 r
.37569 .51 .3827 .49594 .39313 .48379 .38612 .50036 Mtetra
.031 0 .077 r
.38612 .50036 .39313 .48379 .40348 .47329 .39666 .48768 Mtetra
0 0 0 r
.39666 .48768 .40348 .47329 .41371 .4665 .40727 .47286 Mtetra
.749 .937 .598 r
.40727 .47286 .41371 .4665 .42378 .46509 .41781 .45878 Mtetra
.831 .773 .797 r
.41781 .45878 .42378 .46509 .43373 .4699 .42825 .4475 Mtetra
.65 .515 .686 r
.42825 .4475 .43373 .4699 .44369 .47835 .43855 .44089 Mtetra
.559 .407 .632 r
.43855 .44089 .44369 .47835 .45372 .48809 .44873 .44027 Mtetra
.501 .35 .607 r
.44873 .44027 .45372 .48809 .46397 .49288 .45884 .44592 Mtetra
.444 .31 .603 r
.45884 .44592 .46397 .49288 .47442 .48997 .46895 .45704 Mtetra
.376 .292 .633 r
.46895 .45704 .47442 .48997 .48498 .4814 .47918 .46893 Mtetra
.051 .247 .744 r
.47918 .46893 .48498 .4814 .49559 .46904 .48957 .47884 Mtetra
.614 .203 .24 r
.48957 .47884 .49559 .46904 .50617 .45771 .50011 .48472 Mtetra
.525 .216 .386 r
.50011 .48472 .50617 .45771 .51674 .44979 .51078 .48551 Mtetra
.486 .202 .408 r
.51078 .48551 .51674 .44979 .52731 .44639 .52152 .48212 Mtetra
.436 .159 .394 r
.52152 .48212 .52731 .44639 .53795 .44751 .5323 .47453 Mtetra
.294 .016 .31 r
.5323 .47453 .53795 .44751 .54869 .45207 .54306 .46181 Mtetra
0 0 0 r
.54306 .46181 .54869 .45207 .55952 .4577 .55376 .44502 Mtetra
.831 .681 .698 r
.55376 .44502 .55952 .4577 .57041 .45953 .5644 .42617 Mtetra
.705 .517 .633 r
.5644 .42617 .57041 .45953 .58128 .45568 .57498 .40805 Mtetra
.637 .448 .611 r
.57498 .40805 .58128 .45568 .59203 .44402 .58562 .39541 Mtetra
.596 .418 .611 r
.58562 .39541 .59203 .44402 .60264 .42733 .59637 .38909 Mtetra
.555 .405 .633 r
.59637 .38909 .60264 .42733 .61325 .41189 .60731 .38884 Mtetra
.473 .403 .697 r
.60731 .38884 .61325 .41189 .62393 .40012 .61844 .39334 Mtetra
0 .311 .798 r
.61844 .39334 .62393 .40012 .63481 .39465 .62978 .40073 Mtetra
.66 .195 .139 r
.62978 .40073 .63481 .39465 .64592 .39466 .64125 .4089 Mtetra
.601 .221 .295 r
.64125 .4089 .64592 .39466 .65726 .39847 .65278 .41494 Mtetra
.547 .185 .304 r
.65278 .41494 .65726 .39847 .66878 .404 .66428 .4179 Mtetra
.446 .071 .232 r
.66428 .4179 .66878 .404 .68034 .40822 .67567 .4166 Mtetra
.207 0 0 r
.67567 .4166 .68034 .40822 .69189 .4103 .68695 .4118 Mtetra
.563 .928 .775 r
.68695 .4118 .69189 .4103 .70334 .40912 .69814 .40452 Mtetra
.812 .867 .888 r
.69814 .40452 .70334 .40912 .71471 .40533 .70927 .39589 Mtetra
.761 .717 .811 r
.70927 .39589 .71471 .40533 .726 .39968 .72042 .38737 Mtetra
.724 .652 .777 r
.72042 .38737 .726 .39968 .73726 .393 .73161 .37941 Mtetra
.693 .62 .77 r
.73161 .37941 .73726 .393 .74855 .38634 .74291 .3727 Mtetra
.673 .609 .776 r
.74291 .3727 .74855 .38634 .75988 .37997 .75431 .36709 Mtetra
.656 .612 .793 r
.75431 .36709 .75988 .37997 .7713 .37436 .76582 .36255 Mtetra
.644 .623 .814 r
.76582 .36255 .7713 .37436 .78281 .3694 .77744 .35877 Mtetra
.636 .642 .84 r
.77744 .35877 .78281 .3694 .7944 .36507 .78914 .35546 Mtetra
.63 .663 .863 r
.78914 .35546 .7944 .36507 .80608 .36118 .80093 .35244 Mtetra
.629 .685 .884 r
.80093 .35244 .80608 .36118 .81784 .35758 .81277 .34946 Mtetra
.627 .703 .9 r
.81277 .34946 .81784 .35758 .82966 .35415 .82466 .34649 Mtetra
.627 .718 .912 r
.82466 .34649 .82966 .35415 .84154 .35081 .83661 .34348 Mtetra
.63 .731 .92 r
.83661 .34348 .84154 .35081 .85348 .34743 .84861 .34035 Mtetra
.68 .757 .909 r
.21326 .53739 .21976 .54307 .22935 .53933 .22286 .5337 Mtetra
.685 .76 .909 r
.22286 .5337 .22935 .53933 .23897 .53547 .2325 .52986 Mtetra
.69 .763 .907 r
.2325 .52986 .23897 .53547 .24863 .53156 .24219 .52586 Mtetra
.696 .761 .902 r
.24219 .52586 .24863 .53156 .25832 .52767 .25192 .52168 Mtetra
.702 .754 .893 r
.25192 .52168 .25832 .52767 .26803 .52382 .2617 .51728 Mtetra
.7 .737 .88 r
.2617 .51728 .26803 .52382 .27775 .52025 .27151 .51284 Mtetra
.693 .711 .862 r
.27151 .51284 .27775 .52025 .28748 .51713 .28134 .50844 Mtetra
.674 .674 .842 r
.28134 .50844 .28748 .51713 .29719 .51475 .29117 .50445 Mtetra
.647 .63 .819 r
.29117 .50445 .29719 .51475 .30687 .5134 .30099 .50118 Mtetra
.61 .58 .795 r
.30099 .50118 .30687 .5134 .31653 .51312 .31076 .49905 Mtetra
.566 .531 .775 r
.31076 .49905 .31653 .51312 .32617 .51407 .32049 .49845 Mtetra
.526 .49 .759 r
.32049 .49845 .32617 .51407 .33584 .51558 .33018 .49934 Mtetra
.48 .456 .754 r
.33018 .49934 .33584 .51558 .34557 .5172 .33984 .50183 Mtetra
.456 .452 .766 r
.33984 .50183 .34557 .5172 .35543 .51755 .34954 .50487 Mtetra
.436 .482 .809 r
.34954 .50487 .35543 .51755 .36546 .51547 .35933 .50769 Mtetra
.46 .615 .916 r
.35933 .50769 .36546 .51547 .37569 .51 .36929 .50854 Mtetra
.482 .865 .977 r
.36929 .50854 .37569 .51 .38612 .50036 .37945 .50606 Mtetra
0 0 0 r
.37945 .50606 .38612 .50036 .39666 .48768 .38982 .49958 Mtetra
.38982 .49958 .39666 .48768 .40727 .47286 .40038 .48867 Mtetra
0 0 .021 r
.40038 .48867 .40727 .47286 .41781 .45878 .41102 .47492 Mtetra
0 0 .002 r
.41102 .47492 .41781 .45878 .42825 .4475 .42169 .45974 Mtetra
0 0 0 r
.42169 .45974 .42825 .4475 .43855 .44089 .43227 .44635 Mtetra
.488 .829 .544 r
.43227 .44635 .43855 .44089 .44873 .44027 .44272 .437 Mtetra
.598 .847 .991 r
.44272 .437 .44873 .44027 .45884 .44592 .45304 .4341 Mtetra
.373 .463 .823 r
.45304 .4341 .45884 .44592 .46895 .45704 .46326 .43808 Mtetra
.378 .368 .722 r
.46326 .43808 .46895 .45704 .47918 .46893 .47353 .44475 Mtetra
.42 .359 .683 r
.47353 .44475 .47918 .46893 .48957 .47884 .48391 .4516 Mtetra
.485 .388 .67 r
.48391 .4516 .48957 .47884 .50011 .48472 .49441 .45588 Mtetra
.549 .426 .664 r
.49441 .45588 .50011 .48472 .51078 .48551 .50503 .45613 Mtetra
.595 .454 .66 r
.50503 .45613 .51078 .48551 .52152 .48212 .51572 .45269 Mtetra
.633 .48 .657 r
.51572 .45269 .52152 .48212 .5323 .47453 .52645 .44555 Mtetra
.671 .506 .654 r
.52645 .44555 .5323 .47453 .54306 .46181 .53719 .43436 Mtetra
.698 .528 .654 r
.53719 .43436 .54306 .46181 .55376 .44502 .5479 .42055 Mtetra
.71 .546 .665 r
.5479 .42055 .55376 .44502 .5644 .42617 .55858 .40689 Mtetra
.713 .573 .696 r
.55858 .40689 .5644 .42617 .57498 .40805 .56928 .39591 Mtetra
.652 .613 .797 r
.56928 .39591 .57498 .40805 .58562 .39541 .58008 .39185 Mtetra
.089 .566 .905 r
.58008 .39185 .58562 .39541 .59637 .38909 .59106 .39433 Mtetra
.626 .143 .088 r
.59106 .39433 .59637 .38909 .60731 .38884 .60222 .40093 Mtetra
.646 .251 .282 r
.60222 .40093 .60731 .38884 .61844 .39334 .61355 .40939 Mtetra
.612 .245 .321 r
.61355 .40939 .61844 .39334 .62978 .40073 .62496 .41643 Mtetra
.568 .198 .3 r
.62496 .41643 .62978 .40073 .64125 .4089 .63639 .42061 Mtetra
.453 .052 .188 r
.63639 .42061 .64125 .4089 .65278 .41494 .64775 .42029 Mtetra
.06 0 0 r
.64775 .42029 .65278 .41494 .66428 .4179 .65901 .41588 Mtetra
.786 .954 .925 r
.65901 .41588 .66428 .4179 .67567 .4166 .67016 .40804 Mtetra
.793 .745 .809 r
.67016 .40804 .67567 .4166 .68695 .4118 .68122 .39817 Mtetra
.744 .643 .748 r
.68122 .39817 .68695 .4118 .69814 .40452 .69227 .38805 Mtetra
.715 .599 .726 r
.69227 .38805 .69814 .40452 .70927 .39589 .70335 .37847 Mtetra
.688 .577 .725 r
.70335 .37847 .70927 .39589 .72042 .38737 .71454 .37051 Mtetra
.669 .571 .736 r
.71454 .37051 .72042 .38737 .73161 .37941 .72583 .36408 Mtetra
.65 .577 .759 r
.72583 .36408 .73161 .37941 .74291 .3727 .73726 .35924 Mtetra
.635 .593 .789 r
.73726 .35924 .74291 .3727 .75431 .36709 .74881 .35556 Mtetra
.623 .618 .825 r
.74881 .35556 .75431 .36709 .76582 .36255 .76046 .35263 Mtetra
.613 .647 .86 r
.76046 .35263 .76582 .36255 .77744 .35877 .7722 .35014 Mtetra
.611 .68 .891 r
.7722 .35014 .77744 .35877 .78914 .35546 .78401 .34768 Mtetra
.609 .705 .912 r
.78401 .34768 .78914 .35546 .80093 .35244 .79587 .34518 Mtetra
.615 .726 .925 r
.79587 .34518 .80093 .35244 .81277 .34946 .80776 .34245 Mtetra
.621 .737 .93 r
.80776 .34245 .81277 .34946 .82466 .34649 .8197 .33953 Mtetra
.626 .743 .931 r
.8197 .33953 .82466 .34649 .83661 .34348 .83168 .33645 Mtetra
.632 .744 .928 r
.83168 .33645 .83661 .34348 .84861 .34035 .8437 .33321 Mtetra
.664 .753 .917 r
.20671 .53168 .21326 .53739 .22286 .5337 .21629 .52838 Mtetra
.668 .769 .925 r
.21629 .52838 .22286 .5337 .2325 .52986 .22592 .52494 Mtetra
.677 .786 .932 r
.22592 .52494 .2325 .52986 .24219 .52586 .2356 .52129 Mtetra
.689 .802 .935 r
.2356 .52129 .24219 .52586 .25192 .52168 .24534 .51731 Mtetra
.706 .813 .932 r
.24534 .51731 .25192 .52168 .2617 .51728 .25514 .5129 Mtetra
.721 .815 .924 r
.25514 .5129 .2617 .51728 .27151 .51284 .26501 .50807 Mtetra
.735 .803 .906 r
.26501 .50807 .27151 .51284 .28134 .50844 .27494 .50277 Mtetra
.735 .774 .884 r
.27494 .50277 .28134 .50844 .29117 .50445 .2849 .49726 Mtetra
.724 .728 .853 r
.2849 .49726 .29117 .50445 .30099 .50118 .29489 .49168 Mtetra
.695 .666 .817 r
.29489 .49168 .30099 .50118 .31076 .49905 .30488 .4866 Mtetra
.657 .601 .78 r
.30488 .4866 .31076 .49905 .32049 .49845 .31482 .48244 Mtetra
.611 .535 .744 r
.31482 .48244 .32049 .49845 .33018 .49934 .32471 .47978 Mtetra
.564 .478 .716 r
.32471 .47978 .33018 .49934 .33984 .50183 .33452 .47916 Mtetra
.523 .432 .694 r
.33452 .47916 .33984 .50183 .34954 .50487 .34427 .48067 Mtetra
.48 .396 .683 r
.34427 .48067 .34954 .50487 .35933 .50769 .35397 .48445 Mtetra
.447 .38 .688 r
.35397 .48445 .35933 .50769 .36929 .50854 .36368 .48951 Mtetra
.401 .381 .722 r
.36368 .48951 .36929 .50854 .37945 .50606 .37346 .49513 Mtetra
.298 .441 .836 r
.37346 .49513 .37945 .50606 .38982 .49958 .38337 .49979 Mtetra
.318 0 0 r
.38337 .49979 .38982 .49958 .40038 .48867 .39345 .50221 Mtetra
.441 .062 .222 r
.39345 .50221 .40038 .48867 .41102 .47492 .40374 .50105 Mtetra
.416 .112 .339 r
.40374 .50105 .41102 .47492 .42169 .45974 .41424 .49542 Mtetra
.404 .128 .377 r
.41424 .49542 .42169 .45974 .43227 .44635 .42486 .48628 Mtetra
.379 .115 .382 r
.42486 .48628 .43227 .44635 .44272 .437 .43558 .47395 Mtetra
.307 .049 .349 r
.43558 .47395 .44272 .437 .45304 .4341 .44636 .45813 Mtetra
.048 0 .178 r
.44636 .45813 .45304 .4341 .46326 .43808 .45716 .43959 Mtetra
.958 .932 .724 r
.45716 .43959 .46326 .43808 .47353 .44475 .46791 .42095 Mtetra
.737 .564 .659 r
.46791 .42095 .47353 .44475 .48391 .4516 .47857 .40405 Mtetra
.639 .449 .611 r
.47857 .40405 .48391 .4516 .49441 .45588 .48914 .39104 Mtetra
.592 .4 .591 r
.48914 .39104 .49441 .45588 .50503 .45613 .49966 .38292 Mtetra
.564 .375 .583 r
.49966 .38292 .50503 .45613 .51572 .45269 .51016 .3794 Mtetra
.54 .357 .582 r
.51016 .3794 .51572 .45269 .52645 .44555 .5207 .3805 Mtetra
.509 .339 .586 r
.5207 .3805 .52645 .44555 .53719 .43436 .53131 .38651 Mtetra
.458 .32 .605 r
.53131 .38651 .53719 .43436 .5479 .42055 .54206 .39647 Mtetra
.3 .282 .671 r
.54206 .39647 .5479 .42055 .55858 .40689 .55295 .40824 Mtetra
.744 .242 .032 r
.55295 .40824 .55858 .40689 .56928 .39591 .56399 .41996 Mtetra
.618 .288 .389 r
.56399 .41996 .56928 .39591 .58008 .39185 .57513 .42897 Mtetra
.569 .274 .427 r
.57513 .42897 .58008 .39185 .59106 .39433 .58633 .4345 Mtetra
.542 .255 .429 r
.58633 .4345 .59106 .39433 .60222 .40093 .59757 .43683 Mtetra
.507 .217 .409 r
.59757 .43683 .60222 .40093 .61355 .40939 .60881 .4356 Mtetra
.423 .12 .345 r
.60881 .4356 .61355 .40939 .62496 .41643 .61997 .42983 Mtetra
.145 0 .095 r
.61997 .42983 .62496 .41643 .63639 .42061 .63104 .42038 Mtetra
.872 .986 .832 r
.63104 .42038 .63639 .42061 .64775 .42029 .64203 .40863 Mtetra
.795 .689 .748 r
.64203 .40863 .64775 .42029 .65901 .41588 .65298 .39586 Mtetra
.721 .577 .692 r
.65298 .39586 .65901 .41588 .67016 .40804 .66392 .38363 Mtetra
.686 .533 .673 r
.66392 .38363 .67016 .40804 .68122 .39817 .67492 .37269 Mtetra
.658 .511 .673 r
.67492 .37269 .68122 .39817 .69227 .38805 .68602 .36407 Mtetra
.639 .506 .685 r
.68602 .36407 .69227 .38805 .70335 .37847 .69725 .35761 Mtetra
.622 .513 .709 r
.69725 .35761 .70335 .37847 .71454 .37051 .70863 .35325 Mtetra
.606 .532 .745 r
.70863 .35325 .71454 .37051 .72583 .36408 .72015 .35044 Mtetra
.592 .567 .795 r
.72015 .35044 .72583 .36408 .73726 .35924 .73178 .34859 Mtetra
.577 .613 .852 r
.73178 .34859 .73726 .35924 .74881 .35556 .74351 .34725 Mtetra
.569 .669 .906 r
.74351 .34725 .74881 .35556 .76046 .35263 .75531 .34585 Mtetra
.563 .717 .945 r
.75531 .34585 .76046 .35263 .7722 .35014 .76715 .34424 Mtetra
.574 .757 .964 r
.76715 .34424 .7722 .35014 .78401 .34768 .77902 .34214 Mtetra
.589 .778 .97 r
.77902 .34214 .78401 .34768 .79587 .34518 .79092 .3396 Mtetra
.611 .787 .966 r
.79092 .3396 .79587 .34518 .80776 .34245 .80283 .33661 Mtetra
.628 .785 .957 r
.80283 .33661 .80776 .34245 .8197 .33953 .81477 .33328 Mtetra
.64 .776 .946 r
.81477 .33328 .8197 .33953 .83168 .33645 .82675 .32972 Mtetra
.648 .763 .933 r
.82675 .32972 .83168 .33645 .8437 .33321 .83876 .32602 Mtetra
.638 .747 .928 r
.20012 .52592 .20671 .53168 .21629 .52838 .20966 .5232 Mtetra
.637 .768 .943 r
.20966 .5232 .21629 .52838 .22592 .52494 .21925 .52042 Mtetra
.641 .795 .957 r
.21925 .52042 .22592 .52494 .2356 .52129 .22889 .51747 Mtetra
.649 .825 .968 r
.22889 .51747 .2356 .52129 .24534 .51731 .2386 .51421 Mtetra
.662 .857 .974 r
.2386 .51421 .24534 .51731 .25514 .5129 .24837 .51052 Mtetra
.681 .888 .974 r
.24837 .51052 .25514 .5129 .26501 .50807 .25822 .50627 Mtetra
.708 .914 .965 r
.25822 .50627 .26501 .50807 .27494 .50277 .26816 .5013 Mtetra
.735 .928 .954 r
.26816 .5013 .27494 .50277 .2849 .49726 .27817 .49566 Mtetra
.768 .924 .939 r
.27817 .49566 .2849 .49726 .29489 .49168 .28826 .4893 Mtetra
.782 .896 .924 r
.28826 .4893 .29489 .49168 .30488 .4866 .29839 .4826 Mtetra
.779 .838 .897 r
.29839 .4826 .30488 .4866 .31482 .48244 .30854 .47581 Mtetra
.743 .75 .858 r
.30854 .47581 .31482 .48244 .32471 .47978 .31866 .46963 Mtetra
.688 .653 .81 r
.31866 .46963 .32471 .47978 .33452 .47916 .32874 .46466 Mtetra
.624 .559 .761 r
.32874 .46466 .33452 .47916 .34427 .48067 .33873 .46157 Mtetra
.562 .481 .721 r
.33873 .46157 .34427 .48067 .35397 .48445 .34863 .461 Mtetra
.514 .422 .689 r
.34863 .461 .35397 .48445 .36368 .48951 .35846 .46294 Mtetra
.472 .379 .669 r
.35846 .46294 .36368 .48951 .37346 .49513 .36823 .46746 Mtetra
.448 .358 .662 r
.36823 .46746 .37346 .49513 .38337 .49979 .37802 .4734 Mtetra
.432 .354 .668 r
.37802 .4734 .38337 .49979 .39345 .50221 .38789 .47984 Mtetra
.438 .381 .697 r
.38789 .47984 .39345 .50221 .40374 .50105 .39791 .48507 Mtetra
.472 .46 .763 r
.39791 .48507 .40374 .50105 .41424 .49542 .40811 .4877 Mtetra
.555 .667 .912 r
.40811 .4877 .41424 .49542 .42486 .48628 .4185 .48672 Mtetra
.604 .951 .906 r
.4185 .48672 .42486 .48628 .43558 .47395 .42908 .48127 Mtetra
0 0 0 r
.42908 .48127 .43558 .47395 .44636 .45813 .43983 .47049 Mtetra
.43983 .47049 .44636 .45813 .45716 .43959 .45067 .45504 Mtetra
.45067 .45504 .45716 .43959 .46791 .42095 .46149 .4391 Mtetra
.043 0 .112 r
.46149 .4391 .46791 .42095 .47857 .40405 .47223 .42496 Mtetra
.241 0 .232 r
.47223 .42496 .47857 .40405 .48914 .39104 .48291 .41421 Mtetra
.378 .068 .307 r
.48291 .41421 .48914 .39104 .49966 .38292 .49354 .40758 Mtetra
.449 .137 .343 r
.49354 .40758 .49966 .38292 .51016 .3794 .50417 .40407 Mtetra
.501 .183 .36 r
.50417 .40407 .51016 .3794 .5207 .3805 .51483 .40367 Mtetra
.559 .23 .368 r
.51483 .40367 .5207 .3805 .53131 .38651 .52556 .40741 Mtetra
.605 .265 .366 r
.52556 .40741 .53131 .38651 .54206 .39647 .53639 .4146 Mtetra
.634 .279 .352 r
.53639 .4146 .54206 .39647 .55295 .40824 .54734 .42363 Mtetra
.636 .265 .323 r
.54734 .42363 .55295 .40824 .56399 .41996 .55842 .43222 Mtetra
.561 .163 .244 r
.55842 .43222 .56399 .41996 .57513 .42897 .56957 .43612 Mtetra
.326 0 0 r
.56957 .43612 .57513 .42897 .58633 .4345 .58071 .43466 Mtetra
.612 .955 .896 r
.58071 .43466 .58633 .4345 .59757 .43683 .59182 .42866 Mtetra
.793 .751 .814 r
.59182 .42866 .59757 .43683 .60881 .4356 .60288 .41897 Mtetra
.745 .613 .712 r
.60288 .41897 .60881 .4356 .61997 .42983 .61386 .40662 Mtetra
.716 .557 .672 r
.61386 .40662 .61997 .42983 .63104 .42038 .62478 .39299 Mtetra
.692 .526 .657 r
.62478 .39299 .63104 .42038 .64203 .40863 .6357 .37985 Mtetra
.675 .51 .654 r
.6357 .37985 .64203 .40863 .65298 .39586 .64665 .36812 Mtetra
.655 .5 .662 r
.64665 .36812 .65298 .39586 .66392 .38363 .6577 .35901 Mtetra
.638 .502 .681 r
.6577 .35901 .66392 .38363 .67492 .37269 .66887 .35246 Mtetra
.618 .514 .714 r
.66887 .35246 .67492 .37269 .68602 .36407 .68019 .34849 Mtetra
.593 .542 .767 r
.68019 .34849 .68602 .36407 .69725 .35761 .69166 .34646 Mtetra
.56 .593 .843 r
.69166 .34646 .69725 .35761 .70863 .35325 .70326 .34567 Mtetra
.504 .659 .93 r
.70326 .34567 .70863 .35325 .72015 .35044 .71497 .34552 Mtetra
.434 .726 .988 r
.71497 .34552 .72015 .35044 .73178 .34859 .72675 .3453 Mtetra
.37 .761 .988 r
.72675 .3453 .73178 .34859 .74351 .34725 .73857 .34473 Mtetra
.379 .795 .977 r
.73857 .34473 .74351 .34725 .75531 .34585 .75042 .34342 Mtetra
.431 .828 .982 r
.75042 .34342 .75531 .34585 .76715 .34424 .76229 .34142 Mtetra
.513 .856 .994 r
.76229 .34142 .76715 .34424 .77902 .34214 .77416 .33867 Mtetra
.579 .861 .995 r
.77416 .33867 .77902 .34214 .79092 .3396 .78603 .33533 Mtetra
.626 .849 .984 r
.78603 .33533 .79092 .3396 .80283 .33661 .79793 .33155 Mtetra
.653 .828 .967 r
.79793 .33155 .80283 .33661 .81477 .33328 .80985 .32744 Mtetra
.667 .804 .948 r
.80985 .32744 .81477 .33328 .82675 .32972 .82179 .32313 Mtetra
.671 .779 .931 r
.82179 .32313 .82675 .32972 .83876 .32602 .83378 .31877 Mtetra
.609 .739 .937 r
.19348 .52013 .20012 .52592 .20966 .5232 .20299 .51797 Mtetra
.6 .758 .954 r
.20299 .51797 .20966 .5232 .21925 .52042 .21253 .51587 Mtetra
.593 .783 .971 r
.21253 .51587 .21925 .52042 .22889 .51747 .22212 .51372 Mtetra
.585 .813 .986 r
.22212 .51372 .22889 .51747 .2386 .51421 .23177 .51142 Mtetra
.572 .848 .996 r
.23177 .51142 .2386 .51421 .24837 .51052 .24147 .5089 Mtetra
.556 .885 .989 r
.24147 .5089 .24837 .51052 .25822 .50627 .25125 .50595 Mtetra
.534 .909 .95 r
.25125 .50595 .25822 .50627 .26816 .5013 .26112 .50238 Mtetra
.507 .911 .876 r
.26112 .50238 .26816 .5013 .27817 .49566 .27108 .49799 Mtetra
.503 .905 .798 r
.27108 .49799 .27817 .49566 .28826 .4893 .28115 .49254 Mtetra
.521 .903 .743 r
.28115 .49254 .28826 .4893 .29839 .4826 .29132 .48606 Mtetra
.604 .94 .754 r
.29132 .48606 .29839 .4826 .30854 .47581 .30158 .47847 Mtetra
.716 .986 .819 r
.30158 .47847 .30854 .47581 .31866 .46963 .3119 .47015 Mtetra
.821 .981 .887 r
.3119 .47015 .31866 .46963 .32874 .46466 .32225 .46138 Mtetra
.823 .864 .877 r
.32225 .46138 .32874 .46466 .33873 .46157 .33259 .45285 Mtetra
.753 .705 .807 r
.33259 .45285 .33873 .46157 .34863 .461 .3429 .44514 Mtetra
.672 .572 .735 r
.3429 .44514 .34863 .461 .35846 .46294 .35313 .43903 Mtetra
.609 .482 .682 r
.35313 .43903 .35846 .46294 .36823 .46746 .36327 .43518 Mtetra
.569 .425 .646 r
.36327 .43518 .36823 .46746 .37802 .4734 .37334 .43351 Mtetra
.541 .389 .624 r
.37334 .43351 .37802 .4734 .38789 .47984 .38337 .43411 Mtetra
.518 .363 .61 r
.38337 .43411 .38789 .47984 .39791 .48507 .39335 .43712 Mtetra
.498 .345 .604 r
.39335 .43712 .39791 .48507 .40811 .4877 .40334 .44237 Mtetra
.488 .343 .609 r
.40334 .44237 .40811 .4877 .4185 .48672 .4134 .4483 Mtetra
.478 .348 .625 r
.4134 .4483 .4185 .48672 .42908 .48127 .42355 .45427 Mtetra
.422 .346 .666 r
.42355 .45427 .42908 .48127 .43983 .47049 .43377 .46134 Mtetra
0 .242 .758 r
.43377 .46134 .43983 .47049 .45067 .45504 .44407 .46977 Mtetra
.66 .291 .335 r
.44407 .46977 .45067 .45504 .46149 .4391 .45445 .47976 Mtetra
.604 .31 .444 r
.45445 .47976 .46149 .4391 .47223 .42496 .46495 .49035 Mtetra
.568 .3 .469 r
.46495 .49035 .47223 .42496 .48291 .41421 .47563 .49806 Mtetra
.541 .286 .477 r
.47563 .49806 .48291 .41421 .49354 .40758 .48647 .50094 Mtetra
.516 .267 .477 r
.48647 .50094 .49354 .40758 .50417 .40407 .49746 .49748 Mtetra
.488 .245 .471 r
.49746 .49748 .50417 .40407 .51483 .40367 .50852 .48768 Mtetra
.457 .216 .459 r
.50852 .48768 .51483 .40367 .52556 .40741 .51959 .473 Mtetra
.409 .168 .433 r
.51959 .473 .52556 .40741 .53639 .4146 .53063 .45537 Mtetra
.322 .069 .366 r
.53063 .45537 .53639 .4146 .54734 .42363 .54162 .43831 Mtetra
0 0 0 r
.54162 .43831 .54734 .42363 .55842 .43222 .55257 .42277 Mtetra
.831 .73 .753 r
.55257 .42277 .55842 .43222 .56957 .43612 .5635 .40856 Mtetra
.692 .524 .656 r
.5635 .40856 .56957 .43612 .58071 .43466 .57442 .39543 Mtetra
.655 .472 .625 r
.57442 .39543 .58071 .43466 .59182 .42866 .58532 .3823 Mtetra
.636 .448 .612 r
.58532 .3823 .59182 .42866 .60288 .41897 .59621 .36983 Mtetra
.617 .432 .608 r
.59621 .36983 .60288 .41897 .61386 .40662 .60715 .35962 Mtetra
.604 .425 .612 r
.60715 .35962 .61386 .40662 .62478 .39299 .61815 .35184 Mtetra
.594 .427 .624 r
.61815 .35184 .62478 .39299 .6357 .37985 .62925 .34637 Mtetra
.584 .436 .646 r
.62925 .34637 .6357 .37985 .64665 .36812 .64046 .34311 Mtetra
.564 .453 .686 r
.64046 .34311 .64665 .36812 .6577 .35901 .65181 .34217 Mtetra
.53 .491 .758 r
.65181 .34217 .6577 .35901 .66887 .35246 .6633 .34288 Mtetra
.452 .572 .884 r
.6633 .34288 .66887 .35246 .68019 .34849 .67491 .34445 Mtetra
.202 .627 .949 r
.67491 .34445 .68019 .34849 .69166 .34646 .68661 .34629 Mtetra
.123 0 0 r
.68661 .34629 .69166 .34646 .70326 .34567 .69839 .34767 Mtetra
.232 0 0 r
.69839 .34767 .70326 .34567 .71497 .34552 .7102 .34832 Mtetra
.195 0 0 r
.7102 .34832 .71497 .34552 .72675 .3453 .72203 .34784 Mtetra
.089 0 0 r
.72203 .34784 .72675 .3453 .73857 .34473 .73386 .34628 Mtetra
0 0 0 r
.73386 .34628 .73857 .34473 .75042 .34342 .74568 .34364 Mtetra
.327 .813 .818 r
.74568 .34364 .75042 .34342 .76229 .34142 .75749 .34014 Mtetra
.518 .904 .946 r
.75749 .34014 .76229 .34142 .77416 .33867 .76931 .33599 Mtetra
.625 .91 .982 r
.76931 .33599 .77416 .33867 .78603 .33533 .78114 .33138 Mtetra
.671 .879 .976 r
.78114 .33138 .78603 .33533 .79793 .33155 .79299 .32654 Mtetra
.689 .845 .958 r
.79299 .32654 .79793 .33155 .80985 .32744 .80487 .32154 Mtetra
.694 .814 .939 r
.80487 .32154 .80985 .32744 .82179 .32313 .8168 .31648 Mtetra
.692 .787 .923 r
.8168 .31648 .82179 .32313 .83378 .31877 .82876 .31146 Mtetra
.6 .736 .94 r
.18679 .51429 .19348 .52013 .20299 .51797 .1963 .51229 Mtetra
.59 .739 .947 r
.1963 .51229 .20299 .51797 .21253 .51587 .20584 .51041 Mtetra
.581 .746 .955 r
.20584 .51041 .21253 .51587 .22212 .51372 .21542 .50863 Mtetra
.571 .757 .966 r
.21542 .50863 .22212 .51372 .23177 .51142 .22503 .50692 Mtetra
.552 .775 .981 r
.22503 .50692 .23177 .51142 .24147 .5089 .23468 .50529 Mtetra
.534 .805 .996 r
.23468 .50529 .24147 .5089 .25125 .50595 .24438 .50355 Mtetra
.5 .84 .997 r
.24438 .50355 .25125 .50595 .26112 .50238 .25415 .50157 Mtetra
.449 .863 .954 r
.25415 .50157 .26112 .50238 .27108 .49799 .264 .49906 Mtetra
.368 .837 .83 r
.264 .49906 .27108 .49799 .28115 .49254 .27396 .49575 Mtetra
0 0 0 r
.27396 .49575 .28115 .49254 .29132 .48606 .28402 .4914 Mtetra
.28402 .4914 .29132 .48606 .30158 .47847 .29421 .48572 Mtetra
.29421 .48572 .30158 .47847 .3119 .47015 .30451 .47873 Mtetra
.30451 .47873 .3119 .47015 .32225 .46138 .31492 .47035 Mtetra
.31492 .47035 .32225 .46138 .33259 .45285 .32539 .46098 Mtetra
.32539 .46098 .33259 .45285 .3429 .44514 .33591 .4509 Mtetra
.572 .882 .597 r
.33591 .4509 .3429 .44514 .35313 .43903 .34641 .44093 Mtetra
.788 .998 .844 r
.34641 .44093 .35313 .43903 .36327 .43518 .35688 .43172 Mtetra
.807 .866 .892 r
.35688 .43172 .36327 .43518 .37334 .43351 .36728 .42384 Mtetra
.711 .676 .814 r
.36728 .42384 .37334 .43351 .38337 .43411 .37761 .41789 Mtetra
.622 .543 .744 r
.37761 .41789 .38337 .43411 .39335 .43712 .38785 .41452 Mtetra
.556 .455 .695 r
.38785 .41452 .39335 .43712 .40334 .44237 .39801 .41409 Mtetra
.524 .408 .663 r
.39801 .41409 .40334 .44237 .4134 .4483 .40816 .41567 Mtetra
.502 .379 .644 r
.40816 .41567 .4134 .4483 .42355 .45427 .41832 .41905 Mtetra
.462 .344 .633 r
.41832 .41905 .42355 .45427 .43377 .46134 .42847 .42551 Mtetra
.419 .313 .627 r
.42847 .42551 .43377 .46134 .44407 .46977 .43865 .43493 Mtetra
.404 .306 .629 r
.43865 .43493 .44407 .46977 .45445 .47976 .44894 .44505 Mtetra
.421 .319 .633 r
.44894 .44505 .45445 .47976 .46495 .49035 .45938 .45415 Mtetra
.478 .355 .634 r
.45938 .45415 .46495 .49035 .47563 .49806 .47 .45972 Mtetra
.537 .392 .631 r
.47 .45972 .47563 .49806 .48647 .50094 .48078 .46059 Mtetra
.579 .418 .627 r
.48078 .46059 .48647 .50094 .49746 .49748 .49169 .45707 Mtetra
.615 .443 .626 r
.49169 .45707 .49746 .49748 .50852 .48768 .50266 .44918 Mtetra
.654 .473 .628 r
.50266 .44918 .50852 .48768 .51959 .473 .51367 .43653 Mtetra
.683 .497 .629 r
.51367 .43653 .51959 .473 .53063 .45537 .52466 .42031 Mtetra
.694 .507 .63 r
.52466 .42031 .53063 .45537 .54162 .43831 .5356 .40301 Mtetra
.689 .503 .63 r
.5356 .40301 .54162 .43831 .55257 .42277 .5465 .38636 Mtetra
.666 .484 .63 r
.5465 .38636 .55257 .42277 .5635 .40856 .55739 .37267 Mtetra
.644 .471 .634 r
.55739 .37267 .5635 .40856 .57442 .39543 .56829 .36207 Mtetra
.636 .471 .642 r
.56829 .36207 .57442 .39543 .58532 .3823 .57921 .35327 Mtetra
.628 .477 .659 r
.57921 .35327 .58532 .3823 .59621 .36983 .59019 .34648 Mtetra
.606 .488 .691 r
.59019 .34648 .59621 .36983 .60715 .35962 .60126 .34269 Mtetra
.572 .514 .751 r
.60126 .34269 .60715 .35962 .61815 .35184 .61245 .34152 Mtetra
.494 .575 .866 r
.61245 .34152 .61815 .35184 .62925 .34637 .62376 .34232 Mtetra
.161 .6 .935 r
.62376 .34232 .62925 .34637 .64046 .34311 .6352 .3445 Mtetra
.377 0 0 r
.6352 .3445 .64046 .34311 .65181 .34217 .64676 .34749 Mtetra
.494 0 0 r
.64676 .34749 .65181 .34217 .6633 .34288 .65842 .3506 Mtetra
.494 .028 .077 r
.65842 .3506 .6633 .34288 .67491 .34445 .67015 .35301 Mtetra
.468 .015 .092 r
.67015 .35301 .67491 .34445 .68661 .34629 .68191 .35442 Mtetra
.41 0 .048 r
.68191 .35442 .68661 .34629 .69839 .34767 .69369 .35441 Mtetra
.317 0 0 r
.69369 .35441 .69839 .34767 .7102 .34832 .70547 .35306 Mtetra
.147 0 0 r
.70547 .35306 .7102 .34832 .72203 .34784 .71724 .35033 Mtetra
0 0 0 r
.71724 .35033 .72203 .34784 .73386 .34628 .72899 .34651 Mtetra
.433 .874 .843 r
.72899 .34651 .73386 .34628 .74568 .34364 .74073 .34187 Mtetra
.623 .936 .962 r
.74073 .34187 .74568 .34364 .75749 .34014 .75248 .33667 Mtetra
.691 .903 .971 r
.75248 .33667 .75749 .34014 .76931 .33599 .76425 .33122 Mtetra
.711 .86 .953 r
.76425 .33122 .76931 .33599 .78114 .33138 .77605 .32564 Mtetra
.71 .824 .935 r
.77605 .32564 .78114 .33138 .79299 .32654 .78789 .32013 Mtetra
.707 .8 .923 r
.78789 .32013 .79299 .32654 .80487 .32154 .79978 .31468 Mtetra
.703 .785 .915 r
.79978 .31468 .80487 .32154 .8168 .31648 .81172 .30933 Mtetra
.697 .774 .911 r
.81172 .30933 .8168 .31648 .82876 .31146 .82371 .3041 Mtetra
.615 .741 .935 r
.18006 .50842 .18679 .51429 .1963 .51229 .18962 .5061 Mtetra
.609 .728 .93 r
.18962 .5061 .1963 .51229 .20584 .51041 .1992 .50393 Mtetra
.599 .716 .926 r
.1992 .50393 .20584 .51041 .21542 .50863 .20881 .50198 Mtetra
.586 .707 .926 r
.20881 .50198 .21542 .50863 .22503 .50692 .21843 .50028 Mtetra
.567 .701 .932 r
.21843 .50028 .22503 .50692 .23468 .50529 .22807 .49895 Mtetra
.546 .704 .944 r
.22807 .49895 .23468 .50529 .24438 .50355 .23773 .49789 Mtetra
.514 .718 .965 r
.23773 .49789 .24438 .50355 .25415 .50157 .24741 .49711 Mtetra
.473 .751 .99 r
.24741 .49711 .25415 .50157 .264 .49906 .25715 .49637 Mtetra
.388 .782 .987 r
.25715 .49637 .264 .49906 .27396 .49575 .26694 .49552 Mtetra
.224 .742 .847 r
.26694 .49552 .27396 .49575 .28402 .4914 .27682 .49421 Mtetra
0 0 0 r
.27682 .49421 .28402 .4914 .29421 .48572 .28681 .49211 Mtetra
.143 0 0 r
.28681 .49211 .29421 .48572 .30451 .47873 .29691 .48895 Mtetra
.21 0 .002 r
.29691 .48895 .30451 .47873 .31492 .47035 .30715 .48441 Mtetra
.243 0 .114 r
.30715 .48441 .31492 .47035 .32539 .46098 .3175 .47841 Mtetra
.25 0 .174 r
.3175 .47841 .32539 .46098 .33591 .4509 .32797 .47085 Mtetra
.248 0 .204 r
.32797 .47085 .33591 .4509 .34641 .44093 .33854 .46193 Mtetra
.228 0 .207 r
.33854 .46193 .34641 .44093 .35688 .43172 .34917 .45185 Mtetra
.198 0 .185 r
.34917 .45185 .35688 .43172 .36728 .42384 .35982 .44132 Mtetra
.137 0 .124 r
.35982 .44132 .36728 .42384 .37761 .41789 .37046 .43084 Mtetra
0 0 0 r
.37046 .43084 .37761 .41789 .38785 .41452 .38109 .42043 Mtetra
.538 .856 .562 r
.38109 .42043 .38785 .41452 .39801 .41409 .39171 .41032 Mtetra
.835 .858 .862 r
.39171 .41032 .39801 .41409 .40816 .41567 .4023 .40088 Mtetra
.714 .607 .736 r
.4023 .40088 .40816 .41567 .41832 .41905 .41287 .3923 Mtetra
.646 .496 .664 r
.41287 .3923 .41832 .41905 .42847 .42551 .42341 .38448 Mtetra
.611 .437 .622 r
.42341 .38448 .42847 .42551 .43865 .43493 .43396 .37694 Mtetra
.603 .412 .595 r
.43396 .37694 .43865 .43493 .44894 .44505 .44458 .36728 Mtetra
.597 .395 .579 r
.44458 .36728 .44894 .44505 .45938 .45415 .45524 .35541 Mtetra
.583 .377 .567 r
.45524 .35541 .45938 .45415 .47 .45972 .46588 .34417 Mtetra
.568 .362 .561 r
.46588 .34417 .47 .45972 .48078 .46059 .47648 .33534 Mtetra
.55 .346 .556 r
.47648 .33534 .48078 .46059 .49169 .45707 .48702 .3317 Mtetra
.533 .333 .555 r
.48702 .3317 .49169 .45707 .50266 .44918 .49755 .33327 Mtetra
.524 .328 .557 r
.49755 .33327 .50266 .44918 .51367 .43653 .50814 .33727 Mtetra
.52 .329 .562 r
.50814 .33727 .51367 .43653 .52466 .42031 .51883 .34192 Mtetra
.528 .343 .574 r
.51883 .34192 .52466 .42031 .5356 .40301 .52961 .34438 Mtetra
.54 .365 .593 r
.52961 .34438 .5356 .40301 .5465 .38636 .54047 .34473 Mtetra
.538 .386 .622 r
.54047 .34473 .5465 .38636 .55739 .37267 .5514 .34537 Mtetra
.526 .416 .672 r
.5514 .34537 .55739 .37267 .56829 .36207 .56242 .34679 Mtetra
.477 .477 .778 r
.56242 .34679 .56829 .36207 .57921 .35327 .57352 .34909 Mtetra
.075 .537 .901 r
.57352 .34909 .57921 .35327 .59019 .34648 .58473 .3521 Mtetra
.51 .012 .008 r
.58473 .3521 .59019 .34648 .60126 .34269 .59603 .35543 Mtetra
.545 .145 .234 r
.59603 .35543 .60126 .34269 .61245 .34152 .60744 .35887 Mtetra
.548 .183 .3 r
.60744 .35887 .61245 .34152 .62376 .34232 .61894 .36237 Mtetra
.542 .192 .324 r
.61894 .36237 .62376 .34232 .6352 .3445 .63053 .36545 Mtetra
.524 .179 .325 r
.63053 .36545 .6352 .3445 .64676 .34749 .64217 .36735 Mtetra
.499 .151 .307 r
.64217 .36735 .64676 .34749 .65842 .3506 .65384 .36788 Mtetra
.459 .099 .266 r
.65384 .36788 .65842 .3506 .67015 .35301 .66553 .3668 Mtetra
.396 .013 .19 r
.66553 .3668 .67015 .35301 .68191 .35442 .67721 .36424 Mtetra
.276 0 .043 r
.67721 .36424 .68191 .35442 .69369 .35441 .68887 .36026 Mtetra
.042 0 0 r
.68887 .36026 .69369 .35441 .70547 .35306 .70052 .35516 Mtetra
.363 .811 .678 r
.70052 .35516 .70547 .35306 .71724 .35033 .71217 .34925 Mtetra
.665 .963 .931 r
.71217 .34925 .71724 .35033 .72899 .34651 .72382 .34284 Mtetra
.741 .907 .951 r
.72382 .34284 .72899 .34651 .74073 .34187 .73548 .3363 Mtetra
.744 .838 .922 r
.73548 .3363 .74073 .34187 .75248 .33667 .74719 .3298 Mtetra
.73 .791 .901 r
.74719 .3298 .75248 .33667 .76425 .33122 .75894 .32358 Mtetra
.717 .764 .889 r
.75894 .32358 .76425 .33122 .77605 .32564 .77075 .31763 Mtetra
.705 .749 .887 r
.77075 .31763 .77605 .32564 .78789 .32013 .78262 .31205 Mtetra
.696 .745 .889 r
.78262 .31205 .78789 .32013 .79978 .31468 .79456 .30674 Mtetra
.691 .747 .895 r
.79456 .30674 .79978 .31468 .81172 .30933 .80656 .30164 Mtetra
.686 .754 .903 r
.80656 .30164 .81172 .30933 .82371 .3041 .81861 .29669 Mtetra
.65 .75 .922 r
.17328 .5025 .18006 .50842 .18962 .5061 .18294 .49941 Mtetra
.646 .724 .905 r
.18294 .49941 .18962 .5061 .1992 .50393 .19262 .49642 Mtetra
.636 .697 .889 r
.19262 .49642 .1992 .50393 .20881 .50198 .20231 .49365 Mtetra
.623 .671 .875 r
.20231 .49365 .20881 .50198 .21843 .50028 .21202 .4912 Mtetra
.606 .645 .863 r
.21202 .4912 .21843 .50028 .22807 .49895 .22172 .4892 Mtetra
.588 .622 .854 r
.22172 .4892 .22807 .49895 .23773 .49789 .23143 .48767 Mtetra
.566 .603 .849 r
.23143 .48767 .23773 .49789 .24741 .49711 .24113 .48672 Mtetra
.547 .591 .85 r
.24113 .48672 .24741 .49711 .25715 .49637 .25084 .48626 Mtetra
.525 .587 .859 r
.25084 .48626 .25715 .49637 .26694 .49552 .26057 .48625 Mtetra
.508 .601 .881 r
.26057 .48625 .26694 .49552 .27682 .49421 .27035 .48645 Mtetra
.487 .636 .92 r
.27035 .48645 .27682 .49421 .28681 .49211 .28018 .48664 Mtetra
.456 .706 .975 r
.28018 .48664 .28681 .49211 .29691 .48895 .29009 .48647 Mtetra
.366 .78 .979 r
.29009 .48647 .29691 .48895 .30715 .48441 .30011 .48561 Mtetra
.135 .679 .706 r
.30011 .48561 .30715 .48441 .3175 .47841 .31025 .48377 Mtetra
.082 0 0 r
.31025 .48377 .3175 .47841 .32797 .47085 .32051 .48063 Mtetra
.188 0 0 r
.32051 .48063 .32797 .47085 .33854 .46193 .33091 .47597 Mtetra
.227 0 .103 r
.33091 .47597 .33854 .46193 .34917 .45185 .34143 .46963 Mtetra
.259 0 .181 r
.34143 .46963 .34917 .45185 .35982 .44132 .35203 .4621 Mtetra
.277 0 .225 r
.35203 .4621 .35982 .44132 .37046 .43084 .3627 .45362 Mtetra
.268 0 .24 r
.3627 .45362 .37046 .43084 .38109 .42043 .37343 .44385 Mtetra
.243 0 .236 r
.37343 .44385 .38109 .42043 .39171 .41032 .38422 .43288 Mtetra
.231 0 .224 r
.38422 .43288 .39171 .41032 .4023 .40088 .395 .42186 Mtetra
.215 0 .203 r
.395 .42186 .4023 .40088 .41287 .3923 .40577 .41115 Mtetra
.141 0 .147 r
.40577 .41115 .41287 .3923 .42341 .38448 .41655 .39964 Mtetra
0 0 .003 r
.41655 .39964 .42341 .38448 .43396 .37694 .42736 .38683 Mtetra
0 0 0 r
.42736 .38683 .43396 .37694 .44458 .36728 .43821 .37186 Mtetra
.887 .977 .679 r
.43821 .37186 .44458 .36728 .45524 .35541 .44907 .3555 Mtetra
.92 .95 .796 r
.44907 .3555 .45524 .35541 .46588 .34417 .45983 .34145 Mtetra
.851 .903 .872 r
.45983 .34145 .46588 .34417 .47648 .33534 .47048 .33167 Mtetra
.641 .853 .981 r
.47048 .33167 .47648 .33534 .48702 .3317 .48106 .32801 Mtetra
.071 .553 .896 r
.48106 .32801 .48702 .3317 .49755 .33327 .49161 .33047 Mtetra
.456 0 0 r
.49161 .33047 .49755 .33327 .50814 .33727 .50221 .33725 Mtetra
.675 .13 0 r
.50221 .33725 .50814 .33727 .51883 .34192 .51292 .34639 Mtetra
.654 .165 .078 r
.51292 .34639 .51883 .34192 .52961 .34438 .52375 .35416 Mtetra
.596 .17 .203 r
.52375 .35416 .52961 .34438 .54047 .34473 .5347 .35979 Mtetra
.565 .186 .281 r
.5347 .35979 .54047 .34473 .5514 .34537 .54575 .36415 Mtetra
.55 .194 .317 r
.54575 .36415 .5514 .34537 .56242 .34679 .5569 .36772 Mtetra
.554 .208 .336 r
.5569 .36772 .56242 .34679 .57352 .34909 .56814 .37163 Mtetra
.553 .214 .347 r
.56814 .37163 .57352 .34909 .58473 .3521 .57948 .37552 Mtetra
.536 .201 .347 r
.57948 .37552 .58473 .3521 .59603 .35543 .5909 .3782 Mtetra
.517 .18 .336 r
.5909 .3782 .59603 .35543 .60744 .35887 .60238 .3796 Mtetra
.498 .153 .313 r
.60238 .3796 .60744 .35887 .61894 .36237 .61392 .38003 Mtetra
.465 .105 .27 r
.61392 .38003 .61894 .36237 .63053 .36545 .62549 .37927 Mtetra
.394 .009 .186 r
.62549 .37927 .63053 .36545 .64217 .36735 .63708 .37678 Mtetra
.255 0 .014 r
.63708 .37678 .64217 .36735 .65384 .36788 .64866 .37274 Mtetra
0 0 0 r
.64866 .37274 .65384 .36788 .66553 .3668 .66024 .36736 Mtetra
.568 .938 .849 r
.66024 .36736 .66553 .3668 .67721 .36424 .6718 .36096 Mtetra
.762 .92 .942 r
.6718 .36096 .67721 .36424 .68887 .36026 .68336 .35383 Mtetra
.768 .811 .887 r
.68336 .35383 .68887 .36026 .70052 .35516 .69492 .34631 Mtetra
.747 .738 .844 r
.69492 .34631 .70052 .35516 .71217 .34925 .7065 .33878 Mtetra
.728 .696 .819 r
.7065 .33878 .71217 .34925 .72382 .34284 .71812 .33143 Mtetra
.711 .671 .809 r
.71812 .33143 .72382 .34284 .73548 .3363 .72979 .32456 Mtetra
.699 .66 .809 r
.72979 .32456 .73548 .3363 .74719 .3298 .74152 .31817 Mtetra
.687 .657 .815 r
.74152 .31817 .74719 .3298 .75894 .32358 .75333 .31237 Mtetra
.678 .662 .827 r
.75333 .31237 .75894 .32358 .77075 .31763 .76521 .30707 Mtetra
.671 .672 .843 r
.76521 .30707 .77075 .31763 .78262 .31205 .77718 .30222 Mtetra
.665 .687 .861 r
.77718 .30222 .78262 .31205 .79456 .30674 .78921 .2977 Mtetra
.662 .706 .88 r
.78921 .2977 .79456 .30674 .80656 .30164 .80131 .2934 Mtetra
.66 .729 .9 r
.80131 .2934 .80656 .30164 .81861 .29669 .81347 .28921 Mtetra
.688 .758 .905 r
.16646 .49655 .17328 .5025 .18294 .49941 .17623 .49247 Mtetra
.683 .728 .884 r
.17623 .49247 .18294 .49941 .19262 .49642 .18604 .48841 Mtetra
.673 .696 .863 r
.18604 .48841 .19262 .49642 .20231 .49365 .19586 .48449 Mtetra
.66 .665 .843 r
.19586 .48449 .20231 .49365 .21202 .4912 .2057 .48081 Mtetra
.645 .633 .824 r
.2057 .48081 .21202 .4912 .22172 .4892 .21553 .47747 Mtetra
.626 .602 .806 r
.21553 .47747 .22172 .4892 .23143 .48767 .22535 .47462 Mtetra
.606 .571 .789 r
.22535 .47462 .23143 .48767 .24113 .48672 .23517 .47237 Mtetra
.585 .543 .774 r
.23517 .47237 .24113 .48672 .25084 .48626 .24496 .4708 Mtetra
.563 .518 .763 r
.24496 .4708 .25084 .48626 .26057 .48625 .25474 .47002 Mtetra
.544 .499 .755 r
.25474 .47002 .26057 .48625 .27035 .48645 .26452 .46994 Mtetra
.525 .485 .754 r
.26452 .46994 .27035 .48645 .28018 .48664 .2743 .47055 Mtetra
.511 .482 .761 r
.2743 .47055 .28018 .48664 .29009 .48647 .28411 .47163 Mtetra
.497 .49 .779 r
.28411 .47163 .29009 .48647 .30011 .48561 .29396 .47298 Mtetra
.483 .517 .817 r
.29396 .47298 .30011 .48561 .31025 .48377 .30389 .47433 Mtetra
.458 .576 .885 r
.30389 .47433 .31025 .48377 .32051 .48063 .31389 .47544 Mtetra
.38 .686 .979 r
.31389 .47544 .32051 .48063 .33091 .47597 .324 .47594 Mtetra
.062 .627 .747 r
.324 .47594 .33091 .47597 .34143 .46963 .33423 .47552 Mtetra
.273 0 0 r
.33423 .47552 .34143 .46963 .35203 .4621 .34456 .47426 Mtetra
.373 0 .139 r
.34456 .47426 .35203 .4621 .3627 .45362 .35499 .47209 Mtetra
.4 .05 .252 r
.35499 .47209 .3627 .45362 .37343 .44385 .36553 .4687 Mtetra
.413 .095 .313 r
.36553 .4687 .37343 .44385 .38422 .43288 .37617 .46409 Mtetra
.439 .139 .358 r
.37617 .46409 .38422 .43288 .395 .42186 .38685 .45941 Mtetra
.46 .171 .388 r
.38685 .45941 .395 .42186 .40577 .41115 .39755 .45497 Mtetra
.457 .18 .403 r
.39755 .45497 .40577 .41115 .41655 .39964 .40833 .44924 Mtetra
.452 .183 .414 r
.40833 .44924 .41655 .39964 .42736 .38683 .41919 .442 Mtetra
.46 .196 .425 r
.41919 .442 .42736 .38683 .43821 .37186 .43007 .43461 Mtetra
.474 .214 .438 r
.43007 .43461 .43821 .37186 .44907 .3555 .44095 .42782 Mtetra
.491 .234 .452 r
.44095 .42782 .44907 .3555 .45983 .34145 .45182 .42251 Mtetra
.504 .249 .461 r
.45182 .42251 .45983 .34145 .47048 .33167 .46269 .41875 Mtetra
.507 .254 .466 r
.46269 .41875 .47048 .33167 .48106 .32801 .47361 .41514 Mtetra
.508 .254 .466 r
.47361 .41514 .48106 .32801 .49161 .33047 .48456 .41168 Mtetra
.513 .257 .463 r
.48456 .41168 .49161 .33047 .50221 .33725 .49555 .40977 Mtetra
.519 .258 .458 r
.49555 .40977 .50221 .33725 .51292 .34639 .50658 .40937 Mtetra
.521 .253 .449 r
.50658 .40937 .51292 .34639 .52375 .35416 .51768 .40957 Mtetra
.518 .245 .439 r
.51768 .40957 .52375 .35416 .5347 .35979 .52885 .40965 Mtetra
.505 .228 .428 r
.52885 .40965 .5347 .35979 .54575 .36415 .54009 .4082 Mtetra
.489 .207 .413 r
.54009 .4082 .54575 .36415 .5569 .36772 .55137 .40545 Mtetra
.484 .193 .395 r
.55137 .40545 .5569 .36772 .56814 .37163 .56272 .40295 Mtetra
.473 .169 .369 r
.56272 .40295 .56814 .37163 .57948 .37552 .57411 .40039 Mtetra
.435 .115 .322 r
.57411 .40039 .57948 .37552 .5909 .3782 .58554 .39658 Mtetra
.366 .02 .24 r
.58554 .39658 .5909 .3782 .60238 .3796 .59699 .39152 Mtetra
.228 0 .07 r
.59699 .39152 .60238 .3796 .61392 .38003 .60845 .38554 Mtetra
0 0 0 r
.60845 .38554 .61392 .38003 .62549 .37927 .61992 .37867 Mtetra
.734 .983 .907 r
.61992 .37867 .62549 .37927 .63708 .37678 .63138 .37085 Mtetra
.794 .829 .879 r
.63138 .37085 .63708 .37678 .64866 .37274 .64284 .36239 Mtetra
.755 .706 .806 r
.64284 .36239 .64866 .37274 .66024 .36736 .6543 .35365 Mtetra
.725 .64 .764 r
.6543 .35365 .66024 .36736 .6718 .36096 .66577 .34491 Mtetra
.703 .603 .742 r
.66577 .34491 .6718 .36096 .68336 .35383 .67727 .33643 Mtetra
.688 .582 .732 r
.67727 .33643 .68336 .35383 .69492 .34631 .68881 .3284 Mtetra
.675 .571 .73 r
.68881 .3284 .69492 .34631 .7065 .33878 .70041 .32108 Mtetra
.665 .567 .735 r
.70041 .32108 .7065 .33878 .71812 .33143 .71207 .31448 Mtetra
.656 .569 .746 r
.71207 .31448 .71812 .33143 .72979 .32456 .72381 .30868 Mtetra
.649 .577 .761 r
.72381 .30868 .72979 .32456 .74152 .31817 .73564 .30357 Mtetra
.642 .59 .78 r
.73564 .30357 .74152 .31817 .75333 .31237 .74755 .2991 Mtetra
.637 .607 .802 r
.74755 .2991 .75333 .31237 .76521 .30707 .75955 .29511 Mtetra
.633 .628 .827 r
.75955 .29511 .76521 .30707 .77718 .30222 .77163 .29149 Mtetra
.63 .651 .852 r
.77163 .29149 .77718 .30222 .78921 .2977 .78378 .28812 Mtetra
.627 .678 .878 r
.78378 .28812 .78921 .2977 .80131 .2934 .79601 .28489 Mtetra
.626 .707 .904 r
.79601 .28489 .80131 .2934 .81347 .28921 .8083 .28168 Mtetra
.712 .763 .892 r
.15958 .49055 .16646 .49655 .17623 .49247 .16946 .48572 Mtetra
.709 .74 .876 r
.16946 .48572 .17623 .49247 .18604 .48841 .17937 .48083 Mtetra
.703 .717 .86 r
.17937 .48083 .18604 .48841 .19586 .48449 .18931 .47595 Mtetra
.694 .691 .843 r
.18931 .47595 .19586 .48449 .2057 .48081 .19927 .47114 Mtetra
.683 .664 .825 r
.19927 .47114 .2057 .48081 .21553 .47747 .20924 .46647 Mtetra
.668 .633 .806 r
.20924 .46647 .21553 .47747 .22535 .47462 .21921 .46207 Mtetra
.65 .601 .786 r
.21921 .46207 .22535 .47462 .23517 .47237 .22918 .45808 Mtetra
.63 .568 .766 r
.22918 .45808 .23517 .47237 .24496 .4708 .23913 .45463 Mtetra
.608 .536 .747 r
.23913 .45463 .24496 .4708 .25474 .47002 .24906 .45188 Mtetra
.587 .505 .73 r
.24906 .45188 .25474 .47002 .26452 .46994 .25897 .44991 Mtetra
.566 .478 .715 r
.25897 .44991 .26452 .46994 .2743 .47055 .26886 .44883 Mtetra
.549 .456 .702 r
.26886 .44883 .2743 .47055 .28411 .47163 .27873 .44856 Mtetra
.533 .438 .693 r
.27873 .44856 .28411 .47163 .29396 .47298 .28861 .44906 Mtetra
.522 .426 .688 r
.28861 .44906 .29396 .47298 .30389 .47433 .2985 .45019 Mtetra
.512 .419 .687 r
.2985 .45019 .30389 .47433 .31389 .47544 .30843 .45181 Mtetra
.507 .419 .691 r
.30843 .45181 .31389 .47544 .324 .47594 .31842 .45364 Mtetra
.506 .427 .701 r
.31842 .45364 .324 .47594 .33423 .47552 .32849 .45542 Mtetra
.508 .445 .72 r
.32849 .45542 .33423 .47552 .34456 .47426 .33864 .45692 Mtetra
.515 .474 .75 r
.33864 .45692 .34456 .47426 .35499 .47209 .34889 .45793 Mtetra
.522 .519 .793 r
.34889 .45793 .35499 .47209 .36553 .4687 .35923 .45839 Mtetra
.525 .593 .865 r
.35923 .45839 .36553 .4687 .37617 .46409 .36967 .45828 Mtetra
.451 .7 .973 r
.36967 .45828 .37617 .46409 .38685 .45941 .38017 .45818 Mtetra
.119 .66 .844 r
.38017 .45818 .38685 .45941 .39755 .45497 .39074 .45822 Mtetra
.187 0 0 r
.39074 .45822 .39755 .45497 .40833 .44924 .40139 .45752 Mtetra
.34 0 .005 r
.40139 .45752 .40833 .44924 .41919 .442 .41213 .45619 Mtetra
.476 .089 .225 r
.41213 .45619 .41919 .442 .43007 .43461 .42286 .45669 Mtetra
.535 .194 .336 r
.42286 .45669 .43007 .43461 .44095 .42782 .43361 .45934 Mtetra
.537 .226 .387 r
.43361 .45934 .44095 .42782 .45182 .42251 .44444 .46211 Mtetra
.522 .228 .408 r
.44444 .46211 .45182 .42251 .46269 .41875 .45539 .4634 Mtetra
.479 .198 .408 r
.45539 .4634 .46269 .41875 .47361 .41514 .4665 .45981 Mtetra
.429 .155 .394 r
.4665 .45981 .47361 .41514 .48456 .41168 .47773 .45133 Mtetra
.395 .119 .371 r
.47773 .45133 .48456 .41168 .49555 .40977 .48899 .44133 Mtetra
.358 .068 .33 r
.48899 .44133 .49555 .40977 .50658 .40937 .50025 .43145 Mtetra
.326 .004 .257 r
.50025 .43145 .50658 .40937 .51768 .40957 .5115 .4237 Mtetra
.267 0 .126 r
.5115 .4237 .51768 .40957 .52885 .40965 .52277 .41778 Mtetra
.022 0 0 r
.52277 .41778 .52885 .40965 .54009 .4082 .53407 .41122 Mtetra
.47 .866 .684 r
.53407 .41122 .54009 .4082 .55137 .40545 .54539 .40389 Mtetra
.747 .96 .938 r
.54539 .40389 .55137 .40545 .56272 .40295 .55673 .3967 Mtetra
.762 .807 .889 r
.55673 .3967 .56272 .40295 .57411 .40039 .5681 .3895 Mtetra
.733 .685 .804 r
.5681 .3895 .57411 .40039 .58554 .39658 .57948 .38171 Mtetra
.71 .618 .752 r
.57948 .38171 .58554 .39658 .59699 .39152 .59086 .37334 Mtetra
.695 .578 .72 r
.59086 .37334 .59699 .39152 .60845 .38554 .60225 .36445 Mtetra
.682 .551 .699 r
.60225 .36445 .60845 .38554 .61992 .37867 .61364 .35525 Mtetra
.672 .531 .685 r
.61364 .35525 .61992 .37867 .63138 .37085 .62504 .34599 Mtetra
.663 .519 .678 r
.62504 .34599 .63138 .37085 .64284 .36239 .63645 .33692 Mtetra
.656 .512 .676 r
.63645 .33692 .64284 .36239 .6543 .35365 .64789 .32834 Mtetra
.649 .508 .678 r
.64789 .32834 .6543 .35365 .66577 .34491 .65937 .32038 Mtetra
.643 .508 .684 r
.65937 .32038 .66577 .34491 .67727 .33643 .67091 .31321 Mtetra
.637 .512 .693 r
.67091 .31321 .67727 .33643 .68881 .3284 .68251 .30686 Mtetra
.631 .518 .707 r
.68251 .30686 .68881 .3284 .70041 .32108 .6942 .30142 Mtetra
.625 .528 .724 r
.6942 .30142 .70041 .32108 .71207 .31448 .70596 .29677 Mtetra
.62 .542 .745 r
.70596 .29677 .71207 .31448 .72381 .30868 .71782 .29285 Mtetra
.614 .559 .769 r
.71782 .29285 .72381 .30868 .73564 .30357 .72977 .2895 Mtetra
.61 .581 .796 r
.72977 .2895 .73564 .30357 .74755 .2991 .7418 .28656 Mtetra
.606 .603 .823 r
.7418 .28656 .74755 .2991 .75955 .29511 .75392 .28392 Mtetra
.603 .629 .849 r
.75392 .28392 .75955 .29511 .77163 .29149 .76611 .28141 Mtetra
.6 .653 .874 r
.76611 .28141 .77163 .29149 .78378 .28812 .77837 .27899 Mtetra
.598 .677 .896 r
.77837 .27899 .78378 .28812 .79601 .28489 .79069 .27657 Mtetra
.597 .701 .916 r
.79069 .27657 .79601 .28489 .8083 .28168 .80308 .27409 Mtetra
.72 .764 .887 r
.15266 .48451 .15958 .49055 .16946 .48572 .1626 .47937 Mtetra
.722 .755 .879 r
.1626 .47937 .16946 .48572 .17937 .48083 .17257 .47409 Mtetra
.722 .745 .87 r
.17257 .47409 .17937 .48083 .18931 .47595 .18258 .46868 Mtetra
.721 .731 .859 r
.18258 .46868 .18931 .47595 .19927 .47114 .19263 .46317 Mtetra
.718 .713 .844 r
.19263 .46317 .19927 .47114 .20924 .46647 .20271 .45752 Mtetra
.711 .689 .828 r
.20271 .45752 .20924 .46647 .21921 .46207 .21282 .45187 Mtetra
.7 .661 .808 r
.21282 .45187 .21921 .46207 .22918 .45808 .22295 .44627 Mtetra
.684 .628 .787 r
.22295 .44627 .22918 .45808 .23913 .45463 .23308 .44088 Mtetra
.665 .593 .765 r
.23308 .44088 .23913 .45463 .24906 .45188 .2432 .43584 Mtetra
.643 .557 .742 r
.2432 .43584 .24906 .45188 .25897 .44991 .25331 .43131 Mtetra
.621 .522 .721 r
.25331 .43131 .25897 .44991 .26886 .44883 .2634 .42745 Mtetra
.6 .491 .701 r
.2634 .42745 .26886 .44883 .27873 .44856 .27347 .42432 Mtetra
.581 .463 .683 r
.27347 .42432 .27873 .44856 .28861 .44906 .28351 .422 Mtetra
.566 .44 .668 r
.28351 .422 .28861 .44906 .2985 .45019 .29355 .42046 Mtetra
.552 .421 .656 r
.29355 .42046 .2985 .45019 .30843 .45181 .30358 .4197 Mtetra
.542 .407 .646 r
.30358 .4197 .30843 .45181 .31842 .45364 .31362 .41962 Mtetra
.534 .396 .639 r
.31362 .41962 .31842 .45364 .32849 .45542 .32369 .42012 Mtetra
.532 .391 .635 r
.32369 .42012 .32849 .45542 .33864 .45692 .33381 .42082 Mtetra
.532 .39 .633 r
.33381 .42082 .33864 .45692 .34889 .45793 .344 .4215 Mtetra
.529 .387 .632 r
.344 .4215 .34889 .45793 .35923 .45839 .35425 .42243 Mtetra
.525 .386 .634 r
.35425 .42243 .35923 .45839 .36967 .45828 .36454 .42364 Mtetra
.525 .39 .639 r
.36454 .42364 .36967 .45828 .38017 .45818 .37491 .42484 Mtetra
.526 .394 .644 r
.37491 .42484 .38017 .45818 .39074 .45822 .38536 .42598 Mtetra
.523 .396 .648 r
.38536 .42598 .39074 .45822 .40139 .45752 .39587 .42731 Mtetra
.511 .395 .657 r
.39587 .42731 .40139 .45752 .41213 .45619 .40643 .42934 Mtetra
.453 .37 .672 r
.40643 .42934 .41213 .45619 .42286 .45669 .41697 .43427 Mtetra
.358 .335 .696 r
.41697 .43427 .42286 .45669 .43361 .45934 .42753 .44191 Mtetra
.331 .365 .746 r
.42753 .44191 .43361 .45934 .44444 .46211 .43824 .4485 Mtetra
.416 .473 .812 r
.43824 .4485 .44444 .46211 .45539 .4634 .44914 .45167 Mtetra
.638 .626 .822 r
.44914 .45167 .45539 .4634 .4665 .45981 .46026 .44805 Mtetra
.764 .679 .768 r
.46026 .44805 .4665 .45981 .47773 .45133 .47154 .43762 Mtetra
.785 .662 .728 r
.47154 .43762 .47773 .45133 .48899 .44133 .48287 .42372 Mtetra
.763 .617 .698 r
.48287 .42372 .48899 .44133 .50025 .43145 .49418 .40873 Mtetra
.707 .555 .68 r
.49418 .40873 .50025 .43145 .5115 .4237 .50544 .39644 Mtetra
.658 .505 .665 r
.50544 .39644 .5115 .4237 .52277 .41778 .51669 .38704 Mtetra
.64 .482 .652 r
.51669 .38704 .52277 .41778 .53407 .41122 .52793 .37832 Mtetra
.632 .47 .645 r
.52793 .37832 .53407 .41122 .54539 .40389 .5392 .36979 Mtetra
.63 .465 .641 r
.5392 .36979 .54539 .40389 .55673 .3967 .55047 .36117 Mtetra
.627 .46 .637 r
.55047 .36117 .55673 .3967 .5681 .3895 .56175 .35252 Mtetra
.621 .453 .633 r
.56175 .35252 .5681 .3895 .57948 .38171 .57305 .34415 Mtetra
.618 .449 .631 r
.57305 .34415 .57948 .38171 .59086 .37334 .58437 .33601 Mtetra
.619 .45 .632 r
.58437 .33601 .59086 .37334 .60225 .36445 .59571 .32783 Mtetra
.618 .451 .634 r
.59571 .32783 .60225 .36445 .61364 .35525 .60706 .31985 Mtetra
.615 .452 .638 r
.60706 .31985 .61364 .35525 .62504 .34599 .61845 .31244 Mtetra
.613 .455 .644 r
.61845 .31244 .62504 .34599 .63645 .33692 .62989 .30572 Mtetra
.61 .46 .654 r
.62989 .30572 .63645 .33692 .64789 .32834 .64138 .29979 Mtetra
.607 .468 .666 r
.64138 .29979 .64789 .32834 .65937 .32038 .65294 .29465 Mtetra
.603 .477 .681 r
.65294 .29465 .65937 .32038 .67091 .31321 .66458 .29035 Mtetra
.599 .49 .701 r
.66458 .29035 .67091 .31321 .68251 .30686 .67629 .28678 Mtetra
.594 .506 .725 r
.67629 .28678 .68251 .30686 .6942 .30142 .6881 .28392 Mtetra
.589 .527 .752 r
.6881 .28392 .6942 .30142 .70596 .29677 .7 .28158 Mtetra
.585 .551 .783 r
.7 .28158 .70596 .29677 .71782 .29285 .71198 .2796 Mtetra
.581 .578 .814 r
.71198 .2796 .71782 .29285 .72977 .2895 .72404 .27786 Mtetra
.578 .606 .844 r
.72404 .27786 .72977 .2895 .7418 .28656 .73618 .27617 Mtetra
.576 .633 .871 r
.73618 .27617 .7418 .28656 .75392 .28392 .74839 .27447 Mtetra
.577 .658 .892 r
.74839 .27447 .75392 .28392 .76611 .28141 .76065 .27265 Mtetra
.578 .679 .909 r
.76065 .27265 .76611 .28141 .77837 .27899 .77298 .27071 Mtetra
.58 .695 .92 r
.77298 .27071 .77837 .27899 .79069 .27657 .78537 .26864 Mtetra
.583 .708 .929 r
.78537 .26864 .79069 .27657 .80308 .27409 .79782 .26643 Mtetra
.708 .762 .894 r
.14569 .47843 .15266 .48451 .1626 .47937 .15561 .47367 Mtetra
.714 .776 .901 r
.15561 .47367 .1626 .47937 .17257 .47409 .16557 .46875 Mtetra
.722 .79 .906 r
.16557 .46875 .17257 .47409 .18258 .46868 .17557 .46364 Mtetra
.73 .801 .908 r
.17557 .46364 .18258 .46868 .19263 .46317 .18563 .4583 Mtetra
.74 .809 .907 r
.18563 .4583 .19263 .46317 .20271 .45752 .19574 .45267 Mtetra
.746 .811 .903 r
.19574 .45267 .20271 .45752 .21282 .45187 .2059 .4468 Mtetra
.751 .805 .896 r
.2059 .4468 .21282 .45187 .22295 .44627 .2161 .4407 Mtetra
.75 .79 .885 r
.2161 .4407 .22295 .44627 .23308 .44088 .22633 .4345 Mtetra
.745 .765 .869 r
.22633 .4345 .23308 .44088 .2432 .43584 .23659 .42825 Mtetra
.731 .731 .85 r
.23659 .42825 .2432 .43584 .25331 .43131 .24685 .42214 Mtetra
.712 .689 .826 r
.24685 .42214 .25331 .43131 .2634 .42745 .25712 .4163 Mtetra
.689 .643 .799 r
.25712 .4163 .2634 .42745 .27347 .42432 .26738 .41082 Mtetra
.664 .598 .771 r
.26738 .41082 .27347 .42432 .28351 .422 .27762 .40585 Mtetra
.64 .556 .743 r
.27762 .40585 .28351 .422 .29355 .42046 .28786 .40139 Mtetra
.619 .518 .718 r
.28786 .40139 .29355 .42046 .30358 .4197 .29809 .39751 Mtetra
.599 .486 .696 r
.29809 .39751 .30358 .4197 .31362 .41962 .30831 .39426 Mtetra
.583 .459 .677 r
.30831 .39426 .31362 .41962 .32369 .42012 .31853 .39166 Mtetra
.574 .441 .662 r
.31853 .39166 .32369 .42012 .33381 .42082 .32878 .38936 Mtetra
.568 .427 .649 r
.32878 .38936 .33381 .42082 .344 .4215 .33907 .3872 Mtetra
.559 .413 .639 r
.33907 .3872 .344 .4215 .35425 .42243 .34938 .38556 Mtetra
.551 .401 .631 r
.34938 .38556 .35425 .42243 .36454 .42364 .35971 .3845 Mtetra
.553 .398 .625 r
.35971 .3845 .36454 .42364 .37491 .42484 .37012 .38316 Mtetra
.557 .396 .619 r
.37012 .38316 .37491 .42484 .38536 .42598 .3806 .38131 Mtetra
.551 .387 .612 r
.3806 .38131 .38536 .42598 .39587 .42731 .39111 .37984 Mtetra
.542 .376 .606 r
.39111 .37984 .39587 .42731 .40643 .42934 .40165 .37931 Mtetra
.522 .359 .601 r
.40165 .37931 .40643 .42934 .41697 .43427 .41217 .38099 Mtetra
.506 .343 .594 r
.41217 .38099 .41697 .43427 .42753 .44191 .42271 .38461 Mtetra
.515 .346 .59 r
.42271 .38461 .42753 .44191 .43824 .4485 .43337 .38729 Mtetra
.534 .357 .587 r
.43337 .38729 .43824 .4485 .44914 .45167 .44417 .38749 Mtetra
.559 .373 .585 r
.44417 .38749 .44914 .45167 .46026 .44805 .45513 .38379 Mtetra
.581 .39 .586 r
.45513 .38379 .46026 .44805 .47154 .43762 .46621 .37617 Mtetra
.598 .404 .59 r
.46621 .37617 .47154 .43762 .48287 .42372 .47734 .36606 Mtetra
.607 .414 .594 r
.47734 .36606 .48287 .42372 .49418 .40873 .48848 .35497 Mtetra
.6 .412 .599 r
.48848 .35497 .49418 .40873 .50544 .39644 .49961 .34582 Mtetra
.589 .408 .604 r
.49961 .34582 .50544 .39644 .51669 .38704 .51072 .33887 Mtetra
.585 .408 .608 r
.51072 .33887 .51669 .38704 .52793 .37832 .52186 .33287 Mtetra
.585 .411 .613 r
.52186 .33287 .52793 .37832 .5392 .36979 .53304 .32724 Mtetra
.593 .421 .619 r
.53304 .32724 .5392 .36979 .55047 .36117 .54424 .32109 Mtetra
.599 .43 .625 r
.54424 .32109 .55047 .36117 .56175 .35252 .55546 .31464 Mtetra
.597 .433 .631 r
.55546 .31464 .56175 .35252 .57305 .34415 .56673 .30877 Mtetra
.596 .438 .638 r
.56673 .30877 .57305 .34415 .58437 .33601 .57803 .30344 Mtetra
.599 .448 .648 r
.57803 .30344 .58437 .33601 .59571 .32783 .58937 .29823 Mtetra
.602 .459 .66 r
.58937 .29823 .59571 .32783 .60706 .31985 .60076 .29332 Mtetra
.6 .471 .676 r
.60076 .29332 .60706 .31985 .61845 .31244 .61221 .28907 Mtetra
.598 .485 .696 r
.61221 .28907 .61845 .31244 .62989 .30572 .62372 .28548 Mtetra
.596 .505 .721 r
.62372 .28548 .62989 .30572 .64138 .29979 .6353 .28246 Mtetra
.592 .529 .752 r
.6353 .28246 .64138 .29979 .65294 .29465 .64696 .27999 Mtetra
.585 .557 .789 r
.64696 .27999 .65294 .29465 .66458 .29035 .65871 .27803 Mtetra
.576 .589 .83 r
.65871 .27803 .66458 .29035 .67629 .28678 .67054 .27645 Mtetra
.563 .625 .872 r
.67054 .27645 .67629 .28678 .6881 .28392 .68244 .27516 Mtetra
.548 .66 .91 r
.68244 .27516 .6881 .28392 .7 .28158 .69443 .27401 Mtetra
.536 .693 .94 r
.69443 .27401 .7 .28158 .71198 .2796 .70649 .27283 Mtetra
.529 .718 .959 r
.70649 .27283 .71198 .2796 .72404 .27786 .71862 .27154 Mtetra
.532 .737 .969 r
.71862 .27154 .72404 .27786 .73618 .27617 .73081 .27002 Mtetra
.541 .749 .972 r
.73081 .27002 .73618 .27617 .74839 .27447 .74305 .26826 Mtetra
.557 .755 .97 r
.74305 .26826 .74839 .27447 .76065 .27265 .75534 .26619 Mtetra
.572 .754 .964 r
.75534 .26619 .76065 .27265 .77298 .27071 .76768 .26389 Mtetra
.585 .748 .955 r
.76768 .26389 .77298 .27071 .78537 .26864 .78008 .26139 Mtetra
.595 .738 .944 r
.78008 .26139 .78537 .26864 .79782 .26643 .79252 .25872 Mtetra
.676 .756 .911 r
.13868 .4723 .14569 .47843 .15561 .47367 .14851 .46845 Mtetra
.682 .788 .931 r
.14851 .46845 .15561 .47367 .16557 .46875 .15839 .46446 Mtetra
.688 .824 .948 r
.15839 .46446 .16557 .46875 .17557 .46364 .16832 .46027 Mtetra
.695 .859 .961 r
.16832 .46027 .17557 .46364 .18563 .4583 .17832 .45581 Mtetra
.702 .893 .966 r
.17832 .45581 .18563 .4583 .19574 .45267 .18838 .451 Mtetra
.707 .921 .965 r
.18838 .451 .19574 .45267 .2059 .4468 .19851 .44582 Mtetra
.713 .943 .958 r
.19851 .44582 .2059 .4468 .2161 .4407 .2087 .44023 Mtetra
.718 .957 .948 r
.2087 .44023 .2161 .4407 .22633 .4345 .21895 .43426 Mtetra
.73 .964 .939 r
.21895 .43426 .22633 .4345 .23659 .42825 .22926 .42794 Mtetra
.744 .964 .936 r
.22926 .42794 .23659 .42825 .24685 .42214 .23962 .42134 Mtetra
.763 .954 .937 r
.23962 .42134 .24685 .42214 .25712 .4163 .25 .41455 Mtetra
.776 .927 .934 r
.25 .41455 .25712 .4163 .26738 .41082 .26042 .40769 Mtetra
.779 .88 .92 r
.26042 .40769 .26738 .41082 .27762 .40585 .27084 .40084 Mtetra
.768 .816 .891 r
.27084 .40084 .27762 .40585 .28786 .40139 .28129 .39405 Mtetra
.745 .745 .852 r
.28129 .39405 .28786 .40139 .29809 .39751 .29174 .3874 Mtetra
.714 .675 .81 r
.29174 .3874 .29809 .39751 .30831 .39426 .30219 .38105 Mtetra
.683 .613 .771 r
.30219 .38105 .30831 .39426 .31853 .39166 .31263 .37512 Mtetra
.66 .565 .736 r
.31263 .37512 .31853 .39166 .32878 .38936 .32309 .36937 Mtetra
.642 .527 .707 r
.32309 .36937 .32878 .38936 .33907 .3872 .33356 .36372 Mtetra
.623 .495 .685 r
.33356 .36372 .33907 .3872 .34938 .38556 .34404 .35856 Mtetra
.606 .468 .667 r
.34404 .35856 .34938 .38556 .35971 .3845 .35452 .35389 Mtetra
.606 .455 .651 r
.35452 .35389 .35971 .3845 .37012 .38316 .36506 .34861 Mtetra
.607 .446 .637 r
.36506 .34861 .37012 .38316 .3806 .38131 .37568 .34237 Mtetra
.599 .43 .625 r
.37568 .34237 .3806 .38131 .39111 .37984 .38631 .3362 Mtetra
.588 .415 .614 r
.38631 .3362 .39111 .37984 .40165 .37931 .39696 .3305 Mtetra
.578 .4 .604 r
.39696 .3305 .40165 .37931 .41217 .38099 .40761 .3253 Mtetra
.569 .386 .594 r
.40761 .3253 .41217 .38099 .42271 .38461 .41828 .32057 Mtetra
.565 .376 .584 r
.41828 .32057 .42271 .38461 .43337 .38729 .42899 .31571 Mtetra
.561 .368 .577 r
.42899 .31571 .43337 .38729 .44417 .38749 .43974 .31079 Mtetra
.553 .359 .572 r
.43974 .31079 .44417 .38749 .45513 .38379 .45049 .30701 Mtetra
.547 .355 .572 r
.45049 .30701 .45513 .38379 .46621 .37617 .46126 .30435 Mtetra
.548 .359 .576 r
.46126 .30435 .46621 .37617 .47734 .36606 .47208 .30165 Mtetra
.552 .366 .583 r
.47208 .30165 .47734 .36606 .48848 .35497 .48296 .29881 Mtetra
.552 .373 .593 r
.48296 .29881 .48848 .35497 .49961 .34582 .49388 .29645 Mtetra
.551 .38 .603 r
.49388 .29645 .49961 .34582 .51072 .33887 .50485 .2946 Mtetra
.549 .387 .613 r
.50485 .2946 .51072 .33887 .52186 .33287 .51588 .29323 Mtetra
.55 .396 .625 r
.51588 .29323 .52186 .33287 .53304 .32724 .52697 .29193 Mtetra
.563 .415 .638 r
.52697 .29193 .53304 .32724 .54424 .32109 .53812 .28968 Mtetra
.575 .434 .653 r
.53812 .28968 .54424 .32109 .55546 .31464 .54933 .2868 Mtetra
.573 .446 .669 r
.54933 .2868 .55546 .31464 .56673 .30877 .56059 .28443 Mtetra
.57 .461 .69 r
.56059 .28443 .56673 .30877 .57803 .30344 .57192 .28256 Mtetra
.572 .485 .717 r
.57192 .28256 .57803 .30344 .58937 .29823 .58331 .2808 Mtetra
.573 .515 .752 r
.58331 .2808 .58937 .29823 .60076 .29332 .59477 .27922 Mtetra
.564 .552 .799 r
.59477 .27922 .60076 .29332 .61221 .28907 .6063 .27808 Mtetra
.548 .601 .858 r
.6063 .27808 .61221 .28907 .62372 .28548 .61792 .27726 Mtetra
.522 .661 .924 r
.61792 .27726 .62372 .28548 .6353 .28246 .62961 .27658 Mtetra
.471 .72 .978 r
.62961 .27658 .6353 .28246 .64696 .27999 .64137 .27598 Mtetra
.391 .753 .993 r
.64137 .27598 .64696 .27999 .65871 .27803 .65322 .2754 Mtetra
.305 .754 .96 r
.65322 .2754 .65871 .27803 .67054 .27645 .66514 .27475 Mtetra
.246 .741 .912 r
.66514 .27475 .67054 .27645 .68244 .27516 .67712 .27391 Mtetra
.23 .739 .885 r
.67712 .27391 .68244 .27516 .69443 .27401 .68917 .2728 Mtetra
.262 .761 .892 r
.68917 .2728 .69443 .27401 .70649 .27283 .70127 .27132 Mtetra
.323 .795 .923 r
.70127 .27132 .70649 .27283 .71862 .27154 .71342 .26946 Mtetra
.404 .829 .962 r
.71342 .26946 .71862 .27154 .73081 .27002 .72561 .26718 Mtetra
.481 .848 .99 r
.72561 .26718 .73081 .27002 .74305 .26826 .73784 .26451 Mtetra
.547 .848 .998 r
.73784 .26451 .74305 .26826 .75534 .26619 .75011 .26148 Mtetra
.591 .831 .99 r
.75011 .26148 .75534 .26619 .76768 .26389 .76242 .25816 Mtetra
.618 .804 .971 r
.76242 .25816 .76768 .26389 .78008 .26139 .77478 .25462 Mtetra
.632 .774 .948 r
.77478 .25462 .78008 .26139 .79252 .25872 .78718 .25095 Mtetra
.625 .743 .932 r
.13161 .46613 .13868 .4723 .14851 .46845 .14132 .46346 Mtetra
.62 .785 .96 r
.14132 .46346 .14851 .46845 .15839 .46446 .15108 .46072 Mtetra
.611 .83 .984 r
.15108 .46072 .15839 .46446 .16832 .46027 .1609 .45782 Mtetra
.594 .873 .993 r
.1609 .45782 .16832 .46027 .17832 .45581 .17079 .45469 Mtetra
.562 .903 .977 r
.17079 .45469 .17832 .45581 .18838 .451 .18074 .45125 Mtetra
.511 .907 .924 r
.18074 .45125 .18838 .451 .19851 .44582 .19078 .44742 Mtetra
.448 .882 .836 r
.19078 .44742 .19851 .44582 .2087 .44023 .20089 .44313 Mtetra
.382 .833 .73 r
.20089 .44313 .2087 .44023 .21895 .43426 .21108 .43833 Mtetra
.332 .783 .632 r
.21108 .43833 .21895 .43426 .22926 .42794 .22136 .43296 Mtetra
0 0 0 r
.22136 .43296 .22926 .42794 .23962 .42134 .23171 .42706 Mtetra
.23171 .42706 .23962 .42134 .25 .41455 .24213 .42063 Mtetra
.24213 .42063 .25 .41455 .26042 .40769 .25261 .41379 Mtetra
.25261 .41379 .26042 .40769 .27084 .40084 .26313 .40664 Mtetra
.26313 .40664 .27084 .40084 .28129 .39405 .27369 .39928 Mtetra
.42 .815 .591 r
.27369 .39928 .28129 .39405 .29174 .3874 .28426 .39183 Mtetra
.471 .859 .657 r
.28426 .39183 .29174 .3874 .30219 .38105 .29484 .38455 Mtetra
.515 .897 .726 r
.29484 .38455 .30219 .38105 .31263 .37512 .30541 .37765 Mtetra
.57 .935 .799 r
.30541 .37765 .31263 .37512 .32309 .36937 .31598 .37099 Mtetra
.614 .957 .856 r
.31598 .37099 .32309 .36937 .33356 .36372 .32656 .36458 Mtetra
.621 .958 .894 r
.32656 .36458 .33356 .36372 .34404 .35856 .33713 .35867 Mtetra
.627 .954 .926 r
.33713 .35867 .34404 .35856 .35452 .35389 .3477 .35323 Mtetra
.704 .961 .945 r
.3477 .35323 .35452 .35389 .36506 .34861 .35833 .34713 Mtetra
.772 .948 .934 r
.35833 .34713 .36506 .34861 .37568 .34237 .36904 .33997 Mtetra
.79 .92 .925 r
.36904 .33997 .37568 .34237 .38631 .3362 .37978 .33252 Mtetra
.795 .877 .907 r
.37978 .33252 .38631 .3362 .39696 .3305 .39055 .32486 Mtetra
.806 .813 .856 r
.39055 .32486 .39696 .3305 .40761 .3253 .40138 .31599 Mtetra
.784 .719 .792 r
.40138 .31599 .40761 .3253 .41828 .32057 .41226 .30605 Mtetra
.732 .625 .739 r
.41226 .30605 .41828 .32057 .42899 .31571 .42313 .29629 Mtetra
.68 .555 .706 r
.42313 .29629 .42899 .31571 .43974 .31079 .43396 .28802 Mtetra
.603 .487 .694 r
.43396 .28802 .43974 .31079 .45049 .30701 .44468 .2842 Mtetra
.526 .438 .699 r
.44468 .2842 .45049 .30701 .46126 .30435 .45535 .28482 Mtetra
.486 .438 .729 r
.45535 .28482 .46126 .30435 .47208 .30165 .46607 .28695 Mtetra
.455 .475 .79 r
.46607 .28695 .47208 .30165 .48296 .29881 .47686 .28929 Mtetra
.441 .575 .892 r
.47686 .28929 .48296 .29881 .49388 .29645 .48775 .29057 Mtetra
.429 .692 .974 r
.48775 .29057 .49388 .29645 .50485 .2946 .49874 .29064 Mtetra
.356 .731 .987 r
.49874 .29064 .50485 .2946 .51588 .29323 .5098 .29052 Mtetra
.298 .743 .962 r
.5098 .29052 .51588 .29323 .52697 .29193 .52093 .2901 Mtetra
.341 .794 .949 r
.52093 .2901 .52697 .29193 .53812 .28968 .53213 .28862 Mtetra
.343 .811 .917 r
.53213 .28862 .53812 .28968 .54933 .2868 .54338 .28649 Mtetra
.218 .74 .833 r
.54338 .28649 .54933 .2868 .56059 .28443 .55471 .28483 Mtetra
.088 .647 .726 r
.55471 .28483 .56059 .28443 .57192 .28256 .5661 .28369 Mtetra
.009 0 0 r
.5661 .28369 .57192 .28256 .58331 .2808 .57756 .28281 Mtetra
.108 0 0 r
.57756 .28281 .58331 .2808 .59477 .27922 .58911 .28219 Mtetra
.204 0 0 r
.58911 .28219 .59477 .27922 .6063 .27808 .60073 .28196 Mtetra
.265 0 0 r
.60073 .28196 .6063 .27808 .61792 .27726 .61243 .28192 Mtetra
.292 0 0 r
.61243 .28192 .61792 .27726 .62961 .27658 .62422 .28179 Mtetra
.299 0 0 r
.62422 .28179 .62961 .27658 .64137 .27598 .63607 .28147 Mtetra
.29 0 0 r
.63607 .28147 .64137 .27598 .65322 .2754 .64799 .28083 Mtetra
.264 0 0 r
.64799 .28083 .65322 .2754 .66514 .27475 .65997 .27978 Mtetra
.214 0 0 r
.65997 .27978 .66514 .27475 .67712 .27391 .672 .27818 Mtetra
.138 0 0 r
.672 .27818 .67712 .27391 .68917 .2728 .68407 .27604 Mtetra
.024 0 0 r
.68407 .27604 .68917 .2728 .70127 .27132 .69617 .27331 Mtetra
0 0 0 r
.69617 .27331 .70127 .27132 .71342 .26946 .70831 .27006 Mtetra
.301 .794 .783 r
.70831 .27006 .71342 .26946 .72561 .26718 .72048 .26632 Mtetra
.462 .884 .913 r
.72048 .26632 .72561 .26718 .73784 .26451 .73268 .26218 Mtetra
.577 .91 .976 r
.73268 .26218 .73784 .26451 .75011 .26148 .7449 .2577 Mtetra
.641 .889 .985 r
.7449 .2577 .75011 .26148 .76242 .25816 .75716 .25298 Mtetra
.671 .848 .967 r
.75716 .25298 .76242 .25816 .77478 .25462 .76946 .24809 Mtetra
.681 .803 .941 r
.76946 .24809 .77478 .25462 .78718 .25095 .7818 .24311 Mtetra
.562 .724 .949 r
.12449 .45992 .13161 .46613 .14132 .46346 .13409 .45838 Mtetra
.543 .76 .977 r
.13409 .45838 .14132 .46346 .15108 .46072 .14373 .45684 Mtetra
.514 .797 .997 r
.14373 .45684 .15108 .46072 .1609 .45782 .15343 .45523 Mtetra
.47 .826 .996 r
.15343 .45523 .1609 .45782 .17079 .45469 .16319 .45348 Mtetra
.402 .833 .956 r
.16319 .45348 .17079 .45469 .18074 .45125 .17302 .45152 Mtetra
.311 .802 .86 r
.17302 .45152 .18074 .45125 .19078 .44742 .18293 .44925 Mtetra
.211 .73 .717 r
.18293 .44925 .19078 .44742 .20089 .44313 .19292 .44657 Mtetra
0 0 0 r
.19292 .44657 .20089 .44313 .21108 .43833 .20301 .44339 Mtetra
.20301 .44339 .21108 .43833 .22136 .43296 .2132 .4396 Mtetra
.2132 .4396 .22136 .43296 .23171 .42706 .22348 .43518 Mtetra
.03 0 0 r
.22348 .43518 .23171 .42706 .24213 .42063 .23385 .43009 Mtetra
.061 0 0 r
.23385 .43009 .24213 .42063 .25261 .41379 .2443 .42447 Mtetra
.088 0 0 r
.2443 .42447 .25261 .41379 .26313 .40664 .25481 .41841 Mtetra
.115 0 0 r
.25481 .41841 .26313 .40664 .27369 .39928 .26537 .41206 Mtetra
.144 0 .005 r
.26537 .41206 .27369 .39928 .28426 .39183 .27597 .40555 Mtetra
.184 0 .049 r
.27597 .40555 .28426 .39183 .29484 .38455 .28658 .39918 Mtetra
.228 0 .091 r
.28658 .39918 .29484 .38455 .30541 .37765 .29718 .39319 Mtetra
.262 0 .126 r
.29718 .39319 .30541 .37765 .31598 .37099 .30778 .38751 Mtetra
.294 0 .159 r
.30778 .38751 .31598 .37099 .32656 .36458 .31839 .38217 Mtetra
.328 0 .191 r
.31839 .38217 .32656 .36458 .33713 .35867 .32901 .37731 Mtetra
.353 0 .216 r
.32901 .37731 .33713 .35867 .3477 .35323 .33963 .37285 Mtetra
.35 .002 .226 r
.33963 .37285 .3477 .35323 .35833 .34713 .35031 .36794 Mtetra
.338 0 .233 r
.35031 .36794 .35833 .34713 .36904 .33997 .36107 .36216 Mtetra
.339 .007 .247 r
.36107 .36216 .36904 .33997 .37978 .33252 .37189 .35591 Mtetra
.332 .007 .255 r
.37189 .35591 .37978 .33252 .39055 .32486 .38276 .3489 Mtetra
.271 0 .235 r
.38276 .3489 .39055 .32486 .40138 .31599 .39376 .3393 Mtetra
.188 0 .195 r
.39376 .3393 .40138 .31599 .41226 .30605 .40486 .32722 Mtetra
.152 0 .16 r
.40486 .32722 .41226 .30605 .42313 .29629 .41594 .31522 Mtetra
.184 0 .149 r
.41594 .31522 .42313 .29629 .43396 .28802 .42694 .30532 Mtetra
.365 .002 .209 r
.42694 .30532 .43396 .28802 .44468 .2842 .43778 .30148 Mtetra
.516 .145 .274 r
.43778 .30148 .44468 .2842 .45535 .28482 .44851 .30372 Mtetra
.555 .191 .306 r
.44851 .30372 .45535 .28482 .46607 .28695 .45928 .3081 Mtetra
.554 .201 .324 r
.45928 .3081 .46607 .28695 .47686 .28929 .47015 .31257 Mtetra
.516 .174 .325 r
.47015 .31257 .47686 .28929 .48775 .29057 .48116 .31458 Mtetra
.474 .138 .315 r
.48116 .31458 .48775 .29057 .49874 .29064 .49228 .31398 Mtetra
.459 .121 .305 r
.49228 .31398 .49874 .29064 .5098 .29052 .50348 .31264 Mtetra
.446 .103 .29 r
.50348 .31264 .5098 .29052 .52093 .2901 .51474 .31082 Mtetra
.422 .074 .268 r
.51474 .31082 .52093 .2901 .53213 .28862 .52607 .30813 Mtetra
.404 .052 .249 r
.52607 .30813 .53213 .28862 .54338 .28649 .53745 .30498 Mtetra
.408 .048 .239 r
.53745 .30498 .54338 .28649 .55471 .28483 .54888 .30225 Mtetra
.412 .045 .227 r
.54888 .30225 .55471 .28483 .5661 .28369 .56038 .3 Mtetra
.414 .037 .212 r
.56038 .3 .5661 .28369 .57756 .28281 .57194 .2981 Mtetra
.415 .029 .197 r
.57194 .2981 .57756 .28281 .58911 .28219 .58358 .29653 Mtetra
.418 .024 .181 r
.58358 .29653 .58911 .28219 .60073 .28196 .59529 .29535 Mtetra
.414 .011 .161 r
.59529 .29535 .60073 .28196 .61243 .28192 .60707 .29432 Mtetra
.4 0 .134 r
.60707 .29432 .61243 .28192 .62422 .28179 .61892 .29314 Mtetra
.377 0 .099 r
.61892 .29314 .62422 .28179 .63607 .28147 .63084 .29166 Mtetra
.343 0 .052 r
.63084 .29166 .63607 .28147 .64799 .28083 .64281 .28974 Mtetra
.294 0 0 r
.64281 .28974 .64799 .28083 .65997 .27978 .65482 .28727 Mtetra
.217 0 0 r
.65482 .28727 .65997 .27978 .672 .27818 .66687 .28411 Mtetra
.111 0 0 r
.66687 .28411 .672 .27818 .68407 .27604 .67894 .2803 Mtetra
0 0 0 r
.67894 .2803 .68407 .27604 .69617 .27331 .69104 .27586 Mtetra
.69104 .27586 .69617 .27331 .70831 .27006 .70315 .27088 Mtetra
.425 .866 .796 r
.70315 .27088 .70831 .27006 .72048 .26632 .71529 .26547 Mtetra
.578 .938 .917 r
.71529 .26547 .72048 .26632 .73268 .26218 .72745 .25973 Mtetra
.667 .94 .964 r
.72745 .25973 .73268 .26218 .7449 .2577 .73963 .25377 Mtetra
.708 .906 .965 r
.73963 .25377 .7449 .2577 .75716 .25298 .75184 .24765 Mtetra
.722 .861 .947 r
.75184 .24765 .75716 .25298 .76946 .24809 .76409 .24144 Mtetra
.722 .816 .923 r
.76409 .24144 .76946 .24809 .7818 .24311 .77637 .23521 Mtetra
.52 .709 .957 r
.11732 .45366 .12449 .45992 .13409 .45838 .12686 .45275 Mtetra
.503 .726 .973 r
.12686 .45275 .13409 .45838 .14373 .45684 .13643 .45189 Mtetra
.483 .745 .986 r
.13643 .45189 .14373 .45684 .15343 .45523 .14607 .45102 Mtetra
.46 .764 .996 r
.14607 .45102 .15343 .45523 .16319 .45348 .15575 .45009 Mtetra
.43 .783 .997 r
.15575 .45009 .16319 .45348 .17302 .45152 .16551 .44908 Mtetra
.392 .797 .983 r
.16551 .44908 .17302 .45152 .18293 .44925 .17533 .44788 Mtetra
.343 .799 .943 r
.17533 .44788 .18293 .44925 .19292 .44657 .18523 .44642 Mtetra
.279 .779 .867 r
.18523 .44642 .19292 .44657 .20301 .44339 .19522 .44463 Mtetra
.201 .728 .749 r
.19522 .44463 .20301 .44339 .2132 .4396 .20529 .44241 Mtetra
0 0 0 r
.20529 .44241 .2132 .4396 .22348 .43518 .21545 .43978 Mtetra
.001 0 0 r
.21545 .43978 .22348 .43518 .23385 .43009 .2257 .43675 Mtetra
.107 0 0 r
.2257 .43675 .23385 .43009 .2443 .42447 .23601 .43344 Mtetra
.197 0 0 r
.23601 .43344 .2443 .42447 .25481 .41841 .24638 .42995 Mtetra
.265 0 .038 r
.24638 .42995 .25481 .41841 .26537 .41206 .2568 .42631 Mtetra
.315 0 .125 r
.2568 .42631 .26537 .41206 .27597 .40555 .26727 .42258 Mtetra
.352 0 .189 r
.26727 .42258 .27597 .40555 .28658 .39918 .27778 .41882 Mtetra
.378 .025 .234 r
.27778 .41882 .28658 .39918 .29718 .39319 .28833 .4151 Mtetra
.392 .05 .262 r
.28833 .4151 .29718 .39319 .30778 .38751 .29892 .41125 Mtetra
.399 .066 .28 r
.29892 .41125 .30778 .38751 .31839 .38217 .30957 .40722 Mtetra
.407 .079 .293 r
.30957 .40722 .31839 .38217 .32901 .37731 .32026 .40321 Mtetra
.413 .088 .301 r
.32026 .40321 .32901 .37731 .33963 .37285 .33098 .39929 Mtetra
.413 .089 .305 r
.33098 .39929 .33963 .37285 .35031 .36794 .34176 .39519 Mtetra
.411 .09 .309 r
.34176 .39519 .35031 .36794 .36107 .36216 .35259 .39079 Mtetra
.417 .1 .319 r
.35259 .39079 .36107 .36216 .37189 .35591 .36345 .38638 Mtetra
.417 .106 .329 r
.36345 .38638 .37189 .35591 .38276 .3489 .37438 .38154 Mtetra
.377 .077 .324 r
.37438 .38154 .38276 .3489 .39376 .3393 .38547 .3738 Mtetra
.335 .046 .317 r
.38547 .3738 .39376 .3393 .40486 .32722 .3967 .36303 Mtetra
.337 .051 .324 r
.3967 .36303 .40486 .32722 .41594 .31522 .40794 .35188 Mtetra
.37 .082 .339 r
.40794 .35188 .41594 .31522 .42694 .30532 .41912 .34238 Mtetra
.452 .154 .368 r
.41912 .34238 .42694 .30532 .43778 .30148 .43013 .33855 Mtetra
.518 .212 .388 r
.43013 .33855 .43778 .30148 .44851 .30372 .44104 .34041 Mtetra
.535 .226 .391 r
.44104 .34041 .44851 .30372 .45928 .3081 .452 .34394 Mtetra
.531 .221 .387 r
.452 .34394 .45928 .3081 .47015 .31257 .46305 .34711 Mtetra
.497 .188 .372 r
.46305 .34711 .47015 .31257 .48116 .31458 .47426 .34726 Mtetra
.457 .148 .352 r
.47426 .34726 .48116 .31458 .49228 .31398 .48557 .34449 Mtetra
.446 .132 .339 r
.48557 .34449 .49228 .31398 .50348 .31264 .49694 .34129 Mtetra
.441 .122 .327 r
.49694 .34129 .50348 .31264 .51474 .31082 .50837 .33807 Mtetra
.431 .109 .316 r
.50837 .33807 .51474 .31082 .52607 .30813 .51985 .33456 Mtetra
.425 .101 .309 r
.51985 .33456 .52607 .30813 .53745 .30498 .53138 .33087 Mtetra
.425 .098 .306 r
.53138 .33087 .53745 .30498 .54888 .30225 .54296 .32726 Mtetra
.422 .092 .299 r
.54296 .32726 .54888 .30225 .56038 .3 .55459 .32367 Mtetra
.413 .078 .285 r
.55459 .32367 .56038 .3 .57194 .2981 .56627 .3199 Mtetra
.4 .058 .265 r
.56627 .3199 .57194 .2981 .58358 .29653 .57801 .31601 Mtetra
.385 .031 .237 r
.57801 .31601 .58358 .29653 .59529 .29535 .58979 .31214 Mtetra
.362 0 .193 r
.58979 .31214 .59529 .29535 .60707 .29432 .60162 .30824 Mtetra
.324 0 .13 r
.60162 .30824 .60707 .29432 .61892 .29314 .61351 .30424 Mtetra
.266 0 .039 r
.61351 .30424 .61892 .29314 .63084 .29166 .62544 .30009 Mtetra
.18 0 0 r
.62544 .30009 .63084 .29166 .64281 .28974 .63741 .29575 Mtetra
.051 0 0 r
.63741 .29575 .64281 .28974 .65482 .28727 .64943 .29113 Mtetra
0 0 0 r
.64943 .29113 .65482 .28727 .66687 .28411 .66147 .28607 Mtetra
.338 .802 .696 r
.66147 .28607 .66687 .28411 .67894 .2803 .67354 .28059 Mtetra
.52 .918 .854 r
.67354 .28059 .67894 .2803 .69104 .27586 .68563 .27466 Mtetra
.638 .955 .933 r
.68563 .27466 .69104 .27586 .70315 .27088 .69774 .26836 Mtetra
.702 .947 .957 r
.69774 .26836 .70315 .27088 .71529 .26547 .70986 .26179 Mtetra
.733 .919 .956 r
.70986 .26179 .71529 .26547 .72745 .25973 .72201 .25501 Mtetra
.744 .887 .945 r
.72201 .25501 .72745 .25973 .73963 .25377 .73419 .24812 Mtetra
.747 .857 .93 r
.73419 .24812 .73963 .25377 .75184 .24765 .74639 .24116 Mtetra
.745 .829 .916 r
.74639 .24116 .75184 .24765 .76409 .24144 .75863 .23419 Mtetra
.74 .804 .903 r
.75863 .23419 .76409 .24144 .77637 .23521 .7709 .22725 Mtetra
.515 .706 .958 r
.1101 .44736 .11732 .45366 .12686 .45275 .11964 .44651 Mtetra
.508 .707 .96 r
.11964 .44651 .12686 .45275 .13643 .45189 .12922 .44571 Mtetra
.502 .708 .963 r
.12922 .44571 .13643 .45189 .14607 .45102 .13885 .44497 Mtetra
.497 .711 .966 r
.13885 .44497 .14607 .45102 .15575 .45009 .14853 .44426 Mtetra
.49 .717 .972 r
.14853 .44426 .15575 .45009 .16551 .44908 .15826 .44356 Mtetra
.483 .726 .978 r
.15826 .44356 .16551 .44908 .17533 .44788 .16805 .44283 Mtetra
.474 .741 .987 r
.16805 .44283 .17533 .44788 .18523 .44642 .1779 .44203 Mtetra
.456 .76 .995 r
.1779 .44203 .18523 .44642 .19522 .44463 .18782 .44115 Mtetra
.423 .779 .996 r
.18782 .44115 .19522 .44463 .20529 .44241 .1978 .44017 Mtetra
.347 .782 .967 r
.1978 .44017 .20529 .44241 .21545 .43978 .20783 .43915 Mtetra
.206 .727 .857 r
.20783 .43915 .21545 .43978 .2257 .43675 .21792 .43814 Mtetra
.002 0 0 r
.21792 .43814 .2257 .43675 .23601 .43344 .22806 .43724 Mtetra
.197 0 0 r
.22806 .43724 .23601 .43344 .24638 .42995 .23824 .43653 Mtetra
.311 0 0 r
.23824 .43653 .24638 .42995 .2568 .42631 .24847 .43584 Mtetra
.371 0 .045 r
.24847 .43584 .2568 .42631 .26727 .42258 .25877 .43509 Mtetra
.398 0 .134 r
.25877 .43509 .26727 .42258 .27778 .41882 .26915 .43407 Mtetra
.407 .02 .188 r
.26915 .43407 .27778 .41882 .28833 .4151 .27962 .43259 Mtetra
.403 .032 .216 r
.27962 .43259 .28833 .4151 .29892 .41125 .2902 .4304 Mtetra
.391 .032 .23 r
.2902 .4304 .29892 .41125 .30957 .40722 .30089 .42738 Mtetra
.386 .033 .238 r
.30089 .42738 .30957 .40722 .32026 .40321 .31166 .42387 Mtetra
.384 .034 .242 r
.31166 .42387 .32026 .40321 .33098 .39929 .32248 .42014 Mtetra
.391 .042 .247 r
.32248 .42014 .33098 .39929 .34176 .39519 .33334 .41662 Mtetra
.408 .06 .26 r
.33334 .41662 .34176 .39519 .35259 .39079 .34421 .41359 Mtetra
.434 .091 .283 r
.34421 .41359 .35259 .39079 .36345 .38638 .35509 .41142 Mtetra
.451 .116 .306 r
.35509 .41142 .36345 .38638 .37438 .38154 .366 .40969 Mtetra
.418 .097 .312 r
.366 .40969 .37438 .38154 .38547 .3738 .37708 .40558 Mtetra
.382 .077 .318 r
.37708 .40558 .38547 .3738 .3967 .36303 .38832 .39855 Mtetra
.382 .087 .334 r
.38832 .39855 .3967 .36303 .40794 .35188 .39963 .39045 Mtetra
.401 .11 .352 r
.39963 .39045 .40794 .35188 .41912 .34238 .41094 .38281 Mtetra
.455 .161 .375 r
.41094 .38281 .41912 .34238 .43013 .33855 .42214 .37899 Mtetra
.498 .198 .388 r
.42214 .37899 .43013 .33855 .44104 .34041 .43329 .37901 Mtetra
.501 .198 .383 r
.43329 .37901 .44104 .34041 .452 .34394 .44449 .3795 Mtetra
.487 .179 .369 r
.44449 .3795 .452 .34394 .46305 .34711 .45579 .37893 Mtetra
.442 .13 .339 r
.45579 .37893 .46305 .34711 .47426 .34726 .46722 .37542 Mtetra
.389 .072 .303 r
.46722 .37542 .47426 .34726 .48557 .34449 .47873 .36952 Mtetra
.38 .053 .279 r
.47873 .36952 .48557 .34449 .49694 .34129 .49028 .36405 Mtetra
.385 .046 .263 r
.49028 .36405 .49694 .34129 .50837 .33807 .50185 .35944 Mtetra
.387 .041 .251 r
.50185 .35944 .50837 .33807 .51985 .33456 .51347 .35533 Mtetra
.389 .039 .246 r
.51347 .35533 .51985 .33456 .53138 .33087 .52513 .35144 Mtetra
.382 .032 .241 r
.52513 .35144 .53138 .33087 .54296 .32726 .53684 .34731 Mtetra
.367 .015 .23 r
.53684 .34731 .54296 .32726 .55459 .32367 .5486 .34269 Mtetra
.336 0 .207 r
.5486 .34269 .55459 .32367 .56627 .3199 .5604 .3372 Mtetra
.295 0 .169 r
.5604 .3372 .56627 .3199 .57801 .31601 .57222 .33099 Mtetra
.241 0 .111 r
.57222 .33099 .57801 .31601 .58979 .31214 .58407 .3243 Mtetra
.162 0 .016 r
.58407 .3243 .58979 .31214 .60162 .30824 .59594 .31731 Mtetra
.042 0 0 r
.59594 .31731 .60162 .30824 .61351 .30424 .60784 .31024 Mtetra
0 0 0 r
.60784 .31024 .61351 .30424 .62544 .30009 .61978 .30319 Mtetra
.365 .799 .628 r
.61978 .30319 .62544 .30009 .63741 .29575 .63174 .29633 Mtetra
.57 .939 .847 r
.63174 .29633 .63741 .29575 .64943 .29113 .64374 .28956 Mtetra
.687 .962 .941 r
.64374 .28956 .64943 .29113 .66147 .28607 .65578 .28279 Mtetra
.732 .928 .956 r
.65578 .28279 .66147 .28607 .67354 .28059 .66784 .27597 Mtetra
.747 .888 .943 r
.66784 .27597 .67354 .28059 .68563 .27466 .67993 .26903 Mtetra
.75 .855 .927 r
.67993 .26903 .68563 .27466 .69774 .26836 .69205 .26199 Mtetra
.75 .831 .914 r
.69205 .26199 .69774 .26836 .70986 .26179 .70419 .25487 Mtetra
.749 .814 .904 r
.70419 .25487 .70986 .26179 .72201 .25501 .71637 .2477 Mtetra
.746 .803 .898 r
.71637 .2477 .72201 .25501 .73419 .24812 .72857 .24054 Mtetra
.744 .795 .894 r
.72857 .24054 .73419 .24812 .74639 .24116 .74081 .23339 Mtetra
.741 .79 .892 r
.74081 .23339 .74639 .24116 .75863 .23419 .75308 .22628 Mtetra
.739 .786 .891 r
.75308 .22628 .75863 .23419 .7709 .22725 .76539 .21923 Mtetra
.558 .722 .95 r
.10283 .44102 .1101 .44736 .11964 .44651 .11247 .43948 Mtetra
.561 .701 .935 r
.11247 .43948 .11964 .44651 .12922 .44571 .12214 .43801 Mtetra
.562 .68 .919 r
.12214 .43801 .12922 .44571 .13885 .44497 .13186 .43661 Mtetra
.561 .661 .904 r
.13186 .43661 .13885 .44497 .14853 .44426 .14161 .4353 Mtetra
.558 .644 .891 r
.14161 .4353 .14853 .44426 .15826 .44356 .15141 .43411 Mtetra
.554 .63 .881 r
.15141 .43411 .15826 .44356 .16805 .44283 .16124 .43303 Mtetra
.549 .62 .875 r
.16124 .43303 .16805 .44283 .1779 .44203 .17111 .4321 Mtetra
.541 .614 .874 r
.17111 .4321 .1779 .44203 .18782 .44115 .18101 .43134 Mtetra
.531 .612 .879 r
.18101 .43134 .18782 .44115 .1978 .44017 .19096 .43077 Mtetra
.517 .618 .891 r
.19096 .43077 .1978 .44017 .20783 .43915 .20093 .43042 Mtetra
.497 .628 .91 r
.20093 .43042 .20783 .43915 .21792 .43814 .21095 .43031 Mtetra
.474 .646 .933 r
.21095 .43031 .21792 .43814 .22806 .43724 .22101 .43033 Mtetra
.448 .667 .956 r
.22101 .43033 .22806 .43724 .23824 .43653 .23113 .43043 Mtetra
.444 .695 .973 r
.23113 .43043 .23824 .43653 .24847 .43584 .24133 .43029 Mtetra
.465 .726 .982 r
.24133 .43029 .24847 .43584 .25877 .43509 .25164 .42966 Mtetra
.51 .75 .982 r
.25164 .42966 .25877 .43509 .26915 .43407 .26206 .42839 Mtetra
.567 .763 .97 r
.26206 .42839 .26915 .43407 .27962 .43259 .2726 .42632 Mtetra
.614 .759 .948 r
.2726 .42632 .27962 .43259 .2902 .4304 .28325 .42348 Mtetra
.647 .748 .923 r
.28325 .42348 .2902 .4304 .30089 .42738 .294 .41994 Mtetra
.653 .736 .91 r
.294 .41994 .30089 .42738 .31166 .42387 .3048 .41622 Mtetra
.644 .727 .909 r
.3048 .41622 .31166 .42387 .32248 .42014 .31563 .41274 Mtetra
.604 .722 .928 r
.31563 .41274 .32248 .42014 .33334 .41662 .32645 .4102 Mtetra
.519 .722 .965 r
.32645 .4102 .33334 .41662 .34421 .41359 .33724 .40903 Mtetra
.304 .687 .977 r
.33724 .40903 .34421 .41359 .35509 .41142 .348 .40961 Mtetra
0 .502 .753 r
.348 .40961 .35509 .41142 .366 .40969 .35876 .41152 Mtetra
.178 0 0 r
.35876 .41152 .366 .40969 .37708 .40558 .36968 .41185 Mtetra
.189 0 0 r
.36968 .41185 .37708 .40558 .38832 .39855 .38079 .40962 Mtetra
.237 0 .003 r
.38079 .40962 .38832 .39855 .39963 .39045 .39203 .40554 Mtetra
.275 0 .113 r
.39203 .40554 .39963 .39045 .41094 .38281 .40336 .40037 Mtetra
.356 0 .189 r
.40336 .40037 .41094 .38281 .42214 .37899 .41468 .39655 Mtetra
.395 .021 .207 r
.41468 .39655 .42214 .37899 .43329 .37901 .42601 .39407 Mtetra
.336 0 .142 r
.42601 .39407 .43329 .37901 .44449 .3795 .43742 .3905 Mtetra
.172 0 0 r
.43742 .3905 .44449 .3795 .45579 .37893 .44893 .38507 Mtetra
0 0 0 r
.44893 .38507 .45579 .37893 .46722 .37542 .46052 .37706 Mtetra
.736 .991 .827 r
.46052 .37706 .46722 .37542 .47873 .36952 .47216 .36744 Mtetra
.789 .951 .924 r
.47216 .36744 .47873 .36952 .49028 .36405 .48379 .35913 Mtetra
.744 .858 .933 r
.48379 .35913 .49028 .36405 .50185 .35944 .49543 .35258 Mtetra
.694 .783 .919 r
.49543 .35258 .50185 .35944 .51347 .35533 .50708 .34743 Mtetra
.66 .741 .91 r
.50708 .34743 .51347 .35533 .52513 .35144 .51878 .34321 Mtetra
.65 .729 .907 r
.51878 .34321 .52513 .35144 .53684 .34731 .53052 .33924 Mtetra
.657 .737 .909 r
.53052 .33924 .53684 .34731 .5486 .34269 .54231 .33508 Mtetra
.681 .76 .911 r
.54231 .33508 .5486 .34269 .5604 .3372 .55415 .3302 Mtetra
.708 .788 .914 r
.55415 .3302 .5604 .3372 .57222 .33099 .56602 .32454 Mtetra
.735 .814 .914 r
.56602 .32454 .57222 .33099 .58407 .3243 .57792 .31804 Mtetra
.754 .826 .908 r
.57792 .31804 .58407 .3243 .59594 .31731 .58983 .31087 Mtetra
.766 .824 .897 r
.58983 .31087 .59594 .31731 .60784 .31024 .60176 .30319 Mtetra
.768 .807 .884 r
.60176 .30319 .60784 .31024 .61978 .30319 .61371 .29524 Mtetra
.76 .78 .87 r
.61371 .29524 .61978 .30319 .63174 .29633 .62568 .28736 Mtetra
.748 .751 .855 r
.62568 .28736 .63174 .29633 .64374 .28956 .63769 .27961 Mtetra
.734 .724 .842 r
.63769 .27961 .64374 .28956 .65578 .28279 .64972 .27208 Mtetra
.724 .704 .832 r
.64972 .27208 .65578 .28279 .66784 .27597 .66179 .26476 Mtetra
.715 .692 .826 r
.66179 .26476 .66784 .27597 .67993 .26903 .67391 .25763 Mtetra
.71 .686 .825 r
.67391 .25763 .67993 .26903 .69205 .26199 .68606 .25067 Mtetra
.708 .688 .828 r
.68606 .25067 .69205 .26199 .70419 .25487 .69825 .24384 Mtetra
.707 .694 .835 r
.69825 .24384 .70419 .25487 .71637 .2477 .71048 .23713 Mtetra
.708 .705 .845 r
.71048 .23713 .71637 .2477 .72857 .24054 .72275 .23052 Mtetra
.71 .719 .856 r
.72275 .23052 .72857 .24054 .74081 .23339 .73507 .224 Mtetra
.713 .736 .87 r
.73507 .224 .74081 .23339 .75308 .22628 .74743 .21754 Mtetra
.715 .756 .884 r
.74743 .21754 .75308 .22628 .76539 .21923 .75983 .21113 Mtetra
.621 .742 .934 r
.09551 .43462 .10283 .44102 .11247 .43948 .10531 .43193 Mtetra
.621 .706 .907 r
.10531 .43193 .11247 .43948 .12214 .43801 .11514 .42927 Mtetra
.617 .673 .881 r
.11514 .42927 .12214 .43801 .13186 .43661 .12501 .42671 Mtetra
.61 .642 .858 r
.12501 .42671 .13186 .43661 .14161 .4353 .1349 .42427 Mtetra
.601 .615 .837 r
.1349 .42427 .14161 .4353 .15141 .43411 .14482 .42202 Mtetra
.591 .59 .82 r
.14482 .42202 .15141 .43411 .16124 .43303 .15475 .42001 Mtetra
.579 .569 .806 r
.15475 .42001 .16124 .43303 .17111 .4321 .1647 .41832 Mtetra
.567 .552 .797 r
.1647 .41832 .17111 .4321 .18101 .43134 .17466 .41699 Mtetra
.554 .537 .79 r
.17466 .41699 .18101 .43134 .19096 .43077 .18463 .41609 Mtetra
.543 .527 .787 r
.18463 .41609 .19096 .43077 .20093 .43042 .19462 .41552 Mtetra
.534 .519 .785 r
.19462 .41552 .20093 .43042 .21095 .43031 .20463 .41522 Mtetra
.535 .518 .783 r
.20463 .41522 .21095 .43031 .22101 .43033 .21472 .4149 Mtetra
.543 .518 .778 r
.21472 .4149 .22101 .43033 .23113 .43043 .22488 .41433 Mtetra
.561 .52 .767 r
.22488 .41433 .23113 .43043 .24133 .43029 .23517 .41313 Mtetra
.583 .522 .752 r
.23517 .41313 .24133 .43029 .25164 .42966 .24559 .41098 Mtetra
.598 .516 .733 r
.24559 .41098 .25164 .42966 .26206 .42839 .25613 .40797 Mtetra
.609 .509 .716 r
.25613 .40797 .26206 .42839 .2726 .42632 .26679 .4041 Mtetra
.611 .499 .701 r
.26679 .4041 .2726 .42632 .28325 .42348 .27753 .39975 Mtetra
.609 .489 .691 r
.27753 .39975 .28325 .42348 .294 .41994 .28832 .39522 Mtetra
.601 .479 .685 r
.28832 .39522 .294 .41994 .3048 .41622 .29913 .39101 Mtetra
.588 .468 .683 r
.29913 .39101 .3048 .41622 .31563 .41274 .30992 .3876 Mtetra
.565 .453 .685 r
.30992 .3876 .31563 .41274 .32645 .4102 .32066 .38565 Mtetra
.531 .435 .691 r
.32066 .38565 .32645 .4102 .33724 .40903 .33134 .38565 Mtetra
.479 .408 .7 r
.33134 .38565 .33724 .40903 .348 .40961 .34196 .38805 Mtetra
.418 .384 .713 r
.34196 .38805 .348 .40961 .35876 .41152 .35255 .39249 Mtetra
.42 .409 .741 r
.35255 .39249 .35876 .41152 .36968 .41185 .36327 .39631 Mtetra
.461 .478 .79 r
.36327 .39631 .36968 .41185 .38079 .40962 .37418 .39822 Mtetra
.527 .589 .86 r
.37418 .39822 .38079 .40962 .39203 .40554 .38528 .39777 Mtetra
.612 .722 .923 r
.38528 .39777 .39203 .40554 .40336 .40037 .39654 .39492 Mtetra
.644 .81 .963 r
.39654 .39492 .40336 .40037 .41468 .39655 .4079 .39107 Mtetra
.686 .822 .948 r
.4079 .39107 .41468 .39655 .42601 .39407 .41933 .38621 Mtetra
.748 .764 .866 r
.41933 .38621 .42601 .39407 .43742 .3905 .43088 .37894 Mtetra
.757 .689 .787 r
.43088 .37894 .43742 .3905 .44893 .38507 .44251 .36927 Mtetra
.745 .63 .732 r
.44251 .36927 .44893 .38507 .46052 .37706 .4542 .35766 Mtetra
.727 .59 .703 r
.4542 .35766 .46052 .37706 .47216 .36744 .46589 .34541 Mtetra
.689 .552 .694 r
.46589 .34541 .47216 .36744 .48379 .35913 .47753 .33518 Mtetra
.651 .518 .688 r
.47753 .33518 .48379 .35913 .49543 .35258 .48916 .32736 Mtetra
.621 .493 .685 r
.48916 .32736 .49543 .35258 .50708 .34743 .50079 .3215 Mtetra
.598 .475 .683 r
.50079 .3215 .50708 .34743 .51878 .34321 .51245 .31713 Mtetra
.586 .467 .683 r
.51245 .31713 .51878 .34321 .53052 .33924 .52415 .31356 Mtetra
.582 .467 .687 r
.52415 .31356 .53052 .33924 .54231 .33508 .53591 .31031 Mtetra
.587 .475 .693 r
.53591 .31031 .54231 .33508 .55415 .3302 .54773 .30689 Mtetra
.598 .49 .702 r
.54773 .30689 .55415 .3302 .56602 .32454 .5596 .30298 Mtetra
.616 .514 .714 r
.5596 .30298 .56602 .32454 .57792 .31804 .57151 .29819 Mtetra
.637 .539 .727 r
.57151 .29819 .57792 .31804 .58983 .31087 .58344 .2925 Mtetra
.659 .565 .737 r
.58344 .2925 .58983 .31087 .60176 .30319 .5954 .28583 Mtetra
.675 .584 .745 r
.5954 .28583 .60176 .30319 .61371 .29524 .60737 .2785 Mtetra
.684 .595 .75 r
.60737 .2785 .61371 .29524 .62568 .28736 .61936 .2709 Mtetra
.686 .599 .753 r
.61936 .2709 .62568 .28736 .63769 .27961 .63137 .26325 Mtetra
.682 .599 .756 r
.63137 .26325 .63769 .27961 .64972 .27208 .64342 .25589 Mtetra
.678 .598 .76 r
.64342 .25589 .64972 .27208 .66179 .26476 .65552 .24885 Mtetra
.672 .599 .766 r
.65552 .24885 .66179 .26476 .67391 .25763 .66766 .24223 Mtetra
.668 .604 .774 r
.66766 .24223 .67391 .25763 .68606 .25067 .67986 .23599 Mtetra
.666 .613 .786 r
.67986 .23599 .68606 .25067 .69825 .24384 .69212 .23006 Mtetra
.666 .626 .8 r
.69212 .23006 .69825 .24384 .71048 .23713 .70443 .22438 Mtetra
.668 .645 .818 r
.70443 .22438 .71048 .23713 .72275 .23052 .71679 .21888 Mtetra
.671 .668 .839 r
.71679 .21888 .72275 .23052 .73507 .224 .72922 .21351 Mtetra
.675 .696 .862 r
.72922 .21351 .73507 .224 .74743 .21754 .74169 .20823 Mtetra
.679 .727 .886 r
.74169 .20823 .74743 .21754 .75983 .21113 .75422 .20298 Mtetra
.679 .757 .91 r
.08813 .42819 .09551 .43462 .10531 .43193 .09813 .42408 Mtetra
.673 .715 .88 r
.09813 .42408 .10531 .43193 .11514 .42927 .10816 .42 Mtetra
.663 .677 .853 r
.10816 .42 .11514 .42927 .12501 .42671 .11822 .416 Mtetra
.651 .642 .828 r
.11822 .416 .12501 .42671 .1349 .42427 .12829 .41214 Mtetra
.638 .612 .807 r
.12829 .41214 .1349 .42427 .14482 .42202 .13837 .4085 Mtetra
.624 .584 .788 r
.13837 .4085 .14482 .42202 .15475 .42001 .14846 .40516 Mtetra
.609 .559 .773 r
.14846 .40516 .15475 .42001 .1647 .41832 .15854 .40221 Mtetra
.596 .537 .759 r
.15854 .40221 .1647 .41832 .17466 .41699 .16862 .39966 Mtetra
.582 .516 .746 r
.16862 .39966 .17466 .41699 .18463 .41609 .17869 .39756 Mtetra
.573 .5 .735 r
.17869 .39756 .18463 .41609 .19462 .41552 .18879 .39573 Mtetra
.567 .486 .723 r
.18879 .39573 .19462 .41552 .20463 .41522 .19892 .39405 Mtetra
.569 .477 .711 r
.19892 .39405 .20463 .41522 .21472 .4149 .20912 .3922 Mtetra
.574 .471 .698 r
.20912 .3922 .21472 .4149 .22488 .41433 .21942 .38991 Mtetra
.582 .466 .686 r
.21942 .38991 .22488 .41433 .23517 .41313 .22982 .38702 Mtetra
.59 .463 .675 r
.22982 .38702 .23517 .41313 .24559 .41098 .24033 .38335 Mtetra
.593 .459 .667 r
.24033 .38335 .24559 .41098 .25613 .40797 .25093 .37921 Mtetra
.595 .455 .661 r
.25093 .37921 .25613 .40797 .26679 .4041 .26159 .37475 Mtetra
.594 .453 .659 r
.26159 .37475 .26679 .4041 .27753 .39975 .2723 .37021 Mtetra
.593 .451 .658 r
.2723 .37021 .27753 .39975 .28832 .39522 .28303 .36578 Mtetra
.591 .451 .659 r
.28303 .36578 .28832 .39522 .29913 .39101 .29379 .36147 Mtetra
.587 .447 .659 r
.29379 .36147 .29913 .39101 .30992 .3876 .30457 .35747 Mtetra
.573 .436 .657 r
.30457 .35747 .30992 .3876 .32066 .38565 .31533 .35443 Mtetra
.551 .417 .652 r
.31533 .35443 .32066 .38565 .33134 .38565 .32605 .35287 Mtetra
.516 .388 .645 r
.32605 .35287 .33134 .38565 .34196 .38805 .33668 .3537 Mtetra
.481 .359 .637 r
.33668 .3537 .34196 .38805 .35255 .39249 .34726 .3569 Mtetra
.478 .354 .632 r
.34726 .3569 .35255 .39249 .36327 .39631 .35791 .36045 Mtetra
.491 .362 .633 r
.35791 .36045 .36327 .39631 .37418 .39822 .36869 .36314 Mtetra
.519 .385 .638 r
.36869 .36314 .37418 .39822 .38528 .39777 .37967 .3638 Mtetra
.553 .412 .644 r
.37967 .3638 .38528 .39777 .39654 .39492 .39082 .36189 Mtetra
.578 .433 .647 r
.39082 .36189 .39654 .39492 .4079 .39107 .40212 .35799 Mtetra
.601 .448 .646 r
.40212 .35799 .4079 .39107 .41933 .38621 .41353 .35207 Mtetra
.625 .461 .641 r
.41353 .35207 .41933 .38621 .43088 .37894 .42506 .34358 Mtetra
.64 .469 .635 r
.42506 .34358 .43088 .37894 .44251 .36927 .43666 .33302 Mtetra
.645 .47 .632 r
.43666 .33302 .44251 .36927 .4542 .35766 .44828 .32158 Mtetra
.642 .468 .632 r
.44828 .32158 .4542 .35766 .46589 .34541 .45989 .31046 Mtetra
.624 .459 .637 r
.45989 .31046 .46589 .34541 .47753 .33518 .47146 .30171 Mtetra
.604 .449 .644 r
.47146 .30171 .47753 .33518 .48916 .32736 .483 .29538 Mtetra
.59 .444 .651 r
.483 .29538 .48916 .32736 .50079 .3215 .49457 .29052 Mtetra
.58 .441 .656 r
.49457 .29052 .50079 .3215 .51245 .31713 .50617 .28664 Mtetra
.577 .441 .659 r
.50617 .28664 .51245 .31713 .52415 .31356 .51782 .28308 Mtetra
.575 .44 .66 r
.51782 .28308 .52415 .31356 .53591 .31031 .52953 .27964 Mtetra
.574 .439 .659 r
.52953 .27964 .53591 .31031 .54773 .30689 .54129 .27631 Mtetra
.575 .44 .66 r
.54129 .27631 .54773 .30689 .5596 .30298 .55311 .2729 Mtetra
.58 .445 .662 r
.55311 .2729 .5596 .30298 .57151 .29819 .56498 .26917 Mtetra
.588 .455 .667 r
.56498 .26917 .57151 .29819 .58344 .2925 .57689 .26494 Mtetra
.601 .47 .674 r
.57689 .26494 .58344 .2925 .5954 .28583 .58884 .25992 Mtetra
.614 .486 .683 r
.58884 .25992 .5954 .28583 .60737 .2785 .60083 .25427 Mtetra
.625 .502 .693 r
.60083 .25427 .60737 .2785 .61936 .2709 .61284 .24816 Mtetra
.633 .516 .703 r
.61284 .24816 .61936 .2709 .63137 .26325 .62488 .24186 Mtetra
.636 .528 .714 r
.62488 .24186 .63137 .26325 .64342 .25589 .63696 .23571 Mtetra
.637 .538 .725 r
.63696 .23571 .64342 .25589 .65552 .24885 .64909 .22983 Mtetra
.634 .546 .738 r
.64909 .22983 .65552 .24885 .66766 .24223 .66129 .2244 Mtetra
.632 .557 .752 r
.66129 .2244 .66766 .24223 .67986 .23599 .67355 .21939 Mtetra
.629 .569 .768 r
.67355 .21939 .67986 .23599 .69212 .23006 .68588 .21478 Mtetra
.628 .586 .787 r
.68588 .21478 .69212 .23006 .70443 .22438 .69828 .21047 Mtetra
.629 .607 .809 r
.69828 .21047 .70443 .22438 .71679 .21888 .71076 .20638 Mtetra
.63 .633 .834 r
.71076 .20638 .71679 .21888 .72922 .21351 .7233 .20244 Mtetra
.632 .664 .863 r
.7233 .20244 .72922 .21351 .74169 .20823 .7359 .19859 Mtetra
.633 .7 .894 r
.7359 .19859 .74169 .20823 .75422 .20298 .74857 .19475 Mtetra
.722 .764 .886 r
.0807 .4217 .08813 .42819 .09813 .42408 .0909 .41622 Mtetra
.712 .726 .861 r
.0909 .41622 .09813 .42408 .10816 .42 .10113 .41075 Mtetra
.7 .69 .837 r
.10113 .41075 .10816 .42 .11822 .416 .11138 .40535 Mtetra
.686 .658 .816 r
.11138 .40535 .11822 .416 .12829 .41214 .12163 .40009 Mtetra
.672 .628 .798 r
.12163 .40009 .12829 .41214 .13837 .4085 .13189 .39505 Mtetra
.657 .601 .781 r
.13189 .39505 .13837 .4085 .14846 .40516 .14214 .39029 Mtetra
.641 .575 .765 r
.14214 .39029 .14846 .40516 .15854 .40221 .15238 .38593 Mtetra
.627 .552 .751 r
.15238 .38593 .15854 .40221 .16862 .39966 .16261 .38191 Mtetra
.614 .531 .737 r
.16261 .38191 .16862 .39966 .17869 .39756 .17285 .37824 Mtetra
.606 .513 .722 r
.17285 .37824 .17869 .39756 .18879 .39573 .1831 .37469 Mtetra
.602 .498 .708 r
.1831 .37469 .18879 .39573 .19892 .39405 .19341 .37109 Mtetra
.601 .485 .693 r
.19341 .37109 .19892 .39405 .20912 .3922 .20378 .36721 Mtetra
.602 .475 .68 r
.20378 .36721 .20912 .3922 .21942 .38991 .21424 .36284 Mtetra
.602 .466 .668 r
.21424 .36284 .21942 .38991 .22982 .38702 .22476 .35814 Mtetra
.6 .458 .659 r
.22476 .35814 .22982 .38702 .24033 .38335 .23535 .35318 Mtetra
.595 .449 .654 r
.23535 .35318 .24033 .38335 .25093 .37921 .24595 .34842 Mtetra
.587 .442 .651 r
.24595 .34842 .25093 .37921 .26159 .37475 .25654 .34414 Mtetra
.584 .44 .652 r
.25654 .34414 .26159 .37475 .2723 .37021 .26715 .34018 Mtetra
.582 .441 .655 r
.26715 .34018 .2723 .37021 .28303 .36578 .27778 .33644 Mtetra
.588 .448 .658 r
.27778 .33644 .28303 .36578 .29379 .36147 .28848 .33228 Mtetra
.597 .455 .659 r
.28848 .33228 .29379 .36147 .30457 .35747 .29927 .32747 Mtetra
.596 .451 .655 r
.29927 .32747 .30457 .35747 .31533 .35443 .3101 .32262 Mtetra
.586 .438 .648 r
.3101 .32262 .31533 .35443 .32605 .35287 .32094 .31826 Mtetra
.557 .41 .638 r
.32094 .31826 .32605 .35287 .33668 .3537 .33169 .31589 Mtetra
.525 .38 .626 r
.33169 .31589 .33668 .3537 .34726 .3569 .34235 .31592 Mtetra
.511 .363 .616 r
.34235 .31592 .34726 .3569 .35791 .36045 .35303 .31709 Mtetra
.509 .357 .61 r
.35303 .31709 .35791 .36045 .36869 .36314 .36377 .31851 Mtetra
.523 .365 .608 r
.36377 .31851 .36869 .36314 .37967 .3638 .37465 .31864 Mtetra
.543 .379 .608 r
.37465 .31864 .37967 .3638 .39082 .36189 .3857 .31673 Mtetra
.563 .393 .609 r
.3857 .31673 .39082 .36189 .40212 .35799 .39689 .31276 Mtetra
.581 .406 .61 r
.39689 .31276 .40212 .35799 .41353 .35207 .40821 .30672 Mtetra
.597 .418 .609 r
.40821 .30672 .41353 .35207 .42506 .34358 .41963 .29864 Mtetra
.608 .426 .61 r
.41963 .29864 .42506 .34358 .43666 .33302 .4311 .28924 Mtetra
.608 .428 .612 r
.4311 .28924 .43666 .33302 .44828 .32158 .44258 .28007 Mtetra
.603 .428 .618 r
.44258 .28007 .44828 .32158 .45989 .31046 .45404 .27204 Mtetra
.586 .423 .627 r
.45404 .27204 .45989 .31046 .47146 .30171 .46547 .26642 Mtetra
.57 .419 .638 r
.46547 .26642 .47146 .30171 .483 .29538 .47691 .26281 Mtetra
.567 .426 .649 r
.47691 .26281 .483 .29538 .49457 .29052 .48839 .25969 Mtetra
.57 .434 .657 r
.48839 .25969 .49457 .29052 .50617 .28664 .49993 .25654 Mtetra
.58 .444 .66 r
.49993 .25654 .50617 .28664 .51782 .28308 .51153 .25272 Mtetra
.585 .446 .659 r
.51153 .25272 .51782 .28308 .52953 .27964 .52318 .24848 Mtetra
.58 .44 .655 r
.52318 .24848 .52953 .27964 .54129 .27631 .53488 .24446 Mtetra
.575 .435 .653 r
.53488 .24446 .54129 .27631 .55311 .2729 .54664 .24076 Mtetra
.569 .43 .652 r
.54664 .24076 .55311 .2729 .56498 .26917 .55845 .23756 Mtetra
.567 .43 .655 r
.55845 .23756 .56498 .26917 .57689 .26494 .57033 .23456 Mtetra
.572 .439 .661 r
.57033 .23456 .57689 .26494 .58884 .25992 .58226 .23129 Mtetra
.579 .451 .67 r
.58226 .23129 .58884 .25992 .60083 .25427 .59425 .22768 Mtetra
.59 .467 .681 r
.59425 .22768 .60083 .25427 .61284 .24816 .60627 .22357 Mtetra
.599 .484 .694 r
.60627 .22357 .61284 .24816 .62488 .24186 .61835 .21917 Mtetra
.605 .5 .708 r
.61835 .21917 .62488 .24186 .63696 .23571 .63047 .21472 Mtetra
.608 .514 .722 r
.63047 .21472 .63696 .23571 .64909 .22983 .64265 .21038 Mtetra
.607 .526 .738 r
.64265 .21038 .64909 .22983 .66129 .2244 .6549 .2064 Mtetra
.604 .54 .755 r
.6549 .2064 .66129 .2244 .67355 .21939 .66723 .20277 Mtetra
.6 .553 .774 r
.66723 .20277 .67355 .21939 .68588 .21478 .67963 .19955 Mtetra
.596 .57 .795 r
.67963 .19955 .68588 .21478 .69828 .21047 .69212 .19663 Mtetra
.593 .59 .818 r
.69212 .19663 .69828 .21047 .71076 .20638 .70469 .19394 Mtetra
.59 .615 .845 r
.70469 .19394 .71076 .20638 .7233 .20244 .71734 .19139 Mtetra
.587 .644 .874 r
.71734 .19139 .7233 .20244 .7359 .19859 .73007 .18893 Mtetra
.584 .678 .905 r
.73007 .18893 .7359 .19859 .74857 .19475 .74288 .18646 Mtetra
.746 .767 .87 r
.07322 .41517 .0807 .4217 .0909 .41622 .08358 .40872 Mtetra
.738 .741 .854 r
.08358 .40872 .0909 .41622 .10113 .41075 .09396 .40226 Mtetra
.728 .716 .839 r
.09396 .40226 .10113 .41075 .11138 .40535 .10435 .39586 Mtetra
.717 .692 .825 r
.10435 .39586 .11138 .40535 .12163 .40009 .11475 .38958 Mtetra
.705 .669 .812 r
.11475 .38958 .12163 .40009 .13189 .39505 .12515 .38348 Mtetra
.692 .646 .799 r
.12515 .38348 .13189 .39505 .14214 .39029 .13554 .37763 Mtetra
.678 .623 .787 r
.13554 .37763 .14214 .39029 .15238 .38593 .14592 .37209 Mtetra
.666 .601 .774 r
.14592 .37209 .15238 .38593 .16261 .38191 .15631 .36678 Mtetra
.654 .58 .76 r
.15631 .36678 .16261 .38191 .17285 .37824 .16669 .36167 Mtetra
.647 .561 .744 r
.16669 .36167 .17285 .37824 .1831 .37469 .17712 .35651 Mtetra
.643 .544 .728 r
.17712 .35651 .1831 .37469 .19341 .37109 .18759 .35114 Mtetra
.64 .529 .712 r
.18759 .35114 .19341 .37109 .20378 .36721 .19813 .34548 Mtetra
.638 .516 .698 r
.19813 .34548 .20378 .36721 .21424 .36284 .20873 .33944 Mtetra
.63 .501 .687 r
.20873 .33944 .21424 .36284 .22476 .35814 .21936 .33344 Mtetra
.621 .489 .68 r
.21936 .33344 .22476 .35814 .23535 .35318 .22997 .32778 Mtetra
.607 .476 .677 r
.22997 .32778 .23535 .35318 .24595 .34842 .24055 .32295 Mtetra
.589 .465 .678 r
.24055 .32295 .24595 .34842 .25654 .34414 .25105 .31927 Mtetra
.581 .463 .683 r
.25105 .31927 .25654 .34414 .26715 .34018 .26155 .31619 Mtetra
.58 .467 .689 r
.26155 .31619 .26715 .34018 .27778 .33644 .27208 .31331 Mtetra
.597 .483 .694 r
.27208 .31331 .27778 .33644 .28848 .33228 .28273 .30948 Mtetra
.623 .501 .694 r
.28273 .30948 .28848 .33228 .29927 .32747 .29353 .3041 Mtetra
.634 .506 .689 r
.29353 .3041 .29927 .32747 .3101 .32262 .30444 .29774 Mtetra
.635 .498 .679 r
.30444 .29774 .3101 .32262 .32094 .31826 .31541 .29092 Mtetra
.608 .47 .667 r
.31541 .29092 .32094 .31826 .33169 .31589 .32631 .28549 Mtetra
.573 .434 .654 r
.32631 .28549 .33169 .31589 .34235 .31592 .33711 .2822 Mtetra
.548 .406 .64 r
.33711 .2822 .34235 .31592 .35303 .31709 .34787 .28047 Mtetra
.533 .388 .63 r
.34787 .28047 .35303 .31709 .36377 .31851 .35864 .27974 Mtetra
.538 .387 .623 r
.35864 .27974 .36377 .31851 .37465 .31864 .3695 .27851 Mtetra
.551 .393 .62 r
.3695 .27851 .37465 .31864 .3857 .31673 .38049 .27604 Mtetra
.567 .403 .619 r
.38049 .27604 .3857 .31673 .39689 .31276 .39159 .27201 Mtetra
.582 .414 .619 r
.39159 .27201 .39689 .31276 .40821 .30672 .4028 .26643 Mtetra
.594 .423 .62 r
.4028 .26643 .40821 .30672 .41963 .29864 .4141 .25959 Mtetra
.601 .431 .623 r
.4141 .25959 .41963 .29864 .4311 .28924 .42543 .25224 Mtetra
.595 .431 .63 r
.42543 .25224 .4311 .28924 .44258 .28007 .43676 .24589 Mtetra
.584 .431 .64 r
.43676 .24589 .44258 .28007 .45404 .27204 .44808 .2411 Mtetra
.562 .427 .654 r
.44808 .2411 .45404 .27204 .46547 .26642 .4594 .23847 Mtetra
.545 .428 .671 r
.4594 .23847 .46547 .26642 .47691 .26281 .47075 .23726 Mtetra
.555 .447 .686 r
.47075 .23726 .47691 .26281 .48839 .25969 .48217 .23558 Mtetra
.573 .467 .695 r
.48217 .23558 .48839 .25969 .49993 .25654 .49367 .23292 Mtetra
.6 .487 .697 r
.49367 .23292 .49993 .25654 .51153 .25272 .50525 .22868 Mtetra
.613 .493 .692 r
.50525 .22868 .51153 .25272 .52318 .24848 .51687 .22348 Mtetra
.607 .484 .687 r
.51687 .22348 .52318 .24848 .53488 .24446 .52854 .21847 Mtetra
.595 .472 .682 r
.52854 .21847 .53488 .24446 .54664 .24076 .54025 .21406 Mtetra
.577 .456 .679 r
.54025 .21406 .54664 .24076 .55845 .23756 .55202 .21084 Mtetra
.564 .448 .68 r
.55202 .21084 .55845 .23756 .57033 .23456 .56386 .20847 Mtetra
.559 .449 .685 r
.56386 .20847 .57033 .23456 .58226 .23129 .57578 .20644 Mtetra
.56 .457 .694 r
.57578 .20644 .58226 .23129 .59425 .22768 .58776 .20446 Mtetra
.569 .473 .706 r
.58776 .20446 .59425 .22768 .60627 .22357 .59981 .2021 Mtetra
.577 .491 .721 r
.59981 .2021 .60627 .22357 .61835 .21917 .61191 .19944 Mtetra
.585 .51 .737 r
.61191 .19944 .61835 .21917 .63047 .21472 .62408 .19656 Mtetra
.589 .528 .755 r
.62408 .19656 .63047 .21472 .64265 .21038 .63631 .19363 Mtetra
.588 .544 .773 r
.63631 .19363 .64265 .21038 .6549 .2064 .64861 .19091 Mtetra
.584 .559 .792 r
.64861 .19091 .6549 .2064 .66723 .20277 .66099 .18843 Mtetra
.577 .573 .812 r
.66099 .18843 .66723 .20277 .67963 .19955 .67346 .18628 Mtetra
.57 .588 .832 r
.67346 .18628 .67963 .19955 .69212 .19663 .68602 .18439 Mtetra
.563 .605 .853 r
.68602 .18439 .69212 .19663 .70469 .19394 .69867 .18269 Mtetra
.556 .624 .874 r
.69867 .18269 .70469 .19394 .71734 .19139 .7114 .18112 Mtetra
.55 .645 .897 r
.7114 .18112 .71734 .19139 .73007 .18893 .72423 .17961 Mtetra
.543 .669 .919 r
.72423 .17961 .73007 .18893 .74288 .18646 .73713 .1781 Mtetra
.756 .768 .862 r
.06568 .40859 .07322 .41517 .08358 .40872 .07613 .40164 Mtetra
.752 .755 .855 r
.07613 .40164 .08358 .40872 .09396 .40226 .08661 .39468 Mtetra
.747 .742 .848 r
.08661 .39468 .09396 .40226 .10435 .39586 .09709 .38775 Mtetra
.741 .729 .841 r
.09709 .38775 .10435 .39586 .11475 .38958 .10759 .38091 Mtetra
.733 .715 .835 r
.10759 .38091 .11475 .38958 .12515 .38348 .11808 .37422 Mtetra
.724 .701 .828 r
.11808 .37422 .12515 .38348 .13554 .37763 .12858 .36768 Mtetra
.714 .684 .82 r
.12858 .36768 .13554 .37763 .14592 .37209 .13907 .36135 Mtetra
.706 .667 .81 r
.13907 .36135 .14592 .37209 .15631 .36678 .14957 .35511 Mtetra
.698 .649 .797 r
.14957 .35511 .15631 .36678 .16669 .36167 .1601 .34889 Mtetra
.693 .63 .781 r
.1601 .34889 .16669 .36167 .17712 .35651 .17066 .3425 Mtetra
.691 .613 .764 r
.17066 .3425 .17712 .35651 .18759 .35114 .18129 .33576 Mtetra
.685 .594 .748 r
.18129 .33576 .18759 .35114 .19813 .34548 .19196 .32879 Mtetra
.68 .579 .735 r
.19196 .32879 .19813 .34548 .20873 .33944 .20268 .32163 Mtetra
.666 .561 .727 r
.20268 .32163 .20873 .33944 .21936 .33344 .21336 .31491 Mtetra
.648 .545 .724 r
.21336 .31491 .21936 .33344 .22997 .32778 .22399 .30909 Mtetra
.623 .53 .728 r
.22399 .30909 .22997 .32778 .24055 .32295 .23451 .30461 Mtetra
.591 .514 .737 r
.23451 .30461 .24055 .32295 .25105 .31927 .24493 .3018 Mtetra
.576 .515 .749 r
.24493 .3018 .25105 .31927 .26155 .31619 .25533 .29972 Mtetra
.576 .526 .762 r
.25533 .29972 .26155 .31619 .27208 .31331 .26577 .29772 Mtetra
.613 .557 .768 r
.26577 .29772 .27208 .31331 .28273 .30948 .27638 .29429 Mtetra
.663 .589 .762 r
.27638 .29429 .28273 .30948 .29353 .3041 .28722 .28859 Mtetra
.692 .6 .749 r
.28722 .28859 .29353 .3041 .30444 .29774 .29821 .28111 Mtetra
.703 .595 .732 r
.29821 .28111 .30444 .29774 .31541 .29092 .30931 .27235 Mtetra
.68 .565 .719 r
.30931 .27235 .31541 .29092 .32631 .28549 .32037 .26436 Mtetra
.641 .524 .705 r
.32037 .26436 .32631 .28549 .33711 .2822 .33133 .25811 Mtetra
.604 .483 .687 r
.33133 .25811 .33711 .2822 .34787 .28047 .34223 .25355 Mtetra
.575 .45 .672 r
.34223 .25355 .34787 .28047 .35864 .27974 .35308 .25047 Mtetra
.568 .435 .66 r
.35308 .25047 .35864 .27974 .3695 .27851 .36397 .2476 Mtetra
.571 .431 .652 r
.36397 .2476 .3695 .27851 .38049 .27604 .37493 .24433 Mtetra
.579 .434 .648 r
.37493 .24433 .38049 .27604 .39159 .27201 .38598 .24025 Mtetra
.589 .441 .648 r
.38598 .24025 .39159 .27201 .4028 .26643 .39711 .23537 Mtetra
.595 .448 .651 r
.39711 .23537 .4028 .26643 .4141 .25959 .40829 .23008 Mtetra
.596 .454 .658 r
.40829 .23008 .4141 .25959 .42543 .25224 .4195 .225 Mtetra
.581 .454 .672 r
.4195 .225 .42543 .25224 .43676 .24589 .43071 .22141 Mtetra
.559 .454 .691 r
.43071 .22141 .43676 .24589 .44808 .2411 .44192 .21952 Mtetra
.526 .453 .717 r
.44192 .21952 .44808 .2411 .4594 .23847 .45315 .2194 Mtetra
.506 .463 .743 r
.45315 .2194 .4594 .23847 .47075 .23726 .46444 .22006 Mtetra
.537 .503 .765 r
.46444 .22006 .47075 .23726 .48217 .23558 .47584 .21944 Mtetra
.584 .543 .775 r
.47584 .21944 .48217 .23558 .49367 .23292 .48734 .21703 Mtetra
.636 .575 .769 r
.48734 .21703 .49367 .23292 .50525 .22868 .49891 .2123 Mtetra
.662 .583 .757 r
.49891 .2123 .50525 .22868 .51687 .22348 .51054 .20613 Mtetra
.655 .57 .747 r
.51054 .20613 .51687 .22348 .52854 .21847 .52221 .20002 Mtetra
.636 .549 .739 r
.52221 .20002 .52854 .21847 .54025 .21406 .53391 .19466 Mtetra
.601 .52 .735 r
.53391 .19466 .54025 .21406 .55202 .21084 .54567 .19099 Mtetra
.572 .5 .735 r
.54567 .19099 .55202 .21084 .56386 .20847 .55749 .1887 Mtetra
.553 .489 .738 r
.55749 .1887 .56386 .20847 .57578 .20644 .5694 .18733 Mtetra
.543 .49 .746 r
.5694 .18733 .57578 .20644 .58776 .20446 .58139 .18642 Mtetra
.548 .505 .759 r
.58139 .18642 .58776 .20446 .59981 .2021 .59346 .18532 Mtetra
.554 .523 .776 r
.59346 .18532 .59981 .2021 .61191 .19944 .60559 .18399 Mtetra
.563 .547 .794 r
.60559 .18399 .61191 .19944 .62408 .19656 .6178 .18231 Mtetra
.569 .569 .813 r
.6178 .18231 .62408 .19656 .63631 .19363 .63007 .18046 Mtetra
.568 .587 .833 r
.63007 .18046 .63631 .19363 .64861 .19091 .64243 .17863 Mtetra
.564 .603 .851 r
.64243 .17863 .64861 .19091 .66099 .18843 .65486 .1769 Mtetra
.555 .615 .868 r
.65486 .1769 .66099 .18843 .67346 .18628 .66738 .17539 Mtetra
.546 .626 .883 r
.66738 .17539 .67346 .18628 .68602 .18439 .67999 .17405 Mtetra
.537 .636 .897 r
.67999 .17405 .68602 .18439 .69867 .18269 .69269 .17286 Mtetra
.529 .647 .909 r
.69269 .17286 .69867 .18269 .7114 .18112 .70549 .17177 Mtetra
.522 .658 .921 r
.70549 .17177 .7114 .18112 .72423 .17961 .71837 .17073 Mtetra
.517 .67 .932 r
.71837 .17073 .72423 .17961 .73713 .1781 .73134 .16968 Mtetra
.752 .767 .866 r
.05808 .40196 .06568 .40859 .07613 .40164 .06854 .39519 Mtetra
.754 .774 .869 r
.06854 .39519 .07613 .40164 .08661 .39468 .07901 .38841 Mtetra
.755 .78 .873 r
.07901 .38841 .08661 .39468 .09709 .38775 .08951 .38164 Mtetra
.755 .785 .878 r
.08951 .38164 .09709 .38775 .10759 .38091 .10002 .37492 Mtetra
.753 .789 .882 r
.10002 .37492 .10759 .38091 .11808 .37422 .11053 .36828 Mtetra
.752 .792 .885 r
.11053 .36828 .11808 .37422 .12858 .36768 .12106 .36172 Mtetra
.749 .792 .888 r
.12106 .36172 .12858 .36768 .13907 .36135 .1316 .35526 Mtetra
.749 .789 .885 r
.1316 .35526 .13907 .36135 .14957 .35511 .14216 .34876 Mtetra
.75 .783 .879 r
.14216 .34876 .14957 .35511 .1601 .34889 .15276 .34214 Mtetra
.753 .772 .869 r
.15276 .34214 .1601 .34889 .17066 .3425 .16341 .33526 Mtetra
.757 .761 .855 r
.16341 .33526 .17066 .3425 .18129 .33576 .17412 .32799 Mtetra
.755 .748 .846 r
.17412 .32799 .18129 .33576 .19196 .32879 .18487 .3206 Mtetra
.75 .737 .84 r
.18487 .3206 .19196 .32879 .20268 .32163 .19563 .31323 Mtetra
.733 .729 .848 r
.19563 .31323 .20268 .32163 .21336 .31491 .20633 .30662 Mtetra
.701 .725 .868 r
.20633 .30662 .21336 .31491 .22399 .30909 .21693 .30131 Mtetra
.651 .725 .903 r
.21693 .30131 .22399 .30909 .23451 .30461 .2274 .29762 Mtetra
.562 .719 .946 r
.2274 .29762 .23451 .30461 .24493 .3018 .23774 .2958 Mtetra
.5 .73 .976 r
.23774 .2958 .24493 .3018 .25533 .29972 .24807 .2947 Mtetra
.481 .759 .992 r
.24807 .2947 .25533 .29972 .26577 .29772 .25848 .2935 Mtetra
.584 .828 .991 r
.25848 .2935 .26577 .29772 .27638 .29429 .26908 .29059 Mtetra
.718 .879 .956 r
.26908 .29059 .27638 .29429 .28722 .28859 .27994 .28503 Mtetra
.792 .888 .914 r
.27994 .28503 .28722 .28859 .29821 .28111 .291 .27725 Mtetra
.83 .875 .877 r
.291 .27725 .29821 .28111 .30931 .27235 .3022 .26772 Mtetra
.82 .854 .874 r
.3022 .26772 .30931 .27235 .32037 .26436 .31339 .25846 Mtetra
.783 .816 .879 r
.31339 .25846 .32037 .26436 .33133 .25811 .32451 .2505 Mtetra
.731 .76 .876 r
.32451 .2505 .33133 .25811 .34223 .25355 .33554 .24414 Mtetra
.674 .697 .864 r
.33554 .24414 .34223 .25355 .35308 .25047 .3465 .23943 Mtetra
.647 .651 .84 r
.3465 .23943 .35308 .25047 .36397 .2476 .35747 .23535 Mtetra
.636 .623 .82 r
.35747 .23535 .36397 .2476 .37493 .24433 .36847 .23146 Mtetra
.639 .614 .809 r
.36847 .23146 .37493 .24433 .38598 .24025 .37953 .22735 Mtetra
.644 .617 .808 r
.37953 .22735 .38598 .24025 .39711 .23537 .39064 .22302 Mtetra
.642 .626 .819 r
.39064 .22302 .39711 .23537 .40829 .23008 .40179 .21887 Mtetra
.628 .642 .845 r
.40179 .21887 .40829 .23008 .4195 .225 .41296 .21537 Mtetra
.57 .654 .893 r
.41296 .21537 .4195 .225 .43071 .22141 .42413 .21352 Mtetra
.471 .66 .944 r
.42413 .21352 .43071 .22141 .44192 .21952 .43531 .21329 Mtetra
.325 .643 .966 r
.43531 .21329 .44192 .21952 .45315 .2194 .44654 .21439 Mtetra
.236 .637 .959 r
.44654 .21439 .45315 .2194 .46444 .22006 .45785 .21577 Mtetra
.362 .737 .988 r
.45785 .21577 .46444 .22006 .47584 .21944 .46928 .21539 Mtetra
.532 .829 .999 r
.46928 .21539 .47584 .21944 .48734 .21703 .48081 .21278 Mtetra
.689 .877 .969 r
.48081 .21278 .48734 .21703 .49891 .2123 .49244 .20747 Mtetra
.757 .872 .931 r
.49244 .20747 .49891 .2123 .51054 .20613 .50413 .20043 Mtetra
.758 .845 .917 r
.50413 .20043 .51054 .20613 .52221 .20002 .51584 .19326 Mtetra
.732 .807 .911 r
.51584 .19326 .52221 .20002 .53391 .19466 .52758 .18683 Mtetra
.666 .754 .916 r
.52758 .18683 .53391 .19466 .54567 .19099 .53936 .18229 Mtetra
.603 .704 .915 r
.53936 .18229 .54567 .19099 .55749 .1887 .55121 .17941 Mtetra
.549 .663 .912 r
.55121 .17941 .55749 .1887 .5694 .18733 .56314 .17787 Mtetra
.515 .642 .912 r
.56314 .17787 .5694 .18733 .58139 .18642 .57515 .1771 Mtetra
.511 .645 .917 r
.57515 .1771 .58139 .18642 .59346 .18532 .58725 .17637 Mtetra
.512 .658 .925 r
.58725 .17637 .59346 .18532 .60559 .18399 .59943 .17552 Mtetra
.526 .68 .936 r
.59943 .17552 .60559 .18399 .6178 .18231 .61168 .17428 Mtetra
.532 .698 .945 r
.61168 .17428 .6178 .18231 .63007 .18046 .624 .17278 Mtetra
.533 .711 .954 r
.624 .17278 .63007 .18046 .64243 .17863 .63639 .17115 Mtetra
.531 .718 .959 r
.63639 .17115 .64243 .17863 .65486 .1769 .64886 .16949 Mtetra
.524 .718 .961 r
.64886 .16949 .65486 .1769 .66738 .17539 .66142 .16794 Mtetra
.519 .715 .961 r
.66142 .16794 .66738 .17539 .67999 .17405 .67406 .16647 Mtetra
.515 .71 .96 r
.67406 .16647 .67999 .17405 .69269 .17286 .68679 .1651 Mtetra
.514 .704 .956 r
.68679 .1651 .69269 .17286 .70549 .17177 .69961 .16378 Mtetra
.516 .699 .952 r
.69961 .16378 .70549 .17177 .71837 .17073 .71251 .16249 Mtetra
.519 .693 .947 r
.71251 .16249 .71837 .17073 .73134 .16968 .7255 .16118 Mtetra
.734 .766 .878 r
.05043 .39529 .05808 .40196 .06854 .39519 .06081 .38922 Mtetra
.74 .788 .891 r
.06081 .38922 .06854 .39519 .07901 .38841 .07122 .38314 Mtetra
.744 .81 .905 r
.07122 .38314 .07901 .38841 .08951 .38164 .08165 .37704 Mtetra
.746 .833 .918 r
.08165 .37704 .08951 .38164 .10002 .37492 .0921 .37096 Mtetra
.747 .855 .93 r
.0921 .37096 .10002 .37492 .11053 .36828 .10258 .3649 Mtetra
.746 .875 .939 r
.10258 .3649 .11053 .36828 .12106 .36172 .11308 .35884 Mtetra
.745 .893 .946 r
.11308 .35884 .12106 .36172 .1316 .35526 .1236 .35278 Mtetra
.747 .906 .948 r
.1236 .35278 .1316 .35526 .14216 .34876 .13417 .34658 Mtetra
.753 .917 .946 r
.13417 .34658 .14216 .34876 .15276 .34214 .14479 .34015 Mtetra
.761 .924 .942 r
.14479 .34015 .15276 .34214 .16341 .33526 .15546 .33345 Mtetra
.773 .929 .936 r
.15546 .33345 .16341 .33526 .17412 .32799 .1662 .32637 Mtetra
.77 .936 .937 r
.1662 .32637 .17412 .32799 .18487 .3206 .17696 .31929 Mtetra
.756 .945 .942 r
.17696 .31929 .18487 .3206 .19563 .31323 .18771 .31244 Mtetra
.697 .953 .953 r
.18771 .31244 .19563 .31323 .20633 .30662 .19839 .30654 Mtetra
.552 .923 .936 r
.19839 .30654 .20633 .30662 .21693 .30131 .20894 .30213 Mtetra
.298 .794 .819 r
.20894 .30213 .21693 .30131 .2274 .29762 .21937 .29937 Mtetra
.014 0 0 r
.21937 .29937 .2274 .29762 .23774 .2958 .22968 .29839 Mtetra
.137 0 0 r
.22968 .29839 .23774 .2958 .24807 .2947 .24 .29796 Mtetra
.141 0 0 r
.24 .29796 .24807 .2947 .25848 .2935 .25041 .29719 Mtetra
0 0 0 r
.25041 .29719 .25848 .2935 .26908 .29059 .26105 .29456 Mtetra
.316 .776 .636 r
.26105 .29456 .26908 .29059 .27994 .28503 .27196 .28914 Mtetra
.529 .899 .709 r
.27196 .28914 .27994 .28503 .291 .27725 .2831 .28136 Mtetra
.668 .96 .743 r
.2831 .28136 .291 .27725 .3022 .26772 .29439 .27164 Mtetra
.683 .966 .751 r
.29439 .27164 .3022 .26772 .31339 .25846 .3057 .26181 Mtetra
.654 .961 .771 r
.3057 .26181 .31339 .25846 .32451 .2505 .31695 .25289 Mtetra
.612 .953 .811 r
.31695 .25289 .32451 .2505 .33554 .24414 .32812 .24539 Mtetra
.558 .935 .86 r
.32812 .24539 .33554 .24414 .3465 .23943 .33921 .23948 Mtetra
.555 .929 .916 r
.33921 .23948 .3465 .23943 .35747 .23535 .35028 .23447 Mtetra
.556 .919 .951 r
.35028 .23447 .35747 .23535 .36847 .23146 .36136 .23007 Mtetra
.558 .91 .966 r
.36136 .23007 .36847 .23146 .37953 .22735 .37247 .22593 Mtetra
.534 .901 .965 r
.37247 .22593 .37953 .22735 .39064 .22302 .38361 .22206 Mtetra
.449 .87 .938 r
.38361 .22206 .39064 .22302 .40179 .21887 .39477 .21879 Mtetra
.281 .783 .847 r
.39477 .21879 .40179 .21887 .41296 .21537 .40596 .21644 Mtetra
.002 0 0 r
.40596 .21644 .41296 .21537 .42413 .21352 .41714 .21569 Mtetra
.216 0 0 r
.41714 .21569 .42413 .21352 .43531 .21329 .42835 .21638 Mtetra
.328 0 0 r
.42835 .21638 .43531 .21329 .44654 .21439 .43962 .218 Mtetra
.337 0 0 r
.43962 .218 .44654 .21439 .45785 .21577 .45098 .21953 Mtetra
.202 0 0 r
.45098 .21953 .45785 .21577 .46928 .21539 .46248 .21911 Mtetra
0 0 0 r
.46248 .21911 .46928 .21539 .48081 .21278 .47409 .21631 Mtetra
.47409 .21631 .48081 .21278 .49244 .20747 .48581 .21067 Mtetra
.469 .867 .689 r
.48581 .21067 .49244 .20747 .50413 .20043 .49757 .20314 Mtetra
.53 .905 .731 r
.49757 .20314 .50413 .20043 .51584 .19326 .50937 .19525 Mtetra
.54 .918 .776 r
.50937 .19525 .51584 .19326 .52758 .18683 .52119 .1879 Mtetra
.46 .886 .816 r
.52119 .1879 .52758 .18683 .53936 .18229 .53304 .18236 Mtetra
.384 .847 .858 r
.53304 .18236 .53936 .18229 .55121 .17941 .54494 .17851 Mtetra
.311 .797 .89 r
.54494 .17851 .55121 .17941 .56314 .17787 .55692 .17619 Mtetra
.272 .762 .912 r
.55692 .17619 .56314 .17787 .57515 .1771 .56898 .17484 Mtetra
.29 .761 .938 r
.56898 .17484 .57515 .1771 .58725 .17637 .58112 .17373 Mtetra
.315 .767 .955 r
.58112 .17373 .58725 .17637 .59943 .17552 .59334 .17262 Mtetra
.363 .79 .972 r
.59334 .17262 .59943 .17552 .61168 .17428 .60564 .17114 Mtetra
.399 .804 .982 r
.60564 .17114 .61168 .17428 .624 .17278 .618 .16938 Mtetra
.43 .813 .99 r
.618 .16938 .624 .17278 .63639 .17115 .63043 .16739 Mtetra
.456 .816 .996 r
.63043 .16739 .63639 .17115 .64886 .16949 .64294 .16526 Mtetra
.475 .81 .999 r
.64294 .16526 .64886 .16949 .66142 .16794 .65552 .16313 Mtetra
.494 .8 .999 r
.65552 .16313 .66142 .16794 .67406 .16647 .66818 .161 Mtetra
.51 .785 .995 r
.66818 .161 .67406 .16647 .68679 .1651 .68092 .1589 Mtetra
.525 .767 .985 r
.68092 .1589 .68679 .1651 .69961 .16378 .69374 .15681 Mtetra
.538 .747 .972 r
.69374 .15681 .69961 .16378 .71251 .16249 .70664 .15472 Mtetra
.549 .726 .956 r
.70664 .15472 .71251 .16249 .7255 .16118 .71961 .15261 Mtetra
.7 .761 .899 r
.04273 .38856 .05043 .39529 .06081 .38922 .05296 .38367 Mtetra
.705 .799 .923 r
.05296 .38367 .06081 .38922 .07122 .38314 .06322 .37875 Mtetra
.706 .838 .945 r
.06322 .37875 .07122 .38314 .08165 .37704 .07353 .3738 Mtetra
.702 .877 .963 r
.07353 .3738 .08165 .37704 .0921 .37096 .08386 .36882 Mtetra
.688 .911 .972 r
.08386 .36882 .0921 .37096 .10258 .3649 .09423 .36382 Mtetra
.665 .935 .968 r
.09423 .36382 .10258 .3649 .11308 .35884 .10465 .35876 Mtetra
.632 .947 .948 r
.10465 .35876 .11308 .35884 .1236 .35278 .1151 .35362 Mtetra
.596 .946 .914 r
.1151 .35362 .1236 .35278 .13417 .34658 .1256 .34832 Mtetra
.56 .935 .868 r
.1256 .34832 .13417 .34658 .14479 .34015 .13616 .34278 Mtetra
.514 .912 .811 r
.13616 .34278 .14479 .34015 .15546 .33345 .14678 .33703 Mtetra
.461 .875 .741 r
.14678 .33703 .15546 .33345 .1662 .32637 .15746 .33103 Mtetra
.355 .796 .635 r
.15746 .33103 .1662 .32637 .17696 .31929 .16815 .32514 Mtetra
0 0 0 r
.16815 .32514 .17696 .31929 .18771 .31244 .17882 .31962 Mtetra
.17882 .31962 .18771 .31244 .19839 .30654 .18943 .31501 Mtetra
.156 0 0 r
.18943 .31501 .19839 .30654 .20894 .30213 .19994 .31176 Mtetra
.279 0 0 r
.19994 .31176 .20894 .30213 .21937 .29937 .21036 .30981 Mtetra
.361 0 .036 r
.21036 .30981 .21937 .29937 .22968 .29839 .22071 .30912 Mtetra
.369 0 .048 r
.22071 .30912 .22968 .29839 .24 .29796 .23112 .30853 Mtetra
.329 0 .018 r
.23112 .30853 .24 .29796 .25041 .29719 .24167 .30716 Mtetra
.204 0 0 r
.24167 .30716 .25041 .29719 .26105 .29456 .25245 .30378 Mtetra
0 0 0 r
.25245 .30378 .26105 .29456 .27196 .28914 .26351 .29763 Mtetra
.26351 .29763 .27196 .28914 .2831 .28136 .27478 .2892 Mtetra
.27478 .2892 .2831 .28136 .29439 .27164 .28621 .27892 Mtetra
.496 .831 .539 r
.28621 .27892 .29439 .27164 .3057 .26181 .29765 .26841 Mtetra
.484 .833 .561 r
.29765 .26841 .3057 .26181 .31695 .25289 .30905 .25865 Mtetra
.437 .819 .58 r
.30905 .25865 .31695 .25289 .32812 .24539 .32036 .25018 Mtetra
0 0 0 r
.32036 .25018 .32812 .24539 .33921 .23948 .33159 .2433 Mtetra
.333 .785 .639 r
.33159 .2433 .33921 .23948 .35028 .23447 .34277 .23754 Mtetra
.297 .773 .667 r
.34277 .23754 .35028 .23447 .36136 .23007 .35394 .23271 Mtetra
.257 .752 .675 r
.35394 .23271 .36136 .23007 .37247 .22593 .36512 .22855 Mtetra
0 0 0 r
.36512 .22855 .37247 .22593 .38361 .22206 .3763 .22506 Mtetra
.3763 .22506 .38361 .22206 .39477 .21879 .3875 .2225 Mtetra
.109 0 0 r
.3875 .2225 .39477 .21879 .40596 .21644 .39871 .22107 Mtetra
.279 0 0 r
.39871 .22107 .40596 .21644 .41714 .21569 .40992 .22124 Mtetra
.384 0 0 r
.40992 .22124 .41714 .21569 .42835 .21638 .42118 .22275 Mtetra
.434 0 0 r
.42118 .22275 .42835 .21638 .43962 .218 .43249 .22501 Mtetra
.432 0 0 r
.43249 .22501 .43962 .218 .45098 .21953 .44392 .22706 Mtetra
.353 0 0 r
.44392 .22706 .45098 .21953 .46248 .21911 .45548 .22727 Mtetra
.245 0 0 r
.45548 .22727 .46248 .21911 .47409 .21631 .46717 .22516 Mtetra
.104 0 0 r
.46717 .22516 .47409 .21631 .48581 .21067 .47897 .22024 Mtetra
.011 0 0 r
.47897 .22024 .48581 .21067 .49757 .20314 .49084 .21328 Mtetra
0 0 0 r
.49084 .21328 .49757 .20314 .50937 .19525 .50274 .20552 Mtetra
.006 0 0 r
.50274 .20552 .50937 .19525 .52119 .1879 .51468 .19783 Mtetra
.07 0 0 r
.51468 .19783 .52119 .1879 .53304 .18236 .52663 .19143 Mtetra
.115 0 0 r
.52663 .19143 .53304 .18236 .54494 .17851 .53863 .18636 Mtetra
.152 0 0 r
.53863 .18636 .54494 .17851 .55692 .17619 .55069 .18266 Mtetra
.157 0 0 r
.55069 .18266 .55692 .17619 .56898 .17484 .56282 .17991 Mtetra
.121 0 0 r
.56282 .17991 .56898 .17484 .58112 .17373 .57502 .17753 Mtetra
.062 0 0 r
.57502 .17753 .58112 .17373 .59334 .17262 .5873 .17527 Mtetra
0 0 0 r
.5873 .17527 .59334 .17262 .60564 .17114 .59965 .17276 Mtetra
.59965 .17276 .60564 .17114 .618 .16938 .61206 .17003 Mtetra
.227 .746 .764 r
.61206 .17003 .618 .16938 .63043 .16739 .62453 .16705 Mtetra
.32 .807 .854 r
.62453 .16705 .63043 .16739 .64294 .16526 .63706 .16391 Mtetra
.399 .846 .923 r
.63706 .16391 .64294 .16526 .65552 .16313 .64966 .16068 Mtetra
.469 .863 .972 r
.64966 .16068 .65552 .16313 .66818 .161 .66233 .1574 Mtetra
.522 .858 .995 r
.66233 .1574 .66818 .161 .68092 .1589 .67506 .15409 Mtetra
.562 .836 .997 r
.67506 .15409 .68092 .1589 .69374 .15681 .68787 .15075 Mtetra
.587 .804 .982 r
.68787 .15075 .69374 .15681 .70664 .15472 .70074 .14738 Mtetra
.602 .767 .959 r
.70074 .14738 .70664 .15472 .71961 .15261 .71368 .14397 Mtetra
.648 .749 .924 r
.03496 .38178 .04273 .38856 .05296 .38367 .04501 .37829 Mtetra
.646 .795 .954 r
.04501 .37829 .05296 .38367 .06322 .37875 .05509 .37475 Mtetra
.636 .841 .979 r
.05509 .37475 .06322 .37875 .07353 .3738 .06523 .37116 Mtetra
.613 .881 .99 r
.06523 .37116 .07353 .3738 .08386 .36882 .07542 .36751 Mtetra
.571 .905 .978 r
.07542 .36751 .08386 .36882 .09423 .36382 .08565 .36379 Mtetra
.51 .904 .935 r
.08565 .36379 .09423 .36382 .10465 .35876 .09594 .35997 Mtetra
.433 .874 .861 r
.09594 .35997 .10465 .35876 .1151 .35362 .10628 .35605 Mtetra
.35 .821 .764 r
.10628 .35605 .1151 .35362 .1256 .34832 .11668 .35196 Mtetra
.269 .754 .655 r
.11668 .35196 .1256 .34832 .13616 .34278 .12714 .34768 Mtetra
0 0 0 r
.12714 .34768 .13616 .34278 .14678 .33703 .13766 .34326 Mtetra
.13766 .34326 .14678 .33703 .15746 .33103 .14823 .33873 Mtetra
.017 0 0 r
.14823 .33873 .15746 .33103 .16815 .32514 .15881 .33437 Mtetra
.122 0 0 r
.15881 .33437 .16815 .32514 .17882 .31962 .16939 .3304 Mtetra
.223 0 0 r
.16939 .3304 .17882 .31962 .18943 .31501 .17993 .32715 Mtetra
.306 0 .038 r
.17993 .32715 .18943 .31501 .19994 .31176 .19042 .32489 Mtetra
.356 0 .089 r
.19042 .32489 .19994 .31176 .21036 .30981 .20088 .32341 Mtetra
.385 0 .116 r
.20088 .32341 .21036 .30981 .22071 .30912 .21133 .32255 Mtetra
.37 0 .103 r
.21133 .32255 .22071 .30912 .23112 .30853 .22188 .32134 Mtetra
.318 0 .059 r
.22188 .32134 .23112 .30853 .24167 .30716 .23259 .31907 Mtetra
.205 0 0 r
.23259 .31907 .24167 .30716 .25245 .30378 .24353 .31491 Mtetra
.03 0 0 r
.24353 .31491 .25245 .30378 .26351 .29763 .25472 .30833 Mtetra
0 0 0 r
.25472 .30833 .26351 .29763 .27478 .2892 .26609 .29982 Mtetra
.26609 .29982 .27478 .2892 .28621 .27892 .2776 .28982 Mtetra
.2776 .28982 .28621 .27892 .29765 .26841 .28913 .2796 Mtetra
.28913 .2796 .29765 .26841 .30905 .25865 .30062 .26997 Mtetra
.30062 .26997 .30905 .25865 .32036 .25018 .31204 .26144 Mtetra
.018 0 0 r
.31204 .26144 .32036 .25018 .33159 .2433 .32338 .2543 Mtetra
.082 0 0 r
.32338 .2543 .33159 .2433 .34277 .23754 .33468 .24827 Mtetra
.137 0 0 r
.33468 .24827 .34277 .23754 .35394 .23271 .34596 .24326 Mtetra
.183 0 0 r
.34596 .24326 .35394 .23271 .36512 .22855 .35722 .23908 Mtetra
.23 0 0 r
.35722 .23908 .36512 .22855 .3763 .22506 .3685 .23573 Mtetra
.286 0 0 r
.3685 .23573 .3763 .22506 .3875 .2225 .37977 .23341 Mtetra
.341 0 .028 r
.37977 .23341 .3875 .2225 .39871 .22107 .39106 .2322 Mtetra
.401 0 .065 r
.39106 .2322 .39871 .22107 .40992 .22124 .40237 .2324 Mtetra
.44 0 .087 r
.40237 .2324 .40992 .22124 .42118 .22275 .41371 .23373 Mtetra
.459 .008 .091 r
.41371 .23373 .42118 .22275 .43249 .22501 .42513 .23567 Mtetra
.449 0 .077 r
.42513 .23567 .43249 .22501 .44392 .22706 .43664 .23741 Mtetra
.392 0 .035 r
.43664 .23741 .44392 .22706 .45548 .22727 .4483 .23765 Mtetra
.311 0 0 r
.4483 .23765 .45548 .22727 .46717 .22516 .46007 .23595 Mtetra
.205 0 0 r
.46007 .23595 .46717 .22516 .47897 .22024 .47197 .2318 Mtetra
.131 0 0 r
.47197 .2318 .47897 .22024 .49084 .21328 .48394 .22572 Mtetra
.105 0 0 r
.48394 .22572 .49084 .21328 .50274 .20552 .49596 .21854 Mtetra
.109 0 0 r
.49596 .21854 .50274 .20552 .51468 .19783 .50801 .211 Mtetra
.145 0 0 r
.50801 .211 .51468 .19783 .52663 .19143 .5201 .20408 Mtetra
.169 0 0 r
.5201 .20408 .52663 .19143 .53863 .18636 .53221 .19795 Mtetra
.189 0 0 r
.53221 .19795 .53863 .18636 .55069 .18266 .54437 .19283 Mtetra
.187 0 0 r
.54437 .19283 .55069 .18266 .56282 .17991 .55659 .18844 Mtetra
.158 0 0 r
.55659 .18844 .56282 .17991 .57502 .17753 .56887 .18445 Mtetra
.108 0 0 r
.56887 .18445 .57502 .17753 .5873 .17527 .58122 .18064 Mtetra
.025 0 0 r
.58122 .18064 .5873 .17527 .59965 .17276 .59362 .1767 Mtetra
0 0 0 r
.59362 .1767 .59965 .17276 .61206 .17003 .60608 .17263 Mtetra
.60608 .17263 .61206 .17003 .62453 .16705 .61859 .16834 Mtetra
.302 .79 .744 r
.61859 .16834 .62453 .16705 .63706 .16391 .63116 .16389 Mtetra
.412 .862 .854 r
.63116 .16389 .63706 .16391 .64966 .16068 .64378 .15932 Mtetra
.508 .903 .935 r
.64378 .15932 .64966 .16068 .66233 .1574 .65645 .15464 Mtetra
.579 .908 .978 r
.65645 .15464 .66233 .1574 .67506 .15409 .66918 .14989 Mtetra
.626 .885 .988 r
.66918 .14989 .67506 .15409 .68787 .15075 .68196 .14507 Mtetra
.651 .846 .975 r
.68196 .14507 .68787 .15075 .70074 .14738 .6948 .14019 Mtetra
.662 .8 .949 r
.6948 .14019 .70074 .14738 .71368 .14397 .70769 .13525 Mtetra
.577 .729 .946 r
.02714 .37496 .03496 .38178 .04501 .37829 .03699 .37287 Mtetra
.565 .773 .976 r
.03699 .37287 .04501 .37829 .05509 .37475 .04689 .37071 Mtetra
.541 .815 .997 r
.04689 .37071 .05509 .37475 .06523 .37116 .05686 .36847 Mtetra
.501 .844 .996 r
.05686 .36847 .06523 .37116 .07542 .36751 .06688 .36615 Mtetra
.44 .851 .964 r
.06688 .36615 .07542 .36751 .08565 .36379 .07697 .36373 Mtetra
.361 .828 .895 r
.07697 .36373 .08565 .36379 .09594 .35997 .08712 .3612 Mtetra
.27 .776 .794 r
.08712 .3612 .09594 .35997 .10628 .35605 .09733 .35855 Mtetra
0 0 0 r
.09733 .35855 .10628 .35605 .11668 .35196 .10761 .35576 Mtetra
.10761 .35576 .11668 .35196 .12714 .34768 .11796 .35283 Mtetra
.11796 .35283 .12714 .34768 .13766 .34326 .12836 .34982 Mtetra
.072 0 0 r
.12836 .34982 .13766 .34326 .14823 .33873 .13881 .34676 Mtetra
.15 0 0 r
.13881 .34676 .14823 .33873 .15881 .33437 .1493 .34382 Mtetra
.217 0 0 r
.1493 .34382 .15881 .33437 .16939 .3304 .15981 .34114 Mtetra
.272 0 0 r
.15981 .34114 .16939 .3304 .17993 .32715 .17033 .33882 Mtetra
.314 0 .027 r
.17033 .33882 .17993 .32715 .19042 .32489 .18084 .33698 Mtetra
.333 0 .048 r
.18084 .33698 .19042 .32489 .20088 .32341 .19139 .33539 Mtetra
.336 0 .047 r
.19139 .33539 .20088 .32341 .21133 .32255 .20199 .33388 Mtetra
.301 0 .01 r
.20199 .33388 .21133 .32255 .22188 .32134 .2127 .33187 Mtetra
.234 0 0 r
.2127 .33187 .22188 .32134 .23259 .31907 .22355 .32892 Mtetra
.131 0 0 r
.22355 .32892 .23259 .31907 .24353 .31491 .23458 .32464 Mtetra
.016 0 0 r
.23458 .32464 .24353 .31491 .25472 .30833 .2458 .31879 Mtetra
0 0 0 r
.2458 .31879 .25472 .30833 .26609 .29982 .25715 .31172 Mtetra
.25715 .31172 .26609 .29982 .2776 .28982 .2686 .30372 Mtetra
.041 0 0 r
.2686 .30372 .2776 .28982 .28913 .2796 .28008 .29557 Mtetra
.124 0 .013 r
.28008 .29557 .28913 .2796 .30062 .26997 .29156 .28775 Mtetra
.196 0 .08 r
.29156 .28775 .30062 .26997 .31204 .26144 .303 .28061 Mtetra
.254 0 .128 r
.303 .28061 .31204 .26144 .32338 .2543 .31442 .27433 Mtetra
.291 0 .157 r
.31442 .27433 .32338 .2543 .33468 .24827 .32581 .2688 Mtetra
.319 0 .176 r
.32581 .2688 .33468 .24827 .34596 .24326 .3372 .26399 Mtetra
.339 0 .188 r
.3372 .26399 .34596 .24326 .35722 .23908 .3486 .25979 Mtetra
.357 0 .195 r
.3486 .25979 .35722 .23908 .3685 .23573 .36002 .25622 Mtetra
.375 .005 .201 r
.36002 .25622 .3685 .23573 .37977 .23341 .37145 .25338 Mtetra
.392 .016 .202 r
.37145 .25338 .37977 .23341 .39106 .2322 .3829 .25128 Mtetra
.409 .027 .199 r
.3829 .25128 .39106 .2322 .40237 .2324 .39438 .25007 Mtetra
.419 .027 .186 r
.39438 .25007 .40237 .2324 .41371 .23373 .40591 .24954 Mtetra
.419 .012 .158 r
.40591 .24954 .41371 .23373 .42513 .23567 .41751 .24937 Mtetra
.4 0 .112 r
.41751 .24937 .42513 .23567 .43664 .23741 .42919 .24904 Mtetra
.345 0 .039 r
.42919 .24904 .43664 .23741 .4483 .23765 .44098 .2478 Mtetra
.266 0 0 r
.44098 .2478 .4483 .23765 .46007 .23595 .45287 .24532 Mtetra
.163 0 0 r
.45287 .24532 .46007 .23595 .47197 .2318 .46486 .24125 Mtetra
.089 0 0 r
.46486 .24125 .47197 .2318 .48394 .22572 .47693 .23581 Mtetra
.06 0 0 r
.47693 .23581 .48394 .22572 .49596 .21854 .48905 .22942 Mtetra
.064 0 0 r
.48905 .22942 .49596 .21854 .50801 .211 .50122 .2225 Mtetra
.093 0 0 r
.50122 .2225 .50801 .211 .5201 .20408 .51342 .21566 Mtetra
.111 0 0 r
.51342 .21566 .5201 .20408 .53221 .19795 .52565 .20907 Mtetra
.122 0 0 r
.52565 .20907 .53221 .19795 .54437 .19283 .53793 .20295 Mtetra
.111 0 0 r
.53793 .20295 .54437 .19283 .55659 .18844 .55025 .1972 Mtetra
.076 0 0 r
.55025 .1972 .55659 .18844 .56887 .18445 .56261 .19171 Mtetra
.019 0 0 r
.56261 .19171 .56887 .18445 .58122 .18064 .57503 .18633 Mtetra
0 0 0 r
.57503 .18633 .58122 .18064 .59362 .1767 .5875 .1809 Mtetra
.5875 .1809 .59362 .1767 .60608 .17263 .60001 .17538 Mtetra
.60001 .17538 .60608 .17263 .61859 .16834 .61257 .16969 Mtetra
.41 .854 .768 r
.61257 .16969 .61859 .16834 .63116 .16389 .62517 .16387 Mtetra
.517 .916 .868 r
.62517 .16387 .63116 .16389 .64378 .15932 .63781 .15791 Mtetra
.602 .943 .935 r
.63781 .15791 .64378 .15932 .65645 .15464 .6505 .15182 Mtetra
.661 .937 .967 r
.6505 .15182 .65645 .15464 .66918 .14989 .66322 .14562 Mtetra
.695 .908 .97 r
.66322 .14562 .66918 .14989 .68196 .14507 .67599 .13932 Mtetra
.711 .866 .955 r
.67599 .13932 .68196 .14507 .6948 .14019 .6888 .13294 Mtetra
.715 .819 .93 r
.6888 .13294 .6948 .14019 .70769 .13525 .70165 .12647 Mtetra
.498 .7 .96 r
.01926 .36808 .02714 .37496 .03699 .37287 .02893 .36719 Mtetra
.48 .736 .983 r
.02893 .36719 .03699 .37287 .04689 .37071 .03868 .36619 Mtetra
.453 .766 .996 r
.03868 .36619 .04689 .37071 .05686 .36847 .04849 .36508 Mtetra
.414 .787 .993 r
.04849 .36508 .05686 .36847 .06688 .36615 .05838 .36387 Mtetra
.362 .793 .968 r
.05838 .36387 .06688 .36615 .07697 .36373 .06834 .36256 Mtetra
.298 .779 .916 r
.06834 .36256 .07697 .36373 .08712 .3612 .07837 .36114 Mtetra
.223 .743 .837 r
.07837 .36114 .08712 .3612 .09733 .35855 .08847 .35961 Mtetra
.143 .687 .737 r
.08847 .35961 .09733 .35855 .10761 .35576 .09864 .35797 Mtetra
0 0 0 r
.09864 .35797 .10761 .35576 .11796 .35283 .10887 .35622 Mtetra
.008 0 0 r
.10887 .35622 .11796 .35283 .12836 .34982 .11918 .35436 Mtetra
.069 0 0 r
.11918 .35436 .12836 .34982 .13881 .34676 .12956 .35239 Mtetra
.116 0 0 r
.12956 .35239 .13881 .34676 .1493 .34382 .14 .35031 Mtetra
.146 0 0 r
.14 .35031 .1493 .34382 .15981 .34114 .15051 .34812 Mtetra
.157 0 0 r
.15051 .34812 .15981 .34114 .17033 .33882 .16109 .34581 Mtetra
.15 0 0 r
.16109 .34581 .17033 .33882 .18084 .33698 .17173 .34339 Mtetra
.116 0 0 r
.17173 .34339 .18084 .33698 .19139 .33539 .18245 .34086 Mtetra
.06 0 0 r
.18245 .34086 .19139 .33539 .20199 .33388 .19322 .33821 Mtetra
0 0 0 r
.19322 .33821 .20199 .33388 .2127 .33187 .20407 .33544 Mtetra
.20407 .33544 .2127 .33187 .22355 .32892 .21497 .33256 Mtetra
.21497 .33256 .22355 .32892 .23458 .32464 .22594 .32956 Mtetra
.22594 .32956 .23458 .32464 .2458 .31879 .23698 .32645 Mtetra
.122 0 0 r
.23698 .32645 .2458 .31879 .25715 .31172 .24808 .32322 Mtetra
.234 0 0 r
.24808 .32322 .25715 .31172 .2686 .30372 .25923 .31987 Mtetra
.308 0 .104 r
.25923 .31987 .2686 .30372 .28008 .29557 .27046 .3164 Mtetra
.35 0 .187 r
.27046 .3164 .28008 .29557 .29156 .28775 .28174 .31281 Mtetra
.375 .024 .236 r
.28174 .31281 .29156 .28775 .303 .28061 .29308 .3091 Mtetra
.389 .05 .265 r
.29308 .3091 .303 .28061 .31442 .27433 .30448 .30527 Mtetra
.396 .065 .282 r
.30448 .30527 .31442 .27433 .32581 .2688 .31594 .30132 Mtetra
.4 .073 .291 r
.31594 .30132 .32581 .2688 .3372 .26399 .32746 .29725 Mtetra
.4 .075 .295 r
.32746 .29725 .3372 .26399 .3486 .25979 .33904 .29306 Mtetra
.399 .074 .295 r
.33904 .29306 .3486 .25979 .36002 .25622 .35067 .28874 Mtetra
.394 .068 .29 r
.35067 .28874 .36002 .25622 .37145 .25338 .36236 .28431 Mtetra
.387 .057 .279 r
.36236 .28431 .37145 .25338 .3829 .25128 .3741 .27975 Mtetra
.374 .037 .26 r
.3741 .27975 .3829 .25128 .39438 .25007 .38589 .27506 Mtetra
.353 .005 .227 r
.38589 .27506 .39438 .25007 .40591 .24954 .39774 .27026 Mtetra
.318 0 .172 r
.39774 .27026 .40591 .24954 .41751 .24937 .40965 .26533 Mtetra
.258 0 .08 r
.40965 .26533 .41751 .24937 .42919 .24904 .4216 .26028 Mtetra
.151 0 0 r
.4216 .26028 .42919 .24904 .44098 .2478 .4336 .2551 Mtetra
0 0 0 r
.4336 .2551 .44098 .2478 .45287 .24532 .44566 .2498 Mtetra
.44566 .2498 .45287 .24532 .46486 .24125 .45776 .24437 Mtetra
.303 .773 .654 r
.45776 .24437 .46486 .24125 .47693 .23581 .46991 .23882 Mtetra
.319 .784 .665 r
.46991 .23882 .47693 .23581 .48905 .22942 .4821 .23315 Mtetra
0 0 0 r
.4821 .23315 .48905 .22942 .50122 .2225 .49435 .22735 Mtetra
.49435 .22735 .50122 .2225 .51342 .21566 .50663 .22142 Mtetra
.50663 .22142 .51342 .21566 .52565 .20907 .51896 .21538 Mtetra
.51896 .21538 .52565 .20907 .53793 .20295 .53134 .2092 Mtetra
.53134 .2092 .53793 .20295 .55025 .1972 .54375 .2029 Mtetra
.54375 .2029 .55025 .1972 .56261 .19171 .55621 .19648 Mtetra
.55621 .19648 .56261 .19171 .57503 .18633 .5687 .18993 Mtetra
.5687 .18993 .57503 .18633 .5875 .1809 .58123 .18326 Mtetra
.416 .847 .711 r
.58123 .18326 .5875 .1809 .60001 .17538 .5938 .17646 Mtetra
.516 .912 .808 r
.5938 .17646 .60001 .17538 .61257 .16969 .60641 .16954 Mtetra
.599 .951 .881 r
.60641 .16954 .61257 .16969 .62517 .16387 .61905 .16249 Mtetra
.663 .964 .927 r
.61905 .16249 .62517 .16387 .63781 .15791 .63173 .15532 Mtetra
.707 .956 .95 r
.63173 .15532 .63781 .15791 .6505 .15182 .64443 .14802 Mtetra
.734 .932 .954 r
.64443 .14802 .6505 .15182 .66322 .14562 .65717 .1406 Mtetra
.748 .9 .946 r
.65717 .1406 .66322 .14562 .67599 .13932 .66994 .13306 Mtetra
.753 .863 .929 r
.66994 .13306 .67599 .13932 .6888 .13294 .68274 .1254 Mtetra
.752 .824 .908 r
.68274 .1254 .6888 .13294 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Sooooo`03ol3Bj?l0003ooooo01Gooooo00?o
0000ooooooooool0DOooool0063ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`0Mooooo`?o00000_ooool00ol0003oooooooooo`1Oooooo`?o`=;X00?o
0000ol3Bj?ooool05Oooool00ol0003oooooooooo`1@ooooo`00H?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol0000Looooo`;o0000IOooool2ol3Lk@?o`=;X00?o0000okOAk_ooool05?oo
ool00ol0003oooooo`00001Aooooo`00H?ooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00006_ooool3o`0006Gooooo1Oo0g>d00oo0d^So]m7^o`000002okOAkQKooooo
00?o0000ooooooooool0Coooool0063ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgM
gOmEEEGoooooo`0001Sooooo0_l0001Vooooo`;o_nKb1?o0g>d01?nfgOCo]m7^okOAk_l00003okOA
kQKooooo00?o0000ooooooooool0C_ooool0063ooooo00Go410@oooooooooooooooooa0@400<oooo
o`03ogMgMoo<c<co000001Gooooo0ol00002ooooo`03o`000?oooooooooo06;ooooo1?noi_800oo0
g>go]]gdokKMm002okKMm005okOAk_l0003o]m7^okOAk_nYc?805_ooool00ol0003oooooooooo`1>
ooooo`00H?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000004oooool2
o`0006Wooooo1?noi_82ok7Xn0Go]]gd00?o0000ojW<l_nYc?800_nYc?8Fooooo`03o`000?oooooo
oooo04gooooo001Pooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0?
ooooo`?o0000JOooool3ok_^m003okoVl_naj?So/NSh00?o/NSh0_nfgO@2ojKHn@03o`000?nYc?;o
ZLcb00?oZLcb5_ooool00ol0003oooooooooo`1<ooooo`00P_ooool2o`0006[ooooo1?nkk_@00onY
koOo/NShok7Xn003ok7Xn003oj3Ro?nVf?WoY]Si00;oY]Si00Co0000ojW<l_nYc?;oZLcb0_nJa?DF
ooooo`03o`000?oooooooooo04cooooo001oooooo`?o00000_ooool00ol0003oooooooooo`1Uoooo
o`?o]?Cc00?o^nkdojW_monYkoL00_nYkoL00onaj?SoX>;loj3Ro003oj3Ro0;oY]Si00?oU/gko`00
0?nFcO/01OnJa?DDooooo`?o0000COooool007cooooo0ol0001/ooooo`?o]?Cc0_nJlNl2ojW_m`Co
U>Sj0_nPh_`3ohoFo`;oU/gk00?o0000oiK=nonFcO/01?nJa?DGooooo`03o`000?oooooooooo04[o
oooo001jooooo`;o0000K_ooool2okCdl`?oV_7_0on2inl2oiCXnP?oQM_n1On?e_l2oiK=n`03o`00
0?n9_oSoS;Wd00CoS;Wd5_ooool00ol0003oooooooooo`1:ooooo`00Moooool3o`0006kooooo0_nY
m^d2ohCZgP04oi[akon2inooP^O_oh;Wk`CoN=ch1?n5foh2ohoFo`?oQ/Cl00CoRKoho`000?n9_oSo
RKoh1On<^O@Fooooo`03o`000?oooooooooo04Wooooo001eooooo`;o00000_ooool00ol0003ooooo
ooooo`1Zooooo`;oZOK]0_n4j]h2ofWLfPCoI]S/0_mhg?P3ogk<o`CoP/Sn1On6a?`01?l0003oRKoh
ohVon?n9_oP2ohbim0;oQ;7b5oooool00ol0003oooooooooo`18ooooo`00L_ooool3o`0000Gooooo
00?o0000ooooooooool0Ioooool2oiWch@03ofSJa?m=b[koDLkJ00?oDLkJ0_mVf>`3ogW?o`GoO/co
1?n2b?h2ohK4o0;oPkCd00?o0000ohBblon4/_<00_n4/_<4ohBalQKooooo00?o0000ooooooooool0
B?ooool0073ooooo0_l0001`ooooo`;oVO?Q00?oJ=[4ocZn`om^d?d00_m^d?d5ogC@oPCoNLoo0_mn
c?l3ohBgmPCoPkGe0on3]?@00ol0003oQ;;cohBbl`03ohBbl`CoQ;7b5_ooool00ol0003ooooooooo
o`17ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00008?oo
ool3o`00073ooooo0_n4jLh4ofK=n`CoK]3m0_mdd?h3ohNgm@CoQ[Of1On4]oH4oh>em@;oPkCd00Co
0000oh>dm?n4/_?oQ;;c0_n5Z>/4ohB[kQGooooo0ol00018ooooo`00>?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@07_ooool2o`0000?o
oooo00?o0000ooooooooool0I?ooool2oah000?o3`0000Co0000o`H00?n4jLkoQ>W>0_mLb_P2ofK=
n`;oR;;a1On8]_@5ohNgm@CoQ[Of0_n4]oH2oh^PhPCoRJ;U0_n7YNP00ol0003oQjGXohFXj`04ohFX
j`CoQ:_^5_ooool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo0_l000000ol@413oooooooooo`0Yooooo`00>?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h07?ooool3o`0006Cooooo0_lV0003obP000Co7P0000Co3`00
oa/00?lK003o1P000_mZf;H5ohJ^k`CoR;;a1On8]_@2ohNgm@;oT9[I1?n>WMh5oh^PhPCoRJ;U00Co
QjGXo`000?n7YNSoQjGX1On5Z>/4ohB[kQKooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02[ooooo000hooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Hooooo`?o0000Hoooool2oad000?o
9P0000?o:000obl00?l_00001?lX0003oa/000;oJ]Rf0on3Z>`5ohJ^k`CoR;;a0_n8]_@2oi6Fe@Go
T9[I1?n>WMh4oh^PhPGoRJ;U00Co0000ohNUj?n7YNSoQjGX0_n5Z>/2ohbUi@GoRj_[5_ooool00ol0
003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0002_ooooo000hoooo
o`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Eooooo`?o0000H_ooool0
1OlA003o7@00oad00?lM003o9P0000;o<0001?l_0003obP00003oa/00?l4003o000000?oPZGZ1?n3
Z>`2ohJ^k`;oT8c;1?nATM05oi6Fe@CoT9[I1On>WMh4oh^PhP;oRJ;U0_n@V]X01?l0003oSYoOohjO
gon>Wml5ohbUi@GoRj_[5Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00002oooool01?m4A4CogMgMooooool0000/ooooo`00>?ooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool04Oooool3o`0000?ooooo00?o0000ooooooooool0G_ooool2oa40
0003oad00?l[003o<00000?o<0000ol_00001OlX003o4`00oa<00?l4003o000000;oRgfn0on<PL84
ohf5aPGoT8c;1?nATM04oi6Fe@GoT9[I0_n>WMh2oi>Bc`CoTIKD1?n@V]X00ol0003oSYoOohjOg`02
ohjOg`GoS:GU0_n;Zn/2oiF]iaKooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000_ooooo00CogMgMoeEEEOoooooo0000;?ooool003Sooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41004Oooool2o`0006Gooooo00?o0@00oa400?lA
00000ol[0003oc000003obl00?lL003o700000?o4`000_l00004oh]m_P?oS8721?n=QLH4oi2<b`Co
TI7@1OnAU]D2oi2Jf@;oUHo:1OnCT/l4oi6Fe0?oT9[J00?o0000ohjOgon>Wml00on>Wml2ohbUi@;o
UZCO1OnE[NLFooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400<oooo
o`03ogMgMoo<c<co000002cooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnH
V9So410@o`000?lQ8B7oc<c<00kooooo0ol0001Uooooo`;o0@0000?o4@00obD00?l[00000_l[0002
oc000003oal00?lL003o700000;o700000?o4`00o`000?l000000_n=OK`4oh]m_P?oS8721?n=QLH4
oi2<b`GoTI7@0_nAU]D2oiJ;a@GoUHo:1?nCT/l4oi6Fe0?oT9[J00Co0000oi2Jf_n>WmooSYoO0_nG
WMP5oiJTg`GoUJgW5?ooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^
k_m4A4Co000002cooooo001Iooooo`?o0000IOooool00ol0003o0@00o`400003obD000?o:`000olO
0003oa`000;o00001?n=OK`4oh]m_P?oS8721?n=QLH5oi2<b`;oTI7@0_nFQl45oiJ;a@CoUHo:1?nC
T/l5oi6Fe0;oT9[J00?o0000oiNGdOnGWMP01?nGWMP5oiJTg`;oUJgW0_nR/n@Cooooo`04o`000?oo
ooooooooo`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02_o
oooo001Fooooo`?o00000oooool00ol0003oooooooooo`1Qooooo`;o000000Co6`00obD00?lU003o
9@000_l[00001?lL003o7`00oal00?lO0002oa`000;o00000_nBOk`4ohem_0GoRgfn0on<PL84ohf5
aP;oT8c;0_nEP[`5oiJ7`@CoUX_51?nESlX5oi>Bc`;oTIKD0_nHTL/2oiNGd@03o`000?nGUm7oUiOA
00GoUigH0_nFY=l2oj6Yg0GoX[?T5_ooool00ol0003oooooooooo`10ooooo`00E?ooool2o`0006Wo
oooo0_l00002oa/000?o9@000olL0003oal000;o00001OnBOk`4ohem_0CoRgfn0_n<PL800onANKCo
Tgfhoi=m^002oi=m^0GoUH:l1?nFQl44oiJ;a@GoUHo:0_nCT/l2oiV=aPGoV97;00CoUiOAo`000?nG
Um7oUiOA1?nGWMP00onQX]GoXJWLoj6Yg003oj6Yg0CoX[?T5_ooool00ol0003oooooooooo`10oooo
o`00DOooool3o`0006Wooooo00?o0P00o`000?lJ00000_lK0002obD00004oaL00?lL003o7000oa`0
00;o7`000_l00003oiV5_0CoTWnl1?n=OK`2oh]m_P;oSgBa1?nANK@4oi=m^0CoUH:l1?nFQl45oiJ;
a@;oUHo:0_nJR/45oiV=aPCoV97;00?oUiOAo`000?nGUm400_nGUm400onGWMSoXJ;Eoj6Re@02oj6R
e@CoXJWL0_nR/n@3ojfjhQKooooo00?o0000ooooooooool0?oooool004kooooo1Ol0001Xooooo`?o
0P000_lJ0002oa/000?o5`000olL0002o`0000;oXXbm0onIQK`2oi9o_0;oT7:^1?n?LZl4ohmd/@Co
TGVd1?nCOKP4oiF2_0GoUXO10_nFRlD2oi^6_0GoVX[11?nISLH5oiRAb`04o`000?nGUm7oXI_?oj6K
c`GoXJ;E0onQZM`00on//]co[K[RojfjhP04ojfjhQKooooo00?o0000ooooooooool0?_ooool004co
oooo0_l00005ooooo`03o`000?oooooooooo06?ooooo00Co6P00o`800?l2003o0P000_lJ0002oa/0
00?o5`000_lL0002o`0000CoXXbm0_nIQK`00onCM:goT7:^oi1b[P02oi1b[PCoSg:_1On?M;44oi5i
]0?oTgfh1OnEP[`2oiJ7`@;oVh>h1OnKQ[`4oiZ:`@GoVHg60_nHTL/2oj2Fb@03o`000?nQVlooXI_?
00;oXI_?1OnQX]D01?nQZMco[;;Lojbbg?n//]`4ojfjhP03okO1h_oooooooooo01Cooooo00?o0000
ooooooooool0?_ooool004Wooooo0ol0001Iooooo`04o`000?lg003o=`00ocL000CoD`001?mF0006
ooooo`05o`000?lJ003o6P00o`800?lQ00000olJ00000olK003o4000oaL00002oaL000;o00000_nW
TKl3oj:<_@04oiQh[_nCM:goTgB]oi=d[@GoT7:^1?n?LZl4ohmd/@CoTGVd1?nCOKP3oiF2_003oiYo
]OnKPkSoVh>h00?oVh>h1?nKQ[`4oiZ:`@CoVHg600?oXI74oj2FbOnPU/T00onPU/T01?l0003oXI_?
oj6KconQVll4oj6Re@03oj^[e_n//]co[;;L00?o[;;L00?o[K[RokO1h_ng`N800_ng`N8Dooooo`?o
0000?oooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Pooooo`;o0000E_ooool00olK003o
A`00odL00002odL000CoHP001?m_0003ofh00003oeH00?lc003o<`0000;o<`0000?o0000och00?ln
00000_lJ0003ob4000?o6P0000?o4000oaL00?lG00000_l00004ojNA_`04oj:<_OnHN:koV7R^oiQh
[PCoTgB]1?n@LZh4ohmb[`CoSgBa1?nANK@4oi=m^004oiF2_?nJOkGoVWneoiYo]@GoVh>h1?nKQ[`5
oiZ:`@03oiV=a_nQTLCoXI7400;oXI741?nPU/T00ol0003oXI_?oj6Kc`02oj6Kc`03oj6ReOn[ZmKo
Zj_F00;oZj_F0on//]`00onf_=ko]l7RokO1hP04okO1hQGooooo00?o0000ooooooooool0?Oooool0
02;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`?o00000_ooool00ol0003oooooooooo`1@
ooooo`03oa/00?mG00OoE`0700?oIP0@0om`01H2of8000CoK`001?m^0004oeX000?o?P0000?o6P00
oc@00?lQ00000_lQ0002oaX00003o`l00?l@003o400000;o00000_nYUL42ojNA_`;oVg^_1OnHN:h3
oi=d[@CoT7:^1?n?LZl5ohmd/@CoTGVd0_nCOKP00onINk7oVWneoiYo]@03oiYo]@CoVh>h1OnKQ[`2
oiZ:`@;oXHk01OnQTL@4oj2Fb@03o`000?nQVlooXI_?00;oZjGA1On[ZmH00on//]co][cNokJlgP02
okJlgPCo]l7R0_nmbN@Eooooo`03o`000?oooooooooo03cooooo000Rooooo`05oa0@4?oooooooooo
ooooool@41006oooool2o`0005Cooooo0_l000000om9003oE`07oeL01`02oeL01`?oIP0@1?m`01H3
ogD25`03ofl00?m^003oKP0000;oKP001?mJ0003och000?o=0000olQ0002o`l00003oa000?l0003o
ZIG100?oZIG100?oW7jaoi]k[onKNjl00_nKNjl5oiQh[P?oTgB]1?n@LZh4ohmb[`GoSgBa0_nANK@2
oiMg[P?oVG^a1OnJOkD5oi^3^0?oVhJl00?oXX^loj6>`?nQS/000onQS/04oj6Aa0CoX9K900?o0000
oj^UdOn[YM400on[YM43oj^[eP03okFhfonf_=ko][cN00Co][cN00?o]l7Rokg9i?nmbN@00onmbN@E
ooooo`03o`000?oooooooooo03_ooooo000Rooooo`05o`000?ooooooooooooooool000006?ooool3
o`0005?ooooo00?o0000ocX00?lj00000om90003oeL01`?oIP0@1?m`01H4ogD25`CoLP0C1?mT00P3
odl000?o=0000_lQ00000olF003o3`00o`l00004oj:Ca004ojVE`OnLO[7oW7jaoian/@GoVg^_1?nH
N:h3oi=d[@CoT7:^1On?LZl3ohmd/@03oiAcZonGMjkoUgN^00;oUgN^1?nINk44oiYo]@GoVh>h00?o
VhJloj:;_?nRRk`00_nRRk`4oj6>`0GoXI7400GoX9K9ojZPc?nZX<co0000ojZPc004oj^Ud@03oj^[
e_ne^=_o]KSK00;o]KSK1?nf_=h00onmb^Co_LWTokg9i003okg9i003okg=iooooooooooo01?ooooo
00?o0000ooooooooool0>oooool002;ooooo00Go0000ooooooooooooooooo`00000Fooooo`?o0000
D_ooool00om1`:co;P00ocX00002ocX000?oB@000omG00L4ofH040?oL00F1Ome0QL4og804`CoI008
0om?0003oc@000?o5P000onERlH2oj:Ca003oiUl/_nLO[7oW7ja00?oW7ja1?nKNjl4oiQh[P?oTgB]
1On@LZh4ohmb[`04ohmd/OnDLj_oU7>[oiAcZ`GoUgN^0onINk45oiYo]@?oVh>h00?oXhVioj:;_?nR
Rk`00onRRk`4oj6>`0CoXI7400KoZYc9ojZPc?nZX<coZZ3<o`000?nZX<`3oj^Ud@03okFdf?ne^=_o
]KSK00Co]KSK00?o][cNokg:i?nmb^@00_nmb^@3okg9i0?o_LgW5Oooool00ol0003oooooooooo`0j
ooooo`008_ooool01Ol@413ooooooooooooooooo410@01?ooooo0ol00002ooooo`03o`000?oooooo
oooo04kooooo00Co8`00obh00?l^003o;P000_lj00000om9003oG`4coel1<`03of@4<`CoJ0Hb0om[
1Rl3of/3:0;oM@8G1?mb01<4of@020?oC`0000?o=000obT00?lY00000_lF00000omAb:[oUH_6oiF;
aP02oi9g/@?oVGbb1OnLO[44oi]k[`CoV7R^1?nCM:d4oi1b[P;oSg:_0_nBL:T5oiAcZ`CoUgN^0onI
Nk45oiYo]@03oi^3^?nSRKWoXhVi00;oXhVi1?nRRk`5oj6>`003oj6Aa?nZW<WoZYc900;oZYc90_nZ
X<`01?l0003oZZ3<ojZPc?n[YM43okFdf0Co]KSK00?o_/_Tokg:i?nmb^@01?nmb^@00onmbNCo_LgW
okg=i`02okg=iaKooooo00?o0000ooooooooool0>Oooool002;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0@ooooo`?o0000E?ooool2ob<000?o;P0000?o>P00oe/0<OmO0C<00omO0C<3of@4<`CoJ0Hb
0om[1Rl4of/3:0?oIP0L0_mb01<3of@02003odl00?m4003oA00000Co:@0000?oDLRZohV0`on>LZl0
1?nBMk44oiUl/PCoW7ja1?nKNjl5oiQh[P?oTgB]0_n@LZh2oi5^Y`CoTW2Y1OnDLj/4oiMg[PCoVG^a
0onJOkD00onRQkKoXhVioj>9^@03oj>9^@GoXX^l0onQS/000on[V/KoZYc9ojZLb@03ojZLb@;oZZ3<
00?o0000ojZPc?nd/MD01?ne]=P3okFhf`?o_/_T1?nmb^@2okkDjP?o_LgW0_nhd>`Dooooo`;o0000
>oooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`;o0000E?ooool2oa@000;o8`00
00?o;P00oeH0<?mF03000omK0343oel1<`?oI0@c1?mX1S83of/6;`GoJ`<X1?mV01`3oeP02@CoA000
0_lY00000om=aJOoRff[ohib[`02ohib[`GoTWNa0onIO;84oian/@GoVg^_1?nHN:h2oi=d[@03oi5^
Y_nAKZOoTFjW00;oTFjW1OnBL:T4oiAcZ`CoUgN^1?nINk400onJOkGoXXNfoj:7]P02oj:7]PCoXhVi
1OnRRk`00onQS/3oZi[6oj^JaP02oj^JaPCoZYc90_nZX<`00ol0003o];7EokBae@05okFdf003okFh
fonnbnCo_/_T00?o_/_T00?o_L[TokkDj_nne>X00onne>X00onmcNOo^=3/okS@k002okS@k1Gooooo
00?o0000ooooooooool0>?ooool003;ooooo1Ol0001Booooo`?o500000?o8`00oe40;OmF03000omF
0302oe/0<@CoG`4c0omT13<4ofP6<P?oJ`H_1?m[0bP4ofH070CoF0090om400000olY003oCLFWoh]]
Z`02oh]]Z`CoSW:_1?nBMk43oiUl/PGoW7ja1?nKNjl2oiQh[P;oTfnW0onAKZH5oi5^Y`CoTW2Y1?nD
Lj/5oiMg[P;oVG^a00?oXXBcoj:7]_nRQkH00onRQkH5oj>9^@?oXX^l00?o[9W4oj^Ja_n[V/H00on[
V/H5ojZLb@;o00000ond/MD3okFdf0;o_/gU1?nnbn@2okoKkPCo_]CZ00?o^=cbokS@k?nhd>`00_nh
d>`00on^cO3oooooooooo`0Dooooo`03o`000?oooooooooo03Oooooo000`ooooo`;o0000EOooool0
1?m_dICo1000oa@00?lD0003oe40;@?oEP0`0omK0343oel1<`CoI0@c0omX1S84of/6;`CoJ`<X0omV
01`4oeP02@03od@00?l0003o000000?oSffW1?n;KJ/3ohib[`CoTWNa1?nIO;84oian/@;oVg^_0_nD
L:L4oi=_Y`CoTFjV1?nAKZL4oi9`Z@CoU7>[1OnGMjh00onINk7oXXBcoj:4/`05oj:7]PGoXhVi00?o
XX^lojbIa?n/VL@00_n/VL@4oj^JaP;oZYc90ol000000ond/MGo0000okBae@02okBae@03okFdf?nn
cNGo_/gU00?o_/gU00?o_/_TokoKk_nofnh00onofnh00onne>[o^=cbokSLlP02okSLlP03okS@k?n^
cO3o[/g`00;o[/g`5Oooool00ol0003oooooooooo`0gooooo`00;Oooool3o`0005Kooooo00CoKm6D
o`@00?lD003oBP0X0omA02d4oeH0<0;oF`0a1?mO0C<3of@4<`CoJ0Hb00?oJ`H_oeX1>_mJ0CX01?mA
02`3od8050Co9P000ol00004ohm]Y`CoRff[0on>LZl4oi9g/@CoVGbb0_nLO[42oiEbZ0CoU72W1OnC
KjL3oi5^YPCoTFjW1?nBL:T5oiAcZ`?oUgN^00?oWh2aoj:4/onRQ;<00_nRQ;<5oj:7]P?oXhVi00?o
[IW2ojbIa?n/VL@00on/VL@3oj^JaP?o00001?ne/=<00ond/MGo0000okBae@02oko@i`Co_/gU0_nn
ho44okoKkP03okGWmonhg?;o^=cb00;o^=cb0_n[fOL5ojk=l1Gooooo00?o0000ooooooooool0=_oo
ool002cooooo0_l0001Fooooo`04ofoAU?l0003o1000o`@000;oBP0X0omA02d3oeH0<0?oF`0a1?mO
0C<00omT13?oH`i7of<>A`03oel9@PCoFP4j1?mA02`3od8050?o9P0000Co0000oiE^XonEKZ?oUFjS
1?n?KJL4oh]]Z`?oSW:_1OnBMk42oiUl/P03oiAaZ?nELZSoUG:X00;oUG:X1OnDL:L4oi=_Y`?oTFjV
1?nAKZL4oi9`Z@GoU7>[00CoUgN^oin0/OnOP;7oWh2a1?nRQ;<5oj:7]P03oj>9^On]VL;o[IW200;o
[IW21?n/VL@3o`000003oj^Ja_ne[m?o]K3C00Go]K3C00?o];7Eo`000?nod>L00_nod>L00onncNGo
_^?aokkSl@03okkSl@03okoKk_neioOo]NOg00;o]NOg00?o^=cboj_Imon[fOL00on[fOL2ojk=l0?o
XLKb5Oooool00ol0003oooooooooo`0eooooo`00;?ooool3o`0005Cooooo0_l000000ol4003o@@0P
odX0:002odX0:0;oD@0]1?mF0303oe/0<@03oel1<omT4D[oI15:00CoH`i70omO2D83oeX1>PCoD@0/
0om201@2obH000?oV6jQ0onEKZ<4ohm]Y`CoRff[1?n>LZl4oi9g/@03oiUl/_nDLJSoU76X00GoUG:X
1?nDL:L4oi=_Y`?oTFjV1?nAKZL5oi9`Z@?oU7>[00?oWGb^oin0/OnOP;400onOP;43oj:4/`CoXXNf
00?o[YW1ojfI`_n]VL800on]VL801_n/VLCo0000o`000?l0003o[9W4oj^JaPCo]JoC1?ne/=<01Ono
e>Wo_m3Woko@iol0003o_m3W00;o^n_d1?nnho42oj[`mP;o]NOg1?nTho`2oj_Im`?oW/gh1OnQa_8D
ooooo`03o`000?oooooooooo03Gooooo000/ooooo`04o`000?oooooo0000o`0005;ooooo0_l00003
od4080;oBP0X0omA02d4oeH0<003oe/0<OmV4T_oI15:00?oI15:0omS3TL4oel9@P?oFP4j0omA02`4
od8050GoV6jQ0onEKZ<4ohm]Y`GoRff[0on>LZl2oi9g/@;oTFnX1?nDLJP4oiEbZ0CoU72W1?nCKjL3
oi5^YPGoTFjW1?nBL:T01?nDLj_oWGb^oiel[_nMO:h5oin0/@CoXXBc0_nRQkH3ojjI`@;o[IW20ol0
0003ojbIa003okNadone[m?o]JoC00Co]JoC00?o]K3CokoDjOnoe>T00_noe>T00onod>Oo0000ok_[
m003ok_[m004okkSlOnZl?KoZ_3foj[`mP?oTnSi0_nTho`3oiODo@GoW/gh0_nQa_82oiRllA?ooooo
00?o0000ooooool000002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`06Oooool002cooooo0_l00002ooooo`03o`000?oooooooooo04ko
oooo0_l00003od4080?oBP0X0omA02d00omF033oIQ=;ofHCB`03ofHBB`?oI15:1?mS3TL3oel9@P?o
FP4j1?mA02`00om201CoVFjOoiU^W`02oiU^W`CoV6jQ0onEKZ<5ohm]Y`CoRff[0_n>LZl00onAKJKo
TFnXoi5_Z002oi5_Z0CoU76X1?nELZP4oiA`Y`CoTfnW1?nAKZH4oi5^Y`;oTW2Y0_nIN:`5oiel[PCo
Wh2a1?nRQ;<01?nRQkKo[YW1ojjI`On^VL43o`0000?o[IW200?o[9W4okNadong/M<00_ng/M<4okF_
d`;o_m[]0onoe>T3ok?bm003o`000?nkjoCoTo3Z00;oTo3Z0_mfh^T2oi?Xn@?oS=Wo1OnGe?d2oik=
n0;oUKod1OnH_?4Eooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q01Wooooo000[ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0C?ooool2o`000004oc805?m1023o@@0Pod4080?oBP0X00?o
D@0]ofHBB_mV4d/00omV4d/3ofHBB`?oI15:1?mS3TL3oel9@P?oFP4j0_mA02`3oiQ/WPCoVFjO1?nH
KZ44oiE^X`CoSffW0_n;KJ/2oi5[X`?oTFfV1OnAKjP3oiAaZ0CoUG:X1?nDL:L5oi=_Y`?oTFjV0onA
KZL00onFM:[oVGR/oiUh[002oiUh[0GoWGb^1OnOP;42oj:4/`03ojnI`?n^VL7o[YW100;o000000?o
[YW1ojfI`_n]VL800_n]VL800oni]=Co]k7CokNad`03okNad`?o]JoC1?nof^d01?noe>Wo/o;dok?b
m?ncl_@2ofcMb`04o`000?nCl>[oM^;YogKRj@CoNmWm1?n<fOl2oiODo@;oT/7f1OnE_o@4oiRllAGo
oooo00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooo
ooooooooooooo`00000Iooooo`00:oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
04[ooooo0_l000001?lb01Co@@0Pod408?m10203odX0:003oe40;OmV4T[oIQ9:00CoIQ=;0_mV4T/4
of@ABP?oH`i71?mO2D83oeX1>P03oiAYW_nHK9koV6bN00;oV6bN1?nIKYl4oiQ^X@CoUFjS0on?KJL0
0onFK:3oTF^Soi5[X`02oi5[X`CoTFfV1?nAKjP3oiAaZ0CoUG:X1OnDL:L4oi=_Y`?oTFjV00CoTFjW
oiIdZ_nFM:[oUWBZ1OnIN:`4oiel[PGoWh2a00?oXXBcojnI`?l000000_l00004ojjI`@;o[IW20oni
]=@5okNad`03okF_donof^go_m[]00;o_m[]0_nSm>h01_ncl_CoK=g;ofcMbom/gL_oCL_8o`0000?o
ImCf0_mkfOd3ohZon0?oS/7h1OnB`OH2oiFom0;oU;7[1OnE]NdEooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B406Oooool0
02_ooooo0ol00005ooooo`03o`000?oooooooooo04Sooooo00Co0000oal00olb01Co<P0D0om10200
0om:02SoIA18ofD@B003ofHBBP?oIQ=;0omV4T/3of@ABPCoH`i71?mO2D801?mJ0C[oU6VNoiAYW_nD
JIh4oiQ/WPCoVFjO1OnHKZ43oiE^X`04ohm]YonFK:3oUVbPoiI/X0CoTF^S1?nAKJH4oi5_Z0?oU76X
1OnELZP4oiA`Y`CoTfnW0_nAKZH00onDLJWoUWBZoiIdZP03oiIdZPCoVGR/1?nMO:h4oin0/@?o0000
0_n_VL05ojjI`@03ojfI`_ni]=Co^KCD00;o^KCD1?ng/M<3okoSl@06okoJkOnSm>koXoC^oj?dk_l0
003o@l;T0_mBbn`3ohNgm@04o`000?n8_?SoR;chohRln0GoR[oh0on>`OP2oi;1mP;oTjgX1OnD/N/5
oiFekAGooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000oeEEEOl0003o410@olc<c00Iooooo`00:oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo04Kooooo00Co0000oal00olO00?o<P0D0_m102000omS34?oIA18ofD@B002ofD@B0;oIQ9:
1?mV4d/3ofHBB`?oI15:1?mS3TL3oel9@P03oeX1>_nDJIkoU6VN00;oU6VN1?nHK9h4oiU^W`GoV6jQ
0_nEKZ<00onJKIkoUVbPoiI/X002oiI/X0CoTF^S1?nAKJH4oi5_Z0CoU76X1?nELZP4oiA`Y`;oTfnW
0_nCL:P4oiAaZ@CoUWBZ1?nIN:`5oiel[P?o00000_n_V;l3ojnI`0Co[YW100?o^kWGokVde?ni]=@0
1?ni]=@00ong/M?o_n?aokoSl@02okoSl@;oQN_J00?oXoC^ohVal?n9/O000on9/O05ohNgm@04o`00
0?n8_?SoR;chohRln0;oR[oh0_nCX]h3oi>Xi0GoTjgX1OnD/N/2oiFek@;oV;?Z5Oooool00ol0003o
ooooooooo`03ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Koooo
o`00:oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Cooooo00?o0000oal00olO
00<00_lb01@3of<<@`?oIA180omV4TX4ofHCB`;oIQ9;1?mT4DX3of<>A`;oG`U20onAIih5oiAYWP?o
V6bN1?nIKYl5oiQ^X@03oiE^XonJKIkoVVfN00GoUVbP0onAJj<4oi5]YPCoTFnX1?nDLJP4oiEbZ0;o
U72W0_nBL:P4oi=`Z0CoU76Y1?nFM:X4oiUh[0;oWGb^0ol000000onOP;7o[iRoojnH_`02ojnH_`Co
[iW000?o[YW1ok^ieonk^ML00_nk^ML4okVde0?o^ngd00Co_n?aohG[f_n5jm[oQN_J0on<Z>P5ohVa
l0;oQkOe0_nDTm001?nCVmSo0000oi>Kf?nCVmP5oi>RgP?oTjST1OnC[NP2oiBaj`;oVJgU1OnH/nXC
ooooo`?o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P06ooo
ool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`11ooooo`03o`000?l:
003o7`0300;o7`0300?o<P0Dof<<@omS34<00_mS34<3ofD@B0?oIQ9:0omV4d/3ofHBB`?oI15:0_mS
3TL4oheTWP?oTFNN1OnDJIh4oiQ/WPCoVFjO0onHKZ401?nKKIcoVVfNoiY]W_nJKIh5oiI/X0CoTF^S
0onAKJH5oi5_Z0?oU76X0_nELZP2oi=`Z0CoTW2X1OnCL:P3oiAaZ@CoUWBZ0onIN:`3o`0000;oWGb^
00?o[9FnojnH_on_V;l00on_V;l3ojnI`003oko0f_nk^MOo^kWG00Co^kWG00?o^KCDok_]m?nkkO@0
0_nkkO@00omFcK;oT9oOoi2Og`02oi2Og`CoS:SX0_n9/O02oiF=b0GoU9?@00Co0000oi>Kf?nCVmSo
Ti_H1?nCX]h4oi>Xi0;oTjgX0_nIYml5oiV]i@GoV;?Z5Oooool02Ol0003oooooooooooooooook^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@41Wooooo000@ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01?ooool3o`0000[ooooo
00?o0000ooooooooool0?oooool00ol0003o2P00o`X00002oal00`03oc805?mO1ScoH`a300;oH`a3
1?mU44P2ofHBBPCoIQ=;0omV4T/2of@ABP?oRF>O1?n=I9h4oi5WWPCoU6VN1?nHK9h4oiU^W`;oV6jQ
0_nKKI`4oiY]WPCoUVbP1?nAJj<4oi5]YPCoTFnX0_nDLJP5oi=`Z0GoTW2X1?nCL:P4oiAaZ@?oUWBZ
0ol00002oiUh[003oiel[_n/UKko[9Fn00;o[9Fn1On_V;l01?n_VL3o_l3Joko0f_no`=X4ok^ie`?o
[oK`00?o^ngdoi>Fe?nCU]@00_nCU]@2oi2Og`03oiR1^OnFQ/3oUXK000;oUXK01OnESLP4oiBCd003
oi>Kf?l0003oTi_H00;oTi_H0_nCX]h00onKV];oVZ7IoiZQf@02oiZQf@GoVJOO1OnI[ND2oiRcjP;o
X;CW5Oooool00ol0003oooooooooo`0_ooooo`002?ooool6o`0000;ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`Go00001Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03go
oooo00?o0000o`X00?l:00000olO00<00omO1ScoH`a3of<<@`02of<<@`?oIA180omV4TX4ofHCB`;o
IQ9;00?oI15:ohQSXOn8Hj400on9Hil5oheTWP?oTFNN1?nDJIh4oiQ/WPCoVFjO00CoV6jQoi]]W?nK
KIcoVffL1?nJKIh4oiI/X0CoTF^S1?nAKJH2oi5_Z0;oU72W2?nCL:P4oi9`Z0CoTg2X1?nDLJT01?nF
M:[o0000o`000?nFM:X3oiUh[003ojR@_?n/UKko[9Fn00?o[9Fn1?n_V;l00oo2amko_l3Joko0fP03
oko0fP03ok^ieon_m_3o[oK`00;o[oK`0_nES/T2oi>Fe0;oVGfc1?nHPKT4oiJ6`0CoUHg81OnDTm00
1?nCVmSo0000oibDbonLU</4oi^JdPCoVZ7I1OnIYml2oiV]i@;oX:gP1OnP]>LEooooo`03o`000?oo
oooooooo02kooooo000@ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMoooo
ool00006ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0>?ooool01?l0003oD<JR
o`000?l00002o`X000;o7`0300?oF@0_oel6??mO1S`01?mS34<3ofD@B0?oIQ9:0omV4d/2ofHBB`03
ohaWXon8Hj7oR6>Q00;oR6>Q0on9Hil4oheTWP?oTFNN1?nDJIh4oiQ/WP?oVFjO1OnKKI`4oiY]WPCo
UVbP1?nAJj<3oi5]YP03oiMaY_nDL:OoU72W00;oU72W2?nCL:P4oi9`Z0CoTg2X0_nDLJT3o`0000?o
UWBZ00?oVGR/ojR@_?nXT;`00_nXT;`4ojbE_P?o[iRo0oo2amh3oko0fP?oTO3H00Go[oK`oiF>bOnE
S/WoUHk9oiYj[P04oiUm/`CoV86i1?nFQ/05oiF=b0;oU9?@0_nMSl@01?nLU<_o0000oibDbonLU</4
oi^JdPGoVZ7I0_nIYml2oj6VfPGoX:gP0_nP]>L3ojRjiQGooooo00?o0000ooooooooool0;Oooool0
013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0dooooo`03ob@00?l0003o000000Co00000_l:
0003oeT0;`;oG`Hl0omS34<3ofD@B0CoIQ9:0_mV4d/01?nBKjOoS6NSohaWXon<Ij<4ohQSX@?oRF>O
1?n=I9h3oi5WWPCoU6VN1?nHK9h2oiU^W`KoVffL1?nJKIh5oiI/X0?oTF^S00CoTFfVoiMaY_nGLJKo
Ug6V1OnDL:L7oi=`Z0CoTW2X0onCL:P3o`0000?oU76Y0_nFM:X00onSRK[oZ92lojR@_003ojR@_0Go
[9Fn00?o[iRool;7g_o2amh00oo2amh00ono`=[oTO3Hoi7`f003oiN7`004oiF>bOnJNZkoVWZ^oiYj
[PGoVGfc0onHPKT5oiJ6`0;oUHg80_nNR[h5oif?a004oibDbol0003oW9C;oibDb`CoVi[B0_nJXMT2
oj:Pd`GoXJKJ0onP[N000onY]>7oZ;[VojRjiP04ojRjiQCooooo00?o0000ooooooooool0;Oooool0
013ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo0_l0000?
ooooo`;o0000;Oooool01?l3003o8`00ob<00?lS0003ob@00003o`000?ld003o000000?o000000?o
2P00odh06_mI02l00_mI02l2oel6?0CoH`a30omU44P3ofHBBP04ofHCBonBKjOoTVnWoi9_Y`?oS6NS
1?n8Hj43ohUSW`CoSFBN0onAIih4oiAYWPCoV6bN00?oVFjOoi]]W?nKKI`01OnKKI`4oiY]WPGoUVbP
0_nAJj<00onJLZCoUg6VoiMaYP03oiMaYPCoU72W1onCL:P4oi9`Z0?o00000_nCL:P4oiAaZ@04oiId
Z_nSRK[oXhVjoj>9^PCoZ92l1?n/UKh2olC>hPCo`/ON00CoGLbPoiR1^?nHPKSoV86h0_nGQl000onK
Mj[oVWZ^oiYj[P03oiYj[PCoVGfc1?nHPKT3oiJ6`003oin7^OnNR[koWXZn00?oWXZn1?nMSl@2oibD
b`04o`000?nLU<_oVi[Boi^JdP;oXi_=1OnRX=<5oj6VfP04oj2]h?nY]>7oZKCQojVdh@CoZ;[V00?o
[l7Wooooooooool04oooool00ol0003oooooooooo`0/ooooo`004?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?ok^k^odA4A?l000001_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo02Gooooo00CoA`00oe`02OmL00WoG0090omN00`4oe@010;o=00000Go0000o`L00?l0003o
0000o`X00002odh06P?oF@0_0_mO1S`4of<<@`?oIA1800CoIQ9:oi]hZ_nKN:[oVgRZ0onBKjL4ohaW
X`?oR6>Q0on9Hil4oheTWP?oTFNN1OnDJIh3oiQ/WPWoVffL0onJKIh5oiI/X003oi5[XonJLZCoVW:T
00GoUg6V1?nDL:L7oi=`Z005oi9`Z?l0003o0000o`000?nBL:P01?nCL:P2oiAaZ@;oWH>f1?nSRKX5
ojR@_003ojbE__o4c^;oa<kR00?oa<kR00?o`/ONoiUl/_nIO;800onHPKP01?nLMJOoVgNZoi]gZ_nK
MjX5oiYj[PCoVGfc1?nHPKT00onFQ/3oWhNioin7^@02oin7^@CoWXZn1?nMSl@3oibDb`03o`000?nS
VlgoXi_=00?oXi_=1OnRX=<2oj6VfP;oZZoL1OnY]>400onX^^Ko[l7Wojo1i`02ojo1ia?ooooo0_l0
000^ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo027ooooo00Co9`00odL00?m7003oA`00
0_mL00T4oeh030?oE0040_ld0002o`L000?o00000_m>01X3oeT0;`?oG`Hl0omS34<2ofD@B0;oXWn]
1?nKN:X3oi9_Y`CoS6NS0on8Hj43ohUSW`CoSFBN1?nAIih4oiAYWP;oV6bN00?oV6^Koi]]W?nKKI`0
1onKKI`4oiY]WP?oUVbP00?oWgFSoiYbY?nJLZ@00_nJLZ@4oiMaYPCoU72W1OnCL:P3o`0000CoTW2X
0onCL:P00onIOK?oWH>foif3]P03oif3]P?oXhVj1?nXT;`00oo4d^Goa<kRolC>hP03olC>hPCoVGbb
00CoV86hoiaeYonLMJOoW7FW1?nKMjX4oiYj[PGoVGfc0_nHPKT00onQQ;CoWhNioin7^@03oin7^@Co
WXZn1OnMSl@01?nLU<_oY9O7o`000?nTUlL4oj>Kc@CoXZ3C00?oZjcGojZ_g?nZ[m`00onZ[m`3ojVd
h@;o/;oU1?n_`NLEooooo`03o`000?oooooooooo02_ooooo000Yooooo`;o00005?ooool00ol0003o
ooooooooo`0Nooooo`;o9`000om70002oe`02@CoGP0<0omD00@2oc@000;o1`000_l000001?lk003o
CP0Jodh06_m>01X3oeT0;`;oG`Hl0_mS34<3oj:1/0?oXWn]1?nKN:X4oi9_Y`?oS6NS0on8Hj43ohUS
W`CoSFBN1?nAIih4oiAYWP03oiQ/W_nHJi_oV6^K00WoVffL1?nJKIh2oiI/X0;oWgFS1?nJLZ@4oiMa
YPCoU72W0_nCL:P3o`0000?oTg2X1?nBL:P01?nCL:SoVGfcoiUm/onIOK<5oif3]PCoXhVj0_nXT;`3
olCBi@?oa<kR00GoVGR]oiUl/_nIO;;oVGbboiadY005oiaeY`?oVgNZ1?nJNZh5oiUm/`04oiR1^OnQ
Q;CoXHBdoj64]0CoWhNi1OnNR[h2oif?a0;oYY?20onTUlL00ol0003oXi_=oj>Kc@03oj>Kc@03oj:P
don[[=OoZjcG00;oZjcG1?nZ[m`00onY]>7o/;oUok2oi@03ok2oi@;o[l7W0_nba^TEooooo`03o`00
0?oooooooooo02[ooooo000Yooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06ooo
ool3obL000?oA`0000?oG009of807OmN01X00omN01X3oe403`;o=00000Co1`00o`@00?l0003o0000
0_lk0002odh06PCoF@0_00?oG`Hloin0/OnRPK001?nRPK03oj9o[@CoVgRZ1?nBKjL3ohaWX`CoR6>Q
0on9Hil4oheTWP?oTFNN0_nDJIh2oiAWW0CoV6^K2?nKKI`4oiY]WP04oiI/X?nOMJ?oWgFSoimeX`Co
VW:T1?nGLJH4oiA`Y`;o00001_nCL:P2oi9`Z0;oUWVa1OnIOK<4oif3]PCoXhVj00?oZ92lolCBiOo4
d^D00oo4d^D01?o4c^;oVGR]oiUh[OnIO;83oiadY0GoW7FW0onKMjX5oiYj[P?oVGfc00?oXh>aoj64
]?nQQ;@00_nQQ;@5oin7^@?oWXZn00?oYi6nojJC`_nVTl800_nVTl84ojBGa`03o`000?nSVlgoXi_=
00;o[JWC1On[[=L2ojZ_g0?o/[kS1?n`_nD00oncb>[o//KYok;6j@03ok;6jACooooo00?o0000oooo
ooooool0:_ooool002Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Gooooo`;o
000000?o9`00odh02Om>00T00omK01H3of807@CoGP0J0_mA00l2oc@000;o100000Co0000oal00?lk
003o>`000om>01X2oeT0;`03oiQk/OnOP;7oWh2a00;oWh2a1?nRPK04oj9o[@?oVgRZ1?nBKjL3ohaW
X`CoR6>Q0on9Hil4oheTWP;oTFNN00?oT6BKoiAWW?nDIi`00_nDIi`4oiQ[V`SoVffL0onJKIh00onT
Mj7oWgFSoimeX`03oimeX`?oVW:T1OnGLJH3o`000003oiA`YonCL:SoTg2X00?oTg2X0_nDMjl4oiIi
/@GoVGfc1OnMPkH2oj>9^P;o`M?X1?o4d^D4oiUh[@GoW7BT1?nLMJL3oi]gZPGoVWZ^00?oVGfcoj>3
/OnSPk400_nSPk43oj64]0GoWhNi00?oWXZnojNA__nWTKh00_nWTKh4ojJC`P?oY9O700?o[jS@o`00
0?n]ZM<00on]ZM<3oj^/e`03okBohonb_^?o/[kS00Co/[kS00?o/;oUok?8j_ncb>X00_ncb>X3ok;6
j@;o/LW/5?ooool00ol0003oooooooooo`0Yooooo`00:Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo01Gooooo00?o0000ocT00?m>00T00om>00T3oe/05P;oHP0M1?mN01X2oe403`04
oc@00?lQ003o1000o`@000?o7`0000?o>`00odh06_m>01X00_m>01X4oiQk/@?oWh2a1?nRPK04oj9o
[@;oVgRZ00?oSVRSohIQX?n6HJ000_n6HJ03oh9LW@CoR6>Q0on9Hil4oheTWP03oi5WW_n@I9_oT6BK
00CoU6NL1?nHJi/8oi]]W0;oVVfN0_nTMj45oimeX`?oVW:T0_nGLJH3o`0000CoU72W0_nCL:P00onF
MjkoU7N_oiAg[`02oiAg[`GoUWVa1?nIOK<5oif3]P03oj>9^_o1dnSo`M?X00;o`M?X00Coa=;UoiYe
Z?nJMJSoVWFX0_nIN:d00onMLj?oW7BToiadY003oiadY0CoW7FW1?nKMjX3oiYj[P03ojB2[onSPk7o
Xh>a00?oXh>a1?nQQ;@3oin7^@03ojZA_?nWTKkoYi6n00?oYi6n1?nVTl801OnTUlOo[jS@ojnXd?n_
Z=3o000000Go[JWC00CoZjcGokBohond_n?o];oS1?nb_^<2okC<k0Co/lSZ00?o//KYok79k?nabN`0
0onabN`Dooooo`03o`000?oooooooooo02Sooooo000Yooooo`?o00005oooool00ol0003ooooooooo
o`0Cooooo`03o`000?li003o>@0000?oCP090omK01H2of807@CoGP0J00?oD@0?oc/00?lQ00000_lQ
00001?l0003o7`00oal00?lO0002oc/00004odh06_nDMk3oU7N`oiAg/0CoV7^a0onOP;45oj:1/0;o
XWn]00CoUW2UohiXXon>J:?oSVRS1?n6HJ03oh9LW@CoPU^L0on5GI/4oh]QV`?oT6BK1?nDIi`4oiQ[
V`SoVffL00CoVVfNojAgXOnTMj7oY7NQ1OnOMJ<2oiYbY0?o00000onGLJH2oiA`Y`;oVGV^1?nFMjh4
oiAg[`CoUWVa1OnIOK<3oif3]P03okc@jOo1dnSo`M?X00;o`M?X1OnJMJP00onIN:goWG>SoiecX`05
oiadY0CoW7FW1?nKMjX01?nJNZkoY8:_ojB2[onTPZl5oj>3/@CoXHBd00?oWhNiojZA_?nZTK`00_nZ
TK`4ojNA_P?oYY?200?o/ZS?ojnXd?n_Z=000on_Z=001Ol0003o[JWCojfYdon]ZM?o]l?S00Go];oS
00?o/[kSokC<k?ndc>`00ondc>`2ok?8jP;o/M3`1?nabN`00on[ankoooooooooo`0Aooooo`;o0000
:_ooool002Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0@ooooo`04o`000?lO
003o>@00ocT000?oCP090omK01H3of807@03oeh06_m=00;oC@0200?o>`000_lQ00001Ol0003o7`00
oal00?lO003o>`0000;oU7J^1?nDMk04oiQk/@CoWh2a1?nRPK000onROjgoUW2UoiI`Y@03ohiXX`Co
QV6P0on2G9d4oh9KW0?oQEfK1?n;HI/3oi1TV`CoU6NL1?nHJi/8oi]]W0GoY7NQ0onOMJ<3o`0000;o
VW:T0onGLJH00onNOZooVGV^oiUi[P02oiUi[PCoUWN^1?nDMjl4oiIi/@GoVGfc00?oWH>fokc@jOnl
d>T00_nld>T01?o1dnSoVG:UoiUbYOnILZD3oiYeZ003oiicX_nMLj?oWG>S00;oWG>S1?nLM:@5oiae
Y`;oVgNZ00?oYX:]ojB2[onTPZl00onTPZl5oj>3/@;oXHBd00?o[9:jojZA_?nZTK`00onZTK`5ojNA
_P04ojJC`_nbZ<oo/ZS?ok:Xc`Go[jS@00?o0000okO3hong`n<00_ng`n<3okBoh`;o]M;_1?ndc>`0
0on`f?Go/M3`ok7@l003ok7@l003ok79k?n[ankoZlO^00;oZlO^5?ooool00ol0003oooooooooo`0W
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00gooooo00?o1000oal00?lO00000_li0000
0om>00WoD006oe001P03oeD030?oEP0<1?m=0082oc/00004ob400?l0003o0000oal000?oUWN]1?nD
MZh4oiAg/0?oV7^a1?nOP;42oj:1/0;oV7>W0onFL:D4ohiXX`?oQV6P0on2G9d4oh9KW0?oQEfK1?n;
HI/4oi1TV`?oU6NL1?nHJi/8oi]]W0GoY7NQ0ol000000onOMJ?oVW:ToiYbY002oiYbY004oiMaY_nN
OZooWWj_oiin[`GoVGV^0onFMjh4oiAg[`GoUWVa0onIOK<2okG9j@?o_=3Y00?oV72SoiUbYOnILZD0
0_nILZD01?nJMJSoWW>RoiicX_nNLj84oiecX`CoW7BT1OnLMJL00onKMj[oYX:]ojJ2[@05ojB2[`Go
Xh>a00CoXHBdojbB^_n/T[[o[9:j1?nZTK`4ojNA_P03okJ[conbZ<oo/ZS?00;o/ZS?1?n_Z=000onj
b^Ko0000okO3h`03okO3h`03okBohoned^oo]M;_00?o]M;_00?o]<c/ok3HmOn`f?D00_n`f?D2ok7@
l0;oZ/gb1On[anhEooooo`03o`000?oooooooooo02Kooooo000>ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool02_ooool2o`@000;o7`0000?o>@00odD00?m@00H00om@00H3
oeD030;oEP0<1?m=0082oc/000;o00000onKNJd4oiIg[@?oU7J^1?nDMk04oiQk/@;oWh2a00?oV7BX
oiQcYonHLjL00_nHLjL4oiI`Y@?oSVRS0on6HJ04oh9LW@?oPU^L0on5GI/4oh]QV`CoT6BK0onDIi`4
oiQ[V`OoVffL00?oYGRQojAgXOnTMj400ol00005oimeX`?oVW:T1OnNOZl4oiUi[PCoUWN^0onDMjl5
oiIi/@03oiUm/onebNWo]LWY00?o]LWY00Co_=3YoiQ`XonHL:?oV72S0onILZD4oiicXPCoWG>S1OnL
M:@3oiaeY`03ojN3[OnVPZgoYX:]00;oYX:]1?nTPZl4oj>3/@03ok2D^on/T[[o[9:j00;o[9:j1OnZ
TK`00onWTKko]Z_?okJ[c`02okJ[c`Co/ZS?00?o[jS@ok[:i_njb^H00_njb^H00ol0003o]l?SokO3
h`03okKLl`;o]M;_0on[hOT2ok3Hm@?oYm?g1?nZcO82oj_7kP?oYL?^5?ooool00ol0003ooooooooo
o`0Vooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Kooooo0_l0000Mooooo`03o`000?oooooooooo00Oooooo00Go0000o`@00?l4003o7`00
ocL00003odD000?oD0060omE00`2oeH030CoC@0200Co>`00ojF;^OnNOJkoWWf^1?nKNJd4oiIg[@?o
U7J^1?nDMk04oiQk/@03oin0/OnHM:SoV7BX00CoV7>W1?nFL:D3ohiXX`?oQV6P1?n2G9d3oh9KW0Co
QEfK0on;HI/4oi1TV`CoU6NL1?nHJi/5oi]]W0;oYGRQ0_l00003ojAgX@GoWgFS0_nJLZ@00onVQ;3o
WWj_oiin[`03oiin[`CoVGV^1?nFMjh4oiAg[`?oUWVa0_n^`^T4okG9j@GoV72S0_nILZD00onNLj7o
WW>RoiicXP03oiicXP?oWG>S1OnLM:@2oiaeY`;oYh>]1?nVPZd5ojB2[`;oXh>a0on`U;/3ojbB^PCo
ZY6l00?o^[;AokJ[confZll00onfZll3ok:Xc`;o_]K/1?njb^H00on`ioSo0000okKLl`02okKLl`;o
WnSk0on[hOT2oj3In`GoYm?g0_nZcO82oj?6lPGoYL?^5?ooool00ol0003oooooooooo`0Uooooo`00
3_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000o`@00?lV00000_lg0003odD000?o
D0060omE00`00omF00co3`00o`000002o`0000;oZXnj00?oXH2_oiim[_nNOJh00_nNOJh3oi]i[@Co
UWN]1?nDMZh3oiAg/0;oV7^a0_nFLZP4oiQdZ0?oV7>W1?nFL:D3ohiXX`CoQV6P0on2G9d3oh9KW0Co
QEfK0on;HI/4oi1TV`CoU6NL1?nHJi/3oi]]W005oj=hX_l0003o0000o`000?nUN:401?nTMj45oime
X`04oiYbY?nVQ;3oYXB`ojJ4/0CoWWj_1?nINJh4oiIg[PCoU7N_00?oUWVaojk2jOn^`^T00on^`^T0
1?nebNWoV6jQoiQ^XOnHKZ44oiQ`X`03oiUbYOnNLj7oWW>Q00GoWW>R0onMLj<5oiadY003oiaeYonW
PjgoYh>]00;oYh>]0onVPZd5ojB2[`03oj>3/On`U;_o/9Bk00;o/9Bk1?n/T[X2ojZA_0?o^[;A1Onf
Zll00onbZ<oo_]K/okkFk002okkFk003ok[:i_n`ioSo/>Oh00;o/>Oh00?o0000oioXnonOj?/00onO
j?/00on[hOWoX=Wkoj3In`02oj3In`;oYm?g0_nPb?@5oj?6lP;oYL?^0_nQ_^dEooooo`03o`000?oo
oooooooo02Cooooo000>ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`04ooooo`03o`000?oooooooooo01kooooo0_l00003ooooo`;o00000_lV0002ocL000?oA@0000?o
D006obH00?lM00000_lM0003o`l00004o`000?n^U;co[YBlojZ?^P?oXH2_1?nNOJh4oi]i[@CoUWN]
0onDMZh2oiAg/003oiA`YonFLZSoUW:X00;oUW:X1?nHM:P3oiQcY`CoUW2U0on>J:<4ohIQX0?oPUbM
0on2Fi`4ohEMV`?oRf6K1?n@I9/4oiAWW0CoV6^K00CoVffLo`000?l0003o00001?nUN:45ojAgX@?o
WgFS00?o/8faojJ4/?nVQ;000_nVQ;04oiin[`GoVGV^1?nFMjh2oiAg[`;oZ;cX1?n^`^T5oiQ^X@?o
V72S00?oWW:QoiicXOnNLj400_nNLj44oiicXPCoWG>S0onLM:@00onYQ:goYh>]ojN3[@03ojN3[@?o
YX:]1?nTPZl00oncV[go/9Bkok2D^`03ok2D^`Co[9:j00?oZY6lokZbdOnj/]400_nj/]44okJ[c`03
okgXlonne^co_]K/00;o_]K/0_nOkoH2ok3Wn0;oQ>Ob00Co0000ohCWl_nOj?_oWnSk0onDg?h2oj3I
n`;oW<Wg1OnPb?@2oj?6lP?oX;k^1?nQ_^dCooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`02Oooool000kooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00?ooooo0_l0000Qooooo`?o00000olV
00001?lg003o9@00obP00?lX0003obH00003oad00?n`W<?o/9c300?o[iRo0on^U;`00onSQ;;oXH2_
oj60[`03oj60[`?oWWf^1?nKNJd4oiIg[@;oU7J^00CoUG2VoiA`YonDL:OoU72W1?nFLZP4oiQdZ0Co
V7>W0onFL:D3ohiXX`CoQV6P0on2G9d4oh9KW0?oQEfK1?n;HI/3oi1TV`CoU6NL0_nHJi/3o`0000?o
XgRR1?nUN:45ojAgX@;oWgFS0_n`SK44ojJ4/0GoWWj_1?nINJh2oiIg[P?oY[[X1?nX_>P00on^`^Wo
VFjOoiU^W`05oiQ^X@04oiQ`XonNLZ7oWW:QoiibX@CoWW>Q1?nNLj84oiecX`;oW7BT0_nYQ:d5ojN3
[@CoYX:]0_nTPZl3ok>J_@Go/9Bk0_n/T[X00ono_=So^[;AokZbd@04okZbd@03okJ[conmj??o_NSc
00;o_NSc00Co_]K/oio_m_nOkoKoWnof0omCd=42ohCWlP03oh?Ko_l0003oPm_n00;oU=cn0onFaoP4
oic9m`;oX<Sd0onN_>h5oj2nkP;oXKk]0_nQ^n/Dooooo`03o`000?oooooooooo00Gooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Wooooo
000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo0_l0000Qooooo`05odC1YolB003o4P00obH00?lM00000olU0002obP00003obH00?naXLOo/9c3
00Co/9c31?n_V;l00on^U;coXhBboj>4/P05oj60[`?oWWf^1?nKNJd3oiIg[@04oiIaY_nEL:KoUG2V
oiE`YPCoU72W0onFLZP4oiQdZ0CoV7>W1?nFL:D3ohiXX`?oQV6P0on2G9d4oh9KW0?oQEfK1?n;HI/3
oi1TV`?oU6NL0ol000000onHJi_oWgJToj=hXP04oj=hXP?oYGRQ1OnTMj400onOMJ?o/8faok2=/@02
ok2=/@?oYXB`1OnNOZl2oiUi[P;oZ;gX1_nV^^P2ojRlj003oiM[W_nIKYooVFjO00;oVFjO0onHKZ40
0onNLj;oWW:QoiibX@02oiibX@CoWW>Q1?nNLj84oiecX`03oiadY?nYQ:goZHB]00;oZHB]1?nWPjd4
ojJ2[@03ojB2[oncV[go/iZm00;o/iZm1On`U;/01?n/T[[o_kcHoknlf?no_=P4okZbd@;oZ_K^0_nm
j?<2ofkOe`03o`000?mQbo[oHL_j00;oHL_j0_m^do/2oi2gl@;oT/7f00?o0000oi;1m_nFaoP01?nF
aoP2oic9m`;oWKW/1OnN_>h2oj2nkP;oX;OY1OnQ^n/Dooooo`03o`000?oooooooooo00Cooooo00Go
410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000002Oooool000kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool00ol0
003oooooooooo`0Oooooo`03odC1YolB003o7@0000;o7@000olU00000olX003o_lSQol35gP03ok6Q
a`Co/9c30on_V;l00onSQkKoXhBboj>4/P02oj>4/PCoXH2_1?nNOJh3oi]i[@04oiIg[OnFLJKoUW6V
oiIaYPCoUG2V0onDL:L4oiIbZ0?oV7BX1?nHLjL4oiI`Y@?oSVRS0on6HJ03oh9LW@CoPU^L0on5GI/4
oh]QV`?oT6BK0ol000000onDIicoV6^KoiQ[V`02oimfY0GoXgRR0onUN:45ojAgX@Go/8fa1?nVQ;03
oiin[`03ok78jonX_NSoZ;gX00?oZ;gX1?nV^^P4oiM[WPCoVFjO0_nHKZ42oiicXPGoWW:Q0onNLj45
oiicXP?oWG>S1OnYQ:d5ojN3[@;oYX:]00?o^J?3ok>J_OncV[d00oncV[d4ok2D^`03olC?hono_=So
_kcH00?o_kcH00Ko^[;Aoj[fk_nZm^koZ_K^o`000?m_^O`2oek2o0;oTicJ1?nAZnL5oi2gl@;oT/7f
00Co0000oi;1m_nFaoSoU/Oh0_nK]>T5oifik0;oW[c^0_nP/nH5oj2gj@?oXK_[00?oY;_Zoooooooo
ool04_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002oooool01Olb
<S;oV9RHoooooonHV9So<S8b00Wooooo000Wooooo`03o`000?oooooooooo01gooooo00Go0000oa40
0?lA003o7@00okoWlP03oko9hP?o_lSQ00?o/ZK<ok6QaonaXLL00_naXLL5ok2L``03ojnH_onSQkKo
XhNf00CoXhBb1?nQP:l4oiim[P;oVgV]00?oV7:WoiIaY_nFLJH00_nFLJH4oiE`YP?oU72W1?nFLZP4
oiQdZ0?oV7>W1?nFL:D3ohiXX`?oQV6P1?n2G9d3oh9KW0?oQEfK1?n;HI/3o`000005oi1TVonDIico
U6NLoiAWW?nHJi/00onOMZ@5oj=hXPCoYGRQ0onTMj400onjUk?o/8faok2=/@03ok2=/@CoYXB`00?o
WWj_ok78jonab>/00_nab>/5ojRmj003ojJjj?nEJIcoUFVL00CoUf^N1?nIKYl01?nHKZ7oWW>Roiic
X_nNLj85oiibX@?oWW>Q1OnNLj82oiecX`03ojb7[onYQ:goZHB]00?oZHB]1OnWPjd01?nVPZgo^J?3
okVS`oniXl<5ok>J_@;o/9Bk0oo4cn<3oknlf004oec?[On1Z>koVhRnoi^8_P?oUi7;1OnCW=X4oi6[
i`;oT;Oa0_nLYM`2oib^i003o`000?nL[^CoW:kT00CoVkCY0_nM^N`2oj6_hPGoX;?V1?nP]nT00onQ
^n_oY;_ZojBkjP02ojBkjQCooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000_ooooo00Goc<c<o`000?l0003o0000olc<c009ooooo`009oooool2o`0001_ooooo00Co0000
o`800?l2003o4@000_nni?800onoio;o_lWRoko9hP03oko9hP04oko8hOnbY/co/ZK<ok:Vc0Co/J77
0_n`W<<2ojB;^PCoXhNf0onSQ;85oj60[`;oWWf^00CoVGFXoiQbYonHLZOoV7:W1?nFLJH4oiE`YP?o
U72W1?nFLZP4oiQdZ0?oV7>W0_nFL:D2oheZYP?oQ6>U0omkFj<4oh9LW@?oPU^L1?n5GI/00on;HI_o
0000o`000004oi1TV`;oU6NL00?oVG:UoimfY?nOMZ@00onOMZ@4oj=hXPCoYGRQ0_nTMj43okZG/`Go
/8fa0_nVQ;02okkKkPGo/LS[0_nX_NP2oiEXV`?oUFVL1OnGJih3oiU^W`GoWW>R1?nNLZ43oiicX@Go
WW>R00CoWG>Sojb7[on/Qjoo[8N_1?nYQ:d4ojN3[@03ol6dc_niXl?o^J?300;o^J?31OncV[d00on`
U;_oa<oSolC?h`02olC?h`03oknlf?n?UmOoWh>e00CoVhRn1?nGTL/5oi>LfP;oTJ_W00?oWikCoibU
g?nLYM`00onLYM`2oib^i003o`000?nL[^CoW:kT00;oVkCY00?oXJWLoj6_h_nQ[n800onQ[n84oj2c
iP;oX;OY0onT]nL4ojBkjQGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4009ooooo`009oooool00ol0003oooooooooo`0G
ooooo`04o`000?nQl_;oXO;boj7blPCo_^Cb0_nob^<4oko9hP03okBZconbY/co/ZK<00;o/ZK<0ona
XLL00onUSkkoY8^jojB;^P03ojB;^P?oXhNf1?nSQ;84oj60[`03oiim[_nIMJSoVGFX00CoV7:W0onF
LJH4oiE`YP?oU72W1?nFLZP4oiQdZ0;oV7>W00?oTVnXoheZY_n=JZH00_n=JZH3ohASY@?oNe^S0_mj
FZ42oh9LW@?oPU^L0_n5GI/3o`0000;oRf6K1?n@I9/00onDIicoVG:UoiUbY@05oimfY0CoXgRR1?nU
N:400onTMj7o^YNcokZG/`02okZG/`Go/8fa00?oYXB`okkKk_nnfnh00_nnfnh2ok78j`;oUVRJ1?nE
J9/3oiEYW0GoUf^N0_nIKYl00onPMJ?oWW>RoiicXP03oiicXPCoWW:Q1?nNLj43oiicXP03ojj=/_n/
Qjoo[8N_00;o[8N_1OnYQ:d2ojN3[@?o`KC>0oniXl<4ok>J_@;o`n_a0oo4cn<00on?UmOoWh>eoin3
]@02oin3]@CoVhRn1?nGTL/2oi>LfP;oXYO91?nOW]<5oibUg0;oW:kT00?o0000oj:TeonQZM`00onQ
ZM`5oj6_hP;oX;?V0_nT]>@5ojBgi`;oY;_Z0_nW_NTBooooo`?o00001?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000009ooooo`009oooool00ol0003ooooo
ooooo`0Aooooo`?o>KkF0_n2inl3oj[_m`Co_]o`00?o_^Cboko:honob^<00_nob^<00onobN;o]:[?
okBZc`02okBZc`Co/ZK<00Co/J77ojF?__nUSkkoYHnn1?nTRkX3oj>7]PCoXhBb0_nQP:l2oiYgZ`?o
VGFX1?nHLZL4oiIaYP?oUG2V1?nDL:L3oiIbZ0;oV7BX0_nFLZP3oi9_Z0CoSFZV0on4HjD3og]KX`Co
NUZQ0_n2Fi`3o`0000;oQEfK0on;HI/2oi1TV`;oTfjU0onILZD5oimfY0GoXgRR0onUN:45okZG/`Co
/8fa0_o9ln`3okkKkP;oVFVI0onFJ9X4oiEXV`CoUFVL1?nGJih00onIKYooX7FSoj1eX`05oiicXPCo
WW:Q1?nNLj42oiicXP;o[Xfb1?n/Qjl5ojV4[@03ojN3[Oo1]<ko`KC>00;o`KC>1?niXl<00oncV[go
`n_aol?[l@03ol?[l@03olC?honSPJooWh>e00CoWh>e1?nKR;h3oiNAb`03ojJC`_nRUlWoXYO900;o
XYO91OnOW]<2oibUg0;oY9o@0_nRY=L00ol0003oXZCGoj:Te`04oj6Yg0;oXJoR0_nV/N05ojBdi0;o
Y;OW0_nW^^L5ojNmjACooooo00Wo0000ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY00Wooooo000Vooooo`?o00003?ooool4oec;m`;oC<OZ00Co
G=?Uoh;Wkon2inooP^O_0onZkoL4okkOl0;o`<[R0onob^<2okJ_d@Co]:[?0onbY/`00onWU<;oYHnn
ojF?_P02ojF?_PCoY8^j1?nSQkH2oj>4/P03oiYi[_nJMj_oVWN[00;oVWN[0onIMJP4oiQbY`CoUW6V
1?nEL:H3oiA`Y`;oUW:X00?oUg>XoiIbZ?nFLZP00_nFLZP4oi9_Z0?oSFZV1?n4HjD2og]KX`?oNUZQ
0ol000001OmmG:;oQ6:SohARXon4HZ?oQEfK00;oRf6K00?oSFVToi=^YOnCKZD00_nCKZD4oiUbY@Co
WgJT1OnSN:82ojEhX@;o_Z6k1OnjUk<2ok2=/@CobO?/00Co_]_^oiUYVOnIJIWoVFVI0onFJ9X4oiEX
V`CoUFVL0onGJih00onQMjCoX7FSoj1eX`02oj1eX`CoWW>R1?nNLZ44oiicX@03oiicX_n^SK;o[Xfb
00;o[Xfb0on/Qjl4ojV4[@03ol_DhOo1]<ko`KC>00?o`KC>0oniXl<3oi7`f@;o`n_a00?oWX>foiN:
a?nSPJl00_nSPJl4oin3]@CoVhRn00?oUi7;ojJC`_nVTl800_nVTl84oj:Gb@?oWikC00?oYic;ojBO
d?nTWm000onTWm02oj:Te`04o`000?nRY=OoXJWLoj6Yg0;oYjgL1OnV/N02ojBdi0?oZ;ST1?nW^^L2
ojNmj@;oZ/3Y5Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`02oooo
o`?oN[ck1?mca?h2ofW9oPCoP=Sn0_m`fOH3oi;WnP?o/>Wh0onof^h00onngo3o`<[Rol3:hP03ol3:
hP03oko:honf[m7o]ZoA00;o]ZoA1?ndZ/l01?nbY/coYiC2ojND`_nWU<83ojF?_PGoY8^j0onSQkH0
0onSQ;;oVWV^oiYi[P04oiYgZ`?oVGFX1?nHLZL4oiIaYPCoUG2V0_nDL:L4oiMcZ0GoUW:X0onBKjP3
oheZYPCoQ6>U0_mkFj<3o`000004ogYJXOmmG:;oOEbRogeLXPCoQ6:S0on=JJ@5oi=^Y@?oVG:U1?nO
MZ@5oj=hXP04ojEhXOnnXK_o_Z6kokjQ^`Go^YNc00Go/8faolWck?o9lncobO?/oi]YV005oiUYV@?o
UVRJ1OnEJ9/3oiEYW0;oUf^N0_nQMj@4oj1eX`CoWW>R1OnNLZ43oiicX@Go[Xfb1?n/Qjl2ojV4[@?o
bmCQ1Oo1]<h01?niXl?oTO3Ioi7`fOnSP:h3oij3]P03ojR2[?nSPJooXh6_00;oXh6_1OnOPkD2oi^8
_P03oj^B_?nVTl;oYY?200?oYY?21?nRUlT00onOW]?oYic;ojNLb`02ojNLb`GoY9o@0_nRY=L00ol0
003oYjgLojN]g003ojN]g0?oY[7P00?oZ[ORojRhi?nX^>@01?nX^>@2ojNji`;oZkoX1?nZ`>TDoooo
o`03o`000?oooooooooo01kooooo000Kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0
003oooooogncm@02ogncm@CoN[ck0_mca?h4oh[@o`;oP=Sn0onLhOd3ok?PmP03ok3Yn?nof^ko_m[^
00;o_m[^0oo0bN43ol3:hP03okVcdonf[m7o]ZoA00Co]ZoA0_ndZ/l00onZVLKoYiC2ojND`P02ojND
`PCoYHnn1?nTRkX2oj>7]P03oiUl/OnJNJkoVWV^00;oVWV^0onJMj/4oiUeZ0?oV7:W1?nFLJH4oiE`
YP03oiA`YonGLjSoUg>X00CoUg>X1?nFLZP3oi9_Z0CoSFZV0_n4HjD3o`000004og]KXomjFZ7oNUZQ
ogYJX@?oOEbR1?n4HZ<3oheYY0GoTfjU0onILZD5oimfY0?oXgRR00?o`K39okjQ^onnXK/00_nnXK/4
okZG/`;o_?gC00?oVFNGoi]YV?nKJIP00_nKJIP4oiUYV@?oUVRJ1OnEJ9/3oiEYW004oiM[W_nQMjCo
XGNToj5gY0CoX7FS1?nNLj85oiibX@;oWW>Q00?o/I>hojj=/_n^SK800on^SK84ojb7[`03ojV4[Oo;
e>7obmCQ00;obmCQ1?o1]<h00onWOjWoXh2^oj>0[P02oj>0[P04oij3]_nXPZcoZ8:/ojR2[0CoXh6_
1OnOPkD01?nKR;koZi:loj^B_?n[T[`5ojJC`P;oXYO900?o[9_6ojNLbonWW</00onWW</4ojBOd005
ojj[eOnZZmSoZZ_HojZ[f?l000001OnW[M`01?nV/N3oZ[ORojZgh_nZ]n84ojRhi003ojboj?n[_nSo
ZkoX00?oZkoX0_nZ`>T2oj_2jaCooooo00?o0000ooooooooool07Oooool001_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00?oOk?e0_mj_?/4oi35n@;oR]3o1?nReoX0
1?nLhOgo/n3fok?Pm_nch?H4okkEj`03okoJk_o0bN7o`<WQ00?o`<WQ00Co`<[RokVcdoni/m?o^K?C
1?nf[m400on]WlWoZYW6ojZIaP02ojZIaP?oYiC21?nUSkh2ojB;^P;oVWne0onIO;44oiYi[PCoVWN[
0onIMJP4oiQbY`?oUW6V0_nEL:H2oiQcZ0OoUg>X1?nFLZP3oi9_Z0?oSFZV0ol000001?n4HjGoNe^S
og]KXomkFj<3ogYJX@CoOEbR0on4HZ<4oheYY0CoTfjU0onILZD5oimfY0;oXgRR0oo1/<T4okjQ^`;o
^YNc00Co_?gCohaKTonIIiOoVFNG1?nKJIP4oiUYV@?oUVRJ1OnEJ9/2oiEYW003oj5hYOnQMjCoXGNT
00?oXGNT0onPMJ<5oiicXPCoWW:Q00CoWW>Qok6C^?naTkSo/I>h1On^SK82ojb7[`;o^o_X1Oo;e>40
1?o1]<koYgnYojMoZOnWOjT4oj>0[PGoZ8:/1?nSPJl3oin3]@03ok2C^On[T[coZi:l00;oZi:l1?nV
Tl800onaW/Go[9_6ojbKaP02ojbKaPGoYic;00CoY9o@ojj[eOn^ZmGo[Z_E0onZZmP01?l0003oZZ_H
ojN]g?nW[M`2ojfgh0GoZ[OR00?oZ;STojboj?n/_nP00_n/_nP3oj^oj003ojc3jon[`^_oZl;[00?o
Zl;[4oooool2o`0001kooooo000Kooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0000;o
oooo1OnC^_82oi35n@?oYL_d0_nReoX4okCFl@03ok?Pm_nneN_o_]G[00;o_]G[0_o1b>04ol39h@03
ok^geOni/m?o^K?C00?o^K?C00?o]ZoAojfObOn]WlT00_n]WlT3ojZIaPCoYiC20_nUSkh00onKPkSo
VWneoiYo]@02oiYo]@CoVGba0onJNJh4oiYgZ`?oVGFX1?nHLZL2oiIaYP03oiQdZOnHLjSoV7>X00;o
V7>X1onGLjP4oiIbZ0?oTVnX0ol000001?n=JZKoQ6>UohASYOn4HjD3og]KX`?oNUZQ1?mmG:83ohAR
X`CoSFVT1?nCKZD3oiUbY@GoWgJT00?oXgRRol6`bOo1/<T00_o1/<T4okjQ^`03okZG/on<FY;oS5^C
00?oVFNG1?nKJIP4oiUYV@CoUVRJ1?nEJ9/00onEJIcoXGRUoj5hY@05oj5gY0?oX7FS1OnNLj83oiib
X@03okFN`?naTkSo/I>h00;o/I>h1On^SK800on/Qjoo^o_Xok_kj002ok_kj0;obmCQ0_n/PZL4ojMo
Z@CoXh2^1OnXPZ`4oj>1[`03oin3]On`TkWo/9>i00;o/9>i0on[T[`3ojJC`P?o/Ik50on/VlH4ojNL
b`03ok:]don^ZmGo[Z_E00?o[Z_E0onZZmP00ol0003o[KOPojfgh003ojfgh0;oZ[OR0_n]`>L5ojbo
j003oj^oj?n/`n_o[<?[00;o[<?[0on[`^/00on[`n_oooooooooo`0@ooooo`03o`000?oooooo0000
01kooooo000Kooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02oooo
o`;oTk[b0onU_n`3ojG;m0?o]<c/0onde_44okk?i`03okkEjoo1b>3o`LSP00;o`LSP00?o`<WQok^g
eOnk]mD00_nk]mD3okVcd`03ok6Uc?n]WlWo[Io900?o[Io91?nZVLH2ojND`P04oif7_?nKPkSoVh>h
oi^3^0CoVWne1?nIO;43oiYi[PCoVWN[0onIMJP4oiQbY`03oiIaY_nHM:WoV7BY00CoV7>X1onGLjP4
oiIbZ004oi9_Z?l0003o0000oi9_Z0?oSFZV1?n4HjD2og]KX`CoNUZQ0ommG:83ohARX`CoSFVT1?nC
KZD4oiUbY@?oWgJT00?o_l?Mol6`bOo1/<T00oo1/<T3okjQ^`;oS5ZB00?oU6>FoiUWUonIIiL00_nI
IiL4oi]YV0CoVFVI1?nFJ9X3oiEXV`03oj=kY_nQN:GoXGRU00;oXGRU1?nQMj@3oj1eX`GoWW>R00?o
WW:QokFN`?neW/000_neW/03ok6C^0Co[Xfb0ol00002ok_kj003oiQ]WonEKjGo[8:W00;o[8:W1OnW
OjT2oj>0[P;o[hR/1?nXPZ`4oj>1[`Go/9>i1?n[T[`00onVTl;o/Ik5ok6Na@02ok6Na@Co[9_600?o
Yic;ok:]donb[M<00_nb[M<4ojj[e@05ojZ[f?n`^N3o/;WPok2ih?l000000on]]n02ojo3j0Co[L3W
0_n/_nP3ojc5k0Co[<?[00?oZl;[oj_3jon[`n/00_n[`n/Dooooo`03o`000?oooooooooo01_ooooo
000Kooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`GoYKo/
00?oYL_dokC<k?ndc>`00ondc>`00onde_7o_/oWokk?i`02okk?i`;o`LOO0oo1b>02okfje`Go^kOE
00Co^K?Cok6Uc?naYLco/JG<1?n]WlT3ojZIaP03oj2=`?nMQkcoWHNl00;oWHNl0onKPkP4oiYo]@?o
VGba0onJNJh4oiYgZ`?oVGFX0_nHLZL2oiMeZPCoV7BY0onHLjP7oiMcZ0;oUW:X0ol00003oi9_Z0?o
SFZV1?n4HjD2og]KX`CoNUZQ0ommG:84ohARX`?oSFVT1OnCKZD3oiUbY@;oWgJT0ono`md5ol6`b@03
okjQ^on=Fi;oS5ZB00;oU6>F1?nIIiL4oi]YV0CoVFVI1?nFJ9X2oiEXV`;oXg^V1?nQN:D4oj5gY0Co
X7FS0onNLj800onk[lgo]Ik0okFN`003okFN`0Co/I>h0_n^SK82oiY/W0GoV6fO1?n/PZL5ojMoZ@04
oj>0[_n_R:co[hR/ojn8[0GoZ8:/0_nSPJl2okNI^@Co/9>i0on[T[`00oniY/Ko/Ik5ok6Na@03ok6N
a@?o[9_600?o]k?Dok:]donb[M<01?nb[M<2ojj[e@;o];kQ0on`^N000ol0003o[KOPojo3j004ojo3
j0;o[L3W0_n]bNh5ojc5k0;o[<?[0_n[aNd3oj_3j`03ojW2k?oooooooooo01?ooooo00?o0000oooo
ooooool06_ooool001_ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo
00Gooooo0onU_n`3ok?2iP?o]<c/0onmbN@00onncnOo`LOOol77g`03ol77g`03ol78h?nm^]Oo_K[G
00;o_K[G0onk]mD00ondZloo/JG<ok6Uc002ok6Uc0Go[Io900CoZYW6oj2=`?nPSL3oX8g00onMQk`3
oi^3^0CoVWne0onIO;44oiYi[P?oVWN[0_nIMJP00onGMZcoUgFZoiMeZP02oiMeZPCoV7BY1?nHLjP5
oiMcZ0?o00000onFLZP3oi9_Z0?oSFZV1?n4HjD3og]KX`?oNUZQ0ommG:84ohARX`?oSFVT1OnCKZD3
oiUbY@03oimfY?no`mgo_l?M00;o_l?M1?o1/<T00on=Fi;oSenEohmOU@03oiASUPCoVFNG1?nKJIP5
oiUYV@?oUVRJ00CoUFRKoj=kY_nSNjKoXg^V1?nQN:D4oj5gY0CoX7FS0_nNLj83ok^_c@Co]Ik01?na
TkP00on^SK;oVVbLoiY/W002oiY/W0?oV6fO00?o/HJXojb2Yon/PZL00_n/PZL5ojMoZ@Co[hR/1OnX
PZ`01?nSPJoo]iViokNI^OngVKT5ok2C^@04oj^B_?niY/Ko^JK6okVVaPGo/Ik500Co[9_6okNce?ng
/mCo]k?D1?nb[M<00ongb>Oo];kQokBnh@03okBnh@;o/;WP00?o/<S[o`000?n_`nP00on_`nP00on]
c_7o[LW^ojg9kP03ojg9kP;o[<G/0_nZanl5oj_5k@04oj_3jonY`^coZL;/ojW2k1Cooooo00?o0000
ooooooooool06_ooool001_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00001oooool0
0onU_nco/l;Vok?2iP03ok?2iP03okC<k?nmbNCo_LWT00;o_LWT0_o1a]h3ol77g`03oknmfOnm^]Oo
_K[G00Co_K[G00Co^kOEokB[condZloo]:_?1?naYL`2ojfOb@;oY9?31?nPSL03oif7_0?oVh>h1?nJ
OkD4oiUl/@?oVWV^0_nJMj/01?nDMjooUgJ/oiMf[?nGMZ`4oiMeZPCoV7BY1?nHLjP2oiMcZ0?o0000
0_nGLjP2oiIbZ0;oUWN^0on@Ljl3ohM_/0CoNVRc0_m[H[H01?mkFj?oNUZQogYJXOmjFZ43ogeLXPCo
Q6:S1?n=JJ@4oi=^Y@;oVG:U0_n_d_85oko3g@03ol6`bOn8FiKoSenE00?oSenE0onDHiH4oiUWU`Co
VfVH1OnIJIT3oiIXVPGoXg^V0onQN:D5oj5gY0?oX7FS00?oWW>Rok^_cOnk[ld00_nk[ld5okFN`0;o
/I>h0_nMKY/4oiY/W0;oV6fO0onaQZP3ojb2Y`CoYgnY00?o^9>aojn8[?n_R:`00_n_R:`5ojR2[0Co
]iVi1?n`TkT00oo2]loo^JK6okVVaP02okVVaPCo/Ik500?o_;kKokNce?ng/m@00ong/m@00onb[M?o
]lSWokO8i`02okO8i`?o];kQ00?o/M3`ok38jon`b>/00_n`b>/00ol0003o[l?Xojg>l@03ojg>l@;o
[LW^0_nYb_45oj[7k`;oZlG]0_nXaNh5ojW2k1Cooooo00?o0000ooooooooool06Oooool001_ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo00Oooooo1?nc`^H2ok_4h0?o
_LWT1?o1a]h01?o1amoo_kgIoknmfOno_MT4okfje`03okNadondZloo]:_?00;o]:_?0onaYL`00onX
VLOoY9?3ojBC``03ojBC``?oX8g01?nMQk`3oi^3^0?oVWne1?nIO;42oiYi[P04oi9h/_nDMjooU7N_
oiAg[`CoUgJ/0onGMJX4oiQdZ@?oV7>X0ol00004oiMcZ003oiUj[onFMjkoUWN^00;oUWN^0on@Ljl3
ohM_/0CoNVRc0om[H[H3ogYJX@CoOEbR0on4HZ<4oheYY0?oTfjU0_nTcoH4ojoBlP;o_l?M00CoPeRG
ohQKU_n8FiKoR5^F1?n?GiD3oiASUPCoVFNG1?nKJIP5oiUYV@;oUVRJ00?oZ86Zoj=kY_nSNjH00onS
NjH3oj5hY@GoXGNT0_nPMJ<00oo3c^?o^jo=ok^_c@03ok^_c@Co]Ik000?oXW:Loie^VonMKY/00_nM
KY/4oiY/W003oiQ]WonaQZSo/HJX00;o/HJX1?n/PZL2ojMoZ@?o^9>a0on_R:`4ojR2[0;o_ZBo1?ng
VKT2ok2C^@;o`[O?1OniY/H00onaW/Go_;kKokbnf`02okbnf`?o]k?D0_njfO04okO8i`03okBnhOna
d?3o/M3`00;o/M3`0_n`b>/2oj[DmP04o`000?n]c_7o[Lkaojg>l@;oYlgd1?nYb_42oj[7k`?oZ<K`
1?nXaNh2ojW2k0;oYl7/5?ooool00ol0003oooooooooo`0Iooooo`009Oooool00ol0003ooooooooo
o`08ooooo`03ok?2i_nka>3o^lCP00?o^lCP00?o_LWTol76g_o1a]h00_o1a]h00oo0`M[o_kgIoknm
f@03oknmf@03okfjeong/M?o]k7C00;o]k7C1?ndZll01?naYLcoZ9W7ojRIaonXVLL4ojBC``CoX8g0
0onMQk`3oi^3^0;oVWne00?oTGbioi5j]_nAN[H00_nAN[H3oi9h/PCoU7N_0onGMZ`4oiMeZP?oV7BY
0ol000000onHLjSoUg>XoiMcZ003oiMcZ0;oVGZ_1?nFMjh4oi1c[`?oQfn`1?mjJ;<2of]R]P?oJfRm
1?mmG:83ohARX`CoSFVT00?oTfjUojC?m_nTcoH00onTcoH2ojoBlPCoPeRG0on8FiH4ohmOU@CoU6>F
1?nIIiL3oi]YV0GoVFVI00CoUVRJojR1Z_nXPJ[oZ86Z1?nSNjH4oj5hY@CoXGNT00CoX7FSol?>hoo3
c^?o`lkS1Onk[ld01?neW/3oXW:Loj9bW?nRLY`5oie^V`?oVVbL1OnaQZP4ojb2Y`03ojMoZOnhTk7o
^9>a00;o^9>a1?n_R:`2ojR2[0?o_ZBo1?ngVKT00on`TkWo`[O?ol:gc`02ol:gc`?o^JK60_o1e>P4
okbnf`03okNce?njfO3o^]W`00?o^]W`0_ngb>L3ojcJm`;o/M3`0_nTf_/3oj[DmP03o`000?nZe?Ko
[Lka00CoYlgd0_nYb_42ojK8l@GoZ<K`0_nXaNh2ojK2k@CoYl7/4_ooool00ol0003oooooo`00000J
ooooo`009Oooool00ol0003oooooooooo`0:ooooo`?o^lCP0_o0a=d3ol76gP?o`<7J0ono_MT2okZg
ePGo]k7C0_ndZll00on/X<coZ9W7ojRIa`02ojRIa`CoY9?31?nPSL02oif7_004oiB4__nBOkcoTWnl
oi9o_0?oTGbi1?nAN[H4oi9h/P?oU7N_0onGMZ`4oiMeZP?o000000CoV7BYoiQcZ?nHLjSoV7>X0_nG
LjP2oi]m/0CoVGZ_0onFMjh4oi1c[`?oQfn`1?mjJ;<3of]R]P;oJfRm0omfN/X00ommG:;oQ6:SohAR
X`02ohJFg0GoW;S/0_nTcoH00on5FiWoPENHoh5GV002oh5GV0?oPeRG0on8FiH4ohmOU@CoU6>F1?nI
IiL4oi]YV0CoVFVI1?nXPJX4oj=kYPCoXGRU0onQMj@2okoel0Co`lkS0_nk[ld3ojMhW`?oXW:L1OnM
KY/3oiY/W0Go/HJX1?n/PZL5okRC/@Co[hR/00?oZ8:/okjT_onnY;l00_nnY;l4okNI^@Go`[O?00?o
^JK6ol7Dj?o1e>P00oo1e>P2okbnf`?oZnci0_njfO03oi_So@;o[=[g0_nFg_h5ojCJn`;oZ]Cf00?o
Xm3go`000?nSd?L00_nWcO@2oj?9l`GoY/Sa0_nXa_02ojG2kPGoY/;]0_nW`N`2ojJok1Cooooo00?o
0000ooooooooool05oooool002Gooooo0_l0000<ooooo`03ok_4h?o0a=go`<CM00;o`<CM00?o`LKN
ol31f_o0`MX00oo0`MX00ono_MWo^[OFokZgeP02okZgeP?o]k7C00?o[jS@ojbPc?n/X<`00_n/X<`3
ojRIa`GoY9?30_nPSL000onHRL;oU8BnoiB4_P02oiB4_P?oTWnl0onAO;T3oi5j]PCoTWRb0onDMjl3
oiMf[0;oUgFZ0_l00004oiQdZ@;oV7>X00?oW7ncoi]m/?nKOK000_nKOK04oiUj[`CoUWN^0on@Ljl3
ohM_/0CoNVRc0om[H[H3of]X_@?oMW[:1On6U]`3oibhk004ohYPVon5FiWoQE^IohEKV@CoPENH0on3
F9L3ohQKUPCoSenE1?nDHiH4oiUWU`CoVfVH0onIJIT00ondSZkoZ86ZojR1ZP02ojR1ZPCoXg^V1?nQ
N:D00onQMjCo_oG`okoel003okoel0;o`lkS00?oY7RRojMhWonWN9l00onWN9l3oj9bW0GoWFjK0_nJ
K9`2okN>[0Co/HJX1?n/PZL00oo;/;oo^9>aokRC/@02okRC/@Co[hR/1_nnY;l2okNI^@;ocmgS0oo2
]ll2ok3_m`Co`MCX0_mUf]@2oj_/n@?oL]cd0_nKhod4ogkIo@?oU]kn0_nTf_/3oi_An`;oXm3g00?o
X<Seo`000?nPb?D01?nSbO<2ojK8l@;oY<;_1OnU`^h2ojK2k@;oYKo/1OnV_n`Cooooo`03o`000?oo
oooooooo01Oooooo000Tooooo`03o`000?oooooooooo00gooooo0oo0a=d3ol74g0?o`<7J00?o_;gJ
okZge_nj]mH01?nj]mH01?ng/M?o[jS@ojnXd?n_Z=03ojbPc0CoZ9W70_nTTl<2oi^?a@CoV8W20onD
Q;h3oi9o_0?oTGbi1?nAN[H3oi9h/P?oU7N_0_nGMZ`3o`0000;oUgFZ0onHM:T01?nKP[OoW7ncoiao
/onLOk<4oi]m/0CoVGZ_1?nFMjh4oi1c[`?oQfn`1?mjJ;<2of]R]P?oJfRm1?mfN/X5ohJFg004oibh
k?n:H9_oRV2KohYPV`;oQE^I1?n1EiP3oh=HU`CoR5^F0on?GiD4oiASUPCoVFNG1?nKJIP2oiUYV@;o
]8j^1?nXPJX5oj=kYP?oXGRU0_mhgJl2okoel0;oZW^Q0_nTN:800onaQZOoYgROojMhW`03ojMhW`?o
XW:L1OnMKY/01?nJK9co]hj/okN>[?ngSZ`5ok66Z0;o[8:W0_o;/;l5okRC/@;o[hR/0_o;_/l5okjT
_`03okNI^Oo?gN?ocmgS00;ocmgS00?o`[O?ok3_mon`koL00_n`koL01?o1e>SoIM[DofGJe?mUf]@3
oc:ie0;oL]cd0omXco/2ogkIo@;oRlSl1OnCco`2oi_An`;oVlGe0onPb?D01?l0003oX<Seoj?9lonS
bO<2oj;1k`CoY<;_0_nU`^h7ojFok0;oY[o/0_nV_^/Dooooo`03o`000?oooooooooo01Kooooo000T
ooooo`03o`000?oooooooooo00kooooo00?o`<CMol74g?o1a=`00oo1a=`01?o0`M[o_;gJokbmf_nl
_MX4okZgeP03ok>`e_n_Z=3o[jS@00;o[jS@1?n/X<`2ojRIa`03oinEbOnKSlGoVho500;oVho51?nH
RL83oiB4_P?oTWnl0onAO;T4oi5j]P?oTWRb0_nDMjl3o`0000;oUgJ/0onGMJX01?nHM:WoVh:goi^2
]onKP[L4oiao/`CoVgf`0onINZl4oiIg[PCoT7>_0on7Kk04ogYX/`?oJf:f0_m[J;d5ogIjbP;oQYKL
0_n=Hi`4ohYPV`?oQE^I0on1EiP3oh=HU`CoR5^F0on?GiD4oiASUPCoVFNG1?nKJIP01?nIJIWo]8j^
okB>[_ndSZh4ojR1ZPGoXg^V0_nQN:D2ogSM[`03ok20XOnZNj7oZW^Q00;oZW^Q00CoY7RRok66Yona
QZOo/HJW1?nWN9l4oj9bW0CoWFjK1?ngSZ`5ok66Z004ojb2Yoo;/;oobk2ool^`_`Go^9>a00Co[hR/
ol^ncoo;_/oobkk?1?nnY;l2oi3]aP;ocmgS0onHT/`2ok3_m`?oQYoT1?mc]?T2oeo0o@;oSk7]1?n;
_oP4oh_8o0;oTlol0_nJ_o85oi_5m@;oX<Se00?o0000oj6ok_nR`Nl01?nR`Nl2ojC2k`;oY;g[1_nU
_n`3ojFnj`CoY[k[5?ooool00ol0003oooooooooo`0Eooooo`009?ooool3o`0000oooooo1?o1a=`2
okk4gPCo_;gJ00?o^[OFok>`e_nc/=H00_nc/=H4ojnXd0;o[:3<00?oXic>oinEbOnOULT00_nOULT4
oi^?a@?oV8W21?nDQ;h3oi9o_0?oTGbi0onAN[H2oi9h/P?o00000_nDMjl3oiMf[0;oUgFZ00?oVHBk
oi^2]onKP[L00onKP[L3oiao/`CoVgf`1?nINZl3oiIg[P;oT7>_0onJ^>d4ohBhm`CoCJoj00Co0830
of]X_Om[J;goJfRm0_mfN/X3ohiUWP?oSF>L1?n:H9/3ohEKV@?oPENH0on3F9L4ohQKUP?oSenE1?nD
HiH4oiUWU`CoVfVH1OndSZh4ojR1ZPCoXg^V00?oXGRUok20XOn`P:400_n`P:44ojYkX@Co/HJW1?nW
N9l4oj9bW0?oWFjK00?o_YbfokN>[?ngSZ`00_ngSZ`5ok66Z0Gobk2o0onhTk42olWdk0Cobkk?00Co
_ZBooij>`onNS/?oQYSM0onTSK`4oiRBc0?oQYoT00?oY9g>oiZVg_nJY]h00_nJY]h5ohnak@;oRkoh
00?oW:gSoiVfk?nI]^`00onI]^`4oiZolP;oVlGe0_nP^n`3oj6okP04o`000?nQ_nkoX/7_oj;1k`;o
Xk_Z1OnT_N/2ojFok0;oYKgZ1OnU_^/4ojJnja;ooooo0_l00009ooooo`Co000000?o410@oooooooo
ool01oooool002Cooooo00?o0000ooooooooool04?ooool00oo1a=co_/CNokk4gP03okk4gP;o_;gJ
0onf^M`4ok>`eP;o[jS@00?oYZCCoj>Lc_nSW<h00_nSW<h3oinEb@CoVho51?nHRL83oiB4_P?oTWnl
0onAO;T2oi5j]P?o00000_nBN;82oiAg[`04ohn5a?nEQL3oUHG0oiF5`0CoVHBk1?nKP[L3oiao/`Co
Vgf`1?nINZl2oiIg[P;oY;[X1OnJ^>d2ohBhm`03oi5]Y_n?JJ?oSfVS00;oSfVS0_n=IZ44oheUW`?o
SVFN0on=Hi`4ohYPV`?oQE^I0on1EiP3oh=HU`CoR5^F0on?GiD4oiASUPCoVFNG1?nKJIP5okB>[PCo
Z86Z0onSNjH2ok61X@Co/82Q0onZNj400ooD^/3o/HJWok66Y`02ok66Y`CoYgRO1?nRLY`2oie^V`?o
_Ybf0ongSZ`4ok66Z0;ogocD1?o;/;l00onhTk7obOC/olWdk003olWdk0;obkk?0onNS/<00on^SkGo
Y8flojB=_002ojB=_0GoV9;<00CoQYoTojBMc_nTWLkoY9g>1?nJY]h2ohnak@;oXJCH1?nL[N<5oiVf
k0;oV[ob0_nQ]^L4oj2kk0;oXKo^00?oY;WXo`000?nT^NP01?nS^nX2ojBmj`;oYK_Y1OnU_NX2ojFn
j`;oY[gZ1OnV_^/Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool000Wo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000oooo
ooooool04_ooool3okk4gP03okS3h_nf^Mco][WL00Co][WL0_nc/=H00onY[M[oYZCCojJTd`02ojJT
d`?oXic>1?nOULT3oi^?a@CoV8W20_nDQ;h01?n=RL[oRhK9oh^6bOn;Q/T2ohR4b0?o000000?oR8C8
oh^4aon;Q<L00_n;Q<L4ohn5a0?oUHG00onIQ;/4oi^2]`?oW7nc1?nKOK02oiUj[`;oYkcX1OnT^^P3
oiZhk@04oi9`ZOnAKJKoTFfVoi5]YPCoSfVS0on=IZ43oheUW`?oSVFN1?n=Hi`3ohYPV`?oQE^I0on1
EiP3oh=HU`CoR5^F1?n?GiD3oiASUPCoVFNG0onKJIP2ol>M/PCo]8j^1?nXPJX00onSNjKoQeNBok61
X@02ok61X@Co/82Q0_nZNj43omBj`0?o/HJW1OnWN9l3oj9bW003oie^VonnW;Ko_Ybf00;o_Ybf1?ng
SZ`2ok66Z0?ogocD0oo;/;l2oiUj[`03o`l00?o9m>cobOC/00Co[8bd00?oWXk3ojj?]On^SkD00_n^
SkD4ojB=_0;oV9;<0_n]V/@5ojBMcP;oVZKN00?oZ:3>oj6Tf?nQY=P00onQY=P4oib]h`;oVKK/0_nS
/>45oj6fi`;oX;_/0_nT]N@2ojBij003o`000?nT^NSoY;WX00;oXk_Z0_nV^NL4ojFkj@;oYKgZ0_nV
_>T5ojJmjP;oY[k[0_nW_n/Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Ooo
ool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Kooooo00?o0000ooooooooool04oooool01?nna=ko^<?RokS3h_nh`n84okJig003
ojbghOnY[M[oZJgJ00;oZJgJ0onVY=<4oj>LcP;oWiG900CoUiOAoiBAc_nDTLkoU97>1?nASL`4ohf9
bP04oh^6bOl0003o0000o`0000GoR8C81?n;Q<L3ohn5a0?oUHG00onIQ;/5oi^2]`?oW7nc0_nKOK02
ojFok0CoYkcX1OnT^^P00onJ^>goTW2Yoi9`Z@03oi5]YPCoSfVS0on=IZ43oheUW`?oSVFN1?n=Hi`3
ohYPV`?oQE^I0on1EiP4oh=HU`?oR5^F1?n?GiD3oiASUPCoVFNG0_nKJIP3ol>M/PCo]8j^0onXPJX2
ohEDS`04ohMGT_naPJ7o/H6Qok61X@Co/82Q00?oZW^QomBj`?oD^/000_oD^/03ok66Y`GoYgRO0onR
LY`5okjL]PCo]hj/00?o/HJXomole?oOo=@00ooOo=@00oo;/;ooYWfWojImY`02oiUj[`;o]8n_1?n/
S;@5ojj?]@CoY8fl1On]V/@3ojBMcP03ok2PaonXX<koZ:3>00;oZ:3>1?nQY=P2oib]h`?oYjcK1?nS
/>42oj6fi`;oY[;P1OnT]N@2ojBij003o`000?nW^>GoY[WW00CoY[WW0_nU^nT2ojNkj0CoY[cY0_nV
_NX3ojNnjPCoYko[4oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo0009
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oo
oooooooo01Gooooo1?nh`n800onf^Mco[;OQojbgh@02ojbgh@?oZJgJ1?nVY=<2oj>LcP03oiVMe_nG
Um7oUiOA00;oUiOA0onDTLh4oi6=c0;oSHW:0_l00002oh^6b@KoR8C81?n;Q<L3ohn5a0?oUHG01?nI
Q;/4oi^2]`?oW7nc00?oVgf`ojFok?nU_n`00_nU_n`4ojNlj0;oY;[X0_n8IJ<3ohQTXP?oR6>R1?n7
Hj43ohIRXP?oSFFO0on>IIh4oheSW0?oRV2K0on5FiT3oh5GV0CoPeRG0on8FiH4ohmOU@CoU6>F0onI
IiL00onKJISo`ifbol>M/P02ol>M/PCo]8j^00?oZ86ZohEDSon5E8l00_n5E8l4ok61X@Co/82Q1OoD
^/03ok66Y`GoYgRO0_nRLY`2ol_0d0Co_Ybf1?ngSZ`4ok24YPGoYWfW00CoVGZ_okB?[ondSjoo]8n_
1?n/S;@00onlVKCo[Xneojj?]@02ojj?]@?oY8fl0_nhW[h4ojfJa004ojBMc_n`X<Oo/:37ok2Pa`Go
Z:3>0_nQY=P00on]ZMCoYjcKojN/f`04ojN/f`;oXk3Q00?oZJoLojJbh?nV/^000onV/^02ojBei0;o
Z;KS0onW^>D01?l0003oYkSUojJiionV^NL2ojRjiPGoYk_X0_nV_>T2ojRmj@GoYkkZ0_nW_n/2ojRo
ja?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`002Oooool01Ol0003o
oooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`0001Kooooo0_nh`n83ojg1
j0Co[;OQ0onY[MX2ojJTd`03oibTfonIWMKoVIgF00;oVIgF0onGUm44oiBAcP;oTHg<0ol000001?n=
RL[oRhK9oh^6bOn;Q/T6ohR4b0CoRhC71?n?QL@3oiF5`0?oVHBk0_nKP[L3oi73n0?oWL;b1OnU_n`2
ojNlj0;oRVRU0on8IJ<3ohQTXP?oR6>R1?n7Hj43ohIRXP?oQV>S0on6I:@3ohEUY@04oheSW?n:H9_o
RV2KohYPV`?oQE^I1?n1EiP3oh=HU`?oR5^F1?n?GiD4oiASUP?oVFNG1_o3WK82okB>[P;oQU>>1?n5
E8l4ok61X@Co/82Q00?o]H^ZomBj`?oD^/000_oD^/04ok66Y`CoYgRO00CoXW:Lol_0d?o;`=3obl3@
1OnnW;H2okN>[003ojj4Z?n`Q:Ko/8BV00;o/8BV1OnVOJL5okB?[`;o[8bd0_nlVK@5ojj?]@04ojB=
_?nhW[ko^9jnokRN_PCo[I[41On`X<L3ojRPcP03ok:[dOn]ZMCo[JWD00;o[JWD1?nW[=/00on][mWo
ZJoLojV_g002ojV_g0?oY[;P00?oZkGQojRfhonX]^<00onX]^<3ojNhi@03o`000?nX^^KoZ;[V00?o
Z;[V0onW^nP00onX_NSoZ;gYojRmj@03ojRmj@;oYkkZ0_nX_nX5ojRoja7ooooo0ol00007ooooo`03
o`000?oooooooooo00Wooooo0009ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`04ooooo`03o`000?oooooooooo01Sooooo1?n]`NP2ojbgh@04oijdj?nM[>7oWJcQoif/
h@CoW:CK0onIWMH3oiNGd@?oU97>0ol00002oi6=c0?oSHW:0on;Q/T6ohR4b0CoRhC70on?QL@3oiF5
`0;oVHBk0on2_o/4oi73n0?oWL;b0_nU_n`3ohe[Y`?oRVRU0on8IJ<3ohQTXP?oR6>R1?n7Hj43ohIR
XP?oQV>S0on6I:@4ohEUY@?oPVFX0_mcGZ`00on5FiWoPENHoh5GV002oh5GV0?oPeRG0on8FiH4ohmO
U@CoU6>F0onIIiL00oo8ZK[o`ifbol>M/P03ol>M/P04okB>[_n6DhkoQU>>ohICSP?oQEB?00?o[WnQ
ok61XOnaPJ400onaPJ42ok20X@03ok:7YoneRj[o]H^Z00?oe;[01?naQZL3ojMhW`03oicdiOo;`=3o
bl3@00;obl3@1OnnW;H01?ngSZco[XBXol:H[?o2V:`3ok24YPCoYWfW0_o1V[44okB?[`04ojb<]?nl
VKCo_9VdokbI]0Co[Xne00?o`:O0okRN__nhW[h00_nhW[h3ojfJa0;o^:K61?n`X<L00onXX<ko/Z_A
ok:[d@02ok:[d@Co[JWD00?oYjcKojf_fOn][mT00_n][mT4ojV_g004ojJbh?n[]N7oZkGQoj^eh@Co
Z;KS00GoYkSUojViiOnY^NGo0000ojVii@04ojRjiP03ojNkj?nX_NSoZ;gX00;oZ;gX0onX_NT00onX
_nWoZ;oZojRojP03ojRojP;oZ;o[0_nX`>/>ooooo`Co000000?oooooo`000?ooool01_ooool00ol0
003oooooooooo`09ooooo`002Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Iooooo`;o[L7X00?oW[g_oijdj?nN]>P00_nN]>P3oif/
h@CoW:CK0onIWMH2oiNGd@?o00000_n<W]l3ohZMg`?oQicQ0on4W^@4ognPj0CoNJG^0ombZ_@3og6a
n@CoMkWk1?n2_o/2oi73n0?oU7J^0on@L:/3ohe[Y`?oRVRU0on8IJ<4ohQTXP?oR6>R0on7Hj43ohIR
XP?oQV>S0on6I:@4ohEUY@?oPVFX0omcGZ`4oh5GV0?oPeRG0on8FiH4ohmOU@CoU6>F0_nIIiL2olRY
^PCo`ifb0_n8EHh3ohICSP;oQEB?0on^Oj44ok61X@03ok20XOnbQjOo/XNW00?o]H^Z00?oe:jbomBj
`?oD^/000onaQZL00onWN9ooW?CUoicdi@02oicdi@Cobl3@0_nnW;H01?neR:Ko[XBXojj4Z?n^Q:P2
ol:H[0Co/8BV0_nVOJL3ol6J/@Co]8n_1OnlVK@2ojj?]@;o`:O01OnhW[h01?n]V/Co^:K6okRVa_nh
Y/H3ok2Pa`03ok^ad?nbZm7o/Z_A00Co/Z_A0_n]ZM@00onc/]Oo[JoIojf_f@03ojf_f@;oZJoL0_n^
]]l5oj^eh@;oZ;KS0_n[^N@3ojVii@04o`000?nY^NGoZ;[VojRjiP;oZKcW1?nX_NP00onX_NWoZ;oY
ojRoj@02ojRoj@;oZ;oZ0_nY`>/5ojS0j`[ooooo0ol00005ooooo`03o`000?oooooooooo00?ooooo
00?oEEEEofIVI_l000002oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001Oooool2o`0001_ooooo0onN_Nl4oijdj0?oWJcQ0_nLY=/00on?ZNOo
SZCTohjTi003o`0000;oSJ7Q1?n<W]l3ohZMg`?oQicQ0on4W^@4ognPj0CoNJG^0ombZ_@3og6an@;o
MkWk1?nNQKP3oiUm/`?oU7J^0on@L:/4ohe[Y`?oRVRU0_n8IJ<4ohQTXP?oR6>R0on7Hj43ohIRXPCo
QV>S0on6I:@4ohEUY@?oPVFX0_mcGZ`2oe]E/P;oPENH0on3F9L3ohQKUPCoSenE1?nDHiH01?nIIiOo
b:VjolRY^_o8ZKX3ol>M/P?oR5F>0on6Dhh00on5E8oo[WnQojioX@02ojioX@Co/H6Q00?o/82Qok:7
YonbQjL00oneRjX2omB^/P04okB4X_naQZOo/HJWokB4XPCoXg:L00CoV6^LoicdiOo;`=3obl3@1One
R:H01?n^Q:So`YR/ol:H[?o2V:`4ok24YP03ojImYoo1V[7o`IZa00;o`IZa1?ndSjl00oo;[[go_9Vd
okbI]002okbI]003ojj?]Oo0Yl3o`:O000;o`:O00onhW[h00oo6]/_o^:K6okRVaP03okRVaP04ok2P
aonk/M3o^k7@ok^ad0Co/Z_A00?o^;WJok>beonc/]L00_nc/]L3ojf_f@03ok6igon^]]oo[[KO00?o
[[KO0_n[]N42ojfjh`GoZkWT0_nY^ND00on[_NOo0000ojVli`04ojVli`;oZ;gX0_nY_nT3ojRoj@Ko
ZL3[0_nX`>/2ojW1j`Kooooo1?l00008ooooo`03o`000?oooooooooo017ooooo0009ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000oooo
ooooool06oooool3oijmk`;oW[CX00?oSk?_ohn^jon?[^/00_n?[^/01?n?ZNOo0000o`000?l00002
ohjTi0CoSJ7Q1?n<W]l3ohZMg`?oQicQ0on4W^@2ognPj0?o=;[K0onob^82okk3gP03ojZG`onTS[go
Y8jm00;oY8jm1?nNQKP3oiUm/`?oU7J^0on@L:/4ohe[Y`?oRVRU0on8IJ<3ohQTXP?oR6>R0on7Hj43
ohIRXPCoQV>S0on6I:@4ohEUY@?oPVFX0_mcGZ`4oe]E/P?oPeRG1?n8FiH3ohmOU@?oU6>F00?o`jg4
olRY^_o8ZKX00oo8ZKX00oo3WK;oR5F>ohQESP02ohQESP?oQU>>1On^Oj44ok61X@Co/XNW00Co]H^Z
omB^/_oD[[;oe:jb1?ndQ:84oj=bW004oiQ[W?noU:_o_iB[oknDZ`Go]HRV00Co[XBXol:H[?o2V:co
`YR/1?n`Q:H6ol6J/@;o]8n_0_o;[[d4okbI]0Go`:O00_nhW[h3olJfb`?o^:K600?o`;kGok^ad?nk
/M000onk/M000onbZm7o^;WJokRifP02okRifPCo/k;G00Co[JoIok6igona^Moo/KWO0on^]]l2ok2m
i0Co[K[S0_n[^N@2ojbni`?oZkgW00Co0000oj^mionY_>OoZKcW0_nZ_nT5ojVoj@03ojRojOnY`>_o
ZL3[00CoZL3[1_nY`N/2ooooo`?o00003?ooool00ol0003oooooooooo`0Aooooo`008_ooool00ol0
003oooooooooo`0Mooooo`?oS[Sc0on?/nl01?n?[^_o0000o`000?l00003ohnYi`?oSZCT1?n=XN42
ohbNg`;oNKgl1?md`_h3ofc7oP;oF<Sg00?o]_7eol3>iOo0c^D00onob^800on_X<WoZYO3ojZG``02
ojZG``CoY8jm0onNQKP3oiUm/`?oU7J^0on@L:/4ohe[Y`?oRVRU0on8IJ<3ohQTXP?oR6>R1?n7Hj43
ohIRXP?oQV>S0on6I:@4ohEUY@?oPVFX0omcGZ`3oe]E/P03oeAM__n3F9OoPeRG00CoR5^F0on?GiD2
oiASUP?o`jg41?o8ZKX00on<F8koR5F>ohQESP02ohQESP?oQU>>1On^Oj44ok61X@Co/XNW00Co]H^Z
omB^/_oD[[;oe:jb1?ndQ:84oj=bW004oiQ[W?noU:_o_iB[oknDZ`Go]HRV1?o2V:`4ok24YP03oljc
_oo1V[7o`IZa00?o`IZa00Co]8n_ol^^_Oo;[[gobjjm1?nlVK@00oo>`<go`:O0ol2W`002ol2W`003
okRN__o6]/_oa[K;00?oa[K;00Co^:K6ol2neoo0_]Oo`;kG0onk/M000onnan7o^;WJokRifP03okRi
fP;o/k;G0_nf_n45ok6ig`03ojjfgon`_NCo/;gT00;o/;gT0_n]^^<2ojg1j0Co[;kW0_n[_NL00on[
`>Wo0000oj_0j@04ojZoj@;oZKoY0_nY`N/6ojW0j`KoZL7[0_nX`N/00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo01kooooo0on>^?<00on?/noo
0000o`000002ohn^j`?oP;Gf0omo]_L3ogfgn0CoNkWj0omi_O`2ogC2oP;oAlOM00CoL^7FokKamOnf
lOGo]_7e1?o0c^D01?nob^;o[j39ojnPbOn_X<T3ojZG``CoY8jm1?nNQKP3oiUm/`?oU7J^0on@L:/3
ohe[Y`?oRVRU0on8IJ<3ohQTXP?oR6>R1?n7Hj43ohIRXP?oQV>S0on6I:@4ohEUY@?oPVFX0omcGZ`4
oe]E/P03oeAM__n3F9OoR5^F00?oR5^F0on?GiD00onDHiKo`jg4ol>]a002ol>]a0?ob:Vj0_n<F8h4
ohQESP;oQU>>00?oYgVPojioXOn^Oj400on^Oj43ok61X@Go/XNW1?oD[[85okB4XP?oXg:L1?noU:/5
okF8YP03onKD`oo2V:co`YR/00;o`YR/0_n`Q:H2oljc_`Go`IZa1Oo;[[d2okbI]0;oc/3=0oo0Yl00
0oo>eMooa[K;olJfb`03olJfb`03olCIjOo0_]Oo`;kG00?o`;kG00Co^k7@okk7hOnnan7o_/OQ0onh
^MX2okK9j0Co][oQ0_na^Ml2ok73i`Co/;gT00?o[/CZojg1j?n]`NP00on]`NP2ojbni`;oZl;[0on[
`>T01?l0003oZl3YojZojOnZ_nT2ojW2j`CoZL7[0_nY`>/5ojW1j`OoZ<7[4?ooool00ol0003ooooo
ooooo`0@ooooo`008_ooool2o`00023ooooo0ol00004oh:dm@CoP;Gf0omo]_L3ogfgn0;oNkWj0omT
c?/2oeO<l@;oP^S/0ondjoL2okk?i`?o`<kU00?o/jW>ojnPbOn_X<T00_n_X<T3ojZG``CoY8jm1?nN
QKP3oiUm/`?oU7J^0on@L:/3ohe[Y`?oRVRU0on8IJ<4ohQTXP;oR6>R1?n7Hj43ohIRXP?oQV>S0on6
I:@4ohEUY@?oPVFX0omcGZ`4oe]E/P;oE5fn1?n8FiH2ohmOU@03oj>Pd_o3[LCo`jg400Co`jg400Co
b:VjohaHS_n<F8koS5R>1?n8EHh01?n6DhkoYgVPojMiX?nWNJ05ojioX@;o/H6Q00?oZh6Wok:7Yonb
QjL00_nbQjL01?l0003oe:jbomB^/_oD[[85okB4XP?oXg:L1?noU:/4okF8YP;oi]C31?o2V:`01?n`
Q:Koc[>ooljc_oo>/kl4ol6J/@03on;_f?o;[[gobjjm00?objjm00?o_9Vdolk0cOo>`<d00_o>`<d0
1?o0Yl3oc]GOolkEgoo>eMl3olJfb`?oa=WY0oo0_]L00onig?;o_/OQokk7h@03okk7h@03okRif_nf
bNSo]/WX00;o]/WX0_nf_n42ok7;k@Co/L?W00?o/;gTojk4j_n^a>X00_n^a>X3ojg1j003oj_5kOn[
`^_oZl;[00?oZl;[0_n[`>T00onY`nco0000ojW2j`04ojW2j`;oZL7[0_nY`^`3ojW1j`;oZ<;/2?nX
`N/@ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo01cooooo0ol00000
1?ooooooPkCeoh>dmOn3]?D4oh:dm@;oP;Gf0_mk__`4ogG3oP;oK/So0_mVeO@3ohoWnP?o/nCg00?o
]>_gokk?ionncnL00onncnL01?o0c^Go/jW>ok>Yc_ncZLh4ojnPb@?oZYO30_nTS[d00onFPK[oT7Zg
oi1j]`02oi1j]`?oS7Bc0on8L;43ohE]/0?oPf^_0on:J:D3ohQUX`CoR6BR0on8Hj83ohMSX@?oQV:R
1?n6Hj<3ohITY0CoQFFU0on2IJP3og=N[0?oFeFb0_mDGKh3ofYic`03ohQKU_n?GiGoXj3B00;oXj3B
1?o3[L@2oi5LS`?oS5R>0on8EHh00onMLJ3oYgVPojMiX002ojMiX0Go[WnQ00?o/H6Qoj^1Yon[PJL0
0onbQjL2o`0000Coe:jb1?ndQ:82oj=bW0;oa:Rm1?noU:/2okF8YP?oi]C31?o2V:`5oljc_`;o`IZa
0ooRkmP3ol^^_@03olGdk_o>`<goc/3=00;oc/3=0_n@l=d4olkEg`03olJfboo4fNWoa=WY00;oa=WY
00?o`;kGokWLl_nig?800_nig?82okk7h@;o/MOc1?nfbNP00on[e?Ko/L_]ok7;k@03ok7;k@;o/L?W
0_n/bNh4ojk4jP03ojg1j?n[aNgoZlG]00;oZlG]0_n[`^/2ojW4k@?oZL?/00Co0000ojW3k?nY`^_o
ZL;[0_nY`n`5ojW2k003ojW1jonX`^coZ<;/00;oZ<;/0_nX`N/2ojS1k0CoZ<7[3oooool00ol0003o
ooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0Iooooo`?o00001_ooool3ohFem0CoP;Wi
0omk__`2ogG3oP;oN=?n1?nHgoh01?n?io[o/nCgok?Tmonci?L4okg?j0;o_/oW00?o][3Cok>Yc_nc
ZLh00_ncZLh3ojnPb@04oj6Aa?nKRKooVhVooi^9_`CoUX6j0on@N[L3ohad/`?oR72a0on5KK03oh=[
[`?oPF^`0on1KK<4ohQTXP?oR6>R0on7Hj43ohIRXPCoQV>S0on6I:@4ohEUY@?oPVFX0omcGZ`4oe]E
/P;oE5fn0omZNLl4oj>PdP?o`jg40onAG8l3ohaHSP04ohQES_nMLJ3oWG6PoieaX0CoYgVP1On^Oj40
0onaPJ7oZh6Woj^1Y`02ok:7Y`04ojAmZ_nWPZcoYh:/o`0000?oe:jb1?ndQ:801?nSLYcoa:RmolBX
_Oo4Z;d4oknDZ`03okF8Y_oVe<?oi]C300?oi]C30_o2V:`2olCng`Coc[>o00?o`IZaon;_f?oRkmP0
0_oRkmP00oo;[[goaOC^olGdkP02olGdkP03olk0cOn@l=goT?3M00?oT?3M0_o>eMl3oi7[mP;oa=WY
0on7iOL2okWLlP;oUMgn1?naeo<00onfbNSoZmCfoj_DmP02oj_DmP;o/L_]0_nWc_@5ojc9kP;o[/CZ
0onZb>l2oj_5k@;oZ<K_1?nYa>d2ojW3k003ojS4kOl0003oZL?/00CoZL?/0_nY`^`7ojS2k0GoZ<7/
0_nX`N/00onX`>_oooooooooo`0=ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oo
oooooooo01Kooooo0ol0000:ooooo`?oQKGd0_n0^OT3oh_2nP;oPlco1?nLe?/2oiSOoP?o/M_f00?o
/nCgokg?j?nmcnP00_nmcnP00ong]]So][3CokJ`d`02okJ`d`Co/jW>00Co[j39oj6Aa?nQTLCoXI74
0onKRKl3oiJ1^P?oT7Zg0on<M;<3ohQ`/@CoQFf`0_n3Jjl3oh5[/0?oPFfc1?n2LKP3oh=i_`?oQf>Q
0on6HZ84ohISX`?oQVBT0_n5IJD3ogmHVP?oO5NK0omjFIl2ofaHZP03oe]E/_mDGKkoE5fn00CoJWW?
1?nSX=800oo3[LCoTEb?oi5LS`02oi5LS`;oS5R>00?oU6^PoieaX?nMLJ000_nMLJ04ojMiX0Go[WnQ
0on[PJL2ok:7Y`03ojAmZ_nWPZcoYh:/00?oYh:/00?oZ8^gokB4X_ndQ:800_nJi_`4olBX_@Co_iB[
0_n/RK44onKD``04ol:H[?o4o]ooa?kOolCng`?oc[>o00?o]96boib=`ongUK@00_ngUK@3oib?aP03
okJM_onKV=3oViS@00?oViS@1?mdWn`3oc2Kl@;o9:OV0_n7iOL3oe75l`CoUMgn0_naeo<3oiWIo@;o
ZmCf0_nMd?X4ojO>m0;o[<W^0onVbo<2oj[8k`;oY/Oa1OnXa^l2ojW4k@;oYlG_0onXa>d00ol0003o
ZL?/ojW3k002ojS3k@[oZ<;/1?nX`N`4ojS0j`kooooo00?o0000ooooooooool04?ooool002;ooooo
0_l0000Dooooo`?o00003_ooool4ohnilP;oRl;j0_nNb?D4oicDn`?o/=;b0_nafoH3ok[=j003okg?
j?ng]]So]kKH00;o]kKH1?nf/=<2ok>YcP03ojJIbOnQTLCoXI7400;oXI740onKRKl3oiJ1^PCoT7Zg
0on<M;<3ohQ`/@?oQFf`0on3Jjl3oh5[/0?oPFfc1?n2LKP2oh=i_`?oQHC;1_n6Umd2og>cn@04ohYS
Won4G9coQ5bLohALW0?oOeRJ0omlEi/3ogYIW`?oK5RZ0om[D:04ofYic`;oXj3B0_mjFZ84ohUTX@?o
U6^P1OnMLJ03ojMiX0Go[WnQ0on[PJL00onbQjOoY7fZojAmZP05ojN2[0?o/HBT0_nJi_`5olBX_@;o
_iB[00?o_I>Zojb9/OnlTJX00_nlTJX5ojn7Z`03okBA/_o4o]ooc[>o00;o]96b1OngUK@01?nLSlKo
]YfookJM_onfWKl3oi^Hd003ok6OaOnMWmGoWIoE00;oWIoE1On0Y>X3ofF`nPCoEk_l0omhdOl2oiWI
o@?oSLgm1?nMd?X2ojO>m0?oWlcg0_nVbo<2oj;7l`CoY/Oa0_nXa^l2ojK5l0GoYlG_0_nXa>d00onW
`nko0000ojS3k@03ojS3k@OoZ<;/0_nW`N`5ojS1k0;oZ<3[0_nW`>/=ooooo`03o`000?oooooooooo
013ooooo000Qooooo`;o00004_ooool3o`0001;ooooo0_n?^O82oinnkPCoW/Se00?oW=Ckok3Bl_n`
d_800_n`d_82okS:i`?o^/gX00?o^;_KokNff?ng]]P01?ng]]P2okJ`d`03oj^Rc_nVVLWoYYW900;o
YYW90onQTL@3oi^9_`CoUX6j0on@N[L3ohad/`?oR72a0on5KK03oh=[[`?oPF^`0on1KK<4oh9a^0?o
PgVo0on5Q</4ohJGg@04oi5/YOn:HiooRV>OohYSW`?oQ5bL0omoF9X3ogaGV`?oNUVO0om/F:X2o`0m
`P04of]@X?mWCZ7oIdjQofM>X@?oJe6R0_mjFZ84ohUTX@?oU6^P1OnMLJ04ojMiX0?o[WnQ1?n[PJL3
ojAmZPCoYh:/00?o]HZYok64Y?naQ:@00_naQ:@00onUNjCoV^KlolBX_@03olBX_@04oknDZonmTj[o
_I>Zojb9/@?o_96Z1?n_Qj/00oo8WZko]96bokBA/P03okBA/PGo]iFd1OnfWKl01?nKV=3o/Io5ok6O
aOnaWlD4oifOe@;oP:CZ0_nOY]/4ohf]k0CoOKKh1?n1a?d2ohg=o@;oSl?h1?nGb_T2oio<m`;oWLGd
1OnRao<2ojK7l@;oY<Ga1?nVaO02ojO5k`;oY/?^0onW`nh01?l0003oYl?^ojS3kOnX`nd2ojO2k@?o
Z<;/1_nW`N`2ojS1k0OoYl3[3?ooool00ol0003oooooooooo`0@ooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool00oooool00ol0003o
ooooooooo`0?ooooo`;o00005_ooool4oinnkP;oW/Se1?n^bNh00on`d_;o^<[WokS:i`02okS:i`04
ok[=j?nh^m_o^;_KokRkf`Co]kKH00?o[ZWCoj^Rc_n[X/h00_n[X/h3ojJIb@CoXI740onKRKl3oiJ1
^P?oT7Zg0on<M;<3ohQ`/@?oQFf`0on3Jjl3oh5[/0?oPFfc1?n2LKP3oh=i_`CoQHC;00CoQYOMoi5/
YOnAK:GoTFbU0on:Hil3ohALW0?oOeRJ0omlEi/4ogYIW`?oK5RZ0_l0?L83ofM>X@?oJe6R0_mjFZ84
ohUTX@CoU6^P1?nMLJ04ojMiX0;o[WnQ00?oXWZXoj^1Yon[PJL00_n[PJL4ojAmZP;oYh:/0_neRZT5
ok64Y004ojEkY?o4Z;goa:RmolJN/0Co_I>Z1OnlTJX2ojn7Z`?ob9j^0ondTK800oo5Wk;o]iFdokNE
]003okNE]0Go]Yfo1?naWlD3oifOe@03ojnVconOY]_oWjKK00?oWjKK1?n=[N`2ogffn0;oU;3Z0on?
^_@5oho3n0;oUl[i0_nJ`O<4oig5m0;oX/Oc0_nQ`o45ojC5l@;oY/G`0_nU`nh4ojK3kP;oYl?^00?o
Yl;]o`000?nW`^d01?nW`^d00onX`^coYl7/ojO1k004ojO1k0;oYl3/2?nW`>/=ooooo`03o`000?oo
oooooooo00oooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`?o00006Oooool2oinnkP?o[L7Y0on^
bNh2okK6iP?o^<[W0_nh_]h4okRkf`03okNff?n^ZM?o[ZWC00;o[ZWC0on[X/h4ojJIb@?oXI740_nK
RKl01?n@Q<?oRgo1oh]o`On;Ol43ohIl`@?oS7Bc0on8L;44ohE]/0?oPf^_0on1Jk03oh5]/`CoPW6h
0on3NKl2ohF4b`;oN66[0ombFjT3ohYSW`?oQ5bL0omoF9X3ogaGV`CoNUVO1?m/F:X01?l0?L;oSfRQ
ofM>XOmWCZ43of]AXP?oNUZR1?n9I:43oiA[X0CoWG6P1?nWNJ001?n^Oj7oXWZXoj9jZ?nRNZP2oj^1
Y`03oiUgZonTOJ[oY7fZ00;oY7fZ00CoYh:/okF:ZOneRZWo]HZY1OnaQ:@01?nUNjCoaYj`olJN/?o6
W[04okfCZPGo_96Z00?o[hN[olRN[_o8WZh00_o8WZh2okBA/P?oaInb0ongUK@2ol^Y]`?o]Yfo0_o2
ZL04ok6Oa@04oifOeOn_Y/oo[jK?ojnVc`CoWjKK0_n=[N`2oj2ZgPGoU;3Z0on?^_@2oho3n0;oV;_`
1OnJ`O<2oig5m0;oWl3`1?nQ`o42ojC5l@;oY<7^1OnU`nh2ojK3kP;oY/;]0onW`^d00ol0003oYl;]
ojO2k@05ojO1k0OoYl3/2?nW`>/<ooooo`03o`000?oooooooooo00oooooo0007ooooo`05oa0@4?oo
ooooooooooooool@41002oooool5o`0000Gooooo0_l0000:ooooo`?o00007Oooool5ojg1j@03ojk9
k_nfa^Ko]/KV00;o]/KV00?o^<[WokRng_nh_]h00_nh_]h2okRkf`03ok6`eon^ZM?o[ZWC00?o[ZWC
1?n[X/h2ojJIb@04oi^BbOnERlKoUH_6oiF;aPCoT8C30on;Ol42ohIl`@?oPW_20omoOLL3og^4d@04
ohE]/?n3JjooPf^_oh=[[`?oPF^`0on1KK<4oh9a^0;oPgVo0on3K;02ogQQZ`?oLU^Y0_m^FZ/01?n:
HiooQ5bLohALW?n4G9`3ogmHVP?oO5NK1?mjFIl3ofaHZP05ofIDZOnVPjooSfRQohmXXOmWCZ400om[
DJ83ogYJXPCoRFBQ0onDJj04oieaX0CoYgVP1?nRNZP00on[PJOoVGN[oiUgZ`04ojAmZPGo]HZY1?na
Q:@01?nUNjCoaYj`olJN/?o6W[03okfCZP;oe;6f1?nlTJX5olRN[P03okBA/_o5Wk;oaInb00;oaInb
0_ngUK@3ol^Y]`;o]Yfo0oo2ZL03ok6Oa@03okn]b?n_Y/oo[jK?00?o[jK?0_nOY]/2ojbYe0CoX:[N
0_nD/>X2oj:_h@GoW;GY0onH^o02oi[1l`;oWkc]1OnO`?02oj73l@;oXko]1?nT`Nh2ojG3kP;oYL7]
1OnV`^d2ojO2k@03o`000?nW`NcoYl7/00;oYl7/0_nW`>/6ojO0k0_oYl3[2oooool00ol0003ooooo
ooooo`0?ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo
00001_ooool00ol0003oooooooooo`06ooooo`?o00008Oooool2ojg1j@Co]L?T0_nfa^H2okS1h@?o
^;kN00?o/kOLok6`eona/=L00_na/=L5ojjYd`;oZj;>00?oX9[>oi^BbOnKT/T00_nKT/T3oiF;aP?o
T8C30on;Ol43ohIl`@?oPW_20omoOLL3og^4d@CoMI?R0omQ[oX2ok2Wc`?oWho20on?NkP3oh=//0?o
N66[0_mbFjT3ofiJZ`?oQ5bL1?moF9X2ogaGV`CoNUVO0_m/F:X00omcIKCoIUBYofIDZ@03ohmXX@?o
Je6R0omjFZ84ohUTX@?oU6^P1?nMLJ04ojMiX004oiQdZ?nRNZSoXWZXohea[`CoVGN[0_nTOJX00on`
SK3o]HZYokF:Z@03okF:Z@Co/HBT1Oo6W[001?nmTj[oe;6fomBa]_oD/KH4okbAZP03om2c_?o8WZko
b9j^00;ob9j^1Oo5Wk800ongUKCobjVgol^Y]`02ol^Y]`03okJM_oo2ZL3o`ZW000?o`ZW000Co/Io5
okn]b?no[LSo_jg80on_Y/l00onh[/oo[:WDojbYe003ojbYe0;oX:[N00?oZjkJoj:_hOnR[n400onR
[n42oibej@;oY;;R1?nP]^P4oinlk@;oWl3`0_nR_>/5oj>ok@;oY<7^0_nU_n`4ojG1k@;oY/;]0_nV
`>`3ojO1k003o`000?nW`NcoYl7/00CoYl3[0_nW`>`2ojNoj`KoYl3[0_nW_n/5ojO0j`[ooooo00?o
0000ooooooooool03oooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0000Kooooo00?o0000ooooooooool00oooool3o`0002Kooooo0one`n@2okS3h`Co^<7Q
00Co^;kNok>gg?nc]mco/kOL1?na/=L2ojjYd`;oYJ;B1?nPV/h3oi^Bb@?oUH_60on@Q<<3oh]o`@?o
QWc10on2Nl83ogmma`CoNhCA1?meTn801?mQ[o[oT7Zgoi1j]on@N[L3ohE^/@CoSg^h0_n3K;03ogQQ
Z`?oLU^Y0_m^FZ/2og1Q/P03ohALW?moF9[oOeRJ00;oOeRJ0omlEi/3ogYIW`03ofaHZ_nJlnOoLfFd
00;oIUBY00CoH52XohmXXOn?J:7oP5VK0_m[DJ83ogYJXPCoRFBQ0onDJj05oieaX0;oYgVP0_nHM:P0
1?nRNZSoSG6_ohea[on=LJl3oiUgZ`04ojAmZ_n`SK3o/8f`ok2=/0Co]HZY0onaQ:@2omO4a`CoaYj`
00Co_I>ZomBa]_oD/KKoe;6f0onlTJX2om2c_0Cob9j^00?ogL:nolFO/_o5Wk800_o5Wk85ol^Y]`Go
`ZW000?ob[c=okn]b?no[LP00ono[LP01?n_Y/oo^:k?okR^conh[/l3ojbYe003okB`eOn[[][oZjkJ
00;oZjkJ0onR[n400onZ/=coY;;RojBbhP03ojBbhPCoX;KX0_nO_>d2ojBij0CoX[c[0_nS_nd2ojFm
jPGoYKo/0_nU`Nd2ojJoj`CoY/3/0_nW`N`00onW_n_o0000ojNoj`02ojO0j`OoYko[0_nW`>/6ojNo
j`CoYl3[2_ooool00ol0003oooooooooo`0?ooooo`001oooool01Ol@413ooooooooooooooooo410@
00cooooo00?oMgMgolc<c?l000001Oooool01?l0003oooooooooooooool3o`0002[ooooo00?o]L?T
okS3honh`n<00_nh`n<2okS1h@;o]KgP1?nc]m`2ok6`e`03ojRZeonUX];oYJ;B00?oYJ;B0onPV/h3
oi^Bb@?oUH_61?n@Q<<3oh]o`@;oQWc10on2Nl84ogmma`CoNhCA0_meTn82oib8_P?oT7Zg0on5K[43
ogYU[P03ohmk^?n3K;3oPfb`00?oN66[0ombFjT2ofiJZ`?oL66b1?moF9X3ogaGV`;oNUVO0_nJlnL2
og=U]0;oIUBY0_mPD:P00on?J:7oP5VKoh1IV`02of]AXP;oNUZR1?n9I:43oiA[X0GoWG6P00CoYgVP
oiQdZ?mdFjOoM5^W0on3JZh01?n=LJooVGN[oiUgZonLPK@4ok2=/0Co]HZY0_naQ:@3omO4a`CoaYj`
1OoD/KH01?nlTJ[od;>lom2c_?o@/k`3olRN[P;ogL:n1?o5Wk800ooD_L?objVgol^Y]`02ol^Y]`04
omW3a?o2ZL3o`ZW0ol:Y`0;ob[c=1?no[LP00oo5^m7o^:k?okR^c`03okR^c`04ojbYe?nd/=Go];3E
okB`e@CoZjkJ00CoXZoQojZ`g?nZ/=coZ[3L1?nT/^82oj2fj0;oY[KT1OnT^NP2oj:lj`;oY[[X1?nU
_NX2ojFok0;oY[gZ1OnV_n/2ojK0k0GoYko[00?o0000ojNojonW_n/03onW_n/5ojO0j`Wooooo00?o
0000ooooooooool03oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000000Gooooo1?l0000^ooooo`?o^<?S0_nf`n@4okFmh0;o/kOL00?o[;;LojRZeonXZ]L00_nX
Z]L5ojFRdP?oX9[>0onKT/T3oiF;aP;oT8C300CoQYKKoh:IhOn2VN7oPYWQ0on6O<43oh9k`P;oOgg7
0_mMaoX00oo8iNcoamKUojRIa`02ojRIa`?oW8Rn0on@N[L2ohE^/@CoNVF^0_mbHK000on3K;3oN66[
ogQQZ`03og9KZ@?oKUZ[0_m`HK83ogQe``05ogmHV_mlEi_oO5NKogaGVomjFIl00_nJlnL00omOCZKo
LfFdog=U]003ofIDZ@;oH52X0on0FI/00om[DJ;oNUZRogYJXP04ohUTX@?oU6^P1OnMLJ001?nWNJ3o
LUNTogAKYomdFjL4oh=Z[P?oW86d1?n`SK04okF:Z@03ok64Y?oGa<OoelC700;oelC71?o6W[000oo:
oL7oe;6fomBa]P02omBa]P03okbAZ_o@/kcod;>l00;od;>l00Cob9j^omg2__oM`[kogL:n0oo5Wk82
omBm``?objVg0ooI`l@00oo2ZL3ob[c=olZlc@02olZlc@;o_jg80oo5^m43okR^c`03okbhe_nd/=Go
];3E00;o];3E0_n[[]X2ok2af@GoZ[3L0_nT/^82ojZdh0CoY[KT0_nT^NP2ojNhi@GoY[[X0_nU_NX2
ojNlj0CoY[gZ0_nV_n/2ojNnj@CoYko[00GoZ;kZojNoj_nW_n[o0000ojNojP02ojNoj`;oZ;oZ3OnW
_n/4ojO0j`Wooooo00?o0000ooooooooool03oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00Cooooo0_l0000aooooo`03okS3honf`nCo]/?T00;o]/?T0_ne
_N000on^^^;o[;;Lojbbg002ojbbg0CoZ:[G0_nUX]82oi^Ug0?oUYoJ0on@V]T3ohbGf@CoQYKK0on2
VN44ogbRj`;oM;Ci00Coa>c`olSUk?o8iNco/J[A1?nXVLL3oib8_P?oT7Zg0on5K[43ogYU[P?oLV6`
0omhHJ/2og9KZ@?oKUZ[0om`HK84ogQe``?oSZ[Y0_mcFjP2oem>YP04og=U]?mVE:WoIUBYofIDZ@;o
H52X0_mdIK@00on0FI_oLDnJogYJXP02ogYJXP?oRFBQ1?nDJj03oieaX0?oLUNT0omdFjL3oh=Z[PCo
W86d0on`SK04okF:Z@KoelC70_o6W[02ol[m`@?oe;6f00?oXoG[om2c_?o@/k`00oo@/k`00oo8WZko
gL:nomg2_P02omg2_P03olFO/_oD_L?oe;g300;oe;g300?objVgomW3a?oI`l@00_oI`l@5olZlc@03
okn]b?o5^m7oaK_A00;oaK_A00?o^:k?okbhe_nl^=H00_nl^=H2okB`e@03okNgfOn`/MWo/;7I00?o
/;7I0_nZ/=`2ojndg@GoZ[CP0_nV]^@2ojZfhPCoYkSU0_nV^^P2ojRjiPGoYkcX0_nV_NX2ojRmj0Co
YkkY00?oYko[ojRnj_nX_^X00_nX_^X2ojNojP03o`000?nX_^[oZ;oZ00?oZ;oZ0_nW_n/2ojRojPOo
Yko[0_nX_n/4ojO0j`Sooooo00?o0000ooooooooool03oooool002;ooooo00?o0000ooooooooool0
;oooool3okK3i003ok32ion^^^;o[[[R00;o[[[R1?n//]`2ojRZe`;oWj_O1?nKYM`3oiJOfP?oT9[I
0on<UmT4ohJFf`?oPYWQ0_mlX^/3olC/l003okVjf_naZ]7o/J[A00;o/J[A0onXVLL3oib8_P?oT7Zg
0on5K[43ogYU[P?oLV6`0omVHKP2og9KZ@?oKUZ[0om`HK85ogQe``03ohjZjOn5KK3oLe^X00;oLe^X
0_mOCZH00omcIKCoIUBYofIDZ@02of1@Z0?oM6Fd0_maCiX00onPUl_oNUZRohUTX@03ohUTX@?oU6^P
0_nMLJ001?n3JJgoLUNTog9GY?mbEj@3ogAKY`?oPfZ^1?nLPK@4ok2=/0;o]HZY0_nfnl`5omO4a`06
olJN/?nYPZWoZH:YojV2ZOo:oL7oe;6f0onSmN/3om2c_0;oX_KC0ooM`[h00ononnWoe;g3omBm``03
omBm``04om7diooI`lCofL?4omW3a0;oe^?P0oo:_<d2olSChP?oaK_A0_o2bMl4okbheP04okB`eOng
]mWo]kOIokNgf@?o/;7I00?o/[OLojndgOn_]=d00on_]=d2ojZdh0;o[KKO1OnZ]^82ojNhi@;oZkWT
1?nX^^H2ojNlj0;oZKcW1OnX_NP2ojNnj@;oZ;kY0_nX_^X2ojRnj@?oZ;kZ00?o0000ojRnj_nX_nX0
1onX_nX2ojNoj`OoZ;o[0_nW`>/00onX`>_oooooooooo`07ooooo`03o`000?oooooooooo00kooooo
000Sooooo`03o`000?oooooooooo02oooooo00Co]/?Tok32ion``^Oo/<;W1?n^^^82ojbbg0;oX[;S
1?nOZml3oi^Ug0CoUYoJ0on@V]T3ohbGf@;oQYKK0omSb?`01Oli_MSo_>gdokc]m?nlkOCoa>c`00?o
^K[J0onaZ]44ojRIa`?oW8Rn0on@N[L2ohE^/@CoNVF^0_mbHK03ofIQ^0;oC73F00?oLU^YofiJZom^
FZ/00om`HK84ogQe``03oj>?`?n5KK3oQFf`00?oLe^X0omOCZH2ofIDZ@?oH52X0_mdIK@4oj2Gb`Co
RFBQ0onDJj000onMLJ3oEe6`oh=Y[@03og9GY0?oM5^W1?n3JZh3oib1]0Co/8f`00?o]HZYoiYh[?nJ
N:`00_nJN:`2omO4a`03oiaiZonWOJKoZH:Y00?oZH:Y1?nWRK@00oo5W[7oXoG[om2c_004oj;fd`04
omg2__nonnWo_o_Yokokj@?oe;g30ooAm>L00ooI`lCoe^?PomKSh002omKSh003olZlcOo8dn;ob=?R
00;ob=?R00?oaK_Aol;9goo2bMl00_o2bMl2okbheP;o^/7P1?ng]mT01?n`/MWo/[OLok:gg?nb]m`3
ojndg@;o/KSO1?n]]]l2ojZfhP;o[KWR1On[^N@2ojRjiP;oZk_V1?nY_>L2ojRmj0;oZKgX0onX_^T2
ojVnj@CoZ;kY0_nX_^X00ol0003oZ;oZojRojP08ojRojPKoZ;o[1_nX`>/8ooooo`03o`000?oooooo
oooo00kooooo000Tooooo`03o`000?oooooooooo02oooooo1?n``^L2ojjjhP;oYKWW1?nR/^<4oin[
g`?oVjGL0_nFWmX2oh^dl@CoPkOg0omi`?d2of?8o0Co_>gd0_nla^84okVjfP?o/J[A0_nXVLL01?n@
QlKoQWg2ohIm`_n6OL83oi1j]`?oQFja0omjIJh2og9Q/0CoIV6h0_m<L=H3ofiJZ`?oL66b00CoN7G3
og9Y^_mbJK[oLVVj0_n5KK03og=KZ0?oGdjV00?oD56dofIDZOmPD:P00_mPD:P3ogAU]0CoX9O;0_mc
KK`00on9I:7oU6^PoiA[X002oe=A/@;oEe6`1?mbEj@2ogAKY`CoPfZ^1?nLPK@2ok2=/0;oVWjc1?nJ
N:`2oiaiZ`;oYgfV1OnYPZT2ojN9]0?oaIja00Co/J?;olZ``?o:/<3ob[300_oM`l001Ono`]coc<WG
olc9eononnWoe;g300;odOCW0olc^K/2omKSh0?oU^kc0_o8dn82ojkMn0Co`/WO00?o]M;_ok[1h?nj
`N000onj`N02okNgf@;o][kP1?nb]m`00on_]=go/KSOok6hg`02ok6hg`;o[KKO0_n_^^84ojfihP;o
ZkWT0_n/^n@5oj^kiP;oZKcW0_n[_NL4ojVmj003ojRnjOnY_^WoZKkY00;oZKkY0_nX_^T2ojVoj@;o
Z;oZ00?o0000ojRoj_nX_nX02?nX_nX3ojRoj`WoZ<3[1oooool00ol0003oooooooooo`0>ooooo`00
9Oooool2o`00033ooooo0_n``^L2ojJok0CoYKWW0_nR/^<2oiVgk@CoU[C]0onA/nh4oh^dl@;oPkOg
0omoeol01Ombg?Co]NWgokGYmonejOOo_>gd00Go_<KR0_ni^]X01?nUXM7oW9C;oibDbonLU</4oi27
aP;oQWg20omjM<43ogAca0?oNVF^0ombHK03ofIQ^0?oC73F0_n[ZMH2og1Q/P;oR8;60ombJKX2oeiI
]003ohE]/?mcFjSoLe^X00?oGdjV0_m@DK@00omVE:WoH52Xof1@Z003ogAU]0?oX9O;00?oLGC6og=]
_?mcKK`00omQE:d01?mCCZkoDe6aoeMA/?mGDK02of9T_`;oLUNT0omdFjL3oh=Z[PCoW86d00?o/8f`
oh9b^OnJO[<00_nJO[<3oiYh[004oiaiZonWOJKoYgfVojMmYPGoZH:Y00?oYhVdolFN/Oo5W[400_o5
W[43olZ``0?ogL?000CoimC3olc9eoo<bMOoc<WG0oo@cmT3oiVhk@;o>8_]0_nFk_<3obZbg0?o[]gh
00?o`/WOokGBkoned^l00_ned^l3ok[1h003ok76jOnf_^3o][kP00?o][kP0_nb]m`2ok:lh@?o/KSO
00?o/KgSojnjh_n_^^800on_^^82ojfihP;o[[cT1?n/^n@2oj^kiP;o[;gV1On[_NL2ojVmj003ojZn
j?nY_^WoZKkY00;oZKkY1_nY_nT2ojRojP03o`000?nY_n[oZ;oZ00GoZ;oZ1_nX_n/9ojS0j`Kooooo
00?o0000ooooooooool03_ooool002Oooooo00?o0000ooooooooool0;_ooool4ojJok0;oYKWW0onK
^^h3oiVgk@CoU[C]0onA/nh2oh^dl@?oR<kn0_moeol01?n8j??o]NWgokGYmonejOL2okc=i`Co_<KR
00?o[:cGojFQdOnUXM400_nUXM43oibDb`?oT8O60on6OL83ogYd`@;oM7?40om_Nll3og9Q/0CoIV6h
00?oC73FolSChon[ZMH00on[ZMH2ohR2aPCoLVVj0_mNFK@2og=KZ0?oGdjV0om@DK@3of1@Z0?oM6Fd
00?oX9O;og5da_maM<H00omcKK`2of5D[@;oDdj^00?oDe6aoeMA/?mGDK000omRI;l3ogAKY`?oPfZ^
0_nLPK@01?nAVm[oPW:ioh9b^On2L[T3ohIZ[0;oVWR/00?oVGBWojMmY_nWOJH00_nWOJH5ojV2Z@Go
aIja00?ofK6`olZ``?oM`l000ooM`l02onOD``05olc9eoo@cmWod<oIom3?fOo<dMh00onQ]^P4ofJJ
kP;o>Hc]00?o07KMo`J4gol0Q/d00omodol3okGBk`03ok[1h?naa^Wo/LKY00;o/LKY0_nf_^02ok72
i`Go/[cQ00Co/KSOok6mhona_N?o/KgS0on_^^800on__^Co[[cTojjli003ojjli0;o[;_T0_n]_^H4
ojbmiP;oZkgW0_n[_^P4ojZnj003ojVnjOnY_nWoZKoY00CoZKoY1OnY_nX00ol0003oZKoZojRojP02
ojRojPOoZ;o[2_nX`>/6ooooo`03o`000?oooooooooo00kooooo000Xooooo`03o`000?oooooooooo
02kooooo0_nV_n`3oifmk`CoVk[^0onI]nd2oiJdk@?oT/7g0on=a_/2ohS>oP;oS^;m0_n^hoT2okS@
k0Co_<gW00?o_<KRojb/eon/[=L00_n/[=L3ojFQd@?oW9C;0on@QlH3ohIm`P?oNWC10omdLl@2ofmk
c`?oMIgZ0_mVHKP00omkgO[odNoWolSCh`02olSCh`?oZjWF0on8P/H3og9Y^P;oGUVd0_mQH[`01?mc
FjSoGdjVoem>Y_mOCZH4oe1A]003o`1^eomdIKCoM6Fd00;o/;kT0omaM<H2og=]_0;oHEB]0omCCZh2
oeMA/0CoHVBo0omKU^h2om[bh0?oTI_J0on2L[T3ohIZ[0?oVGBW1OnWOJH4ojV2Z@CoaIja0_oI/K00
1?o:/<3ogL?0omg3`?oM`l03onOD``?od<oI0oo<dMh3oj6fj0CoIY[^0_liS>d3obR<k@;oGkgm1OnN
c_P2ok76j@;oY/Oa1?na`^L2ok:lh@;o[l3V1Ona_N<01?n_^^;o[kkTojnni?n__^@2ojjli0;o[[oV
1On]_^H2ojbmiP;o[;oX1?n[_^P2ojZnj0?oZ[oY0_nY_nT2oj[0jPKoZKoZ00?o0000ojW0j_nX_nX0
0onX_nX2ojRoj`ooZ<3[1Oooool00ol0003oooooooooo`0>ooooo`00:Oooool00ol0003ooooooooo
o`0_ooooo`CoWKg_0_nK^^h2oiNmlPCoU;kd0_nB`OL3oiG@o0;oT]Wn0onYfoT00on^hoWo^=3/okS@
k002okS@k0;o_<gW0_na]]`4ojb/e`CoYJ7A0onLU</3oi27aP;oQWg20omjM<43ogAca0?oKg_?0ome
WNX2om7_i`04okBceonMULcoWIG<oifEc0?oQW_00_m/I[/01?n8P/KoLVVjog9Y^_mbJKX3oeiI]0;o
HF:l0omOCZH3oe1A]004ojWhiooNlmcog_?Lok2cfP;oKGG:0omaM<H00oloAk;oLfflof5D[@02of5D
[@;oDdj^0_mHMMD5of9T_`03oe^Fk_oJl^3of_;P00;of_;P0onAVmX3oh9b^@;oQVZ/1?nIM:L4ojMm
YP?oZH:Y0_o1Uj`2olFN/@?ofK6`00?ok<Zbomg3`?oM`l001?oWe<<00ooYh/_od<oIolcAgP02olcA
gP03ol7<honP/nKoX;?V00;oX;?V0omlWnT3oefFk@?o:8c]0_mG[oX2oik>n0;oRLGk1OnVao42ok72
i`;oZ/C/1?n_`>H2ok6mh`;o[l7V0on__^@2ojk1j0Co[[oV0_n]_^H2ojg0j0Go[;oX0_n[_^P00on[
`>WoZ[oYojZoj@02ojZoj@KoZ/3Z0_nY_nX4ojW0jP04o`000?nY`>[oZ;oZojRojQ?oZ<3[1?ooool0
0ol0003oooooooooo`0>ooooo`00:_ooool2o`00037ooooo0onI_?04oiNmlP;oU;kd0onGb?P2oiG@
o0?oY]?g0_nYfoT3okC@kP;o^=3/0_nc_>44ok6fg0Co[:cG0_nUXM401?nFU<ooSXc=ohj<cOn>S<d3
oh>6cP?oNXOE0omjM<43ogAca0?oKg_?00?oMIgZolgji_oAknL00ond/mL3oifEc0?oQW_00_m/I[/4
og9Y^P;oGUVd0_mQH[`3ogJ;f`04oe1A]?nYn>OoZOSWomkcg0?o/;?J0om]MLX2og5daP;o?dNb0omQ
E:d3oe=>[P;oF7GE0_mRI;l01?oBnn7oiORZon7iZooQnJ/2omSne@04ohK1n_lFBlKo5T_6oi6KfP?o
PW:i0on6JZ`3oiUdY`CoYgfV0_nYPZT3ol6G[0;oaIja0ooI/K02onc:/P04omg3`?oWe<?oimC3onOD
``;ojN;;0_oRk=L01?o<dMko`LcSol7<hoo1c><4oj2ciP?oO9oY0omMU^d2od^Dl004obR<kOmG[o[o
EjojoeN_nP?oRLGk0_nVao42oi_4m0GoZ/C/0_n_`>H2ojc3j`Co[l7V00?o[kkTojk1j?n^`NP00_n^
`NP2ojjoiP;o[/;Y1?n]`>P2ojboj0;o[<7Y1?n[`>T00onZ_nWoZ/3Zoj[0jP04oj[0jP;oZL7Z1_nY
`>X00onY`>_o0000ojS0j`0EojS0j`?ooooo00?o0000ooooooooool03_ooool002cooooo00?o0000
ooooooooool0;oooool3oiVll0;oUkgb0onI`_@2oiO8n0;oY<_d0onVdoL2ok3=k`?o]=3^0_nc`N@4
ok>lh@;o/KKL00?oYJGFoinLd_nOW=800_nOW=83oiJDc`?oSXc=1?n3Q/h3ogZ7e@?oKI;U0omH]_`0
0omni/SocO[VolgjiP02olG@hP?o];?G0onMUL`3ohIk`0;oK6Jk0omPHkh00ombJK[oGUVdoeiI]003
of5R_0CoMX_K00?oi?g8omcSfon`/mX00on`/mX2ofeebP;oDeRj00GoLGC6ocm7/_mGG;coEeblof5D
[@03oe=>[P?oF7GE00Cod__QonGhZ_oUn:[ohOV[0_oHo]D00on_jOSo5fgNoaM]gP02oaI;aP?oPW:i
0on6JZ`3oiUdY`CoYgfV0_nYPZT3ol6G[004olFN/OoI/K3ofK6`omVa/0?ok<Zb00?omnBdonOD`ooW
e<<00_oYh//3on;/e`Go`LcS0_nP/nH2oif_i0?oQZ7U0_mbV^T01?mMU^goBiC`od^Dl?m;U?03of2Y
n0?oOk_j1?nKa?@2oj[4k0;oY<C`1On/`n/2ojo1iP03ojg3j_n^`NSo[/7X00;o[/7X00?o[L?[ojk2
jOn^`^T00on^`^T2ojg0j0;o[<;Z1?n/`NT2oj_0j@?oZl7Z0_nZ`>X2oj[1j`CoZL7Z0_nY`>X2ojW1
j`?oZL3[00?o0000ojS0jonX`>/05?nX`>/3ooooo`03o`000?oooooooooo00gooooo000]ooooo`03
o`000?oooooooooo02oooooo1?nK_Nl2oiW2m0;oXlCa1?nTbo@00onVdoOo/<g_ok3=k`02ok3=k`03
okC@k_nc`NCo/l7T00;o/l7T0_nc_>400onZ[M[oYJGFojFUeP02ojFUePCoWicB0onFU<l3ohj<c@?o
PhK>1?mjQmD3offBi@04oeRfo?n5i[WocO[VolgjiPCoaM3R0ond/mL2oifEc0?oQW_00om/I[/3of1S
_P;oDg;D00?oGUVdof5R_?mQH[`00omfRm/01?oToLSog>?KomcSfooLhm/3ok2cfP;oKGG:0omCF;X2
ocm7/P;oEebl1?mCCZh01_mHMMGod__Qom;khOoUn:[ohOV[omSne@Co[nWh0_lGKMh01?lFBlKo?4fj
oh9b^On2L[T3ohIZ[0?oVGBW1?nWOJH00onYPZWo`IN/ol6G[002ol6G[0CofK6`0oo/b[82ooOT]003
onOD`ooYh/_oh^cG00;oh^cG0_oBj>H2ol7<h`;o/lGW1OnM[n@3ohJQi@;oLY[Y1?mUV^h2offWm004
of2Yn?mo^o[oOk_jognknP;oVlCd0_nD`?D4ojC4l0;o[<?[0_nXa>h4ojg3jP03ojk1j?n]`n_o[L?[
00;o[L?[0_n^`^T2ojc4j`Go[<;Z0_n/`NT00on[`^_oZl7Zoj_1jP02oj_1jP03oj[2jonZ`N_oZ/7[
00?oZ/7[0_nY`NX6ojW1j`;oZL3[00?o0000ojS1jonX`>/01OnX`>/2ojS1j`goZ<3[0oooool00ol0
003oooooooooo`0=ooooo`00;_ooool00ol0003oooooooooo`0_ooooo`;oVkg_0_nS_nd4oj?4l@;o
Y<_d0on]bNh2ok3=k`;o//;V0onc`N@00on]]=goZZgJojZ]fP02ojZ]fP?oYJGF1?nOW=83oiJDc`?o
SXc=1?n3Q/h2ogZ7e@?oQl;k00?oS>?kokgjjonmn^/00oo8hn/2olG@hP04ojN/f_nDU];oU9KBoiBF
dP?oO83<0on6Nl02ofaV^`?oH6>n0omCL]@3of5R_003ogJ;fooToLSog>?K00;og>?K00Co/k_Ooh6;
e?n1RmCoPH_D0om]MLX2oe=H^P04oci@_?loAk;oEebloeML_0GoTiWG00CofokAonGhZ_o?nk;ogofm
0_oQnm801OoEkNGoK[_mofjkoOm^^ogo5fgN00;o5T_600?o?4fjoh9b^On6JZ`00_n6JZ`3oiUdY`Co
YgfV1Oo1Uj`00ooH/;3ofK6`omVa/003onc:/P?omnBd00ColOFhomgn`?oMo/3oh^cG0_oBj>H2okgM
l0Co/lGW0_nM[n@2oiV[h`?oS:;S0omoW^H4ofFJkP?oKJOd0omn]_L4oiC0m@;oY<C`0_nO`_44ojS4
kP;o[L?Z0onZaNd2ojg3j`;oZlG]1?n/a>/2ojc2jP;oZlC/1?n[`^/00on[`N[oZ/;[oj[2j`02oj[2
j`;oZ/7[0_nY`^/8ojW1j`?oZ<7[00Co0000ojS1jonX`>_oZ<3[1_nX`N/2ojS0j`?oZ<7[0_nX`>/0
0onX`N_oZ<3[ojS0j`03ojS0j`;ooooo00?o0000ooooooooool03Oooool002oooooo00?o0000oooo
ooooool0;oooool4oj>ok@;oXlCa0on[a>`2ojg9kP;o/<?X1?nb`^H01?nc`NCo[KCMojfdgOn]]=d4
ojZ]fP?oYJGF0_nOW=801?nFXMcoSYgNohjMg_n>WMh4ohVOhPGoQ:W/0_n7`_/00omoj=ko_O[[okgj
j`03olSSj`03okFohOnW[=[oYjcJ00;oYjcJ0onDU]82ogb0c0?oL7O:0_m/I[/4of1S_P?oDg;D00?o
[Nkhojg^XOo@om<00_oMnMX01?oLhm_o/k_Ook>kgonc^ml2oh6;e0;o?ES400GoKGG:oe=H^_mCF;[o
DeRjoci@_003oeML_0?oTiWG00CofokAonGhZ_o?nk;ogofm0_oQnm83omG]i@?oK[_m00Go5fgNoaI;
a_llCK[o?4fjoh9b^@02ohIZ[0CoVGBW0onWOJH01?nhT:go`IN/ol6G[?o1Uj`2omR`/0;ofK6`0oo/
b[83ooOT]005oo7e^?oMo/3ob_oKol[ofooBj>H01?nmgO02ok?5i`;oYKWX1?nIZn<3ohbRh`?oOikV
0omfWn/4ogVXl0?oPk?d1?nB_O@4oio2l@;oZ<C^0onUa?02oj[5k@03ojS5kon[aNgoZlG]00?oZlG]
0_n/a>/2oj_5k@CoZlC/0_n[`^/3oj[3k0;oZ/;[0_nY`^`4ojW2j`;oZL7[0_nY`N`4ojW1j`?oZ<7[
00?o0000ojS1jonX`N/03onX`N/4ojS0j`;ooooo00?o0000ooooooooool03Oooool0033ooooo0_l0
000`ooooo`;oXko]0_nY`>X3oj_4k0;o[l;X1?n``nP2ok;2iP;o[[WQ1?n]]=d2ojZ]fP03oj:[g_nL
Y]coW:KL00;oW:KL0onFXM`3ohjMgPCoRIoR0_n4ZN`3ohOOo@;o/_;d0oo4k?001?o8hn_o]KoQokFo
hOne_n43ojN/fP?oU9KB0omlP<`2og1gbP?oIgWA0omPHkh01OmCL]Co[Nkhojg^n?nLm>Cod?oC00;o
gOWJ0_o=f^<3ok>kg`?oPH_D0_lmF<@3oe=H^P;o?U2l0omGG;`01OnCVMOofokAom_ndOo<n^Oogofm
00;ohO_B0ooEkND2ol?Hj@?oCi_c00Co002@oca=^_llCK[o?4fj0on6JZ`3oiUdY`;oYgfV0_nhT:d3
ol6G[0?of;2`00?ofK6`onc:/_o/b[800oogi;@01?oamKSogOk0ol[ofoo:om/3okGdl`;o_Mg`0_nX
bO44ojFij0?oVJ_S0on<X^<4ognNiP?oMYo[1?miZ?03oh>cm0;oT[gd0_nC^o<4oig2lP;oYLC`0_nS
a?04ojS5k`;oZlG]0_nYaNh5oj_5k@;oZlC/0_nZa>d2oj[3k0;oZL?]1OnY`^`2ojW2j`03ojW2k?nY
`NcoZL7/00?oZL7/0_nY`N/2ojS1k0;oZ<7[00Co0000ojS1jonX`N_oZ<7[0onX`N`2ojS1j`03ojS1
k?nX`N_oZ<7[00OoZ<7[1?nX`>/00ooooooo0000ooooo`0>ooooo`00<_ooool00ol0003ooooooooo
o`0^ooooo`CoZL3Z00?oZlC/ojo2j?n_`^P00_n_`^P2ok33j0;o[kcT1?n^^N42ojfdg@03ojJah?nR
ZmkoXZ_N00;oXZ_N1?nLY]`3oiJQg0?oSYgN0_n9Wn83oh_;o@04ohOOoOnbl_Co/_;dok;bm0?oa>c`
0_nmc^L4okFoh@?oYjcJ0onDU]82ogb0c0?oL7O:0omWNM43ogbQj`;oW?CT00?od?oComgif_oMnMX0
1?o=f^<3ok>kg`;oPH_D0_lmF<@2odYSb`04oe=H^_lnD;co?U2loci@_0?oNZ7[0_o<n^L00ooTnloo
joW6on_iaP02on_`c@03omG]iOo3f>Wo`mSY00;o]LKW0_mBU_02o`00T0;o?4fj0_m[H[H01On6JZco
VGBWoiUdYonIM:OoYgfV00?o^92]0_o1Uj`4omR`/003oo7F]_o/b[;ok<Zb00;omnBd00?olOFhomgn
`?n4j]T00_n4j]T2okGdl`;oXmWk1?nXbO42ojFij003oiZ`ionEZ>?oUJSS00;oUJSS0on?Xn83ohRQ
i0CoPj?X0on4Z^d4ohVbl@CoTk_c0_nM`_82oig1l@CoXlC`0_nXaNl2ojK5k`CoZLG^0_n[aNd3ojW5
kP;oZ/C]0_nYa>d4ojW3k@;oZL;/0_nX`^`4ojW2k0;oZL7/0_nX`^`5ojS1k0;oZ<7[00?o0000ojS1
k?nX`N`01onX`N`2ojS1j`;oZ<7/1OnX`N/3ojS0j`03ooooool0003ooooo00kooooo000cooooo`03
o`000?oooooooooo02kooooo0_nY`>X3ojk1j0;o[l;X0_n__nH4ojnli0;o[[WQ0_nY]^83ojJah0Co
XZ_N0_nLY]`00onG[nSoTk;/oi>bk002oi>bk0CoSK[d0_n;bod3ojGUn`;o]n_f00?o_=K]okg>ionm
c^L00onmc^L2okFoh@04oj:Uf?nBU]CoTYKDoi:Fe0?oQ8WA0omaP]@3og1gbP?oIgWA00CoO:7[oicd
i?nLm>Co__C`0_oBo=l2omK/h`;ocM[S00Co/KSOohnIf?n?VMSoSiWH0omYNM02oceHa0?oBV?;0oln
D;`00omjXN_oc?[Wolcji`02onCkc`;ojoW600Cojo3=on?UdooSiM?o`mSY1?nea^L2oe:Fl003o`00
T?llCK[o?4fj00?oJf:f0_nIM:L00onLOk;o^92]okR@[@03okR@[@03ol6G[?oH/;3of;2`00;of;2`
0_oae[H01?o/b[;omnBdokcZSOmifIl2ohCZf@?oUN;m0_nSfO/2oiK1m0?oVKS]1?nJ/>L4oiFXh`?o
Sj?R0on8XN@4oh>Sj0?oQ:[]0_n9/_42oi2dk`?oU[_a1OnM`O43oj?4l0GoY/G_0_nYaNh3ojS5k`;o
ZLG^00?oZ<C^ojW4kOnYa>d00onYa>d2ojW3k@;oZ<?]1?nX`^`2ojW2k0KoZ<;/1onX`N`00ol0003o
Z<7/ojS1k00;ojS1k0;oZ<7[0_nW`>/4ojS0j`03o`000?oooooooooo00gooooo000dooooo`03o`00
0?oooooooooo02kooooo1On^`NP4ojnoiP;o[kcT0_n[^^@4ojVfhP?oY[7P0_nRZmh2oib`iP?oUjoX
1?nC/^`2ohfjm0?oW]Kk00?oYNGkokO[m_ngjoH01?nle^d2okg>i`;o[KCN1?nRYMP3oi:Fe0?oQ8WA
0_maP]@4og6Ah`?oP/3k0_nnm?02om;lg`;oe^cS00?oam?Sok6hgona^=l00_na^=l3ohnIf0;oJGW@
0_lgG/d3odYSb`CoO9gW0_o7l^h01?oTnloojoW6on_ia_o[l<d3on?Ud`;oemOG0_nea^L2ojnkh`;o
Jio_00?o002@oca=^_m[H[H00_m[H[H3oiao/PGo^92]00Co`IN/omR`/?oH/;3of;2`0ooae[H00oo_
mZ[o_>Z=okcZS@02ohGSn@03oiS>n_nEb?WoULSi00?oULSi0onF`O@3oiVhk@?oV[3W0_nEZ><2oi:V
h`?oTJCR1?n>Y>@3ohbWi`CoSJg/1?n@]>l3oiJkl@;oWL7a0_nN`?44oj?4l0;oY/G_0onUaNl2ojS5
k`;oYlC_1?nXa>h2ojW4k@OoZ<?]0_nX`^`00onX`^goZ<;/ojS2k007ojS2k0OoZ<7/00?o0000ojS1
k?nX`N`02OnX`N`00onW`NcoYl3[ojO0j`03ojO0j`;oZ<3[00?oooooo`000?ooool03_ooool003Go
oooo0_l0000_ooooo`Go[/7X0_n__nH2ojbni`CoZk[T0_nY]^800onT]^KoX;?Uoj2ci@02oj2ci@Co
W;3V0onG[nP2oi>bk0?oVlWg0_nNe_/2ojkTn@?o^=W`0_nle^d2ok>oh`Co[KCN0onRYMP4oi:Fe0?o
Q8WA0_maP]@4og6Ah`03oh;0nonnm?3o__C`00;od_cO00?oe^cSolOChoo7dn<00_o7dn<4ok6hg`?o
SiWH0_mYNM02ocMNc@?oBV?;0_mlWNL2olObkP04onCkcoo[nLKojoW6on_`c@?ohnGC0ooGemL00oo<
b]So[k_Sojnkh`02ojnkh`;oJio_00?o012Qoca=^_m[H[H00_m[H[H3oiao/PCo^92]1?oH/;03oo7F
]P04onofZ_nljXgoY=7gojCAm`?oV<kj0_nEb?T2oi>dkP?oSjo/1?nA[>P3oi>Yi@CoTZKS0onAY>84
ohjTi0?oS:OW1?n=[N`2oi2dk`03oiJfkOnJ^o3oV[_`00?oV[_`0onN`?42oj?4l0?oXl?`0_nUaNl2
ojG4k`CoYlC_0_nXa>h2ojO4kPSoZ<?]1?nX`^d9ojS2k0KoZ<7/00?o0000ojS1k?nX`N`01OnX`N`6
ojO1k0;oYl3[1_ooool00ol0003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`0^oooo
o`;o[/7X0_n/`NT4ojbni`;oZk[T0_nV^^L3ojBfiPCoX;?U0_nL/>H2oiblk`CoVL7c0_nKbOL3ojGJ
nP04ojkTnOnhfO3o^=W`okSIl0;o]/SX1?nc_n<3ojfdgP;oXZGH00?oU9oKohNGg?n7Um`00_n7Um`3
oh:Ih0?oPZK[0_maTN<2oi[=nP;o^?;c00?oc>o[olcQj?o<hNP00oo7dn<00on`^n;oVJCMoiVTg@02
oiVTg@?oN8cJ0omWP]X2ocMNc@;oIIS]00?oO9gWolObk_o7l^h00_oTnll01Oo?mnSog_;Lon7Zf?oQ
j]SohnGC00?oemOG0oo<b]P2ojnkh`05ojjfg_n8ZN_oR:W[ohRYjollCKX00om[H[H3oiao/PCo^92]
00?ock2jomR`/?oH/;000ooae[H01?o_mZ[o_>Z=ojCAmonTdOL2ojRmj@?oW;W]1?nC]>h3ohn_k0Co
TJcX0onCZND3oi:Vh`CoTJCR0_n>Y>@00onBZ>CoTZ_Woi:[i`02oi:[i`?oTk3Z1?nF]^d2oiZkl0;o
WKc^1OnP`?02oj?3l003ojC2konUa>ooYLC_00?oYLC_0_nWa>l00onVa>koYlC^ojO4kP03ojO4kP;o
Z<?]0_nW`nd4ojS3k@;oZ<;]0onW`^d2ojS2k003ojO2k?nX`^coZ<;/00?oZ<;/0_nX`N`01OnW`Nco
Z<7/ojS1k?nX`Nco000000?oZ<7/2?nW`N`9ooooo`03o`000?oooooooooo00cooooo000hooooo`03
o`000?oooooooooo02kooooo1?n/`NT2ojbni`;oYkgY1?nV^^L3ojBfiP;oX;?U0_nM^nd4oiblk`;o
VL7c0onQdOP2ojGJnP?o/MOc00?o^=W`okK8j?nfb>P00_nfb>P2ok>oh`03ojNbh?nNZ=koWZSN00;o
WZSN0onDWm/4ohNGg0?oPYWP1?n2Y^/01?nJcO[o^?;colc_joo<kn/4olcQj004olOChon`^n;o/;_R
ok2khPCoVJCM0_mhS=X3ofN2fP?oGHkX0_mUV>d2oj[Mn@;ocoOX0_oNl]`2on7Zf0;og=gF00?oemOG
olc:f?o<b]P00_o<b]P4ojjfgP;oR:W[00Co012Qof]R]_m[H[KoJf:f0onLOk83okR@[@;ock2j0_oH
/;02oo7F]P04onofZ_n_d?7o/[oTok:oi0CoZ;gY0onL^Nd2oi>dkP03oi>YiOn=YNGoSJGU00GoSJGU
1?n?YN@3oi6Uh`?oTjKS1?nBZ>@4oi:[i`?oTk3Z0_nF]^d2oi^hk0CoWKc^0_nP`?02oj;0k`CoY<;_
0_nUa>l2ojG3kPCoY/C^0_nWa>h3ojO3kPCoYl?]0_nX`nd4ojO2k@KoYl;/0_nX`^`6ojO1k0;oZ<7/
00?oYl7/o`000?nW`N`01_nW`N`<ooooo`03o`000?oooooooooo00cooooo000iooooo`03o`000?oo
oooooooo02kooooo0_n/`NT2ojS0j`CoYkgY0_nV^^L2oj:lj`CoXK_/0onM^nd2oiblk`?oWlWf0_nQ
dOP3ojcBm0;o/MOc0oncc>`2okK8j0;o[K[S0onW/^04oijXgP?oU9oK0on7Um`3oh:Ih0;oPZK[0_nQ
eOX3okkVlP;oanK/0_o<hNP2okk<i@Co/;_R0onIY=d3ogR<fP?oIh;J1?mMS^P00onZgOWocoOXolog
j002omkbg0;ohN[H0ooLgMH01?oEd]Koc<[Holc:f?o<b]P2olC0e`;o[[KN0_n`/mX2oib_i@;o:eG9
0_m[H[H3oiao/P03okR@[Oo?/;[ock2j00;ock2j00Cof;2`oo7F]_oae[Ko[m3a1?nb_n@2ojRmj@03
ojRagonL[N?oW:gS00;oW:gS0onCZND7ohfUi@CoSjGT0onAYN<3oi>Vh`;oTZST00?oUZ_UoiR_ionH
[nL00_nH[nL5oiVcjP?oVkS/0_nM_>h2oj2mk@CoX/3_0_nT`^l2ojG2kPCoYL?^0_nVa>h3ojK3kP;o
Yl?^2_nW`^d8ojO2k0_oYl7/00?o0000ojO1k?nW`N`04?ooool00ol0003oooooooooo`0<ooooo`00
>_ooool2o`0002oooooo1?nX`>/2ojNmj@;oY;k/1?nR_>/2oj6kk0;oX<;`1?nOa?<2oio9mP?oZ<gd
0_n/d_@3ok7=kP;o/lc/0_n__nH4ojfjh`?oYk;P0_nNZ=h00onFYN3oT:?Roi2ShP02oi2ShP?oR:KX
1?n?^?801?nQeO[o_^KbokkVl_nni_82olOVk0;oa=OX1?nnc>D2ok2khP04oinZgon<VmcoS9_LohbK
g0?oM8oO1?mWP]X2oef>j0;oUlKg0_o2gnd00ooNl]cohN[Hon7Zf003omcMeP?oeM;F00Goc<[HolC0
eoo4`=Ooa<3GojjfgP04ok2cfP;oW:oU0ol[ELT3oiao/P03okR@[Oo?/;[ock2j00;ock2j0_o/kL/2
okNng`;o/[oT0_nb]M/4ojRag`CoW:gS0onCZND2ohfUi@04ohjRh_n=X^?oSJ;SohfRh`CoSjCS0onB
Y^<4oiBYi0?oUZ_U1?nH[nL2oiVcjP;oWKKZ0onN^^`5oj2mk@;oX/3_00?oY<3^ojG2k_nU`^h00onU
`^h2ojG3kP;oY/;^0_nV`nh2ojK2k@goYl;]2?nW`^`:ojO1k003o`000?oooooooooo013ooooo00?o
0000ooooooooool03?ooool003cooooo00?o0000ooooooooool0;Oooool2ojS0j`;oYKo/1?nT_^`2
oj:lj`;oXL3_1?nP`_02oio4l`?oYLWb0_nXcO@2ojg<l0?o/Lg^0_n_`nT4ojnoiP;o[K[S00?oYK7Q
oij[gonNZml00_nNZml3oiJUh0CoT:?R0on8Y^P2ohnhlP?oZ=?g00?o_^KbolOVk?o7i^`01?o4enP2
okk<i@;o[k[R0onOZ]l3ohbKg0?oM8oO1?mjWNP01?nGa_Oo`]o]ol;OkOo2gnd3omCThP;of=gK00Go
g=gFomGBe_oEd]KoeM;Folk8e@03olC0e`;o_[[F0on`/mX01?nc/mSoZ[;NojZbg_nZ/]h2ob]Eb@?o
Y9k?1Oo?/;X01?o/kL_o]kkOokNngong]]P5ok:ef`;oZ;7O00?oYj_JoifWgOnMYmd00_nMYmd3oiBT
h0CoSZ;R0on=X^<4ohnTh`?oTZKS1?nDZN@3oiJ[i@;oV:oW0_nL/^P4oiffjP?oW[[/0_nP_Nd3oj>n
k@?oY<3^0_nU`^h3ojG1k@;oY/;^1_nV`^d2ojO2k@;oYl7]1_nW`^d2ojO1k0KoYl;/2?nW`N`5oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool03?ooool003gooooo00?o0000oooooooo
ool0;Oooool4ojFok0;oY;k/0_nR_nh4oj70k`;oX<;`0onTaO42ojG9lP;oZ/W`1?n]c?000onacNko
[l?Yojo3j@02ojo3j@;o[koV00?oZKOSojFahOnU/N400_nU/N44oij[g`?oUZGP0_n@Xn82oiFdk0Co
VKob0_nXdoL2okOPm0?o_M[^0_o4enP2ok[8i@Co[k[R0onOZ]l3ohbKg0?oM8oO0_mjWNP3oi^ml004
ol;OkOoDi>;oe>CRomCThP?of=gK00?oe]KHomGBe_o>b=D00oo>b=D00oo4`=Oo_[[FokjjeP02okjj
eP04ok2cf_nc/mSo/k?Hok>cf0?oZ[;N00?o:eG9ojBNconTW/l00_nTW/l3oln`^P03onc]boni^m_o
]kkO00?o]kKH0onb]M/00on`/=OoYj_JojN[fP02ojN[fPCoWJOM0onDY>04ohjRhP?oSJ;S0on?Y><2
oi:Vh`03oi>Xi?nG[>GoUjcU00;oUjcU0onI[nH5oibbj0;oWKKZ00?oX;WZoj:ljonR_>/00onR_>/2
oj>nk@;oY;o/1?nU`>d2ojG1k@;oY/7]1_nV`^d6ojO1k@;oYl;]1_nW`N`2ojO2k0SoYl7/2Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo000nooooo`03o`000?oooooooooo
02gooooo0_nU_n`2oj>ok@CoX[o^0_nQ`>l3oj?2k`;oY<Ga0_nXa^l4oj[9l0;o[Lc`0on^aN/2ojo3
j@;oZk_U0onY]n<4ojFah@;oWZ_O0_nK[nD3oiJ^j0CoUKC/0_nI_o83ojWBmP04okOPm?nmf^ko_M[^
okgJkP;o^]3Z1?njb>D2ojnjhP03oj>`hOnDY>3oU:CP00;oU:CP0on:W^43oh:Qi`?oVkg`0onfdNh0
1?oDi>;of=gKomSMfooHgM/2omKFf004om7?eoo>b=Goc/SEolk8e@;oal7D0onn^]H2ok^ge@Co/k?H
00CoZ[;Nok:cfOnb/mWo:eG91?nTW/l00oo?/;[ok>g;okVkf`02okZgePCo]kKH00Co/[GKok2`eon`
/=Oo/;3G1?nWZmX2oifWg@04oijTf_nFXMcoUZ7LoiJQg0CoT:3O0on>X^44oi2Th`?oTjST1?nG[>D3
oiV_iP;oW;;X0_nO]^P4oj2ijP;oX[c[0_nT_N/5ojBok0;oYL3]00?oY/3/ojK1kOnV`Nd00onV`Nd2
ojK2k@03ojO1k?nW`NgoYl7]00GoYl7]3?nW`N`@ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03?ooool003oooooo0_l0000_ooooo`?oXko]0_nR_nh3oj?0kP;oXl;_0_nVa>h4ojS6
k`;oZ/W`0on/aN`2ojk5j`;o[;kW1?n[^nD3ojVgh`;oYK7Q0_nO/N@4oi^_i@?oUZkX0_nE]>`3oio5
l`;oZM;f0onee_400onmf^ko^]3Zok[@jP02ok[@jP;o^/SU0_n^^n@3oj>`h@CoU:CP0on:W^43oh:Q
i`04oi^ml?nfdNko]]7^okKAkP?oa=GW00?of=gKomKFf?oFe]P00ooAcmL00oo>b=Goal7DolO1e002
olO1e003okjje_nk]mGo^kOE00;o^kOE0_nc/mP00onf/mKo/[?Iok:cf@02ok:cf@;oY9k?0_mmho@0
0onh]mSo^K_KokZgeP03okZgeP;o]kKH0_ng/]D4ok2`e`;oYj_J0_nWZ=L3oijTfP?oUZ7L1?n@X=l3
ohjRh@CoT:CS0onCZ>@2oiN/i@;oVJoV0onL/^L4oinfj0;oX;WZ0_nS^nX4ojBmj`;oY;o/0_nV_n`4
ojK0k0;oY/7]1_nW`N`2ojO1k@goYl7/5?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00_ooooo0011ooooo`03o`000?oooooooooo02gooooo1?nT_nd2oj?0kP;oY/7]1?nVa>h2ojS6
k`?oZ/C/0_n/aN`2ojc0j0Co[;kW0_n[^nD2ojNhi@?oY;CT1?nO/N@2oi^_i@;oW;O[1?nK^nl2oio5
l`?oZlkb0_nee_43okSBkP;o^]3Z00?o/lCWojjki?n^^n@00on^^n@3oj>`h@;oU:CP00?oTZGRoi6X
i_nAZ>H00_nAZ>H4oiRek004okKAk_o4eNOoa=GWolCEi`;ob]GR00Coe]KHom7?eooAcmOodLoG0_o<
b=L3olO1e0;o`[gE0onk]mD00onj]MGo][?FokJceP02okJceP03ok:cfOng]=Oo]kCG00;o]kCG0_nh
]mP2okZfe@?o^[OF00?o^[CDokNbeOng/]D00ong/]D2ok2`e`03ojn/eOnWZ=OoYjSG00?oYjSG0onN
Y=X3oiJQg0;oT:3O00?oTj7Noi6ShOnAXn400_nAXn43oi:Vh`?oUJ_U1OnI[nH3oibbi`;oWkKX0_nQ
^>T4oj>kjP;oY;g[0_nU_^/4ojJok0;oY/3/0_nW`>`CojO1k1Sooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0;ooooo`00@_ooool00ol0003oooooooooo`0]ooooo`;oY;o]0_nV_n`4
ojK1k@;oY/C^0_nY`n`3oj[4k0;oZl7Y1?n/`>P2ojbni`;oZ;_V1?nW^>D3ojBdi0;oWk7T0_nN]NP4
oibgj`;oVk__0_nTa_43oj_>lP;o/M7`0onhd^h00onebNWo/lCWok?4i`02ok?4i`;o[[_T0_nT/n<3
oib[h@CoTZGR1?nAZ>H2oiRek0;o[<C[00Coa=GWol[Eh_o:eN;ob]GR0oo;d=h00ooAcmOoc<SGolc8
e`02olc8e`03olO1e?o2_MGo`[gE00;o`[gE00Co^kOEokZeeOnj]MGo^[GE0_nf/mH2okNdePCo]kCG
00?o^;OHokZfeOnj]]D00_nj]]D01?nj]mKo^[CDokZde?nj]=@3okNbe@03okF`e?n_[=Go[jcE00;o
[jcE0_nWZ=L2ojNWe`?oWjCI0onHX]/4oi>QgPCoTJ?Q0onBY^<3oiF[i@;oVJoV0_nK/^L4oijej0Co
XKSY0_nS^nX00onT_N_oYKk[ojFnj`03ojFnj`;oY[o/00?oY/3/ojO0k?nW`>`00onW`>`>ojO1k1go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`00@oooool00ol0003ooooo
ooooo`0]ooooo`CoY[o/0_nV`Nd2ojS1k0CoZL?/00?oZ/C/oj_1jOn[`NT00_n[`NT2ojc0j0;oZ[gW
1?nX^nH2ojNhi@;oY;OW0onQ]^L4oijej0;oW;O[0_nQ`>l4ojC6l@03oj_>l_nadO3o/M7`00;o/M7`
00Co^=;^okG9jOnebNWo]LWY0_nca>L2oj^ji@CoY;?S0onLZn43oi:UhP;oTJSV0_nM]NT3ojc4j`?o
^L_X00?ob]GRol_@g_o;d=h00_o;d=h01Oo8c=goc<SGolc8eoo<b=Ooa/CH00Co`[gE00?o_[[FokZe
eOnj]MD00_nj]MD00onf/mKo]kCFokNdeP02okNdeP;o]kCG0_ni]MD3okZfe@03okZee?nj]=Co^[CD
00?o^[CD00Co]k;EokF`e?ne/=Co]K3D0_n_[=D00on^[=GoYjOGojNWe`03ojNWe`?oWjCI0onHX]/4
oi>QgP;oTJ?Q00?oUJGQoiJYi?nFZN@00_nFZN@3oiR]iPCoVk;W0_nN]NP2oj6hj@?oXk_Z1?nT_N/2
ojFnj`?oY[o[0onV`>`5ojO0k0;oYl7/0_nW`>`6ojO1k23ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`00A?ooool00ol0003oooooooooo`0]ooooo`;oY[o/0_nX`>/4ojS1
k0;oZL?/0onZ`NX2oj_1j@;oZ[kX1?nZ_NL2ojRkiP;oY[WW1?nT]nL3oj6fi`;oW[GX0_nP_>d4oj70
k`;oY<Ka0_n[c?42ok7Al0?o//_/0_nebNT2ojo1i`CoZk[U0_nT/n<00onN/>CoVJcToiV/i002oiV/
i0?oUZcV1?nM]NT01?n/a>_o^L_XokW;j?nibnP2oko=i@?obm3N0oo8c=d01Oo<b=Ooa/CHolK4f?o6
a=So`[gE00Co_[[F0_nj]MD2okVfeP?o]kCF00?o^;GFokVeeOni]MD00oni]MD01?nj]]Go^[GDokZe
e?nj]M@2okZde0;o^K?C1?ne/=@01?n_[=Go[ZcEojj/eOn^[=D4ojNWe`;oWjCI00CoX:CHoi^SfonK
Xm_oVj?K1?nFXmh4oiFUh@CoUZWT0onH[NH2oi^bi`;oW[CX1?nQ^>T3oj>kjP;oY;g[0onU_^/2ojJo
j`;oYko[3?nW`>`2ojO1k2Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`00AOooool2o`0002oooooo0onX`>/2ojS1k0GoZ/7Z0_nZ_nT4ojZnj0;oZ[gW0_nW^nL4ojJii`;o
Y;OW00?oX[[Zoj6kjonQ^n/00_nQ^n/4oj2lk@;oXL3_0_nVao02oj_<l@?o[l_^0_nbbn`2ok35jPCo
[l7W0_n[^^D2ojFei@?oW[3T1?nI[>@3oiJ/iP;oWKGY0onX_nX00onibnSo_lgUoko=i@02oko=i@05
ol_@g_o8c=gob<cMolS<gOo5b=d00oo6a=P2ol70f@?o_[[F00?o^kWHokVfe_ni]]H00oni]]H01?ng
]=Ko^;GFokRee_nh]MH3okVee@05okZfe_nj]MCo^[GDokZee?nj]MD01Oni/m<2okF`e0;o]:oD1?n^
[=D2ojNWe`03ojNWe_nPY=SoX:CH00;oX:CH0onKXm/4oiJSgP?oUJGQ0_nFZN@2oiV/i0?oVk3V1OnN
]>P2oj6hj@03oj>jjOnT_>[oY;cZ00?oY;cZ0_nU_^/00onV_n_oYko[ojNoj`03ojNoj`;oYl3/00?o
Yl3[ojO0k?nW`>`01?nW`>`Yooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02ooo
ool004Oooooo00?o0000ooooooooool0;Oooool4ojW0jP;oZ/7Z0_nZ`>X4ojZoj@;oZ[kX0_nX_NP4
ojNki`;oY[WW00?oY;_Yoj:jj_nR^^X00_nR^^X2oj6kj`;oXl3^1?nT`nl2ojK7l0;oZlS_0on_bnh2
ojo7k0Co/<GZ0_n_`NL2ojVkiPCoYKGU0onN/>@2oiV/i0;oVk3V1?nM]>T2ojRojP;o/LGY0onocND3
ol7=h`05olS<gOo5b=goaLSMolG8gOo6a=P01?o1`=T01?nn^]Ko^kWHok^if?nk^MP3okVfeP;o^;KH
1?nh]MH01Oni]MGo^[KFokZfe_nj]]Ko^[GD00?o^[GE0oni/m<00ong/mCo]:oDokB_e003okB_e0;o
[ZcE00?o[J_EojNWe_nWYmH00_nWYmH4oj2Tf0?oVj?K0_nFXmh2oiZVgP?oVJSQ1?nI[>@3oi^`iP;o
W[CX0_nQ]nP4oj>jj@;oY;cZ0_nU_N/4ojJoj`;oYko[1_nW`>/2ojO0k2cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0;ooooo`00B?ooool00ol0003oooooooooo`0]ooooo`CoZL3Z
1?nZ`>X2ojZoj@;oZKkY1?nX_NP2ojNki`03ojJljOnT^nWoY;_Y00;oY;_Y0_nR^^X2oj>nk0CoXl3^
0_nT`nl2ojS6k`CoZlS_00?o[l_^ojo7k?n_an`00_n_an`2ok35jP;o[;oX1?nY^nH2ojFei@;oXK?U
0onL/>D4oi^`iP;oWKCY0_nT_>X4ok75j@05oko=iOo1cN?o`LgSol7=hoo0b^800oo5b=d2ol75g@?o
`L3I0_nm_]/4ok^if003okVfe_nh]]So^;KH00;o^;KH0_nh]MH01?nh]]Oo^[KFokZfe_nj]]H2okVg
e`Co^[GE00Co^K?CokNce?ng/mCo]k?D0ond[m@00onb[mGo[J_Eojf[e@02ojf[e@CoYjOF0_nPY=P0
0onRY]WoWJGKoifUf`02oifUf`CoVZKN0onIZ>42oiV/i0;oWJoT0onN/nH4oj6gj0;oXk[Y0_nT^nT4
ojFmj`;oY[o[0_nW_n/6ojO0jc3ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;
ooooo`00BOooool00ol0003oooooooooo`0]ooooo`CoZL3Z0_nZ`>X2ojVojPCoZKkY0_nX_NP00onW
_NWoY[cYojJlj@02ojJlj@;oY;_Y0_nT_N/4oj>nk0;oXl3^0_nV`nh4ojS6k`;oZlS_0on/anh2ojo7
k0;o[L;Z1?n/_nP2ojVkiP;oYKOV1?nQ/nD3oib`i@;oVk3V0_nN]^T4ojBljP;o/LGY0_nfb>P00oo1
cN?o`<[Rol3:hP02ol3:hP03olG8gOo1aMgo`LGM00;o`LGM00?o`L3Iokfnfonm_]/00_nm_]/2ok^i
f003okRif_nh]]So^;KH00;o^;KH00?o]kSJokRfeonh]]L00_nh]]L00onj]]Ko^KOGokVge`02okVg
e`;o^[GE0_ni]]H4okNce004okB_e?nb[mGo/ZoEok:_e@Co[J_E0_nWYmH00onWZ=OoXZKIoj:Vf@02
oj:Vf@CoWJGK0_nJY]h01?nMZ=koWJ_Qoif[hOnMZn45oif_i0?oW[?V0_nQ]nP2oj>ij0CoY;_Y0_nU
_N/00onV_^[oYko[ojNoj`03ojNoj`;oYl3[=?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo001:ooooo`;o0000;_ooool2ojW0jP;oZL3[1?nY_nX2ojVnj@;oYkkZ0onW_NT2
ojJlj@;oYKg[1?nT_N/2oj>nk0;oYL7^1?nV`nh2ojS6k`?oZ/K^0_n/anh2ojc4j`Co[L;Z0_n/_nP2
ojRki`CoYKOV0_nQ/nD00onN]>OoW;?Xoibcj002oibcj0CoW[KY0_nT_>X2oj[2j`;o]/SX0_ngbNP3
ol3:hP;o_/SS0oo1aMd2okc3g`?o_KkK00?o^KgMokRif_nh^MX00_nh^MX00onh]]So]kSJokNhfP02
okNhfP;o^;KG0_nh^=T3okVge`03okRhfOni]]Ko^KKF00?o^KKF0_ng/m@00onf/mKo/ZoEok:_e@02
ok:_e@;o[J_E0_n/[=L4ojNXe`?oXZKI0_nMYM/2oj2Wf`CoWJSN0onMZn42oif_i0;oXK7T0onR]NH5
oj>ij0;oY;_Y00?oY[cYojJnj_nV_^X00_nV_^X2ojNojcWooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0:ooooo`00C?ooool00ol0003oooooooooo`0/ooooo`CoZL3[0_nY_nX3ojRo
jP?oYkkZ00CoYkgYojJnjonV_^_oY[k[0onU_N/2ojBmj`?oYL3]0onU`Nh2ojK3kP?oZ<G^0_nZa^h2
oj_4k0Co[<C[0_n]`^X2ojZnj0CoZ;_W0_nU]nH00onQ]^OoW[CWoijdi`02oijdi`CoW;?X0_nN]^T0
1?nS_>_oZ/;[oj[2jonZ`^/2ojk5j`Co]lWX00?o`<[Rokk8honnb><00_nnb><00oo1aMgo_<?Ookc3
g`02okc3g`04okfnfoni_Mgo^KgMokVmg@;o^;WJ0_nf^]`3okNhfP03okJig?nh^=Wo^;SI00?o^;SI
00Co^KOGokRhfOnh^=Wo^;SI0oni]]H00ong]]So][?FokJceP02okJceP;o/ZoE0_n`[mL4ojb/e`;o
YjSG00?oYjWHoj>XfOnSZ=T00_nSZ=T4oj2Wf`?oWJSN0_nMZn42oj6^h@CoXK7T0onR]NH2oj>ij0?o
YK[X0onV_>T2ojJnjScooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00
COooool00ol0003oooooooooo`0/ooooo`;oZL3[0onX`>/2ojRojP03ojNojonV_^_oY[k[00CoY[k[
1_nU_n`2ojG0k@;oY/;]1?nV`nh2ojS5kP;oZLC]1?n[a>`2ojc4j`?oZ/7Z0onZ_^P2ojRki`03ojBi
j?nQ]^OoXKKW00;oXKKW0_nN]>L2oijgj@CoW[S[0onS_>/00onZ`^_o[/G[ojk5j`02ojk5j`Go]lWX
0_nnb><3ok[6i0;o_<?O00Co^<7QokVmgOni_Mgo^KgM0_nf_Ml4okJjg004okNhf_nf^Mco][WLokJi
g0?o^;SI00?o]kWKokRhfOnh^=T00onh^=T01?ni]]Ko]kKHokNff?ng]]P2okJceP;o/k?H1?n`[mL2
ojb/e`03oj^/f?nWZMSoYjWH00;oYjWH1?nSZ=T2oj2Wf`03oj>YfonQZmkoXJ_N00;oXJ_N1?nQ[^42
oj6ai0;oY;?S1?nU]nH2ojFjj4?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:
ooooo`00C_ooool00ol0003oooooooooo`0]ooooo`;oZ<3[00?oYl3[ojNojonW_n/00_nW_n/2ojJn
j`;oY[o/1_nU_n`2ojG1k@CoY/;]0_nV`nh2ojS3k@CoZLC]0_n[a>`3oj[2j`;oZ/7Z00?oZ;kYojNl
j?nW_>P00_nW_>P3ojBij0;oXKKW0_nP]nT4oijgj@;oW[S[0_nQ_N`4ojK1k0;o[/G[0on`an/2okO9
j0;o]/SX0onja^@00ongaNGo^<7QokS1h@02okS1h@03okVmgOnf_Moo][gO00;o][gO0_nf^]`2okBk
g`Co][WL00Co^;SIokNifong^M_o]kWK0_nh^=T2okNif`?o]kKH00?o];OJok>cf?nc/mP00onc/mP2
ok2_e`03ojj_fOn[[=SoZjcH00;oZjcH1?nWZMP2oj>Xf@03ojFYf_nSZM_oXjWK00;oXjWK1?nQZmh2
oj6^h@03ojB`h?nT/n?oY;?S00?oY;?S0_nU]nI7ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02_ooool004oooooo0_l0000^ooooo`?oYl3[0_nW_n/6ojJok0;oYKo/0_nU`>d4ojG1
k@;oY/;]0_nW`^d4ojS3k@;oZLC]0onY`n`2oj[2j`03ojVoj_nX_^WoZ;kY00;oZ;kY0_nW_>P2ojBj
j@?oX[SX1?nP]nT2oijgj@;oX;[/1?nQ_N`2ojK1k0;oZLC]0on`an/00on`b>_o]/SXokK8j003okK8
j004ok[6i?ngaNGo]lGUokO5i@;o^<7Q0_ne`N<3okJmg`;o/kgR1?nd^ml2okJig004okBkg_ng^M_o
]kWKokNif`;o]K_N1?ng^M/01?ng]]So];OJokBgf_nd]mX3ok>cf003ok6cf_n^[mWo[ZoI00;o[ZoI
1?n[[=P2ojNYf003ojNZfOnUZM[oYJWJ00;oYJWJ1?nSZM/2oj6[gP03ojB]gOnT/>3oY;3P00;oY;3P
0_nT/n=<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool0057ooooo00?o
0000ooooooooool0;?ooool00onW`>_oY[o/ojJok006ojJok0;oY/3/1?nU`>d2ojG1k@?oY/;]0onW
`^d2ojS3k@GoZL?/00?oZL7[ojVoj_nY_nX00_nY_nX2ojRnj@;oY[cY1?nT^^T3oj:hj0;oX;OY0_nO
^N/4oj2jk0;oXKg/0_nT`Nh4ojW4k@04ok37jon`b>_o/<S[ok38j`;o]/SX0oncanP2okO5i@;o/l?V
1?ne`N<00onf_Moo/kgRok>mhP02ok>mhP;o];_O00?o/[cQokBkg_nd^mh00_nd^mh00ong^M_o]K_N
okFkgP02okFkgP;o]kWK0_nd^Md4okBgfP04ok>cf?na/m[o/K?Jok6cfPCo[ZoI0_n[[=P00onZ[=Wo
Yj[IojNZf@02ojNZf@;oYJWJ00?oYZ_JojF[fonUZm/00_nUZm/4ojB]g@;oY;3PCoooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00[ooooo001Booooo`03o`000?oooooooooo02_ooooo
2OnV_n`3ojK0k0;oYL3]0onV`Nd2ojK2k@;oYl;]1?nX`^d2ojW3k003ojS1jonY`N_oZL7[00;oZL7[
0_nY_nX2ojNnjPCoY[cY0_nT^^T2oj>kjPCoXK[Z0onO^N/2oj2jk0;oXKk]1?nT`Nh2ojW4k@;oZlK]
0_n`b>/2ojo7k0?o/lOX0_naaNT4ok?3iP;o]L7S0ona`>D2ok>mhP03ok2ni?nb_>7o/[cQ00;o/[cQ
0_nd^mh2ok>lh@?o]K_N0_nc_>04okBig@;o];OJ00?o/[OLok6cf_na/mX00_na/mX2ojj_f@;o[:oJ
1?nZ[=T2ojNZf@03ojN[f_nVZm[oYZ_J00;oYZ_J1?nUZm/2ojB]gE?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0:ooooo`00Doooool00ol0003oooooooooo`0[ooooo`OoY[o/1_nV
`>`2ojK1k@;oYl7/1?nW`^d2ojS2k@03ojS1k?nX`N_oZ<7[00;oZ<7[0_nY`N/2ojRojPCoYkkZ0_nV
_>T2ojBljPCoXk_Z0_nQ^^X2oj6kk0CoX;c/0onQ_^d2ojC1kP;oY/?^0_n[a^d2oj_6kPCo[lO/00?o
/lOXok75jOnaaNT00_naaNT2ok?3iP03ok32iona`>Go/L3U00;o/L3U00?o[l3Vok2ni?n`_^@00_n`
_^@2ok:lh@;o/;gT1?nc_>400one^mko/kcPok>lh002ok>lh0;o];WM00?o/[[Ook:gg?nb]m`00_nb
]m`2ok6cfP;o[[?L1?n/[mX2ojZ/f@03ojV]f_nWZm[oYj_J00;oYj_J1?nVZmX2ojF[feOooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`00E?ooool2o`0002gooooo1?nV_n`6
ojK0k0KoYl7/0_nW`^d5ojS1k0;oZ<7[0onX`>/3ojRojP;oYkkZ0_nV_NX4ojBljP;oXk_Z0_nR^n/4
oj6kk0;oX;c/00?oX[o^oj?1k_nS`Nh00_nS`Nh2ojK3kP;oYlG_1?n[a^h2ojo7k0?o[/K/0_naaNT0
0on^a>[o/<;Wok32i`02ok32i`03ok70iOn_`>Ko[l3V00;o[l3V0_n`_^@2ojjoiPCo/;gT0_nc_>43
ok6mh`;o/kcP00?o/;cRok:jgonb^]l00_nb^]l2ok:gg0;o[kKN1?n^/m`2ojb_fP;oZZoL0onY[MX4
ojN[fP;oYZ_JF_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo001Foooo
o`03o`000?oooooooooo02_ooooo1?nV_n`4ojK0k0WoYl7/1?nX`N`5ojS0j`;oYkoZ1?nV_^X3ojJm
jP;oY;cZ0onT_>/3oj:kj`;oXK_/00?oX[k]oj:ok_nR_nh00_nR_nh2oj?1kP;oYL?_1?nWaNl2oj_6
kP?oZlK]0_n^a^`00on/aNco[/CZojk4jP02ojk4jP;o/<;W0on]`^T2ojo0iP;o[<3X1?n^_nH2ok2m
i003ojjni_na_N?o/KgS00;o/KgS00?o[kkUok2lh_n`_>800_n`_>82ok:jg`;o[k[Q1?n_]]h2ojjc
g003oj^bg_nZ[mcoZZoL00?oZZoL0onY[MX2ojN[fUkooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`09ooooo`00Eoooool00ol0003oooooooooo`0[ooooo`;oY[o/1_nV`>`7ojO1k0Oo
Z<3[0_nW_n/4ojNojP;oY[kZ0_nV_NX4ojFmjP;oY;c[00?oXkg/oj:mk?nR_N`00_nR_N`3oj:nk@;o
X[o^0onS`Nh3ojG3k`;oYlG_0onXaNh2oj_6k@03oj[5kOn/aNco[<G/00;o[<G/0_n^a>X3ojc3j`;o
[L;Y0_n[`NX4ojc0j0;o[[oV00?o[;oXojjni_n^_^H00_n^_^H00ona_N?o[kkUojnni@02ojnni@;o
/;cR0_n^_>@4ojnjh@;o[kKN00?oZkKQoj^bg_n[/]h00_n[/]h2ojZ_g6Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`09ooooo`00F?ooool00ol0003oooooooooo`0/ooooo`GoY/3/
0onW`>`2ojO1k003ojO0jonX`>_oZ<3[00CoZ<3[0_nX_n/4ojNoj`;oYkoZ0_nV_^X4ojJmjP;oYKgZ
00?oY;g[oj>mk?nS_N`00_nS_N`2oj:mk0;oXko]1?nS_nh2oj?1kP;oYL;^1?nVa>l3ojS5kPCoZ/G]
0_n/aN`3oj_4k0;o[<?[0_nZ`^/4oj_1jP;o[<3X00?oZl3Yojboj?n/_nP00_n/_nP2ojjniP?o[KoW
0_n__^D2ojbni`Co[[cT0_n_^^400on[^N?oZkKQoj^fh@02oj^fh@;oZk;NJ_ooool01Ol0003ooooo
oooooooooooo000000_ooooo001Iooooo`03o`000?oooooooooo02cooooo1?nW`>/2ojO0k0GoYl3[
1?nX`>/4ojRoj`CoYko[1?nV_^X2ojJmjP03ojFnjonT_N_oY;g[00;oY;g[0_nS_N`2ojBnk0CoXko]
0_nS_nh2ojC1kPCoYL;^0_nVa>l2ojO4kP?oZ<G^0_nZaNd3ojW4k@;oZlC/0_nY`n`4oj[2j`;oZl7Z
0_nY`NX3oj_0j@;o[;oX0on[`>T2ojfoi`;oZkoX1?n/_^L2ojjli003oj^li_n[^N?oZkWS00;oZkWS
0_n[]^5]ooooo`05o`000?ooooooooooooooool000002oooool005[ooooo0_l0000]ooooo`WoYl3[
1_nX`>/2ojRoj`KoYko[0_nV_^X2ojJnj`?oYKk[0_nT_N/6ojBnk0;oXko]0onT`>d3ojC1kP;oYL;^
0_nV`nh4ojO4kPCoZ<C^0_nYa>d2ojW3k@CoZL?/0_nZ`^/2ojW1j`;oZL7Z0_nX`N/4ojW0jP;oZl3Y
0_nY`>X4oj^oj0;o[;kW00?oZ[kXoj^li_n[_>H00_n[_>H2oj^ihg7ooooo00Co0000oooooooooooo
00002oooool005cooooo00?o0000ooooooooool0:oooool5ojO0j`SoZ<3[1onW_n/7ojJnj`CoYKk[
1OnT_^`3ojBok@;oY<3]00?oYL7]ojG2k_nU`^h00_nU`^h2ojK3kP;oYl?^1?nWa>h2ojS4kP;oZ<?]
1?nY`nd2ojW3k0;oZ<;/0_nY`N/6ojS1j`;oZL3Z0_nX`>/4ojW0jP;oZkoX00?oZKoYojZnj?nZ_^P0
0_nZ_^P2oj^liWGooooo00?o0000ooooool000002oooool005gooooo00?o0000ooooooooool0:ooo
ool4ojO0j`CoZ<3[3?nW_n/7ojJnj`;oYKk[1_nU_n`2ojBok@03ojG0kOnU`NgoYL7]00;oYL7]0_nU
`^h2ojK2kPCoYl?^0_nWa>h6ojS3k@;oZL?]1?nX`^`2ojS1k0KoZ<7[1_nX`>/2ojW0jP03ojS0j_nY
_nWoZKoY00;oZKoY0_nZ_^Qhooooo`04o`000?ooooooooooo`0000[ooooo001Nooooo`03o`000?oo
oooooooo02_ooooo1?nW`>/4ojS0j`_oYko[1_nV_^/2ojJoj`KoYKo/00?oYL3/ojG0kOnU`>d00_nU
`>d2ojG1k@?oY/;]0onV`^h2ojO3kP?oYl?]0_nX`nd5ojS2k@;oZ<;/1_nX`N`3ojS1j`WoZ<3[0onX
`>X2ojVojGcooooo00?o0000ooooool000002_ooool005oooooo0_l0000/ooooo`CoYl3[0_nX`>/2
ojO0j`_oYko[0_nV_^/6ojJoj`GoYKo/0_nU`>`2ojG0k@?oY/7]1?nV`^d4ojO2k@;oYl?]00?oYl;]
ojS2kOnX`^d01?nX`^d2ojS2k0SoZ<7/0onX`N/7ojS0jh?ooooo0_l0000:ooooo`00HOooool00ol0
003oooooooooo`0Zooooo`SoYl3[2OnW_n/5ojJoj`KoY[o/0_nU_n`00onV`>coY/3]ojK0k@02ojK0
k@CoY/7]1?nV`^d7ojO2k@;oZ<;]1_nX`^`6ojS1k0;oYl7/1?nW`>/2ojS0jhGooooo0ol0000:oooo
o`00H_ooool00ol0003oooooooooo`0[ooooo`CoYl3[2onW_n/4ojJoj`KoY[o/1OnV`>`2ojK0k@Ko
Y/7]0_nV`^d7ojO2k@GoZ<;/1onX`N`6ojO1k0;oYl3[Q?ooool4o`0000gooooo001Sooooo`03o`00
0?oooooooooo02_ooooo1?nW`>/9ojNoj`KoY[o[0_nV_n`7ojK0k0?oY/7/1OnV`Nd2ojO1k@;oYl;]
1_nW`^`2ojS2k0SoZ<7/1onW`Nb3ooooo`Co00004Oooool006Cooooo0_l0000/ooooo`?oYl3[2OnW
_n/5ojJoj`;oY[o/2?nV`>`4ojK1k0CoYl7/00?oYl7]ojO2k?nW`^`02?nW`^`6ojS1k0OoYl7/Pooo
ool3o`0001Gooooo001Vooooo`03o`000?oooooooooo02_ooooo0_nW`>/7ojNoj`OoY[o/2?nV`>`6
ojK1k0?oYl7/3?nW`^`2ojS1k0CoYl7/QOooool4o`0001Sooooo001Wooooo`03o`000?oooooooooo
02[ooooo1?nW`>/4ojNoj`KoY[o/2OnV`>`6ojK1k0GoYl7/0_nW`^`3ojO1k0;oYl;/1onW`Nb4oooo
o`Co00007?ooool006Sooooo00?o0000ooooooooool0:_ooool2ojO0j`;oYl3/1?nW_n/2ojJok0go
Y/3/0_nV`N`CojO1k8?ooooo1?l0000Pooooo`00JOooool2o`0002cooooo0onW`>`2ojNoj`?oYl3/
2OnV`>`2ojO0k1CoYl7/P_ooool4o`0002Cooooo001[ooooo`03o`000?oooooooooo02[ooooo2onW
`>`2ojK0k0KoYl3/4?nW`Nb2ooooo`?o0000:?ooool006cooooo00?o0000ooooooooool0:_ooool2
ojO0k003ojO0jonW`>coYl3/00coYl3/3?nW`Nb3ooooo`Co0000:oooool006gooooo00?o0000oooo
ooooool0:oooool2ojO0j`coYl3/2_nW`Nb2ooooo`Co0000;oooool006kooooo00?o0000oooooooo
ool0:_ooool4ojO0j`WoYl3/2?nW`Nb1ooooo`Co0000<oooool006oooooo0_l0000[ooooo`CoYl3[
2?nW`>`5ojO1k83ooooo1?l0000gooooo`00LOooool00ol0003oooooooooo`0Zooooo`?oYl3[0_nW
`>`2ojO0j`;oYl3/P_ooool4o`0003_ooooo001booooo`03o`000?oooooooooo02[ooooo1OnW`>^2
ooooo`?o0000?oooool007?ooooo00?o0000ooooooooool0:_ooool00onW`>_oooooooooo`1ooooo
o`Co0000@_ooool007Cooooo0_l0000Zooooo`03o`000?oooooooooo07_ooooo1?l00016ooooo`00
M_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07Sooooo1?l0001:ooooo`00Mooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07Cooooo1?l0001>ooooo`00N?ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo077ooooo0ol0001Booooo`00NOooool2o`00
02Cooooo00?o0000ooooooooool0KOooool4o`0005Gooooo001kooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0JOooool4o`0005Wooooo001looooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool0IOooool4o`0005gooooo001mooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool0HOooool4o`00067ooooo001nooooo`;o00007oooool00ol0003oooooooooo`1M
ooooo`Co0000IOooool0083ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Joooo
o`?o0000JOooool0087ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Fooooo`Co
0000K?ooool008;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Booooo`Co0000
L?ooool008?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1>ooooo`Co0000M?oo
ool008Cooooo0_l0000Iooooo`03o`000?oooooooooo04[ooooo1?l0001hooooo`00Q_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo04Kooooo1?l0001looooo`00Qoooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo04?ooooo0ol00020ooooo`00R?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo03oooooo1?l00023ooooo`00ROooool2o`0001Cooooo00?o
0000ooooooooool0>oooool4o`0008Oooooo002;ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0=oooool4o`0008_ooooo002<ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0<oooool4o`0008oooooo002=ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0<?ooool3o`0009?ooooo002>ooooo`;o00003oooool00ol0003oooooooooo`0/ooooo`Co0000
U_ooool0093ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Xooooo`Co0000V_oo
ool0097ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Tooooo`Co0000W_ooool0
09;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`Co0000X_ooool009?o
oooo0_l00009ooooo`03o`000?oooooooooo01gooooo1?l0002Vooooo`00UOooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01[ooooo0ol0002Zooooo`00U_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Kooooo1?l0002]ooooo`00Uoooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01;ooooo1?l0002aooooo`00V?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00kooooo1?l0002eooooo`00VOooool2o`0000?ooooo00?o0000oooooooo
ool02_ooool4o`000;Wooooo002Kooooo`04o`000?ooooooooooo`0000Wooooo0ol0002mooooo`00
W?ooool00ol0003oooooo`000005ooooo`Co0000`?ooool009gooooo0_l000000ooooooo0000o`00
0002o`000<Cooooo002Nooooo`;o0000b?ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:[ooooo
00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`Go00000oooool5o`0000Gooooo0_lQ8B46ooooo`;o
000000?o410@ooooooooool0TOooool00:[ooooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`Ko
000000KooooooiRHV?lQ8B7ok^k^oooooom4A4@3ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool0T_ooool00:[ooooo00?o0000ooooooooool03?ooool0
0onHV9So8B4Qonk^kP05ooooo`03oiRHV?lQ8B7ok^k^00cooooo1Ol0002Cooooo`00Z_ooool00ol0
003oooooooooo`04ooooo`Ko00000oooool00onHV9So8B4Qonk^kP05ooooo`03oiRHV?lQ8B7ok^k^
00_ooooo00CoA4A4omgMgOoooooo0000U?ooool00:[ooooo00?o0000ooooooooool03_ooool00omg
MgOoIVIVooooo`05ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoeEEEOoooooo0000U?ooool0
0:Sooooo00?o410@o`000?l000000ol0000>ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02_ooool00omgMgOoc<c<o`00002Dooooo`00Z_ooool00ol0003oooooooooo`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41000oooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?ok^k^
odA4A?l00000U?ooool00:[ooooo00?o0000ooooooooool02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00=ooooo`03ogMgMol0003ooooo09?ooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -20 0 ]
[.5 .82364 20 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.2) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.655 .751 .921 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .6947 Mtetra
.654 .752 .922 r
.4053 .6947 .41061 .69934 .41957 .69681 .41427 .69218 Mtetra
.654 .753 .922 r
.41427 .69218 .41957 .69681 .42855 .69428 .42327 .68967 Mtetra
.654 .754 .923 r
.42327 .68967 .42855 .69428 .43756 .69174 .4323 .68714 Mtetra
.653 .756 .925 r
.4323 .68714 .43756 .69174 .4466 .68919 .44136 .68462 Mtetra
.653 .757 .926 r
.44136 .68462 .4466 .68919 .45567 .68663 .45045 .68209 Mtetra
.653 .759 .928 r
.45045 .68209 .45567 .68663 .46478 .68407 .45957 .67956 Mtetra
.652 .761 .929 r
.45957 .67956 .46478 .68407 .47391 .68149 .46873 .67702 Mtetra
.652 .763 .931 r
.46873 .67702 .47391 .68149 .48307 .67891 .47791 .67447 Mtetra
.652 .765 .932 r
.47791 .67447 .48307 .67891 .49227 .67632 .48713 .6719 Mtetra
.653 .767 .933 r
.48713 .6719 .49227 .67632 .50149 .67371 .49637 .66931 Mtetra
.654 .769 .933 r
.49637 .66931 .50149 .67371 .51075 .6711 .50565 .66668 Mtetra
.656 .769 .932 r
.50565 .66668 .51075 .6711 .52004 .66849 .51496 .66399 Mtetra
.659 .767 .93 r
.51496 .66399 .52004 .66849 .52936 .66586 .5243 .66123 Mtetra
.663 .764 .925 r
.5243 .66123 .52936 .66586 .53871 .66322 .53367 .6584 Mtetra
.667 .757 .918 r
.53367 .6584 .53871 .66322 .54809 .66058 .54308 .65547 Mtetra
.67 .748 .908 r
.54308 .65547 .54809 .66058 .55751 .65792 .55251 .65245 Mtetra
.673 .735 .897 r
.55251 .65245 .55751 .65792 .56695 .65526 .56197 .64935 Mtetra
.674 .721 .884 r
.56197 .64935 .56695 .65526 .57643 .65259 .57146 .64617 Mtetra
.674 .705 .871 r
.57146 .64617 .57643 .65259 .58595 .6499 .58099 .64298 Mtetra
.671 .69 .859 r
.58099 .64298 .58595 .6499 .59549 .64721 .59054 .63979 Mtetra
.667 .675 .848 r
.59054 .63979 .59549 .64721 .60507 .64451 .60012 .63666 Mtetra
.663 .663 .84 r
.60012 .63666 .60507 .64451 .61468 .6418 .60974 .63362 Mtetra
.658 .654 .834 r
.60974 .63362 .61468 .6418 .62432 .63908 .61939 .63071 Mtetra
.654 .648 .832 r
.61939 .63071 .62432 .63908 .634 .63636 .62908 .62792 Mtetra
.651 .646 .832 r
.62908 .62792 .634 .63636 .64371 .63362 .63881 .62522 Mtetra
.649 .647 .834 r
.63881 .62522 .64371 .63362 .65345 .63087 .64857 .62258 Mtetra
.65 .65 .836 r
.64857 .62258 .65345 .63087 .66323 .62811 .65837 .61992 Mtetra
.651 .653 .839 r
.65837 .61992 .66323 .62811 .67304 .62535 .66819 .61721 Mtetra
.654 .656 .84 r
.66819 .61721 .67304 .62535 .68289 .62257 .67806 .61442 Mtetra
.656 .657 .839 r
.67806 .61442 .68289 .62257 .69277 .61979 .68795 .61153 Mtetra
.657 .655 .837 r
.68795 .61153 .69277 .61979 .70269 .61699 .69787 .60859 Mtetra
.657 .652 .834 r
.69787 .60859 .70269 .61699 .71264 .61418 .70783 .60564 Mtetra
.654 .649 .832 r
.70783 .60564 .71264 .61418 .72262 .61137 .71783 .60274 Mtetra
.652 .646 .832 r
.71783 .60274 .72262 .61137 .73264 .60854 .72786 .59994 Mtetra
.648 .645 .834 r
.72786 .59994 .73264 .60854 .7427 .60571 .73794 .59726 Mtetra
.645 .648 .839 r
.73794 .59726 .7427 .60571 .75279 .60286 .74807 .5947 Mtetra
.642 .654 .846 r
.74807 .5947 .75279 .60286 .76291 .60001 .75824 .59224 Mtetra
.641 .664 .857 r
.75824 .59224 .76291 .60001 .77308 .59714 .76846 .58984 Mtetra
.64 .677 .869 r
.76846 .58984 .77308 .59714 .78328 .59427 .77871 .58745 Mtetra
.641 .693 .883 r
.77871 .58745 .78328 .59427 .79351 .59138 .789 .58504 Mtetra
.642 .709 .896 r
.789 .58504 .79351 .59138 .80378 .58849 .79933 .58255 Mtetra
.644 .725 .908 r
.79933 .58255 .80378 .58849 .81409 .58558 .8097 .57999 Mtetra
.646 .74 .917 r
.8097 .57999 .81409 .58558 .82443 .58267 .82009 .57732 Mtetra
.648 .751 .925 r
.82009 .57732 .82443 .58267 .83482 .57974 .83052 .57457 Mtetra
.65 .76 .93 r
.83052 .57457 .83482 .57974 .84523 .5768 .84097 .57172 Mtetra
.652 .765 .932 r
.84097 .57172 .84523 .5768 .85569 .57385 .85146 .56881 Mtetra
.653 .768 .933 r
.85146 .56881 .85569 .57385 .86618 .57089 .86199 .56584 Mtetra
.655 .769 .933 r
.86199 .56584 .86618 .57089 .87672 .56792 .87254 .56283 Mtetra
.655 .768 .932 r
.87254 .56283 .87672 .56792 .88729 .56494 .88314 .55978 Mtetra
.656 .767 .931 r
.88314 .55978 .88729 .56494 .89789 .56195 .89377 .55672 Mtetra
.656 .765 .929 r
.89377 .55672 .89789 .56195 .90854 .55895 .90444 .55365 Mtetra
.657 .762 .928 r
.90444 .55365 .90854 .55895 .91923 .55594 .91515 .55056 Mtetra
.657 .76 .926 r
.91515 .55056 .91923 .55594 .92995 .55292 .9259 .54747 Mtetra
.657 .758 .925 r
.9259 .54747 .92995 .55292 .94071 .54988 .93668 .54437 Mtetra
.657 .757 .924 r
.93668 .54437 .94071 .54988 .95152 .54684 .94751 .54127 Mtetra
.657 .755 .923 r
.94751 .54127 .95152 .54684 .96236 .54378 .95838 .53816 Mtetra
.657 .754 .922 r
.95838 .53816 .96236 .54378 .97324 .54071 .96929 .53504 Mtetra
.657 .753 .921 r
.96929 .53504 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.654 .751 .921 r
.391 .69252 .39636 .6972 .4053 .6947 .39996 .69002 Mtetra
.653 .752 .922 r
.39996 .69002 .4053 .6947 .41427 .69218 .40895 .68752 Mtetra
.653 .752 .923 r
.40895 .68752 .41427 .69218 .42327 .68967 .41797 .68501 Mtetra
.653 .753 .924 r
.41797 .68501 .42327 .68967 .4323 .68714 .42701 .6825 Mtetra
.652 .754 .925 r
.42701 .6825 .4323 .68714 .44136 .68462 .43609 .67999 Mtetra
.651 .756 .926 r
.43609 .67999 .44136 .68462 .45045 .68209 .4452 .67749 Mtetra
.651 .757 .928 r
.4452 .67749 .45045 .68209 .45957 .67956 .45434 .67499 Mtetra
.65 .759 .929 r
.45434 .67499 .45957 .67956 .46873 .67702 .46351 .67248 Mtetra
.65 .761 .931 r
.46351 .67248 .46873 .67702 .47791 .67447 .47272 .66997 Mtetra
.65 .763 .932 r
.47272 .66997 .47791 .67447 .48713 .6719 .48195 .66743 Mtetra
.651 .765 .933 r
.48195 .66743 .48713 .6719 .49637 .66931 .49122 .66485 Mtetra
.654 .767 .933 r
.49122 .66485 .49637 .66931 .50565 .66668 .50052 .6622 Mtetra
.658 .769 .931 r
.50052 .6622 .50565 .66668 .51496 .66399 .50985 .65946 Mtetra
.663 .768 .928 r
.50985 .65946 .51496 .66399 .5243 .66123 .51921 .65659 Mtetra
.67 .766 .922 r
.51921 .65659 .5243 .66123 .53367 .6584 .52861 .65357 Mtetra
.677 .761 .914 r
.52861 .65357 .53367 .6584 .54308 .65547 .53803 .65037 Mtetra
.683 .753 .904 r
.53803 .65037 .54308 .65547 .55251 .65245 .54748 .64699 Mtetra
.688 .741 .892 r
.54748 .64699 .55251 .65245 .56197 .64935 .55696 .64345 Mtetra
.69 .727 .878 r
.55696 .64345 .56197 .64935 .57146 .64617 .56647 .63977 Mtetra
.689 .712 .865 r
.56647 .63977 .57146 .64617 .58099 .64298 .576 .63605 Mtetra
.686 .696 .853 r
.576 .63605 .58099 .64298 .59054 .63979 .58556 .63234 Mtetra
.679 .68 .844 r
.58556 .63234 .59054 .63979 .60012 .63666 .59515 .62877 Mtetra
.671 .667 .837 r
.59515 .62877 .60012 .63666 .60974 .63362 .60478 .62541 Mtetra
.663 .656 .833 r
.60478 .62541 .60974 .63362 .61939 .63071 .61444 .6223 Mtetra
.655 .648 .832 r
.61444 .6223 .61939 .63071 .62908 .62792 .62414 .61946 Mtetra
.649 .645 .833 r
.62414 .61946 .62908 .62792 .63881 .62522 .63388 .61681 Mtetra
.646 .646 .836 r
.63388 .61681 .63881 .62522 .64857 .62258 .64366 .61429 Mtetra
.646 .649 .839 r
.64366 .61429 .64857 .62258 .65837 .61992 .65348 .61175 Mtetra
.649 .654 .841 r
.65348 .61175 .65837 .61992 .66819 .61721 .66333 .60911 Mtetra
.654 .658 .841 r
.66333 .60911 .66819 .61721 .67806 .61442 .6732 .60629 Mtetra
.659 .66 .84 r
.6732 .60629 .67806 .61442 .68795 .61153 .68311 .6033 Mtetra
.661 .659 .837 r
.68311 .6033 .68795 .61153 .69787 .60859 .69304 .6002 Mtetra
.661 .655 .834 r
.69304 .6002 .69787 .60859 .70783 .60564 .703 .59709 Mtetra
.657 .65 .832 r
.703 .59709 .70783 .60564 .71783 .60274 .71301 .59409 Mtetra
.651 .646 .832 r
.71301 .59409 .71783 .60274 .72786 .59994 .72306 .5913 Mtetra
.643 .643 .835 r
.72306 .5913 .72786 .59994 .73794 .59726 .73317 .58877 Mtetra
.636 .644 .841 r
.73317 .58877 .73794 .59726 .74807 .5947 .74333 .5865 Mtetra
.63 .649 .85 r
.74333 .5865 .74807 .5947 .75824 .59224 .75354 .58445 Mtetra
.625 .658 .862 r
.75354 .58445 .75824 .59224 .76846 .58984 .76381 .58253 Mtetra
.623 .671 .875 r
.76381 .58253 .76846 .58984 .77871 .58745 .77412 .58064 Mtetra
.623 .687 .889 r
.77412 .58064 .77871 .58745 .789 .58504 .78448 .5787 Mtetra
.626 .704 .902 r
.78448 .5787 .789 .58504 .79933 .58255 .79486 .57663 Mtetra
.63 .721 .913 r
.79486 .57663 .79933 .58255 .8097 .57999 .80528 .57439 Mtetra
.635 .737 .922 r
.80528 .57439 .8097 .57999 .82009 .57732 .81572 .57197 Mtetra
.641 .749 .928 r
.81572 .57197 .82009 .57732 .83052 .57457 .82619 .56937 Mtetra
.646 .759 .931 r
.82619 .56937 .83052 .57457 .84097 .57172 .83668 .56661 Mtetra
.65 .764 .933 r
.83668 .56661 .84097 .57172 .85146 .56881 .8472 .56371 Mtetra
.653 .767 .933 r
.8472 .56371 .85146 .56881 .86199 .56584 .85776 .56072 Mtetra
.656 .768 .932 r
.85776 .56072 .86199 .56584 .87254 .56283 .86834 .55766 Mtetra
.657 .767 .931 r
.86834 .55766 .87254 .56283 .88314 .55978 .87896 .55455 Mtetra
.658 .766 .929 r
.87896 .55455 .88314 .55978 .89377 .55672 .88961 .55142 Mtetra
.659 .764 .927 r
.88961 .55142 .89377 .55672 .90444 .55365 .90031 .54827 Mtetra
.659 .762 .926 r
.90031 .54827 .90444 .55365 .91515 .55056 .91104 .54511 Mtetra
.658 .76 .925 r
.91104 .54511 .91515 .55056 .9259 .54747 .92181 .54196 Mtetra
.658 .758 .924 r
.92181 .54196 .9259 .54747 .93668 .54437 .93263 .53881 Mtetra
.658 .756 .923 r
.93263 .53881 .93668 .54437 .94751 .54127 .94348 .53565 Mtetra
.658 .755 .922 r
.94348 .53565 .94751 .54127 .95838 .53816 .95437 .53249 Mtetra
.658 .754 .921 r
.95437 .53249 .95838 .53816 .96929 .53504 .96531 .52933 Mtetra
.657 .753 .92 r
.96531 .52933 .96929 .53504 .98024 .53192 .97628 .52616 Mtetra
.653 .751 .921 r
.38561 .68781 .391 .69252 .39996 .69002 .39458 .68531 Mtetra
.653 .751 .922 r
.39458 .68531 .39996 .69002 .40895 .68752 .40359 .68281 Mtetra
.652 .752 .923 r
.40359 .68281 .40895 .68752 .41797 .68501 .41263 .6803 Mtetra
.41263 .6803 .41797 .68501 .42701 .6825 .42169 .6778 Mtetra
.651 .753 .924 r
.42169 .6778 .42701 .6825 .43609 .67999 .43079 .67531 Mtetra
.65 .754 .926 r
.43079 .67531 .43609 .67999 .4452 .67749 .43992 .67282 Mtetra
.649 .755 .927 r
.43992 .67282 .4452 .67749 .45434 .67499 .44908 .67034 Mtetra
.648 .757 .928 r
.44908 .67034 .45434 .67499 .46351 .67248 .45827 .66787 Mtetra
.648 .758 .93 r
.45827 .66787 .46351 .67248 .47272 .66997 .46749 .66538 Mtetra
.649 .761 .931 r
.46749 .66538 .47272 .66997 .48195 .66743 .47675 .66287 Mtetra
.65 .763 .932 r
.47675 .66287 .48195 .66743 .49122 .66485 .48603 .66031 Mtetra
.654 .765 .931 r
.48603 .66031 .49122 .66485 .50052 .6622 .49536 .65766 Mtetra
.659 .767 .929 r
.49536 .65766 .50052 .6622 .50985 .65946 .50471 .65488 Mtetra
.667 .768 .926 r
.50471 .65488 .50985 .65946 .51921 .65659 .51409 .65192 Mtetra
.676 .767 .92 r
.51409 .65192 .51921 .65659 .52861 .65357 .52351 .64873 Mtetra
.686 .764 .911 r
.52351 .64873 .52861 .65357 .53803 .65037 .53296 .64529 Mtetra
.695 .757 .9 r
.53296 .64529 .53803 .65037 .54748 .64699 .54243 .64157 Mtetra
.701 .747 .887 r
.54243 .64157 .54748 .64699 .55696 .64345 .55193 .6376 Mtetra
.705 .734 .874 r
.55193 .6376 .55696 .64345 .56647 .63977 .56145 .63342 Mtetra
.704 .719 .861 r
.56145 .63342 .56647 .63977 .576 .63605 .57099 .62917 Mtetra
.7 .703 .849 r
.57099 .62917 .576 .63605 .58556 .63234 .58056 .62494 Mtetra
.691 .686 .841 r
.58056 .62494 .58556 .63234 .59515 .62877 .59016 .62091 Mtetra
.68 .671 .835 r
.59016 .62091 .59515 .62877 .60478 .62541 .5998 .61721 Mtetra
.668 .659 .832 r
.5998 .61721 .60478 .62541 .61444 .6223 .60947 .61392 Mtetra
.655 .65 .833 r
.60947 .61392 .61444 .6223 .62414 .61946 .61918 .61105 Mtetra
.646 .646 .836 r
.61918 .61105 .62414 .61946 .63388 .61681 .62894 .6085 Mtetra
.64 .646 .84 r
.62894 .6085 .63388 .61681 .64366 .61429 .63874 .60615 Mtetra
.641 .651 .844 r
.63874 .60615 .64366 .61429 .65348 .61175 .64858 .60377 Mtetra
.646 .658 .847 r
.64858 .60377 .65348 .61175 .66333 .60911 .65844 .60122 Mtetra
.655 .664 .847 r
.65844 .60122 .66333 .60911 .6732 .60629 .66834 .59838 Mtetra
.663 .667 .844 r
.66834 .59838 .6732 .60629 .68311 .6033 .67825 .59525 Mtetra
.667 .666 .84 r
.67825 .59525 .68311 .6033 .69304 .6002 .68819 .59195 Mtetra
.666 .662 .836 r
.68819 .59195 .69304 .6002 .703 .59709 .69816 .58862 Mtetra
.66 .655 .834 r
.69816 .58862 .703 .59709 .71301 .59409 .70817 .58549 Mtetra
.651 .648 .834 r
.70817 .58549 .71301 .59409 .72306 .5913 .71824 .58268 Mtetra
.639 .643 .838 r
.71824 .58268 .72306 .5913 .73317 .58877 .72837 .5803 Mtetra
.626 .641 .845 r
.72837 .5803 .73317 .58877 .74333 .5865 .73857 .57833 Mtetra
.616 .644 .855 r
.73857 .57833 .74333 .5865 .75354 .58445 .74883 .5767 Mtetra
.608 .652 .868 r
.74883 .5767 .75354 .58445 .76381 .58253 .75915 .57527 Mtetra
.604 .665 .882 r
.75915 .57527 .76381 .58253 .77412 .58064 .76952 .57388 Mtetra
.604 .681 .896 r
.76952 .57388 .77412 .58064 .78448 .5787 .77993 .57241 Mtetra
.609 .7 .909 r
.77993 .57241 .78448 .5787 .79486 .57663 .79037 .57074 Mtetra
.616 .718 .919 r
.79037 .57074 .79486 .57663 .80528 .57439 .80083 .56881 Mtetra
.625 .735 .926 r
.80083 .56881 .80528 .57439 .81572 .57197 .81132 .5666 Mtetra
.634 .748 .93 r
.81132 .5666 .81572 .57197 .82619 .56937 .82183 .56413 Mtetra
.642 .757 .932 r
.82183 .56413 .82619 .56937 .83668 .56661 .83236 .56143 Mtetra
.649 .763 .932 r
.83236 .56143 .83668 .56661 .8472 .56371 .84291 .55854 Mtetra
.654 .766 .931 r
.84291 .55854 .8472 .56371 .85776 .56072 .85349 .55552 Mtetra
.658 .767 .93 r
.85349 .55552 .85776 .56072 .86834 .55766 .8641 .5524 Mtetra
.66 .766 .928 r
.8641 .5524 .86834 .55766 .87896 .55455 .87474 .54922 Mtetra
.661 .764 .927 r
.87474 .54922 .87896 .55455 .88961 .55142 .88542 .54602 Mtetra
.661 .762 .925 r
.88542 .54602 .88961 .55142 .90031 .54827 .89614 .5428 Mtetra
.661 .761 .924 r
.89614 .5428 .90031 .54827 .91104 .54511 .9069 .53959 Mtetra
.66 .759 .923 r
.9069 .53959 .91104 .54511 .92181 .54196 .9177 .53638 Mtetra
.659 .757 .922 r
.9177 .53638 .92181 .54196 .93263 .53881 .92853 .53317 Mtetra
.659 .756 .922 r
.92853 .53317 .93263 .53881 .94348 .53565 .93941 .52997 Mtetra
.659 .755 .921 r
.93941 .52997 .94348 .53565 .95437 .53249 .95034 .52678 Mtetra
.658 .754 .92 r
.95034 .52678 .95437 .53249 .96531 .52933 .9613 .52358 Mtetra
.658 .753 .92 r
.9613 .52358 .96531 .52933 .97628 .52616 .9723 .52037 Mtetra
.653 .751 .922 r
.38018 .68308 .38561 .68781 .39458 .68531 .38917 .68057 Mtetra
.652 .751 .922 r
.38917 .68057 .39458 .68531 .40359 .68281 .3982 .67806 Mtetra
.3982 .67806 .40359 .68281 .41263 .6803 .40725 .67555 Mtetra
.651 .751 .923 r
.40725 .67555 .41263 .6803 .42169 .6778 .41634 .67304 Mtetra
.65 .752 .924 r
.41634 .67304 .42169 .6778 .43079 .67531 .42545 .67055 Mtetra
.649 .752 .925 r
.42545 .67055 .43079 .67531 .43992 .67282 .4346 .66807 Mtetra
.648 .753 .926 r
.4346 .66807 .43992 .67282 .44908 .67034 .44378 .66561 Mtetra
.647 .754 .927 r
.44378 .66561 .44908 .67034 .45827 .66787 .45299 .66315 Mtetra
.646 .755 .928 r
.45299 .66315 .45827 .66787 .46749 .66538 .46223 .66069 Mtetra
.647 .757 .929 r
.46223 .66069 .46749 .66538 .47675 .66287 .47151 .6582 Mtetra
.649 .759 .93 r
.47151 .6582 .47675 .66287 .48603 .66031 .48082 .65566 Mtetra
.653 .762 .929 r
.48082 .65566 .48603 .66031 .49536 .65766 .49016 .65302 Mtetra
.659 .764 .927 r
.49016 .65302 .49536 .65766 .50471 .65488 .49953 .65022 Mtetra
.669 .767 .924 r
.49953 .65022 .50471 .65488 .51409 .65192 .50894 .64719 Mtetra
.68 .768 .917 r
.50894 .64719 .51409 .65192 .52351 .64873 .51838 .64388 Mtetra
.692 .766 .908 r
.51838 .64388 .52351 .64873 .53296 .64529 .52785 .64024 Mtetra
.705 .762 .897 r
.52785 .64024 .53296 .64529 .54243 .64157 .53734 .63621 Mtetra
.714 .754 .884 r
.53734 .63621 .54243 .64157 .55193 .6376 .54686 .63185 Mtetra
.719 .742 .87 r
.54686 .63185 .55193 .6376 .56145 .63342 .5564 .62718 Mtetra
.719 .727 .857 r
.5564 .62718 .56145 .63342 .57099 .62917 .56596 .62239 Mtetra
.714 .711 .846 r
.56596 .62239 .57099 .62917 .58056 .62494 .57554 .61763 Mtetra
.703 .694 .838 r
.57554 .61763 .58056 .62494 .59016 .62091 .58515 .61313 Mtetra
.689 .678 .834 r
.58515 .61313 .59016 .62091 .5998 .61721 .59479 .60908 Mtetra
.672 .663 .833 r
.59479 .60908 .5998 .61721 .60947 .61392 .60448 .60561 Mtetra
.655 .652 .836 r
.60448 .60561 .60947 .61392 .61918 .61105 .61421 .60276 Mtetra
.641 .648 .841 r
.61421 .60276 .61918 .61105 .62894 .6085 .62398 .60037 Mtetra
.632 .648 .848 r
.62398 .60037 .62894 .6085 .63874 .60615 .6338 .59827 Mtetra
.634 .656 .854 r
.6338 .59827 .63874 .60615 .64858 .60377 .64366 .59611 Mtetra
.642 .666 .857 r
.64366 .59611 .64858 .60377 .65844 .60122 .65355 .5937 Mtetra
.656 .675 .857 r
.65355 .5937 .65844 .60122 .66834 .59838 .66346 .59084 Mtetra
.669 .681 .852 r
.66346 .59084 .66834 .59838 .67825 .59525 .67339 .58753 Mtetra
.675 .679 .846 r
.67339 .58753 .67825 .59525 .68819 .59195 .68333 .58397 Mtetra
.675 .673 .84 r
.68333 .58397 .68819 .59195 .69816 .58862 .69331 .58034 Mtetra
.666 .662 .837 r
.69331 .58034 .69816 .58862 .70817 .58549 .70333 .57701 Mtetra
.652 .652 .837 r
.70333 .57701 .70817 .58549 .71824 .58268 .71341 .57414 Mtetra
.634 .643 .842 r
.71341 .57414 .71824 .58268 .72837 .5803 .72356 .57189 Mtetra
.616 .639 .85 r
.72356 .57189 .72837 .5803 .73857 .57833 .73379 .57024 Mtetra
.6 .64 .862 r
.73379 .57024 .73857 .57833 .74883 .5767 .7441 .56904 Mtetra
.588 .646 .876 r
.7441 .56904 .74883 .5767 .75915 .57527 .75447 .56812 Mtetra
.583 .66 .89 r
.75447 .56812 .75915 .57527 .76952 .57388 .76489 .56723 Mtetra
.583 .677 .905 r
.76489 .56723 .76952 .57388 .77993 .57241 .77536 .56622 Mtetra
.591 .697 .916 r
.77536 .56622 .77993 .57241 .79037 .57074 .78585 .56491 Mtetra
.602 .717 .925 r
.78585 .56491 .79037 .57074 .80083 .56881 .79637 .56326 Mtetra
.616 .734 .93 r
.79637 .56326 .80083 .56881 .81132 .5666 .8069 .56122 Mtetra
.629 .747 .932 r
.8069 .56122 .81132 .5666 .82183 .56413 .81744 .55884 Mtetra
.641 .756 .932 r
.81744 .55884 .82183 .56413 .83236 .56143 .828 .55617 Mtetra
.65 .761 .931 r
.828 .55617 .83236 .56143 .84291 .55854 .83858 .55326 Mtetra
.656 .763 .929 r
.83858 .55326 .84291 .55854 .85349 .55552 .84919 .55019 Mtetra
.66 .764 .927 r
.84919 .55019 .85349 .55552 .8641 .5524 .85982 .54701 Mtetra
.662 .763 .925 r
.85982 .54701 .8641 .5524 .87474 .54922 .87049 .54378 Mtetra
.663 .762 .924 r
.87049 .54378 .87474 .54922 .88542 .54602 .8812 .54051 Mtetra
.662 .76 .923 r
.8812 .54051 .88542 .54602 .89614 .5428 .89194 .53724 Mtetra
.662 .759 .922 r
.89194 .53724 .89614 .5428 .9069 .53959 .90272 .53397 Mtetra
.661 .757 .921 r
.90272 .53397 .9069 .53959 .9177 .53638 .91355 .53072 Mtetra
.66 .756 .921 r
.91355 .53072 .9177 .53638 .92853 .53317 .92441 .52747 Mtetra
.66 .755 .92 r
.92441 .52747 .92853 .53317 .93941 .52997 .93532 .52424 Mtetra
.659 .754 .92 r
.93532 .52424 .93941 .52997 .95034 .52678 .94627 .52101 Mtetra
.659 .753 .92 r
.94627 .52101 .95034 .52678 .9613 .52358 .95726 .51777 Mtetra
.658 .753 .92 r
.95726 .51777 .9613 .52358 .9723 .52037 .96829 .51454 Mtetra
.653 .751 .922 r
.37472 .67831 .38018 .68308 .38917 .68057 .38373 .67578 Mtetra
.652 .751 .922 r
.38373 .67578 .38917 .68057 .3982 .67806 .39277 .67326 Mtetra
.652 .75 .922 r
.39277 .67326 .3982 .67806 .40725 .67555 .40185 .67073 Mtetra
.651 .75 .922 r
.40185 .67073 .40725 .67555 .41634 .67304 .41095 .66821 Mtetra
.65 .75 .923 r
.41095 .66821 .41634 .67304 .42545 .67055 .42009 .66571 Mtetra
.649 .75 .923 r
.42009 .66571 .42545 .67055 .4346 .66807 .42925 .66322 Mtetra
.648 .75 .924 r
.42925 .66322 .4346 .66807 .44378 .66561 .43845 .66075 Mtetra
.647 .75 .925 r
.43845 .66075 .44378 .66561 .45299 .66315 .44768 .6583 Mtetra
.646 .751 .926 r
.44768 .6583 .45299 .66315 .46223 .66069 .45694 .65586 Mtetra
.646 .752 .926 r
.45694 .65586 .46223 .66069 .47151 .6582 .46624 .65339 Mtetra
.648 .754 .927 r
.46624 .65339 .47151 .6582 .48082 .65566 .47557 .65087 Mtetra
.652 .757 .926 r
.47557 .65087 .48082 .65566 .49016 .65302 .48493 .64825 Mtetra
.659 .76 .925 r
.48493 .64825 .49016 .65302 .49953 .65022 .49433 .64546 Mtetra
.669 .764 .921 r
.49433 .64546 .49953 .65022 .50894 .64719 .50376 .64242 Mtetra
.682 .767 .916 r
.50376 .64242 .50894 .64719 .51838 .64388 .51322 .63903 Mtetra
.697 .769 .907 r
.51322 .63903 .51838 .64388 .52785 .64024 .52271 .63523 Mtetra
.713 .767 .895 r
.52271 .63523 .52785 .64024 .53734 .63621 .53223 .63096 Mtetra
.724 .761 .882 r
.53223 .63096 .53734 .63621 .54686 .63185 .54176 .62624 Mtetra
.733 .751 .867 r
.54176 .62624 .54686 .63185 .5564 .62718 .55132 .62111 Mtetra
.733 .737 .854 r
.55132 .62111 .5564 .62718 .56596 .62239 .5609 .61578 Mtetra
.729 .721 .843 r
.5609 .61578 .56596 .62239 .57554 .61763 .5705 .61046 Mtetra
.716 .703 .836 r
.5705 .61046 .57554 .61763 .58515 .61313 .58012 .60547 Mtetra
.698 .685 .833 r
.58012 .60547 .58515 .61313 .59479 .60908 .58977 .60106 Mtetra
.676 .668 .835 r
.58977 .60106 .59479 .60908 .60448 .60561 .59946 .59743 Mtetra
.653 .655 .84 r
.59946 .59743 .60448 .60561 .61421 .60276 .60921 .59464 Mtetra
.633 .65 .848 r
.60921 .59464 .61421 .60276 .62398 .60037 .61901 .5925 Mtetra
.62 .651 .859 r
.61901 .5925 .62398 .60037 .6338 .59827 .62886 .59076 Mtetra
.622 .662 .867 r
.62886 .59076 .6338 .59827 .64366 .59611 .63874 .58893 Mtetra
.635 .677 .872 r
.63874 .58893 .64366 .59611 .65355 .5937 .64866 .5867 Mtetra
.657 .692 .871 r
.64866 .5867 .65355 .5937 .66346 .59084 .65859 .58382 Mtetra
.677 .699 .863 r
.65859 .58382 .66346 .59084 .67339 .58753 .66852 .58029 Mtetra
.687 .697 .854 r
.66852 .58029 .67339 .58753 .68333 .58397 .67847 .57635 Mtetra
.687 .688 .845 r
.67847 .57635 .68333 .58397 .69331 .58034 .68844 .57233 Mtetra
.674 .673 .841 r
.68844 .57233 .69331 .58034 .70333 .57701 .69847 .5687 Mtetra
.656 .659 .841 r
.69847 .5687 .70333 .57701 .71341 .57414 .70856 .56572 Mtetra
.63 .645 .847 r
.70856 .56572 .71341 .57414 .72356 .57189 .71874 .56359 Mtetra
.605 .637 .856 r
.71874 .56359 .72356 .57189 .73379 .57024 .729 .56226 Mtetra
.582 .636 .869 r
.729 .56226 .73379 .57024 .7441 .56904 .73935 .56152 Mtetra
.565 .641 .885 r
.73935 .56152 .7441 .56904 .75447 .56812 .74978 .56113 Mtetra
.559 .655 .9 r
.74978 .56113 .75447 .56812 .76489 .56723 .76026 .56074 Mtetra
.561 .674 .914 r
.76026 .56074 .76489 .56723 .77536 .56622 .77078 .56017 Mtetra
.574 .696 .925 r
.77078 .56017 .77536 .56622 .78585 .56491 .78132 .55919 Mtetra
.59 .717 .932 r
.78132 .55919 .78585 .56491 .79637 .56326 .79188 .55776 Mtetra
.609 .734 .934 r
.79188 .55776 .79637 .56326 .8069 .56122 .80244 .55584 Mtetra
.626 .747 .934 r
.80244 .55584 .8069 .56122 .81744 .55884 .81302 .5535 Mtetra
.641 .755 .931 r
.81302 .5535 .81744 .55884 .828 .55617 .82361 .5508 Mtetra
.651 .759 .928 r
.82361 .5508 .828 .55617 .83858 .55326 .83421 .54785 Mtetra
.658 .76 .926 r
.83421 .54785 .83858 .55326 .84919 .55019 .84485 .54472 Mtetra
.662 .76 .923 r
.84485 .54472 .84919 .55019 .85982 .54701 .8555 .54147 Mtetra
.663 .759 .921 r
.8555 .54147 .85982 .54701 .87049 .54378 .8662 .53818 Mtetra
.664 .758 .92 r
.8662 .53818 .87049 .54378 .8812 .54051 .87693 .53486 Mtetra
.663 .757 .919 r
.87693 .53486 .8812 .54051 .89194 .53724 .8877 .53155 Mtetra
.663 .755 .919 r
.8877 .53155 .89194 .53724 .90272 .53397 .89851 .52824 Mtetra
.662 .754 .919 r
.89851 .52824 .90272 .53397 .91355 .53072 .90936 .52496 Mtetra
.661 .754 .919 r
.90936 .52496 .91355 .53072 .92441 .52747 .92026 .52169 Mtetra
.66 .753 .919 r
.92026 .52169 .92441 .52747 .93532 .52424 .93119 .51843 Mtetra
.659 .753 .919 r
.93119 .51843 .93532 .52424 .94627 .52101 .94217 .51517 Mtetra
.94217 .51517 .94627 .52101 .95726 .51777 .9532 .51192 Mtetra
.658 .753 .919 r
.9532 .51192 .95726 .51777 .96829 .51454 .96426 .50866 Mtetra
.653 .751 .921 r
.36922 .67351 .37472 .67831 .38373 .67578 .37825 .67097 Mtetra
.653 .75 .921 r
.37825 .67097 .38373 .67578 .39277 .67326 .38732 .66841 Mtetra
.652 .75 .921 r
.38732 .66841 .39277 .67326 .40185 .67073 .39641 .66586 Mtetra
.39641 .66586 .40185 .67073 .41095 .66821 .40553 .66332 Mtetra
.651 .749 .922 r
.40553 .66332 .41095 .66821 .42009 .66571 .41469 .6608 Mtetra
.649 .748 .922 r
.41469 .6608 .42009 .66571 .42925 .66322 .42387 .65829 Mtetra
.648 .748 .922 r
.42387 .65829 .42925 .66322 .43845 .66075 .43309 .6558 Mtetra
.647 .747 .923 r
.43309 .6558 .43845 .66075 .44768 .6583 .44234 .65334 Mtetra
.645 .747 .923 r
.44234 .65334 .44768 .6583 .45694 .65586 .45162 .65089 Mtetra
.646 .748 .924 r
.45162 .65089 .45694 .65586 .46624 .65339 .46094 .64843 Mtetra
.646 .749 .924 r
.46094 .64843 .46624 .65339 .47557 .65087 .47028 .64594 Mtetra
.65 .752 .924 r
.47028 .64594 .47557 .65087 .48493 .64825 .47967 .64334 Mtetra
.657 .755 .922 r
.47967 .64334 .48493 .64825 .49433 .64546 .48908 .64059 Mtetra
.668 .76 .919 r
.48908 .64059 .49433 .64546 .50376 .64242 .49854 .63756 Mtetra
.682 .765 .914 r
.49854 .63756 .50376 .64242 .51322 .63903 .50802 .63415 Mtetra
.7 .769 .906 r
.50802 .63415 .51322 .63903 .52271 .63523 .51753 .63027 Mtetra
.718 .77 .894 r
.51753 .63027 .52271 .63523 .53223 .63096 .52708 .62581 Mtetra
.733 .767 .88 r
.52708 .62581 .53223 .63096 .54176 .62624 .53664 .62079 Mtetra
.744 .76 .865 r
.53664 .62079 .54176 .62624 .55132 .62111 .54622 .61524 Mtetra
.747 .748 .852 r
.54622 .61524 .55132 .62111 .5609 .61578 .55581 .6094 Mtetra
.743 .732 .841 r
.55581 .6094 .5609 .61578 .5705 .61046 .56543 .60351 Mtetra
.729 .713 .836 r
.56543 .60351 .5705 .61046 .58012 .60547 .57506 .59801 Mtetra
.708 .694 .834 r
.57506 .59801 .58012 .60547 .58977 .60106 .58473 .59323 Mtetra
.681 .676 .839 r
.58473 .59323 .58977 .60106 .59946 .59743 .59444 .58947 Mtetra
.648 .66 .848 r
.59444 .58947 .59946 .59743 .60921 .59464 .6042 .58683 Mtetra
.621 .653 .86 r
.6042 .58683 .60921 .59464 .61901 .5925 .61402 .58506 Mtetra
.6 .655 .876 r
.61402 .58506 .61901 .5925 .62886 .59076 .6239 .58383 Mtetra
.603 .672 .889 r
.6239 .58383 .62886 .59076 .63874 .58893 .63382 .58246 Mtetra
.623 .696 .897 r
.63382 .58246 .63874 .58893 .64866 .5867 .64376 .58052 Mtetra
.658 .719 .894 r
.64376 .58052 .64866 .5867 .65859 .58382 .65371 .57762 Mtetra
.69 .73 .881 r
.65371 .57762 .65859 .58382 .66852 .58029 .66366 .57376 Mtetra
.705 .725 .866 r
.66366 .57376 .66852 .58029 .67847 .57635 .67361 .56933 Mtetra
.705 .711 .853 r
.67361 .56933 .67847 .57635 .68844 .57233 .68358 .56474 Mtetra
.687 .69 .847 r
.68358 .56474 .68844 .57233 .69847 .5687 .6936 .5607 Mtetra
.661 .67 .847 r
.6936 .5607 .69847 .5687 .70856 .56572 .7037 .55753 Mtetra
.627 .651 .854 r
.7037 .55753 .70856 .56572 .71874 .56359 .7139 .55549 Mtetra
.592 .637 .865 r
.7139 .55549 .71874 .56359 .729 .56226 .7242 .55449 Mtetra
.561 .632 .879 r
.7242 .55449 .729 .56226 .73935 .56152 .7346 .55422 Mtetra
.538 .636 .895 r
.7346 .55422 .73935 .56152 .74978 .56113 .74508 .55436 Mtetra
.532 .651 .911 r
.74508 .55436 .74978 .56113 .76026 .56074 .75561 .55446 Mtetra
.537 .672 .924 r
.75561 .55446 .76026 .56074 .77078 .56017 .76618 .55428 Mtetra
.557 .696 .933 r
.76618 .55428 .77078 .56017 .78132 .55919 .77677 .55356 Mtetra
.58 .718 .937 r
.77677 .55356 .78132 .55919 .79188 .55776 .78736 .55228 Mtetra
.605 .735 .937 r
.78736 .55228 .79188 .55776 .80244 .55584 .79796 .55041 Mtetra
.626 .747 .934 r
.79796 .55041 .80244 .55584 .81302 .5535 .80856 .54805 Mtetra
.642 .753 .929 r
.80856 .54805 .81302 .5535 .82361 .5508 .81918 .54531 Mtetra
.654 .756 .925 r
.81918 .54531 .82361 .5508 .83421 .54785 .82981 .54228 Mtetra
.66 .757 .922 r
.82981 .54228 .83421 .54785 .84485 .54472 .84046 .53909 Mtetra
.664 .756 .919 r
.84046 .53909 .84485 .54472 .8555 .54147 .85114 .53578 Mtetra
.665 .755 .918 r
.85114 .53578 .8555 .54147 .8662 .53818 .86186 .53244 Mtetra
.665 .754 .917 r
.86186 .53244 .8662 .53818 .87693 .53486 .87262 .52908 Mtetra
.664 .753 .917 r
.87262 .52908 .87693 .53486 .8877 .53155 .88342 .52574 Mtetra
.663 .753 .917 r
.88342 .52574 .8877 .53155 .89851 .52824 .89426 .52242 Mtetra
.662 .752 .917 r
.89426 .52242 .89851 .52824 .90936 .52496 .90514 .51912 Mtetra
.661 .752 .918 r
.90514 .51912 .90936 .52496 .92026 .52169 .91607 .51583 Mtetra
.66 .752 .918 r
.91607 .51583 .92026 .52169 .93119 .51843 .92704 .51256 Mtetra
.659 .752 .919 r
.92704 .51256 .93119 .51843 .94217 .51517 .93805 .50929 Mtetra
.658 .752 .919 r
.93805 .50929 .94217 .51517 .9532 .51192 .9491 .50602 Mtetra
.9491 .50602 .9532 .51192 .96426 .50866 .9602 .50275 Mtetra
.653 .751 .921 r
.36369 .66869 .36922 .67351 .37825 .67097 .37274 .66611 Mtetra
.653 .75 .921 r
.37274 .66611 .37825 .67097 .38732 .66841 .38183 .66353 Mtetra
.38183 .66353 .38732 .66841 .39641 .66586 .39094 .66095 Mtetra
.652 .749 .921 r
.39094 .66095 .39641 .66586 .40553 .66332 .40008 .65838 Mtetra
.652 .748 .921 r
.40008 .65838 .40553 .66332 .41469 .6608 .40926 .65582 Mtetra
.65 .747 .92 r
.40926 .65582 .41469 .6608 .42387 .65829 .41846 .65327 Mtetra
.649 .746 .92 r
.41846 .65327 .42387 .65829 .43309 .6558 .4277 .65075 Mtetra
.648 .745 .92 r
.4277 .65075 .43309 .6558 .44234 .65334 .43697 .64825 Mtetra
.646 .744 .92 r
.43697 .64825 .44234 .65334 .45162 .65089 .44627 .64578 Mtetra
.646 .743 .92 r
.44627 .64578 .45162 .65089 .46094 .64843 .4556 .64331 Mtetra
.646 .744 .921 r
.4556 .64331 .46094 .64843 .47028 .64594 .46497 .64083 Mtetra
.649 .746 .92 r
.46497 .64083 .47028 .64594 .47967 .64334 .47437 .63827 Mtetra
.654 .749 .919 r
.47437 .63827 .47967 .64334 .48908 .64059 .48381 .63556 Mtetra
.665 .755 .917 r
.48381 .63556 .48908 .64059 .49854 .63756 .49328 .63259 Mtetra
.68 .762 .913 r
.49328 .63259 .49854 .63756 .50802 .63415 .50279 .62923 Mtetra
.699 .768 .905 r
.50279 .62923 .50802 .63415 .51753 .63027 .51233 .62533 Mtetra
.721 .773 .894 r
.51233 .62533 .51753 .63027 .52708 .62581 .52189 .62078 Mtetra
.74 .774 .881 r
.52189 .62078 .52708 .62581 .53664 .62079 .53148 .61555 Mtetra
.755 .77 .865 r
.53148 .61555 .53664 .62079 .54622 .61524 .54109 .60963 Mtetra
.76 .759 .852 r
.54109 .60963 .54622 .61524 .55581 .6094 .5507 .60331 Mtetra
.758 .745 .841 r
.5507 .60331 .55581 .6094 .56543 .60351 .56033 .59686 Mtetra
.743 .726 .836 r
.56033 .59686 .56543 .60351 .57506 .59801 .56998 .59084 Mtetra
.719 .706 .837 r
.56998 .59084 .57506 .59801 .58473 .59323 .57966 .58568 Mtetra
.684 .685 .844 r
.57966 .58568 .58473 .59323 .59444 .58947 .58939 .58182 Mtetra
.641 .666 .859 r
.58939 .58182 .59444 .58947 .6042 .58683 .59917 .57943 Mtetra
.599 .656 .877 r
.59917 .57943 .6042 .58683 .61402 .58506 .60902 .57818 Mtetra
.564 .658 .899 r
.60902 .57818 .61402 .58506 .6239 .58383 .61894 .57768 Mtetra
.566 .684 .919 r
.61894 .57768 .6239 .58383 .63382 .58246 .6289 .57694 Mtetra
.598 .722 .931 r
.6289 .57694 .63382 .58246 .64376 .58052 .63888 .57538 Mtetra
.656 .759 .925 r
.63888 .57538 .64376 .58052 .65371 .57762 .64885 .57246 Mtetra
.707 .774 .904 r
.64885 .57246 .65371 .57762 .66366 .57376 .65881 .56818 Mtetra
.729 .765 .881 r
.65881 .56818 .66366 .57376 .67361 .56933 .66876 .56307 Mtetra
.73 .743 .862 r
.66876 .56307 .67361 .56933 .68358 .56474 .67872 .55772 Mtetra
.706 .713 .855 r
.67872 .55772 .68358 .56474 .6936 .5607 .68873 .5531 Mtetra
.671 .685 .855 r
.68873 .5531 .6936 .5607 .7037 .55753 .69884 .54964 Mtetra
.624 .658 .863 r
.69884 .54964 .7037 .55753 .7139 .55549 .70906 .54766 Mtetra
.576 .639 .876 r
.70906 .54766 .7139 .55549 .7242 .55449 .71939 .547 Mtetra
.536 .63 .891 r
.71939 .547 .7242 .55449 .7346 .55422 .72984 .54722 Mtetra
.506 .631 .908 r
.72984 .54722 .7346 .55422 .74508 .55436 .74037 .5479 Mtetra
.501 .648 .923 r
.74037 .5479 .74508 .55436 .75561 .55446 .75095 .54845 Mtetra
.512 .671 .935 r
.75095 .54845 .75561 .55446 .76618 .55428 .76157 .5486 Mtetra
.542 .699 .942 r
.76157 .5486 .76618 .55428 .77677 .55356 .77219 .54806 Mtetra
.574 .722 .943 r
.77219 .54806 .77677 .55356 .78736 .55228 .78282 .54684 Mtetra
.605 .738 .939 r
.78282 .54684 .78736 .55228 .79796 .55041 .79344 .54494 Mtetra
.629 .747 .933 r
.79344 .54494 .79796 .55041 .80856 .54805 .80407 .5425 Mtetra
.646 .751 .926 r
.80407 .5425 .80856 .54805 .81918 .54531 .8147 .53966 Mtetra
.657 .753 .921 r
.8147 .53966 .81918 .54531 .82981 .54228 .82536 .53654 Mtetra
.662 .752 .917 r
.82536 .53654 .82981 .54228 .84046 .53909 .83603 .53327 Mtetra
.665 .751 .915 r
.83603 .53327 .84046 .53909 .85114 .53578 .84674 .52991 Mtetra
.665 .75 .914 r
.84674 .52991 .85114 .53578 .86186 .53244 .85749 .52654 Mtetra
.85749 .52654 .86186 .53244 .87262 .52908 .86828 .52317 Mtetra
.663 .75 .914 r
.86828 .52317 .87262 .52908 .88342 .52574 .8791 .51982 Mtetra
.662 .75 .915 r
.8791 .51982 .88342 .52574 .89426 .52242 .88998 .5165 Mtetra
.661 .75 .916 r
.88998 .5165 .89426 .52242 .90514 .51912 .90089 .5132 Mtetra
.66 .75 .917 r
.90089 .5132 .90514 .51912 .91607 .51583 .91185 .50991 Mtetra
.659 .751 .918 r
.91185 .50991 .91607 .51583 .92704 .51256 .92285 .50663 Mtetra
.658 .751 .918 r
.92285 .50663 .92704 .51256 .93805 .50929 .93389 .50336 Mtetra
.658 .751 .919 r
.93389 .50336 .93805 .50929 .9491 .50602 .94498 .50008 Mtetra
.658 .752 .919 r
.94498 .50008 .9491 .50602 .9602 .50275 .9561 .4968 Mtetra
.654 .751 .921 r
.35813 .66383 .36369 .66869 .37274 .66611 .3672 .66123 Mtetra
.3672 .66123 .37274 .66611 .38183 .66353 .3763 .65862 Mtetra
.654 .75 .921 r
.3763 .65862 .38183 .66353 .39094 .66095 .38543 .65601 Mtetra
.653 .749 .92 r
.38543 .65601 .39094 .66095 .40008 .65838 .3946 .6534 Mtetra
.3946 .6534 .40008 .65838 .40926 .65582 .40379 .6508 Mtetra
.652 .747 .92 r
.40379 .6508 .40926 .65582 .41846 .65327 .41302 .64821 Mtetra
.651 .746 .919 r
.41302 .64821 .41846 .65327 .4277 .65075 .42227 .64564 Mtetra
.649 .744 .919 r
.42227 .64564 .4277 .65075 .43697 .64825 .43156 .64309 Mtetra
.648 .743 .919 r
.43156 .64309 .43697 .64825 .44627 .64578 .44088 .64057 Mtetra
.647 .741 .918 r
.44088 .64057 .44627 .64578 .4556 .64331 .45024 .63807 Mtetra
.646 .74 .918 r
.45024 .63807 .4556 .64331 .46497 .64083 .45962 .63558 Mtetra
.648 .741 .917 r
.45962 .63558 .46497 .64083 .47437 .63827 .46905 .63303 Mtetra
.652 .744 .917 r
.46905 .63303 .47437 .63827 .48381 .63556 .4785 .63038 Mtetra
.662 .749 .915 r
.4785 .63038 .48381 .63556 .49328 .63259 .488 .62747 Mtetra
.676 .756 .911 r
.488 .62747 .49328 .63259 .50279 .62923 .49752 .6242 Mtetra
.696 .765 .905 r
.49752 .6242 .50279 .62923 .51233 .62533 .50709 .62037 Mtetra
.72 .773 .895 r
.50709 .62037 .51233 .62533 .52189 .62078 .51668 .61583 Mtetra
.743 .779 .882 r
.51668 .61583 .52189 .62078 .53148 .61555 .52629 .61048 Mtetra
.763 .778 .866 r
.52629 .61048 .53148 .61555 .54109 .60963 .53592 .60431 Mtetra
.772 .771 .852 r
.53592 .60431 .54109 .60963 .5507 .60331 .54556 .59758 Mtetra
.773 .759 .841 r
.54556 .59758 .5507 .60331 .56033 .59686 .55522 .59059 Mtetra
.758 .742 .838 r
.55522 .59059 .56033 .59686 .56998 .59084 .56488 .58405 Mtetra
.731 .721 .841 r
.56488 .58405 .56998 .59084 .57966 .58568 .57458 .57851 Mtetra
.688 .697 .854 r
.57458 .57851 .57966 .58568 .58939 .58182 .58432 .57459 Mtetra
.628 .674 .875 r
.58432 .57459 .58939 .58182 .59917 .57943 .59413 .57256 Mtetra
.563 .658 .9 r
.59413 .57256 .59917 .57943 .60902 .57818 .60402 .57204 Mtetra
.498 .655 .93 r
.60402 .57204 .60902 .57818 .61894 .57768 .61398 .57251 Mtetra
.491 .692 .957 r
.61398 .57251 .61894 .57768 .6289 .57694 .62398 .57263 Mtetra
.54 .754 .975 r
.62398 .57263 .6289 .57694 .63888 .57538 .63401 .57162 Mtetra
.643 .816 .966 r
.63401 .57162 .63888 .57538 .64885 .57246 .64401 .56868 Mtetra
.728 .837 .931 r
.64401 .56868 .64885 .57246 .65881 .56818 .65397 .56382 Mtetra
.763 .819 .896 r
.65397 .56382 .65881 .56818 .66876 .56307 .66391 .55781 Mtetra
.764 .786 .87 r
.66391 .55781 .66876 .56307 .67872 .55772 .67386 .55144 Mtetra
.731 .744 .863 r
.67386 .55144 .67872 .55772 .68873 .5531 .68387 .54605 Mtetra
.684 .707 .865 r
.68387 .54605 .68873 .5531 .69884 .54964 .69397 .54218 Mtetra
.622 .671 .875 r
.69397 .54218 .69884 .54964 .70906 .54766 .70421 .54022 Mtetra
.558 .642 .89 r
.70421 .54022 .70906 .54766 .71939 .547 .71459 .53991 Mtetra
.505 .628 .906 r
.71459 .53991 .71939 .547 .72984 .54722 .72508 .54061 Mtetra
.468 .627 .922 r
.72508 .54061 .72984 .54722 .74037 .5479 .73566 .54179 Mtetra
.468 .647 .936 r
.73566 .54179 .74037 .5479 .75095 .54845 .74629 .54272 Mtetra
.49 .673 .946 r
.74629 .54272 .75095 .54845 .76157 .5486 .75694 .5431 Mtetra
.532 .704 .949 r
.75694 .5431 .76157 .5486 .77219 .54806 .7676 .54263 Mtetra
.573 .726 .946 r
.7676 .54263 .77219 .54806 .78282 .54684 .77825 .54136 Mtetra
.609 .74 .938 r
.77825 .54136 .78282 .54684 .79344 .54494 .78889 .53936 Mtetra
.634 .747 .929 r
.78889 .53936 .79344 .54494 .80407 .5425 .79953 .53679 Mtetra
.65 .749 .922 r
.79953 .53679 .80407 .5425 .8147 .53966 .81019 .53383 Mtetra
.66 .749 .916 r
.81019 .53383 .8147 .53966 .82536 .53654 .82086 .53062 Mtetra
.664 .748 .913 r
.82086 .53062 .82536 .53654 .83603 .53327 .83157 .5273 Mtetra
.665 .747 .911 r
.83157 .5273 .83603 .53327 .84674 .52991 .8423 .52391 Mtetra
.8423 .52391 .84674 .52991 .85749 .52654 .85308 .52054 Mtetra
.664 .747 .912 r
.85308 .52054 .85749 .52654 .86828 .52317 .8639 .51717 Mtetra
.662 .747 .913 r
.8639 .51717 .86828 .52317 .8791 .51982 .87476 .51384 Mtetra
.661 .748 .915 r
.87476 .51384 .8791 .51982 .88998 .5165 .88566 .51053 Mtetra
.66 .749 .916 r
.88566 .51053 .88998 .5165 .90089 .5132 .89661 .50723 Mtetra
.659 .75 .917 r
.89661 .50723 .90089 .5132 .91185 .50991 .9076 .50395 Mtetra
.658 .75 .918 r
.9076 .50395 .91185 .50991 .92285 .50663 .91863 .50067 Mtetra
.658 .751 .919 r
.91863 .50067 .92285 .50663 .93389 .50336 .92971 .49739 Mtetra
.92971 .49739 .93389 .50336 .94498 .50008 .94083 .4941 Mtetra
.658 .752 .92 r
.94083 .4941 .94498 .50008 .9561 .4968 .95198 .4908 Mtetra
.654 .751 .921 r
.35253 .65894 .35813 .66383 .3672 .66123 .36162 .65633 Mtetra
.36162 .65633 .3672 .66123 .3763 .65862 .37074 .6537 Mtetra
.37074 .6537 .3763 .65862 .38543 .65601 .37989 .65106 Mtetra
.654 .75 .921 r
.37989 .65106 .38543 .65601 .3946 .6534 .38907 .64842 Mtetra
.654 .75 .92 r
.38907 .64842 .3946 .6534 .40379 .6508 .39829 .64577 Mtetra
.653 .749 .92 r
.39829 .64577 .40379 .6508 .41302 .64821 .40754 .64313 Mtetra
.652 .747 .919 r
.40754 .64313 .41302 .64821 .42227 .64564 .41681 .6405 Mtetra
.651 .745 .918 r
.41681 .6405 .42227 .64564 .43156 .64309 .42612 .63788 Mtetra
.65 .743 .917 r
.42612 .63788 .43156 .64309 .44088 .64057 .43547 .63529 Mtetra
.649 .74 .916 r
.43547 .63529 .44088 .64057 .45024 .63807 .44484 .63273 Mtetra
.648 .738 .915 r
.44484 .63273 .45024 .63807 .45962 .63558 .45425 .63019 Mtetra
.648 .737 .914 r
.45425 .63019 .45962 .63558 .46905 .63303 .46369 .62762 Mtetra
.65 .738 .913 r
.46369 .62762 .46905 .63303 .4785 .63038 .47317 .625 Mtetra
.658 .742 .912 r
.47317 .625 .4785 .63038 .488 .62747 .48268 .62218 Mtetra
.67 .749 .91 r
.48268 .62218 .488 .62747 .49752 .6242 .49223 .61904 Mtetra
.69 .76 .905 r
.49223 .61904 .49752 .6242 .50709 .62037 .50181 .61535 Mtetra
.715 .771 .897 r
.50181 .61535 .50709 .62037 .51668 .61583 .51142 .61093 Mtetra
.742 .782 .885 r
.51142 .61093 .51668 .61583 .52629 .61048 .52107 .60561 Mtetra
.767 .787 .869 r
.52107 .60561 .52629 .61048 .53592 .60431 .53072 .5993 Mtetra
.782 .784 .855 r
.53072 .5993 .53592 .60431 .54556 .59758 .54039 .59227 Mtetra
.787 .775 .843 r
.54039 .59227 .54556 .59758 .55522 .59059 .55007 .5848 Mtetra
.773 .76 .841 r
.55007 .5848 .55522 .59059 .56488 .58405 .55976 .57777 Mtetra
.745 .74 .847 r
.55976 .57777 .56488 .58405 .57458 .57851 .56948 .57184 Mtetra
.69 .714 .867 r
.56948 .57184 .57458 .57851 .58432 .57459 .57924 .56791 Mtetra
.606 .683 .896 r
.57924 .56791 .58432 .57459 .59413 .57256 .58908 .56637 Mtetra
.499 .654 .929 r
.58908 .56637 .59413 .57256 .60402 .57204 .599 .56682 Mtetra
.365 .628 .954 r
.599 .56682 .60402 .57204 .61398 .57251 .60901 .56857 Mtetra
.322 .667 .975 r
.60901 .56857 .61398 .57251 .62398 .57263 .61907 .56985 Mtetra
.392 .761 .992 r
.61907 .56985 .62398 .57263 .63401 .57162 .62915 .56956 Mtetra
.588 .88 .993 r
.62915 .56956 .63401 .57162 .64401 .56868 .63918 .56661 Mtetra
.746 .917 .949 r
.63918 .56661 .64401 .56868 .65397 .56382 .64916 .56099 Mtetra
.805 .887 .904 r
.64916 .56099 .65397 .56382 .66391 .55781 .65909 .55378 Mtetra
.808 .838 .874 r
.65909 .55378 .66391 .55781 .67386 .55144 .66901 .54608 Mtetra
.764 .784 .87 r
.66901 .54608 .67386 .55144 .68387 .54605 .679 .53968 Mtetra
.703 .735 .876 r
.679 .53968 .68387 .54605 .69397 .54218 .68911 .53528 Mtetra
.622 .688 .891 r
.68911 .53528 .69397 .54218 .70421 .54022 .69937 .53328 Mtetra
.534 .648 .908 r
.69937 .53328 .70421 .54022 .71459 .53991 .70978 .53332 Mtetra
.466 .628 .923 r
.70978 .53332 .71459 .53991 .72508 .54061 .72032 .53449 Mtetra
.423 .623 .936 r
.72032 .53449 .72508 .54061 .73566 .54179 .73095 .53611 Mtetra
.434 .648 .949 r
.73095 .53611 .73566 .54179 .74629 .54272 .74161 .53731 Mtetra
.471 .679 .956 r
.74161 .53731 .74629 .54272 .75694 .5431 .7523 .53778 Mtetra
.529 .712 .956 r
.7523 .53778 .75694 .5431 .7676 .54263 .76298 .53725 Mtetra
.579 .732 .947 r
.76298 .53725 .7676 .54263 .77825 .54136 .77364 .53582 Mtetra
.617 .742 .935 r
.77364 .53582 .77825 .54136 .78889 .53936 .7843 .53363 Mtetra
.642 .745 .924 r
.7843 .53363 .78889 .53936 .79953 .53679 .79496 .53088 Mtetra
.655 .745 .916 r
.79496 .53088 .79953 .53679 .81019 .53383 .80563 .52781 Mtetra
.662 .744 .911 r
.80563 .52781 .81019 .53383 .82086 .53062 .81633 .52452 Mtetra
.664 .743 .909 r
.81633 .52452 .82086 .53062 .83157 .5273 .82706 .52117 Mtetra
.664 .743 .908 r
.82706 .52117 .83157 .5273 .8423 .52391 .83782 .5178 Mtetra
.663 .743 .91 r
.83782 .5178 .8423 .52391 .85308 .52054 .84863 .51445 Mtetra
.662 .745 .911 r
.84863 .51445 .85308 .52054 .8639 .51717 .85949 .51112 Mtetra
.66 .746 .914 r
.85949 .51112 .8639 .51717 .87476 .51384 .87038 .50782 Mtetra
.659 .748 .915 r
.87038 .50782 .87476 .51384 .88566 .51053 .88132 .50453 Mtetra
.659 .749 .917 r
.88132 .50453 .88566 .51053 .89661 .50723 .8923 .50125 Mtetra
.658 .75 .918 r
.8923 .50125 .89661 .50723 .9076 .50395 .90332 .49797 Mtetra
.658 .751 .919 r
.90332 .49797 .9076 .50395 .91863 .50067 .91439 .49468 Mtetra
.657 .751 .919 r
.91439 .49468 .91863 .50067 .92971 .49739 .9255 .49139 Mtetra
.657 .752 .92 r
.9255 .49139 .92971 .49739 .94083 .4941 .93664 .48808 Mtetra
.93664 .48808 .94083 .4941 .95198 .4908 .94784 .48476 Mtetra
.654 .751 .921 r
.34689 .65403 .35253 .65894 .36162 .65633 .356 .6514 Mtetra
.356 .6514 .36162 .65633 .37074 .6537 .36514 .64875 Mtetra
.36514 .64875 .37074 .6537 .37989 .65106 .37431 .6461 Mtetra
.37431 .6461 .37989 .65106 .38907 .64842 .38352 .64343 Mtetra
.38352 .64343 .38907 .64842 .39829 .64577 .39275 .64076 Mtetra
.39275 .64076 .39829 .64577 .40754 .64313 .40202 .63807 Mtetra
.654 .749 .92 r
.40202 .63807 .40754 .64313 .41681 .6405 .41132 .63538 Mtetra
.654 .748 .919 r
.41132 .63538 .41681 .6405 .42612 .63788 .42065 .63269 Mtetra
.653 .745 .918 r
.42065 .63269 .42612 .63788 .43547 .63529 .43001 .63001 Mtetra
.652 .742 .916 r
.43001 .63001 .43547 .63529 .44484 .63273 .43941 .62735 Mtetra
.65 .739 .914 r
.43941 .62735 .44484 .63273 .45425 .63019 .44884 .62473 Mtetra
.65 .736 .913 r
.44884 .62473 .45425 .63019 .46369 .62762 .4583 .6221 Mtetra
.65 .735 .911 r
.4583 .6221 .46369 .62762 .47317 .625 .4678 .61947 Mtetra
.656 .737 .909 r
.4678 .61947 .47317 .625 .48268 .62218 .47733 .61669 Mtetra
.665 .742 .908 r
.47733 .61669 .48268 .62218 .49223 .61904 .4869 .61368 Mtetra
.683 .752 .904 r
.4869 .61368 .49223 .61904 .50181 .61535 .4965 .61017 Mtetra
.707 .765 .898 r
.4965 .61017 .50181 .61535 .51142 .61093 .50614 .60597 Mtetra
.737 .78 .888 r
.50614 .60597 .51142 .61093 .52107 .60561 .51581 .60082 Mtetra
.767 .791 .873 r
.51581 .60082 .52107 .60561 .53072 .5993 .52549 .59457 Mtetra
.787 .795 .859 r
.52549 .59457 .53072 .5993 .54039 .59227 .53519 .5874 Mtetra
.798 .792 .846 r
.53519 .5874 .54039 .59227 .55007 .5848 .5449 .57959 Mtetra
.788 .781 .846 r
.5449 .57959 .55007 .5848 .55976 .57777 .55461 .57212 Mtetra
.76 .764 .856 r
.55461 .57212 .55976 .57777 .56948 .57184 .56435 .5658 Mtetra
.692 .736 .884 r
.56435 .5658 .56948 .57184 .57924 .56791 .57414 .56189 Mtetra
.573 .694 .924 r
.57414 .56189 .57924 .56791 .58908 .56637 .584 .56093 Mtetra
.386 .631 .951 r
.584 .56093 .58908 .56637 .599 .56682 .59397 .56254 Mtetra
.115 .526 .913 r
.59397 .56254 .599 .56682 .60901 .56857 .60404 .56592 Mtetra
0 .516 .853 r
.60404 .56592 .60901 .56857 .61907 .56985 .61417 .56866 Mtetra
.082 .627 .841 r
.61417 .56866 .61907 .56985 .62915 .56956 .6243 .5693 Mtetra
.434 .869 .912 r
.6243 .5693 .62915 .56956 .63918 .56661 .63438 .56634 Mtetra
.739 .979 .918 r
.63438 .56634 .63918 .56661 .64916 .56099 .64436 .55975 Mtetra
.843 .949 .887 r
.64436 .55975 .64916 .56099 .65909 .55378 .65428 .55104 Mtetra
.853 .888 .862 r
.65428 .55104 .65909 .55378 .66901 .54608 .66418 .54168 Mtetra
.801 .825 .87 r
.66418 .54168 .66901 .54608 .679 .53968 .67415 .53406 Mtetra
.725 .768 .887 r
.67415 .53406 .679 .53968 .68911 .53528 .68425 .52904 Mtetra
.62 .711 .911 r
.68425 .52904 .68911 .53528 .69937 .53328 .69453 .52698 Mtetra
.501 .657 .93 r
.69453 .52698 .69937 .53328 .70978 .53332 .70498 .52737 Mtetra
.417 .628 .941 r
.70498 .52737 .70978 .53332 .72032 .53449 .71556 .52894 Mtetra
.372 .622 .949 r
.71556 .52894 .72032 .53449 .73095 .53611 .72623 .53087 Mtetra
.404 .653 .96 r
.72623 .53087 .73095 .53611 .74161 .53731 .73693 .53217 Mtetra
.465 .69 .964 r
.73693 .53217 .74161 .53731 .7523 .53778 .74763 .53255 Mtetra
.537 .721 .958 r
.74763 .53255 .7523 .53778 .76298 .53725 .75832 .53182 Mtetra
.592 .737 .944 r
.75832 .53182 .76298 .53725 .77364 .53582 .769 .53011 Mtetra
.627 .741 .929 r
.769 .53011 .77364 .53582 .7843 .53363 .77966 .5277 Mtetra
.648 .742 .918 r
.77966 .5277 .7843 .53363 .79496 .53088 .79034 .52478 Mtetra
.657 .74 .911 r
.79034 .52478 .79496 .53088 .80563 .52781 .80103 .52161 Mtetra
.662 .739 .907 r
.80103 .52161 .80563 .52781 .81633 .52452 .81175 .5183 Mtetra
.81175 .5183 .81633 .52452 .82706 .52117 .82252 .51498 Mtetra
.662 .74 .908 r
.82252 .51498 .82706 .52117 .83782 .5178 .83332 .51165 Mtetra
.66 .742 .911 r
.83332 .51165 .83782 .5178 .84863 .51445 .84416 .50836 Mtetra
.659 .745 .913 r
.84416 .50836 .84863 .51445 .85949 .51112 .85505 .50508 Mtetra
.658 .747 .916 r
.85505 .50508 .85949 .51112 .87038 .50782 .86598 .50181 Mtetra
.658 .749 .917 r
.86598 .50181 .87038 .50782 .88132 .50453 .87695 .49854 Mtetra
.657 .75 .919 r
.87695 .49854 .88132 .50453 .8923 .50125 .88797 .49527 Mtetra
.657 .752 .92 r
.88797 .49527 .8923 .50125 .90332 .49797 .89902 .49198 Mtetra
.89902 .49198 .90332 .49797 .91439 .49468 .91012 .48868 Mtetra
.91012 .48868 .91439 .49468 .9255 .49139 .92126 .48536 Mtetra
.657 .753 .92 r
.92126 .48536 .9255 .49139 .93664 .48808 .93244 .48203 Mtetra
.658 .752 .92 r
.93244 .48203 .93664 .48808 .94784 .48476 .94366 .47868 Mtetra
.653 .751 .921 r
.34122 .64908 .34689 .65403 .356 .6514 .35035 .64645 Mtetra
.653 .751 .922 r
.35035 .64645 .356 .6514 .36514 .64875 .35951 .64381 Mtetra
.653 .752 .922 r
.35951 .64381 .36514 .64875 .37431 .6461 .3687 .64115 Mtetra
.653 .753 .923 r
.3687 .64115 .37431 .6461 .38352 .64343 .37792 .63848 Mtetra
.654 .753 .923 r
.37792 .63848 .38352 .64343 .39275 .64076 .38718 .63578 Mtetra
.38718 .63578 .39275 .64076 .40202 .63807 .39646 .63307 Mtetra
.655 .753 .922 r
.39646 .63307 .40202 .63807 .41132 .63538 .40578 .63033 Mtetra
.656 .752 .921 r
.40578 .63033 .41132 .63538 .42065 .63269 .41514 .62757 Mtetra
.656 .75 .919 r
.41514 .62757 .42065 .63269 .43001 .63001 .42452 .62479 Mtetra
.656 .747 .917 r
.42452 .62479 .43001 .63001 .43941 .62735 .43394 .62202 Mtetra
.655 .743 .914 r
.43394 .62202 .43941 .62735 .44884 .62473 .44339 .61925 Mtetra
.654 .738 .911 r
.44339 .61925 .44884 .62473 .4583 .6221 .45288 .6165 Mtetra
.653 .734 .909 r
.45288 .6165 .4583 .6221 .4678 .61947 .4624 .61378 Mtetra
.656 .732 .906 r
.4624 .61378 .4678 .61947 .47733 .61669 .47195 .61099 Mtetra
.66 .734 .904 r
.47195 .61099 .47733 .61669 .4869 .61368 .48153 .60807 Mtetra
.674 .742 .901 r
.48153 .60807 .4869 .61368 .4965 .61017 .49116 .60476 Mtetra
.695 .755 .898 r
.49116 .60476 .4965 .61017 .50614 .60597 .50082 .60088 Mtetra
.726 .774 .891 r
.50082 .60088 .50614 .60597 .51581 .60082 .51051 .59606 Mtetra
.76 .792 .879 r
.51051 .59606 .51581 .60082 .52549 .59457 .52023 .59008 Mtetra
.788 .806 .866 r
.52023 .59008 .52549 .59457 .53519 .5874 .52996 .583 Mtetra
.807 .81 .853 r
.52996 .583 .53519 .5874 .5449 .57959 .53969 .57504 Mtetra
.802 .805 .854 r
.53969 .57504 .5449 .57959 .55461 .57212 .54944 .56724 Mtetra
.776 .793 .867 r
.54944 .56724 .55461 .57212 .56435 .5658 .5592 .56055 Mtetra
.694 .765 .906 r
.5592 .56055 .56435 .5658 .57414 .56189 .56901 .55666 Mtetra
.518 .704 .955 r
.56901 .55666 .57414 .56189 .584 .56093 .57891 .55634 Mtetra
.185 .557 .933 r
.57891 .55634 .584 .56093 .59397 .56254 .58892 .55934 Mtetra
0 .285 .694 r
.58892 .55934 .59397 .56254 .60404 .56592 .59906 .56469 Mtetra
.398 0 0 r
.59906 .56469 .60404 .56592 .61417 .56866 .60926 .56925 Mtetra
.294 0 0 r
.60926 .56925 .61417 .56866 .6243 .5693 .61947 .57107 Mtetra
0 0 0 r
.61947 .57107 .6243 .5693 .63438 .56634 .62959 .56809 Mtetra
.669 .969 .79 r
.62959 .56809 .63438 .56634 .64436 .55975 .63959 .56029 Mtetra
.866 .99 .829 r
.63959 .56029 .64436 .55975 .65428 .55104 .64949 .54973 Mtetra
.896 .931 .832 r
.64949 .54973 .65428 .55104 .66418 .54168 .65935 .53835 Mtetra
.841 .868 .862 r
.65935 .53835 .66418 .54168 .67415 .53406 .6693 .5293 Mtetra
.75 .807 .898 r
.6693 .5293 .67415 .53406 .68425 .52904 .6794 .52358 Mtetra
.616 .741 .935 r
.6794 .52358 .68425 .52904 .69453 .52698 .6897 .52147 Mtetra
.454 .667 .954 r
.6897 .52147 .69453 .52698 .70498 .52737 .70019 .5222 Mtetra
.354 .629 .957 r
.70019 .5222 .70498 .52737 .71556 .52894 .71081 .52406 Mtetra
.319 .624 .959 r
.71081 .52406 .71556 .52894 .72623 .53087 .72151 .52612 Mtetra
.386 .668 .97 r
.72151 .52612 .72623 .53087 .73693 .53217 .73223 .52729 Mtetra
.475 .708 .971 r
.73223 .52729 .73693 .53217 .74763 .53255 .74294 .52735 Mtetra
.557 .732 .957 r
.74294 .52735 .74763 .53255 .75832 .53182 .75363 .52623 Mtetra
.61 .74 .937 r
.75363 .52623 .75832 .53182 .769 .53011 .7643 .52416 Mtetra
.638 .738 .921 r
.7643 .52416 .769 .53011 .77966 .5277 .77498 .5215 Mtetra
.653 .735 .91 r
.77498 .5215 .77966 .5277 .79034 .52478 .78567 .51844 Mtetra
.658 .733 .905 r
.78567 .51844 .79034 .52478 .80103 .52161 .79639 .51525 Mtetra
.66 .734 .905 r
.79639 .51525 .80103 .52161 .81175 .5183 .80715 .51199 Mtetra
.658 .736 .907 r
.80715 .51199 .81175 .5183 .82252 .51498 .81795 .50876 Mtetra
.657 .739 .91 r
.81795 .50876 .82252 .51498 .83332 .51165 .82879 .50553 Mtetra
.656 .743 .914 r
.82879 .50553 .83332 .51165 .84416 .50836 .83967 .50232 Mtetra
.656 .747 .917 r
.83967 .50232 .84416 .50836 .85505 .50508 .85059 .4991 Mtetra
.656 .75 .919 r
.85059 .4991 .85505 .50508 .86598 .50181 .86156 .49587 Mtetra
.656 .752 .921 r
.86156 .49587 .86598 .50181 .87695 .49854 .87257 .49261 Mtetra
.657 .754 .921 r
.87257 .49261 .87695 .49854 .88797 .49527 .88361 .48932 Mtetra
.657 .754 .922 r
.88361 .48932 .88797 .49527 .89902 .49198 .8947 .48601 Mtetra
.657 .754 .921 r
.8947 .48601 .89902 .49198 .91012 .48868 .90582 .48268 Mtetra
.658 .754 .921 r
.90582 .48268 .91012 .48868 .92126 .48536 .91699 .47932 Mtetra
.91699 .47932 .92126 .48536 .93244 .48203 .9282 .47595 Mtetra
.658 .753 .92 r
.9282 .47595 .93244 .48203 .94366 .47868 .93945 .47256 Mtetra
.652 .75 .922 r
.33552 .6441 .34122 .64908 .35035 .64645 .34466 .64147 Mtetra
.652 .751 .923 r
.34466 .64147 .35035 .64645 .35951 .64381 .35384 .63884 Mtetra
.652 .752 .923 r
.35384 .63884 .35951 .64381 .3687 .64115 .36305 .63619 Mtetra
.652 .753 .924 r
.36305 .63619 .3687 .64115 .37792 .63848 .37229 .63353 Mtetra
.653 .755 .924 r
.37229 .63353 .37792 .63848 .38718 .63578 .38156 .63083 Mtetra
.654 .756 .924 r
.38156 .63083 .38718 .63578 .39646 .63307 .39087 .62811 Mtetra
.655 .756 .924 r
.39087 .62811 .39646 .63307 .40578 .63033 .40021 .62535 Mtetra
.657 .757 .924 r
.40021 .62535 .40578 .63033 .41514 .62757 .40959 .62255 Mtetra
.659 .756 .922 r
.40959 .62255 .41514 .62757 .42452 .62479 .419 .61969 Mtetra
.66 .754 .919 r
.419 .61969 .42452 .62479 .43394 .62202 .42844 .61679 Mtetra
.661 .75 .916 r
.42844 .61679 .43394 .62202 .44339 .61925 .43791 .61386 Mtetra
.661 .745 .912 r
.43791 .61386 .44339 .61925 .45288 .6165 .44742 .61094 Mtetra
.66 .739 .908 r
.44742 .61094 .45288 .6165 .4624 .61378 .45696 .60804 Mtetra
.659 .733 .904 r
.45696 .60804 .4624 .61378 .47195 .61099 .46654 .60513 Mtetra
.66 .73 .901 r
.46654 .60513 .47195 .61099 .48153 .60807 .47614 .6022 Mtetra
.668 .732 .898 r
.47614 .6022 .48153 .60807 .49116 .60476 .48578 .59905 Mtetra
.682 .742 .897 r
.48578 .59905 .49116 .60476 .50082 .60088 .49546 .59551 Mtetra
.71 .762 .893 r
.49546 .59551 .50082 .60088 .51051 .59606 .50518 .59115 Mtetra
.745 .786 .886 r
.50518 .59115 .51051 .59606 .52023 .59008 .51492 .58569 Mtetra
.78 .81 .876 r
.51492 .58569 .52023 .59008 .52996 .583 .52468 .579 Mtetra
.809 .826 .864 r
.52468 .579 .52996 .583 .53969 .57504 .53446 .57119 Mtetra
.813 .833 .865 r
.53446 .57119 .53969 .57504 .54944 .56724 .54423 .56326 Mtetra
.793 .829 .88 r
.54423 .56326 .54944 .56724 .5592 .56055 .55403 .55622 Mtetra
.695 .803 .932 r
.55403 .55622 .5592 .56055 .56901 .55666 .56387 .55228 Mtetra
.444 .711 .98 r
.56387 .55228 .56901 .55666 .57891 .55634 .5738 .55249 Mtetra
0 .416 .828 r
.5738 .55249 .57891 .55634 .58892 .55934 .58385 .55688 Mtetra
.539 0 0 r
.58385 .55688 .58892 .55934 .59906 .56469 .59405 .56438 Mtetra
.602 .033 0 r
.59405 .56438 .59906 .56469 .60926 .56925 .60433 .57097 Mtetra
.481 0 0 r
.60433 .57097 .60926 .56925 .61947 .57107 .61461 .57417 Mtetra
.02 0 0 r
.61461 .57417 .61947 .57107 .62959 .56809 .62478 .57117 Mtetra
.635 .931 .676 r
.62478 .57117 .62959 .56809 .63959 .56029 .63479 .56198 Mtetra
.885 .991 .764 r
.63479 .56198 .63959 .56029 .64949 .54973 .64468 .54935 Mtetra
.926 .942 .789 r
.64468 .54935 .64949 .54973 .65935 .53835 .65451 .53577 Mtetra
.873 .893 .844 r
.65451 .53577 .65935 .53835 .6693 .5293 .66444 .52529 Mtetra
.771 .842 .906 r
.66444 .52529 .6693 .5293 .6794 .52358 .67456 .51899 Mtetra
.602 .774 .962 r
.67456 .51899 .6794 .52358 .6897 .52147 .68489 .51689 Mtetra
.383 .674 .974 r
.68489 .51689 .6897 .52147 .70019 .5222 .69542 .51794 Mtetra
.278 .631 .963 r
.69542 .51794 .70019 .5222 .71081 .52406 .70607 .5199 Mtetra
.28 .637 .965 r
.70607 .5199 .71081 .52406 .72151 .52612 .71678 .52176 Mtetra
.396 .693 .98 r
.71678 .52176 .72151 .52612 .73223 .52729 .7275 .5225 Mtetra
.507 .729 .973 r
.7275 .5225 .73223 .52729 .74294 .52735 .7382 .52199 Mtetra
.585 .739 .949 r
.7382 .52199 .74294 .52735 .75363 .52623 .74888 .52036 Mtetra
.628 .738 .926 r
.74888 .52036 .75363 .52623 .7643 .52416 .75956 .5179 Mtetra
.645 .731 .911 r
.75956 .5179 .7643 .52416 .77498 .5215 .77025 .51504 Mtetra
.654 .728 .904 r
.77025 .51504 .77498 .5215 .78567 .51844 .78096 .51195 Mtetra
.654 .728 .903 r
.78096 .51195 .78567 .51844 .79639 .51525 .79172 .50884 Mtetra
.654 .731 .906 r
.79172 .50884 .79639 .51525 .80715 .51199 .80252 .50572 Mtetra
.652 .736 .911 r
.80252 .50572 .80715 .51199 .81795 .50876 .81336 .50262 Mtetra
.652 .742 .915 r
.81336 .50262 .81795 .50876 .82879 .50553 .82424 .49952 Mtetra
.652 .747 .919 r
.82424 .49952 .82879 .50553 .83967 .50232 .83516 .49639 Mtetra
.653 .751 .922 r
.83516 .49639 .83967 .50232 .85059 .4991 .84612 .49322 Mtetra
.654 .755 .923 r
.84612 .49322 .85059 .4991 .86156 .49587 .85712 .48999 Mtetra
.656 .756 .924 r
.85712 .48999 .86156 .49587 .87257 .49261 .86816 .48672 Mtetra
.657 .757 .924 r
.86816 .48672 .87257 .49261 .88361 .48932 .87923 .4834 Mtetra
.658 .757 .923 r
.87923 .4834 .88361 .48932 .8947 .48601 .89035 .48004 Mtetra
.658 .756 .922 r
.89035 .48004 .8947 .48601 .90582 .48268 .9015 .47666 Mtetra
.659 .756 .922 r
.9015 .47666 .90582 .48268 .91699 .47932 .9127 .47325 Mtetra
.659 .755 .921 r
.9127 .47325 .91699 .47932 .9282 .47595 .92393 .46983 Mtetra
.659 .754 .92 r
.92393 .46983 .9282 .47595 .93945 .47256 .93521 .46639 Mtetra
.651 .75 .922 r
.32977 .63908 .33552 .6441 .34466 .64147 .33894 .63647 Mtetra
.65 .751 .923 r
.33894 .63647 .34466 .64147 .35384 .63884 .34813 .63385 Mtetra
.65 .752 .924 r
.34813 .63385 .35384 .63884 .36305 .63619 .35736 .63122 Mtetra
.651 .754 .925 r
.35736 .63122 .36305 .63619 .37229 .63353 .36662 .62857 Mtetra
.651 .755 .926 r
.36662 .62857 .37229 .63353 .38156 .63083 .37591 .62591 Mtetra
.652 .757 .927 r
.37591 .62591 .38156 .63083 .39087 .62811 .38523 .62321 Mtetra
.653 .759 .927 r
.38523 .62321 .39087 .62811 .40021 .62535 .3946 .62047 Mtetra
.656 .761 .927 r
.3946 .62047 .40021 .62535 .40959 .62255 .40399 .61765 Mtetra
.659 .763 .926 r
.40399 .61765 .40959 .62255 .419 .61969 .41342 .61475 Mtetra
.663 .762 .924 r
.41342 .61475 .419 .61969 .42844 .61679 .42289 .61175 Mtetra
.667 .76 .92 r
.42289 .61175 .42844 .61679 .43791 .61386 .43239 .60865 Mtetra
.669 .755 .915 r
.43239 .60865 .43791 .61386 .44742 .61094 .44193 .6055 Mtetra
.669 .747 .909 r
.44193 .6055 .44742 .61094 .45696 .60804 .45149 .60232 Mtetra
.668 .737 .902 r
.45149 .60232 .45696 .60804 .46654 .60513 .46109 .59917 Mtetra
.665 .729 .897 r
.46109 .59917 .46654 .60513 .47614 .6022 .47072 .59608 Mtetra
.666 .724 .893 r
.47072 .59608 .47614 .6022 .48578 .59905 .48038 .59296 Mtetra
.669 .727 .893 r
.48038 .59296 .48578 .59905 .49546 .59551 .49008 .58973 Mtetra
.689 .744 .893 r
.49008 .58973 .49546 .59551 .50518 .59115 .49981 .58595 Mtetra
.719 .772 .894 r
.49981 .58595 .50518 .59115 .51492 .58569 .50958 .58127 Mtetra
.76 .809 .891 r
.50958 .58127 .51492 .58569 .52468 .579 .51937 .57534 Mtetra
.8 .841 .882 r
.51937 .57534 .52468 .579 .53446 .57119 .52918 .5681 Mtetra
.817 .864 .882 r
.52918 .5681 .53446 .57119 .54423 .56326 .539 .56031 Mtetra
.808 .872 .894 r
.539 .56031 .54423 .56326 .55403 .55622 .54882 .55296 Mtetra
.696 .852 .957 r
.54882 .55296 .55403 .55622 .56387 .55228 .55869 .54884 Mtetra
.353 .713 .986 r
.55869 .54884 .56387 .55228 .5738 .55249 .56865 .54933 Mtetra
0 .245 .653 r
.56865 .54933 .5738 .55249 .58385 .55688 .57875 .55497 Mtetra
.686 .141 0 r
.57875 .55497 .58385 .55688 .59405 .56438 .58901 .56466 Mtetra
.702 .174 0 r
.58901 .56466 .59405 .56438 .60433 .57097 .59936 .57343 Mtetra
.582 .055 0 r
.59936 .57343 .60433 .57097 .61461 .57417 .60972 .57815 Mtetra
.107 0 0 r
.60972 .57815 .61461 .57417 .62478 .57117 .61995 .57515 Mtetra
.651 .915 .612 r
.61995 .57515 .62478 .57117 .63479 .56198 .62997 .5644 Mtetra
.909 .98 .715 r
.62997 .5644 .63479 .56198 .64468 .54935 .63985 .54956 Mtetra
.947 .937 .75 r
.63985 .54956 .64468 .54935 .65451 .53577 .64966 .53374 Mtetra
.896 .906 .824 r
.64966 .53374 .65451 .53577 .66444 .52529 .65958 .52197 Mtetra
.782 .874 .915 r
.65958 .52197 .66444 .52529 .67456 .51899 .66972 .51536 Mtetra
.568 .807 .989 r
.66972 .51536 .67456 .51899 .68489 .51689 .68009 .5134 Mtetra
.272 .666 .969 r
.68009 .5134 .68489 .51689 .69542 .51794 .69066 .51472 Mtetra
.195 .631 .947 r
.69066 .51472 .69542 .51794 .70607 .5199 .70133 .5165 Mtetra
.271 .67 .969 r
.70133 .5165 .70607 .5199 .71678 .52176 .71204 .51775 Mtetra
.44 .734 .989 r
.71204 .51775 .71678 .52176 .7275 .5225 .72274 .51767 Mtetra
.558 .752 .968 r
.72274 .51767 .7275 .5225 .7382 .52199 .73341 .51632 Mtetra
.617 .742 .935 r
.73341 .51632 .7382 .52199 .74888 .52036 .74408 .51407 Mtetra
.644 .73 .911 r
.74408 .51407 .74888 .52036 .75956 .5179 .75476 .51124 Mtetra
.648 .72 .901 r
.75476 .51124 .75956 .5179 .77025 .51504 .76547 .5083 Mtetra
.649 .718 .899 r
.76547 .5083 .77025 .51504 .78096 .51195 .77622 .50534 Mtetra
.646 .722 .904 r
.77622 .50534 .78096 .51195 .79172 .50884 .78702 .50244 Mtetra
.644 .729 .911 r
.78702 .50244 .79172 .50884 .80252 .50572 .79787 .49956 Mtetra
.644 .739 .918 r
.79787 .49956 .80252 .50572 .81336 .50262 .80875 .49666 Mtetra
.645 .747 .923 r
.80875 .49666 .81336 .50262 .82424 .49952 .81968 .4937 Mtetra
.648 .754 .927 r
.81968 .4937 .82424 .49952 .83516 .49639 .83064 .49063 Mtetra
.651 .759 .928 r
.83064 .49063 .83516 .49639 .84612 .49322 .84163 .48747 Mtetra
.654 .761 .928 r
.84163 .48747 .84612 .49322 .85712 .48999 .85266 .48421 Mtetra
.657 .762 .927 r
.85266 .48421 .85712 .48999 .86816 .48672 .86373 .48087 Mtetra
.658 .761 .926 r
.86373 .48087 .86816 .48672 .87923 .4834 .87483 .47749 Mtetra
.659 .76 .924 r
.87483 .47749 .87923 .4834 .89035 .48004 .88597 .47406 Mtetra
.66 .758 .923 r
.88597 .47406 .89035 .48004 .9015 .47666 .89715 .47062 Mtetra
.66 .757 .922 r
.89715 .47062 .9015 .47666 .9127 .47325 .90837 .46715 Mtetra
.66 .755 .921 r
.90837 .46715 .9127 .47325 .92393 .46983 .91964 .46367 Mtetra
.66 .754 .92 r
.91964 .46367 .92393 .46983 .93521 .46639 .93095 .46018 Mtetra
.65 .75 .923 r
.32399 .63404 .32977 .63908 .33894 .63647 .33317 .63143 Mtetra
.33317 .63143 .33894 .63647 .34813 .63385 .34239 .62881 Mtetra
.649 .751 .924 r
.34239 .62881 .34813 .63385 .35736 .63122 .35163 .62619 Mtetra
.649 .752 .925 r
.35163 .62619 .35736 .63122 .36662 .62857 .36091 .62356 Mtetra
.648 .754 .926 r
.36091 .62356 .36662 .62857 .37591 .62591 .37022 .62094 Mtetra
.649 .756 .927 r
.37022 .62094 .37591 .62591 .38523 .62321 .37956 .61828 Mtetra
.65 .759 .929 r
.37956 .61828 .38523 .62321 .3946 .62047 .38894 .61559 Mtetra
.653 .762 .93 r
.38894 .61559 .3946 .62047 .40399 .61765 .39836 .61282 Mtetra
.658 .766 .929 r
.39836 .61282 .40399 .61765 .41342 .61475 .40781 .60992 Mtetra
.663 .768 .928 r
.40781 .60992 .41342 .61475 .42289 .61175 .4173 .60689 Mtetra
.671 .769 .924 r
.4173 .60689 .42289 .61175 .43239 .60865 .42683 .60367 Mtetra
.676 .767 .919 r
.42683 .60367 .43239 .60865 .44193 .6055 .43639 .6003 Mtetra
.681 .76 .911 r
.43639 .6003 .44193 .6055 .45149 .60232 .44598 .59681 Mtetra
.681 .749 .903 r
.44598 .59681 .45149 .60232 .46109 .59917 .45561 .5933 Mtetra
.677 .737 .895 r
.45561 .5933 .46109 .59917 .47072 .59608 .46527 .58986 Mtetra
.67 .724 .889 r
.46527 .58986 .47072 .59608 .48038 .59296 .47495 .58659 Mtetra
.663 .717 .889 r
.47495 .58659 .48038 .59296 .49008 .58973 .48466 .58351 Mtetra
.669 .724 .891 r
.48466 .58351 .49008 .58973 .49981 .58595 .49441 .58025 Mtetra
.686 .748 .899 r
.49441 .58025 .49981 .58595 .50958 .58127 .5042 .57653 Mtetra
.725 .792 .906 r
.5042 .57653 .50958 .58127 .51937 .57534 .51402 .57173 Mtetra
.771 .844 .907 r
.51402 .57173 .51937 .57534 .52918 .5681 .52386 .56559 Mtetra
.806 .891 .905 r
.52386 .56559 .52918 .5681 .539 .56031 .53372 .55838 Mtetra
.814 .915 .907 r
.53372 .55838 .539 .56031 .54882 .55296 .54358 .5509 Mtetra
.695 .906 .97 r
.54358 .5509 .54882 .55296 .55869 .54884 .55349 .54639 Mtetra
.295 .726 .969 r
.55349 .54639 .55869 .54884 .56865 .54933 .56347 .54657 Mtetra
.418 0 0 r
.56347 .54657 .56865 .54933 .57875 .55497 .57359 .55282 Mtetra
.735 .21 0 r
.57359 .55282 .57875 .55497 .58901 .56466 .5839 .56418 Mtetra
.742 .224 0 r
.5839 .56418 .58901 .56466 .59936 .57343 .59431 .57478 Mtetra
.62 .079 0 r
.59431 .57478 .59936 .57343 .60972 .57815 .60474 .58092 Mtetra
0 0 0 r
.60474 .58092 .60972 .57815 .61995 .57515 .61502 .5779 Mtetra
.826 .989 .724 r
.61502 .5779 .61995 .57515 .62997 .5644 .62506 .5657 Mtetra
.95 .951 .725 r
.62506 .5657 .62997 .5644 .63985 .54956 .63494 .54899 Mtetra
.954 .904 .734 r
.63494 .54899 .63985 .54956 .64966 .53374 .64475 .53147 Mtetra
.901 .895 .813 r
.64475 .53147 .64966 .53374 .65958 .52197 .6547 .51905 Mtetra
.773 .891 .929 r
.6547 .51905 .65958 .52197 .66972 .51536 .66489 .51271 Mtetra
.49 .822 .999 r
.66489 .51271 .66972 .51536 .68009 .5134 .67531 .51111 Mtetra
.126 .626 .906 r
.67531 .51111 .68009 .5134 .69066 .51472 .68592 .51253 Mtetra
.146 .643 .912 r
.68592 .51253 .69066 .51472 .70133 .5165 .69659 .51369 Mtetra
.336 .737 .982 r
.69659 .51369 .70133 .5165 .71204 .51775 .70726 .51378 Mtetra
.526 .778 .989 r
.70726 .51378 .71204 .51775 .72274 .51767 .71792 .51251 Mtetra
.616 .763 .949 r
.71792 .51251 .72274 .51767 .73341 .51632 .72857 .51015 Mtetra
.643 .735 .915 r
.72857 .51015 .73341 .51632 .74408 .51407 .73922 .50732 Mtetra
.651 .718 .898 r
.73922 .50732 .74408 .51407 .75476 .51124 .74991 .50429 Mtetra
.643 .71 .895 r
.74991 .50429 .75476 .51124 .76547 .5083 .76066 .50147 Mtetra
.637 .711 .901 r
.76066 .50147 .76547 .5083 .77622 .50534 .77146 .49882 Mtetra
.633 .721 .911 r
.77146 .49882 .77622 .50534 .78702 .50244 .78231 .49624 Mtetra
.631 .733 .921 r
.78231 .49624 .78702 .50244 .79787 .49956 .79321 .49365 Mtetra
.635 .746 .928 r
.79321 .49365 .79787 .49956 .80875 .49666 .80414 .49093 Mtetra
.639 .755 .932 r
.80414 .49093 .80875 .49666 .81968 .4937 .81511 .48805 Mtetra
.646 .762 .933 r
.81511 .48805 .81968 .4937 .83064 .49063 .8261 .48498 Mtetra
.651 .765 .932 r
.8261 .48498 .83064 .49063 .84163 .48747 .83712 .48177 Mtetra
.656 .765 .93 r
.83712 .48177 .84163 .48747 .85266 .48421 .84817 .47842 Mtetra
.659 .764 .927 r
.84817 .47842 .85266 .48421 .86373 .48087 .85926 .47499 Mtetra
.661 .762 .925 r
.85926 .47499 .86373 .48087 .87483 .47749 .87039 .47152 Mtetra
.661 .76 .923 r
.87039 .47152 .87483 .47749 .88597 .47406 .88156 .46801 Mtetra
.661 .758 .922 r
.88156 .46801 .88597 .47406 .89715 .47062 .89276 .4645 Mtetra
.661 .756 .921 r
.89276 .4645 .89715 .47062 .90837 .46715 .90402 .46098 Mtetra
.661 .755 .92 r
.90402 .46098 .90837 .46715 .91964 .46367 .91531 .45746 Mtetra
.661 .754 .919 r
.91531 .45746 .91964 .46367 .93095 .46018 .92665 .45393 Mtetra
.65 .75 .923 r
.31818 .62896 .32399 .63404 .33317 .63143 .32738 .62633 Mtetra
.32738 .62633 .33317 .63143 .34239 .62881 .33661 .62369 Mtetra
.649 .75 .923 r
.33661 .62369 .34239 .62881 .35163 .62619 .34587 .62107 Mtetra
.648 .75 .924 r
.34587 .62107 .35163 .62619 .36091 .62356 .35517 .61845 Mtetra
.646 .75 .925 r
.35517 .61845 .36091 .62356 .37022 .62094 .3645 .61586 Mtetra
.646 .752 .927 r
.3645 .61586 .37022 .62094 .37956 .61828 .37386 .61326 Mtetra
.645 .755 .929 r
.37386 .61326 .37956 .61828 .38894 .61559 .38325 .61066 Mtetra
.648 .76 .931 r
.38325 .61066 .38894 .61559 .39836 .61282 .39268 .60798 Mtetra
.652 .766 .932 r
.39268 .60798 .39836 .61282 .40781 .60992 .40215 .60519 Mtetra
.66 .772 .933 r
.40215 .60519 .40781 .60992 .4173 .60689 .41166 .60221 Mtetra
.67 .778 .93 r
.41166 .60221 .4173 .60689 .42683 .60367 .42122 .59897 Mtetra
.681 .78 .925 r
.42122 .59897 .42683 .60367 .43639 .6003 .4308 .59545 Mtetra
.693 .777 .916 r
.4308 .59545 .43639 .6003 .44598 .59681 .44043 .59164 Mtetra
.697 .767 .906 r
.44043 .59164 .44598 .59681 .45561 .5933 .45009 .58768 Mtetra
.696 .751 .894 r
.45009 .58768 .45561 .5933 .46527 .58986 .45978 .58369 Mtetra
.684 .73 .885 r
.45978 .58369 .46527 .58986 .47495 .58659 .46949 .57999 Mtetra
.666 .712 .883 r
.46949 .57999 .47495 .58659 .48466 .58351 .47922 .57679 Mtetra
.654 .705 .884 r
.47922 .57679 .48466 .58351 .49441 .58025 .48899 .57392 Mtetra
.648 .716 .898 r
.48899 .57392 .49441 .58025 .5042 .57653 .49879 .57121 Mtetra
.67 .76 .918 r
.49879 .57121 .5042 .57653 .51402 .57173 .50862 .5679 Mtetra
.71 .83 .939 r
.50862 .5679 .51402 .57173 .52386 .56559 .5185 .56352 Mtetra
.767 .912 .938 r
.5185 .56352 .52386 .56559 .53372 .55838 .52839 .55746 Mtetra
.801 .956 .916 r
.52839 .55746 .53372 .55838 .54358 .5509 .53831 .55012 Mtetra
.687 .952 .954 r
.53831 .55012 .54358 .5509 .55349 .54639 .54824 .54496 Mtetra
.328 .784 .949 r
.54824 .54496 .55349 .54639 .56347 .54657 .55824 .54398 Mtetra
.396 0 0 r
.55824 .54398 .56347 .54657 .57359 .55282 .56838 .5498 Mtetra
.728 .207 0 r
.56838 .5498 .57359 .55282 .5839 .56418 .57871 .56182 Mtetra
.734 .209 0 r
.57871 .56182 .5839 .56418 .59431 .57478 .58915 .57352 Mtetra
.583 .008 0 r
.58915 .57352 .59431 .57478 .60474 .58092 .59963 .58073 Mtetra
.421 .864 .903 r
.59963 .58073 .60474 .58092 .61502 .5779 .60995 .5777 Mtetra
.92 .949 .798 r
.60995 .5777 .61502 .5779 .62506 .5657 .62002 .5644 Mtetra
.948 .883 .736 r
.62002 .5644 .62506 .5657 .63494 .54899 .62993 .54655 Mtetra
.939 .855 .732 r
.62993 .54655 .63494 .54899 .64475 .53147 .63977 .52833 Mtetra
.886 .869 .815 r
.63977 .52833 .64475 .53147 .6547 .51905 .64978 .51629 Mtetra
.726 .894 .956 r
.64978 .51629 .6547 .51905 .66489 .51271 .66005 .5111 Mtetra
.333 .783 .955 r
.66005 .5111 .66489 .51271 .67531 .51111 .67054 .51013 Mtetra
0 .549 .768 r
.67054 .51013 .67531 .51111 .68592 .51253 .68118 .51136 Mtetra
.162 .687 .874 r
.68118 .51136 .68592 .51253 .69659 .51369 .69183 .51132 Mtetra
.475 .83 .996 r
.69183 .51132 .69659 .51369 .70726 .51378 .70244 .50959 Mtetra
.625 .809 .97 r
.70244 .50959 .70726 .51378 .71792 .51251 .71304 .50676 Mtetra
.665 .759 .92 r
.71304 .50676 .71792 .51251 .72857 .51015 .72365 .50332 Mtetra
.659 .72 .893 r
.72365 .50332 .72857 .51015 .73922 .50732 .7343 .50005 Mtetra
.647 .702 .886 r
.7343 .50005 .73922 .50732 .74991 .50429 .74502 .49711 Mtetra
.629 .698 .894 r
.74502 .49711 .74991 .50429 .76066 .50147 .75582 .49468 Mtetra
.616 .705 .909 r
.75582 .49468 .76066 .50147 .77146 .49882 .76669 .49255 Mtetra
.613 .723 .924 r
.76669 .49255 .77146 .49882 .78231 .49624 .7776 .4904 Mtetra
.616 .741 .935 r
.7776 .4904 .78231 .49624 .79321 .49365 .78855 .48809 Mtetra
.626 .757 .941 r
.78855 .48809 .79321 .49365 .80414 .49093 .79952 .48548 Mtetra
.637 .767 .942 r
.79952 .48548 .80414 .49093 .81511 .48805 .81052 .48258 Mtetra
.648 .771 .939 r
.81052 .48258 .81511 .48805 .8261 .48498 .82154 .47942 Mtetra
.656 .771 .934 r
.82154 .47942 .8261 .48498 .83712 .48177 .83258 .47606 Mtetra
.661 .769 .93 r
.83258 .47606 .83712 .48177 .84817 .47842 .84365 .47257 Mtetra
.663 .765 .925 r
.84365 .47257 .84817 .47842 .85926 .47499 .85476 .46901 Mtetra
.664 .761 .922 r
.85476 .46901 .85926 .47499 .87039 .47152 .86591 .46543 Mtetra
.664 .758 .92 r
.86591 .46543 .87039 .47152 .88156 .46801 .8771 .46185 Mtetra
.662 .756 .919 r
.8771 .46185 .88156 .46801 .89276 .4645 .88834 .45828 Mtetra
.662 .754 .919 r
.88834 .45828 .89276 .4645 .90402 .46098 .89962 .45473 Mtetra
.661 .754 .919 r
.89962 .45473 .90402 .46098 .91531 .45746 .91095 .45118 Mtetra
.661 .753 .919 r
.91095 .45118 .91531 .45746 .92665 .45393 .92232 .44763 Mtetra
.652 .75 .922 r
.31232 .62385 .31818 .62896 .32738 .62633 .32154 .62117 Mtetra
.651 .749 .921 r
.32154 .62117 .32738 .62633 .33661 .62369 .3308 .61849 Mtetra
.65 .748 .921 r
.3308 .61849 .33661 .62369 .34587 .62107 .34008 .61583 Mtetra
.648 .747 .921 r
.34008 .61583 .34587 .62107 .35517 .61845 .3494 .61319 Mtetra
.646 .746 .922 r
.3494 .61319 .35517 .61845 .3645 .61586 .35874 .6106 Mtetra
.644 .746 .923 r
.35874 .6106 .3645 .61586 .37386 .61326 .36812 .60804 Mtetra
.642 .748 .926 r
.36812 .60804 .37386 .61326 .38325 .61066 .37753 .60552 Mtetra
.642 .752 .928 r
.37753 .60552 .38325 .61066 .39268 .60798 .38698 .60297 Mtetra
.645 .758 .931 r
.38698 .60297 .39268 .60798 .40215 .60519 .39646 .60033 Mtetra
.652 .767 .933 r
.39646 .60033 .40215 .60519 .41166 .60221 .40599 .59751 Mtetra
.664 .777 .933 r
.40599 .59751 .41166 .60221 .42122 .59897 .41556 .5944 Mtetra
.679 .786 .931 r
.41556 .5944 .42122 .59897 .4308 .59545 .42517 .59091 Mtetra
.699 .792 .922 r
.42517 .59091 .4308 .59545 .44043 .59164 .43483 .58692 Mtetra
.711 .788 .912 r
.43483 .58692 .44043 .59164 .45009 .58768 .44452 .58257 Mtetra
.718 .775 .898 r
.44452 .58257 .45009 .58768 .45978 .58369 .45425 .57795 Mtetra
.706 .752 .887 r
.45425 .57795 .45978 .58369 .46949 .57999 .46399 .57359 Mtetra
.683 .725 .881 r
.46399 .57359 .46949 .57999 .47922 .57679 .47375 .56988 Mtetra
.654 .7 .88 r
.47375 .56988 .47922 .57679 .48899 .57392 .48353 .567 Mtetra
.619 .688 .892 r
.48353 .567 .48899 .57392 .49879 .57121 .49334 .56504 Mtetra
.605 .708 .917 r
.49334 .56504 .49879 .57121 .50862 .5679 .50319 .56331 Mtetra
.605 .771 .959 r
.50319 .56331 .50862 .5679 .5185 .56352 .51309 .56122 Mtetra
.681 .893 .974 r
.51309 .56122 .5185 .56352 .52839 .55746 .52302 .55703 Mtetra
.754 .97 .928 r
.52302 .55703 .52839 .55746 .53831 .55012 .53298 .55048 Mtetra
.67 .971 .908 r
.53298 .55048 .53831 .55012 .54824 .54496 .54296 .54459 Mtetra
.472 .885 .931 r
.54296 .54459 .54824 .54496 .55824 .54398 .55298 .54145 Mtetra
0 .382 .734 r
.55298 .54145 .55824 .54398 .56838 .5498 .56311 .54527 Mtetra
.594 .074 0 r
.56311 .54527 .56838 .5498 .57871 .56182 .57342 .55606 Mtetra
0 0 .489 r
.57342 .55606 .57871 .56182 .58915 .57352 .58387 .56729 Mtetra
0 .283 .776 r
.58387 .56729 .58915 .57352 .59963 .58073 .59435 .57468 Mtetra
.654 .739 .912 r
.59435 .57468 .59963 .58073 .60995 .5777 .6047 .57162 Mtetra
.859 .778 .771 r
.6047 .57162 .60995 .5777 .62002 .5644 .6148 .5581 Mtetra
.885 .771 .73 r
.6148 .5581 .62002 .5644 .62993 .54655 .62477 .54068 Mtetra
.889 .781 .736 r
.62477 .54068 .62993 .54655 .63977 .52833 .63469 .52365 Mtetra
.841 .824 .832 r
.63469 .52365 .63977 .52833 .64978 .51629 .64482 .5136 Mtetra
.603 .866 .992 r
.64482 .5136 .64978 .51629 .66005 .5111 .65522 .51055 Mtetra
.109 .659 .809 r
.65522 .51055 .66005 .5111 .67054 .51013 .66578 .51028 Mtetra
.07 0 0 r
.66578 .51028 .67054 .51013 .68118 .51136 .67642 .51069 Mtetra
.336 .81 .906 r
.67642 .51069 .68118 .51136 .69183 .51132 .68701 .50872 Mtetra
.66 .892 .981 r
.68701 .50872 .69183 .51132 .70244 .50959 .69754 .50461 Mtetra
.703 .801 .926 r
.69754 .50461 .70244 .50959 .71304 .50676 .70808 .50014 Mtetra
.691 .739 .887 r
.70808 .50014 .71304 .50676 .72365 .50332 .71866 .49589 Mtetra
.659 .702 .879 r
.71866 .49589 .72365 .50332 .7343 .50005 .72934 .49258 Mtetra
.63 .69 .887 r
.72934 .49258 .7343 .50005 .74502 .49711 .74012 .49012 Mtetra
.603 .694 .907 r
.74012 .49012 .74502 .49711 .75582 .49468 .75098 .48832 Mtetra
.586 .709 .928 r
.75098 .48832 .75582 .49468 .76669 .49255 .76192 .4868 Mtetra
.591 .735 .944 r
.76192 .4868 .76669 .49255 .7776 .4904 .77289 .48501 Mtetra
.603 .755 .951 r
.77289 .48501 .7776 .4904 .78855 .48809 .78388 .48284 Mtetra
.624 .771 .95 r
.78388 .48284 .78855 .48809 .79952 .48548 .79489 .48017 Mtetra
.642 .776 .945 r
.79489 .48017 .79952 .48548 .81052 .48258 .8059 .4771 Mtetra
.655 .775 .937 r
.8059 .4771 .81052 .48258 .82154 .47942 .81693 .47372 Mtetra
.663 .771 .929 r
.81693 .47372 .82154 .47942 .83258 .47606 .82799 .47015 Mtetra
.667 .765 .923 r
.82799 .47015 .83258 .47606 .84365 .47257 .83908 .4665 Mtetra
.668 .76 .919 r
.83908 .4665 .84365 .47257 .85476 .46901 .85021 .46281 Mtetra
.666 .756 .917 r
.85021 .46281 .85476 .46901 .86591 .46543 .86139 .45915 Mtetra
.665 .753 .916 r
.86139 .45915 .86591 .46543 .8771 .46185 .87261 .45552 Mtetra
.663 .751 .916 r
.87261 .45552 .8771 .46185 .88834 .45828 .88388 .45193 Mtetra
.661 .751 .916 r
.88388 .45193 .88834 .45828 .89962 .45473 .89519 .44837 Mtetra
.66 .751 .917 r
.89519 .44837 .89962 .45473 .91095 .45118 .90655 .44483 Mtetra
.66 .752 .918 r
.90655 .44483 .91095 .45118 .92232 .44763 .91796 .44128 Mtetra
.654 .751 .921 r
.30643 .61871 .31232 .62385 .32154 .62117 .31567 .61595 Mtetra
.654 .749 .919 r
.31567 .61595 .32154 .62117 .3308 .61849 .32495 .61319 Mtetra
.653 .746 .918 r
.32495 .61319 .3308 .61849 .34008 .61583 .33426 .61045 Mtetra
.651 .743 .917 r
.33426 .61045 .34008 .61583 .3494 .61319 .34359 .60774 Mtetra
.648 .741 .917 r
.34359 .60774 .3494 .61319 .35874 .6106 .35296 .60511 Mtetra
.644 .739 .918 r
.35296 .60511 .35874 .6106 .36812 .60804 .36236 .60254 Mtetra
.64 .738 .92 r
.36236 .60254 .36812 .60804 .37753 .60552 .37179 .60006 Mtetra
.638 .739 .922 r
.37179 .60006 .37753 .60552 .38698 .60297 .38125 .59762 Mtetra
.636 .744 .926 r
.38125 .59762 .38698 .60297 .39646 .60033 .39074 .59519 Mtetra
.64 .754 .931 r
.39074 .59519 .39646 .60033 .40599 .59751 .40028 .59264 Mtetra
.649 .767 .936 r
.40028 .59264 .40599 .59751 .41556 .5944 .40986 .58986 Mtetra
.667 .786 .937 r
.40986 .58986 .41556 .5944 .42517 .59091 .41949 .58662 Mtetra
.694 .803 .932 r
.41949 .58662 .42517 .59091 .43483 .58692 .42917 .58271 Mtetra
.719 .811 .922 r
.42917 .58271 .43483 .58692 .44452 .58257 .4389 .57815 Mtetra
.74 .806 .905 r
.4389 .57815 .44452 .58257 .45425 .57795 .44866 .57292 Mtetra
.735 .784 .891 r
.44866 .57292 .45425 .57795 .46399 .57359 .45845 .56771 Mtetra
.715 .751 .88 r
.45845 .56771 .46399 .57359 .47375 .56988 .46825 .56302 Mtetra
.672 .709 .875 r
.46825 .56302 .47375 .56988 .48353 .567 .47806 .55956 Mtetra
.611 .67 .882 r
.47806 .55956 .48353 .567 .49334 .56504 .48788 .5578 Mtetra
.546 .649 .903 r
.48788 .5578 .49334 .56504 .50319 .56331 .49773 .55749 Mtetra
.458 .662 .95 r
.49773 .55749 .50319 .56331 .51309 .56122 .50763 .55812 Mtetra
.518 .809 .999 r
.50763 .55812 .51309 .56122 .52302 .55703 .51759 .55659 Mtetra
.643 .95 .948 r
.51759 .55659 .52302 .55703 .53298 .55048 .5276 .55175 Mtetra
.643 .967 .849 r
.5276 .55175 .53298 .55048 .54296 .54459 .53762 .54525 Mtetra
.676 .976 .888 r
.53762 .54525 .54296 .54459 .55298 .54145 .54766 .53891 Mtetra
.333 .747 .979 r
.54766 .53891 .55298 .54145 .56311 .54527 .55778 .53878 Mtetra
0 .307 .796 r
.55778 .53878 .56311 .54527 .57342 .55606 .56805 .5458 Mtetra
.1 .311 .787 r
.56805 .5458 .57342 .55606 .58387 .56729 .57844 .55436 Mtetra
.341 .41 .788 r
.57844 .55436 .58387 .56729 .59435 .57468 .58889 .56061 Mtetra
.633 .565 .76 r
.58889 .56061 .59435 .57468 .6047 .57162 .59924 .55753 Mtetra
.761 .63 .715 r
.59924 .55753 .6047 .57162 .6148 .5581 .60938 .54509 Mtetra
.792 .654 .71 r
.60938 .54509 .6148 .5581 .62477 .54068 .61945 .5303 Mtetra
.805 .689 .737 r
.61945 .5303 .62477 .54068 .63469 .52365 .62952 .51701 Mtetra
.742 .749 .857 r
.62952 .51701 .63469 .52365 .64482 .5136 .63982 .51089 Mtetra
.313 .73 .975 r
.63982 .51089 .64482 .5136 .65522 .51055 .65038 .51104 Mtetra
.101 0 0 r
.65038 .51104 .65522 .51055 .66578 .51028 .661 .51136 Mtetra
0 0 0 r
.661 .51136 .66578 .51028 .67642 .51069 .67161 .51001 Mtetra
.606 .941 .944 r
.67161 .51001 .67642 .51069 .68701 .50872 .68211 .5053 Mtetra
.785 .881 .916 r
.68211 .5053 .68701 .50872 .69754 .50461 .69254 .49839 Mtetra
.742 .768 .874 r
.69254 .49839 .69754 .50461 .70808 .50014 .70303 .49242 Mtetra
.692 .708 .86 r
.70303 .49242 .70808 .50014 .71866 .49589 .71363 .48793 Mtetra
.64 .681 .873 r
.71363 .48793 .71866 .49589 .72934 .49258 .72436 .48516 Mtetra
.593 .676 .899 r
.72436 .48516 .72934 .49258 .74012 .49012 .73522 .48366 Mtetra
.56 .694 .93 r
.73522 .48366 .74012 .49012 .75098 .48832 .74617 .4827 Mtetra
.543 .72 .955 r
.74617 .4827 .75098 .48832 .76192 .4868 .75717 .48176 Mtetra
.568 .756 .967 r
.75717 .48176 .76192 .4868 .77289 .48501 .76819 .48014 Mtetra
.599 .778 .966 r
.76819 .48014 .77289 .48501 .78388 .48284 .77921 .47785 Mtetra
.634 .787 .955 r
.77921 .47785 .78388 .48284 .79489 .48017 .79022 .47488 Mtetra
.657 .784 .942 r
.79022 .47488 .79489 .48017 .8059 .4771 .80123 .47142 Mtetra
.668 .774 .929 r
.80123 .47142 .8059 .4771 .81693 .47372 .81227 .46773 Mtetra
.673 .765 .92 r
.81227 .46773 .81693 .47372 .82799 .47015 .82334 .4639 Mtetra
.672 .756 .914 r
.82334 .4639 .82799 .47015 .83908 .4665 .83445 .46008 Mtetra
.67 .75 .91 r
.83445 .46008 .83908 .4665 .85021 .46281 .8456 .4563 Mtetra
.667 .746 .91 r
.8456 .4563 .85021 .46281 .86139 .45915 .85681 .45261 Mtetra
.664 .745 .911 r
.85681 .45261 .86139 .45915 .87261 .45552 .86806 .44898 Mtetra
.661 .745 .912 r
.86806 .44898 .87261 .45552 .88388 .45193 .87937 .44542 Mtetra
.659 .746 .914 r
.87937 .44542 .88388 .45193 .89519 .44837 .89072 .4419 Mtetra
.658 .748 .916 r
.89072 .4419 .89519 .44837 .90655 .44483 .90212 .4384 Mtetra
.657 .75 .918 r
.90212 .4384 .90655 .44483 .91796 .44128 .91357 .43489 Mtetra
.657 .752 .92 r
.3005 .61354 .30643 .61871 .31567 .61595 .30977 .61069 Mtetra
.657 .749 .918 r
.30977 .61069 .31567 .61595 .32495 .61319 .31907 .60783 Mtetra
.656 .746 .916 r
.31907 .60783 .32495 .61319 .33426 .61045 .3284 .60498 Mtetra
.655 .742 .914 r
.3284 .60498 .33426 .61045 .34359 .60774 .33776 .60218 Mtetra
.652 .739 .913 r
.33776 .60218 .34359 .60774 .35296 .60511 .34715 .59943 Mtetra
.648 .734 .912 r
.34715 .59943 .35296 .60511 .36236 .60254 .35657 .59678 Mtetra
.642 .73 .913 r
.35657 .59678 .36236 .60254 .37179 .60006 .36602 .59425 Mtetra
.637 .727 .914 r
.36602 .59425 .37179 .60006 .38125 .59762 .3755 .59183 Mtetra
.63 .727 .917 r
.3755 .59183 .38125 .59762 .39074 .59519 .38501 .58955 Mtetra
.629 .733 .922 r
.38501 .58955 .39074 .59519 .40028 .59264 .39455 .58728 Mtetra
.63 .744 .93 r
.39455 .58728 .40028 .59264 .40986 .58986 .40414 .58494 Mtetra
.647 .767 .936 r
.40414 .58494 .40986 .58986 .41949 .58662 .41377 .58217 Mtetra
.675 .794 .938 r
.41377 .58217 .41949 .58662 .42917 .58271 .42346 .57871 Mtetra
.711 .819 .932 r
.42346 .57871 .42917 .58271 .4389 .57815 .43321 .57433 Mtetra
.749 .832 .915 r
.43321 .57433 .4389 .57815 .44866 .57292 .44302 .56887 Mtetra
.762 .824 .901 r
.44302 .56887 .44866 .57292 .45845 .56771 .45285 .56293 Mtetra
.756 .797 .886 r
.45285 .56293 .45845 .56771 .46825 .56302 .4627 .55701 Mtetra
.713 .748 .88 r
.4627 .55701 .46825 .56302 .47806 .55956 .47255 .55234 Mtetra
.639 .689 .88 r
.47255 .55234 .47806 .55956 .48788 .5578 .48239 .54981 Mtetra
.525 .618 .887 r
.48239 .54981 .48788 .5578 .49773 .55749 .49225 .55009 Mtetra
.343 .545 .905 r
.49225 .55009 .49773 .55749 .50763 .55812 .50215 .55305 Mtetra
.339 .636 .962 r
.50215 .55305 .50763 .55812 .51759 .55659 .51212 .55465 Mtetra
.471 .84 .991 r
.51212 .55465 .51759 .55659 .5276 .55175 .52216 .55282 Mtetra
.633 .964 .864 r
.52216 .55282 .5276 .55175 .53762 .54525 .53223 .54663 Mtetra
.816 1 .831 r
.53223 .54663 .53762 .54525 .54766 .53891 .54231 .53702 Mtetra
.731 .923 .956 r
.54231 .53702 .54766 .53891 .55778 .53878 .55242 .53154 Mtetra
.49 .628 .913 r
.55242 .53154 .55778 .53878 .56805 .5458 .56261 .53222 Mtetra
.461 .472 .783 r
.56261 .53222 .56805 .5458 .57844 .55436 .57291 .53562 Mtetra
.497 .441 .724 r
.57291 .53562 .57844 .55436 .58889 .56061 .58329 .53907 Mtetra
.614 .497 .696 r
.58329 .53907 .58889 .56061 .59924 .55753 .59361 .53595 Mtetra
.689 .543 .683 r
.59361 .53595 .59924 .55753 .60938 .54509 .60381 .52625 Mtetra
.702 .564 .697 r
.60381 .52625 .60938 .54509 .61945 .5303 .61402 .51657 Mtetra
.699 .603 .746 r
.61402 .51657 .61945 .5303 .62952 .51701 .6243 .50961 Mtetra
.564 .661 .902 r
.6243 .50961 .62952 .51701 .63982 .51089 .6348 .50884 Mtetra
0 .412 .734 r
.6348 .50884 .63982 .51089 .65038 .51104 .64551 .51226 Mtetra
.141 0 0 r
.64551 .51226 .65038 .51104 .661 .51136 .65616 .51223 Mtetra
.425 .868 .812 r
.65616 .51223 .661 .51136 .67161 .51001 .66669 .5078 Mtetra
.814 .93 .909 r
.66669 .5078 .67161 .51001 .68211 .5053 .67709 .49988 Mtetra
.82 .808 .839 r
.67709 .49988 .68211 .5053 .69254 .49839 .68743 .49056 Mtetra
.742 .723 .834 r
.68743 .49056 .69254 .49839 .70303 .49242 .69791 .48395 Mtetra
.668 .68 .852 r
.69791 .48395 .70303 .49242 .71363 .48793 .70857 .48018 Mtetra
.597 .669 .89 r
.70857 .48018 .71363 .48793 .72436 .48516 .7194 .47861 Mtetra
.526 .676 .933 r
.7194 .47861 .72436 .48516 .73522 .48366 .73036 .47833 Mtetra
.495 .71 .967 r
.73036 .47833 .73522 .48366 .74617 .4827 .74138 .47806 Mtetra
.501 .745 .982 r
.74138 .47806 .74617 .4827 .75717 .48176 .75244 .47733 Mtetra
.564 .784 .981 r
.75244 .47733 .75717 .48176 .76819 .48014 .76347 .47548 Mtetra
.62 .796 .967 r
.76347 .47548 .76819 .48014 .77921 .47785 .77448 .47269 Mtetra
.658 .79 .945 r
.77448 .47269 .77921 .47785 .79022 .47488 .78549 .46918 Mtetra
.677 .777 .926 r
.78549 .46918 .79022 .47488 .80123 .47142 .7965 .46523 Mtetra
.679 .76 .912 r
.7965 .46523 .80123 .47142 .81227 .46773 .80754 .4612 Mtetra
.678 .749 .905 r
.80754 .4612 .81227 .46773 .82334 .4639 .81862 .45718 Mtetra
.673 .742 .902 r
.81862 .45718 .82334 .4639 .83445 .46008 .82975 .45329 Mtetra
.669 .738 .902 r
.82975 .45329 .83445 .46008 .8456 .4563 .84094 .44951 Mtetra
.664 .737 .905 r
.84094 .44951 .8456 .4563 .85681 .45261 .85218 .44587 Mtetra
.661 .738 .908 r
.85218 .44587 .85681 .45261 .86806 .44898 .86348 .44231 Mtetra
.658 .74 .911 r
.86348 .44231 .86806 .44898 .87937 .44542 .87482 .43882 Mtetra
.656 .743 .914 r
.87482 .43882 .87937 .44542 .89072 .4419 .88622 .43536 Mtetra
.655 .745 .916 r
.88622 .43536 .89072 .4419 .90212 .4384 .89766 .43191 Mtetra
.655 .748 .919 r
.89766 .43191 .90212 .4384 .91357 .43489 .90915 .42846 Mtetra
.66 .752 .919 r
.29453 .60833 .3005 .61354 .30977 .61069 .30382 .6054 Mtetra
.661 .75 .917 r
.30382 .6054 .30977 .61069 .31907 .60783 .31315 .60244 Mtetra
.66 .747 .914 r
.31315 .60244 .31907 .60783 .3284 .60498 .3225 .59948 Mtetra
.659 .744 .912 r
.3225 .59948 .3284 .60498 .33776 .60218 .33189 .59654 Mtetra
.658 .739 .91 r
.33189 .59654 .33776 .60218 .34715 .59943 .34131 .59362 Mtetra
.654 .733 .907 r
.34131 .59362 .34715 .59943 .35657 .59678 .35076 .59079 Mtetra
.649 .726 .905 r
.35076 .59079 .35657 .59678 .36602 .59425 .36023 .58808 Mtetra
.641 .718 .903 r
.36023 .58808 .36602 .59425 .3755 .59183 .36973 .58555 Mtetra
.631 .711 .904 r
.36973 .58555 .3755 .59183 .38501 .58955 .37926 .58328 Mtetra
.622 .709 .908 r
.37926 .58328 .38501 .58955 .39455 .58728 .38881 .5812 Mtetra
.611 .713 .917 r
.38881 .5812 .39455 .58728 .40414 .58494 .3984 .57932 Mtetra
.618 .733 .928 r
.3984 .57932 .40414 .58494 .41377 .58217 .40803 .57723 Mtetra
.638 .766 .94 r
.40803 .57723 .41377 .58217 .42346 .57871 .41772 .57461 Mtetra
.68 .811 .945 r
.41772 .57461 .42346 .57871 .43321 .57433 .42747 .57096 Mtetra
.736 .851 .934 r
.42747 .57096 .43321 .57433 .44302 .56887 .4373 .56588 Mtetra
.776 .869 .917 r
.4373 .56588 .44302 .56887 .45285 .56293 .44717 .55962 Mtetra
.799 .855 .892 r
.44717 .55962 .45285 .56293 .4627 .55701 .45708 .55241 Mtetra
.771 .807 .882 r
.45708 .55241 .4627 .55701 .47255 .55234 .46699 .54595 Mtetra
.704 .736 .876 r
.46699 .54595 .47255 .55234 .48239 .54981 .47688 .54147 Mtetra
.56 .626 .874 r
.47688 .54147 .48239 .54981 .49225 .55009 .48676 .54102 Mtetra
.318 .479 .862 r
.48676 .54102 .49225 .55009 .50215 .55305 .49665 .54525 Mtetra
.215 .458 .876 r
.49665 .54525 .50215 .55305 .51212 .55465 .50661 .55002 Mtetra
.199 .578 .941 r
.50661 .55002 .51212 .55465 .52216 .55282 .51667 .55261 Mtetra
.584 .936 .937 r
.51667 .55261 .52216 .55282 .53223 .54663 .52679 .54819 Mtetra
.885 .99 .795 r
.52679 .54819 .53223 .54663 .54231 .53702 .53691 .53609 Mtetra
.896 .934 .833 r
.53691 .53609 .54231 .53702 .55242 .53154 .54702 .52452 Mtetra
.776 .742 .822 r
.54702 .52452 .55242 .53154 .56261 .53222 .55715 .51655 Mtetra
.645 .554 .737 r
.55715 .51655 .56261 .53222 .57291 .53562 .56733 .5124 Mtetra
.583 .468 .688 r
.56733 .5124 .57291 .53562 .58329 .53907 .5776 .51131 Mtetra
.603 .464 .665 r
.5776 .51131 .58329 .53907 .59361 .53595 .58788 .50815 Mtetra
.625 .479 .663 r
.58788 .50815 .59361 .53595 .60381 .52625 .59815 .50291 Mtetra
.597 .477 .687 r
.59815 .50291 .60381 .52625 .61402 .51657 .60852 .50075 Mtetra
.526 .485 .754 r
.60852 .50075 .61402 .51657 .6243 .50961 .61905 .50244 Mtetra
.159 .445 .877 r
.61905 .50244 .6243 .50961 .6348 .50884 .62976 .50777 Mtetra
.485 0 0 r
.62976 .50777 .6348 .50884 .64551 .51226 .64059 .51365 Mtetra
0 0 0 r
.64059 .51365 .64551 .51226 .65616 .51223 .65122 .51181 Mtetra
.822 .984 .881 r
.65122 .51181 .65616 .51223 .66669 .5078 .66161 .50287 Mtetra
.854 .824 .818 r
.66161 .50287 .66669 .5078 .67709 .49988 .6719 .49168 Mtetra
.804 .733 .785 r
.6719 .49168 .67709 .49988 .68743 .49056 .68221 .48102 Mtetra
.712 .675 .812 r
.68221 .48102 .68743 .49056 .69791 .48395 .69275 .4751 Mtetra
.608 .645 .862 r
.69275 .4751 .69791 .48395 .70857 .48018 .70354 .47328 Mtetra
.505 .654 .926 r
.70354 .47328 .70857 .48018 .7194 .47861 .71449 .4735 Mtetra
.397 .671 .97 r
.71449 .4735 .7194 .47861 .73036 .47833 .72556 .47448 Mtetra
.403 .733 .991 r
.72556 .47448 .73036 .47833 .74138 .47806 .73663 .47452 Mtetra
.482 .788 .998 r
.73663 .47452 .74138 .47806 .75244 .47733 .74769 .47335 Mtetra
.597 .819 .985 r
.74769 .47335 .75244 .47733 .76347 .47548 .7587 .47071 Mtetra
.663 .809 .953 r
.7587 .47071 .76347 .47548 .77448 .47269 .76969 .46701 Mtetra
.687 .782 .923 r
.76969 .46701 .77448 .47269 .78549 .46918 .78067 .46276 Mtetra
.694 .758 .902 r
.78067 .46276 .78549 .46918 .7965 .46523 .79166 .45828 Mtetra
.685 .739 .892 r
.79166 .45828 .7965 .46523 .80754 .4612 .80272 .45401 Mtetra
.678 .729 .888 r
.80272 .45401 .80754 .4612 .81862 .45718 .81382 .44993 Mtetra
.669 .725 .891 r
.81382 .44993 .81862 .45718 .82975 .45329 .825 .44611 Mtetra
.663 .725 .895 r
.825 .44611 .82975 .45329 .84094 .44951 .83623 .44248 Mtetra
.658 .729 .901 r
.83623 .44248 .84094 .44951 .85218 .44587 .84751 .43898 Mtetra
.655 .733 .907 r
.84751 .43898 .85218 .44587 .86348 .44231 .85885 .43556 Mtetra
.653 .737 .911 r
.85885 .43556 .86348 .44231 .87482 .43882 .87024 .43216 Mtetra
.652 .741 .915 r
.87024 .43216 .87482 .43882 .88622 .43536 .88168 .42878 Mtetra
.652 .745 .918 r
.88168 .42878 .88622 .43536 .89766 .43191 .89317 .42539 Mtetra
.652 .748 .92 r
.89317 .42539 .89766 .43191 .90915 .42846 .90469 .42197 Mtetra
.661 .753 .918 r
.28853 .60308 .29453 .60833 .30382 .6054 .29784 .60012 Mtetra
.662 .752 .917 r
.29784 .60012 .30382 .6054 .31315 .60244 .30718 .59711 Mtetra
.663 .751 .916 r
.30718 .59711 .31315 .60244 .3225 .59948 .31656 .59408 Mtetra
.663 .749 .914 r
.31656 .59408 .3225 .59948 .33189 .59654 .32598 .59101 Mtetra
.664 .746 .911 r
.32598 .59101 .33189 .59654 .34131 .59362 .33542 .58792 Mtetra
.663 .74 .908 r
.33542 .58792 .34131 .59362 .35076 .59079 .3449 .58486 Mtetra
.66 .732 .903 r
.3449 .58486 .35076 .59079 .36023 .58808 .35441 .58187 Mtetra
.652 .721 .899 r
.35441 .58187 .36023 .58808 .36973 .58555 .36394 .57906 Mtetra
.64 .709 .897 r
.36394 .57906 .36973 .58555 .37926 .58328 .37349 .57655 Mtetra
.625 .697 .896 r
.37349 .57655 .37926 .58328 .38881 .5812 .38306 .5744 Mtetra
.605 .688 .901 r
.38306 .5744 .38881 .5812 .3984 .57932 .39265 .57273 Mtetra
.598 .693 .909 r
.39265 .57273 .3984 .57932 .40803 .57723 .40228 .57118 Mtetra
.598 .712 .924 r
.40228 .57118 .40803 .57723 .41772 .57461 .41196 .56954 Mtetra
.63 .761 .941 r
.41196 .56954 .41772 .57461 .42747 .57096 .4217 .56707 Mtetra
.687 .823 .948 r
.4217 .56707 .42747 .57096 .4373 .56588 .43152 .5632 Mtetra
.755 .883 .937 r
.43152 .5632 .4373 .56588 .44717 .55962 .44142 .55752 Mtetra
.818 .903 .9 r
.44142 .55752 .44717 .55962 .45708 .55241 .45138 .5498 Mtetra
.825 .882 .886 r
.45138 .5498 .45708 .55241 .46699 .54595 .46135 .54169 Mtetra
.79 .823 .877 r
.46135 .54169 .46699 .54595 .47688 .54147 .47132 .53451 Mtetra
.649 .703 .886 r
.47132 .53451 .47688 .54147 .48676 .54102 .48124 .53167 Mtetra
.397 .517 .862 r
.48124 .53167 .48676 .54102 .49665 .54525 .49114 .53473 Mtetra
.225 .387 .816 r
.49114 .53473 .49665 .54525 .50661 .55002 .50109 .54119 Mtetra
.068 .333 .811 r
.50109 .54119 .50661 .55002 .51667 .55261 .51113 .54846 Mtetra
.489 .755 .989 r
.51113 .54846 .51667 .55261 .52679 .54819 .52128 .54774 Mtetra
.893 .949 .835 r
.52128 .54774 .52679 .54819 .53691 .53609 .53146 .53628 Mtetra
.94 .929 .765 r
.53146 .53628 .53691 .53609 .54702 .52452 .5416 .52079 Mtetra
.906 .826 .757 r
.5416 .52079 .54702 .52452 .55715 .51655 .55171 .50481 Mtetra
.777 .66 .734 r
.55171 .50481 .55715 .51655 .56733 .5124 .56182 .49292 Mtetra
.66 .535 .701 r
.56182 .49292 .56733 .5124 .5776 .51131 .57199 .48666 Mtetra
.608 .478 .678 r
.57199 .48666 .5776 .51131 .58788 .50815 .58223 .48346 Mtetra
.568 .452 .681 r
.58223 .48346 .58788 .50815 .59815 .50291 .59258 .48333 Mtetra
.45 .405 .716 r
.59258 .48333 .59815 .50291 .60852 .50075 .60312 .48888 Mtetra
.121 .291 .763 r
.60312 .48888 .60852 .50075 .61905 .50244 .61386 .49857 Mtetra
.507 0 0 r
.61386 .49857 .61905 .50244 .62976 .50777 .62471 .5078 Mtetra
.504 0 0 r
.62471 .5078 .62976 .50777 .64059 .51365 .63555 .51302 Mtetra
.669 .96 .939 r
.63555 .51302 .64059 .51365 .65122 .51181 .64608 .5074 Mtetra
.889 .835 .787 r
.64608 .5074 .65122 .51181 .66161 .50287 .65632 .49366 Mtetra
.818 .717 .754 r
.65632 .49366 .66161 .50287 .6719 .49168 .66657 .48072 Mtetra
.759 .67 .764 r
.66657 .48072 .6719 .49168 .68221 .48102 .67695 .47119 Mtetra
.655 .645 .828 r
.67695 .47119 .68221 .48102 .69275 .4751 .68763 .46766 Mtetra
.478 .623 .914 r
.68763 .46766 .69275 .4751 .70354 .47328 .69858 .46855 Mtetra
.3 .635 .964 r
.69858 .46855 .70354 .47328 .71449 .4735 .70966 .47041 Mtetra
.198 .647 .946 r
.70966 .47041 .71449 .4735 .72556 .47448 .72079 .47189 Mtetra
.366 .77 .983 r
.72079 .47189 .72556 .47448 .73663 .47452 .73186 .47129 Mtetra
.559 .838 .997 r
.73186 .47129 .73663 .47452 .74769 .47335 .74288 .46884 Mtetra
.669 .822 .957 r
.74288 .46884 .74769 .47335 .7587 .47071 .75384 .46494 Mtetra
.705 .785 .914 r
.75384 .46494 .7587 .47071 .76969 .46701 .76477 .46019 Mtetra
.703 .749 .887 r
.76477 .46019 .76969 .46701 .78067 .46276 .77574 .45533 Mtetra
.696 .729 .875 r
.77574 .45533 .78067 .46276 .79166 .45828 .78675 .45059 Mtetra
.681 .716 .875 r
.78675 .45059 .79166 .45828 .80272 .45401 .79783 .44634 Mtetra
.67 .713 .88 r
.79783 .44634 .80272 .45401 .81382 .44993 .80898 .44246 Mtetra
.66 .715 .889 r
.80898 .44246 .81382 .44993 .825 .44611 .82021 .43889 Mtetra
.654 .721 .898 r
.82021 .43889 .825 .44611 .83623 .44248 .83149 .43551 Mtetra
.651 .729 .906 r
.83149 .43551 .83623 .44248 .84751 .43898 .84283 .4322 Mtetra
.649 .735 .912 r
.84283 .4322 .84751 .43898 .85885 .43556 .85422 .42891 Mtetra
.65 .741 .916 r
.85422 .42891 .85885 .43556 .87024 .43216 .86565 .42559 Mtetra
.65 .745 .919 r
.86565 .42559 .87024 .43216 .88168 .42878 .87712 .42225 Mtetra
.65 .747 .92 r
.87712 .42225 .88168 .42878 .89317 .42539 .88864 .41887 Mtetra
.652 .749 .921 r
.88864 .41887 .89317 .42539 .90469 .42197 .90021 .41544 Mtetra
.659 .752 .919 r
.28248 .59781 .28853 .60308 .29784 .60012 .29181 .59487 Mtetra
.66 .754 .92 r
.29181 .59487 .29784 .60012 .30718 .59711 .30117 .59188 Mtetra
.662 .756 .92 r
.30117 .59188 .30718 .59711 .31656 .59408 .31057 .58884 Mtetra
.665 .757 .919 r
.31057 .58884 .31656 .59408 .32598 .59101 .32001 .58572 Mtetra
.669 .757 .916 r
.32001 .58572 .32598 .59101 .33542 .58792 .32948 .5825 Mtetra
.671 .753 .912 r
.32948 .5825 .33542 .58792 .3449 .58486 .33899 .57921 Mtetra
.672 .746 .906 r
.33899 .57921 .3449 .58486 .35441 .58187 .34853 .57586 Mtetra
.668 .733 .899 r
.34853 .57586 .35441 .58187 .36394 .57906 .3581 .57262 Mtetra
.659 .717 .892 r
.3581 .57262 .36394 .57906 .37349 .57655 .3677 .56959 Mtetra
.642 .696 .885 r
.3677 .56959 .37349 .57655 .38306 .5744 .3773 .56701 Mtetra
.616 .675 .883 r
.3773 .56701 .38306 .5744 .39265 .57273 .38692 .5651 Mtetra
.593 .66 .884 r
.38692 .5651 .39265 .57273 .40228 .57118 .39655 .56375 Mtetra
.567 .655 .896 r
.39655 .56375 .40228 .57118 .41196 .56954 .40621 .56297 Mtetra
.569 .685 .918 r
.40621 .56297 .41196 .56954 .4217 .56707 .41593 .56196 Mtetra
.595 .75 .951 r
.41593 .56196 .4217 .56707 .43152 .5632 .42571 .56014 Mtetra
.682 .86 .967 r
.42571 .56014 .43152 .5632 .44142 .55752 .4356 .55618 Mtetra
.792 .936 .925 r
.4356 .55618 .44142 .55752 .45138 .5498 .44558 .54922 Mtetra
.847 .953 .883 r
.44558 .54922 .45138 .5498 .46135 .54169 .45562 .54023 Mtetra
.869 .915 .858 r
.45562 .54023 .46135 .54169 .47132 .53451 .46568 .53013 Mtetra
.781 .82 .883 r
.46568 .53013 .47132 .53451 .48124 .53167 .47569 .52328 Mtetra
.585 .639 .871 r
.47569 .52328 .48124 .53167 .49114 .53473 .48564 .52217 Mtetra
.34 .416 .794 r
.48564 .52217 .49114 .53473 .50109 .54119 .49559 .52778 Mtetra
.066 .226 .72 r
.49559 .52778 .50109 .54119 .51113 .54846 .50559 .53884 Mtetra
.306 .462 .852 r
.50559 .53884 .51113 .54846 .52128 .54774 .51573 .54351 Mtetra
.774 .833 .898 r
.51573 .54351 .52128 .54774 .53146 .53628 .52595 .53693 Mtetra
.939 .943 .765 r
.52595 .53693 .53146 .53628 .5416 .52079 .53616 .5216 Mtetra
.97 .896 .695 r
.53616 .5216 .5416 .52079 .55171 .50481 .5463 .50045 Mtetra
.91 .807 .732 r
.5463 .50045 .55171 .50481 .56182 .49292 .55639 .48237 Mtetra
.781 .678 .75 r
.55639 .48237 .56182 .49292 .57199 .48666 .56652 .47126 Mtetra
.629 .548 .744 r
.56652 .47126 .57199 .48666 .58223 .48346 .57676 .46803 Mtetra
.434 .433 .759 r
.57676 .46803 .58223 .48346 .59258 .48333 .58719 .47271 Mtetra
0 .168 .704 r
.58719 .47271 .59258 .48333 .60312 .48888 .59786 .48441 Mtetra
.732 .235 0 r
.59786 .48441 .60312 .48888 .61386 .49857 .60874 .49926 Mtetra
.692 .161 0 r
.60874 .49926 .61386 .49857 .62471 .5078 .61962 .50831 Mtetra
.091 0 0 r
.61962 .50831 .62471 .5078 .63555 .51302 .63033 .50857 Mtetra
.858 .839 .826 r
.63033 .50857 .63555 .51302 .64608 .5074 .64071 .49744 Mtetra
.848 .713 .714 r
.64071 .49744 .64608 .5074 .65632 .49366 .65084 .47982 Mtetra
.763 .637 .722 r
.65084 .47982 .65632 .49366 .66657 .48072 .66113 .46768 Mtetra
.676 .604 .767 r
.66113 .46768 .66657 .48072 .67695 .47119 .67172 .46234 Mtetra
.518 .603 .878 r
.67172 .46234 .67695 .47119 .68763 .46766 .68261 .46284 Mtetra
.117 .516 .911 r
.68261 .46284 .68763 .46766 .69858 .46855 .69374 .46667 Mtetra
0 .48 .777 r
.69374 .46667 .69858 .46855 .70966 .47041 .7049 .4694 Mtetra
.048 .607 .807 r
.7049 .4694 .70966 .47041 .72079 .47189 .71602 .47006 Mtetra
.471 .856 .98 r
.71602 .47006 .72079 .47189 .73186 .47129 .72703 .46766 Mtetra
.69 .867 .965 r
.72703 .46766 .73186 .47129 .74288 .46884 .73794 .46306 Mtetra
.726 .791 .904 r
.73794 .46306 .74288 .46884 .75384 .46494 .74883 .45761 Mtetra
.723 .741 .866 r
.74883 .45761 .75384 .46494 .76477 .46019 .75973 .45193 Mtetra
.701 .709 .853 r
.75973 .45193 .76477 .46019 .77574 .45533 .7707 .44681 Mtetra
.685 .696 .855 r
.7707 .44681 .77574 .45533 .78675 .45059 .78175 .44227 Mtetra
.666 .694 .866 r
.78175 .44227 .78675 .45059 .79783 .44634 .79289 .43842 Mtetra
.653 .7 .881 r
.79289 .43842 .79783 .44634 .80898 .44246 .80412 .43503 Mtetra
.646 .712 .896 r
.80412 .43503 .80898 .44246 .82021 .43889 .81541 .43187 Mtetra
.641 .724 .908 r
.81541 .43187 .82021 .43889 .83149 .43551 .82675 .42881 Mtetra
.643 .736 .917 r
.82675 .42881 .83149 .43551 .84283 .4322 .83814 .42569 Mtetra
.644 .744 .922 r
.83814 .42569 .84283 .4322 .85422 .42891 .84957 .4225 Mtetra
.647 .75 .924 r
.84957 .4225 .85422 .42891 .86565 .42559 .86104 .41919 Mtetra
.65 .752 .925 r
.86104 .41919 .86565 .42559 .87712 .42225 .87255 .41581 Mtetra
.652 .753 .924 r
.87255 .41581 .87712 .42225 .88864 .41887 .8841 .41236 Mtetra
.653 .752 .922 r
.8841 .41236 .88864 .41887 .90021 .41544 .89569 .40886 Mtetra
.654 .751 .921 r
.27639 .59249 .28248 .59781 .29181 .59487 .28573 .58964 Mtetra
.655 .755 .923 r
.28573 .58964 .29181 .59487 .30117 .59188 .29511 .58674 Mtetra
.657 .76 .925 r
.29511 .58674 .30117 .59188 .31057 .58884 .30452 .58378 Mtetra
.661 .764 .926 r
.30452 .58378 .31057 .58884 .32001 .58572 .31398 .58071 Mtetra
.667 .768 .925 r
.31398 .58071 .32001 .58572 .32948 .5825 .32347 .57749 Mtetra
.673 .77 .923 r
.32347 .57749 .32948 .5825 .33899 .57921 .33301 .57411 Mtetra
.681 .769 .918 r
.33301 .57411 .33899 .57921 .34853 .57586 .34259 .57052 Mtetra
.683 .762 .911 r
.34259 .57052 .34853 .57586 .3581 .57262 .3522 .56688 Mtetra
.682 .748 .901 r
.3522 .56688 .3581 .57262 .3677 .56959 .36184 .56323 Mtetra
.668 .725 .892 r
.36184 .56323 .3677 .56959 .3773 .56701 .3715 .55992 Mtetra
.645 .695 .882 r
.3715 .55992 .3773 .56701 .38692 .5651 .38116 .55721 Mtetra
.613 .661 .873 r
.38116 .55721 .38692 .5651 .39655 .56375 .39083 .55536 Mtetra
.57 .63 .872 r
.39083 .55536 .39655 .56375 .40621 .56297 .4005 .55463 Mtetra
.54 .619 .879 r
.4005 .55463 .40621 .56297 .41593 .56196 .41019 .55453 Mtetra
.514 .635 .907 r
.41019 .55453 .41593 .56196 .42571 .56014 .41992 .55474 Mtetra
.576 .734 .95 r
.41992 .55474 .42571 .56014 .4356 .55618 .42976 .55328 Mtetra
.702 .872 .962 r
.42976 .55328 .4356 .55618 .44558 .54922 .43972 .54883 Mtetra
.808 .967 .907 r
.43972 .54883 .44558 .54922 .45562 .54023 .44978 .54101 Mtetra
.884 .976 .833 r
.44978 .54101 .45562 .54023 .46568 .53013 .45992 .52986 Mtetra
.88 .953 .851 r
.45992 .52986 .46568 .53013 .47569 .52328 .47003 .51927 Mtetra
.795 .836 .883 r
.47003 .51927 .47569 .52328 .48564 .52217 .48009 .51196 Mtetra
.505 .558 .843 r
.48009 .51196 .48564 .52217 .49559 .52778 .49008 .51306 Mtetra
.161 .268 .727 r
.49008 .51306 .49559 .52778 .50559 .53884 .50006 .52342 Mtetra
.272 .332 .742 r
.50006 .52342 .50559 .53884 .51573 .54351 .51017 .53201 Mtetra
.507 .535 .82 r
.51017 .53201 .51573 .54351 .52595 .53693 .52039 .53337 Mtetra
.838 .859 .86 r
.52039 .53337 .52595 .53693 .53616 .5216 .53067 .5241 Mtetra
.96 .943 .695 r
.53067 .5241 .53616 .5216 .5463 .50045 .54089 .50507 Mtetra
.918 .96 .638 r
.54089 .50507 .5463 .50045 .55639 .48237 .55107 .48664 Mtetra
.773 .96 .648 r
.55107 .48664 .55639 .48237 .56652 .47126 .56124 .47374 Mtetra
0 0 0 r
.56124 .47374 .56652 .47126 .57676 .46803 .57153 .4705 Mtetra
.634 .117 0 r
.57153 .4705 .57676 .46803 .58719 .47271 .58203 .47694 Mtetra
.754 .307 .191 r
.58203 .47694 .58719 .47271 .59786 .48441 .59274 .48897 Mtetra
.759 .318 .204 r
.59274 .48897 .59786 .48441 .60874 .49926 .60361 .50166 Mtetra
.461 0 0 r
.60361 .50166 .60874 .49926 .61962 .50831 .61435 .50457 Mtetra
.806 .869 .895 r
.61435 .50457 .61962 .50831 .63033 .50857 .62486 .49677 Mtetra
.81 .679 .719 r
.62486 .49677 .63033 .50857 .64071 .49744 .63512 .48162 Mtetra
.788 .633 .688 r
.63512 .48162 .64071 .49744 .65084 .47982 .64529 .46465 Mtetra
.699 .592 .733 r
.64529 .46465 .65084 .47982 .66113 .46768 .65578 .45702 Mtetra
.518 .561 .839 r
.65578 .45702 .66113 .46768 .67172 .46234 .66665 .45794 Mtetra
.024 .471 .877 r
.66665 .45794 .67172 .46234 .68261 .46284 .67775 .46221 Mtetra
.416 0 0 r
.67775 .46221 .68261 .46284 .69374 .46667 .68897 .46708 Mtetra
.207 0 0 r
.68897 .46708 .69374 .46667 .7049 .4694 .7001 .46858 Mtetra
.328 .804 .907 r
.7001 .46858 .7049 .4694 .71602 .47006 .71112 .46663 Mtetra
.706 .88 .962 r
.71112 .46663 .71602 .47006 .72703 .46766 .72201 .46162 Mtetra
.759 .792 .879 r
.72201 .46162 .72703 .46766 .73794 .46306 .73282 .45489 Mtetra
.733 .723 .841 r
.73282 .45489 .73794 .46306 .74883 .45761 .74367 .44845 Mtetra
.711 .691 .83 r
.74367 .44845 .74883 .45761 .75973 .45193 .75459 .44266 Mtetra
.683 .678 .839 r
.75459 .44266 .75973 .45193 .7707 .44681 .76562 .43802 Mtetra
.662 .68 .857 r
.76562 .43802 .7707 .44681 .78175 .44227 .77675 .43426 Mtetra
.645 .694 .881 r
.77675 .43426 .78175 .44227 .79289 .43842 .78798 .43112 Mtetra
.632 .711 .903 r
.78798 .43112 .79289 .43842 .80412 .43503 .79928 .42833 Mtetra
.63 .731 .92 r
.79928 .42833 .80412 .43503 .81541 .43187 .81064 .42554 Mtetra
.63 .745 .93 r
.81064 .42554 .81541 .43187 .82675 .42881 .82204 .42268 Mtetra
.637 .756 .934 r
.82204 .42268 .82675 .42881 .83814 .42569 .83347 .41961 Mtetra
.643 .761 .935 r
.83347 .41961 .83814 .42569 .84957 .4225 .84493 .41637 Mtetra
.649 .763 .933 r
.84493 .41637 .84957 .4225 .86104 .41919 .85642 .41297 Mtetra
.653 .762 .93 r
.85642 .41297 .86104 .41919 .87255 .41581 .86795 .40946 Mtetra
.656 .759 .926 r
.86795 .40946 .87255 .41581 .8841 .41236 .87952 .40587 Mtetra
.657 .756 .923 r
.87952 .40587 .8841 .41236 .89569 .40886 .89113 .40224 Mtetra
.648 .75 .923 r
.27027 .58715 .27639 .59249 .28573 .58964 .27962 .58441 Mtetra
.648 .754 .927 r
.27962 .58441 .28573 .58964 .29511 .58674 .289 .58166 Mtetra
.649 .761 .931 r
.289 .58166 .29511 .58674 .30452 .58378 .29843 .57886 Mtetra
.652 .769 .935 r
.29843 .57886 .30452 .58378 .31398 .58071 .30789 .57596 Mtetra
.658 .778 .937 r
.30789 .57596 .31398 .58071 .32347 .57749 .3174 .57291 Mtetra
.667 .787 .938 r
.3174 .57291 .32347 .57749 .33301 .57411 .32695 .56963 Mtetra
.68 .794 .936 r
.32695 .56963 .33301 .57411 .34259 .57052 .33655 .56604 Mtetra
.691 .797 .93 r
.33655 .56604 .34259 .57052 .3522 .56688 .3462 .56216 Mtetra
.703 .791 .919 r
.3462 .56216 .3522 .56688 .36184 .56323 .35589 .55796 Mtetra
.702 .771 .906 r
.35589 .55796 .36184 .56323 .3715 .55992 .36561 .55375 Mtetra
.691 .739 .888 r
.36561 .55375 .3715 .55992 .38116 .55721 .37535 .54975 Mtetra
.659 .691 .869 r
.37535 .54975 .38116 .55721 .39083 .55536 .38509 .5466 Mtetra
.61 .639 .855 r
.38509 .5466 .39083 .55536 .4005 .55463 .3948 .54482 Mtetra
.555 .59 .844 r
.3948 .54482 .4005 .55463 .41019 .55453 .4045 .5446 Mtetra
.481 .551 .851 r
.4045 .5446 .41019 .55453 .41992 .55474 .4142 .54612 Mtetra
.473 .581 .882 r
.4142 .54612 .41992 .55474 .42976 .55328 .42397 .54738 Mtetra
.517 .694 .948 r
.42397 .54738 .42976 .55328 .43972 .54883 .43384 .547 Mtetra
.661 .909 .979 r
.43384 .547 .43972 .54883 .44978 .54101 .44386 .54282 Mtetra
.794 .999 .833 r
.44386 .54282 .44978 .54101 .45992 .52986 .45401 .53357 Mtetra
.84 .99 .726 r
.45401 .53357 .45992 .52986 .47003 .51927 .46423 .52089 Mtetra
.924 .967 .775 r
.46423 .52089 .47003 .51927 .48009 .51196 .47445 .50677 Mtetra
.771 .795 .872 r
.47445 .50677 .48009 .51196 .49008 .51306 .48455 .5 Mtetra
.421 .458 .793 r
.48455 .5 .49008 .51306 .50006 .52342 .49456 .50394 Mtetra
.333 .329 .706 r
.49456 .50394 .50006 .52342 .51017 .53201 .50463 .513 Mtetra
.285 .302 .703 r
.50463 .513 .51017 .53201 .52039 .53337 .51481 .52328 Mtetra
.457 .539 .853 r
.51481 .52328 .52039 .53337 .53067 .5241 .5251 .52539 Mtetra
.751 .994 .846 r
.5251 .52539 .53067 .5241 .54089 .50507 .53544 .51699 Mtetra
0 0 .003 r
.53544 .51699 .54089 .50507 .55107 .48664 .54576 .50562 Mtetra
.265 0 .256 r
.54576 .50562 .55107 .48664 .56124 .47374 .55608 .49529 Mtetra
.465 .154 .353 r
.55608 .49529 .56124 .47374 .57153 .4705 .56648 .49205 Mtetra
.575 .254 .388 r
.56648 .49205 .57153 .4705 .58203 .47694 .57704 .49592 Mtetra
.591 .257 .373 r
.57704 .49592 .58203 .47694 .59274 .48897 .5877 .50086 Mtetra
.536 .152 .261 r
.5877 .50086 .59274 .48897 .60361 .50166 .59839 .50284 Mtetra
.742 .993 .835 r
.59839 .50284 .60361 .50166 .61435 .50457 .60888 .49425 Mtetra
.838 .706 .717 r
.60888 .49425 .61435 .50457 .62486 .49677 .61914 .47737 Mtetra
.753 .592 .678 r
.61914 .47737 .62486 .49677 .63512 .48162 .6294 .46169 Mtetra
.704 .562 .69 r
.6294 .46169 .63512 .48162 .64529 .46465 .63979 .45115 Mtetra
.549 .531 .787 r
.63979 .45115 .64529 .46465 .65578 .45702 .6506 .45146 Mtetra
0 .251 .74 r
.6506 .45146 .65578 .45702 .66665 .45794 .66178 .45926 Mtetra
.591 .033 0 r
.66178 .45926 .66665 .45794 .67775 .46221 .67302 .46563 Mtetra
.479 0 0 r
.67302 .46563 .67775 .46221 .68897 .46708 .68419 .46853 Mtetra
0 0 0 r
.68419 .46853 .68897 .46708 .7001 .46858 .69518 .46627 Mtetra
.739 .932 .952 r
.69518 .46627 .7001 .46858 .71112 .46663 .70601 .46013 Mtetra
.78 .782 .854 r
.70601 .46013 .71112 .46663 .72201 .46162 .71676 .45227 Mtetra
.755 .704 .804 r
.71676 .45227 .72201 .46162 .73282 .45489 .72751 .44414 Mtetra
.71 .66 .799 r
.72751 .44414 .73282 .45489 .74367 .44845 .73839 .43778 Mtetra
.677 .647 .812 r
.73839 .43778 .74367 .44845 .75459 .44266 .74939 .43302 Mtetra
.647 .654 .843 r
.74939 .43302 .75459 .44266 .76562 .43802 .76054 .42967 Mtetra
.622 .675 .88 r
.76054 .42967 .76562 .43802 .77675 .43426 .7718 .4272 Mtetra
.611 .71 .915 r
.7718 .4272 .77675 .43426 .78798 .43112 .78313 .42494 Mtetra
.603 .739 .94 r
.78313 .42494 .78798 .43112 .79928 .42833 .79451 .42268 Mtetra
.612 .764 .952 r
.79451 .42268 .79928 .42833 .81064 .42554 .80592 .42009 Mtetra
.623 .778 .955 r
.80592 .42009 .81064 .42554 .82204 .42268 .81735 .41719 Mtetra
.637 .783 .951 r
.81735 .41719 .82204 .42268 .83347 .41961 .8288 .41397 Mtetra
.648 .782 .945 r
.8288 .41397 .83347 .41961 .84493 .41637 .84028 .41051 Mtetra
.655 .777 .938 r
.84028 .41051 .84493 .41637 .85642 .41297 .85179 .40689 Mtetra
.66 .772 .932 r
.85179 .40689 .85642 .41297 .86795 .40946 .86333 .40316 Mtetra
.662 .765 .927 r
.86333 .40316 .86795 .40946 .87952 .40587 .87492 .39937 Mtetra
.662 .759 .922 r
.87492 .39937 .87952 .40587 .89113 .40224 .88655 .39556 Mtetra
.644 .748 .925 r
.2641 .58177 .27027 .58715 .27962 .58441 .27346 .5791 Mtetra
.642 .751 .928 r
.27346 .5791 .27962 .58441 .289 .58166 .28286 .57646 Mtetra
.641 .756 .932 r
.28286 .57646 .289 .58166 .29843 .57886 .29229 .57382 Mtetra
.642 .763 .936 r
.29229 .57382 .29843 .57886 .30789 .57596 .30176 .57112 Mtetra
.644 .772 .941 r
.30176 .57112 .30789 .57596 .3174 .57291 .31127 .56835 Mtetra
.651 .786 .946 r
.31127 .56835 .3174 .57291 .32695 .56963 .32083 .56538 Mtetra
.663 .802 .949 r
.32083 .56538 .32695 .56963 .33655 .56604 .33044 .56211 Mtetra
.681 .819 .949 r
.33044 .56211 .33655 .56604 .3462 .56216 .3401 .55842 Mtetra
.705 .831 .943 r
.3401 .55842 .3462 .56216 .35589 .55796 .34983 .55415 Mtetra
.721 .831 .933 r
.34983 .55415 .35589 .55796 .36561 .55375 .3596 .54945 Mtetra
.734 .814 .914 r
.3596 .54945 .36561 .55375 .37535 .54975 .36942 .54436 Mtetra
.716 .772 .897 r
.36942 .54436 .37535 .54975 .38509 .5466 .37924 .53965 Mtetra
.679 .714 .875 r
.37924 .53965 .38509 .5466 .3948 .54482 .38905 .5359 Mtetra
.613 .638 .852 r
.38905 .5359 .3948 .54482 .4045 .5446 .39882 .53399 Mtetra
.524 .559 .833 r
.39882 .53399 .4045 .5446 .4142 .54612 .40855 .53464 Mtetra
.468 .513 .821 r
.40855 .53464 .4142 .54612 .42397 .54738 .41828 .53683 Mtetra
.417 .504 .841 r
.41828 .53683 .42397 .54738 .43384 .547 .42806 .53978 Mtetra
.486 .634 .919 r
.42806 .53978 .43384 .547 .44386 .54282 .43798 .54032 Mtetra
.669 .886 .978 r
.43798 .54032 .44386 .54282 .45401 .53357 .44806 .53626 Mtetra
.786 .995 .784 r
.44806 .53626 .45401 .53357 .46423 .52089 .45829 .52612 Mtetra
.868 .97 .65 r
.45829 .52612 .46423 .52089 .47445 .50677 .46861 .51017 Mtetra
.866 .991 .732 r
.46861 .51017 .47445 .50677 .48455 .5 .47886 .49689 Mtetra
.769 .877 .926 r
.47886 .49689 .48455 .5 .49456 .50394 .48901 .49066 Mtetra
.463 .481 .791 r
.48901 .49066 .49456 .50394 .50463 .513 .4991 .49354 Mtetra
.248 .274 .692 r
.4991 .49354 .50463 .513 .51481 .52328 .50923 .50497 Mtetra
.29 .313 .713 r
.50923 .50497 .51481 .52328 .5251 .52539 .5195 .51466 Mtetra
.376 .481 .839 r
.5195 .51466 .5251 .52539 .53544 .51699 .52987 .51861 Mtetra
.099 0 0 r
.52987 .51861 .53544 .51699 .54576 .50562 .5403 .51795 Mtetra
.344 0 .181 r
.5403 .51795 .54576 .50562 .55608 .49529 .55076 .51364 Mtetra
.445 .117 .314 r
.55076 .51364 .55608 .49529 .56648 .49205 .56127 .5104 Mtetra
.468 .138 .322 r
.56127 .5104 .56648 .49205 .57704 .49592 .57183 .50823 Mtetra
.286 0 .156 r
.57183 .50823 .57704 .49592 .5877 .50086 .58238 .5024 Mtetra
.812 1 .805 r
.58238 .5024 .5877 .50086 .59839 .50284 .59285 .49193 Mtetra
.828 .695 .718 r
.59285 .49193 .59839 .50284 .60888 .49425 .60319 .47562 Mtetra
.775 .609 .673 r
.60319 .47562 .60888 .49425 .61914 .47737 .61343 .45753 Mtetra
.694 .556 .694 r
.61343 .45753 .61914 .47737 .6294 .46169 .62387 .44803 Mtetra
.564 .537 .783 r
.62387 .44803 .6294 .46169 .63979 .45115 .63462 .44774 Mtetra
0 .199 .622 r
.63462 .44774 .63979 .45115 .6506 .45146 .6457 .45462 Mtetra
.705 .213 .073 r
.6457 .45462 .6506 .45146 .66178 .45926 .657 .46425 Mtetra
.544 .05 .034 r
.657 .46425 .66178 .45926 .67302 .46563 .66817 .46801 Mtetra
0 0 0 r
.66817 .46801 .67302 .46563 .68419 .46853 .67915 .46558 Mtetra
.783 .912 .928 r
.67915 .46558 .68419 .46853 .69518 .46627 .68994 .45846 Mtetra
.796 .75 .81 r
.68994 .45846 .69518 .46627 .70601 .46013 .70061 .44884 Mtetra
.747 .667 .772 r
.70061 .44884 .70601 .46013 .71676 .45227 .71132 .43998 Mtetra
.714 .638 .771 r
.71132 .43998 .71676 .45227 .72751 .44414 .72214 .43268 Mtetra
.671 .631 .801 r
.72214 .43268 .72751 .44414 .73839 .43778 .73314 .42801 Mtetra
.631 .644 .845 r
.73314 .42801 .73839 .43778 .74939 .43302 .7443 .42524 Mtetra
.596 .68 .9 r
.7443 .42524 .74939 .43302 .76054 .42967 .75559 .42345 Mtetra
.563 .719 .946 r
.75559 .42345 .76054 .42967 .7718 .4272 .76696 .42205 Mtetra
.564 .764 .972 r
.76696 .42205 .7718 .4272 .78313 .42494 .77836 .42026 Mtetra
.576 .791 .98 r
.77836 .42026 .78313 .42494 .79451 .42268 .78978 .41803 Mtetra
.607 .806 .976 r
.78978 .41803 .79451 .42268 .80592 .42009 .80121 .4152 Mtetra
.632 .807 .966 r
.80121 .4152 .80592 .42009 .81735 .41719 .81265 .41193 Mtetra
.65 .799 .954 r
.81265 .41193 .81735 .41719 .8288 .41397 .8241 .40834 Mtetra
.661 .789 .943 r
.8241 .40834 .8288 .41397 .84028 .41051 .83559 .40454 Mtetra
.664 .779 .934 r
.83559 .40454 .84028 .41051 .85179 .40689 .84711 .40066 Mtetra
.667 .771 .927 r
.84711 .40066 .85179 .40689 .86333 .40316 .85867 .39672 Mtetra
.667 .764 .923 r
.85867 .39672 .86333 .40316 .87492 .39937 .87028 .39277 Mtetra
.666 .759 .92 r
.87028 .39277 .87492 .39937 .88655 .39556 .88193 .38884 Mtetra
.644 .748 .925 r
.25789 .57635 .2641 .58177 .27346 .5791 .26727 .57366 Mtetra
.641 .748 .926 r
.26727 .57366 .27346 .5791 .28286 .57646 .27669 .57104 Mtetra
.638 .748 .928 r
.27669 .57104 .28286 .57646 .29229 .57382 .28613 .56846 Mtetra
.635 .751 .932 r
.28613 .56846 .29229 .57382 .30176 .57112 .29561 .56594 Mtetra
.63 .756 .939 r
.29561 .56594 .30176 .57112 .31127 .56835 .30512 .56349 Mtetra
.63 .769 .947 r
.30512 .56349 .31127 .56835 .32083 .56538 .31467 .56097 Mtetra
.632 .789 .957 r
.31467 .56097 .32083 .56538 .33044 .56211 .32427 .55832 Mtetra
.645 .819 .966 r
.32427 .55832 .33044 .56211 .3401 .55842 .33392 .55527 Mtetra
.671 .851 .969 r
.33392 .55527 .3401 .55842 .34983 .55415 .34364 .55158 Mtetra
.704 .881 .963 r
.34364 .55158 .34983 .55415 .3596 .54945 .35344 .54708 Mtetra
.747 .893 .945 r
.35344 .54708 .3596 .54945 .36942 .54436 .36331 .54155 Mtetra
.766 .877 .927 r
.36331 .54155 .36942 .54436 .37924 .53965 .37323 .53552 Mtetra
.766 .826 .899 r
.37323 .53552 .37924 .53965 .38905 .5359 .38317 .52932 Mtetra
.715 .737 .868 r
.38317 .52932 .38905 .5359 .39882 .53399 .39308 .52436 Mtetra
.634 .633 .832 r
.39308 .52436 .39882 .53399 .40855 .53464 .40292 .52175 Mtetra
.539 .529 .792 r
.40292 .52175 .40855 .53464 .41828 .53683 .41271 .52225 Mtetra
.426 .439 .771 r
.41271 .52225 .41828 .53683 .42806 .53978 .42244 .52637 Mtetra
.38 .43 .787 r
.42244 .52637 .42806 .53978 .43798 .54032 .43223 .53116 Mtetra
.359 .51 .872 r
.43223 .53116 .43798 .54032 .44806 .53626 .44214 .53447 Mtetra
.533 .874 .99 r
.44214 .53447 .44806 .53626 .45829 .52612 .45226 .53179 Mtetra
.583 .871 .555 r
.45226 .53179 .45829 .52612 .46861 .51017 .46257 .52094 Mtetra
0 0 0 r
.46257 .52094 .46861 .51017 .47886 .49689 .47295 .50529 Mtetra
.72 .874 .468 r
.47295 .50529 .47886 .49689 .48901 .49066 .4833 .48803 Mtetra
.842 .892 .875 r
.4833 .48803 .48901 .49066 .4991 .49354 .49354 .47898 Mtetra
.479 .473 .773 r
.49354 .47898 .4991 .49354 .50923 .50497 .5037 .48168 Mtetra
.368 .327 .681 r
.5037 .48168 .50923 .50497 .5195 .51466 .51391 .49109 Mtetra
.279 .266 .666 r
.51391 .49109 .5195 .51466 .52987 .51861 .52424 .50396 Mtetra
.196 .298 .743 r
.52424 .50396 .52987 .51861 .5403 .51795 .5347 .51362 Mtetra
.083 .525 .904 r
.5347 .51362 .5403 .51795 .55076 .51364 .54524 .51686 Mtetra
0 0 0 r
.54524 .51686 .55076 .51364 .56127 .5104 .5558 .51361 Mtetra
.67 .951 .705 r
.5558 .51361 .56127 .5104 .57183 .50823 .56632 .50384 Mtetra
.904 .824 .757 r
.56632 .50384 .57183 .50823 .58238 .5024 .57674 .48759 Mtetra
.813 .652 .683 r
.57674 .48759 .58238 .5024 .59285 .49193 .58706 .46808 Mtetra
.731 .56 .661 r
.58706 .46808 .59285 .49193 .60319 .47562 .59738 .45199 Mtetra
.675 .527 .675 r
.59738 .45199 .60319 .47562 .61343 .45753 .60784 .44264 Mtetra
.49 .479 .772 r
.60784 .44264 .61343 .45753 .62387 .44803 .61864 .44515 Mtetra
.642 .097 0 r
.61864 .44515 .62387 .44803 .63462 .44774 .62978 .45599 Mtetra
.681 .26 .239 r
.62978 .45599 .63462 .44774 .6457 .45462 .64101 .46526 Mtetra
.583 .181 .245 r
.64101 .46526 .6457 .45462 .657 .46425 .65217 .46969 Mtetra
.126 0 0 r
.65217 .46969 .657 .46425 .66817 .46801 .66308 .46582 Mtetra
.858 .936 .874 r
.66308 .46582 .66817 .46801 .67915 .46558 .67375 .45583 Mtetra
.799 .711 .768 r
.67375 .45583 .67915 .46558 .68994 .45846 .68435 .44429 Mtetra
.748 .631 .731 r
.68435 .44429 .68994 .45846 .70061 .44884 .69497 .43342 Mtetra
.69 .59 .738 r
.69497 .43342 .70061 .44884 .71132 .43998 .70578 .42624 Mtetra
.646 .585 .772 r
.70578 .42624 .71132 .43998 .72214 .43268 .71681 .42224 Mtetra
.595 .613 .84 r
.71681 .42224 .72214 .43268 .73314 .42801 .72802 .42065 Mtetra
.526 .661 .922 r
.72802 .42065 .73314 .42801 .7443 .42524 .73938 .42036 Mtetra
.474 .733 .983 r
.73938 .42036 .7443 .42524 .75559 .42345 .75079 .41989 Mtetra
.449 .78 .998 r
.75079 .41989 .75559 .42345 .76696 .42205 .76223 .41891 Mtetra
.507 .828 1 r
.76223 .41891 .76696 .42205 .77836 .42026 .77366 .41687 Mtetra
.575 .848 .996 r
.77366 .41687 .77836 .42026 .78978 .41803 .78507 .41399 Mtetra
.631 .843 .981 r
.78507 .41399 .78978 .41803 .80121 .4152 .79648 .41045 Mtetra
.661 .825 .962 r
.79648 .41045 .80121 .4152 .81265 .41193 .8079 .40649 Mtetra
.671 .801 .944 r
.8079 .40649 .81265 .41193 .8241 .40834 .81934 .40238 Mtetra
.675 .784 .931 r
.81934 .40238 .8241 .40834 .83559 .40454 .83083 .3982 Mtetra
.673 .77 .924 r
.83083 .3982 .83559 .40454 .84711 .40066 .84237 .3941 Mtetra
.671 .762 .919 r
.84237 .3941 .84711 .40066 .85867 .39672 .85395 .39003 Mtetra
.668 .758 .917 r
.85395 .39003 .85867 .39672 .87028 .39277 .86559 .38602 Mtetra
.666 .756 .917 r
.86559 .38602 .87028 .39277 .88193 .38884 .87727 .38207 Mtetra
.65 .75 .923 r
.25164 .57089 .25789 .57635 .26727 .57366 .26106 .56805 Mtetra
.648 .744 .92 r
.26106 .56805 .26727 .57366 .27669 .57104 .2705 .56527 Mtetra
.643 .738 .918 r
.2705 .56527 .27669 .57104 .28613 .56846 .27997 .56258 Mtetra
.637 .733 .918 r
.27997 .56258 .28613 .56846 .29561 .56594 .28947 .56002 Mtetra
.628 .73 .921 r
.28947 .56002 .29561 .56594 .30512 .56349 .29899 .55767 Mtetra
.621 .732 .926 r
.29899 .55767 .30512 .56349 .31467 .56097 .30854 .55544 Mtetra
.611 .741 .937 r
.30854 .55544 .31467 .56097 .32427 .55832 .31812 .55336 Mtetra
.614 .764 .951 r
.31812 .55336 .32427 .55832 .33392 .55527 .32775 .55111 Mtetra
.623 .8 .967 r
.32775 .55111 .33392 .55527 .34364 .55158 .33744 .5485 Mtetra
.651 .853 .977 r
.33744 .5485 .34364 .55158 .35344 .54708 .3472 .54509 Mtetra
.699 .905 .969 r
.3472 .54509 .35344 .54708 .36331 .54155 .35707 .54046 Mtetra
.744 .942 .948 r
.35707 .54046 .36331 .54155 .37323 .53552 .36702 .53457 Mtetra
.798 .946 .92 r
.36702 .53457 .37323 .53552 .38317 .52932 .37704 .52731 Mtetra
.806 .908 .911 r
.37704 .52731 .38317 .52932 .39308 .52436 .38709 .51994 Mtetra
.773 .818 .888 r
.38709 .51994 .39308 .52436 .40292 .52175 .39711 .51337 Mtetra
.666 .676 .849 r
.39711 .51337 .40292 .52175 .41271 .52225 .40705 .50976 Mtetra
.526 .529 .801 r
.40705 .50976 .41271 .52225 .42244 .52637 .41688 .51058 Mtetra
.434 .43 .756 r
.41688 .51058 .42244 .52637 .43223 .53116 .42666 .5148 Mtetra
.349 .371 .742 r
.42666 .5148 .43223 .53116 .44214 .53447 .43646 .52153 Mtetra
.389 .445 .798 r
.43646 .52153 .44214 .53447 .45226 .53179 .44642 .52592 Mtetra
.556 .718 .948 r
.44642 .52592 .45226 .53179 .46257 .52094 .45657 .52477 Mtetra
.64 .937 .69 r
.45657 .52477 .46257 .52094 .47295 .50529 .46691 .51544 Mtetra
0 0 0 r
.46691 .51544 .47295 .50529 .4833 .48803 .47737 .49813 Mtetra
.47737 .49813 .4833 .48803 .49354 .47898 .48776 .48256 Mtetra
.637 .937 .693 r
.48776 .48256 .49354 .47898 .5037 .48168 .49806 .47338 Mtetra
.556 .637 .886 r
.49806 .47338 .5037 .48168 .51391 .49109 .50832 .47276 Mtetra
.365 .362 .724 r
.50832 .47276 .51391 .49109 .52424 .50396 .51861 .48017 Mtetra
.415 .357 .684 r
.51861 .48017 .52424 .50396 .5347 .51362 .52902 .48782 Mtetra
.498 .403 .678 r
.52902 .48782 .5347 .51362 .54524 .51686 .53952 .49174 Mtetra
.604 .476 .679 r
.53952 .49174 .54524 .51686 .5558 .51361 .55004 .48844 Mtetra
.68 .524 .667 r
.55004 .48844 .5558 .51361 .56632 .50384 .56053 .47791 Mtetra
.708 .539 .658 r
.56053 .47791 .56632 .50384 .57674 .48759 .57097 .46361 Mtetra
.715 .55 .664 r
.57097 .46361 .57674 .48759 .58706 .46808 .58137 .44951 Mtetra
.659 .544 .713 r
.58137 .44951 .58706 .46808 .59738 .45199 .59191 .44346 Mtetra
.394 .551 .892 r
.59191 .44346 .59738 .45199 .60784 .44264 .60268 .44606 Mtetra
.696 .207 .083 r
.60268 .44606 .60784 .44264 .61864 .44515 .61371 .45513 Mtetra
.696 .296 .285 r
.61371 .45513 .61864 .44515 .62978 .45599 .62491 .46602 Mtetra
.544 .132 .211 r
.62491 .46602 .62978 .45599 .64101 .46526 .63598 .46885 Mtetra
0 0 0 r
.63598 .46885 .64101 .46526 .65217 .46969 .64683 .46338 Mtetra
.836 .795 .812 r
.64683 .46338 .65217 .46969 .66308 .46582 .65748 .45226 Mtetra
.781 .653 .721 r
.65748 .45226 .66308 .46582 .67375 .45583 .66801 .43871 Mtetra
.727 .595 .709 r
.66801 .43871 .67375 .45583 .68435 .44429 .67864 .4277 Mtetra
.688 .578 .727 r
.67864 .4277 .68435 .44429 .69497 .43342 .68943 .42015 Mtetra
.627 .582 .784 r
.68943 .42015 .69497 .43342 .70578 .42624 .70048 .41713 Mtetra
.532 .613 .879 r
.70048 .41713 .70578 .42624 .71681 .42224 .71176 .41714 Mtetra
.387 .678 .975 r
.71176 .41714 .71681 .42224 .72802 .42065 .72316 .41799 Mtetra
.216 .682 .943 r
.72316 .41799 .72802 .42065 .73938 .42036 .73462 .41875 Mtetra
.258 .744 .923 r
.73462 .41875 .73938 .42036 .75079 .41989 .74607 .41809 Mtetra
.404 .827 .965 r
.74607 .41809 .75079 .41989 .76223 .41891 .75749 .41615 Mtetra
.569 .873 .994 r
.75749 .41615 .76223 .41891 .77366 .41687 .76887 .41294 Mtetra
.654 .857 .977 r
.76887 .41294 .77366 .41687 .78507 .41399 .78023 .40889 Mtetra
.683 .819 .948 r
.78023 .40889 .78507 .41399 .79648 .41045 .79161 .40447 Mtetra
.691 .788 .925 r
.79161 .40447 .79648 .41045 .8079 .40649 .80301 .39988 Mtetra
.685 .765 .912 r
.80301 .39988 .8079 .40649 .81934 .40238 .81446 .39542 Mtetra
.679 .752 .906 r
.81446 .39542 .81934 .40238 .83083 .3982 .82597 .39109 Mtetra
.672 .745 .905 r
.82597 .39109 .83083 .3982 .84237 .3941 .83754 .38696 Mtetra
.667 .743 .907 r
.83754 .38696 .84237 .3941 .85395 .39003 .84916 .38297 Mtetra
.663 .745 .911 r
.84916 .38297 .85395 .39003 .86559 .38602 .86085 .37908 Mtetra
.661 .749 .915 r
.86085 .37908 .86559 .38602 .87727 .38207 .87259 .37524 Mtetra
.661 .753 .918 r
.24535 .5654 .25164 .57089 .26106 .56805 .25481 .56229 Mtetra
.66 .743 .912 r
.25481 .56229 .26106 .56805 .2705 .56527 .26429 .55918 Mtetra
.656 .732 .906 r
.26429 .55918 .2705 .56527 .27997 .56258 .2738 .55618 Mtetra
.649 .72 .901 r
.2738 .55618 .27997 .56258 .28947 .56002 .28334 .55335 Mtetra
.638 .709 .898 r
.28334 .55335 .28947 .56002 .29899 .55767 .29289 .55078 Mtetra
.625 .699 .898 r
.29289 .55078 .29899 .55767 .30854 .55544 .30245 .54853 Mtetra
.606 .692 .904 r
.30245 .54853 .30854 .55544 .31812 .55336 .31203 .54671 Mtetra
.591 .696 .915 r
.31203 .54671 .31812 .55336 .32775 .55111 .32163 .54516 Mtetra
.573 .715 .939 r
.32163 .54516 .32775 .55111 .33744 .5485 .33127 .54382 Mtetra
.573 .765 .969 r
.33127 .54382 .33744 .5485 .3472 .54509 .34097 .54213 Mtetra
.583 .841 .994 r
.34097 .54213 .3472 .54509 .35707 .54046 .35075 .53964 Mtetra
.61 .926 .969 r
.35075 .53964 .35707 .54046 .36702 .53457 .36065 .53562 Mtetra
.672 .974 .892 r
.36065 .53562 .36702 .53457 .37704 .52731 .37068 .52939 Mtetra
.731 .991 .837 r
.37068 .52939 .37704 .52731 .38709 .51994 .3808 .5213 Mtetra
.838 .993 .85 r
.3808 .5213 .38709 .51994 .39711 .51337 .39101 .51154 Mtetra
.843 .909 .881 r
.39101 .51154 .39711 .51337 .40705 .50976 .40118 .50261 Mtetra
.742 .732 .842 r
.40118 .50261 .40705 .50976 .41688 .51058 .41126 .4963 Mtetra
.597 .544 .765 r
.41126 .4963 .41688 .51058 .42666 .5148 .42121 .49462 Mtetra
.466 .41 .711 r
.42121 .49462 .42666 .5148 .43646 .52153 .43105 .49884 Mtetra
.391 .345 .686 r
.43105 .49884 .43646 .52153 .44642 .52592 .44087 .50668 Mtetra
.299 .31 .704 r
.44087 .50668 .44642 .52592 .45657 .52477 .45077 .51606 Mtetra
.282 .483 .877 r
.45077 .51606 .45657 .52477 .46691 .51544 .46088 .52018 Mtetra
0 0 0 r
.46088 .52018 .46691 .51544 .47737 .49813 .47122 .51544 Mtetra
.094 0 .141 r
.47122 .51544 .47737 .49813 .48776 .48256 .48169 .50251 Mtetra
0 0 .101 r
.48169 .50251 .48776 .48256 .49806 .47338 .49221 .48328 Mtetra
0 0 0 r
.49221 .48328 .49806 .47338 .50832 .47276 .50264 .4666 Mtetra
.829 .78 .805 r
.50264 .4666 .50832 .47276 .51861 .48017 .51301 .45577 Mtetra
.643 .502 .676 r
.51301 .45577 .51861 .48017 .52902 .48782 .52337 .44934 Mtetra
.584 .425 .632 r
.52337 .44934 .52902 .48782 .53952 .49174 .53376 .44634 Mtetra
.582 .413 .618 r
.53376 .44634 .53952 .49174 .55004 .48844 .54419 .44298 Mtetra
.584 .415 .618 r
.54419 .44298 .55004 .48844 .56053 .47791 .55466 .43927 Mtetra
.559 .407 .632 r
.55466 .43927 .56053 .47791 .57097 .46361 .5652 .43902 Mtetra
.49 .403 .685 r
.5652 .43902 .57097 .46361 .58137 .44951 .57588 .44318 Mtetra
0 .092 .612 r
.57588 .44318 .58137 .44951 .59191 .44346 .58676 .45329 Mtetra
.72 .323 .296 r
.58676 .45329 .59191 .44346 .60268 .44606 .59782 .46601 Mtetra
.603 .266 .371 r
.59782 .46601 .60268 .44606 .61371 .45513 .60887 .47241 Mtetra
.464 .122 .3 r
.60887 .47241 .61371 .45513 .62491 .46602 .6198 .47055 Mtetra
.57 .868 .561 r
.6198 .47055 .62491 .46602 .63598 .46885 .63048 .4597 Mtetra
.851 .734 .733 r
.63048 .4597 .63598 .46885 .64683 .46338 .64097 .44347 Mtetra
.743 .586 .681 r
.64097 .44347 .64683 .46338 .65748 .45226 .65147 .42875 Mtetra
.691 .538 .674 r
.65147 .42875 .65748 .45226 .66801 .43871 .6621 .4177 Mtetra
.635 .516 .701 r
.6621 .4177 .66801 .43871 .67864 .4277 .67299 .41265 Mtetra
.562 .524 .77 r
.67299 .41265 .67864 .4277 .68943 .42015 .68415 .41234 Mtetra
.388 .575 .913 r
.68415 .41234 .68943 .42015 .70048 .41713 .69551 .41472 Mtetra
0 .468 .795 r
.69551 .41472 .70048 .41713 .71176 .41714 .70701 .41798 Mtetra
.239 0 0 r
.70701 .41798 .71176 .41714 .72316 .41799 .7185 .41954 Mtetra
.126 0 0 r
.7185 .41954 .72316 .41799 .73462 .41875 .72995 .41919 Mtetra
.233 .751 .774 r
.72995 .41919 .73462 .41875 .74607 .41809 .74132 .41658 Mtetra
.572 .916 .966 r
.74132 .41658 .74607 .41809 .75749 .41615 .75263 .41237 Mtetra
.698 .877 .965 r
.75263 .41237 .75749 .41615 .76887 .41294 .76392 .40734 Mtetra
.719 .811 .922 r
.76392 .40734 .76887 .41294 .78023 .40889 .77521 .40192 Mtetra
.707 .761 .894 r
.77521 .40192 .78023 .40889 .79161 .40447 .78656 .39673 Mtetra
.695 .734 .88 r
.78656 .39673 .79161 .40447 .80301 .39988 .79796 .39181 Mtetra
.681 .719 .878 r
.79796 .39181 .80301 .39988 .81446 .39542 .80945 .38732 Mtetra
.67 .715 .882 r
.80945 .38732 .81446 .39542 .82597 .39109 .821 .38316 Mtetra
.662 .717 .889 r
.821 .38316 .82597 .39109 .83754 .38696 .83262 .37928 Mtetra
.656 .723 .898 r
.83262 .37928 .83754 .38696 .84916 .38297 .84431 .37557 Mtetra
.653 .731 .907 r
.84431 .37557 .84916 .38297 .86085 .37908 .85606 .37196 Mtetra
.651 .74 .915 r
.85606 .37196 .86085 .37908 .87259 .37524 .86786 .36837 Mtetra
.671 .755 .914 r
.23902 .55988 .24535 .5654 .25481 .56229 .24851 .55649 Mtetra
.672 .747 .907 r
.24851 .55649 .25481 .56229 .26429 .55918 .25804 .55307 Mtetra
.67 .736 .9 r
.25804 .55307 .26429 .55918 .2738 .55618 .2676 .54968 Mtetra
.664 .723 .893 r
.2676 .54968 .2738 .55618 .28334 .55335 .27718 .5464 Mtetra
.656 .708 .885 r
.27718 .5464 .28334 .55335 .29289 .55078 .28678 .54332 Mtetra
.643 .689 .878 r
.28678 .54332 .29289 .55078 .30245 .54853 .2964 .54058 Mtetra
.623 .669 .873 r
.2964 .54058 .30245 .54853 .31203 .54671 .30601 .53836 Mtetra
.601 .65 .871 r
.30601 .53836 .31203 .54671 .32163 .54516 .31563 .53671 Mtetra
.571 .636 .876 r
.31563 .53671 .32163 .54516 .33127 .54382 .32525 .53579 Mtetra
.553 .64 .891 r
.32525 .53579 .33127 .54382 .34097 .54213 .3349 .53519 Mtetra
.534 .667 .923 r
.3349 .53519 .34097 .54213 .35075 .53964 .34459 .53472 Mtetra
.555 .752 .969 r
.34459 .53472 .35075 .53964 .36065 .53562 .35438 .53333 Mtetra
.601 .876 .992 r
.35438 .53333 .36065 .53562 .37068 .52939 .3643 .53022 Mtetra
.629 .96 .9 r
.3643 .53022 .37068 .52939 .3808 .5213 .37436 .52464 Mtetra
.679 .966 .757 r
.37436 .52464 .3808 .5213 .39101 .51154 .38458 .51593 Mtetra
.709 .96 .697 r
.38458 .51593 .39101 .51154 .40118 .50261 .39487 .50548 Mtetra
.831 .999 .785 r
.39487 .50548 .40118 .50261 .41126 .4963 .40519 .49433 Mtetra
.832 .911 .891 r
.40519 .49433 .41126 .4963 .42121 .49462 .4154 .48585 Mtetra
.661 .668 .846 r
.4154 .48585 .42121 .49462 .43105 .49884 .42547 .48232 Mtetra
.496 .462 .749 r
.42547 .48232 .43105 .49884 .44087 .50668 .43541 .48462 Mtetra
.373 .337 .69 r
.43541 .48462 .44087 .50668 .45077 .51606 .44529 .49284 Mtetra
.364 .324 .681 r
.44529 .49284 .45077 .51606 .46088 .52018 .45525 .50188 Mtetra
.393 .382 .728 r
.45525 .50188 .46088 .52018 .47122 .51544 .46538 .50811 Mtetra
.608 .693 .903 r
.46538 .50811 .47122 .51544 .48169 .50251 .47573 .50606 Mtetra
.795 .986 .726 r
.47573 .50606 .48169 .50251 .49221 .48328 .48625 .49416 Mtetra
0 0 0 r
.48625 .49416 .49221 .48328 .50264 .4666 .49678 .47858 Mtetra
.49678 .47858 .50264 .4666 .51301 .45577 .50727 .46267 Mtetra
.50727 .46267 .51301 .45577 .52337 .44934 .51772 .45016 Mtetra
.716 .987 .873 r
.51772 .45016 .52337 .44934 .53376 .44634 .52815 .4427 Mtetra
.637 .844 .98 r
.52815 .4427 .53376 .44634 .54419 .44298 .53861 .43933 Mtetra
.302 .693 .976 r
.53861 .43933 .54419 .44298 .55466 .43927 .54914 .44004 Mtetra
.568 0 0 r
.54914 .44004 .55466 .43927 .5652 .43902 .5598 .44585 Mtetra
.689 .254 .211 r
.5598 .44585 .5652 .43902 .57588 .44318 .5706 .45512 Mtetra
.66 .274 .303 r
.5706 .45512 .57588 .44318 .58676 .45329 .58153 .46409 Mtetra
.6 .198 .253 r
.58153 .46409 .58676 .45329 .59782 .46601 .5925 .46939 Mtetra
0 0 0 r
.5925 .46939 .59782 .46601 .60887 .47241 .60333 .46476 Mtetra
.84 .76 .774 r
.60333 .46476 .60887 .47241 .6198 .47055 .61397 .45173 Mtetra
.76 .602 .682 r
.61397 .45173 .6198 .47055 .63048 .4597 .6245 .43581 Mtetra
.724 .557 .664 r
.6245 .43581 .63048 .4597 .64097 .44347 .63502 .42068 Mtetra
.676 .532 .682 r
.63502 .42068 .64097 .44347 .65147 .42875 .64572 .41154 Mtetra
.618 .534 .737 r
.64572 .41154 .65147 .42875 .6621 .4177 .65667 .40833 Mtetra
.451 .564 .878 r
.65667 .40833 .6621 .4177 .67299 .41265 .66789 .41018 Mtetra
0 .348 .703 r
.66789 .41018 .67299 .41265 .68415 .41234 .67932 .41479 Mtetra
.488 0 0 r
.67932 .41479 .68415 .41234 .69551 .41472 .69082 .41869 Mtetra
.44 0 0 r
.69082 .41869 .69551 .41472 .70701 .41798 .70231 .42084 Mtetra
.17 0 0 r
.70231 .42084 .70701 .41798 .7185 .41954 .71371 .41979 Mtetra
.362 .834 .834 r
.71371 .41979 .7185 .41954 .72995 .41919 .72501 .41619 Mtetra
.702 .908 .968 r
.72501 .41619 .72995 .41919 .74132 .41658 .73624 .41081 Mtetra
.747 .812 .904 r
.73624 .41081 .74132 .41658 .75263 .41237 .74744 .40447 Mtetra
.728 .74 .861 r
.74744 .40447 .75263 .41237 .76392 .40734 .75868 .39825 Mtetra
.711 .704 .842 r
.75868 .39825 .76392 .40734 .77521 .40192 .76996 .39235 Mtetra
.69 .685 .84 r
.76996 .39235 .77521 .40192 .78656 .39673 .78134 .3872 Mtetra
.675 .68 .847 r
.78134 .3872 .78656 .39673 .79796 .39181 .7928 .38264 Mtetra
.663 .684 .86 r
.7928 .38264 .79796 .39181 .80945 .38732 .80435 .37862 Mtetra
.653 .692 .874 r
.80435 .37862 .80945 .38732 .821 .38316 .81598 .37495 Mtetra
.648 .704 .888 r
.81598 .37495 .821 .38316 .83262 .37928 .82767 .37148 Mtetra
.643 .715 .9 r
.82767 .37148 .83262 .37928 .84431 .37557 .83943 .36812 Mtetra
.641 .726 .91 r
.83943 .36812 .84431 .37557 .85606 .37196 .85124 .36481 Mtetra
.642 .737 .918 r
.85124 .36481 .85606 .37196 .86786 .36837 .8631 .36144 Mtetra
.676 .756 .911 r
.23264 .55431 .23902 .55988 .24851 .55649 .24217 .55077 Mtetra
.68 .752 .906 r
.24217 .55077 .24851 .55649 .25804 .55307 .25174 .54712 Mtetra
.681 .746 .9 r
.25174 .54712 .25804 .55307 .2676 .54968 .26134 .54341 Mtetra
.681 .736 .892 r
.26134 .54341 .2676 .54968 .27718 .5464 .27098 .53966 Mtetra
.68 .721 .881 r
.27098 .53966 .27718 .5464 .28678 .54332 .28064 .53589 Mtetra
.67 .7 .869 r
.28064 .53589 .28678 .54332 .2964 .54058 .29033 .53231 Mtetra
.656 .674 .855 r
.29033 .53231 .2964 .54058 .30601 .53836 .30002 .52906 Mtetra
.633 .641 .841 r
.30002 .52906 .30601 .53836 .31563 .53671 .30971 .52646 Mtetra
.601 .608 .83 r
.30971 .52646 .31563 .53671 .32525 .53579 .31938 .5248 Mtetra
.568 .578 .823 r
.31938 .5248 .32525 .53579 .3349 .53519 .32903 .52415 Mtetra
.523 .555 .829 r
.32903 .52415 .3349 .53519 .34459 .53472 .33867 .52469 Mtetra
.493 .562 .854 r
.33867 .52469 .34459 .53472 .35438 .53333 .34833 .52572 Mtetra
.452 .61 .915 r
.34833 .52572 .35438 .53333 .3643 .53022 .35806 .52674 Mtetra
.424 .762 .996 r
.35806 .52674 .3643 .53022 .37436 .52464 .36793 .5262 Mtetra
.298 .789 .753 r
.36793 .5262 .37436 .52464 .38458 .51593 .37797 .52283 Mtetra
0 0 0 r
.37797 .52283 .38458 .51593 .39487 .50548 .38819 .51576 Mtetra
.38819 .51576 .39487 .50548 .40519 .49433 .3986 .50436 Mtetra
.3986 .50436 .40519 .49433 .4154 .48585 .40906 .49106 Mtetra
.797 .968 .663 r
.40906 .49106 .4154 .48585 .42547 .48232 .4195 .4776 Mtetra
.836 .815 .83 r
.4195 .4776 .42547 .48232 .43541 .48462 .42982 .46749 Mtetra
.64 .542 .727 r
.42982 .46749 .43541 .48462 .44529 .49284 .43999 .4631 Mtetra
.52 .4 .657 r
.43999 .4631 .44529 .49284 .45525 .50188 .45004 .4657 Mtetra
.434 .323 .628 r
.45004 .4657 .45525 .50188 .46538 .50811 .46001 .47529 Mtetra
.387 .3 .634 r
.46001 .47529 .46538 .50811 .47573 .50606 .47008 .48673 Mtetra
.283 .302 .704 r
.47008 .48673 .47573 .50606 .48625 .49416 .4803 .49657 Mtetra
.489 0 0 r
.4803 .49657 .48625 .49416 .49678 .47858 .49071 .49994 Mtetra
.428 .11 .322 r
.49071 .49994 .49678 .47858 .50727 .46267 .50125 .49565 Mtetra
.437 .157 .389 r
.50125 .49565 .50727 .46267 .51772 .45016 .51185 .48863 Mtetra
.453 .182 .412 r
.51185 .48863 .51772 .45016 .52815 .4427 .52245 .48152 Mtetra
.495 .219 .424 r
.52245 .48152 .52815 .4427 .53861 .43933 .53309 .47816 Mtetra
.531 .25 .433 r
.53309 .47816 .53861 .43933 .54914 .44004 .54378 .47856 Mtetra
.53 .248 .432 r
.54378 .47856 .54914 .44004 .5598 .44585 .55455 .47889 Mtetra
.497 .209 .407 r
.55455 .47889 .5598 .44585 .5706 .45512 .56534 .47648 Mtetra
.296 0 .276 r
.56534 .47648 .5706 .45512 .58153 .46409 .57607 .46636 Mtetra
.929 .972 .714 r
.57607 .46636 .58153 .46409 .5925 .46939 .58666 .44967 Mtetra
.772 .603 .67 r
.58666 .44967 .5925 .46939 .60333 .46476 .59718 .43131 Mtetra
.695 .511 .634 r
.59718 .43131 .60333 .46476 .61397 .45173 .60768 .41479 Mtetra
.636 .464 .633 r
.60768 .41479 .61397 .45173 .6245 .43581 .61835 .40531 Mtetra
.583 .444 .657 r
.61835 .40531 .6245 .43581 .63502 .42068 .62924 .40292 Mtetra
.476 .444 .742 r
.62924 .40292 .63502 .42068 .64572 .41154 .6404 .40635 Mtetra
0 .299 .766 r
.6404 .40635 .64572 .41154 .65667 .40833 .65177 .41322 Mtetra
.627 .137 .071 r
.65177 .41322 .65667 .40833 .66789 .41018 .66326 .41997 Mtetra
.584 .163 .209 r
.66326 .41997 .66789 .41018 .67932 .41479 .67478 .42481 Mtetra
.467 .049 .162 r
.67478 .42481 .67932 .41479 .69082 .41869 .68618 .42524 Mtetra
.218 0 0 r
.68618 .42524 .69082 .41869 .70231 .42084 .69746 .42187 Mtetra
.53 .919 .807 r
.69746 .42187 .70231 .42084 .71371 .41979 .70861 .41559 Mtetra
.798 .878 .905 r
.70861 .41559 .71371 .41979 .72501 .41619 .71969 .40768 Mtetra
.76 .735 .83 r
.71969 .40768 .72501 .41619 .73624 .41081 .73079 .39975 Mtetra
.726 .671 .795 r
.73079 .39975 .73624 .41081 .74744 .40447 .74194 .39231 Mtetra
.695 .639 .789 r
.74194 .39231 .74744 .40447 .75868 .39825 .75319 .38608 Mtetra
.675 .629 .796 r
.75319 .38608 .75868 .39825 .76996 .39235 .76455 .3809 Mtetra
.657 .633 .814 r
.76455 .3809 .76996 .39235 .78134 .3872 .77602 .37668 Mtetra
.644 .645 .836 r
.77602 .37668 .78134 .3872 .7928 .38264 .78758 .37314 Mtetra
.637 .665 .86 r
.78758 .37314 .7928 .38264 .80435 .37862 .79923 .36993 Mtetra
.632 .684 .881 r
.79923 .36993 .80435 .37862 .81598 .37495 .81095 .36693 Mtetra
.632 .704 .898 r
.81095 .36693 .81598 .37495 .82767 .37148 .82271 .3639 Mtetra
.632 .719 .91 r
.82271 .3639 .82767 .37148 .83943 .36812 .83453 .36084 Mtetra
.633 .73 .917 r
.83453 .36084 .83943 .36812 .85124 .36481 .8464 .35771 Mtetra
.636 .738 .922 r
.8464 .35771 .85124 .36481 .8631 .36144 .85831 .35446 Mtetra
.671 .755 .913 r
.22623 .54871 .23264 .55431 .24217 .55077 .23576 .54528 Mtetra
.676 .761 .915 r
.23576 .54528 .24217 .55077 .25174 .54712 .24534 .54172 Mtetra
.682 .766 .915 r
.24534 .54172 .25174 .54712 .26134 .54341 .25497 .538 Mtetra
.688 .768 .912 r
.25497 .538 .26134 .54341 .27098 .53966 .26463 .5341 Mtetra
.696 .765 .905 r
.26463 .5341 .27098 .53966 .28064 .53589 .27435 .52995 Mtetra
.698 .753 .895 r
.27435 .52995 .28064 .53589 .29033 .53231 .28411 .52571 Mtetra
.696 .732 .879 r
.28411 .52571 .29033 .53231 .30002 .52906 .29389 .52141 Mtetra
.68 .699 .861 r
.29389 .52141 .30002 .52906 .30971 .52646 .30368 .51744 Mtetra
.655 .658 .84 r
.30368 .51744 .30971 .52646 .31938 .5248 .31346 .51409 Mtetra
.619 .608 .818 r
.31346 .51409 .31938 .5248 .32903 .52415 .32322 .51182 Mtetra
.572 .558 .8 r
.32322 .51182 .32903 .52415 .33867 .52469 .33292 .51106 Mtetra
.528 .515 .785 r
.33292 .51106 .33867 .52469 .34833 .52572 .3426 .51177 Mtetra
.476 .482 .784 r
.3426 .51177 .34833 .52572 .35806 .52674 .35225 .51402 Mtetra
.455 .489 .805 r
.35225 .51402 .35806 .52674 .36793 .5262 .36196 .51652 Mtetra
.448 .55 .867 r
.36196 .51652 .36793 .5262 .37797 .52283 .37178 .51829 Mtetra
.507 .755 .985 r
.37178 .51829 .37797 .52283 .38819 .51576 .38178 .51731 Mtetra
.521 .917 .834 r
.38178 .51731 .38819 .51576 .3986 .50436 .392 .51205 Mtetra
0 0 0 r
.392 .51205 .3986 .50436 .40906 .49106 .4024 .5026 Mtetra
.4024 .5026 .40906 .49106 .4195 .4776 .41294 .48915 Mtetra
.41294 .48915 .4195 .4776 .42982 .46749 .42348 .47479 Mtetra
.597 .849 .491 r
.42348 .47479 .42982 .46749 .43999 .4631 .43396 .46189 Mtetra
.796 .949 .921 r
.43396 .46189 .43999 .4631 .45004 .4657 .44427 .45442 Mtetra
.545 .566 .826 r
.44427 .45442 .45004 .4657 .46001 .47529 .45444 .45436 Mtetra
.426 .381 .706 r
.45444 .45436 .46001 .47529 .47008 .48673 .46457 .46016 Mtetra
.372 .313 .662 r
.46457 .46016 .47008 .48673 .4803 .49657 .47472 .47003 Mtetra
.42 .347 .668 r
.47472 .47003 .4803 .49657 .49071 .49994 .48503 .47776 Mtetra
.499 .423 .701 r
.48503 .47776 .49071 .49994 .50125 .49565 .49549 .48075 Mtetra
.565 .526 .77 r
.49549 .48075 .50125 .49565 .51185 .48863 .50604 .48021 Mtetra
.651 .685 .869 r
.50604 .48021 .51185 .48863 .52245 .48152 .51667 .47686 Mtetra
.645 .809 .962 r
.51667 .47686 .52245 .48152 .53309 .47816 .52733 .47348 Mtetra
.646 .81 .962 r
.52733 .47348 .53309 .47816 .54378 .47856 .53804 .47007 Mtetra
.726 .712 .837 r
.53804 .47007 .54378 .47856 .55455 .47889 .54877 .46383 Mtetra
.727 .613 .73 r
.54877 .46383 .55455 .47889 .56534 .47648 .55949 .45404 Mtetra
.727 .565 .671 r
.55949 .45404 .56534 .47648 .57607 .46636 .57013 .43944 Mtetra
.722 .545 .651 r
.57013 .43944 .57607 .46636 .58666 .44967 .58071 .42263 Mtetra
.691 .525 .657 r
.58071 .42263 .58666 .44967 .59718 .43131 .59133 .40991 Mtetra
.655 .526 .694 r
.59133 .40991 .59718 .43131 .60768 .41479 .60206 .40307 Mtetra
.52 .551 .827 r
.60206 .40307 .60768 .41479 .61835 .40531 .61303 .40376 Mtetra
.456 0 0 r
.61303 .40376 .61835 .40531 .62924 .40292 .62423 .40997 Mtetra
.651 .201 .171 r
.62423 .40997 .62924 .40292 .6404 .40635 .63559 .41772 Mtetra
.622 .22 .26 r
.63559 .41772 .6404 .40635 .65177 .41322 .64705 .42457 Mtetra
.538 .134 .223 r
.64705 .42457 .65177 .41322 .66326 .41997 .65845 .42737 Mtetra
.347 0 .011 r
.65845 .42737 .66326 .41997 .67478 .42481 .66976 .4259 Mtetra
.499 .904 .804 r
.66976 .4259 .67478 .42481 .68618 .42524 .68091 .42004 Mtetra
.809 .841 .874 r
.68091 .42004 .68618 .42524 .69746 .42187 .69194 .41133 Mtetra
.764 .694 .785 r
.69194 .41133 .69746 .42187 .70861 .41559 .70294 .40187 Mtetra
.731 .634 .751 r
.70294 .40187 .70861 .41559 .71969 .40768 .71396 .39263 Mtetra
.699 .603 .746 r
.71396 .39263 .71969 .40768 .73079 .39975 .72509 .38497 Mtetra
.677 .595 .757 r
.72509 .38497 .73079 .39975 .74194 .39231 .73633 .3788 Mtetra
.655 .6 .781 r
.73633 .3788 .74194 .39231 .75319 .38608 .7477 .3742 Mtetra
.638 .617 .812 r
.7477 .3742 .75319 .38608 .76455 .3809 .7592 .37071 Mtetra
.626 .644 .849 r
.7592 .37071 .76455 .3809 .77602 .37668 .7708 .36786 Mtetra
.615 .673 .882 r
.7708 .36786 .77602 .37668 .78758 .37314 .78248 .36536 Mtetra
.614 .703 .908 r
.78248 .36536 .78758 .37314 .79923 .36993 .79421 .36281 Mtetra
.615 .726 .925 r
.79421 .36281 .79923 .36993 .81095 .36693 .80599 .36015 Mtetra
.623 .742 .932 r
.80599 .36015 .81095 .36693 .82271 .3639 .81781 .35723 Mtetra
.629 .75 .934 r
.81781 .35723 .82271 .3639 .83453 .36084 .82966 .35412 Mtetra
.635 .751 .932 r
.82966 .35412 .83453 .36084 .8464 .35771 .84155 .35085 Mtetra
.641 .75 .928 r
.84155 .35085 .8464 .35771 .85831 .35446 .85348 .34743 Mtetra
.656 .751 .92 r
.21976 .54307 .22623 .54871 .23576 .54528 .22929 .54 Mtetra
.659 .766 .929 r
.22929 .54 .23576 .54528 .24534 .54172 .23886 .53684 Mtetra
.665 .783 .936 r
.23886 .53684 .24534 .54172 .25497 .538 .24847 .53349 Mtetra
.677 .8 .941 r
.24847 .53349 .25497 .538 .26463 .5341 .25814 .52984 Mtetra
.693 .813 .939 r
.25814 .52984 .26463 .5341 .27435 .52995 .26788 .52579 Mtetra
.709 .82 .934 r
.26788 .52579 .27435 .52995 .28411 .52571 .27768 .52131 Mtetra
.727 .814 .919 r
.27768 .52131 .28411 .52571 .29389 .52141 .28754 .51632 Mtetra
.732 .79 .899 r
.28754 .51632 .29389 .52141 .30368 .51744 .29744 .51108 Mtetra
.727 .749 .87 r
.29744 .51108 .30368 .51744 .31346 .51409 .30737 .50569 Mtetra
.699 .689 .836 r
.30737 .50569 .31346 .51409 .32322 .51182 .3173 .50079 Mtetra
.66 .622 .801 r
.3173 .50079 .32322 .51182 .33292 .51106 .3272 .49684 Mtetra
.61 .553 .765 r
.3272 .49684 .33292 .51106 .3426 .51177 .33703 .49454 Mtetra
.554 .49 .738 r
.33703 .49454 .3426 .51177 .35225 .51402 .34679 .4945 Mtetra
.506 .441 .718 r
.34679 .4945 .35225 .51402 .36196 .51652 .35649 .49664 Mtetra
.45 .403 .714 r
.35649 .49664 .36196 .51652 .37178 .51829 .36615 .50099 Mtetra
.408 .401 .739 r
.36615 .50099 .37178 .51829 .38178 .51731 .37587 .50602 Mtetra
.326 .446 .829 r
.37587 .50602 .38178 .51731 .392 .51205 .3857 .5105 Mtetra
0 .536 .779 r
.3857 .5105 .392 .51205 .4024 .5026 .39572 .51198 Mtetra
.289 0 .046 r
.39572 .51198 .4024 .5026 .41294 .48915 .40599 .50868 Mtetra
.294 0 .242 r
.40599 .50868 .41294 .48915 .42348 .47479 .41645 .50042 Mtetra
.242 0 .273 r
.41645 .50042 .42348 .47479 .43396 .46189 .42708 .48716 Mtetra
.152 0 .234 r
.42708 .48716 .43396 .46189 .44427 .45442 .43775 .47091 Mtetra
0 0 0 r
.43775 .47091 .44427 .45442 .45444 .45436 .44842 .45349 Mtetra
.928 .906 .781 r
.44842 .45349 .45444 .45436 .46457 .46016 .45899 .43831 Mtetra
.697 .547 .68 r
.45899 .43831 .46457 .46016 .47472 .47003 .46945 .42753 Mtetra
.59 .421 .621 r
.46945 .42753 .47472 .47003 .48503 .47776 .47981 .42302 Mtetra
.54 .37 .6 r
.47981 .42302 .48503 .47776 .49549 .48075 .49015 .42449 Mtetra
.531 .363 .598 r
.49015 .42449 .49549 .48075 .50604 .48021 .50054 .42721 Mtetra
.541 .373 .603 r
.50054 .42721 .50604 .48021 .51667 .47686 .51102 .42851 Mtetra
.577 .405 .612 r
.51102 .42851 .51667 .47686 .52733 .47348 .52158 .42507 Mtetra
.609 .428 .611 r
.52158 .42507 .52733 .47348 .53804 .47007 .53217 .41687 Mtetra
.612 .425 .605 r
.53217 .41687 .53804 .47007 .54877 .46383 .54275 .40722 Mtetra
.601 .414 .601 r
.54275 .40722 .54877 .46383 .55949 .45404 .55335 .39883 Mtetra
.566 .39 .602 r
.55335 .39883 .55949 .45404 .57013 .43944 .56404 .39642 Mtetra
.515 .369 .62 r
.56404 .39642 .57013 .43944 .58071 .42263 .57486 .40036 Mtetra
.377 .344 .695 r
.57486 .40036 .58071 .42263 .59133 .40991 .58587 .40878 Mtetra
.694 .151 0 r
.58587 .40878 .59133 .40991 .60206 .40307 .59705 .4195 Mtetra
.647 .284 .342 r
.59705 .4195 .60206 .40307 .61303 .40376 .60834 .42909 Mtetra
.592 .269 .391 r
.60834 .42909 .61303 .40376 .62423 .40997 .61968 .43568 Mtetra
.533 .217 .378 r
.61968 .43568 .62423 .40997 .63559 .41772 .63096 .43723 Mtetra
.433 .101 .302 r
.63096 .43723 .63559 .41772 .64705 .42457 .64215 .43372 Mtetra
.026 0 0 r
.64215 .43372 .64705 .42457 .65845 .42737 .65319 .42531 Mtetra
.881 .941 .85 r
.65319 .42531 .65845 .42737 .66976 .4259 .6641 .41382 Mtetra
.783 .677 .748 r
.6641 .41382 .66976 .4259 .68091 .42004 .67498 .40173 Mtetra
.724 .588 .704 r
.67498 .40173 .68091 .42004 .69194 .41133 .68588 .3903 Mtetra
.683 .548 .694 r
.68588 .3903 .69194 .41133 .70294 .40187 .69688 .38114 Mtetra
.658 .535 .702 r
.69688 .38114 .70294 .40187 .71396 .39263 .70803 .37419 Mtetra
.635 .537 .727 r
.70803 .37419 .71396 .39263 .72509 .38497 .71933 .36957 Mtetra
.615 .555 .764 r
.71933 .36957 .72509 .38497 .73633 .3788 .73079 .36664 Mtetra
.598 .591 .816 r
.73079 .36664 .73633 .3788 .7477 .3742 .74236 .36471 Mtetra
.579 .638 .873 r
.74236 .36471 .7477 .3742 .7592 .37071 .75403 .36328 Mtetra
.572 .695 .924 r
.75403 .36328 .7592 .37071 .7708 .36786 .76576 .36171 Mtetra
.569 .74 .957 r
.76576 .36171 .7708 .36786 .78248 .36536 .77753 .35988 Mtetra
.584 .774 .97 r
.77753 .35988 .78248 .36536 .79421 .36281 .78931 .35751 Mtetra
.602 .791 .971 r
.78931 .35751 .79421 .36281 .80599 .36015 .80112 .35471 Mtetra
.624 .795 .964 r
.80112 .35471 .80599 .36015 .81781 .35723 .81295 .35148 Mtetra
.64 .79 .954 r
.81295 .35148 .81781 .35723 .82966 .35412 .8248 .34794 Mtetra
.65 .779 .942 r
.8248 .34794 .82966 .35412 .84155 .35085 .83668 .3442 Mtetra
.655 .765 .93 r
.83668 .3442 .84155 .35085 .85348 .34743 .84861 .34035 Mtetra
.635 .746 .929 r
.21326 .53739 .21976 .54307 .22929 .54 .22276 .53478 Mtetra
.632 .763 .941 r
.22276 .53478 .22929 .54 .23886 .53684 .2323 .53214 Mtetra
.635 .784 .953 r
.2323 .53214 .23886 .53684 .24847 .53349 .24189 .52938 Mtetra
.641 .81 .964 r
.24189 .52938 .24847 .53349 .25814 .52984 .25154 .52636 Mtetra
.653 .838 .972 r
.25154 .52636 .25814 .52984 .26788 .52579 .26125 .52298 Mtetra
.671 .869 .974 r
.26125 .52298 .26788 .52579 .27768 .52131 .27103 .51908 Mtetra
.699 .896 .968 r
.27103 .51908 .27768 .52131 .28754 .51632 .2809 .51448 Mtetra
.727 .914 .958 r
.2809 .51448 .28754 .51632 .29744 .51108 .29084 .50919 Mtetra
.761 .914 .941 r
.29084 .50919 .29744 .51108 .30737 .50569 .30086 .50311 Mtetra
.776 .888 .926 r
.30086 .50311 .30737 .50569 .3173 .50079 .31092 .49667 Mtetra
.773 .832 .898 r
.31092 .49667 .3173 .50079 .3272 .49684 .321 .49014 Mtetra
.733 .744 .861 r
.321 .49014 .3272 .49684 .33703 .49454 .33106 .48438 Mtetra
.672 .645 .814 r
.33106 .48438 .33703 .49454 .34679 .4945 .34105 .48011 Mtetra
.601 .547 .766 r
.34105 .48011 .34679 .4945 .35649 .49664 .35095 .47811 Mtetra
.53 .465 .727 r
.35095 .47811 .35649 .49664 .36615 .50099 .36076 .47907 Mtetra
.478 .407 .699 r
.36076 .47907 .36615 .50099 .37587 .50602 .3705 .48266 Mtetra
.429 .367 .686 r
.3705 .48266 .37587 .50602 .3857 .5105 .38021 .48863 Mtetra
.418 .369 .697 r
.38021 .48863 .3857 .5105 .39572 .51198 .39002 .49467 Mtetra
.43 .416 .743 r
.39002 .49467 .39572 .51198 .40599 .50868 .39999 .49903 Mtetra
.494 .58 .871 r
.39999 .49903 .40599 .50868 .41645 .50042 .41016 .49982 Mtetra
.582 .927 .955 r
.41016 .49982 .41645 .50042 .42708 .48716 .42056 .49557 Mtetra
0 0 0 r
.42056 .49557 .42708 .48716 .43775 .47091 .43115 .48589 Mtetra
.43115 .48589 .43775 .47091 .44842 .45349 .44186 .47123 Mtetra
0 0 .064 r
.44186 .47123 .44842 .45349 .45899 .43831 .45257 .45546 Mtetra
.003 0 .082 r
.45257 .45546 .45899 .43831 .46945 .42753 .4632 .44118 Mtetra
.126 0 .079 r
.4632 .44118 .46945 .42753 .47981 .42302 .47373 .43202 Mtetra
.286 0 .035 r
.47373 .43202 .47981 .42302 .49015 .42449 .48419 .42877 Mtetra
.246 0 0 r
.48419 .42877 .49015 .42449 .50054 .42721 .49467 .42774 Mtetra
0 0 0 r
.49467 .42774 .50054 .42721 .51102 .42851 .5052 .42696 Mtetra
.556 .899 .979 r
.5052 .42696 .51102 .42851 .52158 .42507 .5158 .4235 Mtetra
.731 .947 .951 r
.5158 .4235 .52158 .42507 .53217 .41687 .52644 .41734 Mtetra
.615 .957 .89 r
.52644 .41734 .53217 .41687 .54275 .40722 .5371 .41143 Mtetra
.005 0 0 r
.5371 .41143 .54275 .40722 .55335 .39883 .54781 .40775 Mtetra
.516 .082 .156 r
.54781 .40775 .55335 .39883 .56404 .39642 .55861 .41001 Mtetra
.628 .248 .303 r
.55861 .41001 .56404 .39642 .57486 .40036 .56957 .41747 Mtetra
.638 .279 .346 r
.56957 .41747 .57486 .40036 .58587 .40878 .58068 .42648 Mtetra
.622 .265 .345 r
.58068 .42648 .58587 .40878 .59705 .4195 .59189 .4344 Mtetra
.545 .172 .284 r
.59189 .4344 .59705 .4195 .60834 .42909 .6031 .43731 Mtetra
.306 0 .016 r
.6031 .43731 .60834 .42909 .61968 .43568 .61425 .43471 Mtetra
.765 .976 .918 r
.61425 .43471 .61968 .43568 .63096 .43723 .62529 .42699 Mtetra
.793 .708 .771 r
.62529 .42699 .63096 .43723 .64215 .43372 .63622 .41559 Mtetra
.742 .6 .698 r
.63622 .41559 .64215 .43372 .65319 .42531 .64708 .40247 Mtetra
.713 .556 .674 r
.64708 .40247 .65319 .42531 .6641 .41382 .65791 .38937 Mtetra
.683 .531 .673 r
.65791 .38937 .6641 .41382 .67498 .40173 .66884 .37869 Mtetra
.661 .524 .686 r
.66884 .37869 .67498 .40173 .68588 .3903 .67989 .37067 Mtetra
.636 .529 .715 r
.67989 .37067 .68588 .3903 .69688 .38114 .69111 .36569 Mtetra
.608 .551 .764 r
.69111 .36569 .69688 .38114 .70803 .37419 .70249 .36304 Mtetra
.573 .597 .839 r
.70249 .36304 .70803 .37419 .71933 .36957 .71403 .36193 Mtetra
.516 .66 .925 r
.71403 .36193 .71933 .36957 .73079 .36664 .72568 .36163 Mtetra
.455 .73 .986 r
.72568 .36163 .73079 .36664 .74236 .36471 .73739 .36124 Mtetra
.404 .77 .994 r
.73739 .36124 .74236 .36471 .75403 .36328 .74916 .36049 Mtetra
.426 .81 .99 r
.74916 .36049 .75403 .36328 .76576 .36171 .76093 .35892 Mtetra
.482 .84 .994 r
.76093 .35892 .76576 .36171 .77753 .35988 .77271 .35664 Mtetra
.556 .857 .997 r
.77271 .35664 .77753 .35988 .78931 .35751 .78449 .35363 Mtetra
.61 .854 .99 r
.78449 .35363 .78931 .35751 .80112 .35471 .79629 .35007 Mtetra
.644 .838 .975 r
.79629 .35007 .80112 .35471 .81295 .35148 .80809 .34614 Mtetra
.663 .817 .957 r
.80809 .34614 .81295 .35148 .8248 .34794 .81993 .34193 Mtetra
.672 .796 .941 r
.81993 .34193 .8248 .34794 .83668 .3442 .83179 .33758 Mtetra
.673 .776 .927 r
.83179 .33758 .83668 .3442 .84861 .34035 .8437 .33321 Mtetra
.615 .741 .935 r
.20671 .53168 .21326 .53739 .22276 .53478 .2162 .52943 Mtetra
.607 .753 .947 r
.2162 .52943 .22276 .53478 .2323 .53214 .22571 .52727 Mtetra
.601 .77 .961 r
.22571 .52727 .2323 .53214 .24189 .52938 .23527 .52511 Mtetra
.596 .793 .975 r
.23527 .52511 .24189 .52938 .25154 .52636 .24487 .52287 Mtetra
.585 .823 .989 r
.24487 .52287 .25154 .52636 .26125 .52298 .25453 .52052 Mtetra
.579 .862 .995 r
.25453 .52052 .26125 .52298 .27103 .51908 .26425 .51779 Mtetra
.57 .899 .983 r
.26425 .51779 .27103 .51908 .2809 .51448 .27405 .51453 Mtetra
.561 .926 .938 r
.27405 .51453 .2809 .51448 .29084 .50919 .28395 .51045 Mtetra
.572 .94 .879 r
.28395 .51045 .29084 .50919 .30086 .50311 .29395 .50528 Mtetra
.6 .95 .83 r
.29395 .50528 .30086 .50311 .31092 .49667 .30405 .49899 Mtetra
.689 .98 .835 r
.30405 .49899 .31092 .49667 .321 .49014 .31425 .49144 Mtetra
.782 .993 .877 r
.31425 .49144 .321 .49014 .33106 .48438 .32451 .48318 Mtetra
.835 .932 .894 r
.32451 .48318 .33106 .48438 .34105 .48011 .33479 .47453 Mtetra
.79 .787 .849 r
.33479 .47453 .34105 .48011 .35095 .47811 .34504 .46654 Mtetra
.707 .637 .777 r
.34504 .46654 .35095 .47811 .36076 .47907 .35523 .46003 Mtetra
.627 .52 .713 r
.35523 .46003 .36076 .47907 .3705 .48266 .36531 .45597 Mtetra
.564 .44 .67 r
.36531 .45597 .3705 .48266 .38021 .48863 .37528 .45517 Mtetra
.519 .388 .641 r
.37528 .45517 .38021 .48863 .39002 .49467 .38516 .45763 Mtetra
.48 .352 .628 r
.38516 .45763 .39002 .49467 .39999 .49903 .39499 .46338 Mtetra
.45 .334 .63 r
.39499 .46338 .39999 .49903 .41016 .49982 .40484 .47105 Mtetra
.405 .326 .653 r
.40484 .47105 .41016 .49982 .42056 .49557 .41476 .47957 Mtetra
.278 .338 .745 r
.41476 .47957 .42056 .49557 .43115 .48589 .42483 .48728 Mtetra
.586 .036 0 r
.42483 .48728 .43115 .48589 .44186 .47123 .43506 .49293 Mtetra
.555 .224 .362 r
.43506 .49293 .44186 .47123 .45257 .45546 .44545 .49618 Mtetra
.524 .242 .428 r
.44545 .49618 .45257 .45546 .4632 .44118 .45598 .49634 Mtetra
.495 .233 .446 r
.45598 .49634 .4632 .44118 .47373 .43202 .46666 .49185 Mtetra
.469 .214 .445 r
.46666 .49185 .47373 .43202 .48419 .42877 .47744 .48311 Mtetra
.455 .198 .434 r
.47744 .48311 .48419 .42877 .49467 .42774 .48823 .4736 Mtetra
.452 .187 .42 r
.48823 .4736 .49467 .42774 .5052 .42696 .49901 .46553 Mtetra
.486 .205 .412 r
.49901 .46553 .5052 .42696 .5158 .4235 .50978 .46208 Mtetra
.532 .245 .424 r
.50978 .46208 .5158 .4235 .52644 .41734 .52059 .46327 Mtetra
.545 .266 .443 r
.52059 .46327 .52644 .41734 .5371 .41143 .53147 .46592 Mtetra
.539 .27 .454 r
.53147 .46592 .5371 .41143 .54781 .40775 .54244 .46782 Mtetra
.514 .252 .456 r
.54244 .46782 .54781 .40775 .55861 .41001 .55345 .46545 Mtetra
.478 .219 .442 r
.55345 .46545 .55861 .41001 .56957 .41747 .56445 .45839 Mtetra
.419 .152 .401 r
.56445 .45839 .56957 .41747 .58068 .42648 .57542 .44819 Mtetra
.222 0 .241 r
.57542 .44819 .58068 .42648 .59189 .4344 .58635 .43552 Mtetra
.913 .98 .762 r
.58635 .43552 .59189 .4344 .6031 .43731 .59721 .42073 Mtetra
.776 .628 .696 r
.59721 .42073 .6031 .43731 .61425 .43471 .60802 .40508 Mtetra
.696 .521 .647 r
.60802 .40508 .61425 .43471 .62529 .42699 .61881 .39026 Mtetra
.66 .48 .631 r
.61881 .39026 .62529 .42699 .63622 .41559 .62963 .37735 Mtetra
.632 .458 .63 r
.62963 .37735 .63622 .41559 .64708 .40247 .64055 .36778 Mtetra
.612 .452 .641 r
.64055 .36778 .64708 .40247 .65791 .38937 .65161 .36152 Mtetra
.589 .457 .669 r
.65161 .36152 .65791 .38937 .66884 .37869 .66284 .3586 Mtetra
.559 .479 .721 r
.66284 .3586 .66884 .37869 .67989 .37067 .67423 .35818 Mtetra
.505 .535 .821 r
.67423 .35818 .67989 .37067 .69111 .36569 .68578 .3593 Mtetra
.355 .619 .951 r
.68578 .3593 .69111 .36569 .70249 .36304 .69744 .36111 Mtetra
.052 .592 .849 r
.69744 .36111 .70249 .36304 .71403 .36193 .70917 .36255 Mtetra
.132 0 0 r
.70917 .36255 .71403 .36193 .72568 .36163 .72094 .36326 Mtetra
.102 0 0 r
.72094 .36326 .72568 .36163 .73739 .36124 .7327 .36268 Mtetra
0 0 0 r
.7327 .36268 .73739 .36124 .74916 .36049 .74446 .36095 Mtetra
.243 .757 .773 r
.74446 .36095 .74916 .36049 .76093 .35892 .7562 .35808 Mtetra
.454 .879 .919 r
.7562 .35808 .76093 .35892 .77271 .35664 .76792 .35437 Mtetra
.593 .909 .98 r
.76792 .35437 .77271 .35664 .78449 .35363 .77966 .35009 Mtetra
.659 .888 .981 r
.77966 .35009 .78449 .35363 .79629 .35007 .79141 .34542 Mtetra
.682 .852 .964 r
.79141 .34542 .79629 .35007 .80809 .34614 .80318 .34062 Mtetra
.69 .822 .946 r
.80318 .34062 .80809 .34614 .81993 .34193 .815 .33573 Mtetra
.691 .798 .931 r
.815 .33573 .81993 .34193 .83179 .33758 .82685 .33083 Mtetra
.687 .778 .92 r
.82685 .33083 .83179 .33758 .8437 .33321 .83876 .32602 Mtetra
.616 .741 .935 r
.20012 .52592 .20671 .53168 .2162 .52943 .20962 .52365 Mtetra
.608 .738 .937 r
.20962 .52365 .2162 .52943 .22571 .52727 .21915 .52152 Mtetra
.6 .738 .941 r
.21915 .52152 .22571 .52727 .23527 .52511 .22871 .51953 Mtetra
.591 .742 .948 r
.22871 .51953 .23527 .52511 .24487 .52287 .2383 .51766 Mtetra
.575 .751 .961 r
.2383 .51766 .24487 .52287 .25453 .52052 .24792 .51596 Mtetra
.563 .774 .978 r
.24792 .51596 .25453 .52052 .26425 .51779 .25759 .51424 Mtetra
.542 .809 .995 r
.25759 .51424 .26425 .51779 .27405 .51453 .2673 .51241 Mtetra
.521 .856 .995 r
.2673 .51241 .27405 .51453 .28395 .51045 .2771 .5101 Mtetra
.479 .885 .941 r
.2771 .5101 .28395 .51045 .29395 .50528 .28699 .50702 Mtetra
.411 .859 .801 r
.28699 .50702 .29395 .50528 .30405 .49899 .297 .50281 Mtetra
.364 .801 .635 r
.297 .50281 .30405 .49899 .31425 .49144 .30714 .4971 Mtetra
0 0 0 r
.30714 .4971 .31425 .49144 .32451 .48318 .31739 .4899 Mtetra
.31739 .4899 .32451 .48318 .33479 .47453 .32776 .48111 Mtetra
.32776 .48111 .33479 .47453 .34504 .46654 .33818 .47141 Mtetra
.664 .941 .676 r
.33818 .47141 .34504 .46654 .35523 .46003 .34862 .46128 Mtetra
.821 .994 .862 r
.34862 .46128 .35523 .46003 .36531 .45597 .35901 .45191 Mtetra
.799 .842 .884 r
.35901 .45191 .36531 .45597 .37528 .45517 .36933 .44425 Mtetra
.677 .637 .803 r
.36933 .44425 .37528 .45517 .38516 .45763 .37953 .43951 Mtetra
.57 .494 .73 r
.37953 .43951 .38516 .45763 .39499 .46338 .3896 .43857 Mtetra
.509 .413 .681 r
.3896 .43857 .39499 .46338 .40484 .47105 .3996 .44094 Mtetra
.468 .363 .652 r
.3996 .44094 .40484 .47105 .41476 .47957 .40957 .44634 Mtetra
.444 .337 .638 r
.40957 .44634 .41476 .47957 .42483 .48728 .41956 .4538 Mtetra
.43 .327 .636 r
.41956 .4538 .42483 .48728 .43506 .49293 .42963 .46217 Mtetra
.446 .348 .65 r
.42963 .46217 .43506 .49293 .44545 .49618 .43986 .46903 Mtetra
.494 .395 .671 r
.43986 .46903 .44545 .49618 .45598 .49634 .45027 .47252 Mtetra
.586 .471 .689 r
.45027 .47252 .45598 .49634 .46666 .49185 .46088 .47026 Mtetra
.668 .534 .692 r
.46088 .47026 .46666 .49185 .47744 .48311 .47163 .46234 Mtetra
.685 .549 .694 r
.47163 .46234 .47744 .48311 .48823 .4736 .48241 .45318 Mtetra
.672 .543 .699 r
.48241 .45318 .48823 .4736 .49901 .46553 .49318 .44528 Mtetra
.612 .508 .712 r
.49318 .44528 .49901 .46553 .50978 .46208 .50393 .4418 Mtetra
.531 .459 .719 r
.50393 .4418 .50978 .46208 .52059 .46327 .51471 .44274 Mtetra
.505 .441 .718 r
.51471 .44274 .52059 .46327 .53147 .46592 .52557 .44496 Mtetra
.531 .455 .715 r
.52557 .44496 .53147 .46592 .54244 .46782 .5365 .44595 Mtetra
.625 .508 .7 r
.5365 .44595 .54244 .46782 .55345 .46545 .54747 .44126 Mtetra
.683 .532 .675 r
.54747 .44126 .55345 .46545 .56445 .45839 .55841 .43074 Mtetra
.698 .528 .655 r
.55841 .43074 .56445 .45839 .57542 .44819 .5693 .4168 Mtetra
.695 .516 .641 r
.5693 .4168 .57542 .44819 .58635 .43552 .58014 .40129 Mtetra
.679 .498 .635 r
.58014 .40129 .58635 .43552 .59721 .42073 .59096 .38667 Mtetra
.665 .489 .637 r
.59096 .38667 .59721 .42073 .60802 .40508 .6018 .3741 Mtetra
.649 .486 .649 r
.6018 .3741 .60802 .40508 .61881 .39026 .6127 .36458 Mtetra
.631 .492 .675 r
.6127 .36458 .61881 .39026 .62963 .37735 .62371 .35842 Mtetra
.593 .508 .728 r
.62371 .35842 .62963 .37735 .64055 .36778 .63488 .35613 Mtetra
.513 .554 .836 r
.63488 .35613 .64055 .36778 .65161 .36152 .64622 .35683 Mtetra
.194 .592 .944 r
.64622 .35683 .65161 .36152 .66284 .3586 .65771 .3593 Mtetra
.36 0 0 r
.65771 .3593 .66284 .3586 .67423 .35818 .66933 .36256 Mtetra
.469 0 0 r
.66933 .36256 .67423 .35818 .68578 .3593 .68102 .36542 Mtetra
.46 0 0 r
.68102 .36542 .68578 .3593 .69744 .36111 .69276 .36735 Mtetra
.391 0 0 r
.69276 .36735 .69744 .36111 .70917 .36255 .7045 .36766 Mtetra
.272 0 0 r
.7045 .36766 .70917 .36255 .72094 .36326 .71622 .36644 Mtetra
.038 0 0 r
.71622 .36644 .72094 .36326 .7327 .36268 .72792 .36367 Mtetra
.295 .787 .748 r
.72792 .36367 .7327 .36268 .74446 .36095 .73959 .35973 Mtetra
.568 .925 .947 r
.73959 .35973 .74446 .36095 .7562 .35808 .75125 .35498 Mtetra
.679 .91 .975 r
.75125 .35498 .7562 .35808 .76792 .35437 .76291 .34973 Mtetra
.706 .859 .955 r
.76291 .34973 .76792 .35437 .77966 .35009 .7746 .34435 Mtetra
.71 .82 .933 r
.7746 .34435 .77966 .35009 .79141 .34542 .78633 .33894 Mtetra
.703 .792 .92 r
.78633 .33894 .79141 .34542 .80318 .34062 .79812 .3337 Mtetra
.697 .776 .912 r
.79812 .3337 .80318 .34062 .815 .33573 .80995 .32859 Mtetra
.692 .768 .91 r
.80995 .32859 .815 .33573 .82685 .33083 .82184 .32361 Mtetra
.687 .764 .91 r
.82184 .32361 .82685 .33083 .83876 .32602 .83378 .31877 Mtetra
.636 .746 .928 r
.19348 .52013 .20012 .52592 .20962 .52365 .20304 .51743 Mtetra
.63 .731 .92 r
.20304 .51743 .20962 .52365 .21915 .52152 .21263 .51486 Mtetra
.621 .714 .912 r
.21263 .51486 .21915 .52152 .22871 .51953 .22223 .51251 Mtetra
.609 .699 .908 r
.22223 .51251 .22871 .51953 .2383 .51766 .23185 .51046 Mtetra
.59 .687 .909 r
.23185 .51046 .2383 .51766 .24792 .51596 .24148 .50882 Mtetra
.57 .683 .916 r
.24148 .50882 .24792 .51596 .25759 .51424 .25112 .50755 Mtetra
.542 .688 .934 r
.25112 .50755 .25759 .51424 .2673 .51241 .26078 .50669 Mtetra
.513 .713 .962 r
.26078 .50669 .2673 .51241 .2771 .5101 .27047 .50599 Mtetra
.457 .756 .994 r
.27047 .50599 .2771 .5101 .28699 .50702 .28021 .50532 Mtetra
.348 .791 .959 r
.28021 .50532 .28699 .50702 .297 .50281 .29004 .50419 Mtetra
0 0 0 r
.29004 .50419 .297 .50281 .30714 .4971 .29997 .50224 Mtetra
.06 0 0 r
.29997 .50224 .30714 .4971 .31739 .4899 .31003 .49899 Mtetra
.14 0 0 r
.31003 .49899 .31739 .4899 .32776 .48111 .32024 .49397 Mtetra
.173 0 .059 r
.32024 .49397 .32776 .48111 .33818 .47141 .33058 .48711 Mtetra
.16 0 .109 r
.33058 .48711 .33818 .47141 .34862 .46128 .34105 .47825 Mtetra
.124 0 .113 r
.34105 .47825 .34862 .46128 .35901 .45191 .35161 .46779 Mtetra
.024 0 .047 r
.35161 .46779 .35901 .45191 .36933 .44425 .36223 .45605 Mtetra
0 0 0 r
.36223 .45605 .36933 .44425 .37953 .43951 .37285 .44407 Mtetra
.749 .971 .702 r
.37285 .44407 .37953 .43951 .3896 .43857 .38343 .43259 Mtetra
.827 .784 .812 r
.38343 .43259 .3896 .43857 .3996 .44094 .39396 .422 Mtetra
.696 .563 .701 r
.39396 .422 .3996 .44094 .40957 .44634 .40444 .41275 Mtetra
.623 .46 .641 r
.40444 .41275 .40957 .44634 .41956 .4538 .41485 .40562 Mtetra
.584 .408 .609 r
.41485 .40562 .41956 .4538 .42963 .46217 .4252 .40075 Mtetra
.572 .387 .592 r
.4252 .40075 .42963 .46217 .43986 .46903 .43557 .39634 Mtetra
.567 .376 .582 r
.43557 .39634 .43986 .46903 .45027 .47252 .44598 .39189 Mtetra
.559 .367 .576 r
.44598 .39189 .45027 .47252 .46088 .47026 .4564 .38853 Mtetra
.553 .361 .575 r
.4564 .38853 .46088 .47026 .47163 .46234 .46683 .3864 Mtetra
.551 .362 .579 r
.46683 .3864 .47163 .46234 .48241 .45318 .4773 .385 Mtetra
.552 .368 .585 r
.4773 .385 .48241 .45318 .49318 .44528 .48783 .38357 Mtetra
.567 .383 .592 r
.48783 .38357 .49318 .44528 .50393 .4418 .49843 .38001 Mtetra
.579 .392 .592 r
.49843 .38001 .50393 .4418 .51471 .44274 .50908 .37431 Mtetra
.575 .385 .586 r
.50908 .37431 .51471 .44274 .52557 .44496 .51976 .36859 Mtetra
.568 .375 .58 r
.51976 .36859 .52557 .44496 .5365 .44595 .53047 .36358 Mtetra
.56 .367 .576 r
.53047 .36358 .5365 .44595 .54747 .44126 .54121 .35981 Mtetra
.556 .364 .576 r
.54121 .35981 .54747 .44126 .55841 .43074 .55201 .35715 Mtetra
.558 .369 .582 r
.55201 .35715 .55841 .43074 .5693 .4168 .56286 .35443 Mtetra
.558 .377 .591 r
.56286 .35443 .5693 .4168 .58014 .40129 .57376 .35219 Mtetra
.546 .381 .608 r
.57376 .35219 .58014 .40129 .59096 .38667 .58476 .35225 Mtetra
.523 .391 .643 r
.58476 .35225 .59096 .38667 .6018 .3741 .59587 .35447 Mtetra
.47 .426 .727 r
.59587 .35447 .6018 .3741 .6127 .36458 .60711 .35808 Mtetra
.13 .478 .897 r
.60711 .35808 .6127 .36458 .62371 .35842 .61847 .3626 Mtetra
.561 .042 0 r
.61847 .3626 .62371 .35842 .63488 .35613 .62995 .36768 Mtetra
.576 .166 .228 r
.62995 .36768 .63488 .35613 .64622 .35683 .64153 .37255 Mtetra
.551 .177 .285 r
.64153 .37255 .64622 .35683 .65771 .3593 .65317 .37612 Mtetra
.522 .157 .288 r
.65317 .37612 .65771 .3593 .66933 .36256 .66484 .37808 Mtetra
.477 .105 .255 r
.66484 .37808 .66933 .36256 .68102 .36542 .67649 .378 Mtetra
.405 .012 .176 r
.67649 .378 .68102 .36542 .69276 .36735 .68813 .37602 Mtetra
.259 0 .003 r
.68813 .37602 .69276 .36735 .7045 .36766 .69973 .37223 Mtetra
0 0 0 r
.69973 .37223 .7045 .36766 .71622 .36644 .7113 .36709 Mtetra
.519 .916 .829 r
.7113 .36709 .71622 .36644 .72792 .36367 .72285 .36108 Mtetra
.727 .939 .955 r
.72285 .36108 .72792 .36367 .73959 .35973 .7344 .3546 Mtetra
.746 .85 .928 r
.7344 .3546 .73959 .35973 .75125 .35498 .74599 .34812 Mtetra
.734 .788 .896 r
.74599 .34812 .75125 .35498 .76291 .34973 .75761 .34181 Mtetra
.716 .75 .879 r
.75761 .34181 .76291 .34973 .7746 .34435 .7693 .3359 Mtetra
.702 .731 .873 r
.7693 .3359 .7746 .34435 .78633 .33894 .78106 .33038 Mtetra
.69 .724 .876 r
.78106 .33038 .78633 .33894 .79812 .3337 .79288 .32528 Mtetra
.681 .725 .883 r
.79288 .32528 .79812 .3337 .80995 .32859 .80478 .32048 Mtetra
.676 .733 .893 r
.80478 .32048 .80995 .32859 .82184 .32361 .81674 .31591 Mtetra
.672 .744 .905 r
.81674 .31591 .82184 .32361 .83378 .31877 .82876 .31146 Mtetra
.667 .754 .916 r
.18679 .51429 .19348 .52013 .20304 .51743 .19644 .51085 Mtetra
.663 .729 .899 r
.19644 .51085 .20304 .51743 .21263 .51486 .20612 .50748 Mtetra
.654 .703 .883 r
.20612 .50748 .21263 .51486 .22223 .51251 .21582 .5043 Mtetra
.64 .677 .869 r
.21582 .5043 .22223 .51251 .23185 .51046 .22552 .50142 Mtetra
.623 .651 .856 r
.22552 .50142 .23185 .51046 .24148 .50882 .23523 .49899 Mtetra
.604 .625 .845 r
.23523 .49899 .24148 .50882 .25112 .50755 .24493 .49708 Mtetra
.58 .601 .838 r
.24493 .49708 .25112 .50755 .26078 .50669 .25462 .49585 Mtetra
.558 .583 .836 r
.25462 .49585 .26078 .50669 .27047 .50599 .2643 .49522 Mtetra
.532 .573 .842 r
.2643 .49522 .27047 .50599 .28021 .50532 .274 .49524 Mtetra
.512 .579 .86 r
.274 .49524 .28021 .50532 .29004 .50419 .28372 .49559 Mtetra
.488 .607 .897 r
.28372 .49559 .29004 .50419 .29997 .50224 .29349 .49607 Mtetra
.466 .68 .958 r
.29349 .49607 .29997 .50224 .31003 .49899 .30335 .49611 Mtetra
.4 .781 .991 r
.30335 .49611 .31003 .49899 .32024 .49397 .31333 .49526 Mtetra
.182 .712 .724 r
.31333 .49526 .32024 .49397 .33058 .48711 .32345 .493 Mtetra
.029 0 0 r
.32345 .493 .33058 .48711 .34105 .47825 .33372 .48887 Mtetra
.128 0 0 r
.33372 .48887 .34105 .47825 .35161 .46779 .34413 .48266 Mtetra
.154 0 .089 r
.34413 .48266 .35161 .46779 .36223 .45605 .35469 .47418 Mtetra
.161 0 .146 r
.35469 .47418 .36223 .45605 .37285 .44407 .36534 .46379 Mtetra
.139 0 .157 r
.36534 .46379 .37285 .44407 .38343 .43259 .37607 .45181 Mtetra
.099 0 .133 r
.37607 .45181 .38343 .43259 .39396 .422 .38681 .4391 Mtetra
.033 0 .074 r
.38681 .4391 .39396 .422 .40444 .41275 .39753 .42638 Mtetra
0 0 0 r
.39753 .42638 .40444 .41275 .41485 .40562 .4082 .4146 Mtetra
.4082 .4146 .41485 .40562 .4252 .40075 .4188 .4044 Mtetra
.614 .933 .708 r
.4188 .4044 .4252 .40075 .43557 .39634 .42936 .39566 Mtetra
.747 .967 .932 r
.42936 .39566 .43557 .39634 .44598 .39189 .43987 .38887 Mtetra
.56 .848 .998 r
.43987 .38887 .44598 .39189 .4564 .38853 .45031 .38626 Mtetra
.047 .583 .855 r
.45031 .38626 .4564 .38853 .46683 .3864 .4607 .38776 Mtetra
.368 0 0 r
.4607 .38776 .46683 .3864 .4773 .385 .47116 .39016 Mtetra
.417 0 0 r
.47116 .39016 .4773 .385 .48783 .38357 .48171 .39132 Mtetra
.211 0 0 r
.48171 .39132 .48783 .38357 .49843 .38001 .49239 .38775 Mtetra
0 0 0 r
.49239 .38775 .49843 .38001 .50908 .37431 .50314 .37943 Mtetra
.488 .829 .546 r
.50314 .37943 .50908 .37431 .51976 .36859 .5139 .36985 Mtetra
.74 .992 .841 r
.5139 .36985 .51976 .36859 .53047 .36358 .52466 .36116 Mtetra
.659 .909 .979 r
.52466 .36116 .53047 .36358 .54121 .35981 .53545 .35659 Mtetra
.356 .751 .985 r
.53545 .35659 .54121 .35981 .55201 .35715 .5463 .35623 Mtetra
0 .491 .708 r
.5463 .35623 .55201 .35715 .56286 .35443 .55723 .35786 Mtetra
.472 0 0 r
.55723 .35786 .56286 .35443 .57376 .35219 .56827 .36098 Mtetra
.575 .136 .167 r
.56827 .36098 .57376 .35219 .58476 .35225 .57943 .36573 Mtetra
.593 .202 .272 r
.57943 .36573 .58476 .35225 .59587 .35447 .5907 .37147 Mtetra
.587 .221 .314 r
.5907 .37147 .59587 .35447 .60711 .35808 .60209 .37722 Mtetra
.574 .219 .329 r
.60209 .37722 .60711 .35808 .61847 .3626 .61358 .38227 Mtetra
.549 .198 .325 r
.61358 .38227 .61847 .3626 .62995 .36768 .62512 .38571 Mtetra
.515 .157 .297 r
.62512 .38571 .62995 .36768 .64153 .37255 .63669 .38723 Mtetra
.453 .075 .23 r
.63669 .38723 .64153 .37255 .65317 .37612 .64826 .38643 Mtetra
.333 0 .085 r
.64826 .38643 .65317 .37612 .66484 .37808 .65981 .38351 Mtetra
.026 0 0 r
.65981 .38351 .66484 .37808 .67649 .378 .67132 .37866 Mtetra
.554 .932 .84 r
.67132 .37866 .67649 .378 .68813 .37602 .6828 .37235 Mtetra
.771 .905 .934 r
.6828 .37235 .68813 .37602 .69973 .37223 .69426 .3651 Mtetra
.767 .786 .868 r
.69426 .3651 .69973 .37223 .7113 .36709 .70572 .35739 Mtetra
.741 .713 .826 r
.70572 .35739 .7113 .36709 .72285 .36108 .7172 .3498 Mtetra
.72 .674 .804 r
.7172 .3498 .72285 .36108 .7344 .3546 .72873 .34253 Mtetra
.701 .653 .798 r
.72873 .34253 .7344 .3546 .74599 .34812 .74033 .33592 Mtetra
.688 .645 .801 r
.74033 .33592 .74599 .34812 .75761 .34181 .752 .32994 Mtetra
.675 .645 .812 r
.752 .32994 .75761 .34181 .7693 .3359 .76375 .32464 Mtetra
.666 .652 .827 r
.76375 .32464 .7693 .3359 .78106 .33038 .77559 .31988 Mtetra
.658 .665 .845 r
.77559 .31988 .78106 .33038 .79288 .32528 .78751 .31559 Mtetra
.652 .681 .864 r
.78751 .31559 .79288 .32528 .80478 .32048 .79951 .31161 Mtetra
.648 .701 .885 r
.79951 .31161 .80478 .32048 .81674 .31591 .81158 .30782 Mtetra
.646 .724 .905 r
.81158 .30782 .81674 .31591 .82876 .31146 .82371 .3041 Mtetra
.695 .76 .901 r
.18006 .50842 .18679 .51429 .19644 .51085 .18981 .50417 Mtetra
.693 .735 .883 r
.18981 .50417 .19644 .51085 .20612 .50748 .1996 .49989 Mtetra
.685 .708 .865 r
.1996 .49989 .20612 .50748 .21582 .5043 .20941 .49568 Mtetra
.674 .68 .847 r
.20941 .49568 .21582 .5043 .22552 .50142 .21923 .49165 Mtetra
.66 .65 .829 r
.21923 .49165 .22552 .50142 .23523 .49899 .22906 .48789 Mtetra
.642 .617 .81 r
.22906 .48789 .23523 .49899 .24493 .49708 .23888 .48457 Mtetra
.621 .585 .792 r
.23888 .48457 .24493 .49708 .25462 .49585 .24869 .48187 Mtetra
.598 .553 .775 r
.24869 .48187 .25462 .49585 .2643 .49522 .25848 .47991 Mtetra
.572 .523 .762 r
.25848 .47991 .2643 .49522 .274 .49524 .26824 .47887 Mtetra
.548 .498 .752 r
.26824 .47887 .274 .49524 .28372 .49559 .27798 .47874 Mtetra
.523 .478 .748 r
.27798 .47874 .28372 .49559 .29349 .49607 .28771 .47958 Mtetra
.502 .47 .754 r
.28771 .47958 .29349 .49607 .30335 .49611 .29745 .48108 Mtetra
.48 .475 .775 r
.29745 .48108 .30335 .49611 .31333 .49526 .30723 .48307 Mtetra
.456 .508 .824 r
.30723 .48307 .31333 .49526 .32345 .493 .31709 .48503 Mtetra
.404 .59 .918 r
.31709 .48503 .32345 .493 .33372 .48887 .32703 .48657 Mtetra
.139 .649 .898 r
.32703 .48657 .33372 .48887 .34413 .48266 .3371 .48731 Mtetra
.294 0 0 r
.3371 .48731 .34413 .48266 .35469 .47418 .34729 .48688 Mtetra
.391 0 .167 r
.34729 .48688 .35469 .47418 .36534 .46379 .35762 .48482 Mtetra
.41 .078 .288 r
.35762 .48482 .36534 .46379 .37607 .45181 .36808 .48088 Mtetra
.431 .129 .35 r
.36808 .48088 .37607 .45181 .38681 .4391 .37864 .4759 Mtetra
.447 .162 .386 r
.37864 .4759 .38681 .4391 .39753 .42638 .38924 .47028 Mtetra
.452 .178 .406 r
.38924 .47028 .39753 .42638 .4082 .4146 .39991 .46373 Mtetra
.457 .189 .418 r
.39991 .46373 .4082 .4146 .4188 .4044 .41063 .4566 Mtetra
.472 .206 .428 r
.41063 .4566 .4188 .4044 .42936 .39566 .42132 .45065 Mtetra
.493 .226 .438 r
.42132 .45065 .42936 .39566 .43987 .38887 .43197 .44685 Mtetra
.517 .249 .448 r
.43197 .44685 .43987 .38887 .45031 .38626 .4426 .44603 Mtetra
.534 .265 .454 r
.4426 .44603 .45031 .38626 .4607 .38776 .45322 .44781 Mtetra
.531 .262 .453 r
.45322 .44781 .4607 .38776 .47116 .39016 .46393 .44912 Mtetra
.518 .25 .449 r
.46393 .44912 .47116 .39016 .48171 .39132 .47474 .44848 Mtetra
.497 .231 .441 r
.47474 .44848 .48171 .39132 .49239 .38775 .48566 .44494 Mtetra
.476 .213 .436 r
.48566 .44494 .49239 .38775 .50314 .37943 .49664 .43848 Mtetra
.463 .204 .436 r
.49664 .43848 .50314 .37943 .5139 .36985 .50765 .43006 Mtetra
.461 .204 .437 r
.50765 .43006 .5139 .36985 .52466 .36116 .51868 .42115 Mtetra
.48 .219 .441 r
.51868 .42115 .52466 .36116 .53545 .35659 .52972 .41483 Mtetra
.5 .234 .443 r
.52972 .41483 .53545 .35659 .5463 .35623 .5408 .41152 Mtetra
.513 .243 .442 r
.5408 .41152 .5463 .35623 .55723 .35786 .55195 .41038 Mtetra
.521 .247 .44 r
.55195 .41038 .55723 .35786 .56827 .36098 .56317 .41046 Mtetra
.515 .239 .433 r
.56317 .41046 .56827 .36098 .57943 .36573 .57446 .40995 Mtetra
.505 .224 .421 r
.57446 .40995 .57943 .36573 .5907 .37147 .58579 .4085 Mtetra
.492 .201 .399 r
.58579 .4085 .5907 .37147 .60209 .37722 .59717 .40641 Mtetra
.465 .159 .362 r
.59717 .40641 .60209 .37722 .61358 .38227 .60859 .40327 Mtetra
.395 .066 .285 r
.60859 .40327 .61358 .38227 .62512 .38571 .62 .3982 Mtetra
.221 0 .091 r
.62 .3982 .62512 .38571 .63669 .38723 .63139 .39145 Mtetra
0 0 0 r
.63139 .39145 .63669 .38723 .64826 .38643 .64276 .38348 Mtetra
.816 .93 .908 r
.64276 .38348 .64826 .38643 .65981 .38351 .65412 .37468 Mtetra
.78 .743 .82 r
.65412 .37468 .65981 .38351 .67132 .37866 .66547 .36542 Mtetra
.737 .65 .763 r
.66547 .36542 .67132 .37866 .6828 .37235 .67682 .35613 Mtetra
.707 .602 .736 r
.67682 .35613 .6828 .37235 .69426 .3651 .6882 .3473 Mtetra
.687 .577 .726 r
.6882 .3473 .69426 .3651 .70572 .35739 .69964 .33915 Mtetra
.671 .564 .726 r
.69964 .33915 .70572 .35739 .7172 .3498 .71115 .33198 Mtetra
.659 .562 .733 r
.71115 .33198 .7172 .3498 .72873 .34253 .72274 .32574 Mtetra
.649 .566 .747 r
.72274 .32574 .72873 .34253 .74033 .33592 .73443 .32045 Mtetra
.641 .576 .766 r
.73443 .32045 .74033 .33592 .752 .32994 .74621 .31593 Mtetra
.634 .591 .788 r
.74621 .31593 .752 .32994 .76375 .32464 .75808 .31204 Mtetra
.628 .61 .813 r
.75808 .31204 .76375 .32464 .77559 .31988 .77004 .30861 Mtetra
.624 .633 .839 r
.77004 .30861 .77559 .31988 .78751 .31559 .78208 .30546 Mtetra
.621 .657 .864 r
.78208 .30546 .78751 .31559 .79951 .31161 .79419 .3025 Mtetra
.618 .682 .888 r
.79419 .3025 .79951 .31161 .81158 .30782 .80637 .29961 Mtetra
.618 .708 .91 r
.80637 .29961 .81158 .30782 .82371 .3041 .81861 .29669 Mtetra
.708 .762 .894 r
.17328 .5025 .18006 .50842 .18981 .50417 .1831 .49783 Mtetra
.709 .75 .884 r
.1831 .49783 .18981 .50417 .1996 .49989 .19296 .49304 Mtetra
.708 .735 .872 r
.19296 .49304 .1996 .49989 .20941 .49568 .20285 .48818 Mtetra
.704 .717 .859 r
.20285 .48818 .20941 .49568 .21923 .49165 .21277 .4833 Mtetra
.698 .695 .843 r
.21277 .4833 .21923 .49165 .22906 .48789 .22271 .47842 Mtetra
.686 .667 .826 r
.22271 .47842 .22906 .48789 .23888 .48457 .23267 .47371 Mtetra
.67 .635 .806 r
.23267 .47371 .23888 .48457 .24869 .48187 .24263 .4693 Mtetra
.649 .598 .784 r
.24263 .4693 .24869 .48187 .25848 .47991 .25257 .4654 Mtetra
.624 .561 .763 r
.25257 .4654 .25848 .47991 .26824 .47887 .26249 .46222 Mtetra
.598 .524 .742 r
.26249 .46222 .26824 .47887 .27798 .47874 .27239 .45993 Mtetra
.572 .49 .724 r
.27239 .45993 .27798 .47874 .28771 .47958 .28224 .45874 Mtetra
.548 .46 .708 r
.28224 .45874 .28771 .47958 .29745 .48108 .29207 .45863 Mtetra
.525 .436 .697 r
.29207 .45863 .29745 .48108 .30723 .48307 .30187 .45966 Mtetra
.509 .42 .69 r
.30187 .45966 .30723 .48307 .31709 .48503 .31169 .46154 Mtetra
.496 .411 .69 r
.31169 .46154 .31709 .48503 .32703 .48657 .32154 .46406 Mtetra
.485 .411 .698 r
.32154 .46406 .32703 .48657 .3371 .48731 .33144 .46694 Mtetra
.477 .421 .716 r
.33144 .46694 .3371 .48731 .34729 .48688 .34142 .46987 Mtetra
.479 .454 .752 r
.34142 .46987 .34729 .48688 .35762 .48482 .3515 .47219 Mtetra
.488 .522 .818 r
.3515 .47219 .35762 .48482 .36808 .48088 .36172 .47347 Mtetra
.452 .637 .935 r
.36172 .47347 .36808 .48088 .37864 .4759 .37203 .47405 Mtetra
.209 .708 .912 r
.37203 .47405 .37864 .4759 .38924 .47028 .38245 .47393 Mtetra
.112 0 0 r
.38245 .47393 .38924 .47028 .39991 .46373 .39299 .47215 Mtetra
.22 0 0 r
.39299 .47215 .39991 .46373 .41063 .4566 .40365 .4686 Mtetra
.324 0 .112 r
.40365 .4686 .41063 .4566 .42132 .45065 .41435 .46517 Mtetra
.387 .009 .194 r
.41435 .46517 .42132 .45065 .43197 .44685 .42507 .46243 Mtetra
.388 .019 .212 r
.42507 .46243 .43197 .44685 .4426 .44603 .43584 .45935 Mtetra
.337 0 .148 r
.43584 .45935 .4426 .44603 .45322 .44781 .44668 .45563 Mtetra
.129 0 0 r
.44668 .45563 .45322 .44781 .46393 .44912 .45757 .45101 Mtetra
.413 .856 .765 r
.45757 .45101 .46393 .44912 .47474 .44848 .46851 .44589 Mtetra
.594 .884 .992 r
.46851 .44589 .47474 .44848 .48566 .44494 .47947 .44233 Mtetra
.467 .833 .993 r
.47947 .44233 .48566 .44494 .49664 .43848 .49045 .44032 Mtetra
0 0 0 r
.49045 .44032 .49664 .43848 .50765 .43006 .50149 .43781 Mtetra
.216 0 0 r
.50149 .43781 .50765 .43006 .51868 .42115 .51258 .43441 Mtetra
.329 0 .144 r
.51258 .43441 .51868 .42115 .52972 .41483 .52372 .43036 Mtetra
.352 0 .196 r
.52372 .43036 .52972 .41483 .5408 .41152 .53491 .42597 Mtetra
.36 0 .182 r
.53491 .42597 .5408 .41152 .55195 .41038 .54613 .42227 Mtetra
.325 0 .113 r
.54613 .42227 .55195 .41038 .56317 .41046 .55741 .41868 Mtetra
.122 0 0 r
.55741 .41868 .56317 .41046 .57446 .40995 .56871 .4133 Mtetra
.399 .816 .626 r
.56871 .4133 .57446 .40995 .58579 .4085 .58001 .40623 Mtetra
.784 .945 .929 r
.58001 .40623 .58579 .4085 .59717 .40641 .59132 .39842 Mtetra
.775 .759 .839 r
.59132 .39842 .59717 .40641 .60859 .40327 .60263 .3899 Mtetra
.74 .649 .758 r
.60263 .3899 .60859 .40327 .62 .3982 .61392 .38028 Mtetra
.714 .59 .716 r
.61392 .38028 .62 .3982 .63139 .39145 .6252 .37001 Mtetra
.692 .554 .693 r
.6252 .37001 .63139 .39145 .64276 .38348 .63648 .35978 Mtetra
.678 .533 .681 r
.63648 .35978 .64276 .38348 .65412 .37468 .64778 .34989 Mtetra
.666 .521 .677 r
.64778 .34989 .65412 .37468 .66547 .36542 .6591 .34064 Mtetra
.657 .515 .679 r
.6591 .34064 .66547 .36542 .67682 .35613 .67048 .33224 Mtetra
.647 .513 .686 r
.67048 .33224 .67682 .35613 .6882 .3473 .68192 .32501 Mtetra
.639 .517 .698 r
.68192 .32501 .6882 .3473 .69964 .33915 .69345 .31888 Mtetra
.63 .525 .716 r
.69345 .31888 .69964 .33915 .71115 .33198 .70507 .31388 Mtetra
.623 .538 .738 r
.70507 .31388 .71115 .33198 .72274 .32574 .71679 .30979 Mtetra
.616 .556 .765 r
.71679 .30979 .72274 .32574 .73443 .32045 .72861 .30644 Mtetra
.609 .578 .794 r
.72861 .30644 .73443 .32045 .74621 .31593 .74052 .30363 Mtetra
.605 .604 .824 r
.74052 .30363 .74621 .31593 .75808 .31204 .75251 .30113 Mtetra
.601 .629 .852 r
.75251 .30113 .75808 .31204 .77004 .30861 .76458 .29881 Mtetra
.6 .655 .876 r
.76458 .29881 .77004 .30861 .78208 .30546 .77671 .29649 Mtetra
.598 .677 .896 r
.77671 .29649 .78208 .30546 .79419 .3025 .78891 .29416 Mtetra
.598 .696 .911 r
.78891 .29416 .79419 .3025 .80637 .29961 .80116 .29175 Mtetra
.6 .713 .923 r
.80116 .29175 .80637 .29961 .81861 .29669 .81347 .28921 Mtetra
.705 .762 .896 r
.16646 .49655 .17328 .5025 .1831 .49783 .17629 .49194 Mtetra
.711 .765 .895 r
.17629 .49194 .1831 .49783 .19296 .49304 .18617 .48717 Mtetra
.716 .768 .893 r
.18617 .48717 .19296 .49304 .20285 .48818 .19609 .4822 Mtetra
.722 .766 .887 r
.19609 .4822 .20285 .48818 .21277 .4833 .20606 .47701 Mtetra
.727 .758 .877 r
.20606 .47701 .21277 .4833 .22271 .47842 .21608 .47155 Mtetra
.727 .742 .863 r
.21608 .47155 .22271 .47842 .23267 .47371 .22615 .46591 Mtetra
.723 .717 .844 r
.22615 .46591 .23267 .47371 .24263 .4693 .23624 .46013 Mtetra
.711 .683 .822 r
.23624 .46013 .24263 .4693 .25257 .4654 .24636 .45441 Mtetra
.693 .643 .796 r
.24636 .45441 .25257 .4654 .26249 .46222 .25648 .44888 Mtetra
.669 .599 .768 r
.25648 .44888 .26249 .46222 .27239 .45993 .26659 .44378 Mtetra
.642 .554 .74 r
.26659 .44378 .27239 .45993 .28224 .45874 .27668 .43934 Mtetra
.615 .512 .714 r
.27668 .43934 .28224 .45874 .29207 .45863 .28673 .43575 Mtetra
.589 .474 .691 r
.28673 .43575 .29207 .45863 .30187 .45966 .29675 .43323 Mtetra
.568 .444 .671 r
.29675 .43323 .30187 .45966 .31169 .46154 .30674 .43174 Mtetra
.55 .419 .655 r
.30674 .43174 .31169 .46154 .32154 .46406 .31671 .43131 Mtetra
.536 .401 .644 r
.31671 .43131 .32154 .46406 .33144 .46694 .32669 .43184 Mtetra
.526 .387 .635 r
.32669 .43184 .33144 .46694 .34142 .46987 .33667 .43321 Mtetra
.52 .38 .631 r
.33667 .43321 .34142 .46987 .3515 .47219 .3467 .4351 Mtetra
.518 .377 .63 r
.3467 .4351 .3515 .47219 .36172 .47347 .35679 .4372 Mtetra
.518 .38 .633 r
.35679 .4372 .36172 .47347 .37203 .47405 .36696 .43923 Mtetra
.523 .388 .638 r
.36696 .43923 .37203 .47405 .38245 .47393 .37723 .44083 Mtetra
.538 .403 .645 r
.37723 .44083 .38245 .47393 .39299 .47215 .38761 .44125 Mtetra
.559 .425 .654 r
.38761 .44125 .39299 .47215 .40365 .4686 .39813 .44007 Mtetra
.575 .444 .664 r
.39813 .44007 .40365 .4686 .41435 .46517 .40874 .43783 Mtetra
.595 .462 .669 r
.40874 .43783 .41435 .46517 .42507 .46243 .41944 .43424 Mtetra
.636 .486 .662 r
.41944 .43424 .42507 .46243 .43584 .45935 .43029 .42686 Mtetra
.657 .488 .643 r
.43029 .42686 .43584 .45935 .44668 .45563 .44126 .41583 Mtetra
.641 .461 .624 r
.44126 .41583 .44668 .45563 .45757 .45101 .45223 .40445 Mtetra
.615 .432 .612 r
.45223 .40445 .45757 .45101 .46851 .44589 .46315 .39501 Mtetra
.569 .393 .604 r
.46315 .39501 .46851 .44589 .47947 .44233 .47398 .39138 Mtetra
.523 .36 .602 r
.47398 .39138 .47947 .44233 .49045 .44032 .48479 .39358 Mtetra
.503 .352 .609 r
.48479 .39358 .49045 .44032 .50149 .43781 .49566 .39774 Mtetra
.501 .363 .624 r
.49566 .39774 .50149 .43781 .51258 .43441 .50663 .40157 Mtetra
.541 .409 .649 r
.50663 .40157 .51258 .43441 .52372 .43036 .5177 .40175 Mtetra
.592 .457 .666 r
.5177 .40175 .52372 .43036 .53491 .42597 .52884 .39813 Mtetra
.61 .471 .668 r
.52884 .39813 .53491 .42597 .54613 .42227 .54002 .39312 Mtetra
.619 .473 .661 r
.54002 .39312 .54613 .42227 .55741 .41868 .55122 .38705 Mtetra
.629 .472 .65 r
.55122 .38705 .55741 .41868 .56871 .4133 .56244 .37934 Mtetra
.634 .469 .641 r
.56244 .37934 .56871 .4133 .58001 .40623 .57365 .37041 Mtetra
.633 .464 .636 r
.57365 .37041 .58001 .40623 .59132 .39842 .58487 .36103 Mtetra
.63 .458 .631 r
.58487 .36103 .59132 .39842 .60263 .3899 .59609 .35156 Mtetra
.627 .454 .629 r
.59609 .35156 .60263 .3899 .61392 .38028 .60732 .34229 Mtetra
.623 .452 .63 r
.60732 .34229 .61392 .38028 .6252 .37001 .61858 .33351 Mtetra
.619 .452 .634 r
.61858 .33351 .6252 .37001 .63648 .35978 .62987 .32559 Mtetra
.615 .455 .642 r
.62987 .32559 .63648 .35978 .64778 .34989 .64122 .31863 Mtetra
.611 .46 .653 r
.64122 .31863 .64778 .34989 .6591 .34064 .65263 .31276 Mtetra
.606 .469 .669 r
.65263 .31276 .6591 .34064 .67048 .33224 .66413 .30793 Mtetra
.6 .482 .69 r
.66413 .30793 .67048 .33224 .68192 .32501 .67572 .30421 Mtetra
.594 .499 .717 r
.67572 .30421 .68192 .32501 .69345 .31888 .6874 .30136 Mtetra
.588 .524 .75 r
.6874 .30136 .69345 .31888 .70507 .31388 .69918 .29919 Mtetra
.582 .553 .788 r
.69918 .29919 .70507 .31388 .71679 .30979 .71105 .29747 Mtetra
.577 .588 .828 r
.71105 .29747 .71679 .30979 .72861 .30644 .723 .29596 Mtetra
.572 .624 .865 r
.723 .29596 .72861 .30644 .74052 .30363 .73503 .29451 Mtetra
.571 .659 .896 r
.73503 .29451 .74052 .30363 .75251 .30113 .74711 .29292 Mtetra
.572 .687 .918 r
.74711 .29292 .75251 .30113 .76458 .29881 .75925 .29115 Mtetra
.58 .709 .931 r
.75925 .29115 .76458 .29881 .77671 .29649 .77144 .2891 Mtetra
.586 .722 .937 r
.77144 .2891 .77671 .29649 .78891 .29416 .78368 .28682 Mtetra
.594 .728 .938 r
.78368 .28682 .78891 .29416 .80116 .29175 .79596 .28434 Mtetra
.601 .73 .935 r
.79596 .28434 .80116 .29175 .81347 .28921 .8083 .28168 Mtetra
.681 .757 .909 r
.15958 .49055 .16646 .49655 .17629 .49194 .16936 .48663 Mtetra
.688 .782 .923 r
.16936 .48663 .17629 .49194 .18617 .48717 .17919 .48255 Mtetra
.697 .809 .935 r
.17919 .48255 .18617 .48717 .19609 .4822 .18908 .47825 Mtetra
.708 .836 .943 r
.18908 .47825 .19609 .4822 .20606 .47701 .19902 .47363 Mtetra
.722 .859 .946 r
.19902 .47363 .20606 .47701 .21608 .47155 .20903 .46861 Mtetra
.736 .877 .946 r
.20903 .46861 .21608 .47155 .22615 .46591 .21911 .46318 Mtetra
.751 .886 .94 r
.21911 .46318 .22615 .46591 .23624 .46013 .22925 .45733 Mtetra
.763 .884 .932 r
.22925 .45733 .23624 .46013 .24636 .45441 .23944 .45113 Mtetra
.771 .868 .92 r
.23944 .45113 .24636 .45441 .25648 .44888 .24967 .44465 Mtetra
.77 .835 .902 r
.24967 .44465 .25648 .44888 .26659 .44378 .25993 .43807 Mtetra
.757 .786 .876 r
.25993 .43807 .26659 .44378 .27668 .43934 .27021 .43154 Mtetra
.732 .724 .844 r
.27021 .43154 .27668 .43934 .28673 .43575 .28048 .42533 Mtetra
.699 .659 .806 r
.28048 .42533 .28673 .43575 .29675 .43323 .29073 .41965 Mtetra
.665 .596 .768 r
.29073 .41965 .29675 .43323 .30674 .43174 .30096 .41464 Mtetra
.632 .541 .734 r
.30096 .41464 .30674 .43174 .31671 .43131 .31117 .41046 Mtetra
.606 .497 .704 r
.31117 .41046 .31671 .43131 .32669 .43184 .32135 .40712 Mtetra
.583 .462 .68 r
.32135 .40712 .32669 .43184 .33667 .43321 .33153 .40465 Mtetra
.565 .435 .661 r
.33153 .40465 .33667 .43321 .3467 .4351 .34169 .40308 Mtetra
.552 .414 .647 r
.34169 .40308 .3467 .4351 .35679 .4372 .35187 .40237 Mtetra
.547 .403 .637 r
.35187 .40237 .35679 .4372 .36696 .43923 .36208 .40194 Mtetra
.547 .398 .63 r
.36208 .40194 .36696 .43923 .37723 .44083 .37236 .40144 Mtetra
.547 .394 .625 r
.37236 .40144 .37723 .44083 .38761 .44125 .3827 .40086 Mtetra
.55 .394 .622 r
.3827 .40086 .38761 .44125 .39813 .44007 .39312 .39993 Mtetra
.559 .401 .624 r
.39312 .39993 .39813 .44007 .40874 .43783 .40362 .39816 Mtetra
.574 .413 .625 r
.40362 .39816 .40874 .43783 .41944 .43424 .41424 .39484 Mtetra
.608 .438 .626 r
.41424 .39484 .41944 .43424 .43029 .42686 .42501 .38776 Mtetra
.637 .459 .625 r
.42501 .38776 .43029 .42686 .44126 .41583 .4359 .37708 Mtetra
.637 .459 .626 r
.4359 .37708 .44126 .41583 .45223 .40445 .44678 .36643 Mtetra
.622 .45 .628 r
.44678 .36643 .45223 .40445 .46315 .39501 .45762 .3579 Mtetra
.58 .422 .632 r
.45762 .3579 .46315 .39501 .47398 .39138 .46838 .35422 Mtetra
.528 .386 .632 r
.46838 .35422 .47398 .39138 .48479 .39358 .47911 .35539 Mtetra
.503 .367 .628 r
.47911 .35539 .48479 .39358 .49566 .39774 .4899 .35871 Mtetra
.504 .366 .626 r
.4899 .35871 .49566 .39774 .50663 .40157 .50077 .36208 Mtetra
.543 .393 .627 r
.50077 .36208 .50663 .40157 .5177 .40175 .51176 .36185 Mtetra
.58 .418 .626 r
.51176 .36185 .5177 .40175 .52884 .39813 .52281 .35784 Mtetra
.593 .426 .625 r
.52281 .35784 .52884 .39813 .54002 .39312 .5339 .35226 Mtetra
.599 .429 .623 r
.5339 .35226 .54002 .39312 .55122 .38705 .54502 .34582 Mtetra
.601 .43 .622 r
.54502 .34582 .55122 .38705 .56244 .37934 .55616 .33901 Mtetra
.604 .433 .624 r
.55616 .33901 .56244 .37934 .57365 .37041 .56733 .33211 Mtetra
.607 .44 .629 r
.56733 .33211 .57365 .37041 .58487 .36103 .57851 .32513 Mtetra
.609 .446 .636 r
.57851 .32513 .58487 .36103 .59609 .35156 .58973 .31843 Mtetra
.606 .451 .646 r
.58973 .31843 .59609 .35156 .60732 .34229 .60099 .31258 Mtetra
.603 .46 .659 r
.60099 .31258 .60732 .34229 .61858 .33351 .61231 .30765 Mtetra
.601 .473 .679 r
.61231 .30765 .61858 .33351 .62987 .32559 .6237 .30361 Mtetra
.597 .492 .706 r
.6237 .30361 .62987 .32559 .64122 .31863 .63516 .30043 Mtetra
.59 .517 .741 r
.63516 .30043 .64122 .31863 .65263 .31276 .64671 .29809 Mtetra
.58 .551 .787 r
.64671 .29809 .65263 .31276 .66413 .30793 .65835 .29645 Mtetra
.562 .595 .844 r
.65835 .29645 .66413 .30793 .67572 .30421 .67008 .29537 Mtetra
.536 .647 .906 r
.67008 .29537 .67572 .30421 .6874 .30136 .6819 .29462 Mtetra
.503 .7 .958 r
.6819 .29462 .6874 .30136 .69918 .29919 .69379 .29393 Mtetra
.468 .741 .988 r
.69379 .29393 .69918 .29919 .71105 .29747 .70575 .29315 Mtetra
.45 .771 .997 r
.70575 .29315 .71105 .29747 .723 .29596 .71777 .29207 Mtetra
.454 .791 .999 r
.71777 .29207 .723 .29596 .73503 .29451 .72985 .29066 Mtetra
.483 .808 1 r
.72985 .29066 .73503 .29451 .74711 .29292 .74196 .28879 Mtetra
.521 .817 .999 r
.74196 .28879 .74711 .29292 .75925 .29115 .75411 .28652 Mtetra
.562 .816 .993 r
.75411 .28652 .75925 .29115 .77144 .2891 .76629 .28381 Mtetra
.593 .805 .981 r
.76629 .28381 .77144 .2891 .78368 .28682 .77851 .28079 Mtetra
.615 .786 .964 r
.77851 .28079 .78368 .28682 .79596 .28434 .79077 .27752 Mtetra
.627 .764 .945 r
.79077 .27752 .79596 .28434 .8083 .28168 .80308 .27409 Mtetra
.637 .747 .928 r
.15266 .48451 .15958 .49055 .16936 .48663 .16235 .48164 Mtetra
.636 .785 .953 r
.16235 .48164 .16936 .48663 .17919 .48255 .17208 .47868 Mtetra
.634 .827 .975 r
.17208 .47868 .17919 .48255 .18908 .47825 .18187 .47552 Mtetra
.63 .87 .987 r
.18187 .47552 .18908 .47825 .19902 .47363 .19173 .47208 Mtetra
.621 .908 .983 r
.19173 .47208 .19902 .47363 .20903 .46861 .20166 .46824 Mtetra
.603 .933 .958 r
.20166 .46824 .20903 .46861 .21911 .46318 .21167 .46393 Mtetra
.583 .941 .913 r
.21167 .46393 .21911 .46318 .22925 .45733 .22177 .45905 Mtetra
.562 .936 .858 r
.22177 .45905 .22925 .45733 .23944 .45113 .23194 .4536 Mtetra
.559 .932 .814 r
.23194 .4536 .23944 .45113 .24967 .44465 .24219 .44753 Mtetra
.573 .935 .792 r
.24219 .44753 .24967 .44465 .25993 .43807 .25251 .44091 Mtetra
.619 .954 .804 r
.25251 .44091 .25993 .43807 .27021 .43154 .26289 .43378 Mtetra
.682 .979 .845 r
.26289 .43378 .27021 .43154 .28048 .42533 .27331 .42632 Mtetra
.752 .988 .895 r
.27331 .42632 .28048 .42533 .29073 .41965 .28376 .4187 Mtetra
.794 .951 .921 r
.28376 .4187 .29073 .41965 .30096 .41464 .29421 .41113 Mtetra
.792 .866 .904 r
.29421 .41113 .30096 .41464 .31117 .41046 .30467 .40378 Mtetra
.76 .764 .856 r
.30467 .40378 .31117 .41046 .32135 .40712 .31512 .39673 Mtetra
.718 .669 .801 r
.31512 .39673 .32135 .40712 .33153 .40465 .32556 .39009 Mtetra
.675 .591 .754 r
.32556 .39009 .33153 .40465 .34169 .40308 .33597 .38419 Mtetra
.638 .531 .717 r
.33597 .38419 .34169 .40308 .35187 .40237 .34636 .37918 Mtetra
.617 .492 .687 r
.34636 .37918 .35187 .40237 .36208 .40194 .35676 .37456 Mtetra
.604 .465 .665 r
.35676 .37456 .36208 .40194 .37236 .40144 .36718 .37017 Mtetra
.583 .438 .65 r
.36718 .37017 .37236 .40144 .3827 .40086 .37759 .36685 Mtetra
.566 .418 .64 r
.37759 .36685 .3827 .40086 .39312 .39993 .38799 .36476 Mtetra
.563 .413 .636 r
.38799 .36476 .39312 .39993 .40362 .39816 .39843 .36285 Mtetra
.567 .417 .636 r
.39843 .36285 .40362 .39816 .41424 .39484 .40893 .36052 Mtetra
.583 .43 .64 r
.40893 .36052 .41424 .39484 .42501 .38776 .41953 .35685 Mtetra
.603 .454 .651 r
.41953 .35685 .42501 .38776 .4359 .37708 .43022 .35182 Mtetra
.613 .481 .677 r
.43022 .35182 .4359 .37708 .44678 .36643 .44093 .34699 Mtetra
.62 .52 .718 r
.44093 .34699 .44678 .36643 .45762 .3579 .45165 .34285 Mtetra
.628 .566 .765 r
.45165 .34285 .45762 .3579 .46838 .35422 .46241 .33913 Mtetra
.619 .561 .767 r
.46241 .33913 .46838 .35422 .47911 .35539 .47321 .33584 Mtetra
.593 .503 .722 r
.47321 .33584 .47911 .35539 .4899 .35871 .48404 .33324 Mtetra
.579 .459 .68 r
.48404 .33324 .4899 .35871 .50077 .36208 .49492 .33085 Mtetra
.588 .443 .652 r
.49492 .33085 .50077 .36208 .51176 .36185 .50586 .32708 Mtetra
.596 .439 .639 r
.50586 .32708 .51176 .36185 .52281 .35784 .51685 .32197 Mtetra
.598 .438 .636 r
.51685 .32197 .52281 .35784 .5339 .35226 .52788 .31643 Mtetra
.597 .437 .636 r
.52788 .31643 .5339 .35226 .54502 .34582 .53893 .31106 Mtetra
.586 .432 .64 r
.53893 .31106 .54502 .34582 .55616 .33901 .55003 .30693 Mtetra
.578 .434 .65 r
.55003 .30693 .55616 .33901 .56733 .33211 .56119 .30389 Mtetra
.58 .449 .667 r
.56119 .30389 .56733 .33211 .57851 .32513 .5724 .30109 Mtetra
.581 .469 .691 r
.5724 .30109 .57851 .32513 .58973 .31843 .58367 .29867 Mtetra
.571 .491 .726 r
.58367 .29867 .58973 .31843 .60099 .31258 .59502 .29718 Mtetra
.556 .527 .778 r
.59502 .29718 .60099 .31258 .61231 .30765 .60645 .29645 Mtetra
.534 .585 .852 r
.60645 .29645 .61231 .30765 .6237 .30361 .61797 .29614 Mtetra
.479 .66 .941 r
.61797 .29614 .6237 .30361 .63516 .30043 .62957 .29615 Mtetra
.344 .712 .985 r
.62957 .29615 .63516 .30043 .64671 .29809 .64125 .2964 Mtetra
.132 .661 .87 r
.64125 .2964 .64671 .29809 .65835 .29645 .65302 .29671 Mtetra
.04 0 0 r
.65302 .29671 .65835 .29645 .67008 .29537 .66487 .29687 Mtetra
.115 0 0 r
.66487 .29687 .67008 .29537 .6819 .29462 .67678 .2967 Mtetra
.67678 .2967 .6819 .29462 .69379 .29393 .68874 .29602 Mtetra
.067 0 0 r
.68874 .29602 .69379 .29393 .70575 .29315 .70074 .29477 Mtetra
0 0 0 r
.70074 .29477 .70575 .29315 .71777 .29207 .71278 .29289 Mtetra
.164 .699 .718 r
.71278 .29289 .71777 .29207 .72985 .29066 .72485 .2904 Mtetra
.324 .81 .851 r
.72485 .2904 .72985 .29066 .74196 .28879 .73694 .28734 Mtetra
.467 .877 .946 r
.73694 .28734 .74196 .28879 .75411 .28652 .74906 .28378 Mtetra
.571 .893 .987 r
.74906 .28378 .75411 .28652 .76629 .28381 .7612 .2798 Mtetra
.631 .872 .987 r
.7612 .2798 .76629 .28381 .77851 .28079 .77337 .27552 Mtetra
.66 .835 .967 r
.77337 .27552 .77851 .28079 .79077 .27752 .78558 .27103 Mtetra
.67 .795 .941 r
.78558 .27103 .79077 .27752 .80308 .27409 .79782 .26643 Mtetra
.585 .731 .944 r
.14569 .47843 .15266 .48451 .16235 .48164 .15528 .47657 Mtetra
.572 .765 .97 r
.15528 .47657 .16235 .48164 .17208 .47868 .16492 .47469 Mtetra
.555 .803 .991 r
.16492 .47469 .17208 .47868 .18187 .47552 .17461 .47272 Mtetra
.529 .839 .999 r
.17461 .47272 .18187 .47552 .19173 .47208 .18436 .47055 Mtetra
.488 .864 .981 r
.18436 .47055 .19173 .47208 .20166 .46824 .19419 .4681 Mtetra
.428 .864 .921 r
.19419 .4681 .20166 .46824 .21167 .46393 .2041 .46526 Mtetra
.354 .828 .814 r
.2041 .46526 .21167 .46393 .22177 .45905 .21409 .46191 Mtetra
.273 .761 .676 r
.21409 .46191 .22177 .45905 .23194 .4536 .22418 .45797 Mtetra
0 0 0 r
.22418 .45797 .23194 .4536 .24219 .44753 .23436 .45333 Mtetra
.23436 .45333 .24219 .44753 .25251 .44091 .24464 .44799 Mtetra
.24464 .44799 .25251 .44091 .26289 .43378 .255 .44189 Mtetra
.255 .44189 .26289 .43378 .27331 .42632 .26544 .43517 Mtetra
.26544 .43517 .27331 .42632 .28376 .4187 .27593 .42789 Mtetra
.27593 .42789 .28376 .4187 .29421 .41113 .28647 .42029 Mtetra
.28647 .42029 .29421 .41113 .30467 .40378 .29703 .41256 Mtetra
.29703 .41256 .30467 .40378 .31512 .39673 .30761 .40475 Mtetra
.30761 .40475 .31512 .39673 .32556 .39009 .31819 .39696 Mtetra
.31819 .39696 .32556 .39009 .33597 .38419 .32877 .38962 Mtetra
.32877 .38962 .33597 .38419 .34636 .37918 .33932 .38294 Mtetra
.425 .84 .664 r
.33932 .38294 .34636 .37918 .35676 .37456 .34988 .37649 Mtetra
.568 .937 .824 r
.34988 .37649 .35676 .37456 .36718 .37017 .36045 .37024 Mtetra
.58 .938 .924 r
.36045 .37024 .36718 .37017 .37759 .36685 .37097 .36539 Mtetra
.514 .884 .975 r
.37097 .36539 .37759 .36685 .38799 .36476 .38145 .36231 Mtetra
.495 .847 .994 r
.38145 .36231 .38799 .36476 .39843 .36285 .39194 .36001 Mtetra
.467 .822 .996 r
.39194 .36001 .39843 .36285 .40893 .36052 .40246 .35823 Mtetra
.309 .759 .958 r
.40246 .35823 .40893 .36052 .41953 .35685 .413 .35755 Mtetra
.102 0 0 r
.413 .35755 .41953 .35685 .43022 .35182 .42357 .35785 Mtetra
.39 0 0 r
.42357 .35785 .43022 .35182 .44093 .34699 .43419 .35845 Mtetra
.434 .018 .149 r
.43419 .35845 .44093 .34699 .45165 .34285 .44491 .35829 Mtetra
.357 0 .186 r
.44491 .35829 .45165 .34285 .46241 .33913 .45577 .35456 Mtetra
.227 0 .128 r
.45577 .35456 .46241 .33913 .47321 .33584 .46674 .34726 Mtetra
.066 0 0 r
.46674 .34726 .47321 .33584 .48404 .33324 .47774 .33919 Mtetra
0 0 0 r
.47774 .33919 .48404 .33324 .49492 .33085 .48875 .3314 Mtetra
.657 .971 .885 r
.48875 .3314 .49492 .33085 .50586 .32708 .49977 .32458 Mtetra
.71 .923 .964 r
.49977 .32458 .50586 .32708 .51685 .32197 .51081 .31886 Mtetra
.694 .9 .97 r
.51081 .31886 .51685 .32197 .52788 .31643 .52188 .31366 Mtetra
.642 .9 .984 r
.52188 .31366 .52788 .31643 .53893 .31106 .53299 .30925 Mtetra
.457 .856 .971 r
.53299 .30925 .53893 .31106 .55003 .30693 .54415 .30663 Mtetra
.169 .706 .812 r
.54415 .30663 .55003 .30693 .56119 .30389 .55537 .30543 Mtetra
.036 0 0 r
.55537 .30543 .56119 .30389 .5724 .30109 .56667 .30445 Mtetra
.192 0 0 r
.56667 .30445 .5724 .30109 .58367 .29867 .57804 .3037 Mtetra
.317 0 0 r
.57804 .3037 .58367 .29867 .59502 .29718 .58949 .30364 Mtetra
.382 0 0 r
.58949 .30364 .59502 .29718 .60645 .29645 .60102 .30404 Mtetra
.405 0 .008 r
.60102 .30404 .60645 .29645 .61797 .29614 .61264 .30449 Mtetra
.414 0 .039 r
.61264 .30449 .61797 .29614 .62957 .29615 .62434 .30487 Mtetra
.414 0 .051 r
.62434 .30487 .62957 .29615 .64125 .2964 .63611 .30512 Mtetra
.401 0 .044 r
.63611 .30512 .64125 .2964 .65302 .29671 .64795 .30505 Mtetra
.371 0 .015 r
.64795 .30505 .65302 .29671 .66487 .29687 .65985 .30443 Mtetra
.326 0 0 r
.65985 .30443 .66487 .29687 .67678 .2967 .67179 .30316 Mtetra
.252 0 0 r
.67179 .30316 .67678 .2967 .68874 .29602 .68377 .30112 Mtetra
.147 0 0 r
.68377 .30112 .68874 .29602 .70074 .29477 .69577 .29835 Mtetra
0 0 0 r
.69577 .29835 .70074 .29477 .71278 .29289 .70779 .29486 Mtetra
.70779 .29486 .71278 .29289 .72485 .2904 .71983 .29075 Mtetra
.407 .859 .827 r
.71983 .29075 .72485 .2904 .73694 .28734 .73188 .28611 Mtetra
.563 .927 .938 r
.73188 .28611 .73694 .28734 .74906 .28378 .74395 .28104 Mtetra
.651 .924 .975 r
.74395 .28104 .74906 .28378 .7612 .2798 .75605 .27569 Mtetra
.692 .891 .97 r
.75605 .27569 .7612 .2798 .77337 .27552 .76817 .27012 Mtetra
.707 .849 .95 r
.76817 .27012 .77337 .27552 .78558 .27103 .78033 .26443 Mtetra
.709 .808 .927 r
.78033 .26443 .78558 .27103 .79782 .26643 .79252 .25872 Mtetra
.541 .716 .954 r
.13868 .4723 .14569 .47843 .15528 .47657 .1482 .47114 Mtetra
.523 .736 .972 r
.1482 .47114 .15528 .47657 .16492 .47469 .15777 .47003 Mtetra
.502 .759 .988 r
.15777 .47003 .16492 .47469 .17461 .47272 .16738 .46893 Mtetra
.473 .782 .998 r
.16738 .46893 .17461 .47272 .18436 .47055 .17705 .46777 Mtetra
.429 .801 .994 r
.17705 .46777 .18436 .47055 .19419 .4681 .18679 .46652 Mtetra
.37 .808 .959 r
.18679 .46652 .19419 .4681 .2041 .46526 .19659 .46506 Mtetra
.288 .784 .875 r
.19659 .46506 .2041 .46526 .21409 .46191 .20647 .46327 Mtetra
.187 .716 .731 r
.20647 .46327 .21409 .46191 .22418 .45797 .21644 .46107 Mtetra
0 0 0 r
.21644 .46107 .22418 .45797 .23436 .45333 .2265 .45834 Mtetra
.009 0 0 r
.2265 .45834 .23436 .45333 .24464 .44799 .23665 .45503 Mtetra
.079 0 0 r
.23665 .45503 .24464 .44799 .255 .44189 .2469 .45106 Mtetra
.137 0 0 r
.2469 .45106 .255 .44189 .26544 .43517 .25724 .44647 Mtetra
.179 0 0 r
.25724 .44647 .26544 .43517 .27593 .42789 .26766 .44126 Mtetra
.218 0 .065 r
.26766 .44126 .27593 .42789 .28647 .42029 .27814 .43562 Mtetra
.252 0 .122 r
.27814 .43562 .28647 .42029 .29703 .41256 .28866 .42971 Mtetra
.275 0 .162 r
.28866 .42971 .29703 .41256 .30761 .40475 .29924 .42349 Mtetra
.292 0 .193 r
.29924 .42349 .30761 .40475 .31819 .39696 .30985 .41703 Mtetra
.313 0 .218 r
.30985 .41703 .31819 .39696 .32877 .38962 .32048 .41062 Mtetra
.332 0 .237 r
.32048 .41062 .32877 .38962 .33932 .38294 .33112 .40445 Mtetra
.335 .002 .244 r
.33112 .40445 .33932 .38294 .34988 .37649 .34179 .39815 Mtetra
.335 .004 .246 r
.34179 .39815 .34988 .37649 .36045 .37024 .35248 .39178 Mtetra
.362 .027 .257 r
.35248 .39178 .36045 .37024 .37097 .36539 .36315 .3864 Mtetra
.395 .055 .267 r
.36315 .3864 .37097 .36539 .38145 .36231 .37379 .38246 Mtetra
.41 .064 .265 r
.37379 .38246 .38145 .36231 .39194 .36001 .38442 .37934 Mtetra
.43 .078 .265 r
.38442 .37934 .39194 .36001 .40246 .35823 .39506 .37722 Mtetra
.496 .138 .29 r
.39506 .37722 .40246 .35823 .413 .35755 .40565 .37811 Mtetra
.549 .198 .325 r
.40565 .37811 .413 .35755 .42357 .35785 .4162 .38192 Mtetra
.553 .216 .351 r
.4162 .38192 .42357 .35785 .43419 .35845 .42684 .38615 Mtetra
.529 .204 .362 r
.42684 .38615 .43419 .35845 .44491 .35829 .43762 .38863 Mtetra
.444 .135 .346 r
.43762 .38863 .44491 .35829 .45577 .35456 .44864 .3849 Mtetra
.337 .042 .309 r
.44864 .3849 .45577 .35456 .46674 .34726 .45982 .37497 Mtetra
.277 0 .273 r
.45982 .37497 .46674 .34726 .47774 .33919 .47104 .36325 Mtetra
.244 0 .235 r
.47104 .36325 .47774 .33919 .48875 .3314 .48224 .35192 Mtetra
.279 0 .217 r
.48224 .35192 .48875 .3314 .49977 .32458 .49341 .34352 Mtetra
.346 0 .227 r
.49341 .34352 .49977 .32458 .51081 .31886 .50457 .33812 Mtetra
.377 .029 .243 r
.50457 .33812 .51081 .31886 .52188 .31366 .51576 .33374 Mtetra
.404 .058 .262 r
.51576 .33374 .52188 .31366 .53299 .30925 .527 .33019 Mtetra
.441 .096 .283 r
.527 .33019 .53299 .30925 .54415 .30663 .53829 .3281 Mtetra
.462 .118 .295 r
.53829 .3281 .54415 .30663 .55537 .30543 .54964 .32702 Mtetra
.461 .117 .296 r
.54964 .32702 .55537 .30543 .56667 .30445 .56106 .32586 Mtetra
.459 .114 .293 r
.56106 .32586 .56667 .30445 .57804 .3037 .57255 .3246 Mtetra
.461 .113 .289 r
.57255 .3246 .57804 .3037 .58949 .30364 .58411 .32358 Mtetra
.459 .106 .278 r
.58411 .32358 .58949 .30364 .60102 .30404 .59574 .32262 Mtetra
.448 .088 .259 r
.59574 .32262 .60102 .30404 .61264 .30449 .60744 .32142 Mtetra
.433 .062 .233 r
.60744 .32142 .61264 .30449 .62434 .30487 .6192 .31992 Mtetra
.413 .028 .197 r
.6192 .31992 .62434 .30487 .63611 .30512 .63101 .31814 Mtetra
.38 0 .146 r
.63101 .31814 .63611 .30512 .64795 .30505 .64288 .31592 Mtetra
.326 0 .071 r
.64288 .31592 .64795 .30505 .65985 .30443 .65478 .31307 Mtetra
.245 0 0 r
.65478 .31307 .65985 .30443 .67179 .30316 .66671 .30958 Mtetra
.118 0 0 r
.66671 .30958 .67179 .30316 .68377 .30112 .67867 .3054 Mtetra
0 0 0 r
.67867 .3054 .68377 .30112 .69577 .29835 .69064 .30061 Mtetra
.29 .764 .648 r
.69064 .30061 .69577 .29835 .70779 .29486 .70263 .29527 Mtetra
.498 .907 .839 r
.70263 .29527 .70779 .29486 .71983 .29075 .71464 .28949 Mtetra
.635 .953 .936 r
.71464 .28949 .71983 .29075 .73188 .28611 .72666 .28336 Mtetra
.702 .939 .961 r
.72666 .28336 .73188 .28611 .74395 .28104 .7387 .277 Mtetra
.728 .904 .957 r
.7387 .277 .74395 .28104 .75605 .27569 .75077 .27053 Mtetra
.736 .867 .941 r
.75077 .27053 .75605 .27569 .76817 .27012 .76287 .264 Mtetra
.736 .834 .925 r
.76287 .264 .76817 .27012 .78033 .26443 .77501 .25745 Mtetra
.731 .804 .91 r
.77501 .25745 .78033 .26443 .79252 .25872 .78718 .25095 Mtetra
.542 .717 .953 r
.13161 .46613 .13868 .4723 .1482 .47114 .14115 .46493 Mtetra
.537 .714 .954 r
.14115 .46493 .1482 .47114 .15777 .47003 .15073 .46381 Mtetra
.531 .712 .955 r
.15073 .46381 .15777 .47003 .16738 .46893 .16035 .46277 Mtetra
.525 .713 .958 r
.16035 .46277 .16738 .46893 .17705 .46777 .17002 .4618 Mtetra
.516 .717 .963 r
.17002 .4618 .17705 .46777 .18679 .46652 .17973 .46089 Mtetra
.507 .727 .972 r
.17973 .46089 .18679 .46652 .19659 .46506 .18949 .46 Mtetra
.494 .744 .984 r
.18949 .46 .19659 .46506 .20647 .46327 .19931 .45906 Mtetra
.471 .769 .996 r
.19931 .45906 .20647 .46327 .21644 .46107 .20919 .45803 Mtetra
.426 .793 .995 r
.20919 .45803 .21644 .46107 .2265 .45834 .21913 .45688 Mtetra
.334 .792 .943 r
.21913 .45688 .2265 .45834 .23665 .45503 .22914 .45554 Mtetra
.175 .711 .778 r
.22914 .45554 .23665 .45503 .2469 .45106 .23923 .45399 Mtetra
.016 0 0 r
.23923 .45399 .2469 .45106 .25724 .44647 .24939 .45213 Mtetra
.163 0 0 r
.24939 .45213 .25724 .44647 .26766 .44126 .25962 .44992 Mtetra
.261 0 0 r
.25962 .44992 .26766 .44126 .27814 .43562 .26994 .44738 Mtetra
.319 0 .082 r
.26994 .44738 .27814 .43562 .28866 .42971 .28032 .44454 Mtetra
.347 0 .159 r
.28032 .44454 .28866 .42971 .29924 .42349 .29078 .4412 Mtetra
.361 0 .209 r
.29078 .4412 .29924 .42349 .30985 .41703 .30132 .43728 Mtetra
.372 .026 .243 r
.30132 .43728 .30985 .41703 .32048 .41062 .31193 .43292 Mtetra
.379 .044 .265 r
.31193 .43292 .32048 .41062 .33112 .40445 .3226 .42819 Mtetra
.375 .047 .275 r
.3226 .42819 .33112 .40445 .34179 .39815 .33334 .42285 Mtetra
.368 .045 .28 r
.33334 .42285 .34179 .39815 .35248 .39178 .34415 .41691 Mtetra
.375 .053 .286 r
.34415 .41691 .35248 .39178 .36315 .3864 .35497 .41108 Mtetra
.383 .059 .287 r
.35497 .41108 .36315 .3864 .37379 .38246 .3658 .40574 Mtetra
.377 .047 .274 r
.3658 .40574 .37379 .38246 .38442 .37934 .37666 .4005 Mtetra
.377 .036 .255 r
.37666 .4005 .38442 .37934 .39506 .37722 .38752 .39588 Mtetra
.447 .087 .261 r
.38752 .39588 .39506 .37722 .40565 .37811 .39828 .39474 Mtetra
.524 .149 .271 r
.39828 .39474 .40565 .37811 .4162 .38192 .40897 .39733 Mtetra
.541 .157 .262 r
.40897 .39733 .4162 .38192 .42684 .38615 .41972 .40079 Mtetra
.509 .118 .235 r
.41972 .40079 .42684 .38615 .43762 .38863 .4306 .40288 Mtetra
.333 0 .143 r
.4306 .40288 .43762 .38863 .44864 .3849 .44172 .39915 Mtetra
.08 0 .024 r
.44172 .39915 .44864 .3849 .45982 .37497 .45301 .38958 Mtetra
.027 0 .009 r
.45301 .38958 .45982 .37497 .47104 .36325 .46433 .37861 Mtetra
.098 0 .059 r
.46433 .37861 .47104 .36325 .48224 .35192 .47564 .36849 Mtetra
.279 0 .161 r
.47564 .36849 .48224 .35192 .49341 .34352 .4869 .36212 Mtetra
.406 .048 .241 r
.4869 .36212 .49341 .34352 .50457 .33812 .49816 .35924 Mtetra
.435 .089 .278 r
.49816 .35924 .50457 .33812 .51576 .33374 .50948 .35699 Mtetra
.446 .109 .3 r
.50948 .35699 .51576 .33374 .527 .33019 .52085 .35486 Mtetra
.46 .127 .315 r
.52085 .35486 .527 .33019 .53829 .3281 .53228 .35321 Mtetra
.463 .132 .319 r
.53228 .35321 .53829 .3281 .54964 .32702 .54377 .3517 Mtetra
.451 .12 .312 r
.54377 .3517 .54964 .32702 .56106 .32586 .55533 .34958 Mtetra
.437 .103 .3 r
.55533 .34958 .56106 .32586 .57255 .3246 .56694 .34684 Mtetra
.423 .084 .283 r
.56694 .34684 .57255 .3246 .58411 .32358 .5786 .34371 Mtetra
.402 .054 .256 r
.5786 .34371 .58411 .32358 .59574 .32262 .5903 .34015 Mtetra
.367 .006 .213 r
.5903 .34015 .59574 .32262 .60744 .32142 .60205 .33598 Mtetra
.317 0 .147 r
.60205 .33598 .60744 .32142 .6192 .31992 .61383 .33131 Mtetra
.243 0 .045 r
.61383 .33131 .6192 .31992 .63101 .31814 .62564 .32631 Mtetra
.119 0 0 r
.62564 .32631 .63101 .31814 .64288 .31592 .63749 .32097 Mtetra
0 0 0 r
.63749 .32097 .64288 .31592 .65478 .31307 .64936 .31526 Mtetra
.373 .82 .69 r
.64936 .31526 .65478 .31307 .66671 .30958 .66125 .30923 Mtetra
.602 .951 .9 r
.66125 .30923 .66671 .30958 .67867 .3054 .67317 .30295 Mtetra
.705 .945 .958 r
.67317 .30295 .67867 .3054 .69064 .30061 .68512 .29648 Mtetra
.737 .899 .951 r
.68512 .29648 .69064 .30061 .70263 .29527 .69709 .28987 Mtetra
.744 .856 .932 r
.69709 .28987 .70263 .29527 .71464 .28949 .70909 .28315 Mtetra
.743 .825 .915 r
.70909 .28315 .71464 .28949 .72666 .28336 .72112 .27638 Mtetra
.74 .804 .903 r
.72112 .27638 .72666 .28336 .7387 .277 .73318 .2696 Mtetra
.735 .791 .897 r
.73318 .2696 .7387 .277 .75077 .27053 .74527 .26288 Mtetra
.732 .783 .894 r
.74527 .26288 .75077 .27053 .76287 .264 .75741 .25622 Mtetra
.729 .78 .893 r
.75741 .25622 .76287 .264 .77501 .25745 .76958 .24963 Mtetra
.726 .779 .894 r
.76958 .24963 .77501 .25745 .78718 .25095 .7818 .24311 Mtetra
.582 .73 .945 r
.12449 .45992 .13161 .46613 .14115 .46493 .13413 .45805 Mtetra
.582 .709 .929 r
.13413 .45805 .14115 .46493 .15073 .46381 .1438 .45626 Mtetra
.58 .687 .914 r
.1438 .45626 .15073 .46381 .16035 .46277 .1535 .45459 Mtetra
.575 .667 .901 r
.1535 .45459 .16035 .46277 .17002 .4618 .16323 .45308 Mtetra
.567 .649 .891 r
.16323 .45308 .17002 .4618 .17973 .46089 .17299 .45177 Mtetra
.558 .636 .884 r
.17299 .45177 .17973 .46089 .18949 .46 .18278 .45068 Mtetra
.547 .626 .882 r
.18278 .45068 .18949 .46 .19931 .45906 .19259 .44983 Mtetra
.533 .623 .887 r
.19259 .44983 .19931 .45906 .20919 .45803 .20243 .44926 Mtetra
.513 .627 .901 r
.20243 .44926 .20919 .45803 .21913 .45688 .2123 .449 Mtetra
.483 .642 .927 r
.2123 .449 .21913 .45688 .22914 .45554 .2222 .44902 Mtetra
.432 .666 .96 r
.2222 .44902 .22914 .45554 .23923 .45399 .23213 .44932 Mtetra
.343 .695 .982 r
.23213 .44932 .23923 .45399 .24939 .45213 .24212 .44972 Mtetra
.179 .677 .915 r
.24212 .44972 .24939 .45213 .25962 .44992 .25217 .45009 Mtetra
.046 0 0 r
.25217 .45009 .25962 .44992 .26994 .44738 .26231 .45031 Mtetra
.216 0 0 r
.26231 .45031 .26994 .44738 .28032 .44454 .27252 .45023 Mtetra
.29 0 0 r
.27252 .45023 .28032 .44454 .29078 .4412 .28285 .44956 Mtetra
.314 0 0 r
.28285 .44956 .29078 .4412 .30132 .43728 .29329 .44807 Mtetra
.326 0 .058 r
.29329 .44807 .30132 .43728 .31193 .43292 .30384 .44581 Mtetra
.327 0 .107 r
.30384 .44581 .31193 .43292 .3226 .42819 .31449 .44275 Mtetra
.315 0 .133 r
.31449 .44275 .3226 .42819 .33334 .42285 .32525 .43873 Mtetra
.298 0 .147 r
.32525 .43873 .33334 .42285 .34415 .41691 .3361 .43372 Mtetra
.284 0 .155 r
.3361 .43372 .34415 .41691 .35497 .41108 .34703 .42792 Mtetra
.26 0 .144 r
.34703 .42792 .35497 .41108 .3658 .40574 .35803 .42144 Mtetra
.197 0 .096 r
.35803 .42144 .3658 .40574 .37666 .4005 .36909 .41397 Mtetra
.117 0 .013 r
.36909 .41397 .37666 .4005 .38752 .39588 .3802 .4061 Mtetra
.166 0 0 r
.3802 .4061 .38752 .39588 .39828 .39474 .3912 .40103 Mtetra
.249 0 0 r
.3912 .40103 .39828 .39474 .40897 .39733 .40211 .39943 Mtetra
.152 0 0 r
.40211 .39943 .40897 .39733 .41972 .40079 .41302 .39925 Mtetra
.182 .7 .884 r
.41302 .39925 .41972 .40079 .4306 .40288 .42401 .39895 Mtetra
.629 .853 .985 r
.42401 .39895 .4306 .40288 .44172 .39915 .43517 .39519 Mtetra
.773 .881 .925 r
.43517 .39519 .44172 .39915 .45301 .38958 .44645 .38797 Mtetra
.759 .956 .937 r
.44645 .38797 .45301 .38958 .46433 .37861 .45776 .38061 Mtetra
.467 .884 .774 r
.45776 .38061 .46433 .37861 .47564 .36849 .46907 .37467 Mtetra
.189 0 0 r
.46907 .37467 .47564 .36849 .4869 .36212 .48036 .37222 Mtetra
.429 0 .093 r
.48036 .37222 .4869 .36212 .49816 .35924 .49168 .3726 Mtetra
.444 .038 .174 r
.49168 .3726 .49816 .35924 .50948 .35699 .50307 .37259 Mtetra
.431 .045 .205 r
.50307 .37259 .50948 .35699 .52085 .35486 .51455 .37158 Mtetra
.42 .045 .217 r
.51455 .37158 .52085 .35486 .53228 .35321 .52609 .3699 Mtetra
.399 .025 .208 r
.52609 .3699 .53228 .35321 .54377 .3517 .5377 .36742 Mtetra
.362 0 .178 r
.5377 .36742 .54377 .3517 .55533 .34958 .54936 .36393 Mtetra
.313 0 .134 r
.54936 .36393 .55533 .34958 .56694 .34684 .56106 .35947 Mtetra
.251 0 .071 r
.56106 .35947 .56694 .34684 .5786 .34371 .57279 .35418 Mtetra
.155 0 0 r
.57279 .35418 .5786 .34371 .5903 .34015 .58455 .3481 Mtetra
0 0 0 r
.58455 .3481 .5903 .34015 .60205 .33598 .59632 .34117 Mtetra
.59632 .34117 .60205 .33598 .61383 .33131 .60811 .33361 Mtetra
.528 .904 .73 r
.60811 .33361 .61383 .33131 .62564 .32631 .61991 .32574 Mtetra
.724 .984 .901 r
.61991 .32574 .62564 .32631 .63749 .32097 .63172 .31769 Mtetra
.785 .93 .929 r
.63172 .31769 .63749 .32097 .64936 .31526 .64356 .30959 Mtetra
.781 .851 .903 r
.64356 .30959 .64936 .31526 .66125 .30923 .65542 .30159 Mtetra
.76 .786 .874 r
.65542 .30159 .66125 .30923 .67317 .30295 .66731 .29385 Mtetra
.741 .742 .853 r
.66731 .29385 .67317 .30295 .68512 .29648 .67924 .28639 Mtetra
.726 .714 .84 r
.67924 .28639 .68512 .29648 .69709 .28987 .69122 .27924 Mtetra
.715 .7 .834 r
.69122 .27924 .69709 .28987 .70909 .28315 .70324 .27237 Mtetra
.709 .694 .834 r
.70324 .27237 .70909 .28315 .72112 .27638 .7153 .26573 Mtetra
.705 .696 .839 r
.7153 .26573 .72112 .27638 .73318 .2696 .72742 .25932 Mtetra
.702 .704 .848 r
.72742 .25932 .73318 .2696 .74527 .26288 .73958 .2531 Mtetra
.702 .716 .86 r
.73958 .2531 .74527 .26288 .75741 .25622 .7518 .24704 Mtetra
.702 .732 .874 r
.7518 .24704 .75741 .25622 .76958 .24963 .76406 .24109 Mtetra
.704 .751 .889 r
.76406 .24109 .76958 .24963 .7818 .24311 .77637 .23521 Mtetra
.641 .748 .926 r
.11732 .45366 .12449 .45992 .13413 .45805 .12712 .4506 Mtetra
.638 .71 .899 r
.12712 .4506 .13413 .45805 .1438 .45626 .13694 .4476 Mtetra
.631 .675 .874 r
.13694 .4476 .1438 .45626 .1535 .45459 .14679 .44474 Mtetra
.62 .643 .852 r
.14679 .44474 .1535 .45459 .16323 .45308 .15666 .4421 Mtetra
.607 .614 .833 r
.15666 .4421 .16323 .45308 .17299 .45177 .16653 .43976 Mtetra
.593 .589 .817 r
.16653 .43976 .17299 .45177 .18278 .45068 .17641 .43779 Mtetra
.578 .567 .805 r
.17641 .43779 .18278 .45068 .19259 .44983 .18628 .43627 Mtetra
.563 .549 .797 r
.18628 .43627 .19259 .44983 .20243 .44926 .19617 .43522 Mtetra
.546 .534 .793 r
.19617 .43522 .20243 .44926 .2123 .449 .20605 .43469 Mtetra
.533 .523 .79 r
.20605 .43469 .2123 .449 .2222 .44902 .21595 .43455 Mtetra
.522 .516 .79 r
.21595 .43455 .2222 .44902 .23213 .44932 .22588 .43475 Mtetra
.521 .514 .789 r
.22588 .43475 .23213 .44932 .24212 .44972 .23587 .43498 Mtetra
.528 .516 .786 r
.23587 .43498 .24212 .44972 .25217 .45009 .24594 .43502 Mtetra
.538 .518 .781 r
.24594 .43502 .25217 .45009 .26231 .45031 .2561 .43474 Mtetra
.552 .52 .773 r
.2561 .43474 .26231 .45031 .27252 .45023 .26636 .43399 Mtetra
.567 .521 .763 r
.26636 .43399 .27252 .45023 .28285 .44956 .27672 .43271 Mtetra
.581 .522 .754 r
.27672 .43271 .28285 .44956 .29329 .44807 .28718 .43082 Mtetra
.589 .523 .749 r
.28718 .43082 .29329 .44807 .30384 .44581 .29772 .42854 Mtetra
.595 .527 .748 r
.29772 .42854 .30384 .44581 .31449 .44275 .30832 .42597 Mtetra
.604 .538 .753 r
.30832 .42597 .31449 .44275 .32525 .43873 .319 .42301 Mtetra
.618 .557 .764 r
.319 .42301 .32525 .43873 .3361 .43372 .32976 .41955 Mtetra
.643 .59 .78 r
.32976 .41955 .3361 .43372 .34703 .42792 .34062 .41522 Mtetra
.676 .627 .793 r
.34062 .41522 .34703 .42792 .35803 .42144 .35157 .40971 Mtetra
.719 .661 .792 r
.35157 .40971 .35803 .42144 .36909 .41397 .36265 .40231 Mtetra
.745 .672 .78 r
.36265 .40231 .36909 .41397 .3802 .4061 .37383 .39333 Mtetra
.714 .644 .778 r
.37383 .39333 .3802 .4061 .3912 .40103 .38495 .3857 Mtetra
.656 .584 .762 r
.38495 .3857 .3912 .40103 .40211 .39943 .396 .38039 Mtetra
.612 .523 .73 r
.396 .38039 .40211 .39943 .41302 .39925 .40703 .37661 Mtetra
.587 .482 .702 r
.40703 .37661 .41302 .39925 .42401 .39895 .41807 .37375 Mtetra
.596 .474 .684 r
.41807 .37375 .42401 .39895 .43517 .39519 .42919 .36994 Mtetra
.609 .482 .683 r
.42919 .36994 .43517 .39519 .44645 .38797 .44038 .3652 Mtetra
.602 .491 .701 r
.44038 .3652 .44645 .38797 .45776 .38061 .45159 .36137 Mtetra
.583 .506 .734 r
.45159 .36137 .45776 .38061 .46907 .37467 .46282 .35909 Mtetra
.528 .514 .784 r
.46282 .35909 .46907 .37467 .48036 .37222 .47407 .35914 Mtetra
.47 .521 .828 r
.47407 .35914 .48036 .37222 .49168 .3726 .48537 .36057 Mtetra
.523 .571 .845 r
.48537 .36057 .49168 .3726 .50307 .37259 .49678 .36043 Mtetra
.587 .602 .834 r
.49678 .36043 .50307 .37259 .51455 .37158 .50826 .35837 Mtetra
.618 .6 .81 r
.50826 .35837 .51455 .37158 .52609 .3699 .51982 .35513 Mtetra
.633 .585 .783 r
.51982 .35513 .52609 .3699 .5377 .36742 .53142 .351 Mtetra
.636 .567 .76 r
.53142 .351 .5377 .36742 .54936 .36393 .54307 .34636 Mtetra
.638 .557 .747 r
.54307 .34636 .54936 .36393 .56106 .35947 .55476 .34132 Mtetra
.641 .553 .74 r
.55476 .34132 .56106 .35947 .57279 .35418 .56649 .33597 Mtetra
.647 .556 .738 r
.56649 .33597 .57279 .35418 .58455 .3481 .57825 .33023 Mtetra
.659 .566 .74 r
.57825 .33023 .58455 .3481 .59632 .34117 .59003 .32384 Mtetra
.671 .578 .743 r
.59003 .32384 .59632 .34117 .60811 .33361 .60184 .3169 Mtetra
.682 .591 .747 r
.60184 .3169 .60811 .33361 .61991 .32574 .61366 .30946 Mtetra
.69 .6 .75 r
.61366 .30946 .61991 .32574 .63172 .31769 .62549 .30168 Mtetra
.695 .606 .752 r
.62549 .30168 .63172 .31769 .64356 .30959 .63734 .29369 Mtetra
.696 .607 .754 r
.63734 .29369 .64356 .30959 .65542 .30159 .64921 .28572 Mtetra
.691 .606 .756 r
.64921 .28572 .65542 .30159 .66731 .29385 .66112 .27808 Mtetra
.685 .604 .76 r
.66112 .27808 .66731 .29385 .67924 .28639 .67307 .27083 Mtetra
.677 .603 .765 r
.67307 .27083 .67924 .28639 .69122 .27924 .68508 .26411 Mtetra
.671 .605 .773 r
.68508 .26411 .69122 .27924 .70324 .27237 .69715 .25786 Mtetra
.665 .611 .784 r
.69715 .25786 .70324 .27237 .7153 .26573 .70928 .25207 Mtetra
.662 .623 .799 r
.70928 .25207 .7153 .26573 .72742 .25932 .72148 .24666 Mtetra
.661 .639 .817 r
.72148 .24666 .72742 .25932 .73958 .2531 .73374 .24155 Mtetra
.661 .661 .839 r
.73374 .24155 .73958 .2531 .7518 .24704 .74607 .23667 Mtetra
.663 .688 .863 r
.74607 .23667 .7518 .24704 .76406 .24109 .75846 .23193 Mtetra
.665 .72 .89 r
.75846 .23193 .76406 .24109 .77637 .23521 .7709 .22725 Mtetra
.694 .76 .902 r
.1101 .44736 .11732 .45366 .12712 .4506 .12009 .44291 Mtetra
.685 .718 .874 r
.12009 .44291 .12712 .4506 .13694 .4476 .1301 .4385 Mtetra
.673 .68 .849 r
.1301 .4385 .13694 .4476 .14679 .44474 .14012 .43423 Mtetra
.658 .646 .826 r
.14012 .43423 .14679 .44474 .15666 .4421 .15015 .43021 Mtetra
.642 .614 .807 r
.15015 .43021 .15666 .4421 .16653 .43976 .16017 .42654 Mtetra
.625 .586 .79 r
.16017 .42654 .16653 .43976 .17641 .43779 .17018 .4233 Mtetra
.607 .559 .775 r
.17018 .4233 .17641 .43779 .18628 .43627 .18018 .42059 Mtetra
.591 .537 .762 r
.18018 .42059 .18628 .43627 .19617 .43522 .19017 .41837 Mtetra
.576 .516 .75 r
.19017 .41837 .19617 .43522 .20605 .43469 .20015 .41667 Mtetra
.568 .5 .738 r
.20015 .41667 .20605 .43469 .21595 .43455 .21016 .41524 Mtetra
.564 .486 .726 r
.21016 .41524 .21595 .43455 .22588 .43475 .22021 .41392 Mtetra
.566 .476 .712 r
.22021 .41392 .22588 .43475 .23587 .43498 .23033 .41238 Mtetra
.573 .469 .698 r
.23033 .41238 .23587 .43498 .24594 .43502 .24054 .41033 Mtetra
.578 .461 .684 r
.24054 .41033 .24594 .43502 .2561 .43474 .25085 .4078 Mtetra
.582 .454 .67 r
.25085 .4078 .2561 .43474 .26636 .43399 .26125 .40472 Mtetra
.582 .445 .659 r
.26125 .40472 .26636 .43399 .27672 .43271 .27172 .40134 Mtetra
.58 .436 .65 r
.27172 .40134 .27672 .43271 .28718 .43082 .28224 .39784 Mtetra
.574 .427 .644 r
.28224 .39784 .28718 .43082 .29772 .42854 .29278 .39462 Mtetra
.566 .419 .641 r
.29278 .39462 .29772 .42854 .30832 .42597 .30333 .39197 Mtetra
.56 .415 .641 r
.30333 .39197 .30832 .42597 .319 .42301 .31389 .38983 Mtetra
.556 .415 .644 r
.31389 .38983 .319 .42301 .32976 .41955 .32449 .38805 Mtetra
.564 .425 .651 r
.32449 .38805 .32976 .41955 .34062 .41522 .33516 .3858 Mtetra
.582 .445 .66 r
.33516 .3858 .34062 .41522 .35157 .40971 .34595 .38239 Mtetra
.618 .477 .668 r
.34595 .38239 .35157 .40971 .36265 .40231 .35692 .37653 Mtetra
.653 .507 .672 r
.35692 .37653 .36265 .40231 .37383 .39333 .36804 .36809 Mtetra
.658 .513 .675 r
.36804 .36809 .37383 .39333 .38495 .3857 .37919 .35933 Mtetra
.645 .499 .67 r
.37919 .35933 .38495 .3857 .396 .38039 .39032 .35134 Mtetra
.622 .473 .66 r
.39032 .35134 .396 .38039 .40703 .37661 .40141 .34468 Mtetra
.596 .447 .649 r
.40141 .34468 .40703 .37661 .41807 .37375 .41247 .33965 Mtetra
.579 .429 .642 r
.41247 .33965 .41807 .37375 .42919 .36994 .42353 .3358 Mtetra
.565 .42 .642 r
.42353 .3358 .42919 .36994 .44038 .3652 .4346 .33312 Mtetra
.547 .413 .65 r
.4346 .33312 .44038 .3652 .45159 .36137 .44568 .33208 Mtetra
.528 .411 .664 r
.44568 .33208 .45159 .36137 .46282 .35909 .4568 .33239 Mtetra
.515 .414 .679 r
.4568 .33239 .46282 .35909 .47407 .35914 .46798 .33349 Mtetra
.519 .423 .686 r
.46798 .33349 .47407 .35914 .48537 .36057 .47924 .33429 Mtetra
.562 .448 .681 r
.47924 .33429 .48537 .36057 .49678 .36043 .49062 .33249 Mtetra
.594 .462 .67 r
.49062 .33249 .49678 .36043 .50826 .35837 .50208 .32821 Mtetra
.604 .46 .659 r
.50208 .32821 .50826 .35837 .51982 .35513 .51358 .32276 Mtetra
.604 .453 .649 r
.51358 .32276 .51982 .35513 .53142 .351 .52513 .31682 Mtetra
.596 .442 .643 r
.52513 .31682 .53142 .351 .54307 .34636 .53671 .31125 Mtetra
.589 .435 .64 r
.53671 .31125 .54307 .34636 .55476 .34132 .54833 .30618 Mtetra
.583 .431 .641 r
.54833 .30618 .55476 .34132 .56649 .33597 .56 .30169 Mtetra
.581 .432 .644 r
.56 .30169 .56649 .33597 .57825 .33023 .57172 .29749 Mtetra
.585 .44 .65 r
.57172 .29749 .57825 .33023 .59003 .32384 .58348 .29315 Mtetra
.592 .451 .658 r
.58348 .29315 .59003 .32384 .60184 .3169 .59529 .2885 Mtetra
.604 .468 .669 r
.59529 .2885 .60184 .3169 .61366 .30946 .60713 .2833 Mtetra
.616 .485 .68 r
.60713 .2833 .61366 .30946 .62549 .30168 .619 .27758 Mtetra
.629 .504 .692 r
.619 .27758 .62549 .30168 .63734 .29369 .63089 .27133 Mtetra
.639 .521 .703 r
.63089 .27133 .63734 .29369 .64921 .28572 .6428 .26484 Mtetra
.643 .534 .715 r
.6428 .26484 .64921 .28572 .66112 .27808 .65475 .25846 Mtetra
.645 .545 .726 r
.65475 .25846 .66112 .27808 .67307 .27083 .66675 .25235 Mtetra
.641 .553 .739 r
.66675 .25235 .67307 .27083 .68508 .26411 .67882 .24676 Mtetra
.637 .562 .753 r
.67882 .24676 .68508 .26411 .69715 .25786 .69095 .24168 Mtetra
.632 .572 .77 r
.69095 .24168 .69715 .25786 .70928 .25207 .70316 .23714 Mtetra
.628 .587 .789 r
.70316 .23714 .70928 .25207 .72148 .24666 .71545 .23305 Mtetra
.624 .605 .811 r
.71545 .23305 .72148 .24666 .73374 .24155 .72782 .22932 Mtetra
.621 .629 .837 r
.72782 .22932 .73374 .24155 .74607 .23667 .74027 .22584 Mtetra
.62 .658 .866 r
.74027 .22584 .74607 .23667 .75846 .23193 .7528 .22251 Mtetra
.619 .693 .897 r
.7528 .22251 .75846 .23193 .7709 .22725 .76539 .21923 Mtetra
.728 .765 .882 r
.10283 .44102 .1101 .44736 .12009 .44291 .11298 .4354 Mtetra
.719 .732 .861 r
.11298 .4354 .12009 .44291 .1301 .4385 .12316 .42981 Mtetra
.707 .701 .842 r
.12316 .42981 .1301 .4385 .14012 .43423 .13334 .42435 Mtetra
.693 .671 .825 r
.13334 .42435 .14012 .43423 .15015 .43021 .14352 .41909 Mtetra
.677 .643 .808 r
.14352 .41909 .15015 .43021 .16017 .42654 .1537 .41414 Mtetra
.661 .616 .793 r
.1537 .41414 .16017 .42654 .17018 .4233 .16386 .40953 Mtetra
.645 .588 .777 r
.16386 .40953 .17018 .4233 .18018 .42059 .17402 .40533 Mtetra
.631 .563 .76 r
.17402 .40533 .18018 .42059 .19017 .41837 .18417 .40143 Mtetra
.618 .539 .743 r
.18417 .40143 .19017 .41837 .20015 .41667 .19434 .3978 Mtetra
.61 .517 .724 r
.19434 .3978 .20015 .41667 .21016 .41524 .20454 .39422 Mtetra
.605 .499 .706 r
.20454 .39422 .21016 .41524 .22021 .41392 .21478 .39055 Mtetra
.602 .483 .689 r
.21478 .39055 .22021 .41392 .23033 .41238 .22509 .38667 Mtetra
.601 .47 .675 r
.22509 .38667 .23033 .41238 .24054 .41033 .23546 .38247 Mtetra
.597 .459 .664 r
.23546 .38247 .24054 .41033 .25085 .4078 .24587 .37818 Mtetra
.592 .449 .656 r
.24587 .37818 .25085 .4078 .26125 .40472 .25632 .37397 Mtetra
.586 .441 .651 r
.25632 .37397 .26125 .40472 .27172 .40134 .26678 .37006 Mtetra
.578 .434 .649 r
.26678 .37006 .27172 .40134 .28224 .39784 .27723 .36665 Mtetra
.57 .429 .65 r
.27723 .36665 .28224 .39784 .29278 .39462 .28768 .36391 Mtetra
.559 .423 .653 r
.28768 .36391 .29278 .39462 .30333 .39197 .29812 .36198 Mtetra
.549 .419 .656 r
.29812 .36198 .30333 .39197 .31389 .38983 .30856 .36085 Mtetra
.54 .417 .661 r
.30856 .36085 .31389 .38983 .32449 .38805 .31902 .36035 Mtetra
.543 .425 .669 r
.31902 .36035 .32449 .38805 .33516 .3858 .32955 .35967 Mtetra
.559 .443 .678 r
.32955 .35967 .33516 .3858 .34595 .38239 .3402 .35807 Mtetra
.602 .481 .687 r
.3402 .35807 .34595 .38239 .35692 .37653 .35105 .3539 Mtetra
.65 .52 .692 r
.35105 .3539 .35692 .37653 .36804 .36809 .36209 .34672 Mtetra
.674 .543 .697 r
.36209 .34672 .36804 .36809 .37919 .35933 .37322 .33807 Mtetra
.68 .547 .696 r
.37322 .33807 .37919 .35933 .39032 .35134 .38439 .32898 Mtetra
.662 .529 .692 r
.38439 .32898 .39032 .35134 .40141 .34468 .39552 .3209 Mtetra
.632 .503 .687 r
.39552 .3209 .40141 .34468 .41247 .33965 .40659 .31468 Mtetra
.596 .474 .684 r
.40659 .31468 .41247 .33965 .42353 .3358 .41762 .31078 Mtetra
.559 .45 .686 r
.41762 .31078 .42353 .3358 .4346 .33312 .42862 .30921 Mtetra
.526 .436 .696 r
.42862 .30921 .4346 .33312 .44568 .33208 .43962 .30951 Mtetra
.504 .431 .707 r
.43962 .30951 .44568 .33208 .4568 .33239 .45068 .31085 Mtetra
.512 .444 .716 r
.45068 .31085 .4568 .33239 .46798 .33349 .46183 .31176 Mtetra
.543 .462 .714 r
.46183 .31176 .46798 .33349 .47924 .33429 .47309 .31119 Mtetra
.595 .486 .7 r
.47309 .31119 .47924 .33429 .49062 .33249 .48446 .3076 Mtetra
.627 .496 .684 r
.48446 .3076 .49062 .33249 .50208 .32821 .4959 .3014 Mtetra
.632 .491 .672 r
.4959 .3014 .50208 .32821 .51358 .32276 .50738 .29426 Mtetra
.629 .482 .663 r
.50738 .29426 .51358 .32276 .52513 .31682 .51889 .28693 Mtetra
.617 .469 .658 r
.51889 .28693 .52513 .31682 .53671 .31125 .53042 .28023 Mtetra
.606 .458 .654 r
.53042 .28023 .53671 .31125 .54833 .30618 .54198 .27433 Mtetra
.594 .447 .652 r
.54198 .27433 .54833 .30618 .56 .30169 .55358 .26925 Mtetra
.585 .44 .65 r
.55358 .26925 .56 .30169 .57172 .29749 .56524 .26485 Mtetra
.579 .435 .65 r
.56524 .26485 .57172 .29749 .58348 .29315 .57695 .26097 Mtetra
.576 .435 .652 r
.57695 .26097 .58348 .29315 .59529 .2885 .58872 .25738 Mtetra
.577 .439 .657 r
.58872 .25738 .59529 .2885 .60713 .2833 .60055 .25387 Mtetra
.581 .448 .665 r
.60055 .25387 .60713 .2833 .619 .27758 .61243 .25028 Mtetra
.589 .463 .676 r
.61243 .25028 .619 .27758 .63089 .27133 .62436 .24635 Mtetra
.597 .479 .69 r
.62436 .24635 .63089 .27133 .6428 .26484 .63633 .24221 Mtetra
.604 .498 .706 r
.63633 .24221 .6428 .26484 .65475 .25846 .64835 .23796 Mtetra
.61 .517 .724 r
.64835 .23796 .65475 .25846 .66675 .25235 .66042 .23377 Mtetra
.611 .535 .744 r
.66042 .23377 .66675 .25235 .67882 .24676 .67256 .22985 Mtetra
.61 .552 .764 r
.67256 .22985 .67882 .24676 .69095 .24168 .68477 .22624 Mtetra
.605 .568 .786 r
.68477 .22624 .69095 .24168 .70316 .23714 .69707 .22306 Mtetra
.6 .585 .808 r
.69707 .22306 .70316 .23714 .71545 .23305 .70945 .22022 Mtetra
.593 .603 .832 r
.70945 .22022 .71545 .23305 .72782 .22932 .72192 .21771 Mtetra
.587 .625 .857 r
.72192 .21771 .72782 .22932 .74027 .22584 .73448 .21542 Mtetra
.581 .65 .883 r
.73448 .21542 .74027 .22584 .7528 .22251 .74711 .21326 Mtetra
.575 .679 .91 r
.74711 .21326 .7528 .22251 .76539 .21923 .75983 .21113 Mtetra
.746 .767 .87 r
.09551 .43462 .10283 .44102 .11298 .4354 .10578 .42824 Mtetra
.739 .746 .857 r
.10578 .42824 .11298 .4354 .12316 .42981 .11607 .42189 Mtetra
.731 .726 .846 r
.11607 .42189 .12316 .42981 .13334 .42435 .12637 .41562 Mtetra
.721 .705 .835 r
.12637 .41562 .13334 .42435 .14352 .41909 .13668 .40947 Mtetra
.71 .684 .823 r
.13668 .40947 .14352 .41909 .1537 .41414 .14699 .40353 Mtetra
.698 .661 .81 r
.14699 .40353 .1537 .41414 .16386 .40953 .1573 .39775 Mtetra
.686 .637 .795 r
.1573 .39775 .16386 .40953 .17402 .40533 .16761 .39214 Mtetra
.676 .612 .777 r
.16761 .39214 .17402 .40533 .18417 .40143 .17795 .38656 Mtetra
.667 .587 .756 r
.17795 .38656 .18417 .40143 .19434 .3978 .18832 .3809 Mtetra
.658 .562 .735 r
.18832 .3809 .19434 .3978 .20454 .39422 .19874 .37511 Mtetra
.651 .539 .715 r
.19874 .37511 .20454 .39422 .21478 .39055 .2092 .36908 Mtetra
.64 .518 .698 r
.2092 .36908 .21478 .39055 .22509 .38667 .21969 .36303 Mtetra
.63 .499 .684 r
.21969 .36303 .22509 .38667 .23546 .38247 .23019 .35709 Mtetra
.617 .482 .675 r
.23019 .35709 .23546 .38247 .24587 .37818 .24067 .35169 Mtetra
.602 .468 .67 r
.24067 .35169 .24587 .37818 .25632 .37397 .2511 .34715 Mtetra
.589 .458 .669 r
.2511 .34715 .25632 .37397 .26678 .37006 .2615 .34347 Mtetra
.576 .45 .672 r
.2615 .34347 .26678 .37006 .27723 .36665 .27186 .34073 Mtetra
.565 .446 .676 r
.27186 .34073 .27723 .36665 .28768 .36391 .28222 .33873 Mtetra
.555 .443 .681 r
.28222 .33873 .28768 .36391 .29812 .36198 .29257 .33737 Mtetra
.542 .438 .686 r
.29257 .33737 .29812 .36198 .30856 .36085 .30294 .33677 Mtetra
.529 .433 .69 r
.30294 .33677 .30856 .36085 .31902 .36035 .31332 .33684 Mtetra
.525 .435 .695 r
.31332 .33684 .31902 .36035 .32955 .35967 .32375 .33709 Mtetra
.534 .447 .703 r
.32375 .33709 .32955 .35967 .3402 .35807 .33428 .33691 Mtetra
.58 .486 .712 r
.33428 .33691 .3402 .35807 .35105 .3539 .34501 .33448 Mtetra
.637 .534 .72 r
.34501 .33448 .35105 .3539 .36209 .34672 .35594 .3291 Mtetra
.679 .573 .728 r
.35594 .3291 .36209 .34672 .37322 .33807 .36702 .32157 Mtetra
.706 .597 .732 r
.36702 .32157 .37322 .33807 .38439 .32898 .37818 .31269 Mtetra
.699 .596 .737 r
.37818 .31269 .38439 .32898 .39552 .3209 .38933 .3044 Mtetra
.671 .579 .744 r
.38933 .3044 .39552 .3209 .40659 .31468 .40042 .29781 Mtetra
.621 .548 .752 r
.40042 .29781 .40659 .31468 .41762 .31078 .41144 .29388 Mtetra
.561 .514 .761 r
.41144 .29388 .41762 .31078 .42862 .30921 .42241 .2926 Mtetra
.514 .491 .769 r
.42241 .2926 .42862 .30921 .43962 .30951 .4334 .29304 Mtetra
.496 .483 .772 r
.4334 .29304 .43962 .30951 .45068 .31085 .44445 .29408 Mtetra
.535 .503 .767 r
.44445 .29408 .45068 .31085 .46183 .31176 .45562 .29379 Mtetra
.586 .52 .748 r
.45562 .29379 .46183 .31176 .47309 .31119 .46689 .29133 Mtetra
.634 .532 .721 r
.46689 .29133 .47309 .31119 .48446 .3076 .47827 .2859 Mtetra
.659 .534 .701 r
.47827 .2859 .48446 .3076 .4959 .3014 .48972 .27819 Mtetra
.658 .524 .69 r
.48972 .27819 .4959 .3014 .50738 .29426 .50118 .27002 Mtetra
.651 .515 .684 r
.50118 .27002 .50738 .29426 .51889 .28693 .51267 .26203 Mtetra
.64 .504 .682 r
.51267 .26203 .51889 .28693 .53042 .28023 .52417 .2547 Mtetra
.628 .494 .679 r
.52417 .2547 .53042 .28023 .54198 .27433 .5357 .24813 Mtetra
.618 .484 .677 r
.5357 .24813 .54198 .27433 .55358 .26925 .54726 .24221 Mtetra
.606 .473 .674 r
.54726 .24221 .55358 .26925 .56524 .26485 .55887 .23704 Mtetra
.591 .46 .671 r
.55887 .23704 .56524 .26485 .57695 .26097 .57053 .23282 Mtetra
.579 .451 .67 r
.57053 .23282 .57695 .26097 .58872 .25738 .58226 .22948 Mtetra
.567 .444 .673 r
.58226 .22948 .58872 .25738 .60055 .25387 .59406 .22702 Mtetra
.56 .445 .68 r
.59406 .22702 .60055 .25387 .61243 .25028 .60595 .22512 Mtetra
.56 .454 .691 r
.60595 .22512 .61243 .25028 .62436 .24635 .6179 .22334 Mtetra
.563 .469 .707 r
.6179 .22334 .62436 .24635 .63633 .24221 .62993 .22153 Mtetra
.57 .491 .727 r
.62993 .22153 .63633 .24221 .64835 .23796 .64202 .2195 Mtetra
.576 .515 .75 r
.64202 .2195 .64835 .23796 .66042 .23377 .65418 .21732 Mtetra
.581 .541 .775 r
.65418 .21732 .66042 .23377 .67256 .22985 .6664 .21507 Mtetra
.582 .565 .799 r
.6664 .21507 .67256 .22985 .68477 .22624 .67869 .21286 Mtetra
.579 .585 .824 r
.67869 .21286 .68477 .22624 .69707 .22306 .69106 .21082 Mtetra
.573 .605 .846 r
.69106 .21082 .69707 .22306 .70945 .22022 .70352 .20895 Mtetra
.565 .621 .867 r
.70352 .20895 .70945 .22022 .72192 .21771 .71606 .2073 Mtetra
.556 .638 .887 r
.71606 .2073 .72192 .21771 .73448 .21542 .7287 .20579 Mtetra
.548 .655 .906 r
.7287 .20579 .73448 .21542 .74711 .21326 .74142 .20437 Mtetra
.541 .674 .924 r
.74142 .20437 .74711 .21326 .75983 .21113 .75422 .20298 Mtetra
.747 .767 .869 r
.08813 .42819 .09551 .43462 .10578 .42824 .09844 .42175 Mtetra
.746 .766 .869 r
.09844 .42175 .10578 .42824 .11607 .42189 .10876 .41532 Mtetra
.745 .765 .869 r
.10876 .41532 .11607 .42189 .12637 .41562 .11911 .40891 Mtetra
.743 .762 .868 r
.11911 .40891 .12637 .41562 .13668 .40947 .12947 .40254 Mtetra
.74 .756 .866 r
.12947 .40254 .13668 .40947 .14699 .40353 .13984 .39624 Mtetra
.737 .747 .86 r
.13984 .39624 .14699 .40353 .1573 .39775 .15023 .38992 Mtetra
.734 .733 .85 r
.15023 .38992 .1573 .39775 .16761 .39214 .16066 .38351 Mtetra
.731 .714 .835 r
.16066 .38351 .16761 .39214 .17795 .38656 .17113 .37692 Mtetra
.728 .692 .816 r
.17113 .37692 .17795 .38656 .18832 .3809 .18165 .37003 Mtetra
.722 .668 .797 r
.18165 .37003 .18832 .3809 .19874 .37511 .19221 .36293 Mtetra
.714 .645 .779 r
.19221 .36293 .19874 .37511 .2092 .36908 .20281 .35566 Mtetra
.701 .622 .766 r
.20281 .35566 .2092 .36908 .21969 .36303 .21341 .34861 Mtetra
.685 .603 .758 r
.21341 .34861 .21969 .36303 .23019 .35709 .22397 .34206 Mtetra
.666 .587 .757 r
.22397 .34206 .23019 .35709 .24067 .35169 .23448 .33635 Mtetra
.643 .571 .759 r
.23448 .33635 .24067 .35169 .2511 .34715 .24491 .33176 Mtetra
.625 .562 .763 r
.24491 .33176 .2511 .34715 .2615 .34347 .25531 .32798 Mtetra
.61 .553 .765 r
.25531 .32798 .2615 .34347 .27186 .34073 .2657 .32484 Mtetra
.599 .543 .763 r
.2657 .32484 .27186 .34073 .28222 .33873 .2761 .32209 Mtetra
.591 .53 .755 r
.2761 .32209 .28222 .33873 .29257 .33737 .28653 .3196 Mtetra
.569 .506 .745 r
.28653 .3196 .29257 .33737 .30294 .33677 .29695 .31794 Mtetra
.543 .481 .736 r
.29695 .31794 .30294 .33677 .31332 .33684 .30735 .31733 Mtetra
.519 .461 .731 r
.30735 .31733 .31332 .33684 .32375 .33709 .31776 .31767 Mtetra
.505 .453 .733 r
.31776 .31767 .32375 .33709 .33428 .33691 .3282 .31856 Mtetra
.542 .486 .743 r
.3282 .31856 .33428 .33691 .34501 .33448 .3388 .31798 Mtetra
.601 .541 .759 r
.3388 .31798 .34501 .33448 .35594 .3291 .3496 .31501 Mtetra
.662 .603 .778 r
.3496 .31501 .35594 .3291 .36702 .32157 .36057 .30968 Mtetra
.715 .66 .794 r
.36057 .30968 .36702 .32157 .37818 .31269 .37167 .30242 Mtetra
.729 .695 .818 r
.37167 .30242 .37818 .31269 .38933 .3044 .38279 .29517 Mtetra
.714 .713 .848 r
.38279 .29517 .38933 .3044 .40042 .29781 .39389 .289 Mtetra
.655 .703 .882 r
.39389 .289 .40042 .29781 .41144 .29388 .40493 .28504 Mtetra
.57 .669 .905 r
.40493 .28504 .41144 .29388 .42241 .2926 .41594 .28327 Mtetra
.523 .634 .902 r
.41594 .28327 .42241 .2926 .4334 .29304 .42698 .28261 Mtetra
.53 .61 .877 r
.42698 .28261 .4334 .29304 .44445 .29408 .43809 .28196 Mtetra
.601 .609 .832 r
.43809 .28196 .44445 .29408 .45562 .29379 .44931 .27938 Mtetra
.651 .598 .782 r
.44931 .27938 .45562 .29379 .46689 .29133 .46064 .27442 Mtetra
.68 .584 .741 r
.46064 .27442 .46689 .29133 .47827 .2859 .47205 .26704 Mtetra
.69 .572 .718 r
.47205 .26704 .47827 .2859 .48972 .27819 .4835 .25817 Mtetra
.676 .555 .711 r
.4835 .25817 .48972 .27819 .50118 .27002 .49496 .24983 Mtetra
.662 .546 .713 r
.49496 .24983 .50118 .27002 .51267 .26203 .50644 .24245 Mtetra
.649 .543 .721 r
.50644 .24245 .51267 .26203 .52417 .2547 .51793 .23613 Mtetra
.64 .547 .734 r
.51793 .23613 .52417 .2547 .5357 .24813 .52945 .23064 Mtetra
.64 .558 .746 r
.52945 .23064 .5357 .24813 .54726 .24221 .54102 .2254 Mtetra
.636 .563 .756 r
.54102 .2254 .54726 .24221 .55887 .23704 .55263 .22055 Mtetra
.624 .56 .763 r
.55263 .22055 .55887 .23704 .57053 .23282 .56429 .21637 Mtetra
.606 .551 .767 r
.56429 .21637 .57053 .23282 .58226 .22948 .57602 .213 Mtetra
.58 .537 .771 r
.57602 .213 .58226 .22948 .59406 .22702 .58782 .21079 Mtetra
.559 .529 .778 r
.58782 .21079 .59406 .22702 .60595 .22512 .59972 .20944 Mtetra
.545 .529 .787 r
.59972 .20944 .60595 .22512 .6179 .22334 .6117 .20861 Mtetra
.538 .539 .803 r
.6117 .20861 .6179 .22334 .62993 .22153 .62377 .20802 Mtetra
.541 .561 .824 r
.62377 .20802 .62993 .22153 .64202 .2195 .63592 .20725 Mtetra
.544 .587 .848 r
.63592 .20725 .64202 .2195 .65418 .21732 .64814 .20629 Mtetra
.551 .617 .872 r
.64814 .20629 .65418 .21732 .6664 .21507 .66042 .20502 Mtetra
.553 .644 .894 r
.66042 .20502 .6664 .21507 .67869 .21286 .67278 .20356 Mtetra
.551 .664 .911 r
.67278 .20356 .67869 .21286 .69106 .21082 .68521 .20203 Mtetra
.548 .678 .924 r
.68521 .20203 .69106 .21082 .70352 .20895 .69771 .20047 Mtetra
.541 .685 .932 r
.69771 .20047 .70352 .20895 .71606 .2073 .7103 .19899 Mtetra
.537 .689 .937 r
.7103 .19899 .71606 .2073 .7287 .20579 .72297 .19755 Mtetra
.534 .691 .94 r
.72297 .19755 .7287 .20579 .74142 .20437 .73573 .19614 Mtetra
.532 .692 .941 r
.73573 .19614 .74142 .20437 .75422 .20298 .74857 .19475 Mtetra
.734 .766 .879 r
.0807 .4217 .08813 .42819 .09844 .42175 .09096 .41578 Mtetra
.737 .782 .889 r
.09096 .41578 .09844 .42175 .10876 .41532 .10125 .40986 Mtetra
.741 .799 .899 r
.10125 .40986 .10876 .41532 .11911 .40891 .11156 .4039 Mtetra
.745 .815 .907 r
.11156 .4039 .11911 .40891 .12947 .40254 .12191 .39788 Mtetra
.749 .827 .912 r
.12191 .39788 .12947 .40254 .13984 .39624 .13229 .39178 Mtetra
.755 .835 .913 r
.13229 .39178 .13984 .39624 .15023 .38992 .14271 .38549 Mtetra
.763 .837 .908 r
.14271 .38549 .15023 .38992 .16066 .38351 .1532 .3789 Mtetra
.771 .832 .899 r
.1532 .3789 .16066 .38351 .17113 .37692 .16374 .37198 Mtetra
.779 .823 .887 r
.16374 .37198 .17113 .37692 .18165 .37003 .17434 .36464 Mtetra
.779 .81 .877 r
.17434 .36464 .18165 .37003 .19221 .36293 .18498 .35714 Mtetra
.775 .798 .872 r
.18498 .35714 .19221 .36293 .20281 .35566 .19563 .34965 Mtetra
.763 .792 .877 r
.19563 .34965 .20281 .35566 .21341 .34861 .20625 .34263 Mtetra
.742 .792 .893 r
.20625 .34263 .21341 .34861 .22397 .34206 .21681 .33645 Mtetra
.717 .802 .917 r
.21681 .33645 .22397 .34206 .23448 .33635 .22731 .33118 Mtetra
.678 .81 .946 r
.22731 .33118 .23448 .33635 .24491 .33176 .23774 .32692 Mtetra
.661 .819 .96 r
.23774 .32692 .24491 .33176 .25531 .32798 .24819 .32299 Mtetra
.664 .816 .956 r
.24819 .32299 .25531 .32798 .2657 .32484 .25867 .31899 Mtetra
.677 .789 .934 r
.25867 .31899 .2657 .32484 .2761 .32209 .26922 .31473 Mtetra
.684 .744 .897 r
.26922 .31473 .2761 .32209 .28653 .3196 .27983 .31016 Mtetra
.648 .678 .865 r
.27983 .31016 .28653 .3196 .29695 .31794 .29042 .30646 Mtetra
.593 .61 .838 r
.29042 .30646 .29695 .31794 .30735 .31733 .30094 .30424 Mtetra
.532 .55 .819 r
.30094 .30424 .30735 .31733 .31776 .31767 .31139 .30381 Mtetra
.473 .505 .81 r
.31139 .30381 .31776 .31767 .3282 .31856 .3218 .30501 Mtetra
.489 .52 .816 r
.3218 .30501 .3282 .31856 .3388 .31798 .33231 .30576 Mtetra
.543 .574 .836 r
.33231 .30576 .3388 .31798 .3496 .31501 .34299 .30495 Mtetra
.62 .657 .865 r
.34299 .30495 .3496 .31501 .36057 .30968 .35386 .30195 Mtetra
.697 .746 .89 r
.35386 .30195 .36057 .30968 .37167 .30242 .36488 .2968 Mtetra
.722 .819 .925 r
.36488 .2968 .37167 .30242 .38279 .29517 .37597 .2911 Mtetra
.707 .871 .959 r
.37597 .2911 .38279 .29517 .39389 .289 .38708 .28573 Mtetra
.623 .879 .989 r
.38708 .28573 .39389 .289 .40493 .28504 .39816 .28173 Mtetra
.525 .843 .999 r
.39816 .28173 .40493 .28504 .41594 .28327 .40924 .27912 Mtetra
.528 .816 .998 r
.40924 .27912 .41594 .28327 .42698 .28261 .42036 .27684 Mtetra
.596 .783 .97 r
.42036 .27684 .42698 .28261 .43809 .28196 .43156 .27401 Mtetra
.688 .745 .894 r
.43156 .27401 .43809 .28196 .44931 .27938 .44287 .26902 Mtetra
.726 .699 .825 r
.44287 .26902 .44931 .27938 .46064 .27442 .45427 .26182 Mtetra
.735 .664 .78 r
.45427 .26182 .46064 .27442 .47205 .26704 .46573 .25304 Mtetra
.73 .643 .761 r
.46573 .25304 .47205 .26704 .4835 .25817 .47721 .24378 Mtetra
.701 .624 .768 r
.47721 .24378 .4835 .25817 .49496 .24983 .48867 .23615 Mtetra
.672 .621 .789 r
.48867 .23615 .49496 .24983 .50644 .24245 .50015 .23033 Mtetra
.647 .635 .824 r
.50015 .23033 .50644 .24245 .51793 .23613 .51165 .22601 Mtetra
.629 .67 .87 r
.51165 .22601 .51793 .23613 .52945 .23064 .5232 .22257 Mtetra
.642 .731 .913 r
.5232 .22257 .52945 .23064 .54102 .2254 .5348 .21881 Mtetra
.65 .782 .944 r
.5348 .21881 .54102 .2254 .55263 .22055 .54645 .21479 Mtetra
.648 .811 .962 r
.54645 .21479 .55263 .22055 .56429 .21637 .55816 .21069 Mtetra
.631 .809 .968 r
.55816 .21069 .56429 .21637 .57602 .213 .56992 .20693 Mtetra
.582 .777 .972 r
.56992 .20693 .57602 .213 .58782 .21079 .58175 .20421 Mtetra
.538 .741 .969 r
.58175 .20421 .58782 .21079 .59972 .20944 .59367 .20242 Mtetra
.496 .706 .964 r
.59367 .20242 .59972 .20944 .6117 .20861 .60569 .20151 Mtetra
.468 .689 .963 r
.60569 .20151 .6117 .20861 .62377 .20802 .61779 .20108 Mtetra
.463 .693 .967 r
.61779 .20108 .62377 .20802 .63592 .20725 .62998 .20066 Mtetra
.462 .707 .974 r
.62998 .20066 .63592 .20725 .64814 .20629 .64225 .2001 Mtetra
.477 .73 .981 r
.64225 .2001 .64814 .20629 .66042 .20502 .65459 .19911 Mtetra
.489 .748 .986 r
.65459 .19911 .66042 .20502 .67278 .20356 .66699 .19779 Mtetra
.503 .761 .988 r
.66699 .19779 .67278 .20356 .68521 .20203 .67946 .19616 Mtetra
.516 .765 .987 r
.67946 .19616 .68521 .20203 .69771 .20047 .69199 .19433 Mtetra
.525 .76 .982 r
.69199 .19433 .69771 .20047 .7103 .19899 .7046 .19243 Mtetra
.536 .751 .975 r
.7046 .19243 .7103 .19899 .72297 .19755 .71728 .19046 Mtetra
.545 .737 .965 r
.71728 .19046 .72297 .19755 .73573 .19614 .73004 .18846 Mtetra
.552 .722 .953 r
.73004 .18846 .73573 .19614 .74857 .19475 .74288 .18646 Mtetra
.702 .761 .898 r
.07322 .41517 .0807 .4217 .09096 .41578 .08336 .41033 Mtetra
.707 .796 .92 r
.08336 .41033 .09096 .41578 .10125 .40986 .09353 .40546 Mtetra
.71 .833 .941 r
.09353 .40546 .10125 .40986 .11156 .4039 .10374 .40052 Mtetra
.713 .869 .955 r
.10374 .40052 .11156 .4039 .12191 .39788 .114 .39543 Mtetra
.713 .901 .963 r
.114 .39543 .12191 .39788 .13229 .39178 .12432 .39014 Mtetra
.716 .927 .962 r
.12432 .39014 .13229 .39178 .14271 .38549 .1347 .38454 Mtetra
.723 .946 .953 r
.1347 .38454 .14271 .38549 .1532 .3789 .14516 .37852 Mtetra
.727 .96 .943 r
.14516 .37852 .1532 .3789 .16374 .37198 .15569 .37214 Mtetra
.731 .971 .93 r
.15569 .37214 .16374 .37198 .17434 .36464 .16628 .36536 Mtetra
.709 .977 .917 r
.16628 .36536 .17434 .36464 .18498 .35714 .17689 .3586 Mtetra
.653 .969 .889 r
.17689 .3586 .18498 .35714 .19563 .34965 .18749 .35213 Mtetra
.518 .913 .811 r
.18749 .35213 .19563 .34965 .20625 .34263 .19804 .34637 Mtetra
0 0 0 r
.19804 .34637 .20625 .34263 .21681 .33645 .20851 .3417 Mtetra
.20851 .3417 .21681 .33645 .22731 .33118 .21893 .33783 Mtetra
.095 0 0 r
.21893 .33783 .22731 .33118 .23774 .32692 .22934 .33459 Mtetra
.113 0 0 r
.22934 .33459 .23774 .32692 .24819 .32299 .23982 .33097 Mtetra
.04 0 0 r
.23982 .33097 .24819 .32299 .25867 .31899 .25044 .32627 Mtetra
0 0 0 r
.25044 .32627 .25867 .31899 .26922 .31473 .26119 .32045 Mtetra
.26119 .32045 .26922 .31473 .27983 .31016 .27206 .31355 Mtetra
.46 .872 .724 r
.27206 .31355 .27983 .31016 .29042 .30646 .2829 .30723 Mtetra
.509 .912 .883 r
.2829 .30723 .29042 .30646 .30094 .30424 .29365 .3025 Mtetra
.449 .851 .971 r
.29365 .3025 .30094 .30424 .31139 .30381 .30428 .30004 Mtetra
.318 .724 .979 r
.30428 .30004 .31139 .30381 .3218 .30501 .3148 .29997 Mtetra
.342 .691 .981 r
.3148 .29997 .3218 .30501 .33231 .30576 .32536 .30034 Mtetra
.417 .716 .986 r
.32536 .30034 .33231 .30576 .34299 .30495 .33603 .30007 Mtetra
.528 .786 .992 r
.33603 .30007 .34299 .30495 .35386 .30195 .34687 .29815 Mtetra
.627 .86 .986 r
.34687 .29815 .35386 .30195 .36488 .2968 .35786 .2943 Mtetra
.642 .908 .982 r
.35786 .2943 .36488 .2968 .37597 .2911 .36894 .2897 Mtetra
.611 .928 .967 r
.36894 .2897 .37597 .2911 .38708 .28573 .38007 .28494 Mtetra
.516 .903 .944 r
.38007 .28494 .38708 .28573 .39816 .28173 .39121 .28092 Mtetra
.445 .87 .933 r
.39121 .28092 .39816 .28173 .40924 .27912 .40236 .27764 Mtetra
.499 .884 .965 r
.40236 .27764 .40924 .27912 .42036 .27684 .41357 .27421 Mtetra
.609 .898 .987 r
.41357 .27421 .42036 .27684 .43156 .27401 .42486 .27002 Mtetra
.73 .885 .952 r
.42486 .27002 .43156 .27401 .44287 .26902 .43624 .26389 Mtetra
.782 .854 .905 r
.43624 .26389 .44287 .26902 .45427 .26182 .44771 .25609 Mtetra
.794 .837 .885 r
.44771 .25609 .45427 .26182 .46573 .25304 .4592 .24762 Mtetra
.786 .848 .898 r
.4592 .24762 .46573 .25304 .47721 .24378 .47071 .23958 Mtetra
.708 .878 .961 r
.47071 .23958 .47721 .24378 .48867 .23615 .48219 .23396 Mtetra
.514 .878 .981 r
.48219 .23396 .48867 .23615 .50015 .23033 .4937 .23064 Mtetra
.161 .701 .769 r
.4937 .23064 .50015 .23033 .51165 .22601 .50525 .22892 Mtetra
.106 0 0 r
.50525 .22892 .51165 .22601 .5232 .22257 .51686 .22781 Mtetra
.148 0 0 r
.51686 .22781 .5232 .22257 .5348 .21881 .52855 .2256 Mtetra
.142 0 0 r
.52855 .2256 .5348 .21881 .54645 .21479 .54029 .22225 Mtetra
.102 0 0 r
.54029 .22225 .54645 .21479 .55816 .21069 .55208 .21781 Mtetra
.061 0 0 r
.55208 .21781 .55816 .21069 .56992 .20693 .56392 .21296 Mtetra
.052 0 0 r
.56392 .21296 .56992 .20693 .58175 .20421 .57582 .20876 Mtetra
.028 0 0 r
.57582 .20876 .58175 .20421 .59367 .20242 .58778 .20538 Mtetra
.016 0 0 r
.58778 .20538 .59367 .20242 .60569 .20151 .59983 .20311 Mtetra
0 0 0 r
.59983 .20311 .60569 .20151 .61779 .20108 .61198 .20159 Mtetra
.076 .636 .711 r
.61198 .20159 .61779 .20108 .62998 .20066 .6242 .20037 Mtetra
.141 .686 .792 r
.6242 .20037 .62998 .20066 .64225 .2001 .63651 .19917 Mtetra
.232 .746 .863 r
.63651 .19917 .64225 .2001 .65459 .19911 .64888 .19758 Mtetra
.314 .791 .916 r
.64888 .19758 .65459 .19911 .66699 .19779 .66132 .19561 Mtetra
.397 .828 .958 r
.66132 .19561 .66699 .19779 .67946 .19616 .67381 .1932 Mtetra
.466 .845 .986 r
.67381 .1932 .67946 .19616 .69199 .19433 .68635 .19048 Mtetra
.519 .843 .998 r
.68635 .19048 .69199 .19433 .7046 .19243 .69895 .18755 Mtetra
.559 .826 .996 r
.69895 .18755 .7046 .19243 .71728 .19046 .71161 .18447 Mtetra
.585 .797 .98 r
.71161 .18447 .71728 .19046 .73004 .18846 .72434 .1813 Mtetra
.599 .763 .958 r
.72434 .1813 .73004 .18846 .74288 .18646 .73713 .1781 Mtetra
.652 .75 .922 r
.06568 .40859 .07322 .41517 .08336 .41033 .07565 .40511 Mtetra
.65 .796 .953 r
.07565 .40511 .08336 .41033 .09353 .40546 .08566 .40159 Mtetra
.644 .843 .977 r
.08566 .40159 .09353 .40546 .10374 .40052 .09573 .39795 Mtetra
.631 .885 .987 r
.09573 .39795 .10374 .40052 .114 .39543 .10587 .39411 Mtetra
.612 .916 .978 r
.10587 .39411 .114 .39543 .12432 .39014 .11607 .38999 Mtetra
.587 .932 .949 r
.11607 .38999 .12432 .39014 .1347 .38454 .12636 .38551 Mtetra
.564 .935 .904 r
.12636 .38551 .1347 .38454 .14516 .37852 .13674 .38055 Mtetra
.518 .916 .842 r
.13674 .38055 .14516 .37852 .15569 .37214 .14719 .37527 Mtetra
.454 .876 .761 r
.14719 .37527 .15569 .37214 .16628 .36536 .1577 .36972 Mtetra
0 0 0 r
.1577 .36972 .16628 .36536 .17689 .3586 .16821 .36438 Mtetra
.16821 .36438 .17689 .3586 .18749 .35213 .17869 .35962 Mtetra
.069 0 0 r
.17869 .35962 .18749 .35213 .19804 .34637 .18912 .35574 Mtetra
.237 0 0 r
.18912 .35574 .19804 .34637 .20851 .3417 .19946 .35306 Mtetra
.313 0 .04 r
.19946 .35306 .20851 .3417 .21893 .33783 .20979 .35092 Mtetra
.345 0 .098 r
.20979 .35092 .21893 .33783 .22934 .33459 .22017 .34888 Mtetra
.312 0 .101 r
.22017 .34888 .22934 .33459 .23982 .33097 .2307 .34566 Mtetra
.225 0 .06 r
.2307 .34566 .23982 .33097 .25044 .32627 .24147 .34035 Mtetra
.108 0 0 r
.24147 .34035 .25044 .32627 .26119 .32045 .25245 .33307 Mtetra
0 0 0 r
.25245 .33307 .26119 .32045 .27206 .31355 .26359 .32397 Mtetra
.26359 .32397 .27206 .31355 .2829 .30723 .27473 .31508 Mtetra
.27473 .31508 .2829 .30723 .29365 .3025 .28576 .30769 Mtetra
.28576 .30769 .29365 .3025 .30428 .30004 .29662 .30279 Mtetra
.29662 .30279 .30428 .30004 .3148 .29997 .30733 .30076 Mtetra
.30733 .30076 .3148 .29997 .32536 .30034 .31801 .29993 Mtetra
.116 .666 .796 r
.31801 .29993 .32536 .30034 .33603 .30007 .32875 .2993 Mtetra
.268 .768 .883 r
.32875 .2993 .33603 .30007 .34687 .29815 .33961 .29769 Mtetra
.406 .853 .912 r
.33961 .29769 .34687 .29815 .35786 .2943 .35061 .29462 Mtetra
.423 .868 .877 r
.35061 .29462 .35786 .2943 .36894 .2897 .3617 .29079 Mtetra
.401 .856 .826 r
.3617 .29079 .36894 .2897 .38007 .28494 .37287 .28653 Mtetra
.331 .811 .77 r
.37287 .28653 .38007 .28494 .39121 .28092 .38406 .28248 Mtetra
.306 .795 .76 r
.38406 .28248 .39121 .28092 .40236 .27764 .3953 .27866 Mtetra
.394 .852 .824 r
.3953 .27866 .40236 .27764 .41357 .27421 .4066 .27441 Mtetra
.527 .919 .898 r
.4066 .27441 .41357 .27421 .42486 .27002 .41797 .26938 Mtetra
.676 .964 .934 r
.41797 .26938 .42486 .27002 .43624 .26389 .42943 .26288 Mtetra
.739 .971 .929 r
.42943 .26288 .43624 .26389 .44771 .25609 .44094 .25538 Mtetra
.717 .974 .925 r
.44094 .25538 .44771 .25609 .4592 .24762 .45247 .24809 Mtetra
.581 .944 .883 r
.45247 .24809 .4592 .24762 .47071 .23958 .46401 .24199 Mtetra
0 0 0 r
.46401 .24199 .47071 .23958 .48219 .23396 .47553 .23879 Mtetra
.235 0 0 r
.47553 .23879 .48219 .23396 .4937 .23064 .48708 .23812 Mtetra
.391 0 0 r
.48708 .23812 .4937 .23064 .50525 .22892 .49869 .23898 Mtetra
.432 0 .064 r
.49869 .23898 .50525 .22892 .51686 .22781 .51038 .24008 Mtetra
.389 0 .097 r
.51038 .24008 .51686 .22781 .52855 .2256 .52217 .23932 Mtetra
.337 0 .105 r
.52217 .23932 .52855 .2256 .54029 .22225 .53404 .23657 Mtetra
.271 0 .089 r
.53404 .23657 .54029 .22225 .55208 .21781 .54595 .23168 Mtetra
.217 0 .058 r
.54595 .23168 .55208 .21781 .56392 .21296 .55789 .22558 Mtetra
.194 0 .02 r
.55789 .22558 .56392 .21296 .57582 .20876 .56988 .21958 Mtetra
.171 0 0 r
.56988 .21958 .57582 .20876 .58778 .20538 .58191 .21412 Mtetra
.169 0 0 r
.58191 .21412 .58778 .20538 .59983 .20311 .59402 .20988 Mtetra
.147 0 0 r
.59402 .20988 .59983 .20311 .61198 .20159 .6062 .20655 Mtetra
.103 0 0 r
.6062 .20655 .61198 .20159 .6242 .20037 .61846 .20382 Mtetra
.032 0 0 r
.61846 .20382 .6242 .20037 .63651 .19917 .63081 .20131 Mtetra
0 0 0 r
.63081 .20131 .63651 .19917 .64888 .19758 .64321 .19852 Mtetra
.212 .733 .735 r
.64321 .19852 .64888 .19758 .66132 .19561 .65566 .19541 Mtetra
.352 .827 .853 r
.65566 .19541 .66132 .19561 .67381 .1932 .66816 .19179 Mtetra
.469 .882 .936 r
.66816 .19179 .67381 .1932 .68635 .19048 .6807 .18779 Mtetra
.558 .898 .98 r
.6807 .18779 .68635 .19048 .69895 .18755 .69329 .1835 Mtetra
.616 .881 .99 r
.69329 .1835 .69895 .18755 .71161 .18447 .70592 .17899 Mtetra
.646 .844 .976 r
.70592 .17899 .71161 .18447 .72434 .1813 .7186 .17435 Mtetra
.658 .798 .95 r
.7186 .17435 .72434 .1813 .73713 .1781 .73134 .16968 Mtetra
.583 .731 .944 r
.05808 .40196 .06568 .40859 .07565 .40511 .06788 .39986 Mtetra
.57 .775 .976 r
.06788 .39986 .07565 .40511 .08566 .40159 .07772 .39771 Mtetra
.55 .819 .996 r
.07772 .39771 .08566 .40159 .09573 .39795 .08764 .39542 Mtetra
.52 .853 .996 r
.08764 .39542 .09573 .39795 .10587 .39411 .09762 .39292 Mtetra
.482 .872 .968 r
.09762 .39292 .10587 .39411 .11607 .38999 .1077 .39011 Mtetra
.43 .867 .91 r
.1077 .39011 .11607 .38999 .12636 .38551 .11786 .38696 Mtetra
.374 .84 .825 r
.11786 .38696 .12636 .38551 .13674 .38055 .12812 .38337 Mtetra
.278 .769 .703 r
.12812 .38337 .13674 .38055 .14719 .37527 .13844 .37956 Mtetra
0 0 0 r
.13844 .37956 .14719 .37527 .1577 .36972 .14882 .37564 Mtetra
.14882 .37564 .1577 .36972 .16821 .36438 .1592 .37207 Mtetra
.16 0 0 r
.1592 .37207 .16821 .36438 .17869 .35962 .16953 .36923 Mtetra
.279 0 0 r
.16953 .36923 .17869 .35962 .18912 .35574 .17983 .36722 Mtetra
.366 0 .071 r
.17983 .36722 .18912 .35574 .19946 .35306 .19007 .36622 Mtetra
.39 0 .121 r
.19007 .36622 .19946 .35306 .20979 .35092 .20035 .36535 Mtetra
.383 0 .139 r
.20035 .36535 .20979 .35092 .22017 .34888 .21075 .36397 Mtetra
.319 0 .114 r
.21075 .36397 .22017 .34888 .2307 .34566 .22138 .36076 Mtetra
.196 0 .046 r
.22138 .36076 .2307 .34566 .24147 .34035 .23231 .35477 Mtetra
.044 0 0 r
.23231 .35477 .24147 .34035 .25245 .33307 .24349 .3463 Mtetra
0 0 0 r
.24349 .3463 .25245 .33307 .26359 .32397 .25488 .3356 Mtetra
.25488 .3356 .26359 .32397 .27473 .31508 .26626 .32485 Mtetra
.26626 .32485 .27473 .31508 .28576 .30769 .27754 .31547 Mtetra
.27754 .31547 .28576 .30769 .29662 .30279 .28864 .30858 Mtetra
.28864 .30858 .29662 .30279 .30733 .30076 .29954 .30473 Mtetra
.047 0 0 r
.29954 .30473 .30733 .30076 .31801 .29993 .31037 .30255 Mtetra
.046 0 0 r
.31037 .30255 .31801 .29993 .32875 .2993 .3212 .30121 Mtetra
0 0 0 r
.3212 .30121 .32875 .2993 .33961 .29769 .33212 .29947 Mtetra
.173 .702 .692 r
.33212 .29947 .33961 .29769 .35061 .29462 .34316 .29677 Mtetra
.215 .729 .689 r
.34316 .29677 .35061 .29462 .3617 .29079 .35429 .2934 Mtetra
0 0 0 r
.35429 .2934 .3617 .29079 .37287 .28653 .3655 .28947 Mtetra
.3655 .28947 .37287 .28653 .38406 .28248 .37676 .2854 Mtetra
.37676 .2854 .38406 .28248 .3953 .27866 .38807 .28119 Mtetra
.316 .791 .702 r
.38807 .28119 .3953 .27866 .4066 .27441 .39946 .27643 Mtetra
.422 .861 .77 r
.39946 .27643 .4066 .27441 .41797 .26938 .41091 .27099 Mtetra
.538 .923 .822 r
.41091 .27099 .41797 .26938 .42943 .26288 .42244 .26457 Mtetra
.56 .933 .819 r
.42244 .26457 .42943 .26288 .44094 .25538 .434 .25775 Mtetra
.431 .861 .745 r
.434 .25775 .44094 .25538 .45247 .24809 .44558 .25176 Mtetra
0 0 0 r
.44558 .25176 .45247 .24809 .46401 .24199 .45715 .24746 Mtetra
.218 0 0 r
.45715 .24746 .46401 .24199 .47553 .23879 .46871 .24623 Mtetra
.408 0 0 r
.46871 .24623 .47553 .23879 .48708 .23812 .48031 .24755 Mtetra
.479 .013 .068 r
.48031 .24755 .48708 .23812 .49869 .23898 .49199 .25027 Mtetra
.487 .042 .118 r
.49199 .25027 .49869 .23898 .51038 .24008 .50377 .25296 Mtetra
.429 .001 .123 r
.50377 .25296 .51038 .24008 .52217 .23932 .51566 .2534 Mtetra
.36 0 .115 r
.51566 .2534 .52217 .23932 .53404 .23657 .52764 .25131 Mtetra
.272 0 .091 r
.52764 .25131 .53404 .23657 .54595 .23168 .53967 .24639 Mtetra
.203 0 .062 r
.53967 .24639 .54595 .23168 .55789 .22558 .55174 .23958 Mtetra
.167 0 .034 r
.55174 .23958 .55789 .22558 .56988 .21958 .56383 .23224 Mtetra
.138 0 0 r
.56383 .23224 .56988 .21958 .58191 .21412 .57596 .22501 Mtetra
.135 0 0 r
.57596 .22501 .58191 .21412 .59402 .20988 .58813 .21882 Mtetra
.113 0 0 r
.58813 .21882 .59402 .20988 .6062 .20655 .60037 .21348 Mtetra
.072 0 0 r
.60037 .21348 .6062 .20655 .61846 .20382 .61268 .20888 Mtetra
0 0 0 r
.61268 .20888 .61846 .20382 .63081 .20131 .62505 .20463 Mtetra
.62505 .20463 .63081 .20131 .64321 .19852 .63747 .20027 Mtetra
.274 .766 .699 r
.63747 .20027 .64321 .19852 .65566 .19541 .64995 .19568 Mtetra
.432 .873 .839 r
.64995 .19568 .65566 .19541 .66816 .19179 .66245 .19063 Mtetra
.554 .926 .928 r
.66245 .19063 .66816 .19179 .6807 .18779 .67499 .18522 Mtetra
.639 .933 .968 r
.67499 .18522 .6807 .18779 .69329 .1835 .68757 .17947 Mtetra
.686 .908 .973 r
.68757 .17947 .69329 .1835 .70592 .17899 .70017 .17349 Mtetra
.707 .866 .957 r
.70017 .17349 .70592 .17899 .7186 .17435 .71282 .16737 Mtetra
.711 .818 .932 r
.71282 .16737 .7186 .17435 .73134 .16968 .7255 .16118 Mtetra
.506 .703 .959 r
.05043 .39529 .05808 .40196 .06788 .39986 .06007 .39438 Mtetra
.484 .738 .983 r
.06007 .39438 .06788 .39986 .07772 .39771 .06977 .39341 Mtetra
.456 .77 .997 r
.06977 .39341 .07772 .39771 .08764 .39542 .07954 .39231 Mtetra
.422 .796 .993 r
.07954 .39231 .08764 .39542 .09762 .39292 .08939 .39101 Mtetra
.384 .811 .967 r
.08939 .39101 .09762 .39292 .1077 .39011 .09933 .38941 Mtetra
.331 .804 .912 r
.09933 .38941 .1077 .39011 .11786 .38696 .10937 .38753 Mtetra
.27 .776 .828 r
.10937 .38753 .11786 .38696 .12812 .38337 .11949 .38529 Mtetra
.164 .697 .696 r
.11949 .38529 .12812 .38337 .13844 .37956 .12969 .38295 Mtetra
0 0 0 r
.12969 .38295 .13844 .37956 .14882 .37564 .13992 .38063 Mtetra
.112 0 0 r
.13992 .38063 .14882 .37564 .1592 .37207 .15016 .37871 Mtetra
.249 0 0 r
.15016 .37871 .1592 .37207 .16953 .36923 .16037 .37753 Mtetra
.336 0 0 r
.16037 .37753 .16953 .36923 .17983 .36722 .17057 .37701 Mtetra
.396 0 .044 r
.17057 .37701 .17983 .36722 .19007 .36622 .18075 .37719 Mtetra
.396 0 .072 r
.18075 .37719 .19007 .36622 .20035 .36535 .19103 .37708 Mtetra
.36 0 .067 r
.19103 .37708 .20035 .36535 .21075 .36397 .20147 .37597 Mtetra
.259 0 .01 r
.20147 .37597 .21075 .36397 .22138 .36076 .21219 .37268 Mtetra
.077 0 0 r
.21219 .37268 .22138 .36076 .23231 .35477 .22325 .36635 Mtetra
0 0 0 r
.22325 .36635 .23231 .35477 .24349 .3463 .23457 .35742 Mtetra
.23457 .35742 .24349 .3463 .25488 .3356 .2461 .34624 Mtetra
.2461 .34624 .25488 .3356 .26626 .32485 .25764 .33486 Mtetra
.25764 .33486 .26626 .32485 .27754 .31547 .26907 .32468 Mtetra
.26907 .32468 .27754 .31547 .28864 .30858 .28034 .31678 Mtetra
.029 0 0 r
.28034 .31678 .28864 .30858 .29954 .30473 .2914 .31178 Mtetra
.12 0 0 r
.2914 .31178 .29954 .30473 .31037 .30255 .30237 .30859 Mtetra
.17 0 0 r
.30237 .30859 .31037 .30255 .3212 .30121 .31332 .30657 Mtetra
.142 0 0 r
.31332 .30657 .3212 .30121 .33212 .29947 .32432 .30458 Mtetra
.079 0 0 r
.32432 .30458 .33212 .29947 .34316 .29677 .33542 .302 Mtetra
.039 0 0 r
.33542 .302 .34316 .29677 .35429 .2934 .3466 .29888 Mtetra
.003 0 0 r
.3466 .29888 .35429 .2934 .3655 .28947 .35787 .29516 Mtetra
0 0 0 r
.35787 .29516 .3655 .28947 .37676 .2854 .36921 .29108 Mtetra
.36921 .29108 .37676 .2854 .38807 .28119 .38062 .28662 Mtetra
.38062 .28662 .38807 .28119 .39946 .27643 .39209 .28156 Mtetra
.39209 .28156 .39946 .27643 .41091 .27099 .40363 .27594 Mtetra
.40363 .27594 .41091 .27099 .42244 .26457 .41522 .26974 Mtetra
.41522 .26974 .42244 .26457 .434 .25775 .42685 .26356 Mtetra
.42685 .26356 .434 .25775 .44558 .25176 .43848 .25855 Mtetra
.131 0 0 r
.43848 .25855 .44558 .25176 .45715 .24746 .45011 .25537 Mtetra
.34 0 0 r
.45011 .25537 .45715 .24746 .46871 .24623 .46174 .25513 Mtetra
.452 0 .034 r
.46174 .25513 .46871 .24623 .48031 .24755 .47341 .25722 Mtetra
.497 .032 .08 r
.47341 .25722 .48031 .24755 .49199 .25027 .48516 .26054 Mtetra
.493 .034 .091 r
.48516 .26054 .49199 .25027 .50377 .25296 .49703 .2637 Mtetra
.422 0 .064 r
.49703 .2637 .50377 .25296 .51566 .2534 .50901 .26458 Mtetra
.329 0 .029 r
.50901 .26458 .51566 .2534 .52764 .25131 .5211 .2628 Mtetra
.202 0 0 r
.5211 .2628 .52764 .25131 .53967 .24639 .53324 .25792 Mtetra
.098 0 0 r
.53324 .25792 .53967 .24639 .55174 .23958 .54543 .25081 Mtetra
.036 0 0 r
.54543 .25081 .55174 .23958 .56383 .23224 .55763 .24265 Mtetra
0 0 0 r
.55763 .24265 .56383 .23224 .57596 .22501 .56985 .23417 Mtetra
.56985 .23417 .57596 .22501 .58813 .21882 .58211 .22641 Mtetra
.58211 .22641 .58813 .21882 .60037 .21348 .59441 .21931 Mtetra
.59441 .21931 .60037 .21348 .61268 .20888 .60676 .21296 Mtetra
.60676 .21296 .61268 .20888 .62505 .20463 .61917 .20701 Mtetra
.339 .799 .678 r
.61917 .20701 .62505 .20463 .63747 .20027 .63162 .20108 Mtetra
.471 .892 .813 r
.63162 .20108 .63747 .20027 .64995 .19568 .64412 .19503 Mtetra
.593 .946 .904 r
.64412 .19503 .64995 .19568 .66245 .19063 .65664 .18861 Mtetra
.672 .956 .948 r
.65664 .18861 .66245 .19063 .67499 .18522 .66918 .18188 Mtetra
.72 .938 .958 r
.66918 .18188 .67499 .18522 .68757 .17947 .68175 .17482 Mtetra
.743 .904 .949 r
.68175 .17482 .68757 .17947 .70017 .17349 .69434 .16754 Mtetra
.751 .865 .932 r
.69434 .16754 .70017 .17349 .71282 .16737 .70696 .16011 Mtetra
.749 .824 .91 r
.70696 .16011 .71282 .16737 .7255 .16118 .71961 .15261 Mtetra
.448 .679 .963 r
.04273 .38856 .05043 .39529 .06007 .39438 .05227 .38837 Mtetra
.433 .699 .977 r
.05227 .38837 .06007 .39438 .06977 .39341 .06187 .38813 Mtetra
.418 .72 .987 r
.06187 .38813 .06977 .39341 .07954 .39231 .07155 .38777 Mtetra
.405 .741 .993 r
.07155 .38777 .07954 .39231 .08939 .39101 .08132 .38723 Mtetra
.395 .764 .993 r
.08132 .38723 .08939 .39101 .09933 .38941 .09118 .38644 Mtetra
.377 .781 .984 r
.09118 .38644 .09933 .38941 .10937 .38753 .10112 .38541 Mtetra
.355 .793 .963 r
.10112 .38541 .10937 .38753 .11949 .38529 .11116 .38411 Mtetra
.297 .779 .917 r
.11116 .38411 .11949 .38529 .12969 .38295 .12127 .38271 Mtetra
.213 .736 .84 r
.12127 .38271 .12969 .38295 .13992 .38063 .13143 .38134 Mtetra
.09 .648 .724 r
.13143 .38134 .13992 .38063 .15016 .37871 .14161 .38027 Mtetra
.049 0 0 r
.14161 .38027 .15016 .37871 .16037 .37753 .15178 .37972 Mtetra
.14 0 0 r
.15178 .37972 .16037 .37753 .17057 .37701 .16198 .37959 Mtetra
.203 0 0 r
.16198 .37959 .17057 .37701 .18075 .37719 .17219 .37983 Mtetra
.161 0 0 r
.17219 .37983 .18075 .37719 .19103 .37708 .18252 .37964 Mtetra
.039 0 0 r
.18252 .37964 .19103 .37708 .20147 .37597 .19303 .37841 Mtetra
0 0 0 r
.19303 .37841 .20147 .37597 .21219 .37268 .20378 .37531 Mtetra
.46 .882 .783 r
.20378 .37531 .21219 .37268 .22325 .36635 .21483 .3697 Mtetra
.588 .939 .782 r
.21483 .3697 .22325 .36635 .23457 .35742 .2261 .36205 Mtetra
.626 .942 .727 r
.2261 .36205 .23457 .35742 .2461 .34624 .23755 .35269 Mtetra
.494 .849 .593 r
.23755 .35269 .2461 .34624 .25764 .33486 .249 .34328 Mtetra
0 0 0 r
.249 .34328 .25764 .33486 .26907 .32468 .26038 .33492 Mtetra
.006 0 0 r
.26038 .33492 .26907 .32468 .28034 .31678 .27162 .32843 Mtetra
.207 0 0 r
.27162 .32843 .28034 .31678 .2914 .31178 .28272 .32426 Mtetra
.299 0 .043 r
.28272 .32426 .2914 .31178 .30237 .30859 .29375 .32156 Mtetra
.346 0 .08 r
.29375 .32156 .30237 .30859 .31332 .30657 .30476 .31979 Mtetra
.349 0 .087 r
.30476 .31979 .31332 .30657 .32432 .30458 .31585 .318 Mtetra
.331 0 .081 r
.31585 .318 .32432 .30458 .33542 .302 .32702 .31569 Mtetra
.311 0 .075 r
.32702 .31569 .33542 .302 .3466 .29888 .3383 .31279 Mtetra
.288 0 .067 r
.3383 .31279 .3466 .29888 .35787 .29516 .34966 .30922 Mtetra
.269 0 .061 r
.34966 .30922 .35787 .29516 .36921 .29108 .36111 .30511 Mtetra
.247 0 .05 r
.36111 .30511 .36921 .29108 .38062 .28662 .37263 .30048 Mtetra
.215 0 .031 r
.37263 .30048 .38062 .28662 .39209 .28156 .38422 .29517 Mtetra
.184 0 .011 r
.38422 .29517 .39209 .28156 .40363 .27594 .39588 .28927 Mtetra
.153 0 0 r
.39588 .28927 .40363 .27594 .41522 .26974 .4076 .28282 Mtetra
.147 0 0 r
.4076 .28282 .41522 .26974 .42685 .26356 .41935 .27636 Mtetra
.187 0 0 r
.41935 .27636 .42685 .26356 .43848 .25855 .43111 .27082 Mtetra
.245 0 .012 r
.43111 .27082 .43848 .25855 .45011 .25537 .44286 .26677 Mtetra
.331 0 .033 r
.44286 .26677 .45011 .25537 .46174 .25513 .45462 .26507 Mtetra
.387 0 .023 r
.45462 .26507 .46174 .25513 .47341 .25722 .46641 .26527 Mtetra
.407 0 0 r
.46641 .26527 .47341 .25722 .48516 .26054 .47827 .26656 Mtetra
.371 0 0 r
.47827 .26656 .48516 .26054 .49703 .2637 .49023 .26781 Mtetra
.207 0 0 r
.49023 .26781 .49703 .2637 .50901 .26458 .50229 .26734 Mtetra
0 0 0 r
.50229 .26734 .50901 .26458 .5211 .2628 .51445 .26479 Mtetra
.339 .809 .728 r
.51445 .26479 .5211 .2628 .53324 .25792 .52667 .25967 Mtetra
.513 .908 .785 r
.52667 .25967 .53324 .25792 .54543 .25081 .53894 .25262 Mtetra
.58 .937 .787 r
.53894 .25262 .54543 .25081 .55763 .24265 .55122 .24449 Mtetra
.602 .945 .783 r
.55122 .24449 .55763 .24265 .56985 .23417 .56353 .2359 Mtetra
.581 .937 .785 r
.56353 .2359 .56985 .23417 .58211 .22641 .57586 .22769 Mtetra
.58 .94 .809 r
.57586 .22769 .58211 .22641 .59441 .21931 .58823 .21988 Mtetra
.587 .946 .848 r
.58823 .21988 .59441 .21931 .60676 .21296 .60064 .2126 Mtetra
.62 .958 .895 r
.60064 .2126 .60676 .21296 .61917 .20701 .61309 .20562 Mtetra
.665 .963 .932 r
.61309 .20562 .61917 .20701 .63162 .20108 .62558 .19865 Mtetra
.703 .954 .951 r
.62558 .19865 .63162 .20108 .64412 .19503 .6381 .19158 Mtetra
.736 .937 .953 r
.6381 .19158 .64412 .19503 .65664 .18861 .65065 .18421 Mtetra
.754 .913 .945 r
.65065 .18421 .65664 .18861 .66918 .18188 .66321 .17657 Mtetra
.766 .888 .932 r
.66321 .17657 .66918 .18188 .68175 .17482 .6758 .16866 Mtetra
.77 .863 .918 r
.6758 .16866 .68175 .17482 .69434 .16754 .6884 .16055 Mtetra
.77 .838 .904 r
.6884 .16055 .69434 .16754 .70696 .16011 .70103 .1523 Mtetra
.766 .814 .891 r
.70103 .1523 .70696 .16011 .71961 .15261 .71368 .14397 Mtetra
.426 .67 .963 r
.03496 .38178 .04273 .38856 .05227 .38837 .04447 .38184 Mtetra
.424 .678 .968 r
.04447 .38184 .05227 .38837 .06187 .38813 .05405 .38183 Mtetra
.425 .688 .973 r
.05405 .38183 .06187 .38813 .07155 .38777 .06371 .38173 Mtetra
.429 .699 .978 r
.06371 .38173 .07155 .38777 .08132 .38723 .07345 .38148 Mtetra
.437 .714 .982 r
.07345 .38148 .08132 .38723 .09118 .38644 .08327 .38103 Mtetra
.443 .73 .987 r
.08327 .38103 .09118 .38644 .10112 .38541 .09318 .3804 Mtetra
.448 .747 .992 r
.09318 .3804 .10112 .38541 .11116 .38411 .10318 .37955 Mtetra
.439 .76 .996 r
.10318 .37955 .11116 .38411 .12127 .38271 .11325 .3786 Mtetra
.422 .768 .996 r
.11325 .3786 .12127 .38271 .13143 .38134 .12338 .37762 Mtetra
.389 .766 .991 r
.12338 .37762 .13143 .38134 .14161 .38027 .13356 .37677 Mtetra
.347 .753 .982 r
.13356 .37677 .14161 .38027 .15178 .37972 .14377 .37617 Mtetra
.332 .744 .979 r
.14377 .37617 .15178 .37972 .16198 .37959 .15402 .37572 Mtetra
.338 .737 .983 r
.15402 .37572 .16198 .37959 .17219 .37983 .16432 .37537 Mtetra
.411 .754 .994 r
.16432 .37537 .17219 .37983 .18252 .37964 .17474 .3746 Mtetra
.501 .773 .993 r
.17474 .3746 .18252 .37964 .19303 .37841 .1853 .37301 Mtetra
.593 .795 .977 r
.1853 .37301 .19303 .37841 .20378 .37531 .19606 .37016 Mtetra
.673 .825 .957 r
.19606 .37016 .20378 .37531 .21483 .3697 .20703 .36567 Mtetra
.719 .871 .953 r
.20703 .36567 .21483 .3697 .2261 .36205 .21816 .35995 Mtetra
.74 .932 .952 r
.21816 .35995 .2261 .36205 .23755 .35269 .22941 .35328 Mtetra
.656 .967 .912 r
.22941 .35328 .23755 .35269 .249 .34328 .24068 .34673 Mtetra
.387 .831 .705 r
.24068 .34673 .249 .34328 .26038 .33492 .2519 .34103 Mtetra
0 0 0 r
.2519 .34103 .26038 .33492 .27162 .32843 .26304 .33662 Mtetra
.177 0 0 r
.26304 .33662 .27162 .32843 .28272 .32426 .27411 .33373 Mtetra
.27 0 0 r
.27411 .33373 .28272 .32426 .29375 .32156 .28517 .33173 Mtetra
.31 0 0 r
.28517 .33173 .29375 .32156 .30476 .31979 .29625 .3302 Mtetra
.305 0 0 r
.29625 .3302 .30476 .31979 .31585 .318 .30741 .32847 Mtetra
.278 0 0 r
.30741 .32847 .31585 .318 .32702 .31569 .31868 .32619 Mtetra
.248 0 0 r
.31868 .32619 .32702 .31569 .3383 .31279 .33004 .3233 Mtetra
.214 0 0 r
.33004 .3233 .3383 .31279 .34966 .30922 .34149 .31974 Mtetra
.184 0 0 r
.34149 .31974 .34966 .30922 .36111 .30511 .35303 .31562 Mtetra
.152 0 0 r
.35303 .31562 .36111 .30511 .37263 .30048 .36465 .31094 Mtetra
.113 0 0 r
.36465 .31094 .37263 .30048 .38422 .29517 .37635 .30558 Mtetra
.077 0 0 r
.37635 .30558 .38422 .29517 .39588 .28927 .38811 .29961 Mtetra
.041 0 0 r
.38811 .29961 .39588 .28927 .4076 .28282 .39993 .29307 Mtetra
.028 0 0 r
.39993 .29307 .4076 .28282 .41935 .27636 .4118 .28633 Mtetra
.048 0 0 r
.4118 .28633 .41935 .27636 .43111 .27082 .42368 .28005 Mtetra
.076 0 0 r
.42368 .28005 .43111 .27082 .44286 .26677 .43557 .27466 Mtetra
.124 0 0 r
.43557 .27466 .44286 .26677 .45462 .26507 .44747 .27081 Mtetra
.44747 .27081 .45462 .26507 .46641 .26527 .45939 .26827 Mtetra
.047 0 0 r
.45939 .26827 .46641 .26527 .47827 .26656 .47136 .2666 Mtetra
.157 .698 .784 r
.47136 .2666 .47827 .26656 .49023 .26781 .48341 .26506 Mtetra
.444 .837 .982 r
.48341 .26506 .49023 .26781 .50229 .26734 .49554 .26256 Mtetra
.6 .843 .99 r
.49554 .26256 .50229 .26734 .51445 .26479 .50775 .25879 Mtetra
.689 .833 .952 r
.50775 .25879 .51445 .26479 .52667 .25967 .52002 .25336 Mtetra
.734 .836 .928 r
.52002 .25336 .52667 .25967 .53894 .25262 .53233 .24661 Mtetra
.759 .852 .92 r
.53233 .24661 .53894 .25262 .55122 .24449 .54467 .23902 Mtetra
.773 .872 .921 r
.54467 .23902 .55122 .24449 .56353 .2359 .55704 .23098 Mtetra
.77 .891 .93 r
.55704 .23098 .56353 .2359 .57586 .22769 .56944 .22303 Mtetra
.765 .9 .936 r
.56944 .22303 .57586 .22769 .58823 .21988 .58187 .21521 Mtetra
.756 .899 .941 r
.58187 .21521 .58823 .21988 .60064 .2126 .59433 .20765 Mtetra
.753 .891 .941 r
.59433 .20765 .60064 .2126 .61309 .20562 .60683 .20019 Mtetra
.754 .878 .936 r
.60683 .20019 .61309 .20562 .62558 .19865 .61935 .1927 Mtetra
.757 .863 .927 r
.61935 .1927 .62558 .19865 .6381 .19158 .63191 .18509 Mtetra
.762 .848 .916 r
.63191 .18509 .6381 .19158 .65065 .18421 .64449 .17725 Mtetra
.765 .836 .906 r
.64449 .17725 .65065 .18421 .66321 .17657 .65709 .16919 Mtetra
.768 .825 .897 r
.65709 .16919 .66321 .17657 .6758 .16866 .66971 .16091 Mtetra
.769 .816 .89 r
.66971 .16091 .6758 .16866 .6884 .16055 .68235 .15246 Mtetra
.77 .808 .884 r
.68235 .15246 .6884 .16055 .70103 .1523 .69501 .1439 Mtetra
.769 .801 .878 r
.69501 .1439 .70103 .1523 .71368 .14397 .70769 .13525 Mtetra
.45 .68 .963 r
.02714 .37496 .03496 .38178 .04447 .38184 .03671 .37471 Mtetra
.462 .675 .957 r
.03671 .37471 .04447 .38184 .05405 .38183 .04634 .37439 Mtetra
.474 .671 .95 r
.04634 .37439 .05405 .38183 .06371 .38173 .05605 .37398 Mtetra
.487 .667 .943 r
.05605 .37398 .06371 .38173 .07345 .38148 .06583 .37346 Mtetra
.5 .665 .936 r
.06583 .37346 .07345 .38148 .08327 .38103 .07569 .37279 Mtetra
.511 .663 .93 r
.07569 .37279 .08327 .38103 .09318 .3804 .08563 .37199 Mtetra
.521 .663 .926 r
.08563 .37199 .09318 .3804 .10318 .37955 .09565 .37102 Mtetra
.528 .664 .923 r
.09565 .37102 .10318 .37955 .11325 .3786 .10575 .36995 Mtetra
.533 .663 .92 r
.10575 .36995 .11325 .3786 .12338 .37762 .11591 .36879 Mtetra
.536 .66 .916 r
.11591 .36879 .12338 .37762 .13356 .37677 .12614 .3676 Mtetra
.537 .651 .909 r
.12614 .3676 .13356 .37677 .14377 .37617 .13642 .36642 Mtetra
.542 .639 .895 r
.13642 .36642 .14377 .37617 .15402 .37572 .14677 .36519 Mtetra
.549 .623 .878 r
.14677 .36519 .15402 .37572 .16432 .37537 .15719 .36388 Mtetra
.562 .608 .856 r
.15719 .36388 .16432 .37537 .17474 .3746 .1677 .36227 Mtetra
.579 .599 .837 r
.1677 .36227 .17474 .3746 .1853 .37301 .17831 .3602 Mtetra
.598 .6 .825 r
.17831 .3602 .1853 .37301 .19606 .37016 .18905 .35752 Mtetra
.619 .614 .824 r
.18905 .35752 .19606 .37016 .20703 .36567 .19992 .35412 Mtetra
.637 .643 .839 r
.19992 .35412 .20703 .36567 .21816 .35995 .21088 .35022 Mtetra
.654 .69 .871 r
.21088 .35022 .21816 .35995 .22941 .35328 .22192 .34602 Mtetra
.654 .758 .926 r
.22192 .34602 .22941 .35328 .24068 .34673 .23298 .34198 Mtetra
.617 .83 .982 r
.23298 .34198 .24068 .34673 .2519 .34103 .24405 .33842 Mtetra
.514 .862 .991 r
.24405 .33842 .2519 .34103 .26304 .33662 .25512 .33548 Mtetra
.363 .821 .928 r
.25512 .33548 .26304 .33662 .27411 .33373 .26618 .33321 Mtetra
.283 .781 .876 r
.26618 .33321 .27411 .33373 .28517 .33173 .27728 .33122 Mtetra
.277 .776 .872 r
.27728 .33122 .28517 .33173 .29625 .3302 .28844 .32926 Mtetra
.339 .81 .912 r
.28844 .32926 .29625 .3302 .30741 .32847 .29969 .32701 Mtetra
.423 .848 .952 r
.29969 .32701 .30741 .32847 .31868 .32619 .31102 .32428 Mtetra
.49 .872 .974 r
.31102 .32428 .31868 .32619 .33004 .3233 .32245 .32106 Mtetra
.544 .888 .984 r
.32245 .32106 .33004 .3233 .34149 .31974 .33396 .31735 Mtetra
.581 .899 .985 r
.33396 .31735 .34149 .31974 .35303 .31562 .34555 .3132 Mtetra
.609 .908 .983 r
.34555 .3132 .35303 .31562 .36465 .31094 .35721 .30862 Mtetra
.636 .92 .977 r
.35721 .30862 .36465 .31094 .37635 .30558 .36895 .30353 Mtetra
.655 .933 .97 r
.36895 .30353 .37635 .30558 .38811 .29961 .38075 .29795 Mtetra
.669 .946 .959 r
.38075 .29795 .38811 .29961 .39993 .29307 .39261 .29189 Mtetra
.668 .955 .948 r
.39261 .29189 .39993 .29307 .4118 .28633 .40452 .28552 Mtetra
.65 .957 .938 r
.40452 .28552 .4118 .28633 .42368 .28005 .41647 .27917 Mtetra
.632 .951 .94 r
.41647 .27917 .42368 .28005 .43557 .27466 .42844 .27311 Mtetra
.614 .935 .96 r
.42844 .27311 .43557 .27466 .44747 .27081 .44043 .26771 Mtetra
.625 .902 .985 r
.44043 .26771 .44747 .27081 .45939 .26827 .45246 .26293 Mtetra
.638 .835 .976 r
.45246 .26293 .45939 .26827 .47136 .2666 .46452 .25864 Mtetra
.643 .754 .929 r
.46452 .25864 .47136 .2666 .48341 .26506 .47664 .25452 Mtetra
.649 .688 .873 r
.47664 .25452 .48341 .26506 .49554 .26256 .48881 .25008 Mtetra
.653 .65 .835 r
.48881 .25008 .49554 .26256 .50775 .25879 .50104 .24513 Mtetra
.664 .635 .811 r
.50104 .24513 .50775 .25879 .52002 .25336 .51333 .23944 Mtetra
.676 .637 .803 r
.51333 .23944 .52002 .25336 .53233 .24661 .52566 .23312 Mtetra
.689 .651 .807 r
.52566 .23312 .53233 .24661 .54467 .23902 .53803 .22631 Mtetra
.701 .67 .816 r
.53803 .22631 .54467 .23902 .55704 .23098 .55043 .21918 Mtetra
.71 .691 .83 r
.55043 .21918 .55704 .23098 .56944 .22303 .56287 .21196 Mtetra
.717 .71 .842 r
.56287 .21196 .56944 .22303 .58187 .21521 .57534 .20468 Mtetra
.721 .724 .852 r
.57534 .20468 .58187 .21521 .59433 .20765 .58784 .1974 Mtetra
.724 .732 .857 r
.58784 .1974 .59433 .20765 .60683 .20019 .60038 .19006 Mtetra
.727 .737 .859 r
.60038 .19006 .60683 .20019 .61935 .1927 .61295 .18263 Mtetra
.73 .741 .86 r
.61295 .18263 .61935 .1927 .63191 .18509 .62554 .17507 Mtetra
.735 .744 .859 r
.62554 .17507 .63191 .18509 .64449 .17725 .63817 .16733 Mtetra
.739 .749 .86 r
.63817 .16733 .64449 .17725 .65709 .16919 .65082 .15943 Mtetra
.744 .756 .862 r
.65082 .15943 .65709 .16919 .66971 .16091 .66349 .15137 Mtetra
.749 .764 .865 r
.66349 .15137 .66971 .16091 .68235 .15246 .67619 .14317 Mtetra
.754 .773 .869 r
.67619 .14317 .68235 .15246 .69501 .1439 .68891 .13486 Mtetra
.758 .782 .873 r
.68891 .13486 .69501 .1439 .70769 .13525 .70165 .12647 Mtetra
.517 .707 .957 r
.01926 .36808 .02714 .37496 .03671 .37471 .02898 .36692 Mtetra
.534 .685 .936 r
.02898 .36692 .03671 .37471 .04634 .37439 .03876 .36567 Mtetra
.546 .662 .913 r
.03876 .36567 .04634 .37439 .05605 .37398 .04861 .36432 Mtetra
.555 .641 .891 r
.04861 .36432 .05605 .37398 .06583 .37346 .05853 .36287 Mtetra
.561 .622 .87 r
.05853 .36287 .06583 .37346 .07569 .37279 .06852 .36132 Mtetra
.566 .605 .851 r
.06852 .36132 .07569 .37279 .08563 .37199 .07857 .35968 Mtetra
.569 .59 .835 r
.07857 .35968 .08563 .37199 .09565 .37102 .0887 .35793 Mtetra
.572 .578 .82 r
.0887 .35793 .09565 .37102 .10575 .36995 .09889 .35608 Mtetra
.574 .566 .807 r
.09889 .35608 .10575 .36995 .11591 .36879 .10915 .35414 Mtetra
.575 .555 .795 r
.10915 .35414 .11591 .36879 .12614 .3676 .11947 .35209 Mtetra
.576 .544 .782 r
.11947 .35209 .12614 .3676 .13642 .36642 .12986 .34994 Mtetra
.577 .533 .769 r
.12986 .34994 .13642 .36642 .14677 .36519 .14032 .34769 Mtetra
.577 .521 .756 r
.14032 .34769 .14677 .36519 .15719 .36388 .15084 .34533 Mtetra
.577 .511 .744 r
.15084 .34533 .15719 .36388 .1677 .36227 .16143 .34287 Mtetra
.577 .503 .736 r
.16143 .34287 .1677 .36227 .17831 .3602 .17208 .3403 Mtetra
.578 .5 .731 r
.17208 .3403 .17831 .3602 .18905 .35752 .18279 .33763 Mtetra
.58 .502 .731 r
.18279 .33763 .18905 .35752 .19992 .35412 .19357 .33486 Mtetra
.584 .51 .738 r
.19357 .33486 .19992 .35412 .21088 .35022 .20442 .33197 Mtetra
.589 .523 .749 r
.20442 .33197 .21088 .35022 .22192 .34602 .21532 .32898 Mtetra
.595 .54 .764 r
.21532 .32898 .22192 .34602 .23298 .34198 .22629 .32589 Mtetra
.6 .555 .776 r
.22629 .32589 .23298 .34198 .24405 .33842 .23732 .32268 Mtetra
.604 .562 .781 r
.23732 .32268 .24405 .33842 .25512 .33548 .24841 .31937 Mtetra
.605 .559 .776 r
.24841 .31937 .25512 .33548 .26618 .33321 .25957 .31595 Mtetra
.603 .544 .762 r
.25957 .31595 .26618 .33321 .27728 .33122 .27078 .31242 Mtetra
.6 .527 .744 r
.27078 .31242 .27728 .33122 .28844 .32926 .28205 .30878 Mtetra
.597 .51 .727 r
.28205 .30878 .28844 .32926 .29969 .32701 .29338 .30503 Mtetra
.594 .497 .714 r
.29338 .30503 .29969 .32701 .31102 .32428 .30477 .30116 Mtetra
.592 .489 .705 r
.30477 .30116 .31102 .32428 .32245 .32106 .31622 .29719 Mtetra
.592 .484 .699 r
.31622 .29719 .32245 .32106 .33396 .31735 .32772 .29311 Mtetra
.592 .482 .697 r
.32772 .29311 .33396 .31735 .34555 .3132 .33928 .28891 Mtetra
.594 .483 .697 r
.33928 .28891 .34555 .3132 .35721 .30862 .3509 .2846 Mtetra
.596 .487 .699 r
.3509 .2846 .35721 .30862 .36895 .30353 .36257 .28018 Mtetra
.6 .493 .704 r
.36257 .28018 .36895 .30353 .38075 .29795 .3743 .27565 Mtetra
.605 .504 .713 r
.3743 .27565 .38075 .29795 .39261 .29189 .38608 .271 Mtetra
.612 .519 .725 r
.38608 .271 .39261 .29189 .40452 .28552 .39791 .26624 Mtetra
.62 .539 .741 r
.39791 .26624 .40452 .28552 .41647 .27917 .40979 .26137 Mtetra
.629 .559 .757 r
.40979 .26137 .41647 .27917 .42844 .27311 .42173 .25638 Mtetra
.636 .575 .769 r
.42173 .25638 .42844 .27311 .44043 .26771 .43372 .25128 Mtetra
.639 .581 .773 r
.43372 .25128 .44043 .26771 .45246 .26293 .44575 .24606 Mtetra
.639 .576 .768 r
.44575 .24606 .45246 .26293 .46452 .25864 .45784 .24073 Mtetra
.636 .563 .756 r
.45784 .24073 .46452 .25864 .47664 .25452 .46997 .23529 Mtetra
.632 .548 .742 r
.46997 .23529 .47664 .25452 .48881 .25008 .48215 .22973 Mtetra
.629 .536 .731 r
.48215 .22973 .48881 .25008 .50104 .24513 .49438 .22405 Mtetra
.627 .53 .724 r
.49438 .22405 .50104 .24513 .51333 .23944 .50665 .21827 Mtetra
.629 .53 .723 r
.50665 .21827 .51333 .23944 .52566 .23312 .51897 .21236 Mtetra
.632 .536 .727 r
.51897 .21236 .52566 .23312 .53803 .22631 .53133 .20634 Mtetra
.638 .546 .735 r
.53133 .20634 .53803 .22631 .55043 .21918 .54373 .2002 Mtetra
.644 .56 .744 r
.54373 .2002 .55043 .21918 .56287 .21196 .55618 .19395 Mtetra
.651 .574 .755 r
.55618 .19395 .56287 .21196 .57534 .20468 .56867 .18759 Mtetra
.658 .588 .765 r
.56867 .18759 .57534 .20468 .58784 .1974 .58119 .18111 Mtetra
.665 .602 .775 r
.58119 .18111 .58784 .1974 .60038 .19006 .59376 .17451 Mtetra
.672 .616 .784 r
.59376 .17451 .60038 .19006 .61295 .18263 .60636 .1678 Mtetra
.679 .63 .793 r
.60636 .1678 .61295 .18263 .62554 .17507 .619 .16097 Mtetra
.686 .645 .804 r
.619 .16097 .62554 .17507 .63817 .16733 .63168 .15403 Mtetra
.694 .663 .815 r
.63168 .15403 .63817 .16733 .65082 .15943 .64439 .14698 Mtetra
.702 .683 .828 r
.64439 .14698 .65082 .15943 .66349 .15137 .65714 .13981 Mtetra
.712 .705 .842 r
.65714 .13981 .66349 .15137 .67619 .14317 .66991 .13252 Mtetra
.721 .73 .858 r
.66991 .13252 .67619 .14317 .68891 .13486 .68272 .12512 Mtetra
.731 .756 .873 r
.68272 .12512 .68891 .13486 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Sooooo`03ok_1gol0003ooooo01Gooooo00?o
0000ooooooooool0DOooool0063ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`0Mooooo`?o00000_ooool00ol0003oooooooooo`1Oooooo`?o^l7O00?o
0000ok_1goooool05Oooool00ol0003oooooooooo`1@ooooo`00H?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol0000Looooo`;o0000IOooool00onh^]_o^l7Ook_1g`02ok_1g`03o`000?o2
b=oooooo01Cooooo00?o0000ooooool00000DOooool0063ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0001[ooooo0ol0001Uooooo`Co^;[K0onk`Ml00ol0003o`/SO
ol;8g`0Fooooo`03o`000?oooooooooo04oooooo001Pooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool0000Hooooo`;o0000I_ooool00onf]=Oo^;[KokRjf`04okRjf`03
ok_1goo2b=oo000000?o`/SO5_ooool00ol0003oooooooooo`1>ooooo`00H?ooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oMgMgolc<c?l000005Oooool3o`0000;ooooo00?o0000oooooooo
ool0H_ooool3okJde`Co^;[K00Co`LGNol;8goo2b=oo00000_o2b=l00oo4cN3oooooooooo`0Doooo
o`03o`000?oooooooooo04kooooo001Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^
k^koA4A4o`00000Cooooo`;o0000JOooool4okJde`?o^;[K0oo1aMh00oo2b=oo0000ol;8g`03olC=
h1Kooooo00?o0000ooooooooool0COooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=oooo
o`03ogMgMol0003ooooo00oooooo0ol0001Yooooo`03ok>^donf]=Oo][CG00Co][CG00?o^;[Kol75
g_o1aMh00oo1aMh00ol0003oa<gPolC=h003olC=h1Kooooo00?o0000ooooooooool0C?ooool008;o
oooo0_l0001Zooooo`Co/jkC1?nf]=L00ono`mgo`LGNol75gP03ol75gP03olG>h_l0003oa<gP00?o
a<gP00?oa=3Tooooooooool05?ooool00ol0003oooooooooo`1<ooooo`00Ooooool3o`0000;ooooo
00?o0000ooooooooool0IOooool00onaZM3o/jkCok>^d`04ok>^d`03okJdeono`mgo_l?M00;o_l?M
0oo1aMh2olG>hP04o`000?o4cN3oa<gPolC=h0?oa=3T5?ooool3o`0004gooooo001looooo`?o0000
Joooool4ok6Yd0Co/jkC00?o_/7Loko3gOno`md01?no`md01oo1aMkoaLkRolG>h_o5c^;o0000olG>
h_o4cN001?o4d>@Gooooo`03o`000?oooooooooo04[ooooo001jooooo`;o0000K?ooool00on_YLgo
/JW@ok6Yd003ok6Yd0?o/jkC0onn`M`4oko3g@;oa=3S1?o5c^800ol0003oa=3TolC@i002olC@i0;o
_m;X5_ooool00ol0003oooooooooo`1:ooooo`00Moooool3o`0006cooooo1?n_YLd5ok6Yd003ok>^
donn`Mco_/7L00?o_/7L00?o_l?MolC@hoo4d><00oo4d><01_o5c^;oaMKWolGFiol0003oaMKWolC@
i0Go_m;X5_ooool00ol0003oooooooooo`19ooooo`00MOooool2o`0000;ooooo00?o0000oooooooo
ool0J?ooool00on]XL_o[jG=ojnUc@03ojnUc@Co/JW@00?o_KoLokk1g?nn`M`00onn`M`00oo4dnGo
a=3SolC@h`03olC@h`05olGLjoo5e^OoaMKWolGFiol000000_o0gNh4okoBj003okKAk_oooooooooo
01Gooooo00?o0000ooooooooool0B?ooool007;ooooo0ol00005ooooo`03o`000?oooooooooo06Ko
oooo0on]XL/5ojnUc@03ok6Yd?nm_mco_KoL00;o_KoL0onn`M`3olCCi@?oa=3S0oo5g>/00oo5e^Oo
`=g^o`000003ol3MkP03okoBj?nfdNko]]7^00;o]]7^5_ooool00ol0003oooooooooo`18ooooo`00
L?ooool2o`00073ooooo1?n]XL/4ojnUc@03okbnfonm_mco_KoL00Co_KoL00?o_/7LolCCiOo4dnD0
0oo4dnD01?o4d>?oaMc[olGLjoo5g>/2okkWlP05ol3Mk_l0003o`=g^ol3Mk_ndgO@01_nfdNhFoooo
o`03o`000?oooooooooo04Oooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo1Ol0000Pooooo`?o0000L?ooool00on/WLSo[J7;ojfQb`03ojfQb`?o[jG=0onl_]/4okfo
g0;o`mKW1?o4dnD01?o4hnkoaMc[olGLjoo5g>/4okkWlP03o`000?ndgOCo]=gd00;o]=gd1?nfdNh0
0onXc??oooooooooo`0Cooooo`?o0000B?ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A401kooooo0_l00003ooooo`03o`000?oo
oooooooo06_ooooo1?n/WLP5ojfQb`03ojnUcOnl_]_o_;kK00;o_;kK0onm_m`4ol?Fi`03olCCiOo4
hnkoa>?^00;oa>?^00?oaMc[okkWl_nnio800_nnio800on_j?Wo0000okCMm004okCMm003okKAk_nX
c??oZ<cc00;oZ<cc5_ooool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`0Yooooo`00>?ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h07?ooool3o`00077ooooo00?oZY[6ojbMb?n/WLP0
0on/WLP4ojfQb`03okZmg?nl_]_o_;kK00Co_;kK00?o_KoLol?Fioo3e^L00_o3e^L00oo1jO7oa>?^
olCSkP02olCSkP?o^?3e00Ko_^ObojoXnOn_j?Wo[nSio`000?n_j?T2okCMm0?oYMSi1OnXc?<Foooo
o`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`0Zooooo`00>?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h06?ooool3o`0007;ooooo1?nZV/H5ojbMb003ojfQbonj_Mco^[gL00;o^[gL1?nl_]/2
ol?IjP?o`mKW0oo1jO400oo4hnko^?3eokS`m@02okS`m@?oXnkg0_n_j?T00ol0003oWN7moigQo@05
ojGHn@;oZ<cc0onI`oDFooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@
400;ooooo`Go0000:oooool003Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo01Gooooo0ol0001booooo`03ojRF`onZV/KoZY[600?oZY[61?n/WLP00onj_=_o^[gLokZm
g004okZmg003okbnfoo3fN[o`mWZ00?o`mWZ00Co`mKWol7YlOo1jO7o`NWa0on/m?800onhl?GoXnkg
oj?^m`02oj?^m`;oS^Gj00?oWN7mo`000?nMhOd00_nMhOd2ojGHn@?oULcj1OnI`oDEooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`00
02cooooo000hooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Aoooo
o`?o00000oooool00ol0003oooooooooo`1]ooooo`CoZ9K31?nZV/H3ojbMb0?o^[cK1?nj_M`2ol7L
k@Co`mWZ0onlko<01?o1jO7o[?Cbojcdl_n/m?83ohg]k@03oj?^mon>iO[oS^Gj00?oS^Gj00?o0000
oigQoOn?doh00_n?doh5oiG<nP;oVL?e0_n=^?<Fooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002cooooo000hooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@017ooooo0_l0001dooooo`03
ojJB`OnXU/?oZ9K300?oZ9K31OnZV/H00on/WLSo^[cKokZlf`03okZlf`03okZmg?o1g>go`Mc]00?o
`Mc]00?o`mWZokc_lonlko<00_nlko<2oiObi`04ojcdl_n=kNgoSNg]ohg]k@CoN>7_0_n>iOX2ohCG
o`03o`000?n4eoooSm?n00?oSm?n0_nEc?X3oh^lm`CoSKSc5_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000/ooooo`00>?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00>ooooo`?o0000M?oo
ool4ojJB`@CoZ9K31?nZV/H00oni^m_o^[cKokZlf`03okZlf`;o`N3_1?o1g>d3ok?dl`03okc_lonG
l^OoUo;W00;oK]oF1?mJdmX2ogSQk`CoMmSl0_n4eol00ol0003oQ/;kohK2n`04ohW0n@GoRkcg1?n=
^?<Dooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;?ooool005Wooooo0ol0001dooooo`03ojB?__nVT/7oYY;100?oYY;11OnXU/<00onZV/Ko^K_KokVk
f`02okVkf`?o^[cK1?o1h>l00oo1g>go/oCcok?dl`02ok?dl`04ogSTd?m6a;;o=[^locJk_0CoD<[Z
1?mUdoD2ogOHo0?oQ<?l00?oQ/;ko`000?n6`_/00_n6`_/4ohW0n@;oRkcg0_n8/?04ohRal1?ooooo
00Co0000oooooooooooo00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`00
0?ooool0:oooool005Kooooo0ol00003ooooo`03o`000?oooooooooo06oooooo1?nTSkh4ojJB`@Co
Z9K300?o^;WJokVkfoni^m/01?ni^m/00onj_=_o`N3_ol7Pk`02ol7Pk`?oZ_K^00?o/oCcogSTd?lT
[lX00_lk_]`3ogZjn`CoOKol1On0`_`4ohC3o004o`000?n6`__oRZo^ohZ_kPCoRK3_1On8/?04ohRa
l1Kooooo00?o0000ooooooooool0@?ooool005Cooooo0_l0001fooooo`03oj>;_?nTSkkoY8nn00?o
Y8nn1OnVT/400onXU/?o^;WJokRifP02okRifPCo^K_K0_o0i?03ol7Pk`?oZ_K^00?oM[7gogJdnOmf
]?T00_mf]?T5ogZjn`CoOKol0_n0`_`2ohfYj@CoS:g/00?o0000ohZ_k_n:[nh00_n:[nh4ohV`k`Co
R;3`1?n8/O0Fooooo`03o`000?oooooooooo043ooooo001Aooooo`?o0000M_ooool4oj>;_0CoY8nn
1?nVT/400ong]MOo^;WJokRifP04okRifP03okVkfoo0i?3o`>C`00?o`>C`00?o`N3_oj[fk_nZm^h0
1?mf/OL4ogJdn@;oN[[k0_n=WMl4ohfTi0GoSJWY0on<[N`00ol0003oRZo^ohZ_kP02ohZ_kPCoRK3_
0_n8/?02ohbWi`GoRZc/5_ooool00ol0003oooooooooo`0oooooo`00C_ooool5o`0007Gooooo00?o
XHVjoj>;_?nSRk`00onSRk`5ojB?_P;oYY;10ong]ML4okRifP;o`NK`1?o0i?02oikei@;oRHW=1?n:
Sm84oh^Ff@GoSIgO1?n=Y>@4ohfYj@?oS:g/00?o0000ohZ_k_n:[nh00_n@W]d4ohjSh`GoS:OW1On:
[>`Fooooo`03o`000?oooooooooo03kooooo001<ooooo`;o00001Oooool00ol0003oooooooooo`1`
ooooo`CoXHVj1?nSRk`5ojB?_P03ojJB`Ong]MOo]kGG00;o]kGG0onh^MX4ol7Vl004ol3Tl?nNmNGo
W_GUoh^7b@CoRHW=1?n:Sm84oh^Ff@GoSIgO0on=Y>@2ohfYj@;oU9GB0onBV]P00ol0003oT9kMoi2N
g@03oi2Ng@CoSZ?S1On<YnL2ohZ/k0;oTjgX5_ooool00ol0003oooooooooo`0nooooo`00BOooool3
o`0007Sooooo00?oXHNioj69^_nQRKX00onQRKX5oj>;_0?oY8nn00?o]K3DokNeeong]ML01?ng]ML0
0onh^M[o`NK`ol7Vl002ol7Vl0;oU_;I0on;QlT4ohV9c@CoRXoB1On;U]T2ohfMg`;oU8[60onDT<`5
oiBEdP?oTY[H00?o0000oi2NgOn@W]d00on@W]d4ohjSh`;oS:OW0_nDY^85oi>]j1Cooooo0ol0000o
ooooo`008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^023ooooo0_l0001iooooo`CoXHNi1?nQRKX5
oj>;_003ojB?__ne/=Co]K3D00;o]K3D1?ng]ML3ol?Vk`04ol7Vl?nFl]WoU_;Iohn7a`CoRhO91?n9
RLd5ohZ?dP;oRiKI0_nCPkl5oiB:aP?oU93<1?nDUM83oi:Jf004o`000?nBV]SoT9kMoi2Ng@;oUi[D
1?nFWm/5oiBVhPGoTjgX5Oooool00ol0003oooooooooo`0mooooo`008_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01gooooo0ol00002ooooo`03o`000?oooooooooo07?ooooo0_nPQkT5oj67^@GoXHVj
0onSRk`00oncZm3o]K3DokF`e004okF`e003okNeeoo3i^oo`nK_00;o`nK_0_nDl<l3ohn7a`GoRhO9
1?n9RLd2ohZ?dP;oTGfj1OnCPkl4oiB:aP?oU93<1OnDUM82oi:Jf003o`000?nIULkoUi[D00CoUi[D
1?nFWm/5oiBVhP;oTjgX0onN/NDEooooo`03o`000?oooooooooo03cooooo000Rooooo`05oa0@4?oo
ooooooooooooool@41006oooool2o`0007Sooooo00?oXHVkoj27^OnPQkT00onPQkT4oj67^@GoXHVj
00?oXh^lok>[d?ncZm000_ncZm04okF`e0;oaNC^0oo3i^l01?nDl<ooU8W5oiB9aOnDRLD3ohn7a`;o
RhO90_n?M;04oi1h]0GoTGfj1?nCPkl4oiB:aPCoU93<0_nDUM82oiZAb@;oVIG>00?o0000oiVEc_nI
ULh01?nGV]@5oiJOf`;oU:KR0_nNZ=d6oijaiAGooooo00?o0000ooooooooool0>oooool002;ooooo
00Go0000ooooooooooooooooo`00000Hooooo`?o0000N?ooool3oj69^`GoX8Ni1OnQQkT3oj69^P03
ok2Vc_ncZm3o/j_@00?o/j_@0one/=@4olGTkP04ol?VkonKSLCoU8W5oiB9a@;oTG6/0on?LJh4ohmd
/0GoT7Rd1?nAOKX4oi>3_`GoU8[60_nDT<`00onLSL?oVY79oiZAb@03oiZAb@04oiVEc_l0003oVIG>
oiVEcPGoUi[D0_nFWm/2oijQePGoWZSM1?nN/ND00onZ^>?oooooooooo`0Cooooo`03o`000?oooooo
oooo03_ooooo000Rooooo`05o`000?ooooooooooooooool000005_ooool3o`0007Sooooo00?oXHbm
oj69^onQRK/00onQRK/4oj27^@GoXHNi00?oXHVjok2Vc_n`Y/h00_n`Y/h5ok>[d003okF`e?o5i>ko
aNC^00;oaNC^00?oU>o8oiAcZonDLj/01?nALJ`3ohma[PGoSgB`1?n@N;@4oi5m^PGoTh>o0_nDR/H2
oib8_PCoW8g31?nJTLT00onIULko0000oiVEcP02oiVEcP;oUi[D0_nOV/l5oijQePGoWZSM00?oW[7U
ojZhhonZ^><00_nZ^><Eooooo`03o`000?oooooooooo03[ooooo000Rooooo`05oa0@4?oooooooooo
ooooool@41004oooool3o`0000;ooooo00?o0000ooooooooool0M?ooool3oj6<_@GoXHVk1OnPQkT3
oj67^@03ojfScOn`Y/ko/:K>00?o/:K>1?ncZm03olGOj`03olGTk_nDklSoU>o800?oU7>[1OnALJ`3
ohma[PCoSgB`1?n@N;@5oi5m^P?oTh>o00?oW8Bioib8__nLR;h00onLR;h3oib=``GoVY7900Co0000
oiVEc_nPU/WoX9K91OnOV/l5oijQeP;oWZSM0_nY/=`5ojZhhaKooooo00?o0000ooooooooool0>Ooo
ool002;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`?o0000N_ooool00onRT<7oXHbmoj6<
_@03oj6<_@CoXHVk1OnPQkT00onQQkWo[J?=ojfSc@02ojfSc@Go/:K>00?o/j_@olGOjoo5gn/00_o5
gn/2oi[ab003oiMeZonDLj_oU7>[00?oU7>[1?nALJ`3ohma[PCoSgB`1On@N;@4oi5m^P03oi>3_onL
Q;WoW8Bi00;oW8Bi1?nLR;h3oib=``CoVY7900?oXI;5o`000?nPU/T00onPU/T4oinJc`CoWZ7F00?o
ZJWFojV`g?nY/=`00onY/=`3ojZhh`;o]<3S5?ooool2o`0003_ooooo000Rooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03_ooool2o`0007_ooooo1?nRT<44oj6<_@GoXHVk0onPQkT00onYX/oo[J?=ojfS
c@03ojfSc@Co/:K>0_o2f^/3olGOj`03oi[ab?nGMJ_oUgF[00;oUgF[1?nDLj/4oi5a[0?oSg6^1On?
M;04oi1h]0;oTGfj0_nJOk@5oib4^@CoW8Rn1?nLSL<01OnJTLWoXI;5oj6BaOnQT/Go000000CoX9K9
1OnOV/l00onNXMKoZJWFojVYeP02ojVYePGoZK3L00?oZ[SSokC0hond`><00_nd`><Eooooo`03o`00
0?oooooooooo03Sooooo000booooo`Go0000NOooool00onSTlCoXY31oj:@`@03oj:@`@CoXHbm1OnQ
RK/00onPQkWoZJ;?ojVRc`02ojVRc`Co[J?=0on`Y/h4ol;Jj`03olGOjonKNJcoVgV/00CoUgF[1?nD
Lj/4oi5a[0?oSg6^1On?M;02oi1h]0;oV7Z`1OnJOk@4oib4^@GoW8Rn0_nLSL<01?nSSl3oXI;5oj6B
aOnQT/D2o`0000CoX9K91?nOV/l00onYXm7oZJWFojVYeP03ojVYePCoZK3L00?o/k_OokC0hond`><0
0_nd`><00onianCoooooooooo`0Dooooo`03o`000?oooooooooo03Oooooo000`ooooo`;o0000Nooo
ool00onSU<GoXi?4oj>Ca002oj>Ca0CoXY311OnQS;d3oj69^`03ojNVeOnYX/ooZJ;?00?oZJ;?1On]
Xld00on`Y/ko`][[ol;Jj`02ol;Jj`04oiC_bOnKNJcoVgV/oi]i[0CoUgF[1?nDLj/4oi5a[0CoSg6^
0on?M;000onFMZgoV7Z`oiQj/002oiQj/0GoVWnd1OnLQ;T4oib8_P03oib=`onSSl3oXho000?o0000
00?oXI;5o`000?nPU/T01?nPU/T00onOV/ooZJ?AojVSd@02ojVSd@GoZJWF00?oZK3Lok>kgonc^ml0
0_nc^ml00ond`>?o^LOTokW7i002okW7i1Gooooo00?o0000ooooooooool0=oooool002gooooo0ol0
001kooooo`CoXiC51?nSTl@4oj:@`@CoXHbm00?oXHVkojNVeOnWY]D00_nWY]D4ojVRc`Co[J?=0onk
e^d01?o2f^_oU>o9oiC_bOnNNjd4oi]i[0?oUgF[1?nDLj/5oi5a[0?oSg6^00CoSgB`oiIf[OnFMZgo
UWJ]1OnHN[04oiYo]0GoW8Bi0_nLR;h2ojB=_@?o000000?oXho0oj6BaOnQT/D00_nQT/D00ol0003o
X9K9oj2Fb@02ojVOc0GoZJ?A1?nYZMH00onc]mco/k_Ook>kg`02ok>kg`03ok[7i?nianCo^LOT00Co
^LOT5Oooool00ol0003oooooooooo`0fooooo`00;?ooool2o`0007_ooooo00?oXY?4oj>DaOnSU<D0
0onSU<D4oj>Ca0CoXY310_nQS;d2ojJ`g`GoYjKE1OnYX/l00on]Xlgo^mK]ok_Fk@02ok_Fk@;oPnS8
0onNNjd4oi]i[0?oUgF[1OnDLj/4oi5a[0;oSg6^00?oU7:ZoiIf[OnFMZd00onFMZd4oiQj/0GoVWnd
0onLQ;T00onURkWoY8fmo`000002o`000004ojB=_OnSSl3oXho0oj>?`0CoXI;500?oZYc8o`000?nY
Wl`00onYWl`5ojVSd@03ojVYe_nc]mco/kOL00;o/kOL0_nc^ml3ok[7i0Co^LOT0_nkcNPEooooo`03
o`000?oooooooooo03Gooooo000/ooooo`?o0000N?ooool4oj:Ca0CoXiC51OnSTl@2oj:@`@;oY<7]
1?nV/=l5ojNVe@;oZJ;?0on`eO<3ok_Fk@03oh?Xb?nPOZgoWW^]00?oWW^]1?nKNJ`4oiMeZ`CoU7>[
0_nALJ`2oi=`Z0CoU7:Z1?nFMZd4oiQj/0GoVWnd00?oW8BiojF;^Ol000000_l00004ojB=_@CoXho0
00?oXI;5ojZLb?nZW<P00_nZW<P01?l0003oZIo<ojVOc?nYWl`4ojVSd@03ok>dfOnc]mco/kOL00?o
/kOL00?o/k_Ook[7i?njan@00onjan@00onianCo^lgXok_=j003ok_=j1Cooooo00?o0000oooooooo
ool0=Oooool002cooooo00Co0000ooooool0003o0000M?ooool2oj6?`@GoXY?41OnSU<D3oj>Ca003
oj?EnOnT`NgoY<7]00?oY<7]0onV/=l4ojNVe@;oVMOm1On`eO<01?nke^goX7j]oj1n[OnPOZd4oiik
[@GoVgV/0onGMJ/2oiAcZ`;oTfnV1?nCL:P4oiAbZPCoUWJ]1OnHN[03oiYo]0?o00000onURkT4ojB=
_@?oXho000?oZi[5ojZLb?nZW<P00onZW<P00ol0003oZIo<ojVOc002ojVOc003ojVSdOnc]=Wo/kCI
00;o/kCI0onc]m`2ok_8i0Co^/OT0_nleN`4ok_=j003okG>kOoooooooooo017ooooo00?o0000oooo
ool000002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o
0000oa0@4?o<c<`06Oooool002cooooo0_l00002ooooo`03o`000?oooooooooo06kooooo00?oWXVm
oj6?`OnQSl400onQSl44oj:Ca0GoXiC500?oXi?4oj?EnOnSeOT00_nSeOT5ojC1k@?oY[3O00?oYjKE
oiWGoOnIeod00onIeod2ok3El`;oE/nj1?nPOZd4oiik[@GoVgV/0_nGMJ/00onDKjKoTfnVoi=_YP02
oi=_YPGoTg2X0onDLZX4oiIf[@GoV7Z`0ol00002ojB8]`CoYH^i1OnTSKd01?nSSl3oZi[5oj^JaOn[
V/D4ojZLb005ojVOc?l0003oZIo<ojVOc?nd/]H01_nc]=T00onc]mco^lSTok_8i002ok_8i003ok[7
i?nleNco_=G/00?o_=G/00?o^lgXokG>kOnec^d00_nec^dEooooo`03o`000?oooooooooo00Gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q
01Wooooo000[ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Joooool4oij9_@Co
XHo11OnRTl@2oj>Da@CoWnKl1?nSeOT2ojC1k@Co:;;81?mae_/2oiWGo@03ojJ3[onSPJkoXh6^00;o
Xh6^1?nPOZd5oiik[@?oVgV/00CoUG2VoiA_Y_nDKjKoU6nV1OnCKjH4oi=`Z0CoU7:Z1?nFMZd2oiQj
/0;o00001OnTR;L5ojF;^@?oY8fm00?o[I[3oj^JaOn[V/D00_n[V/D5ojZLb003ojVOc?l0003o];;F
00;o];;F1?nc]=T00onlb^Go^lSTok_8i002ok_8i0;o_=g`1?nleN`00ondfO?o]Lk]okG>k@03okG>
kAGooooo00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000Iooooo`00:oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06Sooooo00?oW8Bioij9_OnNRKd00onNRKd4oj6?`@CoXY?40onMkoD2oioVo003okVbdonlZLOo
_:W700;o_:W700?o[YFmok2B]on`T[L00on`T[L4ojf>]P03ojV;]_nVPjooYX>_00;oYX>_0onSPJh5
oj1n[@CoWW^]00CoVgV/oiE`Y_nEL:KoUG2V1?nDKjH4oi=_YPCoTg2X1?nDLZX3oiIf[@?o00000_nS
QK<5ojB8]`GoYH^i00CoY8fmojfJ`on]V/?o[I[31?n[V/D4ojZLb003okFaeOnd/]Ko000000Co];;F
00?o/kCIokc:iOnlb^D00_nlb^D00onkb>Co_=g`okcMl003okcMl003okcEk?ndfO?o]=Wc00;o]=Wc
0_nec^d3oj_;l1Gooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000oiRHV?ooooooV9RHob4Q8@0Iooooo`00:oooool3o`0000Gooooo00?o0000oooooooo
ool0I?ooool00onJPKKoW8Bioib4^@02oib4^@CoWXVm1OnQSl401OnRTlCoWNoeoig_mOnMkoGo/;kT
00Go^K;C00?o_:W7ojjE_On^UKd00_n^UKd4ok2B]`Co[Hjf1OnVPjl3oj>1[PGoX7j]0_nNNjd2oiQb
YPCoUG2V1?nDKjH4oi=_YPCoTg2X1?nDLZX3o`000003oj61/OnSQK?oXhFc00?oXhFc1OnTR;L3ojF;
^@03ojnJ`_n]V/?o[I[300?o[I[31?n[V/D00onZW<So]K7EokFae@02okFae@04okBbe_l0003o];;F
okBbeP;o_LgW0onlb^D2ok[Wm0Co_=g`0_nai?P3okCIl`;oZ=Gg1On[bo0Eooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
6Oooool002_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Qooooo`?oVX6f1?nL
Q;T5oij9_@?oXHo10_nQlo05ok2ni0?o^K;C00?oYYW8ojjE_On^UKd00on^UKd5ok2B]`;o[Hjf00?o
Z8J`ojJ3[onVPjl00onVPjl4oj>1[P?oX7j]00?oVgFWoiQbY_nHLZH00_nHLZH5oiE`YP?oU6nV1?nC
KjH4oi=`Z006oiAbZ_l0003o0000o`000?nDLZ[oUWJ]0_nQPK45oj>5/`GoY8Rg00?oYH^iojnJ`_n_
V/800_n_V/84ojfJ``?oZi[500?o]k?EokFaeOne/MD01?ne/MD00ond/]Ko0000okg=i`03okg=i`03
okc:iOnjioCo^^Od00;o^^Od00?o_=g`ok7Tn?nai?P00onai?P00ondfO?oZ=GgojSEm`02ojSEm`;o
Zl_`0_nP`o4Eooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`03oeEEEOn7QhOooooo01_ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0GOooool2oiUn]0GoVX6f1?nLQ;T4oij9_@04oj6?`OnQlo3oXO?`oj7cl0;oV<Sh1On`_^@01?ni
/]?oYYW8ojJIb?nVVLP4ojjE_@Go/9:g00Co[HjfojR6/?nXQ[3oZ8J`1?nVPjl4oj>1[P04oj1n[OnK
MJOoVgFWoi]eY`GoV7:V1?nEL:H3oiA_YPCoTfnV0_nCL:P3o`0000?oU7:Z00?oWGb^oj61/OnQPK40
0_nQPK44oj>5/`CoY8Rg00?o/9_1ojnJ`_n_V/800on_V/84ojfJ``03oj^JaOng/mGo]k?E00;o]k?E
1?ne/MD2okkCjP04okg=iol0003o_LgWokg=i`;o/o3f0_njio@4ojK/n@;o/NCh0onQgo`2ojSEm`?o
WLWf1?nP`o4Cooooo`?o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@
4?nHV9P06oooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`00
0003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Ioooo
o`03oiQl/_nIO[CoVGjd00;oVGjd1OnJPKH4oib4^@?oWXVm0onVm?02ohO@o`?oV<Sh0_n`_^@2oiVK
e0CoYYW81On^UKd3ok2B]`03ojR8/onXQ[3oZ8J`00;oZ8J`1OnVPjl2oj>1[P03oiehZ?nKMJOoVgFW
00?oVgFW1?nHLZH4oiE`YP?oU6nV0onCKjH3o`0000?oTg2X00CoU7:Zoiel[_nMO:koWGb^1?nQPK45
oj>5/`;oY8Rg0on`Vl44ojnJ`P?o[I[300?o^KKGokNceOng/mD01?ng/mD00one/MGo_]?ZokkCjP03
okkCjP04o`000?ncl?Ko/o3fok?`mP?oT>g`0_nVk?T3oi;To0;oXMol0onGc_/5oig9mPCoX<?a5Ooo
ool02Ol0003oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000
oa0@41Wooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool01?ooool3o`0000[ooooo00?o0000ooooooooool0Eoooool2oiQl/PGoVGjd1?nJPKH5
oib4^@03oij9_OnVm?3oY_C`00CoQJ;V0on7W>05oiVKe0?oYYW81On^UKd01?n`T[OoZ8RcojR8/onX
R;<4ojR6/0GoYX>_00?oXh6^oiehZ?nMN:P01OnKMJL4oiQbYPCoUG2V0onDKjH3o`0000;oTfnV0onC
L:P00onJMj_oWGb^oiel[P03oiel[P?oXH6a1OnSQK<00onTR;Oo/9_1ok2K`@02ok2K`@Go[i[200Co
[I[3okVfeoni]]Oo^KKG1?ng/mD2okkKkPCo_]?Z0_nRlnl01?l0003oT>g`oi3]l?n@kO03ogOPlP;o
T^Cl0on?d?h5oiO>n`;oWLWf0_nH^_04oiVjkaGooooo00?o0000ooooooooool0;oooool000Sooooo
1_l00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`1Cooooo`;oV7^b1?nHO;84oiUn]0GoVX6f0onLQ;T2oj_dlP?o
TJ_W1?n5X^H3ohNLh0CoVI_D1?nVVLP3ojjE_@03oj:8^?nXR;?oZ8Rc00?oZ8Rc0onXQ[04ojJ3[`03
oj5kZOnMN:SoWGRX00;oWGRX1?nKMJL4oiQbYPCoUG2V00CoU6nVo`000?l0003oU6nV1?nCKjH01?nC
L:SoVWN[oiYgZonJMj/5oiel[PCoXH6a0onSQK<00onbVl7o/9_1ok2K`@03ok2K`@Co[i[200?o_KgJ
okVfeoni]]L00oni]]L00ong/mGo_]_^okkKkP03okkKkP07okkCj_nRlnooX_?_oj;ckomXfm?oD/oI
o`000002oe;?f@;oMn3b0_n5dOl5oho@oP;oUlkk0_nF^>l5oiRjl0CoVK[_5Oooool00ol0003ooooo
ooooo`0^ooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo
00001_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04kooooo0_nGNk84oiQk/PCo
V7bb1?nIO[@5oiZ1]P03oib4^On[m?;oZoCb00?oYk?Q0onAZnL4ohFRiP;oQicP1OnIVm@3ojJIb004
ojjE_OnRR;SoXXRhoj:8^0GoZ8Rc1?nXQ[02ojJ3[`;oXG^Y1?nMN:P4oi]eY`CoV7:V0_nEL:H3o`00
00?oU6nV0_nCKjH2oiMcZ0GoVWN[1?nMO:h4oj61/@03oj>5/onbVl7o/Y_100;o/Y_11On`Vl400on_
V/;o_KgJokfmfP02okfmfP?o^KKG0_nli_<4okkKkP?oOnSF00GoX_?_ogC:oomdb_ooNlkoo`000003
og_>o`CoQM7o0_n?d?h3oiBekPCoU[S_1?nH^_02oiVjk`?oVKK/5Oooool00ol0003oooooooooo`0]
ooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04[ooooo1OnGNk85oiQk/P?oV7bb1OnI
O[@3oiZ1]P;oZo;e1?nW/n401?nNS<3oSh?2ohn3`_n?Pl84oh=ma0?oOW_50_nIVm@2ohR0a0?oUXFo
1OnRR;P4ojR8/`CoZ8J`00?oYX>_oj5kZOnQNjT00_nQNjT3oiehZ0CoVgFW0onHLZH3o`0000?oUG2V
0_nDKjH00onEL:KoUg>XoiMcZ002oiMcZ0GoVWN[1?nMO:h4oj61/@Go/Y_11?n`Vl400oo2bMoo_KgJ
okfmfP04okfmfP03okVfeonli_?o_>Kc00;o_>Kc00Co_]_^ogoXe_moj=KoOnSF0omcaOl3ogC:o`04
og_>ool0003oTZSUoi:Xi@GoTZo[1OnD]Nh3oiJhk`;oV;[`0onI/^T5oiVfk1Cooooo00?o0000oooo
ooooool0;Oooool0013ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co0000
00Kooooo0_l0000?ooooo`;o0000BOooool7oiMk/PCoV7^b0onHO;85oiUn]003oiZ1]_n[l_GoZo;e
00?o][KI00?oYk?Qoij<`?nNS<000_nNS<03ohn3`PCoPgg40_mnNlD5ohR0a0?oUXFo1?nRR;P5ojR8
/`;oZ8J`00?oXGf/oj5kZOnQNjT00onQNjT3oiehZ0CoVgFW0ol00002oiQbYPCoUG2V00?oU6nVoiE`
Y_nEL:H01OnGLjP4oiYgZ`GoWGb^0_nQPK42ok6K`0Co/Y_10on`Vl43ol;9g`Co_KgJ00?o]?7eokcV
lonli_<00_nli_<01?m:`jGoMkglogNmo?mg_O`2og?5o`;oTiKC0onBWmd2oi:Xi@03o`000?nBZ>Go
TZSU00GoTZo[0_nD]Nh2oiVWh0CoVJgU1OnI/^T2oiVfk0;oW[GX5Oooool00ol0003oooooooooo`0/
ooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03oooooo1?l00002oiMm]0SoUg^b1?nHNk84
oiQl/P?oVGjd0_nWk_P01Onj/M7o][KIokJffOnf]]WoZiBn00GoWXc00on?Pl84oh=ma0?oOW_51?n8
P<@3oiJ5_`CoXXRh1OnXR;<00onXQ[3oXGf/oj5m[005oj5kZ@?oWGRX00GoVgFWo`000?l0003o0000
oi]eY`04oiQbYP;oUG2V0_nDKZ@4oiE`YPCoUg>X1?nJMj/5oiel[P04oj61/OnaVl3o/I_0ok6K`0Go
/Y_100?o/9_1ol;9goo2bMl00oo2bMl00onm_M[o]?7eokCam@02okCam@03okcVlonFQ[ooUXJo00Co
U8g91OnCU]<3oi:Og@;oTZSU00?o0000oi:XiOnBZ>D00_nB[n/2oiVQfPGoVJOP1?nI[ND2oiVbj@;o
WZkS1OnN]NPCooooo`;o0000;_ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03
ogMgMol0003ooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0kooooo`?o
00000_nHOkH4oiMm]0SoUg^b1OnHNk83oiQl/P04oiUn]?nWk_SoYnkhojO^n0?o^[7A00Co][KIoj^D
__n[U;koZiBn1?nNS<03ohn3`PCoPgg40omnNlD4ohR0a0?oUXFo1OnRR;P3ojR8/`03oj1n[onQOJco
XGf/00;oXGf/1?nQNjT01?nMN:So0000o`000?l00004oi]eY`;oV7:V0_nEKZ@4oiA^Y0CoUG2V1?nG
LjP5oiYgZ`?oWGb^00?o/9Vook6K`?naVl000_naVl04ok:K`@;oamWW1?o2bMl2oi[ciP;o]?7e00?o
V7ngoiJ6_onFQ[l00onFQ[l4oiB=b@CoTiKC1?nBWmd01?nBZ>Go0000oiZJd_nJV]85oiVQfPCoVJOP
0_nI[ND2oijXg@GoWZkS1?nN]NPEooooo`03o`000?oooooooooo02_ooooo000Yooooo`;o00005?oo
ool00ol0003oooooooooo`0iooooo`03o`000?nHP[[oV7nf00?oV7nf1OnGOK@7oiMk/PGoV7^b0_nH
O;83oj;[nPCo^[7A00?o/YRloj^D__n[U;h00_n[U;h5oij<`0?oSh?21?n3OL@2ogika@GoR8340onF
QKl4oj:8^004ojR8/onPOZooX7j_oj1n[`CoXGf/0_nQNjT3o`0000?oWGRX0onKMJL00onFKj?oUFjT
oiE^Y002oiE^Y0GoU6jT0onEL:H4oiMcZ0GoVWN[00?oWGb^ok2I_on`VKl00_n`VKl4ok6K`003ok:K
`Oo7fNOoamWW00?oamWW00Go`/WOoi[ci_nJlnKoV_?VoiUk/004oiQo]`CoUXJo1?nDSLT3oi>Fd`03
oif>`onKTl_oVi?;00;oVi?;0_nJV]800ol0003oVY[BoiZJdP04oiVQfP;oVJOP0_nOX]H5oijXg@Go
WZkS0_nN]NP2ojFiiaGooooo00?o0000ooooooooool0:_ooool002Wooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0eooooo`;oVHJn0onHP[X5oiQo]PCoUgfd2?nGNk83oiQk/P?oVnSk
00GoX^_jokNXbongZ<_o]jS;okZad@04ok:H_0?oZiBn1OnNS<02ohn3`P03ohmc[on6Kk;oQVnb00;o
QVnb0on1K[@4ohR0a0?oUXFo0_nRR;P2oiQl/`CoX7j_1?nQOJ`2o`0000?oXG^Y0onMN:P01?nKMJOo
UVnSoiI_XonFKj<4oiE^Y0GoU6jT0onEL:H4oiMcZ0CoVWN[00?o[YNook2I_on`VKl00on`VKl4ok6K
`003olS^kOo7fNOoamWW00;oamWW0_mOdK05oiUk/0?oV7ng1?nFQ[l5oiB=b@04oi>FdonMS/?oWHk3
oif>``CoVi?;0_nJV]800ol0003oVY[BoiZJdP02oiVQfP03oj2Ld?nOX]KoWj;F00?oWj;F1OnNZ=d2
oij^h`;oYK?R1OnU^NLDooooo`03o`000?oooooooooo02[ooooo000Yooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0<Oooool00onJRl?oVHJnoiV6_P02oiV6_PCoV8:j1?nHOkH4oiMm
]0SoUg^b00GoV7^boi_XnonKj?_oVnSkojVJa`05okNXb`Go/YRl1?n[U;h2oij<`0;oV7V_0on?Ljl4
ohI_/P?oPFjd1?n3LKL3oh]f]PCoV7bc1?nPOZl01?nQOJco0000o`000?l00005oj5kZ@;oWGRX00?o
V76ToiI_XonFKj<00_nFKj<5oiE^Y0CoU6jT0onEL:H5oiMcZ0;oVWN[0on^Ukl4ok2I_`?o/I_00oo8
k^d00oo7fNOoGm6`oeoA/002oi]hZ`GoVG^`0onHOkL5oiJ6_`;oU8g90_nORK`4oif>``GoVi?;0_nJ
V]800ol0003oXYO9oj2Ld003oj2Ld0GoWj;F0_nNZ=d2ojJ^g@GoYK?R0_nU^NL3ojbniaCooooo00?o
0000ooooooooool0:Oooool002Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0]
ooooo`03oiZ?a_nJRl?oVX_300;oVX_31?nIQ[h3oiR2^PCoV7nf1OnGOK@5oiMk/P?oU>Kl1OnYV/L3
okNXb`;o]9Rk1?nbV;`3oj^D_P03oj60[onHNJooV7V_00;oV7V_1?n?Ljl4ohI_/P;oPFjd1?n3LKL3
oh]f]PGoV7bc00CoX7j_o`000?l0003o00000onQOJ`5oj5kZ@03oiehZ?nHLJCoV76T00GoUVnS1?nE
KZ@4oiA^Y0CoUG2V1?nGLjP00onJMj_o[YNoojjG_`02ojjG_`Go/9Vo00Co/I_0olS^kOo8k^gob>k]
0_nLMJL5oi]hZ`CoVG^`1?nHOkL2oiJ6_`;oXHJg1?nORK`4oif>``CoVi?;00GoY9?4oj:GbOnRUlWo
0000oj:Gb@04oj2Ld0CoWj;F00?oZ:[HojJ^gOnV[]d00onV[]d3ojFchP03ojfki?n/_^Oo[;kW00Co
[;kW5?ooool00ol0003oooooooooo`0Xooooo`00:Oooool3o`0001Oooooo00?o0000ooooooooool0
:_ooool4oiZ?aP?oVX_31?nIQ[h3oiR2^PGoV7nf1?nGOK@2oiMk/PCoRn?k00?oU>KloiV:`_nIR/80
1OnYV/L01?ngZ<_o]9RkokBH^ondV;/5ok:H_003oj^D__nQP:ooXH2_00GoV7V_0on?Ljl4ohI_/P?o
PFjd1?n3LKL3oh]f]P;oV7bc0ol00003oj1n[`CoXGf/0onQNjT01?nJLjKoV76ToiQaY?nHLJ@5oiI_
X`CoUFjT1?nDKZ@4oiE`YP?oUg>X00?oZi>nojjG_on^Ukl00on^Ukl4ok2I_`;o^O_V00?ob>k]oied
Y?nLMJL00onLMJL4oi]hZ`GoVG^`0_nHOkL00onSQ;;oXHJgoj66]`03oj66]`CoWhVl1?nMS/<00onK
Tl_oY9?4ojBCa002ojBCa0;oXYO900?o0000oj:GbOnPW=000onPW=000onOX]KoZ:[HojRZf002ojRZ
f0CoYZkM00?oYK?Rojfki?n]^n@00_n]^n@4ojbni`03ojo3j?oooooooooo017ooooo0_l0000Zoooo
o`00:Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Oooooo00?oVXo7oiZ?a_nJ
SlH00onJSlH3oiZ;``CoVHJn1?nHP[X4oiQo]P;oUgfd1?mmgoT2oh_Sn`;oRWbn0onIR/84ojVJa`03
ojfB^_ndV;_o]9Rk00;o]9Rk1?nbV;`00onYQk7oXH2_oj60[`02oj60[`CoV7V_0on?Ljl4ohI_/P?o
PFjd1?n3LKL2oh]f]P?o00000_nHO;<4oj1n[`CoXGf/00CoXG^YoiYcY_nJLjKoVW>V1?nHLJ@4oiI_
X`CoUFjT1OnDKZ@3oiE`YP03oiMcZ?n[TkkoZi>n00;oZi>n1On^Ukl2ok2I_`;o^O_V00?oV7fdoied
Y?nMM:@01?nLMJL4oi]hZ`GoVG^`00?oV7ngoj>4/_nSQ;801OnQQ[L4oin9_0?oWHk300?oYY2oojBC
a?nTTl@00onTTl@3oj:Gb@03o`000?nPW=3oX9c@00;oZZKC1_nXZ]P2ojJ^g@03ojjih_n]^nCo[K_T
00Co[K_T00?o[;kWojo3j?n_`nP00_n_`nPDooooo`03o`000?oooooooooo02Oooooo000>ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00005ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool08_ooool2oiV>aPCoVXo71?nJSlH4oiZ;``CoVHJn0onHP[X2oiQo
]PCoK=Wc0_mmgoT2oh5c^`CoRWbn0onIR/83ojVJa`?o[I:j1?ndV;/2ok:H_0;oZHNa1?nQP:l4oiQi
[`?oSg>_1?n6Kk83oh5^]0?oPg6g0ol000000on;M[KoV7bcoiQl/`02oiQl/`CoX7j_0_nQOJ`2oiYe
Z0CoVW>V1?nHLJ@4oiI_X`CoUFjT1OnDKZ@2oiE`YP03ojR@_On[TkkoZi>n00?oZi>n1On^Ukl01?n`
VKoo^O_VokWki_nHOK@4oiedY0?oW7FW1?nKN:/4oiUk/003ojF3[onSQ;;oXhBb00;oXhBb1?nQQ[L4
oin9_003oif>`onVT;ooYY2o00;oYY2o1?nTTl@3oj:Gb@03o`000?nZY]?oZZKC00?oZZKC1?nXZ]P0
0on`^N3o[[WRojjihP02ojjihPCo[K_T00?o/LCXojo3j?n_`nP00on_`nPEooooo`03o`000?oooooo
oooo02Kooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07_oo
ool00onHR/?oVHk6oiV>aP03oiV>aP?oVXo71OnJSlH3oiZ;``CoVHJn0_nHP[X2oeK?j@?oRg^l0on4
M[/3oh5c^`CoRWbn1?nIR/800onYV/Oo[I:jojfB^P02ojfB^PCo]9Rk00?o/YRlojV7/OnYQk400_nY
Qk43oj60[`CoV7V_1?n?Ljl4ohI_/P;oPFjd0ol00002oh=a]`?oRgJf1?nHO;<2oj1n[`03oiQfZonJ
MJSoVWFX00;oVWFX1OnJLjH3oiQaY0CoUVnS1OnEKZ@4oiA^Y004oiE`Y_nXT;goZ92mojR@_@CoZi>n
1?n^Ukl01?n7ik[oVGV]oiUi[OnNLj85oiedY0?oW7FW1OnKN:/2oiUk/0;oYH>_1?nSQ;85oj66]`;o
WhVl00?oZ8nkojJ@_onVT;l00onVT;l5ojBCa004oj:GbOn/YLoo[:G?o`0000GoZZKC00?oZ:[Hok2i
h?n`^N000_n`^N04ojjihP03ojfki?naa>So/LCX00;o/LCX0_n_`nP3ojo7jaCooooo00?o0000oooo
ooooool09_ooool000Kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onH
V9So8B4Qonk^kP06ooooo`;o00007Oooool00ol0003oooooooooo`0Iooooo`;oUXFo1?nHR/<4oiV>
aP?oVXo71OnJSlH2oiZ;``;oB<OP0onGQl44oi61_PCoRg^l0on4M[/3oh5c^`CoRWbn0_nIR/800onS
R;So[I:jojfB^P03ojfB^PCo]9Rk1OnYQk43oj60[`GoV7V_0on?Ljl4ohI_/P;o000000?oPFjdoh=a
]on3LKL00_n3LKL3oh]f]PCoV7bc00?oX7j_oiQfZonHMZ/01OnJMJP4oiYcYP?oV76T1?nFKj<5oiE^
Y0?oU6jT00?oYHjlojR@_OnXT;d00_nXT;d5oj^C_P04ojjG_onJMJSoVWFXoiUi[@?oWW>R1OnMM:@3
oiaeY`GoVgR[00?oVG^`ojF3[onUPjl00_nUPjl3oj>4/PGoXHJg00CoWhVlojR?^onXSk_oZ8nk1?nV
T;l4ojBCa003ok2UcOn/YLoo[:G?00;o[:G?00Go0000ojZVdonZY]?oZZKCok>kg`05ok2ih0;o[[WR
0onba^T3ok74j0;o/<c^1On_an/Dooooo`03o`000?oooooooooo02Gooooo000>ooooo`05o`000?oo
ooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool04Oooool2oiB0^`?oUH:l1OnFQKl3oiR:``CoVHk61?nJSlL2oiZ?aP?oG=;]
1?nIRl<3oiN7`@?oTH6n1?n;Nk`3ohAf^`?oPG>k0_n:O;h2oiAl]PCoXhRh1On]T[X2okBH^`03ojj<
/_nYQk7oZHNa00?oZHNa1?nQP:l4oiQi[`;oSg>_00?oT6^TohaYY_l000000_l00003ohMYZ@CoPfV]
0on4K:l4ohmb[PCoV7J[1?nJMJP4oiYcYP?oV76T1OnFKj<4oiE^Y003oiA^Y?nUS[coYHjl00;oYHjl
0onXT;d4oj^C_P04oi]cYOnJMJSoVWFXoiYeZ0GoWW>R1?nMM:@4oiaeY`?oVgR[00?oZ8>]ojF3[onU
Pjl00onUPjl4oj>4/P?oXHJg00?oZi2iojR?^onXSk/00_nXSk/5ojJ@_`03ojBCa?n`YLgo/:G=00;o
/:G=1?n/YLl00ol0003o/k_Ook>kg`02ok>kg`?o/;WP0_ncb^/5ok;6j@03ok74j?n`c>ko/<c^00;o
/<c^0_n_an/2ojc6kAGooooo00?o0000ooooooooool09?ooool000kooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool07_ooool2o`0000ko
oooo00?oTgnkoiB0^onDP;/00_nDP;/4oiF2_0CoUXFo0onHR/<5oiV>aP;oVXo70_n3g?d4oib=``Co
VH_30_nGQl401?n>LJkoRW2_ohY`[on:L:l4ohM^/0?oQVna0on8L[<4oiAl]PCoXhRh1On]T[X01?nd
V;_o[Xbbojj</_n^S;84ojV7/@CoXH2_0_nHNJl2oiA]Y004oi1[Y?l0003o0000o`0000?oS6VV0on7
JJT4oh=Y[@?oQ6b_1?n?LZh4oiQfZ`CoVWFX1?nJLjH4oiQaY0CoUVnS0onEKZ@00onTSKgoYHjlojF>
_003ojF>_0CoZ92m00CoZi>noi]cYOnKLjGoVg>U0_nJMJP00onOLj7oWW>RoiicXP03oiicXPCoWGBT
1?nLMJL01?nKN:_oZ8>]ojR3[OnXPjd5ojF3[`CoXhBb00?oXHJgoj^@^On[T;T00_n[T;T3ojR?^`Co
YY2o00?o/jO<ok2UcOn`YLd00on`YLd3ojbUc`03okNohOl0003o/k_O00Co/k_O00?o/;WPok?:jonc
b^/00_ncb^/2ok;6j@;o/=;b1?n`c>h2ojc;l0Co[<K]4oooool2o`0000Sooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Wooooo000>oooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`;o00008Oooool0
0ol0003oooooooooo`07ooooo`;oTh2l0onCOk/5oiB0^`?oUH:l1?nFQKl4oiR:``;oVHk60onMe?/0
1?mSe;CoWho3oin?`onOSl<2oib=``03oi=c[?n@LZgoT7:]00;oT7:]0on>LJh3ohY`[`CoQfj`0on6
Kk43ohQb/`GoU7bf0onSR;P4ojfB^P03ojb;/_n^S;;o[Xbb00;o[Xbb1OnYQk42oj60[`03oiQbY_nD
KJCoU6fT00?o00000on@Jj@3ohaYYPCoQfVY1?n3JJd3ohA/[`CoSg:^0onHMZ/4oiYeZ0CoVW>V1?nH
LJ@4oiI_X`03oiE^Y?nTSKgoY8fm00;oY8fm1?nUS[`4ojR@_@CoVg>U00CoVWFXoimcXOnOLj7oWg>Q
1?nNLj85oiedY0?oW7FW1OnXPjd5ojF3[`;oXhBb00?o[i>ioj^@^On[T;T00on[T;T4ojR?^`03ojJ@
_oncYlco/jO<00;o/jO<1On`YLd01On/YLoo]koQokNohOng_n7o000000;o/k_O0_nedNh4ok?:j`;o
[][f1?n`d_800on`c>ko[<_`ojc;l003ojc;l0;o[<K]0_nW`nhDooooo`03o`000?oooooooooo00Go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q00Wooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@00Cooooo0_l0000Sooooo`03o`000?oooooooooo00?ooooo00?oTh:noi>0_?nCP;`00_nC
P;`4oi=o^`CoU82k0onEP[`5oiJ5_`;oV8[31?nW`^d00onMe?_oYoOYojBB`P02oin?``04oiIeZonC
LjcoTg>/oi=c[0CoT7:]1?n>LJh3ohY`[`?oQfj`1?n6Kk43ohQb/`CoU7bf1?nSR;P00on]T[[o[8^b
ojb;/P02ojb;/P?o[Xbb1OnYQk400onQP:ooV7:Vo`000002o`0000;oU6fT1?n@Jj@3ohaYYPCoQfVY
1?n3JJd3ohA/[`CoSg:^0onHMZ/4oiYeZ0GoVW>V0onHLJ@2oiI_X`;oXhjo1OnTSKd5ojF>_0;oZ92m
00GoVg:Roi]cYOnKLjGoVg>Uoj1dX@04oimcX@CoWW>R1OnMM:@2oiaeY`03ojZ5[OnXPjgoZ8>]00?o
Z8>]1OnUPjl01?nSQ;;o[i>iojnC^On_TkT4oj^@^@?oZ8nk00?o^:c=ok>Wc?ncYl`00oncYl`4ok2U
c@03ok_9iOng_n7o]koQ00;o]koQ00?o]=_do`000?nedNh00onedNh00oncb^_o[][fojkJmP03ojkJ
mP;o/=;b0_nYdO@4ojc;l003ojK7lOnW`nkoYl?^00?oYl?^5?ooool00ol0003oooooooooo`04oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Wooooo000>
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo
00?o0000ooooooooool08oooool00ol0003ooooooi>5`@04oi>2_PCoTh2l0onCOk/4oiB0^`CoUH:l
0_nFQKl3ojN`gPCoYl;]0_nWmnT00onTT/;oVWN[oiIeZ`02oiIeZ`CoTg>/0on@LZd4ohia[P?oRW2_
0on7K[04ohI_/@?oR7:c1?nDO;H4oj>8^0Go[8^b1?n^S;83ojV7/@?o000000?oV7:VoiA]Y?nDKJ@0
0_nDKJ@4oi1[Y0CoS6VV0on7JJT4oh=Y[@?oQ6b_1?n?LZh3oiQfZ`GoVWFX1?nJLjH2oiQaY003oj:A
`_nSS[ooXhjo00?oXhjo1?nTSKd5ojF>_003ojR@_OnKLZ;oVg:R00;oVg>U0_nPM:44oimcX@CoWW>R
1OnMM:@01?nLMJOoZXF]ojZ5[OnZQJd4ojR3[@CoYH>_00?o]9ZlojnC^On_TkT00_n_TkT5oj^@^@04
ojR?^onh[<go^:c=okR/c@Go/jO<00?o/:G=ok_9iOnkbND00_nkbND00ong_n7o]=_dokCKm002okCK
m003o`000?nedNko]M7^00?oZ>?k0_n^f_H2ojCFn@GoZM7d00?o[<_`ojK7lOnVao400_nVao43ojO3
kP03ojBokOoooooooooo01;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P09ooooo`009oooool00ol0003oooooooooo`0N
ooooo`03oi>;b?nCR<CoThS400;oThS41?nCQL43oi>2_PCoTh2l0onCOk/5oiB0^`;oUH:l00?oXjCF
ojN`g_nW/=h01?nW/=h01OnW`^goYoOYojOgjOnWmnWoX?6j00;oVWN[1?nFMJ/3oi=c[0?oT7:]1?n>
LJh3ohY`[`CoQfj`0on6Kk43ohQb/`GoU7bf0_nSR;P00onVQK7o[8^bojb;/P03ojb;/PCo[Xbb0ol0
00000onONJSoV7:VoiQbYP02oiQbYP?oU6fT1?n@Jj@4ohaYYP?oQfVY1?n3JJd3ohA/[`CoSg:^1?nH
MZ/4oiYeZ0CoVW>V00CoV76Toj:A`_nRTL;oXY721?nSS[l5ojB=_@?oYHjl1?nKLZ801?nKLjGoX7BQ
oj1dXOnPM:44oimcX@GoWW>R0onMM:@00on]R:koZXF]ojZ5[@02ojZ5[@GoZ8>]0_nUPjl2okBJ_0Co
[i>i1?n[T;T00onm]]?o^:c=okR/c@02okR/c@Co/jO<0_nnfNd3ok_9i@;o[NSi1?ndfo@01?l0003o
UnSjojSSnonXho/2oicJo@GoY=Ki0_nYdO@2oj?:m0GoY/Oa00?oYl?^ojBokOnT_nd00_nT_ndDoooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o
0000o`000?o<c<`02Oooool002Oooooo0_l0000Looooo`03oi>>bonCRlSoTh_800;oTh_81?nCR<@3
oi>5`@?oTh:n1?nCP;`4oi=o^`CoU82k00CoUH:loj>Te_nSY=KoXjCF1?nW/=h3okg^l`;oX?6j1?nJ
Mj/3oiIeZ`?oTg>/1?n@LZd3ohia[P?oRW2_1?n7K[04ohI_/@?oR7:c1?nDO;H01?nSR;SoYXFaojJ5
/OnVQK45ojb;/P03ojj</_l0003o000000CoWgVX1?nHLZH4oiA]Y0?oT6^T1?n<JJH4ohMYZ@CoPfV]
0_n4K:l4ohmb[PCoV7J[1?nJMJP2oiYcYP;oXYG81?nRTL84oj>>_`GoY8fm00CoYHjloi]`XOnKL:7o
Vg2Q0onKLZ85oj1dX@CoWg>Q1?nNLj82oiedY0;o[HR^1?nZQJd5ojR3[@04ojF3[ondV[co]9ZlokBJ
_0Go[i>i0_n[T;T2okffd`Go^:c=00?o/jO<okkIkOnnfNd00onnfNd00onkbNGo[NSiojgXn@02ojgX
n@06okCKm?nGj?[oUnSjohkKool0003oS]_o1?nLf_d2ojCFn@?oWl_f1?nSb_@2ojK7l@?oX/3^1?nT
_ndEooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@
4?nj^[[ooooookZj^_l@41002Oooool002Oooooo00?o0000ooooooooool05?ooool2oi:Cd@?oTY3>
1?nCS//4oi>;b0?oThS40onCQL44oi>2_PCoTh2l0onCOk/2oiB0^`;oWYgB1OnSY=H00onW/=ko_Nkc
okg^l`02okg^l`;oX?6j00?oWG^/oiYgZonJMj/00_nJMj/3oiIeZ`?oTg>/1?n@LZd4ohia[P?oRW2_
0on7K[04ohI_/@?oR7:c0_nDO;H2oiYk[`CoYXFa0on/Rk83o`0000;oYGn[1?nONJP4oiQbYPCoU6fT
1?n@Jj@3ohaYYPCoQfVY1?n3JJd3ohA/[`CoSg:^0onHMZ/2oiYeZ0;oWYW?1OnRULP3oj:A`PGoXhjo
0_nTSKd00onJKYooVg2Qoi]`X@03oi]`X@;oVg:R00?oXGFQoj1dXOnPM:400onPM:44oimcX@CoWW>R
00?oWGBTojf8[_n]R:h00_n]R:h3ojZ5[@CoZ8>]00?o_:K3okBJ_?ndV[`00ondV[`4ojnC^@03oj^@
^Onm]]?o_KKC00;o_KKC0onh[<d3ok[`m0;o_]W]0onAk?82ojgXn@;oM>7[0omkeoh2ohkKo`04o`00
0?n>foooW=[moicJo@;oV/[h1OnOboH2oj?:m0;oXKo_1OnR`>h2ojBok@;oX[c/4_ooool3o`0000Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000002Oooool0
02Oooooo00?o0000ooooooooool03_ooool01?n@V]WoTIOEoi6GeOnAUmD5oi:Cd@?oTY3>0onCS//4
oi>;b0?oThS41?nCQL43oi>2_PCoTh2l0_nCOk/00onIVM?oWYgBoijMdP03oijMdP?oXjCF1?nhg_<0
0onmk_?oX?6joiek[002oiek[0CoVWN[0onFMJ/3oi=c[0CoT7:]1?n>LJh3ohY`[`?oQfj`0_n6Kk42
oh]/Z`?oSg6]1?nJNjl4ojJ5/@?o000000?o[8^bojR3[?nUOj/00onUOj/3oimiZ0CoV7:V1?nDKJ@4
oi1[Y0?oS6VV0_n7JJT2oiF1^`CoQh?80omhQM<4ohmb[P;oV7J[00?oUY[EoijIconNVLl00onNVLl4
oj:Eb0CoXY720onSS[l01?nIKYooVVjOoiY^WonJKYl5oi]`X@03oi]bX_nQMJ7oXGFQ00GoX7BQ1?nO
Lj44oiicXPGo[HR^1?nZQJd2ojR3[@?o_:K31?ndV[`3ojnC^@03olC9g_nm]]?o_KKC00?o_KKC00?o
^:c=ok[`m?njl?@00_njl?@2od_9_`;oTNcb0_ln`LD3ofg?o@;oNmOn0_nA_O@2oiG6n003o`000?nE
a_SoULKh00CoV/[h0_nOboH2oinmkPGoXKo_0_nR`>h2oj:jjPGoX[c/5?ooool02Ol0003ooooooooo
ooooooook^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT02Oooool0
02Kooooo0ol00009ooooo`04ohjTi?n?WmkoSioNohnOgPCoT9[I0onAUmD4oi:Cd@?oTY3>0onCS//5
oi>;b0?oThS40onCQL42oi>2_P03ohnKfonDVMKoU9WF00;oU9WF1?nIVM<5oijMdP03oj>Te_nhg_?o
^=kc00;o^=kc00?oU_38oj5o[onMNj`00onMNj`4oiYgZ`?oUWF[1?nCLj`3oi1b[@;oSW6^0_n?K:L3
oha[Y`?oRVZY1?n;K:/3ohma[@CoVW^_00GoYXFao`000?l0003o0000ojJ5/@02ojb;/P;oZ8>/1?nU
Oj/4oimiZ0?oV7:V1?nDKJ@4oi1[Y0;oS6VV00?oVWfcoiF1^onEPK/00onEPK/4ohN3b0;oN8GC1?n5
T]P4oiJJe@CoWYW?1?nRULP4oj:A`P04oj>>_onIKYooVFjOoiU^W`CoVVjO0onKL:400onRMZ;oXGFQ
oj5eX@02oj5eX@CoX7BQ1?nOLj44oiicXPGo[HR^1?nZQJd00onXPjgo_:K3okbV``02okbV``Co]9Zl
00?o[i>iolC9g_o4bMh00_o4bMh3okffd`?oQ>[D00?o^_3dogBjo?md^_`00_md^_`3ofO5oP;oKLom
0onB/N`4oi6mm0;oULKh00?o0000oifcj?nM^N`00onM^N`5oinmkP;oXKo_0_nQ^>P5oj:jjP;oX[c/
0_nT_>/Eooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo00;ooooo0_n8
[nl3oh^Yj@CoSZCT0on?Wmh3oi2Jf@CoTIOE0onBTm44oi:@cP?oThk;0_nCRlP2ohVVj0?oRZ?U0on<
Wn04ohnKf`CoU9WF0onIVM<4oijMdP;o[=?d0onhg_<4oj5o[`CoWG^/0onJMj/4oiIeZ`?oTg>/0_n@
LZd00onAKJKoSfbWohm/Y`02ohm/Y`?oS6^W0on:JZT5oh]/Z`?oSg6]00CoVW^_o`000?l0003o0000
1?nVQK401?n/Rk;oZ8>/ojR3[?nXPj`4ojEoZ`CoWgVX1?nHLZH3oiA]Y0?oT6^T00?oVg^^oiYm/onJ
OK<00_nJOK<4oiF1^`CoQh?80omhQM<4ohFBf0?oUY[E1?nNVLl5oj:Eb0;oXY7200?oVFfOoiU^WonI
KYl00_nIKYl4oiY^W`;oVg2Q0_nRMZ84oj5eX@CoX7BQ1OnOLj42oiicXP;o/Hfa1?n]R:h4ojZ5[@Go
_:K30ondV[`2olGWk`Goa<WN00?o_KKCohCZe?n4j]@00on4Z>`2ogBjo0;oVIO@1?nDXml5oi:ak0;o
TKgd00KoWJcQoifcj?nM/nSoWK?Xo`000?nM/nP4oifik0;oWkg^0onQ]>D4oj6hj0;oX[[Z0onT^NP4
ojBljaCooooo00?o0000ooooooooool07_ooool001_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06
ooooo`03o`000?ooooooQ;Cd00;oQ;Cd0on8[nl3oh^Yj@?oSZCT0on?Wmh4oi2Jf@CoTIOE0onBTm42
oi:@cP03ohRYjon9Z>[oRJSZ00;oRJSZ1?n9Y^P3ohZSi@?oS9oP1?n?Vm/3oiBIePCoVIWC00?oWYgB
ojcCm?n/do@00on/do@00onhg_?oXhBboj>4/P03oj5o[`CoWG^/1?nJMj/3oiIeZ`;oTg>/00CoTfnV
oi5]Y_nAKJKoTFfV1?n?K:L4oha[Y`?oRVZY1?n;K:/01?n?LJgo0000o`000?l00003oiYk[`?oYXFa
00?oYh6/ojR3[?nXPj`00_nXPj`4ojEoZ`CoWgVX1?nHLZH3oiA]Y004oi1[Y?nKNjkoVg^^oi]k[PCo
VWfc1?nEPK/5ohN3b0?oN8GC1?n5T]P3oiJJe@CoWYW?0_nRULP2oiM]W`?oVFfO1?nIKYl4oiY^W`04
oi]`XOnRMZ;oXWJRoj9fXPCoXGFQ1?nPM:45oimcX@04oiicX_naSK7o/Hfaok6=/@Go[HR^0_nZQJd2
olNnd@Go_:K300?o]9ZlolGWkoo5inl00_o5inl2olC9gP?oTYSF00?oXXVjoif>`onMS/<00_nMS/<5
oiVGd0CoU:?O0_nB/N`2oj2Tf@CoWJcQ0onM/nP01?l0003oWK?Xoifik?nM^N`2oj6_h@GoXKCU0_nQ
^>P2ojBgiPGoY;WX0_nT_>/2ojJmjQCooooo00?o0000ooooooooool07Oooool001_ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00?oQ;Cd0on8[nl3oh^Yj@?oSZCT0on?
Wmh2oi2Jf@;oPZW^0on5ZNd4ohNYk0?oR:W[1?n9Z>X3ohVVj0CoRZ?U0on<Wn04ohnKf`?oU9WF0_nI
VM<4oiO;nP;o[=?d1?nSQ;83oj5o[`CoWG^/1?nJMj/2oiIeZ`04oiI`Y_nCKjKoTfnVoi=_YPCoTFfV
0on?K:L4oha[Y`?oRVZY0_n;K:/3o`0000;oSg6]1?nJNjl2ojJ5/@;oYh6/1OnXPj`3ojEoZ`CoWgVX
1?nHLZH2oiA]Y003oiQi[onKNjkoVg^^00?oVg^^0onJOK<5oiF1^`;oQh?80_n7HZ43oh1MX0CoPEfP
0on;I:04oiA[X0CoUffO0onIKIl5oiU^W`?oVVjO1OnRMZ83oj5eX@GoX7BQ0onOLj400onfUkOo/Hfa
ok6=/@02ok6=/@Go[HR^00CoZXF]olNndOo7_]7oakkA1?nlY/<00on=k]OoaNO_olGWk`02olGWk`Co
Vhg300CoTYSFoj:9^_nRRK[oXXVj1?nMS/<4oiVGd0;oU:?O0_nSWLl5oj2Tf@CoWJcQ0_nM/nP00ol0
003oXj[Loj6_h@04oj6_h@;oXKCU0_nU]><5ojBgiP;oY;WX0_nW^nP5ojJmjQ?ooooo0_l0000Noooo
o`006oooool01Ol@413ooooooooooooooooo410@00Kooooo0_l00002ooooo`?oLjkf0omf[?@3ogV[
l`CoO:[a0omoZ^l3oh:YkP?oQJW]1?n7ZN`3ohRYj`CoRJSZ0on9Y^P2ohZSi@?oE;kj0omF_?/3ofW1
oPCoP<Gn0_nGboX2o`0000;oYXVg1?nSQ;83oj5o[`CoWG^/0_nJMj/2oiMbY`?oUW2V1?nCKjH3oi5]
YP?oSfbW1?n<JjL2ohYZZ@?o00000_n;K:/3ohma[@CoVW^_00?oYXFaojN1[?nWPJ`00_nWPJ`4ojR3
[0CoYGn[0onONJP2oiQbYP;oUW^c0onHNJl5oi]k[PCoVWfc0onEPK/00omgh/KoU6bQohMRX@02ohMR
X@?oP5fP1?n1GJ03oh]TX0CoU6^P1?nGKIl3oiU]W`GoVFjO0_nJKYl00onRN:CoXWJRoj9fXP03oj9f
XP?oXGFQ1OnPM:42oimcX@;o]YNg1?naSK44ojf8[P03om3^j?o7_]7oakkA00?oakkA00?o_:K3ohg^
eon=k]L00_n=k]L00oo5inooXXNgoi^=``03oi^=``03ojR8/onRRK[oXXVj00;oXXVj1OnMS/<2oiVG
d003ojNIaonSWLooXig?00?oXig?1?nPY=T2oif/h@;oY:GF0onSZ]`01?l0003oXj[Loj6_hOnQ[n42
ojNag`GoYKCS0onT]nH00onW^NGoYk_XojNkj003ojNkj0?oY[gZ00?oZKoZooooooooool04?ooool0
0ol0003oooooo`00000Nooooo`006oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool00_ooool3og>^mP?oMZcd0omiZo<4ogbZl@?oOj[_0on2ZNh3ohFYk@;oQjW/0om``_h4
ofc4oP?oHlCm0omH`?/4oeBnnP?oE[ck0omY`Oh2oh35oP04okR[c?nXSkcoZ8nlojR?_0CoYXVg0onS
Q;84oj5o[`;oWG^/00?oV7FYoiMbYonGLZL00_nGLZL3oiI`YPCoTfnV0onAKJH4ohm/Y`?oS6^W0_l0
00000on:JZWoRfb[oh]/Z`02oh]/Z`CoSg6]0_nJNjl00onNNZ_oYh6/ojN1[003ojN1[0CoZ8>/1?nU
Oj/2oimiZ003oib5^_nFNk?oUW^c00;oUW^c1?nHNJl4oi]k[PCoVWfc00?oUH6kogORa_o2m>l00_nD
K:43ohMRX@CoP5fP0on1GJ03oh]TX0CoU6^P1?nGKIl4oiU]W`CoVFjO00?oVVjOoj9hY?nRN:@01OnR
MZ83oj5eX@GoX7BQ00CoWg>QokJG]onfUkOo]YNg1OnaSK42ojf8[P?od>kX0oo7_]45ojV6[`CoXXNg
00?oVhg3ojR8/onXR;<00_nXR;<3oj:9^PCoWHk300?o[IS1ojNIaonWVLL00_nWVLL5oj>Mc`;oX:CI
00?oZ:;@ojBUe_nTYMH00onTYMH3oj>Zg003o`000?nW/MooYk7O00?oYk7O1?nU]><00onT]nKoYkWU
ojNii@02ojNii@CoYk_X00?oY[gZojVoj_nY_nX00_nY_nXDooooo`03o`000?oooooooooo01_ooooo
000Kooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`CoKJ_f
0om/[OL3ofb`n@?oKK;j0om_]_/3og6jo0GoL[om0om``_h2ofc4oP;o=[cG00?oT>oWokWblonil_<0
0_nil_<3ol?Fj003olGDi_nk]]Go^kKE00;o^kKE0onj/M000onZU/7oZ8nlojR?_002ojR?_0CoYXVg
1?nSQ;83oj5o[`03oiek[?nHMJWoV7FY00CoUg:W0onFL:H4oi=_YP?oTFfV1?n?K:L3o`0000CoRVZY
1?n;K:/3ohma[@03oiYk[onNNZ_oWWZ[00GoYh6/1?nXPj`3ojEoZ`04ojNE`onLQK[oW8Fjoib5^PGo
UW^c0onHNJl5oi]k[P;oVWfc0oo2m>l4oiA/X@;oQf:Q1?n0GJ03oh5MX0CoRfBP0onDJj04oiM]W`Co
VFfO0onIKYl00onQN:KoXWRToj9hY002oj9hY0CoXWJR1?nQMJ43oj1dX@03okfV`_nfUkOo]YNg00?o
]YNg1?naSK400on]R:kod>kXom3^j003om3^j003olNndOnFM:_oZHJ_00CoZHJ_1?nRQkL5ojR8/`Co
XXVj00?oWHk3ojfH`On]V<400_n]V<43ojNIa`CoXig?00?o[:7;ojRRd?nXX]000_nXX]05ojBUeP04
oj>Zg?nY[mco0000ojV_g0GoYk7O0_nU]><2ojVgh`GoYkWU0_nW^nP2ojVnj@?oZKoZ00?oZ/7Zoooo
ooooool04oooool00ol0003oooooooooo`0Jooooo`006oooool01Ol@413ooooooooooooooooo410@
00Gooooo00?o0000ooooooooool01Oooool4off[mP?oK:gg0om//?T3offbnP?oKkKk0oma^_`2og:o
o@?oF/_f0om5a]<00omOem?oT>oWokO]mP03okO]mP05okWbloo3e^So`mKXol?Fj?nk^mT01_nk]]D0
1?nj/M3oZYK1ojZF`OnZU/43ojR?_0CoYXVg1?nSQ;82oj5o[`03oiUh[?nHMJWoV7FY00;oV7FY0onG
LZL3oiI`YPCoTfnV0onAKJH01?n?K:Oo0000o`000?l00004oha[Y`?oRVZY1?n;K:/2ohma[@03oiAa
Z?nNNZ_oWWZ[00;oWWZ[1?nWPJ`4ojR3[003ojEoZonWUL?oYiG300;oYiG30onLQKX4oiIk/`?oV7V_
1OnKNjh01?nJOK?o`_C_ol;dkoo2m>l5oiA/X@?oQf:Q0on0GJ03oh5MX0CoRfBP0onDJj05oiM]W`?o
VFfO00CoVFjOoj5hY_nQN:KoXGRV1?nRN:@4oj9fXPCoXGFQ0_nPM:43okfV`PCo]YNg0onaSK43o`00
00;od>kX00?oW7>ToiIdZonFM:/00_n^Qj`5ojV6[`;oXXNg00?o[XbaojR8/onXR;<00onXR;<4oj:9
^PGo[IS11?nWVLL01?nSWLoo[:7;ojbQbon/XL/5ojRRd0;oY:GF0_n/[]P3ojV_g004o`000?nY[mco
Yk7OojNag`;oZkOQ1OnY]n<2ojNii@;oZ[kX1OnY_^T01?nY_n[oZ/7Zoj[1j_nZ`NXDooooo`03o`00
0?oooooooooo01[ooooo000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000Oooooo
0_m]ZoH2og:]mP?oK[;j0om[^?`5ofNmoP?oIL?n0_mPao/2oeC=j@?oK]gX0_nFk_84okO]mP?o`MGY
00Co`mKXok^kfOnk^mWo^k_I1?nk]]D00on]W<KoZYK1ojZF`@02ojZF`@CoZ8nl0onVRKL2oj>4/P;o
VW^`0onIN:`4oiQeZ@?oUg:W1?nFL:H3oi=_YP04oi5]Y_l0003o0000o`0000?oSfbW1?n<JjL2ohYZ
Z@03ohiZY?n@K:KoT6bV00;oT6bV0onDLJP4oiijZ`GoYh6/0_nXPj`00onfY<OoYiG3ojNE``03ojNE
``?oW8Fj1?nFNk<3oiQi[`CoVg^^0oo5hN`00oo2m>ooWg>PoimcX004oiA/X@?oQf:Q0on0GJ03oh5M
X0CoRfBP0onDJj05oiM]W`;oVFfO00?oWWVYoj5hY_nQN:H00onQN:H3oj9hY0CoXWJR1?nQMJ400onP
M:7o_JK2okfV`P02okfV`PCo]YNg00Co/Hfaoj5eXOnQMJ7oXGFQ1OnLLj@01?nFM:_o[XN/ojj7[?n^
Qj`5ojV6[`04oj:7]on^S;7o[Xbaojj</@GoZ8Rc0_nRRKX2ok:J_PCo[IS10onWVLL00onaXlWo[:7;
ojbQb`03ojbQb`?oZ:;@00?o/:oGojb^f?n/[]P00on/[]P3ojV_g003o`000?n[]n7oZkOQ00?oZkOQ
0_nY]n<2ojbni`GoZ[kX0_nY_^T2oj_2jPGoZ/7Z5?ooool00ol0003oooooooooo`0Iooooo`006ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool01oooool4og:]mP?oK[;j
0om[^?`2ofNmoPCoK<_n0_mRcoL3og_Om`?oW>[j0onfi_H00ongkOKo`MGYol7Ej@02ol7Ej@;o_;oL
1?nk^mT00onk]]Go[Ic6ojfLaP02ojfLaP?oZYK11?nXSk`2ojJ9]`03oiYo]?nJNk3oVW^`00;oVW^`
1?nIN:`3oiQeZ@CoUg:W0onFL:H01?nCKjKo0000o`000?l00003oi5]YP?oSfbW0_n<JjL2ohmZY0?o
SVZT1?n@K:H4oiAaZ0?oWWZ[1OnWPJ`01?nXPjco]ZC7okJTaonfY<L4ojNE``?oW8Fj1?nFNk<4oiQi
[`;oVg^^0oo5hN`4oimcX0?oU6bQ00CoTFBJohELV_n5G9[oQEbJ0on0GJ03oh5MX0CoRfBP1?nDJj04
oiM]W`03oiU]WonNNJWoWWVY00GoXGRV0onRN:@5oj9fXP?oXGFQ1OnmY/84okJG]`04ojQjXOnQMJ7o
XGFQoj5eX@GoW7>T1?n^Qj`5ojV6[`Co[Xba1OnXR;<01?nRRK[o/YZnok:J__nbV[h5ojfH`@04ojNI
aonaXlWo/J?9ok6Sb@Co[:7;00?oZ:;@ok2_eon`[mL00_n`[mL4ojb^f005ojV_g?n^^>3o[[SPojjh
h?l000000on[]n400on]`>Oo[;kWojbni`03ojbni`;oZ[kX0on[`n/4oj_2jP;oZ/7Z0_nZ`^/Doooo
o`03o`000?oooooooooo01Wooooo000Uooooo`03o`000?oooooooooo00Sooooo0_mb[OH3oh6cm@Co
Nkck0omdaOl2ofc;oP?oQM[n0onQh_`00onLj_[o]^KfokKVmP02okKVmPCo_m?Y00?o`MGYokbog?nl
_m`00_nl_m`2ok^kf@03ojnSbon]W<Ko[Ic600?o[Ic61?nZU/42ojR?_004oib4^OnJOkCoVWndoiYo
]0CoVW^`1?nIN:`3oiQeZ@CoUg:W00CoUW2Vo`000?l0003o00000onCKjH2oi5]YP04oi9]Y?n@JjCo
T6^Toi1[Y0CoSfZT1?n>JZ@3oi1/YPCoU76X0onNNZ/4ojN1[003okj/aonfY<Oo]ZC700;o]ZC71OnW
UL<3oib5^PCoUW^c0onHNJl01OnKNjkoaN7/olGQk?o5hNcoXgFP00CoWg>P00CoU6bQoi5TV_nAI9[o
TFBJ0on5G9X3oh1JV`CoPEfP0on;I:04oiA[X0?oUffO00?oW7R[oiiiZOnNNJT00_nNNJT4oj5hYP?o
XWRT1OnRMZ82oj5eX@;oa/;F1OnmY/82okJG]`;oZ7ZQ1?nQMJ43oiacY003okJ>[?n^Qjco[XN/00;o
[XN/1?nYQZl00oniU[Co[Xbaojj</@02ojj</@CoZ8Rc00?o^j;0ok:J__nbV[h00_nbV[h4ojfH`@03
okV[bonaXlWo/J?900;o/J?90on/XL/00onf]=Oo/:oGok2_e`04ok2_e`;o[:kH0_na^n43ojjhh003
o`000?n^^>3oZkOQ00?o[L3W0on/_^L2ojc5k0GoZl?[0_n[`^X2oj[3k0CoZ/;[4_ooool00ol0003o
ooooo`00000Jooooo`009Oooool00ol0003oooooooooo`0:ooooo`CoPK?e0_mk_?/2oi76n@CoS=7n
0onTeoX2oj7Ro0?o]]kd0_nnd>P4okoCj@;o_L7M0onl_m`00onbZLoo[j?;ojnSb`02ojnSb`Co[Ic6
0onZU/401?nNRKkoW8Bioib4^OnLQ;T4oiYo]0?oVW^`1?nIN:`3oiQeZ@;oUg:W0ol00002oiI`YP?o
TfnV00CoU6nVoi9]Y?nBKJCoTVfT0on@Jj@4ohmZY0CoSVZT0on@K:H4oiAaZ0CoWWZ[0_nWPJ`3okj/
a`Co]ZC71?nWUL<3oib5^PCoUW^c0_nHNJl3oj7Jo004olGQk?nSMJ3oXgFPoj=eX0?oWg>P1?nAI9X3
ohELVP?oP5ZK0_n0G9l2oh5MX0?oRfBP1?nDJj001?nGKIooW7R[oiahZonLN:/4oiiiZ@CoXGRV1?nR
N:@4oj9fXP04oj5eXOo6`]Koa/;FolK2ePGo_JK200Co]YNgojQjXOnXNZ7oZ7ZQ1?nQMJ42oiacY0?o
]Xj/1?n^Qj`2ojV6[`?o^IJd1?n^S;42ojR8/`;o^j;01OnbV[h01?n]V<7o^J_;okV[boniZl/5ok6S
b@04ojbQbonf]=Oo][CGokJde`Co/:oG00?o]<;Tok6khOna^n400ona^n42ojjhh003ojo3jOl0003o
[L3W00Co[L3W00?o[;kWojc5k?n/aN`00_n/aN`2oj_3j`;oZ/G]1OnZ`n`2oj[2j`;oZL;/5?ooool0
0ol0003oooooooooo`0Gooooo`009Oooool2o`0000cooooo0_n1/oD2oiFkl@CoTLKi00?oS=7nojCG
n_nTeoX00_nTeoX4okGEl003okKNm?nnd>So_]3X00;o_]3X00?o_m?Yokg1gOnm`Md00onm`Md01?nl
_mco/ZW?ok:YconbZLl3ojnSb`Go[Ic600CoZYK1oij9__nNRKkoWXVn0onLQ;T3oiYo]0CoVW^`0onI
N:`3oiQeZ@;o00000_nGLZL3oiI`YP04oi=_Y_nDKjKoU6nVoiA_YP?oTVfT1?n@Jj@3ohmZY0CoSVZT
1?n@K:H3oiAaZ0CoWWZ[00?oYh6/okj/aonn[<L00_nn[<L3okJTa`;oS6BO0on?IYl4oi9YW`CoVg2P
00?o;[?Roj7Jo?nQf_`01OnSMJ02oimcX003oie^W?nAI9[oTFBJ00;oTFBJ0on5G9X3oh1JV`CoP5bO
0on;I:02oiA[X0;oUgBZ1?nLN:/4oiiiZ@CoXGRV1?nRN:@3oj9fXP;ob?7]1?o6`]H2okfV`P?o/XFU
0onXNZ44oj5eX@03oiacY?nfSZco]Xj/00;o]Xj/1?n^Qj`00onYQZoo^IJdokVF]002okVF]0Co[Xba
00?oZ8Rcok^R`?nkX/000_nkX/03ok:J_P03ol:le?niZl_o^J_;00?o^J_;0onaXlT2okZmg0Co][CG
00?o/:oGokC2i?nd`^@00_nd`^@3ok6kh@03ok39k?n_`nWo[l?Y00;o[l?Y00?o0000ojg0ion]`>L0
0_n/b>h4ojc5k003ojW7konZaNgoZ/G]00?oZ/G]0_nZ`n`2ojW3k@GoZL;/4oooool00ol0003ooooo
ooooo`0Gooooo`009?ooool00ol0003oooooooooo`0=ooooo`CoUK_a0_nAa_T4ojK;l`03ojCGn_ne
eO3o]MG`00;o]MG`0_nmc>H3okk@j0?o_/?N0onm`Md00one[m;o/ZW?ok:Yc`02ok:Yc`Co[j?;0_n]
W<H2oj6@`PCoWXVn0onLQ;T3oiYo]0CoVW^`0onIN:`3o`000004oiQeZOnGLZOoUg:WoiMbY`;oUW2V
00?oU76XoiA_Y_nDKjH00_nDKjH4oi9]Y0?oT6^T0on?JZ@4ohiZY0CoT6bV1?nDLJP2oiijZ`03okRY
b_nn[<Oo_Zc700Co_Zc700Co]ZC7ohaTWon<I9ooS6BO0on?IYl4oi9YW`CoVg2P0onSMIl5oj=eX003
oimcX?nMKYcoWFjL00CoTFBJ0on5G9X3oh1JV`CoP5bO0on:J:H4oiMdZPCoW7R[1?nNNJT5oj5hYP?o
XWRT00?oXWJRolSakOo8lNd00oo8lNd2olK2eP03ojYmXonVO:Ko/XFU00?o/XFU0onXNZ44oj5eX@Go
]Xj/1?n^Qj`5okVF]0Co[Xba1OnkX/02ok:J_P?o`[cD1?niZl/00onaXlWo^[gLokZmg003okZmg0;o
][CG0_nhcn`4okC2i003ok6khOn`bNco/<W/00;o/<W/0_n_`nT2oj_=l@03o`000?n/b>ko[<S^00;o
[<S^00?o[<G/ojW7konYanl00_nYanl2oj[5k@?oZ<G^1?nY`nd2ojW2k0;oZ<7/5?ooool00ol0003o
ooooooooo`0Fooooo`009?ooool00ol0003oooooooooo`0>ooooo`;oUK_a1?nV_n`2ojK;l`?o]<_[
00?o]MG`okg<i_nmc>H00onmc>H00onnd>So_/?Nokk3gP03okk3gP04okg1gOne[m;o]JoBokF_dPCo
/ZW?0_n_Xl/00onUU/KoXI32oj6@`P03oj6@`P?oWXVn0onLQ;T3oiYo]0CoVW^`0ol000001?nIN:co
V7FYoiQeZOnHMJT2oiMbY`04oiAdZonDLJSoU76XoiAaZ0CoU6nV1?nBKJ@3oi1[Y0CoSfZT0on>JZ@4
oi1/YPCoU76X00CoWWZ[okRYb_nhZL[o^:W:1?nn[<L5ohaTW`?oSfJO1?nBJIl4oi]`X0CoXgFO0onS
MJ001?nTMYooWFjLoie^W?nMKY`4oi5TVPCoQEbJ0on0FY/3oh1LW`?oRVRV1OnGM:X4oiahZ`?oWWVY
1OnQN:H2oj9hY0?oI]2P0_o8lNd00on]Oj;oZWfSojYmX`02ojYmX`Go/XFU1?nXNZ43oj5eX@Go]Xj/
1?n^Qj`00oo8[Koo^IJdokVF]003okVF]0;o[Xba0_o3/LP4ok^R`003ok:J__o2_=Co`[cD00;o`[cD
0oniZl/2oko?i`Co^[gL00?o/^3gokS?k?nhcn`00onhcn`2okC2i0?o[]7b0_n`bN`2ojWCmP?oZlga
00Co0000oj_=lOn/b>ko[<S^0onYbO42ojW7k`;oYlK`1OnXaNh2ojW3k@;oYl;]1?nX`N`Dooooo`03
o`000?oooooooooo01Gooooo000Tooooo`?o00003oooool4ojJok0;o/l;U0ondbn/3okc8h`?o_LcV
1_nn`mh00onh]=Go]JoBokF_dP02okF_dP?o/ZW?00?oZIg;ojFFa_nUU/H00_nUU/H4oj6@`PCoWXVn
0onLQ;T3oiYo]0?o00000_nIN:`2oi9h/P?oTgJ_0onDM:/4oiAaZ0?oU6nV1?nBKJ@3oi1[Y0CoSfZT
1?n>JZ@3oi1/YP?oU76X00?o[J3;okRYb_nhZLX00_nhZLX3okj/a`OoS6BO0on?IYl3oi9YW`CoVg2P
1?nSMIl2oj=eX0;oY7JO1?nMKY`3oi5TVPCoQEbJ0on0FY/4oh1LW`?oRVRV1?nGM:X4oiahZ`CoWWVY
1?nQN:H01?nRN:CoSV2Gok64Y?naQ:@4ojeoXPCoZWfS1OnbQJD4ojQjX@;oXGFQ0_nmVK85okJ>[0;o
[XN/0_o8[Kl5okVF]004ojj</Oo3/LSo`k78ol>ab0?o^j;00_o<h>L5ol:le003okV[bonocnOo_loW
00;o_loW00?o^[gLok;Pmonbh?L00_nbh?L2okS?k0;oYm_j1?n^dO800onQeo_oZM?fojWCmP03ojWC
mP;oZlga00?oY/cdo`000?nYbO400onYbO400onUb?7oYlK`ojO6l003ojO6l0;oZ<G^0_nW`nh5ojO2
k@;oZ<7/0_nW`>`Booooo`;o00002Oooool4o`000003oa0@4?oooooooooo00Oooooo000Tooooo`03
o`000?oooooooooo013ooooo00?oY[o/ok?2iOnc`^D00onc`^D00ondbn_o_<SSokc8h`03okc8h`03
okg<i_nn`mko_/?N00?o_/?N1?nh]=D4okF_dP04ok:YconYWL_oZIg;ojVMb`?oYIK61?nQT<84oij9
_P?oW8Bi0ol00002oiYk/003oi1i]_nBN;;oTWRb00;oTWRb0onCMZl4oiAdZ`?oU76X1?nDKjH3oi9]
Y0?oT6^T1?n?JZ@4ohiZY0?oT6bV00?oU76XojfPbon]X</00_n]X</4okRYbP03okj/aon<IJ7oS6BO
00KoS6BO0on?IYl3oi9YW`CoVg2P1?nSMIl01?nSMJ3oY7JOojAfWonTMYl4oie^W0?oTFBJ1?n5G9X3
oh1JV`CoP5bO0on:J:H4oiMdZPCoW7R[1?nNNJT3oj5hYP03ohiNU?n>H9Oo/HBT00;o/HBT1On]Oj82
ojYmX`;oaZ2b1?nbQJD4ojQjX@04oj5eXOnmVK;o_IVbokfI/PGo]Xj/00Co[XN/olR]_oo8[Koob:fo
1?niU[@00oo?emoo`k78ol>ab003ol>ab003ok^R`?o<h>Ooc>3W00;oc>3W0_o2_=@3ok?Xm`;o_loW
0onBj_L2ok;Pm`CoTMon0onWfoX00on^dO;oXMOkoj7Gn`02oj7Gn`;oZM?f0_nQc_L4ojK<m003o`00
0?nYbO7oYLSa00?oYLSa0_nWa_02ojK3kPGoYl?^0_nW`^d2ojK0k0GoYl3/4oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo01;ooooo0onc`^D2ok_4h@Co_<SS
0_nna=h3okk3gP;o^kWH1Onh]=D2okF_dP03ojfTc_nYWL_oZIg;00;oZIg;0onUU/H5oj6@`P;oWXVn
00CoThBoo`000?l0003o00000on@O;T3oi1i]PCoTWRb0onCMZl4oiAdZ`?oU76X1?nDKjH3oi9]Y0Co
T6^T0on?JZ@4ohiZY0;oT6bV00?oY9O7ojfPbon]X</00on]X</3okRYbP?oS6FQ1on<I9l3ohmVW`Co
TVVO0onKL:04oj=eW`CoY7JO1?nMKY`4oi5TVP?oQEbJ0on0FY/4oh1LW`?oRVRV1?nGM:X4oiahZ`Co
WWVY00CoXGRVohiNU?n>GYCoSUjD1?naQ:@5ojeoXP04ojYmXoo6X;;oaZ2bolJP/PCo/XFU1?nXNZ44
okfI/PCo]Xj/00?ohO3IolR]_oo8[Kl00oo8[Kl2okVF]0?ocmOO0oo3/LP3ohO[cP;oc>3W0omLeMD2
ok?Xm`?o>l360_nBj_L3ofOCm`;oTMon0_n1dol5oi?IoP;oXMOk0_nKc_T4oj7>m`;oY/cd00CoXlSc
o`000?nSb??oXlSc0_nUb?42ojC2k`CoY/?^0_nW`nh7ojK0k0;oYl3/0_nV_n/Dooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02Oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0
4oooool00onc`^Go^lCQok_4h@02ok_4h@03okc8honna=ko_/CN00?o_/CN00?o_/?Nok^if?nk^MP0
0_nk^MP3okRde@03ok6[don]Y<ko[JC>00;o[JC>0onYWL/4ojFFaP;oXI320_nGRL<3o`000004oi>4
_onAOkcoTGnloi5o_0?oT7bi0on@NKH3oi9h/P?oTgJ_1?nDM:/3oiAaZ0CoU6nV1?nBKJ@3oi1[Y0?o
SfZT0_n>JZ@2oij>``CoY9O71On]X</00onhZL[oS6NSohaUX@02ohaUX@OoS6BO0on?IYl4oi9YW`Co
Vg2P0onSMIl4ojAfW`CoWFjL1?nAI9X3ohELVP?oP5ZK1?n0G9l3ohYXYPGoUgBZ0onLN:/2oiiiZ@;o
SUfC1?n>GY@4ok64Y0Go[GnR00CoZWfSolJP/_o6X;;oaZ2b1OnbQJD3ojQjX@03ol^eaOnmVK;o_IVb
00;o_IVb0_nfSZ`3on7`f@Cob:fo00?o^IJdoloGgoo?eml00_o?eml01?o3/LSoQn_>ohO[c_n7jlh3
ohRLh@?oHjgi1?lg[_42od:nk0;oNK_k1?mbaol4oh7Co`;oTmWn0onCb_X4oi_>n@;oXLkg0onOao@2
oj?8l`03o`000?nS`NooY<;_00CoY<;_0_nV`nh2ojFok0KoY/3/1onV_n/Cooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02Oooool000Wooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool05Oooool3ok_4h@?o_lCN0onna=h0
0onm_]_o^kWHok^if004ok^if004okRdeOnaZm?o/J_Cok6[d`?o[JC>1?nYWL/2ojFFaP03oi^?a_nG
RL?oUhW300;o00001?nCQ;l3oi5o_0?oT7bi0on@NKH4oi9h/P?oTgJ_0onDM:/3oiAaZ0CoU6nV1?nB
KJ@3oi1[Y0;oSfZT00?oVXW0oij>`onNS/<00onNS/<3ojBGa`Co[J3;0on<Ij<3ohaUX@OoS6BO0on?
IYl4oi9YW`CoVg2P0_nSMIl00onXO:CoY7JOojAfW`02ojAfW`CoWFjL1?nAI9X3ohELVP?oP5ZK1?n0
G9l3ohYXYPGoUgBZ0_nLN:/2ohmMT`?oSUfC0on>GY@2ok:7Y`?o/HBT1On]Oj84olJP/PGo/XFU0_nX
NZ42ol^ea@Co_IVb00?o]Xj/on7`fOoQl=T00ooQl=T2olR]_`?oOnO=0_o?eml4oj2Db0;oR9cQ0_nU
ULD4oiRLe`CoQZW/1?mi^o/2og;7o`;oT;Sb1On@`oP2oi?:nP;oV[g`1?nL`o<2oio7m0;oXKk^0onS
`Nl01?l0003oXl7_ojC2konT`^l2ojBnk0GoYKo/0_nV`>`2ojJnj`WoY[o[4oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP05ooooo`?o00005_ooool00onka>7o_lCNoko4gP03oko4gP04okk4
g_nm_]_o_KkKokfnf`Co^kWH00?o];?Gok6[donaZm<00_naZm<4ojfTcP;oZIg;00?oWiK:oi^?a_nK
SlH00ol00003oiN9``?oThBo0onAOk`3oi1l^@?oT7Vf1?nBN;83oi=f[`?oU7B[1?nDLJP3oiA_YPCo
TVfT0_n@Jj@00onHQ[ooVXW0oiZ9`002oiZ9`0CoWXk31?nTUlL00on]X<_oSFVUoheYY@03ohaWX`?o
S6FQ1on<I9l3ohmVW`CoTVVO1?nKL:001?nSMIooZ7bTojQlY?nXO:@3ojAfW`CoWFjL1?nAI9X3ohEL
VP?oP5ZK1On0G9l3ohYXYP?oUgBZ00?oTEnDohmMTon?GI<00_n?GI<3ohiMT`;oSUjD0onbQjL4ok64
Y0?o[GnR0_oYn/<3olJP/PGo/XFU00CoZ7ZQol^eaOo;]LGobkG51?nmVK801?nNR;co1P00on7`fOoQ
l=T4oj:4/`03ohn6aOn`Tk[o/9>j00;o/9>j1?nPU<P4ojFEa@GoV9cG0_n6ZN`00onQY=SoV:kVoiR^
iP02oiR^iPGoT;Sb0_n@`oP2oibejPGoV[g`0_nL`o<2oj6kj`CoXKk^0_nS`Nl00onT_>[o0000ojBl
jP04ojBnk0;oYKo/0_nV_NX5ojJnj`;oY[o[0_nV_^/5ojJoja7ooooo0ol00007ooooo`03o`000?oo
oooooooo00Wooooo0009ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`04ooooo`03o`000?oooooooooo01Sooooo0onoa=h2okk4gPCo_KkK00?o^kWHokBceond/mL00_nd
/mL4ok6[d`;o[JC>00?oY9g>oinFb_nOU/X00ol00002oi^?aPCoUhW31?nCQ;l3oi5o_0?oT7bi0on@
NKH3oi9h/P?oTgJ_1?nDM:/3oiAaZ0?oU6nV0_nBKJ@2oiJ5_`CoV8Jo0onJRL04oij>``?oY9O700Co
T6nYoheYYOn=JJGoSFVU0on<Ij<3ohaUX@OoS6BO1?n?IYl3oi9YW`?oVg2P00?oXWbYojQlY?nXO:@0
0_nXO:@4ojAfW`?oWFjL1?nAI9X4ohELVP?oP5ZK1?n0G9l3ohYXYP04oiMdZ_nAGiCoTEnDoi5OU0Co
SefC0on>GI<00on>GYCo/XNWok:7Y`02ok:7Y`Co/HBT0_n]Oj83onWj``CoaZ2b0onbQJD00oo3nN_o
bkG5ol^ea@03ol^ea@;o_IVb00?o[HR^ok29[?n`RJ`00_n`RJ`4oj:4/`Go/9>j0onPU<P2ok2G_0Co
YIG50onHW=L00on[XLgoXJCHoj6Tf002oj6Tf0CoV:kV0_n@^?83oin/h@CoW;GZ0_nJ_O02oj6fi`Go
XK_[0_nQ_^h2ojBij0;oY;cZ00?o0000ojBlj_nT_>X00_nT_^`2ojJlj@CoY[gZ0_nV_^/2ojJmjPGo
Y[k[0_nV_n/2ojNoj`kooooo1?l000000ooooooo0000ooooo`06ooooo`03o`000?oooooooooo00Wo
oooo0009ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01Wooooo00?o_lCNokk4g_nna=h00_nna=h2okfnf`?o^;_L1?nd/mL2ok6[d`03
ojRUdonTWLkoY9g>00?o00000_nOU/X3oi^?aPCoUhW31?nCQ;l3oi5o_0?oT7bi0on@NKH3oi9h/P?o
TgJ_1?nDM:/3oiAaZ0;oU6nV00?oU8G1oiJ5_onFQKl00onFQKl3oiR6_`?oVXW01OnNS/<00onTUlOo
T6nYoi1_Z@03oheYY@CoS6NS0on<IJ47ohaTW`?oSfJO0onBJIl01?nKL:3oXWbYoj9lZOnRO:T4ojQl
Y0CoY7JO0onMKY`4oi5TVPCoQEbJ0on0FY/4oh1LW`;oRVRV0_nCHYH3oi5OU0CoSefC0on>GI<5ok:7
Y`Co/HBT00?o[GnRonWj`ooYn/<00_oYn/<4olJP/P03ok:5YOo3nN_o`oW[00;o`oW[1?o;]LD00onm
VK;o[HR^ojf8[P05ok29[0;oXXBc0_njV;D5ok2C^P04oj2Db?n`Ukco/9Nlok2G_0CoYIG500?oV9cG
oj^QcOn[XLd00_n[XLd4oj6Tf0;oV:kV0_nUYmL5oin/h@;oW;GZ0_nU/N44oj6fi`;oXK_[0_nU]^D5
ojBij0;oY;cZ00?o0000ojJjionV_>T01?nV_>T2ojJmjP;oYkcY1?nV_NX2ojJnj`;oYkkZ1OnW_n/:
ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`03oeEEEOmVIVKo000000_ooooo0009oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo0_l0
000Kooooo`?o_/CN00?o^/?QokRkg?nh^m`01?nh^m`2okBce`03ojb^fOnXYM?oZ:GC00?o00000_nT
WLh4oinFbP?oVho60_nGRL<00on@S<coRhS;oh^8b`02oh^8b`?oR8G:0on5Q<X3ohF3b@?oQhC90on9
Q<L4ohf5a@?oTHG31?nDQL44oiJ5_`?oV8Jo1?nJRL02oij>``;oQV>R0on5HJ43ohAPX@CoS6NS0on<
IJ47ohaTW`?oSfJO0_nBJIl00onHMZ_oXWbYoj9lZ@02oj9lZ@CoZ7bT1?nTMYl4oie^W0?oTFBJ1?n5
G9X3oh1JV`;oP5bO0_nDI9L4oi=RUP?oTEnD1?n?GI<2ohiMT`03ojj8[?nbQjOo/XNW00?o/XNW1?na
Q:@4ok26Z004ok62X_oYn/?oaZ2bolJP/PCoXWJR00GoUG6XokV>ZOo;]LGobkG5okV>Z@03ojf8[P;o
_YJ^1?n`RJ`01?nRQ;?o^YReokZH]OnjV;D4ok2C^P03oknQ^on`Ukco/9Nl00;o/9Nl0onUULD00onf
XlGoZj7=oj^Qc@03oj^Qc@;oXJCH0_n]YLl5ojFWe`;oWjcQ0_nY[]/5ojFah@;oXKKW00?oYk?QojFf
iOnU]^D00onU]^D2ojBij0;oYkSU0onV^^L00ol0003oY[[WojJlj@02ojJlj@03ojNkj?nW_>WoYkcY
00?oYkcY0_nV_NX2ojNnj@CoYkkZ0_nW_n/2ojRoj`Kooooo1?l00008ooooo`03o`000?oooooooooo
017ooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Gooooo00?o0000ooooooooool06oooool01?nna=ko^/?Qok[3hOnj`n44okRkg003ojnggon/
[]Wo[:kI00?o00000onXYM<3ojBMcP;oWiK:00CoUiKAoi>Ac_nCTLkoTi7>1?n@S<`4oh^8b`?oR8G:
0on5Q<X3ohF3b@?oQhC90on9Q<L4ohf5a@?oTHG30onDQL44oiJ5_`CoV8Jo0_nJRL02ohUVY0?oQV>R
0on5HJ43ohAPX@?oQ66R00CoS6NSohaUXOn<IJ7oS6FQ1on<I9l2ohmVW`04oi=aZOnHMZ_oV7J[oiQf
Z`CoXWbY1?nXO:@4ojAfW`CoWFjL0onAI9X4ohELVP;oP5ZK0_nAHYL3oiATU`CoTf:F0onAGi@4ohmM
T`04ohiMTon^R:co[XR/ojj8[0Go/XNW0onaQ:@3ok26Z003olFJZonaPZ;o/H:R00;o/H:R1?nRMZ86
okV>Z@04ojf8[_nnUZko_YJ^okjF[PCo/8V/1?njV;D3ok2C^P;o_j6k1On`Uk`01?nUULGo]Z?5okJS
aOnfXlD3oj^Qc@03okFXc?n]YLoo[JG?00?o[JG?0onUYmL00on^[MKoZJkKojV^f`03ojV^f`?oYK7Q
00?oZ[7MojNchOnW/n400_nW/n43ojFfi@03ojRghonW^>GoYkSU00?oYkSU0_nV^^L00ol0003oY[[W
ojJlj@04ojNkj0?oYkcY00?oZ;gYojNnjOnW_^T00onW_^T2ojNnjP;oZ;oZ1?nX_n/2ooooo`?o0000
3?ooool00ol0003oooooooooo`0Aooooo`008_ooool00ol0003oooooooooo`0Mooooo`Co^/?Q00?o
^;_Lojnggon_]ml00ol00003ojb^f@;oZ:GC00CoWZCJoi^MeOnKWMGoVigE1?nGU]43oi>AcP?oT8c<
1?n;R</3ohR5bP?oQHC:0on5PlT3ohN4b@?oRHC71?n=QLD3oi65``?oU8G11OnFQKl3oiR6_`04oiZ9
`?n9IZCoRFJTohUVY0?oQV>R0on5HJ43ohAPX@CoQ66R0on5Hj<3ohUWY@CoSfbW0onCLJT4oiQfZ`?o
XWbY1?nXO:@4ojAfW`CoWFjL0onAI9X2ohELVP03ogOEo_n=GYGoSEjE00;oTF:G00CoW8:fohMe^?n7
MKSoQgFh1?nCHYH3oi5OU0?oSefC00?oWh:cojj8[?n^R:`00_n^R:`5ok:7Y`;o/HBT0on`QZP3olFJ
Z`?o/H:R1?nRMZ86okV>Z@04ojf8[_nnUZko_YJ^okjF[PCo/8V/00?oajNhokZH]OnjV;D00_njV;D0
0on`Tk[o_j6koknQ^`02oknQ^`?o/9Nl00?o_j[5okJSaOnfXlD00onfXlD01?n[XLgo]JS<okFXc?ne
Z<`5ojfUc`04ojFWeon^[MKo[ZgFojj]ePCoZJkK00?oYK7QojZagOnZ/Md00_nZ/Md4ojNch@04ojFf
iOnX]n?oZ;OSojRgh`CoYkSU0_nV^^L00onX^^Ko0000ojRjiP04ojNkj003ojNljOnX_NWoZ;gY00;o
Z;gY0onW_^T00onX_^WoZ;oZojRojP03ojRojP;oZ;o[0_nX`>/00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo01kooooo0_nj`n42ok72iP;o0000
0on_]ml2ojb^f@03oj6/gonNY=[oWZCJ00;oWZCJ0onKWMD3oiNFd@?oTi7>0on@S<`4oh^8b`?oR8G:
0on5Q<X3ohF3b@?oQhC90on9Q<L4ohf5a@?oTHG31?nDQL44oiJ5_`;oV8Jo0_n<JjL3ohUVY0CoQV>R
0on5HJ42ohAPX@CoQ66R0on5Hj<3ohUWY@CoSfbW1?nCLJT3oiQfZ`CoXWbY0onXO:@4ojAfW`CoWFjL
0_nAI9X2oiSRo@CoSEjE00?oTF:Goib2]_nLP[H00on7MKP4oh5`]`?oQgBg00CoSefCoin2/onOP[?o
Wh:c1?n^R:`5ok:7Y`03ok64Y?nhRjKo^8^V00;o/8JX0oo5VZ/4ok62XP;oXWJR0_o2VZh5okV>Z@Co
_YJ^0on`RJ`2olNW^0Co^YRe1OnoXK/2ok2G_0?o_j[51?nfXlD4okFXc0Co[JG?00?o][3Dojj]e_n^
[MH00on^[MH2ojV^f`;o[k;J1?nZ/Md2ojNch@;oZkKQ1OnX]n<2ojNhi@;oZKWU0onX^^H01?l0003o
Z;[VojNkj?nW^nP2ojVlj0CoZ;gY00?oYkkYojRnjOnX_^T00_nX_^T2ojRojP;oZ<3Z1OnX`>/@oooo
o`03o`000?oooooooooo013ooooo000Rooooo`;o00008?ooool3o`0000;o/L;V0_n_]ml00onS]NKo
XJcOoj6/g`02oj6/g`?oWZCJ0onKWMD4oiNFd@?oTi7>0on@S<`4oh^8b`?oR8G:0on5Q<X3ohF3b@?o
QhC90on9Q<L4ohf5a@?oTHG30_nDQL43oiIi/0CoTG6[0on<JjL3ohUVY0?oQV>R0on5HJ43ohAPX@?o
Q66R0on5Hj<4ohUWY@?oSfbW1?nCLJT3oiQfZ`CoXWbY1?nXO:@3ojAfW`;oWFjL1?mYfl<00onHh_go
SEbDoheNU@02oheNU@03ojb;/_nLP[KoW8:f00;oW8:f0on7MKP3oh5`]`?oQgBg1OnOP[<3ojj8[0Go
/XNW0onhRjH00on`QZSoaIZ[olFJZ`02olFJZ`Co/H:R00CoXWJRol:J[_o2VZko`YZ^1OniSZT5okjF
[P04ok29[?o7YkSoajNholNW^0Co^YRe00?oc;K4oknQ^onoXK/00_noXK/00on`Ukco_j[5oknZa@02
oknZa@?o]Z?50_o1]<d4okFXc003ojfUconf/=Co][3D00;o][3D0on^[MH00onc]M[o[k;JojnbfP03
ojnbfP;oZ[7M0_n^]ml4oj^fh@;oZ;OS0_n[^N@5ojVii@;oZ;[V00?oZKcWo`000?nY_>P01?nY_>P2
ojRmj@;oZKkY0onX_^T00onY`>[oZ<3ZojS0jP03ojS0jP;oZ<3[0_nY`>/@ooooo`03o`000?oooooo
oooo013ooooo000Rooooo`03o`000?oooooooooo01cooooo0ol000000ooooooo/L;Vok72iP02ojBo
k@CoXkGV1?nQ[=l3oijTfP?oVigE0_nGU]401?n>X^;oS:3QohbPhOn<X>44ohROh`CoPj3V0omkY>d4
ofjZm@?oEk7k0_l][NX00onaY<_oZiW4oj^Ia002oj^Ia0?oY8fm0onMPkH3oiIi/0CoTG6[0on<JjL3
ohUVY0?oQV>R0on5HJ43ohAPX@?oQ66R1?n5Hj<3ohUWY@?oSfbW1?nCLJT3oiQfZ`CoXWbY1?nXO:@2
ojAfW`;oSefC1?n=G9<3oheLU003oheNUOn/Rk;o[8^b00;o[8^b0onLP[H3ohMe^0CoPG2g0_n7M;L5
oin2/`?o[XR/1?nbQjL4okR;YPGoaIZ[1?naPZ801?nRMZ;o`YZ^ol:J[_o2VZh4okV>Z@03omVk^onn
UZko_YJ^00?o_YJ^00?o/8V/olNW^?o7YkP00_o7YkP2okZH]@;oc;K41?noXK/6oknZa@04okJSaOo1
]<go`KC=ol6dc@?o]JS<0_nk^ML4okJ`e003ojj]e_nc]M[o/kGJ00;o/kGJ0on_/]X00onb^]oo[[OO
ojjgg`03ojjgg`;oZkKQ0_n]^^<4oj^ii0;oZKWU0_n[_>H3ojVli`04o`000?nY_>OoZKcXojVlj0Oo
ZKkY00CoZ;kYojW0j_nY`>[oZL3Z0onX`>X2ojW1j`CoZL3[3oooool00ol0003oooooooooo`0@oooo
o`008_ooool00ol0003oooooooooo`0Iooooo`?o00001_ooool3ojBok@CoXkGV0_nQ[=l01?nD[nWo
Tj[Voi>Zi_nCZ^H4oi6Vi0?oSZ;R0on<X>44ohROh`CoPj3V0omkY>d2ofjZm@03obbfaoo3h^ko]ZkB
00Go/JC;0on[VL@4ojB=_@?oWH>f0onFNK03oi5aZ`?oS6^W0on9IZ@3ohISXP?oQF6Q0on4H:43ohAQ
XPCoQF>S0on9IjD4ohm/Y`?oTg6Y0onHMZ/4oj9lZ@CoZ7bT00CoY7JOohmMTon?GI?oSefC1?n=G9<3
oheLU0Go[8^b0onLP[H3ohMe^0CoPG2g0on7M;L4oin2/`Co[XR/0_nbQjL00onjT:_o^8^VokR;YP02
okR;YP03ongh]_o5VZ_oaIZ[00;oaIZ[1?naPZ85ol:J[P;o^HjY0ooI^k/3okjF[P03omK;coo7YkSo
ajNh00?oajNh00Co^YReolbfa?o<]/Coc;K40onoXK/2ol^oc`Co_j[500?oalSJol6dcOo1]<d00oo1
]<d00oneZ<co^kWGok^ie`02ok^ie`;o][3D0_ni_Md4ok>efP03ojnbf_nb^]oo/[[O00;o/[[O0on^
]ml00on__NCo[K[Sojfjh`03ojfjh`;oZkWT0_n/_NH4oj^liP;oZKcW00?oZ[kXo`000?nY_^T01_nY
_^T7ojW0jP03ojS0j_nY`N_oZL7[00;oZL7[0_nY`>/00onY`N_oooooooooo`0=ooooo`03o`000?oo
oooooooo013ooooo000Rooooo`03o`000?oooooooooo01Kooooo0ol0000:ooooo`?oY;o]0_nS]NH2
oiBek@?oU:oY0onCZ^H4oi6Vi0?oSZ;R0on<X>44ohROh`;oPj3V0om]boh2oeG:l@03ol3Rl?o3h^ko
]ZkB00;o]ZkB1?naY</4oj^Ia0?oY8fm0onMPkH3oiIi/0?oTG6[0on<JjL3ohUVY0?oQV>R0on5HJ43
ohAPX@CoQ66R0on5Hj<3ohUWY@CoSfbW0onCLJT4oiQfZ`?oXWbY0_nXO:@3oi5PU0?oSefC1?n=G9<2
oheLU0;o[hba1?n/Rk84oib2]P?oQgFh0on1L;L3ohMd]`CoWh:c1?n^R:`00onbQjOo^Y2[okZ@Z`03
okR;YP;okORf1Oo5VZ/3ok62XP03omO2a_o2VZko`YZ^00;o`YZ^00?o^HjYomVk^ooI^k/00_oI^k/2
okjF[P?oe/_?1?o7YkP5olbfa003oknQ^oo;_loobko?00;obko?00?o_j[5olO8f_o7b=X00_o7b=X3
ol6dc@03ol;:hOnk^MOo^kWG00;o^kWG00?o^L[WokVmgOni_Md00oni_Md2ok>efP;o/koS1?nb^]l0
0on^]moo[kgTojnmi002ojnmi0?o[K[S00?o[KoWojbmi_n/_NH00on/_NH2oj^liP;oZkoX0onZ_^P0
0ol0003oZKkYojVnj@02oj[0jPOoZL3Z2onY`N/>ooooo`03o`000?oooooooooo013ooooo000Roooo
o`;o00005?ooool3o`0000kooooo0onD^_44oiBek@?oU:oY0onCZ^H2oi6Vi0;oQ;Of1?n1^_P4ogjn
n`?oN<Cn0_m]boh3ol3Rl003okVgf?nf[];o]ZkB00;o]ZkB1OnaY</2oj^Ia004oiV6_OnBOKWoTWfi
oi9m^@?oS7Fe0on6Kk83oh9[/0?oS6^W0on9IZ@4ohISXP;oQF6Q0on4H:44ohAQXP?oQF>S0on9IjD4
ohm/Y`CoTg6Y0onHMZ/2oj9lZ@?oTV>G0onAH9@3ohmMT`CoSEbC00CoSEbDojn</On_S;7o[hba1On/
Rk83oib2]P?oQgFh1?n1L;L2ohMd]`GoWh:c0_n^R:`00onjW;[o^Y2[okZ@Z`02okZ@Z`04okR;Y_o]
n;KokORfongh]PGoaIZ[0_naPZ82omO2aPCo`YZ^1OoI^k/00onnUZkoe/_?omK;c`02omK;c`?oajNh
0_oKkml3olbfa0;ob>W]0oo;_ll2okg^l`CoalSJ00?o`KC=ol;:hOo2b^400_o2b^400onk^MOo^L[W
okW:i`02okW:i`?o^KgM00?o]<SYok>ohonc_n<00onc_n<2ok:jg`;o/L;V1?n__N@00on]^^?o[KoW
ojfoi`02ojfoi`;o[;gV0_n/`NT5oj^oj0;oZ[kX00?oZ/7Zo`000?nZ`>X00onZ`>X2ojW0jPkoZL7[
0_nX`N/=ooooo`03o`000?oooooooooo013ooooo000Qooooo`;o00004_ooool3o`0001;ooooo0onD
^_42oiBek@;oRKKd0on7]_@3ohJfm@CoQ;Of1?n1^_P2ogjnn`;oBLSO0_nJk_D3okcPlP04ol3Rl?ni
]mSo^KOHokVgf0Co]ZkB0_naY</2oin?``?oVHJm1?nBOKT2ohae]@?oQVnb0on2Jk03ogiY/0?oO6Vb
1?n6Hj83ohEQX@?oQ62Q0on4HJ83ohESX`CoRFNU0on?K:L4oi=aZ@;oV7J[0om^Dj82og9IYP04oi9S
UonAH9CoTF2Doi5PU0?oSefC0on=G9<00on[R;7o[hbaojn</@02ojn</@Go[8^b0_nLP[H2ohYOVPCo
TfNL00?oVffLoh5`]on7M;L00_n7M;L4oin2/`03ojj8[?njW;[o^Ybj00Co^Y2[00Go^8^VokN<ZOng
S:WoZ8^fongh]P04olFJZ`04ok62X_oG`/Koel;6omO2aPCo`YZ^00CoTMj?omVk^ooI^k_ofK^k0_l0
0005omK;c`03olNW^?oKkmoofnoO00;ofnoO00?oc;K4olSYkOo8jNd00_o8jNd00oo;_loo_Nkcokg^
l`02okg^l`;oalSJ0_ndhOH3ol;:h@;o/=gg1?nib^L00oni_Mgo]<SYokC8j@02okC8j@;o/koS0_n_
b>`5ok72iP;o[kgT0_n]`^T3ojfoi`;o[<?[1?n/`NT2oj^oj0;oZl;[0onZ`NX01?l0003oZ/7Zoj[0
j_nZ`>X2ojW2j`_oZL7[1onX`N/<ooooo`03o`000?oooooooooo013ooooo0007ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03ooooo`03o`00
0?oooooooooo00oooooo0_l0000Fooooo`?oR[Oc1?n9]_@3ohNfm0?oQ[Ke0_n4]oH4ofg=oP;oG/ke
00CoKMg[oi[^mOnJk_GoV^ke0onlh?800onj_Mco^KOHokVgf003okVgf0;o]ZkB00?oYYW8oin?`onO
Sl<00_nOSl<3oiV6_@CoTWfi0on<MKD3ohI_/P;oPV^`0omnJK03ogaY/P?oNV^g00CoQV>RohEQXOn5
HJ7oQF6Q0on4H:43ohAQXPCoQF>S0on9IjD3ohm/Y`;oTg6Y00CoMebVog5FXomaEZ?oLEJS0om^Dj83
og9IYP?oTF2D0on?GI<01?n=G9?oZhRaoj^8/On[R;45ojn</@?o[8^b0_n7G9T4ohYOVP?oTfNL1?nK
KI`01?nLK9[oWh:coin2/oni]]H4okZL^PCo^Y2[0ongS:T01_nXRkKo^hnYolFJZoo5VZ_o^hnYojb6
[0Goel;60_o2VZh01?naS[7o`9N]oi7NSooI^k/2okB?/0;o/YNk0_oFbll00onbUk_oQ8oFojfJa002
om__g`?oQ9[P0_o8jNd3oaf4j@;o_Nkc0omCcNP4okCQmP03ol;:hOn`gOOo/=gg00;o/=gg0_nib^L2
oj_Bm0?o]<SY0_nYco<4ojo8k0;o/L;V0_n]a^d5ojg2j@03ojfoion/`n_o[<?[00;o[<?[0_n/`NT2
oj[3k0CoZl;[0_nZ`NX00onY`^co0000ojW2j`04ojW2j`;oZL7[0_nY`^`3ojW1j`;oZ<7/2?nX`N/=
ooooo`03o`000?oooooooooo00oooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`?o00006Oooool3
ohZgl`;oRKKd0on5_?P4oh32o0?oNLSo0_m]cOh2ogcMn`;oW^Sk1?nhfo801?nlh?;o^[gLokZmg?nj
_M`3okVgf003oj^Rc_nVVLSoYYW800;oYYW81?nOSl<3oiV6_@?oTWfi0on<MKD3ohI_/P?oPV^`0omn
JK02ogaY/PCoNV^g0omjM<03ohAPX@?oQ66R1?n5Hj<3ohUWY@;oSfbW0_mcEJ43ogMLYP;oLEJS0om^
Dj83og9IYP?oOVF[0_n?GI<00onFN;3oZhRaoj^8/@03oj^8/@Co[hba00?o[8^bohYNVOn7G9T00on7
G9T3ohYOVP?oTfNL0_nKKI`2ojG?mPCo^KKF1OnjW;X2okZ@Z`Co]hbY1_nkSjT00on/QZcoel;6omO2
aP02omO2aP04ol:J[_naS[7o`9N]ol2G[@Co]8n`00?obJ:`ok:G^onbUk/00_nbUk/5ojfJa0;oQ9[P
0_nWYM<4ogZOj@CoC:;f00?o<ZGbo`bKc_mhfoX00_mhfoX2ok3Mm`?oSmKo1?n[d_@00ondb>WoZLoc
ojW?l`02ojW?l`;o[lS/0_nXb_44ojg6k@;o[L;Y0_n[a^d4ojc3j`03ojW5kOnZ`ncoZ/?/00?oZ/?/
0_n[`^/2ojW3k0?oZL;/00?o0000ojW2jonY`^/01onY`^`00onY`N_oZ<7/ojS1k002ojS1k0SoZ<7[
3?ooool00ol0003oooooooooo`0?ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo
1Ol00005ooooo`;o00002_ooool3o`0001gooooo1On:]o@3ohFln0;oP<;l0on>cOd2ohOFo`;oXMkl
0onee_43okSKlP;o^/;P1?nj_M`01?ni]mSoZj;>oj^Rc_n[X/h3ojJIb0CoWho30onIQ[d4oi9m^@;o
S7Fe0on6Kk83oh9[/0?oOVV`0omlJK83ogY[]`?oNWC00omlQM43og>Sk`CoQF>S0_n9IjD2ogYJX0?o
LeFQ0_mWDjL00omgG:KoLEJSog5FX`03ofiCXP?oLUVV0omnIJ/3oiIh/0GoZhRa1?n_S;42ohYNV@Co
QebI0on:GiX2oi=WW0KoYLof0oni]]H5okZL^P03okZ@ZoneRJSo]hbY00?o]hbY1_nkSjT00on/QZco
aY^/olJK[002olJK[004ok6>/Oo0Ujgo`9N]ol2G[@?o]8n`0_o9X[03ok:G^`;o`j>h1?n]V/@5ojNU
d`;oNYoY00?oVjGLoh6WkOn1Ynd00_n1Ynd3ofF[n0CoGLGk0_n?e_l2og_9o`CoV=7l0_nYco<2oik;
m`GoZ<[a0_n]a^d2ojS8l@CoZlK]00?o[<?[ojW5kOnYaNd00_nYaNd2oj[3k0;oZLC^1OnY`n`2ojW2
k003o`000?nY`ncoZL;/00GoZL;/0onX`^`4ojS1k0OoZ<7[0_nX`>/;ooooo`03o`000?oooooooooo
00oooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00006
ooooo`03o`000?oooooooooo00Kooooo0ol0000Qooooo`;oR[Od0onE^o44oi;3n0;oS/gm0onRdoT0
0onQg_co]MKaokGFl@03okGFl@03okSKl_nj`^3o^/;P00;o^/;P0_nj_M`00on_Z]?oZj;>oj^RcP02
oj^RcPCoYYW80onOSl<3oiV6_@CoTWfi0on<MKD3ohI_/P;oPV^`0omnJK03ogaY/P?oNV^g1?mjM<03
ogb5d@?oLj?_00CoT72[ohASY?n4HjCoQ6>T0omjFZ03og=EX@?oIe>W0_maEZ<3ofiCXPCoLUVV0_mn
IJ/4oiIh/0CoZhRa1?n_S;42ohYNV@CoQebI0on:GiX00onCIicoYLofojG?mP06ojG?mP?o^KKF0_nj
W;X01?n?J:7o]HVXokF9Z?neRJP3okN<Z@;od:J^1OnkSjT5olJK[003ok6>/Oo0Ujgo`9N]00;o`9N]
00?o]8n`olVR/?o9X[000_o9X[001?nbUk_o`j>hol>S^?o3XkP3ojfJa0;o`Z_30onWYM<00onf[<oo
VjGLoi^Ug002oi^Ug0CoPJO]1?mUZoP3ofNko@CoNlWo0_nHdO`2oi38n`CoW/_g0_nXb_42oj;9m0Go
Z<Sa0_n[a^d3ojO6k`;oZLG]0_nWaNl4ojW4kP;oZL?/0_nX`nd3ojW3k004o`000?nY`ncoZL;/ojW2
k0GoZ<;/1_nX`N`4ojS1j`GoZ<3[2_ooool00ol0003oooooooooo`0?ooooo`001oooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003oooooooooo`03
ooooo`?o00009_ooool4oiFkl@;oT/?h0onRb?<2oj;Cn@?o//o_0_nee_43okS4h`?o^/;P00?o/[7G
ojnZdon_Z]<00_n_Z]<4oj^RcP;oYYW800CoVHg6oi:5`onBQL?oTXG30on<Ol04ohEj_`?oP7S10on6
Kk83oh9[/0;oOVV`0omlJK84ogY[]`?oNWC01?mlQM401?mcXnooT72[oi1`Zon@L:/2ohASY0?oNUZP
0omcEJ43ofMCY`03odMF__maEZ?oLEJS00?oKU>R0ombFJH3ogiUZ`?oUWR`1On[R;42ojn</@?oOfbc
1?n7G9T2ohYOVP?oYZoN0_nUcoH3oiE/X@CoU6VN0onEJYh4okF9Z0?o]hbY0_o@YZh5ok^?Z@GoaY^/
1Oo0Ujd00ondSk3obJ:`olVR/002olVR/0Go`j>h00?o[I[4ol:[`oo2Zl<00_o2Zl<01?nWYM?o]Zc?
okJ/conf[<l4oi^Ug0;oPJO]0_nHZn<3ohJ]kPGoO[Gg0on0__/4oi38n`;oW/_g0onIaoL3oj;9m0;o
Z<Sa0onTa_42ojO6k`;oYLG`1OnWaNl2ojW4kP;oYl?^1?nX`nd2ojW3k003ojS2kOl0003oZ<;/00Go
Z<;/1_nX`N`6ojS1j`CoZ<3[2_ooool00ol0003oooooooooo`0?ooooo`001oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oMgMgolc<c?l000001Oooool01?l0003oooooooooooooool3o`00
02[ooooo0_nE^o42oj>ok@?oX/Sc0_n`b>`3ok;?k`?o]lCT1?nha><01?nj`^3o/[7Gok:aeonb/ML4
ojnZd`;oZj;>00?oWYG:oiV=a_nISLH00_nISLH3oi:5``?oS7o00on5N[l3oh1h`@?oNWW60omdP]83
ogiY/0?oO6Vb0omjJkL4ogYd`0;oO8GA0_mjJ;82ofeM[`03oi1`Zon4HjCoQ6>T00CoNUZP0_mcEJ44
ofMCY`03odMF__maEZ?oKU>R00;oKU>R0ombFJH3ogiUZ`?oUWR`1On[R;400on_S;7oJeR[ogm//`02
ogm//`GoT8K50onV[mh2ofYK[`04ojB0[OnEK:7oUFbQoiE/X@CoU6VN0_nEJYh00on^QZ[o]HVXokF9
Z003okF9Z004okN<ZOo@YZkod:J^om2V[PCo^hnY00?odk6golJK[?o6Vj`00oo6Vj`5ol2G[@GobJ:`
1Oo3XkP4ol:[``03olfkb?nf[<oo]Zc?00?o]Zc?0_nKYM`2oj^^fPCoV:_S0on6[Nh2ogjem`;oSk7^
1?n;^?@4oi71m`;oVLOg0_nJ`O<5oio5l`;oY<Ka0_nSa?44ojG5l0;oYlG_0_nV`nh5ojO3kPCoZ<?]
0onX`^d00ol0003oZ<;/ojS2k005ojS1k0SoZ<7[1onX`>/9ooooo`03o`000?oooooooooo00oooooo
0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000005ooooo`Co0000
;_ooool4oj>ok@03oj;8lon`b>co/<S/00;o/<S/00?o//o_okO4i?nga>@00onga>@2okS4h`;o];OK
1?nb/ML2ojnZd`03ojBMconNUL[oWYG:00;oWYG:0onISLH3oi:5``?oS7o00on5N[l3oh1h`@CoNWW6
0_mdP]83ofNGj`?oO6Vb0omjJkL2ogYd`0?oQgNj0omjJ;83ofeM[`?oQ6>T0omjFZ03og=EX@?oIe>W
0_m7E[h3ofiCXP?oLUVV0omnIJ/4oiIh/0?oZhRa00CoGe2Yof]HZom[F:_oJeR[0omoK;<5oi26a@03
ojJ_g_mMG;WoJU^_00;oJU^_0onEK:44oiAYWP04oiEZW_n^QZ[o[XJZojj6ZPCo]HVX00?o]hbYom2V
[_o@YZh00_o@YZh2ok^?Z@?odk6g0oo6Vj`00ooF];Oo`9N]ol2G[@03ol2G[@CobJ:`0_oI][H3ol>S
^0;odKO10_o2Zl<3olfkb0?o]Zc?00?o_KWEoj^^f_n[[]X00on[[]X2oiR[h`03oj>^gonG[NKoUjgV
00;oUjgV1?n?/Nh4oh^hm0;oTL7g0_nG_?44oi[1l`;oWlGc0_nP`O05oj?4l@;oYLG`0_nU`nh4ojK3
kP;oYl?^0_nW`^d5ojS3k@;oZ<;]00?o0000ojS1k?nX`N`00onX`N`7ojS1j`[oZ<3[2Oooool00ol0
003oooooooooo`0?ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`00
0?ooool01?ooool2o`00037ooooo0_nS_nd3ojk1j0;o/<S/0_nf`nD4okO4i0;o]KcO1?nd]m/2ok:a
e`03ojRVe?nTWLooY9g?00;oY9g?0onNULX3oiV=aP?oTXG30on<Ol04ohEj_`?oP7S10omjNLH3ogB2
dP?oIiO[00Co^kkLojbUd?n/YM3o[:G@1?nIS<@3ohMg^P;oNVRb0om]GJl2of]N/P04ohASY?mjFZ3o
NUZPogYJX0?oLeFQ0omWDjL3odMF_P03ogif_om^Dj;oLUVV00;oLUVV0omnIJ/4oiIh/004oj^8/Om8
CKCoB4fdoem@Z@?oJeR[0omoK;<4oi26a@04oeiC[_mMG;WoGEbioeeL^@;oJU^_0omoIjd2oiAYWP;o
VWV]1?n^QZX4okF9Z0God:J^00?o^hnYom>a]ooC/KL00_oC/KL2olJK[0?oe[Bg0oo0Ujd2oln]^0;o
bJ:`0ooI][H2ol>S^0?odKO100?o`Z_3olfkb?o=^lP00_o=^lP00onf[<oo_KWEokfie@02okfie@;o
ZjkJ0_na]M`4oj>^g`CoUjgV0_n?/Nh2oiZaj0CoU[G]1?nG_?42oi[1l`;oWKg_1?nP`O02oj?4l@;o
Xl7^1OnU`nh2ojK3kP;oY/;]1?nW`^d2ojS3k@;oYl7/0onX`N`00ol0003oZ<7[ojS1k003ojS1k0;o
Z<7[3onX`>/8ooooo`03o`000?oooooooooo00oooooo000Rooooo`03o`000?oooooooooo02oooooo
0on^`NP2okC3i@Co]/?U00?o]lCTokFlgone_=l00one_=l2okBgf`03ojb^f?nXY]CoZ:KD00;oZ:KD
0onTWLl3oijEbPCoVHg60onBQL<3ohao`0?oQGZo0on0N<44ogYiaP?oM8;B00CoIiO[ok^ng?nk_]co
^kkL0on/YM03oiV<a0?oQgNj0_mjJ;83ofeM[`?oJejb0omjFZ03og=EX@CoIe>W00CoAeJnojV[f?mn
M[ooOWJo1?mbFJH3ogiUZ`;oUWR`0omSC:82odQ=]003oem@ZOm[F:_oJeR[00CoOfbc00GoT8K5ogYi
aOmNDjkoGU>^odM4ZP02oeeL^@;oJU^_0omoIjd4oiYi[@Co[XJZ1?neRJP00ooWd/7od:J^om2V[P02
om2V[PGodk6g00?oaY^/omJd]ooF];L00_oF];L2ol2G[@?ocjfh0_o9X[03omVf]P03ol>S^?oA]l7o
dKO100;odKO11Oo=^lP01OoAc]Ko_KWEokfieOnm^MGo_LCO00Go/KGL1?nS[]l2oiN]iP;oXK3S1?nJ
/NP2oiJek@;oWKCX0onL^N`5oifmk`;oX<7`0_nR_^d4oj?1kP;oYL?^0_nU`Nd5ojK2k@;oYl;]1_nW
`N`01OnX`NcoZ<7[ojS1jol0003oZ<7[00;oZ<7/4_nX`>/9ooooo`03o`000?oooooooooo00kooooo
000Sooooo`03o`000?oooooooooo02oooooo00?o[/7XokC3iOnd`nD00_nd`nD2okK3i@?o]KoR0one
_=l00on_]Mgo[:kHojb^f002ojb^f0?oZ:KD1?nTWLl3oijEbP;oVHg600CoSYGFohRBeon8T]OoR9;G
0on3U=`3ogbKi@?oP7S10_mjNLH3ofK7o@?oaMCU0_nk_]`01?nLSL?oSGflohem_?n=OK`3oh5`]`?o
QgNj0omjJ;83ofeM[`;oJejb0_m^J[h01?mjFZ3oLeFQog=EXOmcEJ43ofMCY`04oiC]m?mgJ;KoMfRf
ogMX]P;oOWJo0_mOE[001_mbFJKoOVF[ogiUZomnIJ_oUWR`ofmBX0?oHdbR0om8CK@3of]HZ`;oOfbc
00?oMW_:ocm6/OmjNLD00_mNDjh2odM4ZP04oeeL^OmZFjooJU^_ofYK[`;oOfN]1OnJNJd3ojj6ZP?o
]HVX0_oWd/44om2V[P03olooc_oC/KOodk6g00;odk6g1OoF];L00oo0Ujgocjfholn]^002oln]^003
olVR/?oI][KofKJf00;ofKJf1OoA]l401?oJd]7ocK_8olfkb?o=^lP3om7>eP04okfieOnma=oo_LCO
okg4g`Co/KGL0_nS[]l2ojRch@GoXK3S0_nJ/NP00onQ/^CoWKCXoifdj003oifdj0?oW;W/0_nM_Nl2
oj6kj`GoX[k]0_nS`Nh2ojFok0CoYL7]0_nV`^d2ojO0k0KoYl7/0onW`>/2ojS1j`03o`000?nX_n_o
Z<3[01CoZ<3[2?ooool00ol0003oooooooooo`0>ooooo`009?ooool00ol0003oooooooooo`0_oooo
o`?o]<?U0_ne`n@5okFohP04okFlgon_]Mgo[kGMojneg@Co[:kH0onXY]@2ojBMc`04oiZOf?nDVMKo
U9WFoiBIePCoSYGF0on8T]L3oh>Dg0?oO9_U1Omg[_D01OmVaogoa^?]olGDiOo5e>GoZ9o=00CoW8g3
0on=OK`2oh5`]`?oLfNf0omjJ;83ofeM[`?oJejb0_m^J[h3og=EX@04ofMCYonDkOCoU>gdoiR;``?o
MfRf00CoI5R_ogif_omOE[3oGeJ`1?mMDZh3ofmBX0;oHdbR1?m8CK@2olCPk@03ogm//omfNl[oMW_:
00;o?dJa00?oNWW5oeiC[_mNDjh00_m7A:X00omMG;WoJU^_ofYK[`03ogmW[@CoVWV]1?n^QZX01?ne
RJSoim;1onOB`OoWd/43om2V[P;ocoo>0ooC/KL2okgne@?oe[Bg00?oc]kUoln]^?o?[KP00oo?[KP5
omVf]P04on?EbOoA]l7odKO1om6g`@?of];A00?ocK_8om7>e_oAc]H00_oAc]H5okg4g`;o/KGL0_n`
_N<4ojRch@;oXK3S0_nU/n84oj6bi0;oWKCX0_nS]^H4oj:hj@CoXK_[0_nR_^d2ojBmj`GoYKo/0_nU
`Nd2ojJoj`CoYl3/0_nW`N`3ojNoj`;oYl3[0_nX_nX2ojRoj`04o`000?nX_n_oZ<3[ojS0j`;oZ;o[
4OnX`>/7ooooo`03o`000?oooooooooo00kooooo000Uooooo`;o0000<?ooool00ond`nGo]L?TokG3
i002okG3i0;o]KoR0ona_>84ojneg@;o[:kH00CoXjgNoinVfonOY]_oWjKK1?nJWmP3oiBIeP?oSYGF
0on8T]L4oh>Dg0?oO9_U0_mg[_D3olKSk@03ok:`e_nXWlgoZ9o=00;oZ9o=0onLSL<3ohem_0?oPG2g
0_mcIkH2ofQV_@04ogYX/_m]GJooKEf_ofeM[`?oJejb0_m^J[h5ogjDgP?oV8_30_mgJ;H2ofAH[`03
ogif_omOE[3oGeJ`00?oGE:^0_mTHKX01?m_DZ3oHdbRof=<X_mSC:82odQ=]004ol_l^Om[ML_oJgG;
of]eb`;oMW_:0oloA[42oeiC[P?oAdBZ0_mZFjl3ogmW[@CoVWV]1?n^QZX00oneRJSoim;1onOB`@02
onOB`@03om2V[_nKNZgoTG>^00;oTG>^00?odk6gog=W]onHNZl00_n6O<401?oF];Ooc]kUolkNiOo>
g^D4oln]^004om_FdooI][KofKJfomVf]P?ohmG900CodKO1om[BdOoJd]7of];A0_o@k^P3om7>eP;o
b>7Z0_nma=l2ok?=k@Go/;gS0_nX/n42ojRhi0CoYK?R0_nQ/^@2ojBei@CoXkKV1?nR^>T2oj6kj`;o
Y;[Y1?nT_N/2ojFok0;oY[gZ1OnV_n/2ojO0k0;oYkoZ0_nW_n/7ojRojP;oZ;o[00?o0000ojRoj_nX
_n/00onX_n/2ojS0j`;oZ;o[3OnX`>/6ooooo`03o`000?oooooooooo00kooooo000Wooooo`03o`00
0?oooooooooo02kooooo0one`n@3ok72iPCo/KcR0_n_]Md00onW/n;oXjgNoj>]gP02oj>]gP?oWjKK
1?nJWmP3oiBIeP?oSYGF0on8T]L2oh>Dg0;oFL[e00?oJM_=oiWce?o2jO000_o2jO001?o6hngo/[3F
ok:`e_nb/=H3ojROc@?oW8g30on=OK`3oh5`]`?oLfNf0_mXI[d4ofeM[`;oJejb0om^J[h3ogjDgP04
okfkeonHRl?oV8_3oiR;``?oMfRf0_mTF:l2oemF/0?oGE:^0omTHKX3of=<XP04odQ=]?nK/NOoaL_O
olG;g`;oJgG;00?oEEBdogIkb_mfNlX00_loA[42oeiC[P?oAdBZ00?o<TbnofYK[omoIjd00_moIjd4
oiYi[@Co[XJZ0_n[lk@2onOB`@?oVgZ]0_nALjh00onONZWoV7Z_oiQj[`02oiQj[`?oQWc10_o>g^D3
oln]^0?ofmKC00?ofKJfon?EbOoSeLT00_oSeLT2om;kh@03om[BdOo@k^Sod>kX00;od>kX00?odLkF
olSQj_o8hNX00_nXi?/4ok?=k@;o/;gS0_nZ`^/5ojRhi0;oYK?R0_nV]nD4ojBei@?oXkKV0_nR^>T2
ojFhi`GoY;[Y0_nT_N/2ojJlj@CoY[gZ0_nV_n/2ojNnj@?oYkoZ0_nX_^T;ojRojP05o`000?nX_n[o
Z;o[ojRojonX_nX01OnX_n/<ojS0j`Kooooo00?o0000ooooooooool03_ooool002Sooooo00?o0000
ooooooooool0;_ooool00one`nCo/L;Vok72iP03ok72iP;o/KcR00?oZK[VojNch_nW/n800_nW/n84
oj>]gP?oWjKK0_nJWmP2oi6^jP?oR[3_1?n3]_H2ogC1oP;oN^;`00?oT_3Qol;Yl?o2jO000_o2jO02
okZogP?o/[3F1?nXWld3oib=``?oSGfl0_n1L;L3og=W]P;oJ6Jm0omCL]@01?m]GJooJejbof]N/_m[
G[83ofiZ_P03ogjDg_nm^mOo_K_G00?oV8_30omgJ;H2ofAH[`03oda?]?mOE[3oGE:^00;oGE:^0omT
HKX5oi^ai`;oaL_O0om[ML/00omEE;CoMW_:ocm6/@02ocm6/@04oeiC[_m7A:[oAdBZodM4ZP;o<Tbn
00?oJU^_ogmW[OmoIjd01OnJNJd2ojj6ZP04oj_c]?nXR;?oZ8RcojR8/`;oVgZ]0_nJMZX3oimjZ@Co
V7Z_1?n6O<42obQah004oln]^?oKe]?ofmKCom_Fd`;oZoG`0ooSeLT2om;kh@;oK=k?0_o@k^P3oi_`
l@03olSQj_nXi?_oZ>Ck00;oZ>Ck0_nccNd2oio?n0CoZ/;[0_nX^>@2ojBljPGoY[OU0_nT]ND00onU
^>KoY[OVojJgiP02ojJgiPCoYKSW0_nT^^T2ojNki`GoY[cY0_nV_NX2ojRmj0CoYkkY00?oYkoZojRn
jOnX_^T00_nX_^T2ojRojP;oZ;kY1_nX_nX00ol0003oZ;oZojRojP03ojRojP;oZ;o[3onX`>/5oooo
o`03o`000?oooooooooo00kooooo000Yooooo`03o`000?oooooooooo02oooooo0_na`^H3oj[1jP?o
ZK[V1?nW/n82oj>]gP;oVk;X0onG[nP4oi6^jP?oR[3_0_n3]_H2ohGKoP;oSng`0onjjOD2ok_:iPCo
^[oN0onb/=H2ojROc@04oi:>c?n7PlSoQh?8ohN3b0?oSGfl0on1L;L2og=W]P?oJ6Jm1OmCL]@01?l0
RLOoKVZnofiZ__nZ[MT3ohJ7c@;oKfk10_nHRl<2ogMX]P?oI5R_00?oC4ndoemF/?mMDZh00_mMDZh3
ofAQ^P?oVk7W00Cok?O6olG;goo5bmooaL_O0_m[ML/2oeED]0?o?dJa00?oBU2foeiC[_m7A:X00_m7
A:X2oc9<_P?oOfN]1?nJNJd00on^QZ[oaZRkolJX^`02ojR8/`03oiEg/?nJMZ[oVWJZ00;oVWJZ1?nO
NZT3oiQj[`?oQWc10_nbV[h3oi2YiP03om_Fdon[mO3oZoG`00;oZoG`00CohmG9om;khOnii?Co^NCd
0_mEb?@3oggBo`03ob2Piol0S<Co:JoO00;o:JoO1?mie?h3oio?n0;oZ/;[0_nM`o84ojBljP;oY[OU
0_nT^^T4ojFhiPCoY[OV0_nU^>L2ojNji`CoYk_W0_nV_>T2ojRlj0GoZ;gX0_nW_^T2ojRmj@;oZ;kY
0_nY_^T5ojRnj@;oZ;oZ00GoZKoZojRoj_nX_n[oZ;oZo`000005ojRojQ7oZ<3[1?ooool00ol0003o
ooooooooo`0>ooooo`00:_ooool2o`00037ooooo1?nZ`NX3ojVjiP;oYk?R0_nN]^T4oi^bj0?oUjoX
0_nA[^X2oi36nP?oR/on0_nAi_/3ok;Um`03ok[YmOnkb^Ko^l[V00?o^l[V0_nj_mh01?nWZ=OoWY_A
oijKdOnNVm44oi:>c0;oQh?80omiNlP3ogAmcP?oLfNf0omXI[d2oe=be003ohGZeOoFo]WoaM7S00Co
ZZgI0on6Qld3ofm^`@;oMfRf0omTF:l2oda?]0?oGE:^1?mTHKX00onK/NOok?O6ol_FhP03oh6>e`04
obU4^_m[ML_oEEBdoeED]0;oB4fc00?o?dJaodY@]_m:D;H00om7A:X3oc9<_P;o5HKW0_nJNJd2onOC
`@;oaZRk00CoYHfloiEg/?nEMk3oUGN`1OnJMZX3oimjZ@CoV7Z_00?oQWc1ok:J__nbV[h00_nbV[h0
0on@ZNKo_KoKokfof`02okfof`03omOBe?nJgOgo^NCd00;o^NCd0oo5i>d2oggBo`;oTLkm0_m5Z_P4
obFTj@?oE[ck0on6aod4oig3lP;oY;cZ0_nM_Nl4ojBjj@CoYKSV0_nV]nH6ojNji`;oYk_W0_nX^nL4
ojRlj0;oZ;gX0_nY_NP3ojRmj@;oZKkX1?nY_^T2ojRnj@;oZKoY1?nY_nX2ojRojP03ojVoj_l0003o
Z;oZ00CoZ;oZ4OnX`>/3ooooo`03o`000?oooooooooo00kooooo000/ooooo`03o`000?oooooooooo
02oooooo0_nZ`NX2oj:nk@?oXK_[1?nN]^T2oi^bj0;oUkgb1?nC`?H3oi36nP03oh[?o_nAi__oTNKk
00?o/^Gg0_njd>/4ok_:iP03ojjbg?nWZ=OoYjSG00;oYjSG0onNVm43oi:>c0?oQh?80omiNlP2ogAm
cP?oLXcM0_mXI[d2oh71o003ojgg`OoFo]WoaM7S00;oaM7S0onZ[MT3ohJ7c@?oKfk10_mIG[d00omg
J;KoI5R_ofAH[`02oda?]0?oB7_P0_mTHKX2oncgaPCobmKR0_n1S]L2obU4^P03of]ebomEE;CoEEBd
00;oB4fc00?o?dJaodY@]_mPNmH00_mPNmH4oc9<_P03oaF6iooWdl7oim?100;oim?10onUSK`4oiEg
/0CoVWJZ0onONZT4oiQj[`Go/YZn00Coc[2lokfofonm_m_o_KoK0_oGd]@2on;Nd004okWTm?o5i>go
aNC]olGTk@;ob=oZ0_nAc_d2oi[6mP;oHZci00CoAJ[hoc6Ql_laXO;o<J7b0om5ZoP3og2ko@?oS/3g
1OnM_Nl3ojBjj@;oYKSV0_nU^nT6ojNji`OoZ;_W0_nX_>P6ojVmj003ojRmjOnY_^SoZKkX00;oZKkX
0_nY_^T6ojVoj@OoZKoZ00?o0000ojRoj_nX_nX00_nY`>/BojS0j`?ooooo00?o0000ooooooooool0
3Oooool002gooooo00?o0000ooooooooool0;oooool4oj:nk@?oXK_[0_nN]^T2oiVll0CoUkgb0_nC
`?H3oiGBo@;oU=cn0on[g_T00onbiOOo^]3[ok[@j`02ok[@j`03ok_:i_n^/]co[[;L00;o[[;L0onW
Z=L3oijKd@?oTXk<0on7PlP3ogUkb0?oM7g>1?mbS=d01?n1`Oco[OO1ok_me_o>j>T4olGAh`?oZZgI
0_n6Qld3ofm^`@?oFEjm0omTF:l2oda?]0?oB7_P00CoXnn`omOm^OoQlmWohO?I0oo;e^83oh6>e`;o
:DBj0_mEE;@3odQ=/`;oBU2f0omPNmH01?o0o]SomO6aoo3a`oo`kL<3onOC`@;oa[gB0onUSK`3oiEg
/0CoVWJZ1?nONZT2oiQj[`;o/i2b1?nbV[h2olj`_004okfofooGd]Coem;DomOBe0;oh]k@00?oi^G@
olGTkOo8gnX00_o8gnX3olGGi`?oV/Kf0omR[?T4odNQmP03odNSmom5ZoSoL;_m00;oL;_m0on>`?L2
oifmk`;oUKgb1?nP_>d4ojFkj@;oYk[W0_nW_>P6ojRki`WoZKgX1?nY_^P2ojZoj@SoZKoY1onY_nX0
0ol0003oZL3ZojW0j`03ojW0ja7oZ<3[0oooool00ol0003oooooooooo`0=ooooo`00;_ooool00ol0
003oooooooooo`0_ooooo`;oX[k]0_nM_Nl3oi^lk`CoVKc`0_nG_O83oiS;n@;oUM;m0onWe_P2oj_N
n@?o]M7_0_njd>/2ok:kh@Co[[;L1?nWZ=L3oijKd@?oTXk<0on7PlP3ogUkb0?oM7g>0_mbS=d00om<
bL3o^ogFok_meP03olkXj@;oaM7S00CoXZ;DohV7b_n9Ql[oRHO:0om]L<D3ofm^`@;oFEjm0omSLL`3
oda?]003odQkh?n>]o;oeofi00;ohO?I00Coam7RoiFSg_nEXmkoUJ?N0_mGJ//01On1S]Oo:DBjobU4
^_m5E;goEEBd00?oB4fc0omdRMX00omPNmKo`?kHol3nf002oo3a``;ol>g300Coim?1olJmd_o6_M;o
a[gB0onUSK`3oiEg/0CoVWJZ1?nONZT01?nHNZoo/i2bok>@/_ncT;83ok:J_P?oc[2l0ooGd]@3on;N
d004onKUd?oUim;oiNOBolSOjP?oaMOW00?o_lkUoifmkonM_Nl00onM_Nl2ogBZm0?oFZ7d0omAWoD2
ofFanPCoPK[i1?nE_O84oj2lk@;oYK_Y0_nS_>/4ojNlj0;oZ;_W0_nX_NT6ojVmj0GoZKkX1_nZ_nT2
ojVoj@;oZ[oY1?nY_nT2ojVojPGoZL3Z00Go0000ojW0j_nY`>_oZL3[ojW1j`07ojS0j`?oZ<7[0_nX
`>/00onX`N_oZ<3[ojS0j`03ojS0j`;ooooo00?o0000ooooooooool03Oooool002oooooo00?o0000
ooooooooool0;oooool4oifmk`?oVkc_0_nI_?03oiW5mP;oV<_i0onTcoH2ojOFn0?o/M3`0_nedNl2
ok;0i@Co/[_Q0_n^/]`00onRY=OoVI_DoiVKe002oiVKe0?oTI?B0on5S]@4ogj?fPCoLicZ0_m/`oh0
0onQmNKo^ogFok_meP03olkXj@03okNlg_nRX]CoXZ;D00;oXZ;D0on9QlX2ofe`a@;oHFk900?oKfk1
oeUN_OmIG[d01?mSLL`3ohjglP03omOm^OoQlmWohO?I00?oam7R0onEXmh2oeMZb`?o:DBj00?oAEBm
oeED]?m8CK<00_m8CK<3ogB9fP;oe]_L00Col?73oo3]`oo`kL?ol>g31?o6_M83ojF=_0?oUGN`1?nJ
MZX4oimjZ@Go/i2b00?o/YZnolj`_?o>/;`00_o>/;`00ooSakcoem;Don;Nd002on;Nd0;oi^G@0_oU
im82omoTf004olGGionoc^Go_lkUoko>i@;oWKg_0_nN]^T3oh2XkP?oFZ7d0omAWoD2of:[n0CoPK[i
0_nE_O82ohjkm0CoW;g_1?nS_>/2ojNlj003ojFmjonX_NWoZ;gY00?oZ;gY0_nY_NP2ojVnj@GoZKkX
3?nZ_nT2ojVoj@SoZL3Z00?oZL7[o`000?nY`N/00onY`N/2ojS0j`_oZ<7[1?nX`>/2ooooo`03o`00
0?oooooooooo00gooooo000`ooooo`;o0000<?ooool4oifmk`CoVl3b0_nIaOH3oj;8l`;oY<of0_n]
c?03ok7@l0;o//?W1?nb`>D2ok:kh@03ojN/f_nRY=OoXZCG00;oXZCG1?nIVm@3oi6CdP?oQHkD1?mn
SmX2og>LjP;oVN3m0_n/nN@2olcbj`;oa=?V0ong_=h3oj:Re0?oRHO:0om]L<D2of5^b@?oFEjm1?mS
LL`01On>]o;oeofion;ieOoRnMGog^[K00Coam7R0_nEXmh2oeMZb`;o43Vh00?o:DBjodED_Om5E;d0
0om8CK<01OmdRM[oe]_LomKKg?oFfmcol?7300?ol>g30_oUkmD4olJmdP?oYHfl0_nEMk05oiYfZP;o
WgZY0_n`Rjh4ok>@/PCoc[2l0_oSak`2oo3J^`03on;Nd?oViM3oi^G@00;oiNOB0_oOi=P01?oGg]co
_lkUoko>iOnoc^D2okW4h`CoW[KY0on0Z>h3ofZPl0;oGiob00CoDIoeof:[n?mRZoSoHZ_h0omi]OP4
ohjkm0;oW;g_0_nG_?43oj2mk@CoYKg[0_nX_NT2ojNnjPGoZKkY0_nY_^P2ojVoj@;oZ[oY0_nZ`>X7
ojZoj@03oj[1j_nY`>[oZL3Z00GoZL3Z1?nY`N/01?l0003oZL7[ojW1jonY`N/5ojS1j`03ojS1k?nX
`N_oZ<7[00OoZ<7[1?nX`>/00ooooooo0000ooooo`0>ooooo`00<_ooool00ol0003oooooooooo`0^
ooooo`CoWKg_0_nK`?82oj73l0?oX/Sc0_nZb>l4ojg<l003ok7@l?nb`nOo//?W00;o//?W0_nb`>D0
0on[/mkoYjcJojN/fP02ojN/fP?oXZCG1?nIVm@3oi6CdPCoQHkD0_mnSmX3ohk0n003oiWPoOn/nNCo
[?WT00;oc?;[1?o4dnH3okNlgP?oXZ;D0_n9QlX3ofe`a@;oHFk90omKP]l2of=ac004ohSOoOo9o/So
bOk8ol_oe@;oh_WE0_oNj]/2olOAhP04ojJch_mUQ=coIHCLofF4g0;oEf[;0_l@>KP2odED_@CoPHSA
0_oFfm`2oo3a``;ol>g30_oUkmD2ok_/m0?oOJ3Y0omfN<P3oiEg/0CoVWJZ00CoWgZYok2;[_n`Rjko
/8^^1?ncT;83olj`_0?ohlNl0_o`f[/01?odik_oi^G@onGWd_oUim82omoTf0?oemkL00?o_lkUokW4
honia><00_nia><2oijfj@04oin`i?n8YNSoR:GXohRUj0?oMj3/00CoJZ3`oenOl_mOWo;oGiob0_mW
YoD4ogN`mP?oRKSe1OnG_?43oj2mk@;oYKg[0_nT_^`4ojNnjP;oZKkY0onX_nX2ojVoj@;oZL3Z1?nZ
`>X2ojZoj@;oZ/7[1?nZ`NX2ojW0jPWoZL7[00Co0000ojW1jonX`N_oZ<7[1_nX`N`2ojS1j`;oZ<7/
1OnX`N/3ojS0j`03ooooool0003ooooo00kooooo000cooooo`03o`000?oooooooooo02kooooo0_nM
_Nl2oj:nk@CoXL?`00?oX/Scoj[8konZb>l00_nZb>l2ojg<l0?o/<CY0_nb`nL00on^^>7oZk?Noj^c
gP02oj^cgPCoYjcJ0onRY=L2oiVKe003oi:Rh?n=XnCoSJ?T00;oSJ?T1?n8Z^`2ohk0n0?oW>gh0_nn
lO83olCPk@;oa=?V00Co[KKOoibSf_nLXm[oW:?J0on6SmD3ogN3dP?oKG350_mQK/T3oe^2g`;oZn;j
0_o;omD2on;ie@;og^[K00?ob];PojJch_nV/n800_nV/n82ofF4g0;o>F?@0ol@>KP2odED_@CoPHSA
00Koe]_LolKEiOoTl]Goi?;Eon;mbooUkmD4ok_/m0;oOJ3Y0omfN<P3ogm`^@;oVWJZ0_nMOk84ok2;
[P?o/i2b0_o:YkD2olj`_0;ohlNl0oo`f[/01Oodik_ol^nooo;__oo]lLWognCH00?oemkL0oo=dmh2
okW4h`03ok>lh?nO/>CoWk3T00;oWk3T0on8YNP3ogNPk0CoK9o_0_m_YO84ogN`mP?oRKSe0_nG_?42
oiBklPCoWKg_1?nT_^`2ojNnjP?oY[o/0_nX_nX00onX`>_oZL3ZojW0jP03ojW0jP;oZ/3Z0_nY`N/4
oj[1j`;oZ/7Z0_nY`^/6ojW1j`?oZL;/0_nY`N/00ol0003oZ<;/ojS1k00;ojS1k0;oZ<7[0_nX`N`4
ojS0j`03o`000?oooooooooo00gooooo000dooooo`03o`000?oooooooooo02kooooo1?nR_^d2oj73
l0?oZ<C]0_nZb>l2ojk4jP?o/<CY00?o[[cTojjhhOn^^>400_n^^>44oj^cgP;oYjcJ00?oWj_OoiVV
g_nIY]h00_nIY]h3oi:Rh0CoSJ?T0_n8Z^`3oiGGoP03oic]n?nnlO;o__7b00Coa>3]00?o]lGUojff
gon]]]l00_n]]]l3oibSfP?oQXoE0_mgPm83ofZ1e`?oO:;[00?oFh;Ooj_Rn_n[h_X00_o;omD2on;i
e@;og^[K0oo:d^04ojJchP;oIHCL0_liHm02oa0i^0;oCWKJ0on1R=43olKEi@04onCbeOoRoL_oh_g;
om3oe0?o[OWS0_mE_oX00ol0C/_oOJ3YogIhb002ogIhb0;oOg2i1?nMOk85ok2;[P05ok>@/_o:YkGo
bZNeolZW]Oo>/;`00ooSak`2oo3J^`;om>Nk0_obkkl01?o]lLWoiNkDonG^e?oGg]`3olgCgP03ol?8
g_nc_>3o/kcP00;o/kcP1?nO/>@3ohRUj0?oMj3/1?m/Wnl3ofnUlP;oN:gd1On7]_@3oiBklP;oWKg_
0_nK_O04oj:ok@;oY[o/0_nU`>d4ojS0j`;oZL3Z0_nX`N`5ojW1j`;oZ/7[1_nY`^/2ojW1j`KoZL;/
0onX`^`01Ol0003oZ<;/ojS1k?nX`NcoZ<;/00goZ<7/0_nX`>/00ooooooo0000ooooo`0>ooooo`00
=Oooool2o`0002oooooo0_nR_^d3ojO0j`;oZ<C]0_n]`^X4ojk4jP04ok34jOn^_>Co[[cTojjli0Co
[[SQ0_n[/mh2ojB`h0?oWj_O1?nIY]h3oi:Rh0;oSJ?T0onB`oP2oiGGoP;o/^Oh0onoi?400oo4h>go
]lGUokO5i@02okO5i@?o[KKO1?nLXmX3ohJ?e@;oMh?B0omZPML3ogbRj`;oZNSj0_o>mnP2omSchP;o
dn7R0_o:d^000ond_>3oSj3OohnPg`02ohnPg`?oDG[L00Co>F?@oa5EcolAELoo43Vh0_m>M]X01On1
R=7oa]GUolKEiOo6eNGoi?;E00;oh_g;00?od?oDojgihon]nN<00omhh^h2o`1Q^`04o`1>bomfN<So
MWS8ogIhb0;oOg2i1?nMOk85ok2;[P05ok>@/_o:YkGobZNeolZW]OoRaKX00_oSak`2oo3J^`;om>Nk
0_obkkl2ongab@;oiNkD00?of^?LolgCg_o3b=h00oo3b=h2ok>lh003ojndgOnOZmooWj_O00;oWj_O
0on>Y><4oh6Pi`?oMj3/0omgYNl3ogf/lP;oQkKd0_n8]?84oi:ilPCoVkg`0_nR_nd2oj6okPCoYL3]
0_nX`>/2ojO1k0CoZ<7/0_nY`N/2ojW2k0KoZL;[0onY`n`2ojW2k0;oZL?/1?nY`^`2ojS2k003o`00
0?nX`^coZ<;/00?oZ<;/2_nX`N`6ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oo
oooooooo02kooooo0_nW`>/2oj_1j@Co[L;Z0_n^a>X2ojjniPCo[[cT0_n^^>42ojNehPCoY;3P0onO
Zml2oiVVgP;oUk;Z1?nB]o02oi;3n0?oY][j00Co/^OhokoTlOnoi?7o_nCa0_nkd>T4okO5i@;o[KKO
00?oW:?JohjGf?n>UmP00_n>UmP3og^=f@?oNICQ0omZPML00omlX^_oZNSjojWXnP02olkgj0;of??R
0_oChN82olG>h@?o];cP1?n?X=l2oe5jg0;o=gGP0_lAELl4odiffP05olKEiOoTl]Goh_g;on;mbonT
mmT00_n[n>P3ojocm0?oDlSb00Co04k;oaU?bOlIClWoMWS80omoL;T4oieo/PCo/8^^1?o:YkD2on;5
^P04on?7_?o`f[_ol=ZkooCW^`;ol^no0_o]lLT2onG^e0;of^?L00Goc]KOol?8g_o3b=ko`lSNok^n
g004ojndg@CoWj_O0on>Y><4oh6Pi`?oMj3/0omgYNl4ogf/lP?oR;Cb1?nB^O82oi^ml003oiZll?nQ
_nkoXKo^00?oXKo^0_nU`>d00onT`>goYl7/ojO1k003ojO1k0;oZ<7/0_nX`^d4ojW2k0;oZL;[1OnY
`n`00onY`ngoZL?/ojW3k003ojW3k0;oZL;/00GoZ<?]ojS2k?nX`^coZ<;/o`000005ojS2k0KoZ<7/
2Oooool00ol0003oooooooooo`0<ooooo`00>?ooool00ol0003oooooooooo`0^ooooo`CoZl7Y0_n]
`^X2ojk0i`Co[[kV0_n^_>@2ojVii0CoYkGR0_nT/>02oinbi@?oVk7W1?nG/^X2oi:gl0?oWlcg0_nV
f_X3okCQmP03okoTlOnkd>Wo^m3Y00;o^m3Y0_ngaND2ojR`gP?oW:?J1?n>UmP3og^=f@?oNICQ0on4
/O82ok?OmP;ob^o/00?of??Rom?Qh_oChN801?o5c^43okBlh0?oSj3O0omAN]`2ocMeh0;o4EG?0omm
`Od2oiG_k`04oj;fgOnTmmWoZoSXoj_hj0?o[o?d00Ko/NOhok;Jm?nbf_Co/][doeZfo?l0C//2oaU?
b@03ogIhb?moL;WoOg2i00CoWGnb0on`Rjh01?o2XKOobZNeolZW]Oo:YkD3on;5^P;ol^:l00Golo>i
ooCW^oobkkool^noongab@02onG^e0;of^?L0oo>e]l01?o3b=ko^kkLok^ng?nk_]`4ojndg@;oWj_O
0_nOZ=`3oi>Sh0?oRJ7T1?n1XNP3oh2Uk0?oPj__1?n:/_44oi:hl@?oV[c`0_nQ_nh2oj2ok`CoY<3]
0_nW`N`2ojK2k@GoZ<;]0_nY`^`2ojS3k@;oZL?/0_nXa>d4ojW3k@;oZL?/1_nX`nd2ojS2k003ojS2
kOl0003oZ<;/00CoZ<;/0_nX`N`<ooooo`03o`000?oooooooooo00cooooo000iooooo`03o`000?oo
oooooooo02kooooo0_n[`NT2ojg1j@Co[/3W0_n^_^H2oj^liPCoZKWT0_nW]N82oj>ei@CoWk;U0onK
/NL2oiNbjP?oWL?c0_nOc?L3oj_In0;o]>7f0onhe>h2ok_@j@;o/;gS1?nX/=h3oibSfP?oSYOH0omk
SMT4ogVDh@03ohBal_ncgoKo/mof00;ob^o/0ooAinH01Oo<f^CoaLkQolG>hOo5c^7o][oQ00CoXk3Q
0on6W^<2oeN;i`06oe5jg?lgMN3o=gGPocMeh?lbTo3oOL7m0_nEknl00onTlo;o`OS]ol7hk@02olgd
jP;od>[X00Co/NOhok;Jm?nbf_Co/][d0_nacNh01?ma]_[o6Do9oaU?bOlIClT2ogm`^@CoWGnb0_n`
Rjh3ol:Q]`03olZW]OoRaK[oh/Fj00;oh/Fj0_obh[`01?oclkWoj?ZgonSj]ooRoL<2omgme003omOb
hooJhmcoc]KO00;oc]KO0_o3bMh4ok^ng0;o[kCM00?oZjoJoinXg?nOZ=`00onOZ=`3oi>Sh0?oRJ7T
1?n1XNP3oh2Uk0?oPj__1?n:/_42oi:hl@03oiBgkonJ_>ooV[c_00;oV[c_1?nP_nl2ojC0k@;oY<7^
1?nV`^d2ojS2k@?oYl?]0_nX`nd2ojS4kPCoZ<C]0_nY`nd2ojS4k@SoZ<?]0onX`^d00ol0003oZ<;/
ojS2k00@ooooo`03o`000?oooooooooo00cooooo000jooooo`;o0000;oooool4ojg1j@;o[/3W0_n/
_nP4oj^liP;oZKWT0_nV^>H4oj>ei@;oWk;U0_nN^nd4oibmk`;oWL?c0onUdOL2oj_In0?o]=Ca0_nh
e>h2ok?5i`Co/;gS0_nX/=h01?nLZMooTJ7Ooi6QgonAXMl3ohZNh@CoPj;X1?nC^o<00oncgoKob^o/
ol[_k003om7WiP?oc=[T00CoaLkQokJohOnf_n7o][oQ1?nS/>43ohJNh`?oEh_W0omFX_H00omheogo
Y??bojCclP02ol7hk@;ocOCZ0_o@j^P3olkOi003ok;Jm?nacNko/Lg^00;o/Lg^00?oLKKjoaU?bOlI
ClT00_mGJ<T01OmoL;WoWGnboieo/_nMOk;o/8^^00Co`Z6g00CobZNeon;5^_oRaK[oh/Fj0_obh[`2
oo?c^@;oj?Zg0_oMoM@01OoGl^?oc^?WolkSioo>hnOoc]KO00Co`lWN0_nk_]`00ond]][oZjoJoj^_
fP02oj^_fP;oWjSL0_nPY]X3oiNSg@CoSj7Q0on9X^D3ohRVj@CoRJc/0on>/^h4oiBgk`CoV[c_0onP
_nl5ojC1kP;oY/;]0onV`^h2ojO3k@03ojO4k_nXa>koZ<C^00?oZ<C^0_nXa>d00onXa>koZ<C]ojS4
k@03ojS4k@;oZ<?]00?oYl?]ojS3kOnX`nd00onX`nd2ojS2k@03o`000?oooooooooo013ooooo00?o
0000ooooooooool03?ooool003cooooo00?o0000ooooooooool0;Oooool2ojg1j@;oZl7Y1?n/_nP2
oj^liP;oYk_W1?nV^>H2oj>ei@;oX;[[1?nN^nd2oibmk`;oXLWd0onUdOL2ojkAlP?o]=Ca0_ncb^/4
ok?5i`;o/;gS00?oYK7QoibYgonLZMl00_nLZMl3oi6Qg`?oRYkQ1?n3X^P2oi>kl`;o[]cg0oo1h^l0
1?oAinKoc=[TolcJi?o<f^@2ol7<hPCo][oQ0_nS/>42oib[h@?oRjKW1?meZO<2ohC?o`;o[^Ci0_o4
jO02olkTi`04om3Zj?o>gnCoc]oTolkOi0?obmCQ0_nacNh2ok73i`03ohBdm?lIClWoEfS900;oEfS9
0_nMOk800onRT<;o`Z6gol:Q]`03ol:Q]`03om_7aOoRaK[oh/Fj00;ol^:l0_oclkT2onSj]`;ogOgD
00Goeo;SolkSioo>hnOoc^?Wol?Ai@04ol?9gP03okZng?nd]][o];KJ00;o];KJ0_n[[mX00onYZmSo
X:KJoj2VfP03oj2VfP?oUj?M1?n?XN43ohVRi@?oR:KY1?n9[>`3ohjbkP;oU;O_0_nG]nh4oi^kk`?o
X;o_1OnT`Nh2ojK2kP;oY/?^1?nWa>h2ojS4kP;oYlC^1?nXa>h2ojS4k@;oYlC^1?nW`nd2ojS3k@Go
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`00?Oooool00ol0003ooooo
ooooo`0]ooooo`CoZl7Y0_n/_nP2ojRnj@CoYk_W0_nV^>H2oj>kj`CoX;[[0_nN^nd2oj74lPCoXLWd
00?oYM7gojkAl_n^dO800_n^dO800onde?7o/l[[ok?:j`02ok?:j`;o/lGW0_n[^N@3ojFah@CoW:WO
0onAXMl3ohZNh@;oPj;X0onH_o<01?n^g?Oo`N;_ol7Rkoo1h^l3olKNjP03olcJi?o1c>;o`LcR00;o
`LcR0_nf_n42ojbeg`CoW:_Q0on;Y^L2ogFYl`?oV/Ge00?o[^CiolCYl?o4jO000_o>i>L3om7Mh@05
olkOi?o;e>7obmCQol_DhOo6bmd00ona`nL2ok6lhP04oi:ak?lIClWoEfS9oeMXb@CoXY321?o2XKL2
om_7a@04on;5^_obh[col^:loo?c^@;oj?Zg00?oZoS:okgjjonnj_800_nnj_801Oo>hnOo`m7Uol?A
iOo3dNGo`lWN00Co^[kL0_nd]]X00on_/=SoZJ_HojV[f002ojV[f0CoX:KJ0onGXmd2ohnQh@;oU:;N
1?n@Y>83ohnWiP?oSjcY1?nB/^`4oiNgkP;oVk__0_nM^nh4oj6okPCoY<7^1?nV`nh8ojO4kP;oZ<C^
1_nWa>h2ojO3k@Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`00?_oo
ool00ol0003oooooooooo`0]ooooo`;oZl7Y0onY`>/3ojRnj@;oYk_W0_nT_>/4oj>kj`;oX;[[0_nQ
`O04oj74lP;oXLWd0onYcO82ojkAlP?o/<c^0_ncb^/2ojjoiPCoZkWT0onU/N42oibYg`;oUjSR0onA
YnD4oi6_j`;oV;oc0on_d_801?o1h^ooa]kZolKNj_o6g^X3ol?BiP;o`LcR00?o]l3Qojbegon/]Ml0
0on/]Ml2oib[h@03oij`i?nJ]N[oV[GZ00?oV[GZ0_nJaOD2okGDl003olCYl?o>i>Ooc^CW00?odMgQ
0oo@eMd01Oo;e>7oa/_MolK;gOo6bmgo/L?W00Co/KcR00CoT[7/oeMXbOmGJ<WoEfS90onRT<83ol:Q
]`?oflO500Gojo;<oo;R_?oCoKWoY^ZLoj_hbP02okgjj`?o_^[b0_nje^h2ol?Ai@;o^/?Q0onj_]`0
0ond]][o[k3Hojn`f002ojn`f0CoZJ_H0_nPY]X00onQYMSoVZ?KoiZSf`02oiZSf`CoU:;N1?n@Y>83
ohnWiP?oSjcY0_nB/^`2oiNbjP?oV[O/1OnM^nh2oj6okP03oj:ok_nT`NkoY<7^00?oY<7^0onV`nh;
ojO4kQ3ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`00?oooool2o`00
02oooooo0_nY`>/2ojJok0CoYKk[0onT_>/2oj>kj`?oX/3^0onQ`O02oj74lP?oY/Wb0_nYcO83ojk;
k`;o/<c^0_n^`nT4ojjoiP;oZkWT0_nT/^83oif/hPCoUjSR0onAYnD2oi6_j`?oXL;`0_n_d_83okcI
k`05olKNj_o3d^Ko`m;Vol?Bi_nlb>@01?ng`>42ojbeg`;oYk?Q1?nN/>@2oiZejP;oZl;[0onee?03
olGHj0;oc=OQ00GodMgQom3EgOo@eMgod=GMolg>fP03olK;g@;o`/?K0ona_>801On`]]goVjkUoi^^
iOl0B<KoEfS900?oXY320_o2XKL4om_7a@03on_bc?oCoKWodofi00;oKmkY0_nFhOh01?nnj_;o^]K^
ok[Fk_nje^h2okC6i`Co^/?Q00Co^[kLokBff_nd]][o];KJ1?n_/=P2ojV[f0;oYjSG0onQYMP4oiZS
f`?oU:;N0_n@Y>82oiJUh0?oUJSS1?nE[NL4oiNbjP?oV[O/0_nM^nh2oinlk@CoX[o^0_nT`Nh2ojG2
kPCoY/?^1onWa>hDooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool0047o
oooo00?o0000ooooooooool0;Oooool4ojJok0;oYKk[0_nT_nd4oj>ok@;oX/3^0_nT`nl4ojC5l0;o
Y/Wb0onZbO02ojk;k`;o[/C[1?n^`nT2ojjoiP;oZ;OT1?nT/^83oif/hP;oUjSR0_nI/NP3oiVfk0?o
XL;`0on^co42okcIk`?o_mCZ00Co`m;Vokc8i?nlb>Co_<ST0_ng`>42ojjih@CoYk?Q0_nN/>@2ojFg
i@CoZl;[00Co]MC`olGHj?o5f>SoaMSX0oo<en43om3Eg@?ocLkJ00?oa/_Mol;3foo2`m/00_o2`m/0
1?na_>;o/;KMok2fgOn`]]d2oi^^i@03o`18a_nRT<;oXY3200;oXY3200Co`Z6gom_7aOoKalGoflO5
0_o[l/`00ooCoKWoI<;mofC2o@02oiKQoP?oY=3g00?o^]K^okC6ionda^L00_nda^L2ok[3h@03okBi
gOnd]][o];KJ00?o];KJ0_n_/=P00on/[=OoYjSGojNXe`03ojNXe`?oXJGH0_nJXm/00onMXmWoVJ?L
oiVSg002oiVSg0CoUZGP0onEZ><4oiF]i`;oUk;Z00?oVk?XoifgjonM]n/00onM]n/3oinlk@;oX[o^
0_nT_nd4ojG2kPGoY/?^0_nWa>hHooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
2oooool004;ooooo00?o0000ooooooooool0;Oooool2ojJok0;oY;o/1?nT_nd2oj>ok@;oY<7^1?nT
`nl2ojC5l0?oZ<O_0_nZbO02ojc5k0Co[/C[0_n^`nT2oj^kiPCoZ;OT0_nT/^800onO/^GoV[3VoiZ`
iP02oiZ`iPCoVK7X0onI]^`01OnQ`_3o[/oaojk?lOn^co7o]]7^00Co_mCZ00Co_LkWokc8i?nlb>Co
_<ST0_nd`><4ojjih@;oYk?Q0_nW]>84ojFgi@;oZl;[0onib^L01?o5f>Soc=OQolcGhOo<en42oloC
g@04om3EgOo=c][ocLkJolg>fP;obLOH0oo2`m/00onn_MSo/;KMok2fg@03ok2fg@;oVjkU00?oX:cO
oj:@`_nRT<800_nW_NT2om_7a@;ojo;<00?odofiogfam?mm/O@00on:`OT2ojC@m`?oYl;/0_nda^L0
0on`^^7o];WMokBig@02okBig@;o];KJ0_n_/=P4ojb/e`;oYjSG0_nVY]H3oj:Te`CoWJ?I1?nIXm`3
oiJUh0;oUJSS0_nJZ^43oiZ^i@CoVk?X0_nM]n/2oj6hj@CoX[c/1?nT_nd2ojG2kP;oY/;^0_nV`nhM
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool004?ooooo00?o0000oooo
ooooool0;Oooool4ojBok0;oY;o]0_nT`>d4ojC1kP;oY<?_0onVa>l2ojS7k`;oZ/C/1?n/aN`2ojk4
j`;o[;kW1?n[^nH2ojRgi0;oXkGU0onO/^D4oiZ`iP;oVK7X00?oW[_]oj?4l?nSa?000onSa?001On^
co7o]]7^okKAk_nfdNko_mCZ00Co_LkW00?o_<STokC0hond`><00_nd`><2ojjih@;oZ[KR1?nW]>82
ojFgi@;o[koV0onib^L3ol;?i003olcGhOo?dmgocm?M00?oc/oJ00?ocLkJolW7f?o9amP00_o9amP0
1?o2`m_o_[gHokjmf?nn_MP2ok2fg@;o/;;J1?nP[=l4ojNmj@03om_7aOo[l/coT:SV00?oT:o[1?nI
^>h2ojO2k0;oZ;ST1?n`^^42okBig@;o[k;J1?n_/=P2ojb/e`03ojZYe_nVY]KoYZKF00?oYZKF0onR
Y=L3oifSf@;oVJ?L0_nMY=X3oi^VgPGoVZ[Q0onJ[^D2oi^cj0;oX;CV1?nQ^>T2oj:lk0;oYKgZ1?nU
`>`2ojK2kR3ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`00A?ooool0
0ol0003oooooooooo`0]ooooo`CoY;o/1?nT`>d2ojC1kP?oY/;^0_nVa>l2ojW3k@CoZ/C/0_n/aN`2
oj_0j@Co[;kW0_n[^nH2ojJhiPCoXkGU0onO/^D2oiZ`iP03oibfj_nN^ngoW[_]00;oW[_]0_nSa?03
ojc;l0;o]]7^0onhcn`2okg>i`?o]lKU0_nd`><2ojnjhPCoZ[KR0_nW]>82oj^ii0Co[koV00Co^L[W
ol;?i?o2cnCo`/oT0_o7cn000oo?dmgoc/oJolk?fP02olk?fP05olc:f?o9amSobLOHolW7f?o5`]L0
0onn_MP2ok^he`Co/;;J0_nP[=l2ojBZf`03oiVWh?m[gNOoJmgW00CoT:SV0on@[n/2oiVhkP;oWk;U
1?nX^>@2ok2jh@03ojfbg?n_/][o[k;J00?o[k;J0_n_/=P00on/[=OoZZWFojZYeP02ojZYePCoYZKF
0_nRY=L00onSY=KoX:CHoj2Tf002oj2Tf0CoWJCJ0onKY]h2oiZZh@;oWj_O0onO[n<5oj2diP;oXKSY
00?oY;WXojFmj_nU_NX00onU_NX2ojG0k2Cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`00AOooool2o`0002oooooo0onT_n`2ojC0k@?oYL7]0_nV`^h2ojS2k0CoZL?]0_nZ
a>`2oj_1jPCoZl3Y0_n/_^L00onX^nOoY[SVojJhiP03ojJhiP;oXkGU00CoXKKWoinej?nO]NSoWkGX
1?nL]^X2oijkk@?oYLC_0_n/bo03ok7=kP;o^<o/0_nfbNT3okO6i@;o//3T1?n_^^82ojZfhP;oZKOS
1?n[^N@2ojnoiP?o^<GT00?o`/oTolO?h?o7cn000_o9c]d3olk?fP?oc<[H00GobLOHolG2eoo5`]Oo
aL;Gokjmf004ok^he`;o/;;J0_n_[mP4ojBZf`?oVJOP0_n@Z>H00onIYn3oVZcSoiZ/h`02oiZ/h`Co
Wk;U0_nX^>@00onX/Mko[K;Lojfbg002ojfbg0?o[k;J00?o[:gHojb/eon/[=L00_n/[=L4ojZYeP;o
YZKF00?oYZGEoj>Te_nSY=H00_nSY=H4oj2Tf0?oWJCJ0_nKY]h2oinXg0CoWj_O0onO[n<2oj2diP;o
Y;GU1?nT^NP2ojFmjRWooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`00
Aoooool00ol0003oooooooooo`0]ooooo`CoYKo/0_nU`Nd2ojO1k0CoZ<;/0_nY`nd2oj[1j`CoZl7Z
0_n[`>T00onY_NSoZ;_WojRki`02ojRki`;oY[SV0_nT]nL4oj6fi`?oWkGX0_nL]^X3oj6nkP;oYLC_
0_nZbNl3ok7=kP;o//[/1?nfbNT00onga^Go//3Tok;0i002ok;0i0;o[k[R0_n[^N<4ojVgh`;oZkWT
00?o/;kTokS5i?nhaN@00_nhaN@2okk9hP03olO?h?o9c]gobLkM00;obLkM00Goc/oJolc:f?o<b]So
c<[HolW6e`03olG2e`;o`[gF0onk^=L2okRdePCo[joH0_nTZ]/00onUZ=WoWZOLoijWg002oijWg0?o
VJOP1?nJ[><2oinbi@03oj:]gonX/MkoZ;7N00;oZ;7N1?n]/]`01?n_/][o[:gHojb]f?n/[MP4ojb/
e`;oZZWF00?oZ:OEojJUeOnVYMD00_nVYMD4oj>TeP;oX:CH00?oXZCGoj6VfOnQY]T00_nQY]T4oinX
g0?oWj_O0_nO[n<2ojBahPCoY;GU0_nT^NP/ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02oooool004Sooooo00?o0000ooooooooool0;Oooool2ojFok0;oYl3[1?nW`N`2ojS2k0;o
ZL7[1?nZ`N/2oj_1jP03ojVnjOnY_NSoZKgX00;oZKgX0_nX^nL2ojJii`CoY;OW0_nQ]^L2oj6jjPCo
XK_/0_nQ_^h2ojK4k`CoZ/W_00?o/Lg^ok;:k?nbb^`00_nbb^`2okK9j@?o//CW0_nb`>@2ojfli@Co
ZkWS0_nY]n<00on[^^Co/;kTok2ni002ok2ni004okS5i?nnbN;o_/WRokk9hP;o`/[Q0oo9c]d3olW;
f`05olc:f?o9a]OobLKGolW6eoo5`]L01?o2_MH00onk^=Oo^;CFokRdeP02okRdeP;o[joH00?o[ZgF
ojFXfOnUZ=T00_nUZ=T4oijWg0?oVJOP0_nJ[><00onOZMgoXZgOoj:]g`02oj:]g`CoZ;7N0_n]/]`0
0on[[][o[:gHojb]f003ojb]f0;o[:cG00?oZZWFojRWeOnXYmD00_nXYmD4ojJUe@;oXjCF00?oY:CE
oj:TeonRY=L00_nRY=L4oj6Vf@;oWjSL00?oY:WKoj>]g_nS[Mh00_nS[Mh4ojBahP;oY;GU<?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo0019ooooo`03o`000?oooooooooo
02gooooo1?nW`>/2ojO1k0;oZ<7[1?nY`N/2oj[1j`?oZKoY0_nY_^T2ojVmj0;oYk_X1?nV^NL2ojBg
i`;oXk[Y1?nQ^^X2oj6kk0;oXl7^1?nVa>l2oj[9k`?o[LW^0_nbb^`2ok76jP?o//CW00?o[[oWojfl
iOn]_>D00on]_>D2oj^ih`03ojZii?n[^^CoZk[T00;oZk[T0_n`_^@3okG3i003okk9h_o2b^7o`/[Q
00;o`/[Q00GobLkMolW;foo9bm_obL_KolS8fP03olW6e`;oaL;G0oo2_MH2okjieP?o^;CF00?o]K7E
ojj]e_n^[MH00_n^[MH3ojFXf@;oWZOL0_nRY]T3oijVf`CoWjWM1?nR[Ml2ojRagP03ojN/fon[[][o
ZjkJ00;oZjkJ0_n/[MP2ojZZe`CoZZWF0onXYmD2ojJUe@;oYZGD1?nTY=D3oj:Te`;oXJKI0_nTYmP4
ojBYf`CoXjgN0_nT/N8dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
04[ooooo0_l0000^ooooo`;oYl3[0_nX`>/4ojS1j`;oZL7[0onY`>X2ojVoj@03ojRnjOnX_NSoZ;gX
00;oZ;gX0onW^nP2ojJii`;oY;[Y1?nS^^T2oj6jjP;oX[k]1?nS`Nh2ojK4k`?oZLK^0_n]bNh2ojk7
k0Co/LKZ00Co//CWojjoion^_nOo[[oW0_n]_>D2ojZji@CoZ[WT0_n[^^@2ojjmi@?o]L?T0_nia^@3
ol;:h@?oa<[O00GobL_KolS8f_o8b=[ob<SJolW6e`04olG2e`03ol:me_nn^MKo_[WF00;o_[WF00Co
^;CFokFaeOne/MGo]K7E0on^[MH2ojFXf@;oYjOG1?nRY]T3oijVf`;oWjWM00?oXZOJojBZfonTZ]/0
0_nTZ]/4ojN/f`;oZjkJ00?oZJ[HojZZeonZZ]L00onZZ]L3ojZYeP;oZ:OE0_nXY]@4ojJUe0?oY:CE
0_nRY=L2ojFUePCoY:OH0onTZM/2oj>]gSWooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0:ooooo`00C?ooool00ol0003oooooooooo`0/ooooo`CoZ<3[0_nX`N/5ojW0jP03ojRojOnX
_^WoZ;kY00;oZ;kY0_nX_NP2ojJmj@CoYK_Y0onT^^T2oj>jj@;oXkg/1?nR_^d2oj?1kP?oY/C^0_nY
a^h2oj_7kPCo[/O/0_naa^X2ojk2j@;o[[oW0_n[_>H4ojZji@;oZ[WT0_n[^nD4ojjmi@03okG3i?ni
a^Co^LKT00;o^LKT00Go`/[QolC:goo4b]ooa<[OolC9gP03olS8fP;oaLGJ0oo5`]L2ol:ne`?o_[WF
00?o^[KFokFaeOne/MD00_ne/MD2ojj]eP;o[J_E1?nWYmL3oj:Vf@;oWZKK00?oXJGIoj:Wf_nRYmX0
0_nRYmX4ojBZf`;oYjcK00?oYjWHojVZf?nYZ]P00_nYZ]P4ojZZe`;oZZWF0_nYYmD4ojRVe0?oYZGD
0_nTY=D2ojFUe@CoYJGF0onTYmP2ojBYfccooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0:ooooo`00COooool00ol0003oooooooooo`0/ooooo`;oZ<3[0onY`>/2ojW0jP03ojVoj_nX
_nWoZ;oY00;oZ;oY0_nX_^T2ojNmj@CoY[gY0_nU^nT2ojBmj`CoXkc[0onS_N`2oj:nk@?oYL;^0_nV
a>h2ojS5kPCoZlO^0_n^an`2ojg4j`;o[/;Y0_n[_nP4oj^liP;oZ[[U0_nX^^H4oj^ki@;o[[gU0ona
`ND2okW6i0?o_<OS00Goa<[OolC9g_o4bMkoa<WNolS8fP04olG5fP03olG2eoo2_]Oo`[kG00;o`[kG
00Co_[WFokZfe_nj]]Ko^[KF0_ne/MD2ok:_e@Co[J_E0_nWYmL00onWY]KoY:GGojBUe`02ojBUe`?o
XJGI1?nRYmX2ojBZf`;oYJSH0onWZMP4ojVZf0;oZZ[G0_nYZ=H4ojVWe@;oZ:KD00?oYjKDojJUe?nV
YM@00_nVYM@4ojFUe@;oYJGF@oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[o
oooo001>ooooo`03o`000?oooooooooo02gooooo0_nY`>/00onX`>_oZKoZojVojP02ojVojP;oZ;oY
0_nW_^X4ojNmj@;oY[gY0_nU_NX4ojBmj`;oXkc[0_nT_nd4ojC0k@;oYL;^0_nVa>h4ojS5kP;oZlO^
0_n[a>`2ojg4j`;oZl7Z1?n[_nP2oj^liP;oZ;_W1?nX^^H2oj^ki@;o[;gV0ona`ND00ond`nGo_<OS
okc7h`02okc7h`04okg8h_o4bMkoa<WNolC9gP;o`lOM0oo5aMX2ol;2fP?o`[kG00Go_[_GokZfe_nj
]]Ko^[KFokNceP05ok:_e@;o[J_E00?o[:WEojNVe_nWY]H00_nWY]H4ojBUe`?oXJGI0_nRYmX00onT
Y]SoYJSHojFXf003ojFXf0?oYjWH0_nYZ]P00onXZ=OoZJSFojVXeP03ojVXeP;oZJOE00?oZ:KEojNV
e?nWY]@00_nWY]@4ojJUe0;oYJGEAoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00[ooooo001?ooooo`;o0000;_ooool3ojS0j`;oZKoZ0_nX_n/4ojNnjP;oYkgY0_nV_^X4ojFmjP;o
Y;g[0_nT_^`4ojBok@;oY<3]0_nU`^h4ojK4kP;oZ<G^0_nYa>d2oj_4k0;oZ/;[1?n[`NX2oj^oj0;o
Z;gX1?nX^nL2ojRjiP;oZ;_W1?n/_NH01Ona`NGo]<?UokC3iOnd`nGo_<OS00Co_LSR00?oa<WNol?7
gOo3amd00_o3amd00oo5aM[o`/;Jol;2fP02ol;2fP05ol:neonn^mOo_[_Gokjkeonj]]H00ong/mH3
ok:_e@03ok2]eOn/ZMGo[:WE00;o[:WE1?nWY]H2ojBUe`04ojFUe_nSYMOoXjGGoj>Ue`CoY:KH0_nU
Z=P2ojJWe`?oYjSG1?nXZ=L2ojVXeP;oZ:OF1?nXY]D3ojNVe0;oYZGDC?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00[ooooo001Aooooo`03o`000?oooooooooo02cooooo0onX`>/4
ojRoj`;oYkkZ0_nW_^/4ojJnjP;oYKgZ0_nU_^`4ojBnk0;oY;o]0_nU`Nd4ojG2kP;oY/C^0_nXa>d2
ojW4k@;oZL?/1?nZ`^/2oj_1jP;oZKkY1?nX_NP2ojRki`;oYk_W1?nX^nL2ojbmiP;o[/3W0_nd`nD2
okO5i@?o_LSR0_nnan43ol?7g@;o`LGM0_o2`]X2oknofP?o_[_G0_nj^=L4okNceP04ok:_eOn`[MGo
/:gEok2]e@Co[:WE0_nWY]H00onWY]GoYJGFojFUeP02ojFUeP?oXjGG0_nTY]P00onUY]KoYZOGojJW
e`03ojJWe`?oYjSG0_nXZ=L00onWZ=KoZ:OFojRWeP03ojRWeP?oZ:KE0_nWY]A?ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02_ooool005;ooooo00?o0000ooooooooool0:oooool4
ojS0j`;oZ;o[0onW_n/3ojNnj`;oY[kZ0onU_n/3ojFnk0;oY;k/0onU`>d3ojG1k@;oYL;^0_nW`nh2
ojS4k@;oZ<?]1?nY`n`2oj[2j`;oZKoZ1?nY_^T2ojRmj0;oYk_X1?nW^nL2ojRki`04ojZmj?n^`>Oo
[/3Wojk0i`;o/<;W1?ngaND00onmb>;o_/OQokk7h@02okk7h@03ol?7gOo1aMgo`LGM00;o_/;M1?no
_mX00onn^mOo^[SGokZhe`02okZhe`;o]k?F00?o/k7Fok2]eOn`[MD00_n`[MD2ojbYe@;oZjSD1?nW
Y]D3ojFUeP;oXjGG00?oYJGFojFVe_nUY]H00_nUY]H4ojJWe`;oYjSG00?oYjOGojNXe_nWZ=H00_nW
Z=H4ojRWeP;oZ:KEDoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo001C
ooooo`03o`000?oooooooooo02_ooooo0_nX`>/3ojO0j`;oYko[1_nV_n/2ojFoj`KoYKo/0_nU`>d0
0onV`NgoY/;]ojK2k@02ojK2k@;oYl?^0_nW`^d4ojS3k@;oZL?/0_nX`N/4ojVojP;oZKkY0_nW_>T4
ojNkj0;oYk_W00?oYkcXojZmj?nZ_NP00_nZ_NP00on^`>Oo/<;Wok32i`02ok32i`;o]lGU0onhaND2
okk7h@;o_LKQ00?o`LGMokk2gOnn`]d00_nn`]d2oknofP;o^kcJ0onj^=L00onf]]So/k7Fok>aeP02
ok>aeP;o/:gE00?o[Z_Eoj^Xe?n[Z=@00on[Z=@3ojNVe@;oYJGF00?oYZGEojFUe_nUYMH00_nUYMH4
ojFVeP;oYZOG00?oYZOFojNWeonWYmL00_nWYmL4ojNXeP;oZ:OFEoooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Wooooo001Dooooo`;o0000;Oooool2ojO0j`;oY[o/1_nV_n/2ojJo
k0KoYKo/00?oYL7]ojK1kOnV`Nd00_nV`Nd2ojK2k@KoYl;]0_nX`nd3ojS1k0?oZ<7[0_nY_nX3ojNn
j@?oYkcY0_nW^nP00onV_>WoYkcXojNlj002ojNlj0;oZ[gX0on[_nP2ok32i`;o//?W0onhaND01?nh
aNCo_LKQokg6hOnma^42ok_4h@?o_/;M0_nk`=d4ok^lfP04okZheonf]]So][KHokJff0;o/k7F00?o
/:oGojj[eOn^ZmD00_n^ZmD4oj^Xe0;oYjKE0_nWYM@3ojJUe@CoYJGF0_nUY]H2ojJVeP?oYZOF1?nW
YmL2ojNXeU[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`00E_ooool0
0ol0003oooooooooo`0[ooooo`CoY[o/0_nV_n/6ojJok0;oYKo/0_nV`>`3ojG1k@GoY/7]1OnW`^d5
ojS1k0;oYko[1?nW_nX2ojNnj@03ojJmjOnV_>WoY[cY00GoY[cY0_nW_>P3ojRmj@;oZkoX0_n]`NT4
ok;3i`05okS5iOnhaNCo^<GTokS5i?nma^401?nka>400onn`]go^l3Mok_0g@02ok_0g@;o^kcJ00Go
^;[KokJff?nf]]So][KHok>cf@04ok2_e`Co[Z_E0_n[Z=@2ojVWe@CoYjGD0onVYMD2ojFUeP03ojJU
eOnVY]KoYZKF00?oYZKF0onVYmH2ojNWeekooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`09ooooo`00Eoooool00ol0003oooooooooo`0[ooooo`[oY[o/1_nV`>`00onU`NgoY/7]ojK1
k@03ojK1k@KoYl7/0_nX`N`2ojO0j`CoYko[0_nW_nX00onV_N[oY[gYojJmj@02ojJmj@;oY[cY0_nU
_>T4ojJlj@;oZ;gY0_nY_nX4ojg1j@;o//?W0_nba>L2okS5i0?o]lGT0_nka>42okW2h@?o^l3M00?o
^;gNokRjfonh^]/00_nh^]/01?nf]]So/k?Iok>cfOnc/mT4ok2_e`;o[Z_E0_n[Z]H4ojVWe@?oYjGD
0onVYM@4ojJUe@;oYZKFI_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo
001Hooooo`03o`000?oooooooooo02cooooo2?nV_n`3ojK0k0CoY/7/0_nV`Nd8ojO1k0;oYl3/1?nW
`>/2ojNoj`03ojNnjonV_N[oY[gZ00;oY[gZ0_nV_NT2ojFljPCoYKcY0_nV_>T2ojJnjPCoZKoZ0_n]
`NT2ojk3j@;o//CW0_nca>L3okO5i0;o]/CU1?ni`^401?nk`=go^;gNokRmg_nh_Mh2okRjf`;o];SL
1?nc/mT2ok2_e`;o[JkH1?n[Z]H2ojVWe@03ojRWeOnWYMCoYjGD00;oYjGD0onVYM@2ojJUeF[ooooo
00Go0000ooooooooooooooooo`00000;ooooo`00FOooool00ol0003oooooooooo`0/ooooo`KoY[o/
1OnV`>`2ojK1k0;oY/3/1_nW`N`6ojO0k0;oYl3[00?oYko[ojNnjonW_^/00_nW_^/4ojJmjPCoYKcZ
0_nU_>T2ojFmjPCoY[kZ0_nY_nX2oj[1jPCo[/?Y1?nca>L00ongaNCo]/CUokK4i@02okK4i@;o^L;Q
0_nf`N82okRmgP;o];_O1?nd^=`2ok>cf@;o[k;J1?n][]P2oj^ZeP03ojVYeonXYmGoZ:OE00;oZ:OE
0onWYM@2ojJUe6gooooo00Go0000ooooooooooooooooo`00000;ooooo`00F_ooool2o`0002gooooo
1?nV_n`;ojK0k0;oYl7/2?nW`>`5ojNoj`;oYkk[0onV_^X3ojJmjP;oYKcZ0_nU_N/4ojFmjP;oY[kZ
0_nW_n/2oj[1jP;oZl;[1?n^`nT2ok?4i`?o//CX0_nfa>D01?nd`nGo]/7RokK1h_nf`N82ok>oh`Co
];_O0_nd^=`2ok2fg@Co[k;J0_n][]P00onZ[=WoZJWGojVYe`02ojVYe`?oZ:OE0_nWYMAaooooo`04
o`000?ooooooooooo`0000_ooooo001Looooo`03o`000?oooooooooo02_ooooo1?nV_n`9ojK0k0Go
Yl3/1_nW`>/00onW_n_oY[o[ojJoj`04ojJnj`;oY[kZ0_nU_^/7ojFmj`;oYKgZ0_nV_^/2ojNoj`;o
Z<7/1?n[`^/2ojk3j@?o[/CZ0_nba>P00onaa>So]<?UokC3i@02okC3i@03okK1h_nc_n?o/koS00;o
/koS0_nd^ml00on`^^3o/;KMok2fg@03ok2fg@;o[k;J00?oZk3KojZ/fOnZ[=T00_nZ[=T3ojVYe`;o
Z:OEMOooool00ol0003oooooo`00000;ooooo`00GOooool00ol0003oooooooooo`0[ooooo`CoY[o/
0_nV`>`8ojO0k0SoYl3[00?oYko[ojJojonV_n/00_nV_n/4ojJnj`CoYKk[0_nU_N/5ojFnj`;oY[k[
0_nV`>`4ojS1k0;oZl;[0_n[`n/4ojk4jPCo/LCX0_nd`nD3ok71iP;o/koS00?o/;gTok2jh?n`^^00
0_n`^^02ok2fg@;o[;CN1?n[/=/3ojZ/f@;oZJWGN?ooool01?l0003oooooooooool0000:ooooo`00
G_ooool00ol0003oooooooooo`0[ooooo`;oY[o/0_nW`>/6ojO0k0SoYl3[1OnW_n/2ojJoj`KoY[k[
2OnU_^/2ojFok0CoY/3/0_nX`N`3ojS2k0?oZl?[1?n^a>X2ok74j0;o[l?Y0ona`NH00on^`>Oo/;gT
ok2mi002ok2mi0;o/;[P0_n/^>84ojbdgP?oZk3K0_nZ[=Ulooooo`03o`000?oooooo000000[ooooo
001Oooooo`;o0000;?ooool4ojO0j`;oYl3/2?nW`>/7ojNoj`?oY[o[1OnV_^/7ojFnj`KoYKo/0_nV
`>`3ojK1k@;oZ<;/00?oZ<?]oj_4k?n[a>`00_n[a>`2ojk4jP;o[LC[1?n_`nT01?na`NKo[/3Wojk0
ion^`>L2ok2mi0;o[;cU1?n/^>82ojbdgX?ooooo0_l0000:ooooo`00HOooool00ol0003ooooooooo
o`0Zooooo`coYl3[2?nW_n/4ojJoj`CoY[k[0_nU_^/:ojFok0?oYL7]0_nV`Nd00onW`ngoZ<?]ojS3
k@02ojS3k@;oZlC/0_nZa>d4ojg4j`;o[l?Y0_n]`^T2ojk0i`;oZkoX1?n/_>D2ojbhhXGooooo0ol0
000:ooooo`00H_ooool00ol0003oooooooooo`0[ooooo`WoYl3[2?nW_n/6ojJoj`;oY[k[1onU_n`6
ojG0k@;oYL7]00?oY/;^ojO3kOnW`nd00_nW`nd2ojS3k@?oZ<C]0onZa>d2ojg4j`?oZlC/00?o[L;Y
oj[1jonZ`N/01?n[_nP2ojbliHCooooo1?l0000=ooooo`00Hoooool00ol0003oooooooooo`0[oooo
o`OoYl3[1_nW_n/8ojJoj`03ojJok?nU_ncoYKo/00KoYKo/1_nU`>d00onU`NgoY/;^ojK2kP02ojK2
kP;oYl?]0onW`nh2ojS4k@;oZ<C^1?nYa>d2oj_4k003ojW3k?nZ`N_oZ/7[00;oZ/7[0_n[_nR3oooo
o`Co00004Oooool006Cooooo0_l0000/ooooo`OoYl3[1OnW_n/5ojJoj`GoY[o/2?nU_n`2ojG0k@Go
YL7]0_nV`^h3ojK3kP;oYl?^0_nWa>h4ojS4kP;oZLC]0_nXa>h3ojW3k0;oZ/7[Poooool3o`0001Go
oooo001Vooooo`03o`000?oooooooooo02_ooooo1?nW`>/5ojNoj`KoY[o[1onV_n`2ojFok0;oYL3]
1_nU`Nd00onU`^koY/;^ojK2kP02ojK2kPCoY/?^1?nWa>h2ojS4kP;oYlC^0_nXa>j5ooooo`Co0000
6?ooool006Oooooo00?o0000ooooooooool0:_ooool4ojO0j`CoYko[1_nV_n/7ojJok0;oY/3/1?nU
`>d3ojG1k@CoYL;^0_nV`^h6ojK3kPKoYlC^Q?ooool4o`0001cooooo001Xooooo`03o`000?oooooo
oooo02[ooooo1?nW`>/4ojNoj`;oY[o[1onV_n`6ojK0k0;oYL3]0_nV`Nd3ojG1k@;oYL;^0onV`^h3
ojK3kPKoYlC^Poooool4o`00023ooooo001Yooooo`;o0000;?ooool3ojO0j`;oYko[0onV`>`4ojJo
k0OoY/3/1onV`Nd4ojK2k@;oY/;^1OnV`nh2ojO4kX;ooooo1?l0000Tooooo`00Joooool00ol0003o
ooooooooo`0Zooooo`CoYl3/3onV`>`7ojK1k@GoY/;]1?nV`nj2ooooo`?o0000:?ooool006cooooo
00?o0000ooooooooool0:_ooool3ojO0k0koY/3/0_nV`N`5ojK1k@?oYl;]0_nV`^f3ooooo`Co0000
:oooool006gooooo00?o0000ooooooooool0:oooool2ojO0k0;oY/3/0onW`>`5ojK0k0;oYl3/0_nV
`N`2ojO1k0CoYl7]0_nW`^f2ooooo`Co0000;oooool006kooooo00?o0000ooooooooool0:_ooool4
ojO0j`WoYl3/1_nW`N`2ojO1kH7ooooo1?l0000cooooo`00Koooool2o`0002_ooooo1?nW`>/8ojO0
k0GoYl7/P?ooool4o`0003Oooooo001aooooo`03o`000?oooooooooo02[ooooo0onW`>/6ojO0k8;o
oooo1?l0000kooooo`00L_ooool00ol0003oooooooooo`0Zooooo`?oYl3[0_nW`>b2ooooo`?o0000
?oooool007?ooooo00?o0000ooooooooool0:_ooool00onW`>_oooooooooo`1oooooo`Co0000@_oo
ool007Cooooo0_l0000Zooooo`03o`000?oooooooooo07_ooooo1?l00016ooooo`00M_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo07Sooooo1?l0001:ooooo`00Moooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo07Cooooo1?l0001>ooooo`00N?ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo077ooooo0ol0001Booooo`00NOooool2o`0002Cooooo00?o
0000ooooooooool0KOooool4o`0005Gooooo001kooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0JOooool4o`0005Wooooo001looooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0IOooool4o`0005gooooo001mooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool0HOooool4o`00067ooooo001nooooo`;o00007oooool00ol0003oooooooooo`1Mooooo`Co0000
IOooool0083ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Jooooo`?o0000JOoo
ool0087ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Fooooo`Co0000K?ooool0
08;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Booooo`Co0000L?ooool008?o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1>ooooo`Co0000M?ooool008Cooooo
0_l0000Iooooo`03o`000?oooooooooo04[ooooo1?l0001hooooo`00Q_ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04Kooooo1?l0001looooo`00Qoooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo04?ooooo0ol00020ooooo`00R?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo03oooooo1?l00023ooooo`00ROooool2o`0001Cooooo00?o0000oooooooo
ool0>oooool4o`0008Oooooo002;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
=oooool4o`0008_ooooo002<ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<ooo
ool4o`0008oooooo002=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<?ooool3
o`0009?ooooo002>ooooo`;o00003oooool00ol0003oooooooooo`0/ooooo`Co0000U_ooool0093o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Xooooo`Co0000V_ooool0097ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Tooooo`Co0000W_ooool009;ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`Co0000X_ooool009?ooooo0_l00009
ooooo`03o`000?oooooooooo01gooooo1?l0002Vooooo`00UOooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01[ooooo0ol0002Zooooo`00U_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Kooooo1?l0002]ooooo`00Uoooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01;ooooo1?l0002aooooo`00V?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00kooooo1?l0002eooooo`00VOooool2o`0000?ooooo00?o0000ooooooooool02_ooool4
o`000;Wooooo002Kooooo`04o`000?ooooooooooo`0000Wooooo0ol0002mooooo`00W?ooool00ol0
003oooooo`000005ooooo`Co0000`?ooool009gooooo0_l000000ooooooo0000o`000002o`000<Co
oooo002Nooooo`;o0000b?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:[ooooo00GoV9RHo`00
0?l0003oA4A4okZj^P09ooooo`Go00000oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ
8B44ooooo`Go0000Toooool00:[ooooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`Ko000000Ko
oooooiRHV?lQ8B7ok^k^oooooom4A4@3ooooo`05oa0@4?nj^[[oooooogMgMolb<S801Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A02Cooooo`00Z_ooool00ol0003oooooooooo`0<oooo
o`03oiRHV?lQ8B7ok^k^00Sooooo00?o0000ooooooooool02_ooool00onHV9So8B4Qonk^kP2Doooo
o`00Z_ooool00ol0003oooooooooo`04ooooo`Ko00000oooool00onHV9So8B4Qonk^kP06ooooo`03
ojVYZOl@413ooooo00cooooo00?oV9RHob4Q8Oo^k^h0Toooool00:[ooooo00?o0000ooooooooool0
3_ooool00omgMgOoIVIVooooo`04ooooo`03oa0@4?l0003o^[Zj00kooooo00?oMgMgofIVI_ooool0
T_ooool00:Sooooo00?o410@o`000?l000000ol0000>ooooo`03o`000?oooooooooo00Cooooo00?o
^[Zjob4Q8Oooool03_ooool00ol0003oooooooooo`2Aooooo`00Z_ooool00ol0003oooooooooo`0;
ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Ol@413oV9RHoooooonj^[[o000000_ooooo
00Go0000okZj^_ooooooV9RHoa0@402Cooooo`00Z_ooool00ol0003oooooooooo`0;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`00oooool01OnYZJWo410@o`000?l@413oZJVY00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c02Cooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -17 0 ]
[.5 .82364 17 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(24.) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.655 .751 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69468 Mtetra
.655 .752 .921 r
.4053 .69468 .41061 .69934 .41957 .69681 .41427 .69215 Mtetra
.41427 .69215 .41957 .69681 .42855 .69428 .42327 .68961 Mtetra
.42327 .68961 .42855 .69428 .43756 .69174 .4323 .68706 Mtetra
.655 .753 .922 r
.4323 .68706 .43756 .69174 .4466 .68919 .44137 .68451 Mtetra
.44137 .68451 .4466 .68919 .45567 .68663 .45046 .68195 Mtetra
.655 .754 .922 r
.45046 .68195 .45567 .68663 .46478 .68407 .45958 .67937 Mtetra
.45958 .67937 .46478 .68407 .47391 .68149 .46873 .67678 Mtetra
.656 .754 .922 r
.46873 .67678 .47391 .68149 .48307 .67891 .47791 .67418 Mtetra
.657 .754 .922 r
.47791 .67418 .48307 .67891 .49227 .67632 .48713 .67154 Mtetra
.658 .753 .92 r
.48713 .67154 .49227 .67632 .50149 .67371 .49638 .66886 Mtetra
.66 .752 .918 r
.49638 .66886 .50149 .67371 .51075 .6711 .50565 .66614 Mtetra
.663 .748 .914 r
.50565 .66614 .51075 .6711 .52004 .66849 .51496 .66335 Mtetra
.665 .743 .908 r
.51496 .66335 .52004 .66849 .52936 .66586 .5243 .66049 Mtetra
.668 .736 .901 r
.5243 .66049 .52936 .66586 .53871 .66322 .53367 .65755 Mtetra
.671 .726 .891 r
.53367 .65755 .53871 .66322 .54809 .66058 .54307 .65453 Mtetra
.672 .715 .88 r
.54307 .65453 .54809 .66058 .55751 .65792 .5525 .65142 Mtetra
.673 .701 .868 r
.5525 .65142 .55751 .65792 .56695 .65526 .56196 .64826 Mtetra
.672 .687 .856 r
.56196 .64826 .56695 .65526 .57643 .65259 .57145 .64507 Mtetra
.669 .672 .844 r
.57145 .64507 .57643 .65259 .58595 .6499 .58097 .64189 Mtetra
.665 .659 .834 r
.58097 .64189 .58595 .6499 .59549 .64721 .59052 .63877 Mtetra
.66 .648 .827 r
.59052 .63877 .59549 .64721 .60507 .64451 .6001 .63575 Mtetra
.655 .639 .822 r
.6001 .63575 .60507 .64451 .61468 .6418 .60972 .63288 Mtetra
.651 .634 .821 r
.60972 .63288 .61468 .6418 .62432 .63908 .61938 .63016 Mtetra
.647 .633 .822 r
.61938 .63016 .62432 .63908 .634 .63636 .62907 .62757 Mtetra
.645 .635 .826 r
.62907 .62757 .634 .63636 .64371 .63362 .6388 .62508 Mtetra
.644 .641 .832 r
.6388 .62508 .64371 .63362 .65345 .63087 .64857 .62262 Mtetra
.646 .649 .839 r
.64857 .62262 .65345 .63087 .66323 .62811 .65837 .6201 Mtetra
.65 .657 .843 r
.65837 .6201 .66323 .62811 .67304 .62535 .66821 .61746 Mtetra
.655 .662 .845 r
.66821 .61746 .67304 .62535 .68289 .62257 .67807 .61466 Mtetra
.659 .664 .844 r
.67807 .61466 .68289 .62257 .69277 .61979 .68796 .61171 Mtetra
.661 .661 .839 r
.68796 .61171 .69277 .61979 .70269 .61699 .69787 .60863 Mtetra
.662 .656 .833 r
.69787 .60863 .70269 .61699 .71264 .61418 .70782 .6055 Mtetra
.659 .648 .827 r
.70782 .6055 .71264 .61418 .72262 .61137 .71781 .60239 Mtetra
.656 .64 .823 r
.71781 .60239 .72262 .61137 .73264 .60854 .72783 .59938 Mtetra
.651 .635 .821 r
.72783 .59938 .73264 .60854 .7427 .60571 .7379 .59651 Mtetra
.647 .633 .822 r
.7379 .59651 .7427 .60571 .75279 .60286 .74801 .59378 Mtetra
.644 .634 .826 r
.74801 .59378 .75279 .60286 .76291 .60001 .75817 .5912 Mtetra
.641 .639 .833 r
.75817 .5912 .76291 .60001 .77308 .59714 .76838 .58873 Mtetra
.64 .648 .842 r
.76838 .58873 .77308 .59714 .78328 .59427 .77863 .58632 Mtetra
.64 .66 .854 r
.77863 .58632 .78328 .59427 .79351 .59138 .78892 .58393 Mtetra
.641 .674 .866 r
.78892 .58393 .79351 .59138 .80378 .58849 .79925 .5815 Mtetra
.643 .69 .879 r
.79925 .5815 .80378 .58849 .81409 .58558 .80961 .57902 Mtetra
.645 .704 .89 r
.80961 .57902 .81409 .58558 .82443 .58267 .82001 .57645 Mtetra
.647 .718 .9 r
.82001 .57645 .82443 .58267 .83482 .57974 .83045 .5738 Mtetra
.649 .729 .908 r
.83045 .5738 .83482 .57974 .84523 .5768 .84091 .57107 Mtetra
.651 .738 .914 r
.84091 .57107 .84523 .5768 .85569 .57385 .85141 .56826 Mtetra
.652 .745 .918 r
.85141 .56826 .85569 .57385 .86618 .57089 .86194 .56538 Mtetra
.654 .75 .92 r
.86194 .56538 .86618 .57089 .87672 .56792 .87251 .56245 Mtetra
.654 .752 .922 r
.87251 .56245 .87672 .56792 .88729 .56494 .88311 .55948 Mtetra
.655 .754 .922 r
.88311 .55948 .88729 .56494 .89789 .56195 .89374 .55648 Mtetra
.656 .754 .922 r
.89374 .55648 .89789 .56195 .90854 .55895 .90442 .55345 Mtetra
.90442 .55345 .90854 .55895 .91923 .55594 .91513 .55041 Mtetra
.91513 .55041 .91923 .55594 .92995 .55292 .92588 .54736 Mtetra
.656 .753 .922 r
.92588 .54736 .92995 .55292 .94071 .54988 .93667 .54429 Mtetra
.656 .753 .921 r
.93667 .54429 .94071 .54988 .95152 .54684 .94751 .54121 Mtetra
.94751 .54121 .95152 .54684 .96236 .54378 .95838 .53812 Mtetra
.656 .752 .921 r
.95838 .53812 .96236 .54378 .97324 .54071 .96929 .53503 Mtetra
.656 .752 .92 r
.96929 .53503 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.655 .751 .921 r
.391 .69252 .39636 .6972 .4053 .69468 .39996 .68999 Mtetra
.655 .752 .921 r
.39996 .68999 .4053 .69468 .41427 .69215 .40895 .68746 Mtetra
.40895 .68746 .41427 .69215 .42327 .68961 .41797 .68491 Mtetra
.655 .752 .922 r
.41797 .68491 .42327 .68961 .4323 .68706 .42702 .68236 Mtetra
.655 .753 .922 r
.42702 .68236 .4323 .68706 .44137 .68451 .4361 .6798 Mtetra
.4361 .6798 .44137 .68451 .45046 .68195 .44521 .67723 Mtetra
.655 .754 .922 r
.44521 .67723 .45046 .68195 .45958 .67937 .45435 .67465 Mtetra
.45435 .67465 .45958 .67937 .46873 .67678 .46352 .67204 Mtetra
.656 .754 .922 r
.46352 .67204 .46873 .67678 .47791 .67418 .47273 .66941 Mtetra
.658 .754 .921 r
.47273 .66941 .47791 .67418 .48713 .67154 .48196 .66672 Mtetra
.661 .754 .919 r
.48196 .66672 .48713 .67154 .49638 .66886 .49123 .66397 Mtetra
.664 .752 .916 r
.49123 .66397 .49638 .66886 .50565 .66614 .50053 .66113 Mtetra
.669 .749 .911 r
.50053 .66113 .50565 .66614 .51496 .66335 .50986 .65818 Mtetra
.673 .745 .905 r
.50986 .65818 .51496 .66335 .5243 .66049 .51922 .6551 Mtetra
.679 .739 .896 r
.51922 .6551 .5243 .66049 .53367 .65755 .52861 .65185 Mtetra
.683 .73 .886 r
.52861 .65185 .53367 .65755 .54307 .65453 .53803 .64846 Mtetra
.686 .719 .874 r
.53803 .64846 .54307 .65453 .5525 .65142 .54747 .64491 Mtetra
.687 .706 .862 r
.54747 .64491 .5525 .65142 .56196 .64826 .55694 .64127 Mtetra
.686 .693 .851 r
.55694 .64127 .56196 .64826 .57145 .64507 .56644 .63757 Mtetra
.682 .678 .84 r
.56644 .63757 .57145 .64507 .58097 .64189 .57597 .6339 Mtetra
.676 .665 .832 r
.57597 .6339 .58097 .64189 .59052 .63877 .58553 .63037 Mtetra
.668 .653 .826 r
.58553 .63037 .59052 .63877 .6001 .63575 .59512 .62706 Mtetra
.659 .643 .823 r
.59512 .62706 .6001 .63575 .60972 .63288 .60475 .62404 Mtetra
.65 .636 .823 r
.60475 .62404 .60972 .63288 .61938 .63016 .61442 .62134 Mtetra
.642 .634 .827 r
.61442 .62134 .61938 .63016 .62907 .62757 .62413 .61894 Mtetra
.636 .636 .833 r
.62413 .61894 .62907 .62757 .6388 .62508 .63388 .61673 Mtetra
.635 .642 .84 r
.63388 .61673 .6388 .62508 .64857 .62262 .64367 .61459 Mtetra
.638 .652 .847 r
.64367 .61459 .64857 .62262 .65837 .6201 .6535 .61233 Mtetra
.645 .662 .852 r
.6535 .61233 .65837 .6201 .66821 .61746 .66336 .60985 Mtetra
.655 .671 .853 r
.66336 .60985 .66821 .61746 .67807 .61466 .67323 .60703 Mtetra
.665 .674 .849 r
.67323 .60703 .67807 .61466 .68796 .61171 .68313 .60388 Mtetra
.67 .672 .843 r
.68313 .60388 .68796 .61171 .69787 .60863 .69305 .6005 Mtetra
.672 .666 .836 r
.69305 .6005 .69787 .60863 .70782 .6055 .703 .597 Mtetra
.668 .657 .829 r
.703 .597 .70782 .6055 .71781 .60239 .71298 .59357 Mtetra
.662 .647 .825 r
.71298 .59357 .71781 .60239 .72783 .59938 .72301 .59032 Mtetra
.653 .639 .823 r
.72301 .59032 .72783 .59938 .7379 .59651 .73308 .58738 Mtetra
.644 .634 .825 r
.73308 .58738 .7379 .59651 .74801 .59378 .74322 .58476 Mtetra
.636 .633 .83 r
.74322 .58476 .74801 .59378 .75817 .5912 .75341 .58244 Mtetra
.63 .636 .838 r
.75341 .58244 .75817 .5912 .76838 .58873 .76366 .58035 Mtetra
.626 .644 .848 r
.76366 .58035 .76838 .58873 .77863 .58632 .77396 .57839 Mtetra
.624 .655 .859 r
.77396 .57839 .77863 .58632 .78892 .58393 .78431 .57648 Mtetra
.625 .669 .872 r
.78431 .57648 .78892 .58393 .79925 .5815 .79469 .5745 Mtetra
.628 .684 .884 r
.79469 .5745 .79925 .5815 .80961 .57902 .80512 .57243 Mtetra
.632 .7 .894 r
.80512 .57243 .80961 .57902 .82001 .57645 .81557 .57021 Mtetra
.636 .714 .903 r
.81557 .57021 .82001 .57645 .83045 .5738 .82605 .56783 Mtetra
.641 .726 .91 r
.82605 .56783 .83045 .5738 .84091 .57107 .83656 .56529 Mtetra
.645 .736 .915 r
.83656 .56529 .84091 .57107 .85141 .56826 .8471 .56261 Mtetra
.648 .743 .919 r
.8471 .56261 .85141 .56826 .86194 .56538 .85767 .55981 Mtetra
.651 .748 .921 r
.85767 .55981 .86194 .56538 .87251 .56245 .86827 .55692 Mtetra
.653 .751 .922 r
.86827 .55692 .87251 .56245 .88311 .55948 .8789 .55397 Mtetra
.655 .753 .922 r
.8789 .55397 .88311 .55948 .89374 .55648 .88956 .55096 Mtetra
.656 .754 .922 r
.88956 .55096 .89374 .55648 .90442 .55345 .90027 .54791 Mtetra
.90027 .54791 .90442 .55345 .91513 .55041 .91101 .54484 Mtetra
.91101 .54484 .91513 .55041 .92588 .54736 .92179 .54176 Mtetra
.92179 .54176 .92588 .54736 .93667 .54429 .93261 .53866 Mtetra
.656 .753 .921 r
.93261 .53866 .93667 .54429 .94751 .54121 .94347 .53555 Mtetra
.94347 .53555 .94751 .54121 .95838 .53812 .95436 .53243 Mtetra
.656 .752 .921 r
.95436 .53243 .95838 .53812 .96929 .53503 .9653 .5293 Mtetra
.656 .752 .92 r
.9653 .5293 .96929 .53503 .98024 .53192 .97628 .52616 Mtetra
.655 .751 .921 r
.38561 .68781 .391 .69252 .39996 .68999 .39458 .68528 Mtetra
.654 .752 .921 r
.39458 .68528 .39996 .68999 .40895 .68746 .40359 .68274 Mtetra
.654 .752 .922 r
.40359 .68274 .40895 .68746 .41797 .68491 .41263 .68019 Mtetra
.41263 .68019 .41797 .68491 .42702 .68236 .4217 .67763 Mtetra
.654 .753 .922 r
.4217 .67763 .42702 .68236 .4361 .6798 .4308 .67507 Mtetra
.654 .753 .923 r
.4308 .67507 .4361 .6798 .44521 .67723 .43993 .67249 Mtetra
.655 .754 .923 r
.43993 .67249 .44521 .67723 .45435 .67465 .44909 .6699 Mtetra
.656 .754 .922 r
.44909 .6699 .45435 .67465 .46352 .67204 .45828 .66727 Mtetra
.657 .754 .922 r
.45828 .66727 .46352 .67204 .47273 .66941 .4675 .6646 Mtetra
.66 .754 .92 r
.4675 .6646 .47273 .66941 .48196 .66672 .47676 .66186 Mtetra
.663 .754 .918 r
.47676 .66186 .48196 .66672 .49123 .66397 .48605 .65904 Mtetra
.668 .753 .914 r
.48605 .65904 .49123 .66397 .50053 .66113 .49537 .65608 Mtetra
.674 .75 .908 r
.49537 .65608 .50053 .66113 .50986 .65818 .50472 .65297 Mtetra
.681 .747 .901 r
.50472 .65297 .50986 .65818 .51922 .6551 .5141 .64966 Mtetra
.688 .741 .892 r
.5141 .64966 .51922 .6551 .52861 .65185 .52351 .64613 Mtetra
.694 .733 .881 r
.52351 .64613 .52861 .65185 .53803 .64846 .53295 .64238 Mtetra
.698 .724 .869 r
.53295 .64238 .53803 .64846 .54747 .64491 .54241 .63842 Mtetra
.7 .712 .858 r
.54241 .63842 .54747 .64491 .55694 .64127 .5519 .63432 Mtetra
.698 .699 .847 r
.5519 .63432 .55694 .64127 .56644 .63757 .56141 .63015 Mtetra
.693 .686 .838 r
.56141 .63015 .56644 .63757 .57597 .6339 .57095 .62604 Mtetra
.686 .672 .831 r
.57095 .62604 .57597 .6339 .58553 .63037 .58052 .62213 Mtetra
.675 .66 .828 r
.58052 .62213 .58553 .63037 .59512 .62706 .59012 .61856 Mtetra
.662 .649 .827 r
.59012 .61856 .59512 .62706 .60475 .62404 .59976 .61545 Mtetra
.648 .642 .83 r
.59976 .61545 .60475 .62404 .61442 .62134 .60944 .61282 Mtetra
.635 .638 .836 r
.60944 .61282 .61442 .62134 .62413 .61894 .61917 .61066 Mtetra
.626 .64 .845 r
.61917 .61066 .62413 .61894 .63388 .61673 .62895 .60878 Mtetra
.622 .648 .854 r
.62895 .60878 .63388 .61673 .64367 .61459 .63877 .60702 Mtetra
.628 .66 .862 r
.63877 .60702 .64367 .61459 .6535 .61233 .64862 .60507 Mtetra
.64 .674 .867 r
.64862 .60507 .6535 .61233 .66336 .60985 .6585 .60275 Mtetra
.657 .687 .866 r
.6585 .60275 .66336 .60985 .67323 .60703 .6684 .59992 Mtetra
.672 .693 .861 r
.6684 .59992 .67323 .60703 .68313 .60388 .67831 .59656 Mtetra
.682 .691 .852 r
.67831 .59656 .68313 .60388 .69305 .6005 .68823 .59283 Mtetra
.685 .684 .843 r
.68823 .59283 .69305 .6005 .703 .597 .69817 .58891 Mtetra
.679 .672 .835 r
.69817 .58891 .703 .597 .71298 .59357 .70815 .5851 Mtetra
.67 .659 .831 r
.70815 .5851 .71298 .59357 .72301 .59032 .71818 .58157 Mtetra
.657 .648 .829 r
.71818 .58157 .72301 .59032 .73308 .58738 .72827 .57852 Mtetra
.643 .64 .832 r
.72827 .57852 .73308 .58738 .74322 .58476 .73842 .57595 Mtetra
.63 .635 .837 r
.73842 .57595 .74322 .58476 .75341 .58244 .74864 .57384 Mtetra
.62 .636 .845 r
.74864 .57384 .75341 .58244 .76366 .58035 .75893 .57209 Mtetra
.613 .641 .855 r
.75893 .57209 .76366 .58035 .77396 .57839 .76928 .57054 Mtetra
.609 .651 .866 r
.76928 .57054 .77396 .57839 .78431 .57648 .77968 .56907 Mtetra
.61 .664 .878 r
.77968 .56907 .78431 .57648 .79469 .5745 .79012 .56752 Mtetra
.613 .679 .889 r
.79012 .56752 .79469 .5745 .80512 .57243 .80059 .56583 Mtetra
.619 .695 .898 r
.80059 .56583 .80512 .57243 .81557 .57021 .8111 .56393 Mtetra
.626 .71 .906 r
.8111 .56393 .81557 .57021 .82605 .56783 .82163 .56181 Mtetra
.633 .723 .912 r
.82163 .56181 .82605 .56783 .83656 .56529 .83218 .55946 Mtetra
.639 .733 .916 r
.83218 .55946 .83656 .56529 .8471 .56261 .84276 .55691 Mtetra
.644 .741 .919 r
.84276 .55691 .8471 .56261 .85767 .55981 .85336 .5542 Mtetra
.649 .747 .921 r
.85336 .5542 .85767 .55981 .86827 .55692 .864 .55135 Mtetra
.652 .75 .922 r
.864 .55135 .86827 .55692 .8789 .55397 .87466 .54841 Mtetra
.654 .753 .922 r
.87466 .54841 .8789 .55397 .88956 .55096 .88536 .5454 Mtetra
.655 .754 .922 r
.88536 .5454 .88956 .55096 .90027 .54791 .89609 .54234 Mtetra
.656 .754 .922 r
.89609 .54234 .90027 .54791 .91101 .54484 .90686 .53924 Mtetra
.657 .754 .922 r
.90686 .53924 .91101 .54484 .92179 .54176 .91767 .53613 Mtetra
.91767 .53613 .92179 .54176 .93261 .53866 .92851 .533 Mtetra
.657 .754 .921 r
.92851 .533 .93261 .53866 .94347 .53555 .9394 .52986 Mtetra
.657 .753 .921 r
.9394 .52986 .94347 .53555 .95436 .53243 .95033 .52671 Mtetra
.95033 .52671 .95436 .53243 .9653 .5293 .96129 .52354 Mtetra
.657 .752 .92 r
.96129 .52354 .9653 .5293 .97628 .52616 .9723 .52037 Mtetra
.654 .751 .921 r
.38018 .68308 .38561 .68781 .39458 .68528 .38917 .68054 Mtetra
.654 .751 .922 r
.38917 .68054 .39458 .68528 .40359 .68274 .3982 .678 Mtetra
.654 .752 .922 r
.3982 .678 .40359 .68274 .41263 .68019 .40726 .67545 Mtetra
.654 .753 .922 r
.40726 .67545 .41263 .68019 .4217 .67763 .41634 .67289 Mtetra
.654 .753 .923 r
.41634 .67289 .4217 .67763 .4308 .67507 .42546 .67032 Mtetra
.654 .754 .923 r
.42546 .67032 .4308 .67507 .43993 .67249 .43461 .66773 Mtetra
.655 .754 .923 r
.43461 .66773 .43993 .67249 .44909 .6699 .44379 .66512 Mtetra
.656 .754 .922 r
.44379 .66512 .44909 .6699 .45828 .66727 .453 .66247 Mtetra
.658 .755 .921 r
.453 .66247 .45828 .66727 .4675 .6646 .46225 .65976 Mtetra
.662 .755 .919 r
.46225 .65976 .4675 .6646 .47676 .66186 .47153 .65697 Mtetra
.666 .754 .916 r
.47153 .65697 .47676 .66186 .48605 .65904 .48084 .65405 Mtetra
.672 .753 .911 r
.48084 .65405 .48605 .65904 .49537 .65608 .49018 .65098 Mtetra
.68 .751 .905 r
.49018 .65098 .49537 .65608 .50472 .65297 .49955 .6477 Mtetra
.688 .748 .897 r
.49955 .6477 .50472 .65297 .5141 .64966 .50896 .64418 Mtetra
.696 .743 .887 r
.50896 .64418 .5141 .64966 .52351 .64613 .51839 .64038 Mtetra
.703 .736 .877 r
.51839 .64038 .52351 .64613 .53295 .64238 .52785 .63631 Mtetra
.709 .727 .865 r
.52785 .63631 .53295 .64238 .54241 .63842 .53733 .63197 Mtetra
.71 .717 .854 r
.53733 .63197 .54241 .63842 .5519 .63432 .54683 .62747 Mtetra
.709 .706 .845 r
.54683 .62747 .5519 .63432 .56141 .63015 .55636 .62287 Mtetra
.704 .694 .838 r
.55636 .62287 .56141 .63015 .57095 .62604 .56591 .61839 Mtetra
.694 .682 .833 r
.56591 .61839 .57095 .62604 .58052 .62213 .57549 .61417 Mtetra
.681 .67 .833 r
.57549 .61417 .58052 .62213 .59012 .61856 .5851 .61043 Mtetra
.663 .659 .835 r
.5851 .61043 .59012 .61856 .59976 .61545 .59476 .60729 Mtetra
.645 .651 .842 r
.59476 .60729 .59976 .61545 .60944 .61282 .60446 .6048 Mtetra
.625 .647 .851 r
.60446 .6048 .60944 .61282 .61917 .61066 .61421 .60294 Mtetra
.612 .649 .863 r
.61421 .60294 .61917 .61066 .62895 .60878 .62401 .60147 Mtetra
.605 .658 .876 r
.62401 .60147 .62895 .60878 .63877 .60702 .63386 .60014 Mtetra
.613 .676 .886 r
.63386 .60014 .63877 .60702 .64862 .60507 .64375 .59855 Mtetra
.631 .695 .891 r
.64375 .59855 .64862 .60507 .6585 .60275 .65366 .59644 Mtetra
.658 .712 .888 r
.65366 .59644 .6585 .60275 .6684 .59992 .66357 .59358 Mtetra
.682 .721 .879 r
.66357 .59358 .6684 .59992 .67831 .59656 .67349 .58998 Mtetra
.696 .719 .867 r
.67349 .58998 .67831 .59656 .68823 .59283 .68342 .58585 Mtetra
.701 .709 .854 r
.68342 .58585 .68823 .59283 .69817 .58891 .69336 .58145 Mtetra
.694 .694 .846 r
.69336 .58145 .69817 .58891 .70815 .5851 .70334 .57719 Mtetra
.682 .678 .84 r
.70334 .57719 .70815 .5851 .71818 .58157 .71336 .57332 Mtetra
.663 .663 .839 r
.71336 .57332 .71818 .58157 .72827 .57852 .72346 .57007 Mtetra
.644 .651 .842 r
.72346 .57007 .72827 .57852 .73842 .57595 .73362 .56749 Mtetra
.626 .642 .847 r
.73362 .56749 .73842 .57595 .74864 .57384 .74387 .56553 Mtetra
.61 .639 .855 r
.74387 .56553 .74864 .57384 .75893 .57209 .75419 .56404 Mtetra
.6 .642 .864 r
.75419 .56404 .75893 .57209 .76928 .57054 .76458 .56284 Mtetra
.594 .649 .874 r
.76458 .56284 .76928 .57054 .77968 .56907 .77503 .56175 Mtetra
.595 .661 .884 r
.77503 .56175 .77968 .56907 .79012 .56752 .78552 .56057 Mtetra
.599 .675 .894 r
.78552 .56057 .79012 .56752 .80059 .56583 .79604 .55923 Mtetra
.607 .691 .902 r
.79604 .55923 .80059 .56583 .8111 .56393 .8066 .55762 Mtetra
.615 .705 .909 r
.8066 .55762 .8111 .56393 .82163 .56181 .81717 .55574 Mtetra
.625 .719 .914 r
.81717 .55574 .82163 .56181 .83218 .55946 .82777 .55357 Mtetra
.633 .73 .918 r
.82777 .55357 .83218 .55946 .84276 .55691 .83839 .55115 Mtetra
.64 .738 .92 r
.83839 .55115 .84276 .55691 .85336 .5542 .84903 .54853 Mtetra
.646 .745 .921 r
.84903 .54853 .85336 .5542 .864 .55135 .8597 .54573 Mtetra
.65 .749 .922 r
.8597 .54573 .864 .55135 .87466 .54841 .87039 .54281 Mtetra
.653 .752 .922 r
.87039 .54281 .87466 .54841 .88536 .5454 .88112 .5398 Mtetra
.655 .754 .922 r
.88112 .5398 .88536 .5454 .89609 .54234 .89188 .53673 Mtetra
.656 .755 .922 r
.89188 .53673 .89609 .54234 .90686 .53924 .90268 .53361 Mtetra
.657 .755 .922 r
.90268 .53361 .90686 .53924 .91767 .53613 .91352 .53047 Mtetra
.91352 .53047 .91767 .53613 .92851 .533 .92439 .52731 Mtetra
.657 .754 .921 r
.92439 .52731 .92851 .533 .9394 .52986 .93531 .52413 Mtetra
.93531 .52413 .9394 .52986 .95033 .52671 .94626 .52095 Mtetra
.657 .753 .921 r
.94626 .52095 .95033 .52671 .96129 .52354 .95726 .51775 Mtetra
.657 .753 .92 r
.95726 .51775 .96129 .52354 .9723 .52037 .96829 .51454 Mtetra
.653 .751 .921 r
.37472 .67831 .38018 .68308 .38917 .68054 .38373 .67578 Mtetra
.653 .751 .922 r
.38373 .67578 .38917 .68054 .3982 .678 .39277 .67324 Mtetra
.653 .752 .923 r
.39277 .67324 .3982 .678 .40726 .67545 .40185 .67069 Mtetra
.653 .753 .923 r
.40185 .67069 .40726 .67545 .41634 .67289 .41096 .66812 Mtetra
.41096 .66812 .41634 .67289 .42546 .67032 .42009 .66555 Mtetra
.654 .754 .923 r
.42009 .66555 .42546 .67032 .43461 .66773 .42926 .66295 Mtetra
.655 .755 .923 r
.42926 .66295 .43461 .66773 .44379 .66512 .43846 .66032 Mtetra
.657 .755 .922 r
.43846 .66032 .44379 .66512 .453 .66247 .4477 .65764 Mtetra
.659 .755 .921 r
.4477 .65764 .453 .66247 .46225 .65976 .45696 .65488 Mtetra
.664 .755 .918 r
.45696 .65488 .46225 .65976 .47153 .65697 .46626 .65202 Mtetra
.669 .754 .914 r
.46626 .65202 .47153 .65697 .48084 .65405 .47559 .64901 Mtetra
.677 .753 .909 r
.47559 .64901 .48084 .65405 .49018 .65098 .48496 .64581 Mtetra
.685 .751 .902 r
.48496 .64581 .49018 .65098 .49955 .6477 .49435 .64237 Mtetra
.694 .748 .893 r
.49435 .64237 .49955 .6477 .50896 .64418 .50378 .63864 Mtetra
.703 .744 .883 r
.50378 .63864 .50896 .64418 .51839 .64038 .51323 .6346 Mtetra
.711 .738 .872 r
.51323 .6346 .51839 .64038 .52785 .63631 .52271 .63024 Mtetra
.717 .731 .862 r
.52271 .63024 .52785 .63631 .53733 .63197 .53221 .62558 Mtetra
.719 .723 .852 r
.53221 .62558 .53733 .63197 .54683 .62747 .54174 .62074 Mtetra
.718 .713 .845 r
.54174 .62074 .54683 .62747 .55636 .62287 .55128 .61582 Mtetra
.712 .703 .84 r
.55128 .61582 .55636 .62287 .56591 .61839 .56085 .61105 Mtetra
.701 .693 .839 r
.56085 .61105 .56591 .61839 .57549 .61417 .57044 .60662 Mtetra
.685 .682 .841 r
.57044 .60662 .57549 .61417 .5851 .61043 .58007 .60279 Mtetra
.663 .672 .848 r
.58007 .60279 .5851 .61043 .59476 .60729 .58974 .59971 Mtetra
.638 .664 .859 r
.58974 .59971 .59476 .60729 .60446 .6048 .59947 .59747 Mtetra
.609 .66 .874 r
.59947 .59747 .60446 .6048 .61421 .60294 .60924 .59601 Mtetra
.588 .663 .89 r
.60924 .59601 .61421 .60294 .62401 .60147 .61908 .59503 Mtetra
.575 .675 .907 r
.61908 .59503 .62401 .60147 .63386 .60014 .62896 .59423 Mtetra
.586 .699 .92 r
.62896 .59423 .63386 .60014 .64375 .59855 .63888 .59307 Mtetra
.615 .727 .926 r
.63888 .59307 .64375 .59855 .65366 .59644 .64882 .59119 Mtetra
.656 .752 .92 r
.64882 .59119 .65366 .59644 .66357 .59358 .65876 .58832 Mtetra
.694 .764 .905 r
.65876 .58832 .66357 .59358 .67349 .58998 .6687 .58444 Mtetra
.715 .76 .888 r
.6687 .58444 .67349 .58998 .68342 .58585 .67863 .57985 Mtetra
.723 .747 .871 r
.67863 .57985 .68342 .58585 .69336 .58145 .68857 .57488 Mtetra
.714 .727 .861 r
.68857 .57488 .69336 .58145 .70334 .57719 .69854 .57007 Mtetra
.697 .706 .854 r
.69854 .57007 .70334 .57719 .71336 .57332 .70856 .56576 Mtetra
.673 .686 .854 r
.70856 .56576 .71336 .57332 .72346 .57007 .71866 .56223 Mtetra
.648 .668 .856 r
.71866 .56223 .72346 .57007 .73362 .56749 .72884 .55954 Mtetra
.623 .655 .861 r
.72884 .55954 .73362 .56749 .74387 .56553 .73911 .55762 Mtetra
.602 .647 .867 r
.73911 .55762 .74387 .56553 .75419 .56404 .74946 .55631 Mtetra
.588 .646 .875 r
.74946 .55631 .75419 .56404 .76458 .56284 .75988 .55535 Mtetra
.58 .65 .884 r
.75988 .55535 .76458 .56284 .77503 .56175 .77037 .55456 Mtetra
.581 .66 .892 r
.77037 .55456 .77503 .56175 .78552 .56057 .7809 .55369 Mtetra
.585 .672 .9 r
.7809 .55369 .78552 .56057 .79604 .55923 .79147 .55263 Mtetra
.595 .687 .906 r
.79147 .55263 .79604 .55923 .8066 .55762 .80207 .55128 Mtetra
.606 .701 .911 r
.80207 .55128 .8066 .55762 .81717 .55574 .81269 .54961 Mtetra
.617 .715 .915 r
.81269 .54961 .81717 .55574 .82777 .55357 .82333 .54761 Mtetra
.627 .726 .918 r
.82333 .54761 .82777 .55357 .83839 .55115 .83398 .54532 Mtetra
.636 .735 .92 r
.83398 .54532 .83839 .55115 .84903 .54853 .84466 .54279 Mtetra
.643 .743 .921 r
.84466 .54279 .84903 .54853 .8597 .54573 .85536 .54005 Mtetra
.648 .748 .922 r
.85536 .54005 .8597 .54573 .87039 .54281 .8661 .53717 Mtetra
.652 .751 .922 r
.8661 .53717 .87039 .54281 .88112 .5398 .87685 .53417 Mtetra
.654 .754 .923 r
.87685 .53417 .88112 .5398 .89188 .53673 .88765 .53109 Mtetra
.656 .755 .923 r
.88765 .53109 .89188 .53673 .90268 .53361 .89848 .52796 Mtetra
.657 .755 .922 r
.89848 .52796 .90268 .53361 .91352 .53047 .90934 .52479 Mtetra
.658 .755 .922 r
.90934 .52479 .91352 .53047 .92439 .52731 .92025 .52159 Mtetra
.92025 .52159 .92439 .52731 .93531 .52413 .93119 .51838 Mtetra
.658 .755 .921 r
.93119 .51838 .93531 .52413 .94626 .52095 .94217 .51515 Mtetra
.658 .754 .921 r
.94217 .51515 .94626 .52095 .95726 .51775 .95319 .51191 Mtetra
.658 .753 .92 r
.95319 .51191 .95726 .51775 .96829 .51454 .96426 .50866 Mtetra
.652 .751 .922 r
.36922 .67351 .37472 .67831 .38373 .67578 .37825 .67099 Mtetra
.652 .751 .923 r
.37825 .67099 .38373 .67578 .39277 .67324 .38732 .66845 Mtetra
.652 .752 .923 r
.38732 .66845 .39277 .67324 .40185 .67069 .39641 .6659 Mtetra
.652 .753 .924 r
.39641 .6659 .40185 .67069 .41096 .66812 .40553 .66334 Mtetra
.652 .754 .924 r
.40553 .66334 .41096 .66812 .42009 .66555 .41469 .66077 Mtetra
.653 .755 .924 r
.41469 .66077 .42009 .66555 .42926 .66295 .42388 .65816 Mtetra
.655 .755 .924 r
.42388 .65816 .42926 .66295 .43846 .66032 .4331 .65551 Mtetra
.657 .756 .922 r
.4331 .65551 .43846 .66032 .4477 .65764 .44235 .65279 Mtetra
.661 .756 .921 r
.44235 .65279 .4477 .65764 .45696 .65488 .45164 .64998 Mtetra
.666 .756 .917 r
.45164 .64998 .45696 .65488 .46626 .65202 .46096 .64704 Mtetra
.673 .755 .913 r
.46096 .64704 .46626 .65202 .47559 .64901 .47032 .64393 Mtetra
.681 .754 .907 r
.47032 .64393 .47559 .64901 .48496 .64581 .4797 .6406 Mtetra
.69 .752 .899 r
.4797 .6406 .48496 .64581 .49435 .64237 .48912 .63699 Mtetra
.7 .749 .89 r
.48912 .63699 .49435 .64237 .50378 .63864 .49857 .63307 Mtetra
.71 .745 .88 r
.49857 .63307 .50378 .63864 .51323 .6346 .50805 .6288 Mtetra
.717 .74 .869 r
.50805 .6288 .51323 .6346 .52271 .63024 .51755 .62419 Mtetra
.724 .734 .86 r
.51755 .62419 .52271 .63024 .53221 .62558 .52707 .61927 Mtetra
.726 .728 .852 r
.52707 .61927 .53221 .62558 .54174 .62074 .53662 .61418 Mtetra
.725 .721 .846 r
.53662 .61418 .54174 .62074 .55128 .61582 .54618 .60903 Mtetra
.718 .713 .845 r
.54618 .60903 .55128 .61582 .56085 .61105 .55577 .60409 Mtetra
.706 .705 .847 r
.55577 .60409 .56085 .61105 .57044 .60662 .56538 .59958 Mtetra
.686 .697 .855 r
.56538 .59958 .57044 .60662 .58007 .60279 .57503 .59579 Mtetra
.659 .689 .867 r
.57503 .59579 .58007 .60279 .58974 .59971 .58472 .5929 Mtetra
.625 .682 .884 r
.58472 .5929 .58974 .59971 .59947 .59747 .59447 .59098 Mtetra
.583 .677 .904 r
.59447 .59098 .59947 .59747 .60924 .59601 .60427 .59 Mtetra
.548 .68 .925 r
.60427 .59 .60924 .59601 .61908 .59503 .61414 .5896 Mtetra
.525 .693 .945 r
.61414 .5896 .61908 .59503 .62896 .59423 .62406 .58939 Mtetra
.539 .725 .96 r
.62406 .58939 .62896 .59423 .63888 .59307 .63402 .58869 Mtetra
.583 .764 .965 r
.63402 .58869 .63888 .59307 .64882 .59119 .64399 .58709 Mtetra
.648 .799 .955 r
.64399 .58709 .64882 .59119 .65876 .58832 .65396 .58419 Mtetra
.705 .814 .933 r
.65396 .58419 .65876 .58832 .6687 .58444 .66391 .58001 Mtetra
.736 .809 .909 r
.66391 .58001 .6687 .58444 .67863 .57985 .67385 .57491 Mtetra
.748 .792 .889 r
.67385 .57491 .67863 .57985 .68857 .57488 .68379 .56931 Mtetra
.738 .768 .877 r
.68379 .56931 .68857 .57488 .69854 .57007 .69376 .56389 Mtetra
.717 .742 .871 r
.69376 .56389 .69854 .57007 .70856 .56576 .70378 .55905 Mtetra
.688 .717 .871 r
.70378 .55905 .70856 .56576 .71866 .56223 .71388 .55515 Mtetra
.656 .694 .874 r
.71388 .55515 .71866 .56223 .72884 .55954 .72407 .55223 Mtetra
.624 .675 .878 r
.72407 .55223 .72884 .55954 .73911 .55762 .73435 .55023 Mtetra
.598 .661 .883 r
.73435 .55023 .73911 .55762 .74946 .55631 .74472 .54896 Mtetra
.58 .655 .888 r
.74472 .54896 .74946 .55631 .75988 .55535 .75518 .54814 Mtetra
.569 .655 .894 r
.75518 .54814 .75988 .55535 .77037 .55456 .7657 .54753 Mtetra
.569 .661 .899 r
.7657 .54753 .77037 .55456 .7809 .55369 .77627 .54688 Mtetra
.574 .671 .905 r
.77627 .54688 .7809 .55369 .79147 .55263 .78688 .54605 Mtetra
.585 .684 .91 r
.78688 .54605 .79147 .55263 .80207 .55128 .79751 .54491 Mtetra
.597 .698 .914 r
.79751 .54491 .80207 .55128 .81269 .54961 .80817 .54344 Mtetra
.61 .711 .917 r
.80817 .54344 .81269 .54961 .82333 .54761 .81885 .5416 Mtetra
.621 .723 .919 r
.81885 .5416 .82333 .54761 .83398 .54532 .82955 .53945 Mtetra
.631 .733 .921 r
.82955 .53945 .83398 .54532 .84466 .54279 .84027 .53701 Mtetra
.64 .741 .922 r
.84027 .53701 .84466 .54279 .85536 .54005 .85101 .53434 Mtetra
.646 .747 .923 r
.85101 .53434 .85536 .54005 .8661 .53717 .86177 .5315 Mtetra
.651 .751 .923 r
.86177 .5315 .8661 .53717 .87685 .53417 .87256 .52851 Mtetra
.654 .754 .923 r
.87256 .52851 .87685 .53417 .88765 .53109 .88339 .52543 Mtetra
.656 .755 .923 r
.88339 .52543 .88765 .53109 .89848 .52796 .89424 .52228 Mtetra
.657 .756 .923 r
.89424 .52228 .89848 .52796 .90934 .52479 .90514 .51908 Mtetra
.658 .756 .922 r
.90514 .51908 .90934 .52479 .92025 .52159 .91607 .51585 Mtetra
.91607 .51585 .92025 .52159 .93119 .51838 .92704 .5126 Mtetra
.659 .755 .921 r
.92704 .5126 .93119 .51838 .94217 .51515 .93805 .50933 Mtetra
.659 .754 .921 r
.93805 .50933 .94217 .51515 .95319 .51191 .9491 .50605 Mtetra
.659 .754 .92 r
.9491 .50605 .95319 .51191 .96426 .50866 .9602 .50275 Mtetra
.651 .75 .922 r
.36369 .66869 .36922 .67351 .37825 .67099 .37274 .66617 Mtetra
.651 .751 .923 r
.37274 .66617 .37825 .67099 .38732 .66845 .38182 .66364 Mtetra
.651 .752 .924 r
.38182 .66364 .38732 .66845 .39641 .6659 .39093 .66111 Mtetra
.651 .753 .924 r
.39093 .66111 .39641 .6659 .40553 .66334 .40008 .65855 Mtetra
.652 .754 .925 r
.40008 .65855 .40553 .66334 .41469 .66077 .40925 .65597 Mtetra
.653 .755 .925 r
.40925 .65597 .41469 .66077 .42388 .65816 .41846 .65336 Mtetra
.655 .756 .924 r
.41846 .65336 .42388 .65816 .4331 .65551 .4277 .65069 Mtetra
.658 .757 .923 r
.4277 .65069 .4331 .65551 .44235 .65279 .43698 .64794 Mtetra
.662 .757 .921 r
.43698 .64794 .44235 .65279 .45164 .64998 .44628 .64507 Mtetra
.669 .757 .917 r
.44628 .64507 .45164 .64998 .46096 .64704 .45563 .64205 Mtetra
.676 .757 .912 r
.45563 .64205 .46096 .64704 .47032 .64393 .465 .63883 Mtetra
.685 .755 .905 r
.465 .63883 .47032 .64393 .4797 .6406 .47441 .63536 Mtetra
.695 .753 .896 r
.47441 .63536 .4797 .6406 .48912 .63699 .48386 .63158 Mtetra
.705 .75 .887 r
.48386 .63158 .48912 .63699 .49857 .63307 .49333 .62746 Mtetra
.715 .746 .877 r
.49333 .62746 .49857 .63307 .50805 .6288 .50283 .62298 Mtetra
.723 .742 .867 r
.50283 .62298 .50805 .6288 .51755 .62419 .51235 .61817 Mtetra
.728 .738 .859 r
.51235 .61817 .51755 .62419 .52707 .61927 .5219 .61307 Mtetra
.73 .733 .853 r
.5219 .61307 .52707 .61927 .53662 .61418 .53147 .60783 Mtetra
.729 .729 .85 r
.53147 .60783 .53662 .61418 .54618 .60903 .54105 .60259 Mtetra
.721 .725 .853 r
.54105 .60259 .54618 .60903 .55577 .60409 .55066 .59763 Mtetra
.707 .721 .86 r
.55066 .59763 .55577 .60409 .56538 .59958 .5603 .5932 Mtetra
.683 .717 .874 r
.5603 .5932 .56538 .59958 .57503 .59579 .56997 .58959 Mtetra
.648 .712 .894 r
.56997 .58959 .57503 .59579 .58472 .5929 .57968 .58701 Mtetra
.6 .706 .918 r
.57968 .58701 .58472 .5929 .59447 .59098 .58946 .58555 Mtetra
.536 .698 .944 r
.58946 .58555 .59447 .59098 .60427 .59 .5993 .58513 Mtetra
.475 .696 .965 r
.5993 .58513 .60427 .59 .61414 .5896 .6092 .58536 Mtetra
.428 .705 .98 r
.6092 .58536 .61414 .5896 .62406 .58939 .61917 .5858 Mtetra
.444 .745 .992 r
.61917 .5858 .62406 .58939 .63402 .58869 .62917 .58563 Mtetra
.512 .801 .998 r
.62917 .58563 .63402 .58869 .64399 .58709 .63918 .58432 Mtetra
.618 .855 .988 r
.63918 .58432 .64399 .58709 .65396 .58419 .64918 .58141 Mtetra
.708 .878 .96 r
.64918 .58141 .65396 .58419 .66391 .58001 .65915 .57689 Mtetra
.757 .871 .931 r
.65915 .57689 .66391 .58001 .67385 .57491 .6691 .57123 Mtetra
.775 .849 .907 r
.6691 .57123 .67385 .57491 .68379 .56931 .67904 .56495 Mtetra
.765 .82 .896 r
.67904 .56495 .68379 .56931 .69376 .56389 .68901 .55885 Mtetra
.742 .79 .891 r
.68901 .55885 .69376 .56389 .70378 .55905 .69903 .55341 Mtetra
.707 .759 .893 r
.69903 .55341 .70378 .55905 .71388 .55515 .70913 .54901 Mtetra
.668 .73 .896 r
.70913 .54901 .71388 .55515 .72407 .55223 .71932 .54574 Mtetra
.63 .704 .899 r
.71932 .54574 .72407 .55223 .73435 .55023 .72961 .54351 Mtetra
.597 .683 .901 r
.72961 .54351 .73435 .55023 .74472 .54896 .74 .54212 Mtetra
.575 .67 .903 r
.74 .54212 .74472 .54896 .75518 .54814 .75047 .54127 Mtetra
.562 .664 .905 r
.75047 .54127 .75518 .54814 .7657 .54753 .76102 .54071 Mtetra
.561 .665 .907 r
.76102 .54071 .7657 .54753 .77627 .54688 .77161 .54017 Mtetra
.565 .672 .91 r
.77161 .54017 .77627 .54688 .78688 .54605 .78226 .5395 Mtetra
.576 .683 .913 r
.78226 .5395 .78688 .54605 .79751 .54491 .79293 .53853 Mtetra
.588 .695 .916 r
.79293 .53853 .79751 .54491 .80817 .54344 .80363 .53722 Mtetra
.602 .708 .919 r
.80363 .53722 .80817 .54344 .81885 .5416 .81435 .53555 Mtetra
.615 .72 .921 r
.81435 .53555 .81885 .5416 .82955 .53945 .82509 .53353 Mtetra
.626 .731 .922 r
.82509 .53353 .82955 .53945 .84027 .53701 .83584 .5312 Mtetra
.636 .74 .923 r
.83584 .5312 .84027 .53701 .85101 .53434 .84662 .52861 Mtetra
.643 .746 .924 r
.84662 .52861 .85101 .53434 .86177 .5315 .85742 .52581 Mtetra
.649 .751 .924 r
.85742 .52581 .86177 .5315 .87256 .52851 .86824 .52284 Mtetra
.653 .754 .924 r
.86824 .52284 .87256 .52851 .88339 .52543 .8791 .51976 Mtetra
.656 .756 .924 r
.8791 .51976 .88339 .52543 .89424 .52228 .88999 .51659 Mtetra
.657 .757 .923 r
.88999 .51659 .89424 .52228 .90514 .51908 .90091 .51336 Mtetra
.659 .757 .923 r
.90091 .51336 .90514 .51908 .91607 .51585 .91187 .51009 Mtetra
.659 .757 .922 r
.91187 .51009 .91607 .51585 .92704 .5126 .92287 .50679 Mtetra
.66 .756 .921 r
.92287 .50679 .92704 .5126 .93805 .50933 .93391 .50347 Mtetra
.66 .755 .921 r
.93391 .50347 .93805 .50933 .9491 .50605 .94498 .50014 Mtetra
.66 .754 .92 r
.94498 .50014 .9491 .50605 .9602 .50275 .9561 .4968 Mtetra
.65 .75 .923 r
.35813 .66383 .36369 .66869 .37274 .66617 .36719 .66132 Mtetra
.649 .751 .924 r
.36719 .66132 .37274 .66617 .38182 .66364 .37629 .65881 Mtetra
.65 .752 .924 r
.37629 .65881 .38182 .66364 .39093 .66111 .38542 .65628 Mtetra
.65 .753 .925 r
.38542 .65628 .39093 .66111 .40008 .65855 .39458 .65373 Mtetra
.651 .754 .925 r
.39458 .65373 .40008 .65855 .40925 .65597 .40378 .65116 Mtetra
.652 .756 .925 r
.40378 .65116 .40925 .65597 .41846 .65336 .41301 .64854 Mtetra
.654 .757 .925 r
.41301 .64854 .41846 .65336 .4277 .65069 .42227 .64586 Mtetra
.658 .758 .923 r
.42227 .64586 .4277 .65069 .43698 .64794 .43156 .64308 Mtetra
.664 .759 .921 r
.43156 .64308 .43698 .64794 .44628 .64507 .44089 .64017 Mtetra
.671 .759 .917 r
.44089 .64017 .44628 .64507 .45563 .64205 .45026 .63707 Mtetra
.68 .759 .911 r
.45026 .63707 .45563 .64205 .465 .63883 .45966 .63374 Mtetra
.69 .758 .904 r
.45966 .63374 .465 .63883 .47441 .63536 .46909 .63013 Mtetra
.701 .756 .895 r
.46909 .63013 .47441 .63536 .48386 .63158 .47856 .62618 Mtetra
.711 .753 .885 r
.47856 .62618 .48386 .63158 .49333 .62746 .48806 .62187 Mtetra
.72 .749 .875 r
.48806 .62187 .49333 .62746 .50283 .62298 .49758 .6172 Mtetra
.727 .745 .866 r
.49758 .6172 .50283 .62298 .51235 .61817 .50713 .61221 Mtetra
.732 .741 .859 r
.50713 .61221 .51235 .61817 .5219 .61307 .5167 .60698 Mtetra
.732 .738 .856 r
.5167 .60698 .5219 .61307 .53147 .60783 .52629 .60168 Mtetra
.729 .736 .857 r
.52629 .60168 .53147 .60783 .54105 .60259 .5359 .59649 Mtetra
.72 .736 .864 r
.5359 .59649 .54105 .60259 .55066 .59763 .54553 .59168 Mtetra
.702 .737 .878 r
.54553 .59168 .55066 .59763 .5603 .5932 .55519 .58751 Mtetra
.672 .738 .9 r
.55519 .58751 .5603 .5932 .56997 .58959 .56489 .58427 Mtetra
.625 .737 .928 r
.56489 .58427 .56997 .58959 .57968 .58701 .57463 .58215 Mtetra
.554 .73 .957 r
.57463 .58215 .57968 .58701 .58946 .58555 .58444 .58121 Mtetra
.455 .713 .979 r
.58444 .58121 .58946 .58555 .5993 .58513 .59431 .58138 Mtetra
.353 .692 .982 r
.59431 .58138 .5993 .58513 .6092 .58536 .60426 .58224 Mtetra
.276 .68 .97 r
.60426 .58224 .6092 .58536 .61917 .5858 .61426 .58329 Mtetra
.301 .723 .973 r
.61426 .58329 .61917 .5858 .62917 .58563 .6243 .5836 Mtetra
.406 .802 .986 r
.6243 .5836 .62917 .58563 .63918 .58432 .63436 .58257 Mtetra
.569 .886 .99 r
.63436 .58257 .63918 .58432 .64918 .58141 .64439 .57965 Mtetra
.701 .923 .967 r
.64439 .57965 .64918 .58141 .65915 .57689 .65439 .57482 Mtetra
.769 .92 .937 r
.65439 .57482 .65915 .57689 .6691 .57123 .66436 .56864 Mtetra
.797 .899 .914 r
.66436 .56864 .6691 .57123 .67904 .56495 .67431 .5617 Mtetra
.79 .871 .908 r
.67431 .5617 .67904 .56495 .68901 .55885 .68429 .55494 Mtetra
.767 .841 .908 r
.68429 .55494 .68901 .55885 .69903 .55341 .69431 .54887 Mtetra
.729 .81 .914 r
.69431 .54887 .69903 .55341 .70913 .54901 .70441 .5439 Mtetra
.686 .776 .919 r
.70441 .5439 .70913 .54901 .71932 .54574 .7146 .54012 Mtetra
.642 .742 .922 r
.7146 .54012 .71932 .54574 .72961 .54351 .72489 .53749 Mtetra
.604 .712 .921 r
.72489 .53749 .72961 .54351 .74 .54212 .73528 .53579 Mtetra
.577 .69 .918 r
.73528 .53579 .74 .54212 .75047 .54127 .74576 .53475 Mtetra
.56 .676 .916 r
.74576 .53475 .75047 .54127 .76102 .54071 .75632 .53411 Mtetra
.556 .672 .915 r
.75632 .53411 .76102 .54071 .77161 .54017 .76695 .53358 Mtetra
.558 .674 .916 r
.76695 .53358 .77161 .54017 .78226 .5395 .77762 .533 Mtetra
.568 .682 .917 r
.77762 .533 .78226 .5395 .79293 .53853 .78833 .53216 Mtetra
.58 .693 .92 r
.78833 .53216 .79293 .53853 .80363 .53722 .79906 .53102 Mtetra
.594 .707 .922 r
.79906 .53102 .80363 .53722 .81435 .53555 .80982 .5295 Mtetra
.608 .719 .924 r
.80982 .5295 .81435 .53555 .82509 .53353 .8206 .52762 Mtetra
.621 .731 .925 r
.8206 .52762 .82509 .53353 .83584 .5312 .83139 .5254 Mtetra
.632 .74 .926 r
.83139 .5254 .83584 .5312 .84662 .52861 .8422 .52288 Mtetra
.64 .747 .926 r
.8422 .52288 .84662 .52861 .85742 .52581 .85304 .52012 Mtetra
.647 .752 .926 r
.85304 .52012 .85742 .52581 .86824 .52284 .8639 .51717 Mtetra
.652 .756 .925 r
.8639 .51717 .86824 .52284 .8791 .51976 .87478 .51407 Mtetra
.656 .757 .925 r
.87478 .51407 .8791 .51976 .88999 .51659 .8857 .51088 Mtetra
.658 .758 .924 r
.8857 .51088 .88999 .51659 .90091 .51336 .89665 .50761 Mtetra
.66 .758 .923 r
.89665 .50761 .90091 .51336 .91187 .51009 .90764 .50429 Mtetra
.66 .758 .922 r
.90764 .50429 .91187 .51009 .92287 .50679 .91867 .50095 Mtetra
.661 .757 .921 r
.91867 .50095 .92287 .50679 .93391 .50347 .92973 .49758 Mtetra
.661 .756 .92 r
.92973 .49758 .93391 .50347 .94498 .50014 .94084 .49419 Mtetra
.661 .755 .92 r
.94084 .49419 .94498 .50014 .9561 .4968 .95198 .4908 Mtetra
.649 .75 .923 r
.35253 .65894 .35813 .66383 .36719 .66132 .36161 .65644 Mtetra
.648 .751 .924 r
.36161 .65644 .36719 .66132 .37629 .65881 .37073 .65394 Mtetra
.648 .752 .925 r
.37073 .65394 .37629 .65881 .38542 .65628 .37988 .65142 Mtetra
.649 .753 .925 r
.37988 .65142 .38542 .65628 .39458 .65373 .38906 .64889 Mtetra
.649 .754 .926 r
.38906 .64889 .39458 .65373 .40378 .65116 .39827 .64633 Mtetra
.651 .756 .926 r
.39827 .64633 .40378 .65116 .41301 .64854 .40752 .64372 Mtetra
.654 .757 .926 r
.40752 .64372 .41301 .64854 .42227 .64586 .4168 .64104 Mtetra
.658 .759 .924 r
.4168 .64104 .42227 .64586 .43156 .64308 .42611 .63824 Mtetra
.664 .761 .922 r
.42611 .63824 .43156 .64308 .44089 .64017 .43547 .6353 Mtetra
.673 .762 .918 r
.43547 .6353 .44089 .64017 .45026 .63707 .44485 .63214 Mtetra
.683 .763 .912 r
.44485 .63214 .45026 .63707 .45966 .63374 .45428 .62871 Mtetra
.694 .762 .904 r
.45428 .62871 .45966 .63374 .46909 .63013 .46374 .62496 Mtetra
.706 .761 .895 r
.46374 .62496 .46909 .63013 .47856 .62618 .47323 .62083 Mtetra
.717 .757 .884 r
.47323 .62083 .47856 .62618 .48806 .62187 .48275 .61633 Mtetra
.726 .753 .874 r
.48275 .61633 .48806 .62187 .49758 .6172 .4923 .61147 Mtetra
.731 .749 .866 r
.4923 .61147 .49758 .6172 .50713 .61221 .50187 .60634 Mtetra
.734 .745 .861 r
.50187 .60634 .50713 .61221 .5167 .60698 .51146 .60103 Mtetra
.732 .743 .861 r
.51146 .60103 .5167 .60698 .52629 .60168 .52108 .59578 Mtetra
.726 .744 .866 r
.52108 .59578 .52629 .60168 .5359 .59649 .53071 .59078 Mtetra
.712 .748 .88 r
.53071 .59078 .5359 .59649 .54553 .59168 .54037 .58631 Mtetra
.688 .755 .902 r
.54037 .58631 .54553 .59168 .55519 .58751 .55006 .58262 Mtetra
.647 .762 .933 r
.55006 .58262 .55519 .58751 .56489 .58427 .55978 .57994 Mtetra
.576 .764 .968 r
.55978 .57994 .56489 .58427 .57463 .58215 .56956 .57843 Mtetra
.464 .748 .991 r
.56956 .57843 .57463 .58215 .58444 .58121 .5794 .5781 Mtetra
.308 .699 .978 r
.5794 .5781 .58444 .58121 .59431 .58138 .58931 .57884 Mtetra
.159 .635 .927 r
.58931 .57884 .59431 .58138 .60426 .58224 .59929 .58025 Mtetra
.064 .591 .869 r
.59929 .58025 .60426 .58224 .61426 .58329 .60934 .58182 Mtetra
.112 .641 .87 r
.60934 .58182 .61426 .58329 .6243 .5836 .61943 .58254 Mtetra
.262 .754 .912 r
.61943 .58254 .6243 .5836 .63436 .58257 .62952 .58176 Mtetra
.493 .887 .956 r
.62952 .58176 .63436 .58257 .64439 .57965 .6396 .57882 Mtetra
.677 .952 .953 r
.6396 .57882 .64439 .57965 .65439 .57482 .64963 .57371 Mtetra
.77 .958 .931 r
.64963 .57371 .65439 .57482 .66436 .56864 .65962 .56709 Mtetra
.809 .943 .913 r
.65962 .56709 .66436 .56864 .67431 .5617 .66959 .5596 Mtetra
.808 .922 .913 r
.66959 .5596 .67431 .5617 .68429 .55494 .67958 .55225 Mtetra
.788 .898 .921 r
.67958 .55225 .68429 .55494 .69431 .54887 .68961 .54556 Mtetra
.752 .869 .933 r
.68961 .54556 .69431 .54887 .70441 .5439 .69971 .53995 Mtetra
.708 .832 .941 r
.69971 .53995 .70441 .5439 .7146 .54012 .7099 .53552 Mtetra
.661 .791 .944 r
.7099 .53552 .7146 .54012 .72489 .53749 .72019 .53227 Mtetra
.619 .751 .941 r
.72019 .53227 .72489 .53749 .73528 .53579 .73057 .53005 Mtetra
.587 .718 .934 r
.73057 .53005 .73528 .53579 .74576 .53475 .74105 .52862 Mtetra
.565 .694 .928 r
.74105 .52862 .74576 .53475 .75632 .53411 .75162 .52774 Mtetra
.555 .681 .923 r
.75162 .52774 .75632 .53411 .76695 .53358 .76226 .52713 Mtetra
.553 .678 .921 r
.76226 .52713 .76695 .53358 .77762 .533 .77296 .52658 Mtetra
.56 .683 .922 r
.77296 .52658 .77762 .533 .78833 .53216 .7837 .52585 Mtetra
.57 .693 .924 r
.7837 .52585 .78833 .53216 .79906 .53102 .79447 .52487 Mtetra
.585 .706 .926 r
.79447 .52487 .79906 .53102 .80982 .5295 .80527 .52351 Mtetra
.6 .719 .928 r
.80527 .52351 .80982 .5295 .8206 .52762 .81609 .52177 Mtetra
.615 .732 .929 r
.81609 .52177 .8206 .52762 .83139 .5254 .82692 .51964 Mtetra
.627 .742 .929 r
.82692 .51964 .83139 .5254 .8422 .52288 .83777 .51719 Mtetra
.638 .749 .929 r
.83777 .51719 .8422 .52288 .85304 .52012 .84863 .51446 Mtetra
.646 .754 .928 r
.84863 .51446 .85304 .52012 .8639 .51717 .85952 .5115 Mtetra
.652 .757 .927 r
.85952 .5115 .8639 .51717 .87478 .51407 .87044 .50838 Mtetra
.656 .759 .925 r
.87044 .50838 .87478 .51407 .8857 .51088 .88138 .50514 Mtetra
.659 .759 .924 r
.88138 .50514 .8857 .51088 .89665 .50761 .89236 .50183 Mtetra
.661 .759 .923 r
.89236 .50183 .89665 .50761 .90764 .50429 .90338 .49846 Mtetra
.661 .758 .922 r
.90338 .49846 .90764 .50429 .91867 .50095 .91443 .49506 Mtetra
.662 .757 .921 r
.91443 .49506 .91867 .50095 .92973 .49758 .92553 .49164 Mtetra
.662 .756 .92 r
.92553 .49164 .92973 .49758 .94084 .49419 .93666 .48821 Mtetra
.662 .755 .919 r
.93666 .48821 .94084 .49419 .95198 .4908 .94784 .48476 Mtetra
.648 .749 .924 r
.34689 .65403 .35253 .65894 .36161 .65644 .356 .65153 Mtetra
.647 .75 .924 r
.356 .65153 .36161 .65644 .37073 .65394 .36513 .64903 Mtetra
.647 .751 .925 r
.36513 .64903 .37073 .65394 .37988 .65142 .37429 .64652 Mtetra
.647 .752 .925 r
.37429 .64652 .37988 .65142 .38906 .64889 .38349 .64399 Mtetra
.648 .753 .926 r
.38349 .64399 .38906 .64889 .39827 .64633 .39273 .64145 Mtetra
.65 .755 .926 r
.39273 .64145 .39827 .64633 .40752 .64372 .40199 .63885 Mtetra
.652 .757 .926 r
.40199 .63885 .40752 .64372 .4168 .64104 .41129 .63619 Mtetra
.657 .759 .925 r
.41129 .63619 .4168 .64104 .42611 .63824 .42063 .6334 Mtetra
.664 .762 .923 r
.42063 .6334 .42611 .63824 .43547 .6353 .43 .63045 Mtetra
.673 .765 .919 r
.43 .63045 .43547 .6353 .44485 .63214 .43941 .62726 Mtetra
.685 .767 .914 r
.43941 .62726 .44485 .63214 .45428 .62871 .44886 .62376 Mtetra
.698 .768 .906 r
.44886 .62376 .45428 .62871 .46374 .62496 .45834 .6199 Mtetra
.711 .767 .896 r
.45834 .6199 .46374 .62496 .47323 .62083 .46786 .61562 Mtetra
.722 .764 .886 r
.46786 .61562 .47323 .62083 .48275 .61633 .47741 .61094 Mtetra
.732 .76 .876 r
.47741 .61094 .48275 .61633 .4923 .61147 .48698 .60588 Mtetra
.736 .755 .868 r
.48698 .60588 .4923 .61147 .50187 .60634 .49658 .60059 Mtetra
.737 .751 .864 r
.49658 .60059 .50187 .60634 .51146 .60103 .5062 .59523 Mtetra
.731 .749 .867 r
.5062 .59523 .51146 .60103 .52108 .59578 .51583 .59008 Mtetra
.719 .75 .877 r
.51583 .59008 .52108 .59578 .53071 .59078 .52549 .58538 Mtetra
.697 .756 .897 r
.52549 .58538 .53071 .59078 .54037 .58631 .53517 .58142 Mtetra
.66 .767 .929 r
.53517 .58142 .54037 .58631 .55006 .58262 .54489 .57843 Mtetra
.596 .778 .967 r
.54489 .57843 .55006 .58262 .55978 .57994 .55465 .57653 Mtetra
.482 .772 .995 r
.55465 .57653 .55978 .57994 .56956 .57843 .56447 .57578 Mtetra
.312 .724 .977 r
.56447 .57578 .56956 .57843 .5794 .5781 .57434 .57608 Mtetra
.118 .629 .895 r
.57434 .57608 .5794 .5781 .58931 .57884 .58429 .57726 Mtetra
0 .54 .804 r
.58429 .57726 .58931 .57884 .59929 .58025 .59431 .57899 Mtetra
0 .507 .756 r
.59431 .57899 .59929 .58025 .60934 .58182 .60439 .58077 Mtetra
.027 .589 .802 r
.60439 .58077 .60934 .58182 .61943 .58254 .61451 .58165 Mtetra
.224 .734 .887 r
.61451 .58165 .61943 .58254 .62952 .58176 .62464 .58096 Mtetra
.49 .886 .954 r
.62464 .58096 .62952 .58176 .6396 .57882 .63476 .57801 Mtetra
.682 .954 .951 r
.63476 .57801 .6396 .57882 .64963 .57371 .64482 .57277 Mtetra
.772 .965 .927 r
.64482 .57277 .64963 .57371 .65962 .56709 .65486 .56597 Mtetra
.811 .959 .909 r
.65486 .56597 .65962 .56709 .66959 .5596 .66486 .55823 Mtetra
.812 .952 .91 r
.66486 .55823 .66959 .5596 .67958 .55225 .67488 .55053 Mtetra
.797 .94 .921 r
.67488 .55053 .67958 .55225 .68961 .54556 .68493 .54337 Mtetra
.77 .921 .937 r
.68493 .54337 .68961 .54556 .69971 .53995 .69504 .53708 Mtetra
.733 .888 .951 r
.69504 .53708 .69971 .53995 .7099 .53552 .70522 .53184 Mtetra
.689 .842 .957 r
.70522 .53184 .7099 .53552 .72019 .53227 .71549 .52776 Mtetra
.646 .793 .953 r
.71549 .52776 .72019 .53227 .73057 .53005 .72586 .52479 Mtetra
.606 .747 .944 r
.72586 .52479 .73057 .53005 .74105 .52862 .73634 .52281 Mtetra
.576 .713 .936 r
.73634 .52281 .74105 .52862 .75162 .52774 .74691 .52158 Mtetra
.557 .692 .929 r
.74691 .52158 .75162 .52774 .76226 .52713 .75756 .52082 Mtetra
.548 .683 .927 r
.75756 .52082 .76226 .52713 .77296 .52658 .76828 .52029 Mtetra
.551 .685 .928 r
.76828 .52029 .77296 .52658 .7837 .52585 .77905 .51968 Mtetra
.559 .694 .93 r
.77905 .51968 .7837 .52585 .79447 .52487 .78987 .51886 Mtetra
.575 .708 .933 r
.78987 .51886 .79447 .52487 .80527 .52351 .8007 .51764 Mtetra
.592 .722 .934 r
.8007 .51764 .80527 .52351 .81609 .52177 .81156 .51603 Mtetra
.609 .735 .935 r
.81156 .51603 .81609 .52177 .82692 .51964 .82243 .51398 Mtetra
.624 .745 .934 r
.82243 .51398 .82692 .51964 .83777 .51719 .83331 .51155 Mtetra
.637 .752 .932 r
.83331 .51155 .83777 .51719 .84863 .51446 .84421 .50881 Mtetra
.647 .757 .93 r
.84421 .50881 .84863 .51446 .85952 .5115 .85512 .50582 Mtetra
.653 .759 .927 r
.85512 .50582 .85952 .5115 .87044 .50838 .86607 .50266 Mtetra
.658 .76 .925 r
.86607 .50266 .87044 .50838 .88138 .50514 .87704 .49936 Mtetra
.66 .759 .923 r
.87704 .49936 .88138 .50514 .89236 .50183 .88805 .49599 Mtetra
.662 .759 .922 r
.88805 .49599 .89236 .50183 .90338 .49846 .89909 .49257 Mtetra
.662 .758 .921 r
.89909 .49257 .90338 .49846 .91443 .49506 .91017 .48912 Mtetra
.663 .757 .92 r
.91017 .48912 .91443 .49506 .92553 .49164 .92129 .48565 Mtetra
.663 .756 .919 r
.92129 .48565 .92553 .49164 .93666 .48821 .93245 .48217 Mtetra
.663 .755 .919 r
.93245 .48217 .93666 .48821 .94784 .48476 .94366 .47868 Mtetra
.648 .749 .924 r
.34122 .64908 .34689 .65403 .356 .65153 .35034 .64657 Mtetra
.647 .749 .924 r
.35034 .64657 .356 .65153 .36513 .64903 .3595 .64406 Mtetra
.647 .75 .924 r
.3595 .64406 .36513 .64903 .37429 .64652 .36868 .64155 Mtetra
.647 .75 .925 r
.36868 .64155 .37429 .64652 .38349 .64399 .3779 .63903 Mtetra
.646 .751 .926 r
.3779 .63903 .38349 .64399 .39273 .64145 .38715 .6365 Mtetra
.648 .753 .926 r
.38715 .6365 .39273 .64145 .40199 .63885 .39643 .63393 Mtetra
.65 .755 .926 r
.39643 .63393 .40199 .63885 .41129 .63619 .40575 .6313 Mtetra
.655 .758 .926 r
.40575 .6313 .41129 .63619 .42063 .6334 .41511 .62855 Mtetra
.661 .762 .925 r
.41511 .62855 .42063 .6334 .43 .63045 .4245 .62564 Mtetra
.672 .767 .922 r
.4245 .62564 .43 .63045 .43941 .62726 .43393 .62246 Mtetra
.685 .771 .917 r
.43393 .62246 .43941 .62726 .44886 .62376 .4434 .61895 Mtetra
.7 .774 .91 r
.4434 .61895 .44886 .62376 .45834 .6199 .45291 .61502 Mtetra
.716 .776 .9 r
.45291 .61502 .45834 .6199 .46786 .61562 .46245 .61061 Mtetra
.728 .774 .889 r
.46245 .61061 .46786 .61562 .47741 .61094 .47203 .60576 Mtetra
.739 .77 .878 r
.47203 .60576 .47741 .61094 .48698 .60588 .48163 .60049 Mtetra
.742 .764 .871 r
.48163 .60049 .48698 .60588 .49658 .60059 .49125 .59504 Mtetra
.74 .759 .868 r
.49125 .59504 .49658 .60059 .5062 .59523 .5009 .5896 Mtetra
.728 .755 .874 r
.5009 .5896 .5062 .59523 .51583 .59008 .51056 .58456 Mtetra
.708 .755 .889 r
.51056 .58456 .51583 .59008 .52549 .58538 .52024 .58026 Mtetra
.673 .762 .918 r
.52024 .58026 .52549 .58538 .53517 .58142 .52995 .57697 Mtetra
.609 .771 .958 r
.52995 .57697 .53517 .58142 .54489 .57843 .53969 .57491 Mtetra
.499 .775 .994 r
.53969 .57491 .54489 .57843 .55465 .57653 .54949 .57402 Mtetra
.309 .729 .974 r
.54949 .57402 .55465 .57653 .56447 .57578 .55934 .57421 Mtetra
.091 .624 .864 r
.55934 .57421 .56447 .57578 .57434 .57608 .56926 .57513 Mtetra
0 .518 .74 r
.56926 .57513 .57434 .57608 .58429 .57726 .57924 .57652 Mtetra
.128 0 0 r
.57924 .57652 .58429 .57726 .59431 .57899 .58928 .57818 Mtetra
0 .49 .708 r
.58928 .57818 .59431 .57899 .60439 .58077 .59939 .57971 Mtetra
.063 .616 .822 r
.59939 .57971 .60439 .58077 .61451 .58165 .60954 .58034 Mtetra
.293 .767 .934 r
.60954 .58034 .61451 .58165 .62464 .58096 .6197 .57953 Mtetra
.544 .89 .982 r
.6197 .57953 .62464 .58096 .63476 .57801 .62985 .57656 Mtetra
.702 .938 .962 r
.62985 .57656 .63476 .57801 .64482 .57277 .63996 .57142 Mtetra
.771 .951 .934 r
.63996 .57142 .64482 .57277 .65486 .56597 .65005 .56482 Mtetra
.802 .959 .914 r
.65005 .56482 .65486 .56597 .66486 .55823 .66011 .55731 Mtetra
.802 .968 .91 r
.66011 .55731 .66486 .55823 .67488 .55053 .67017 .54965 Mtetra
.79 .97 .914 r
.67017 .54965 .67488 .55053 .68493 .54337 .68026 .54225 Mtetra
.776 .963 .926 r
.68026 .54225 .68493 .54337 .69504 .53708 .69038 .53529 Mtetra
.759 .939 .943 r
.69038 .53529 .69504 .53708 .70522 .53184 .70055 .52907 Mtetra
.725 .893 .956 r
.70055 .52907 .70522 .53184 .71549 .52776 .7108 .52394 Mtetra
.683 .836 .957 r
.7108 .52394 .71549 .52776 .72586 .52479 .72115 .51998 Mtetra
.634 .778 .95 r
.72115 .51998 .72586 .52479 .73634 .52281 .73161 .51728 Mtetra
.592 .732 .941 r
.73161 .51728 .73634 .52281 .74691 .52158 .74217 .51561 Mtetra
.561 .702 .935 r
.74217 .51561 .74691 .52158 .75756 .52082 .75284 .51469 Mtetra
.542 .688 .934 r
.75284 .51469 .75756 .52082 .76828 .52029 .76359 .51419 Mtetra
.54 .689 .936 r
.76359 .51419 .76828 .52029 .77905 .51968 .7744 .51372 Mtetra
.546 .697 .939 r
.7744 .51372 .77905 .51968 .78987 .51886 .78525 .51306 Mtetra
.564 .713 .942 r
.78525 .51306 .78987 .51886 .8007 .51764 .79613 .51199 Mtetra
.583 .728 .943 r
.79613 .51199 .8007 .51764 .81156 .51603 .80702 .51046 Mtetra
.605 .742 .942 r
.80702 .51046 .81156 .51603 .82243 .51398 .81792 .50844 Mtetra
.623 .752 .939 r
.81792 .50844 .82243 .51398 .83331 .51155 .82883 .50599 Mtetra
.638 .757 .935 r
.82883 .50599 .83331 .51155 .84421 .50881 .83975 .50319 Mtetra
.648 .76 .931 r
.83975 .50319 .84421 .50881 .85512 .50582 .85069 .50013 Mtetra
.655 .761 .927 r
.85069 .50013 .85512 .50582 .86607 .50266 .86166 .49688 Mtetra
.66 .76 .924 r
.86166 .49688 .86607 .50266 .87704 .49936 .87266 .49351 Mtetra
.662 .759 .922 r
.87266 .49351 .87704 .49936 .88805 .49599 .88369 .49008 Mtetra
.663 .758 .921 r
.88369 .49008 .88805 .49599 .89909 .49257 .89476 .48659 Mtetra
.663 .757 .92 r
.89476 .48659 .89909 .49257 .91017 .48912 .90587 .4831 Mtetra
.663 .756 .919 r
.90587 .4831 .91017 .48912 .92129 .48565 .91702 .47959 Mtetra
.663 .755 .918 r
.91702 .47959 .92129 .48565 .93245 .48217 .92822 .47607 Mtetra
.92822 .47607 .93245 .48217 .94366 .47868 .93945 .47256 Mtetra
.648 .749 .923 r
.33552 .6441 .34122 .64908 .35034 .64657 .34466 .64156 Mtetra
.647 .749 .923 r
.34466 .64156 .35034 .64657 .3595 .64406 .35383 .63903 Mtetra
.647 .748 .923 r
.35383 .63903 .3595 .64406 .36868 .64155 .36303 .6365 Mtetra
.646 .748 .924 r
.36303 .6365 .36868 .64155 .3779 .63903 .37227 .63397 Mtetra
.646 .749 .924 r
.37227 .63397 .3779 .63903 .38715 .6365 .38154 .63145 Mtetra
.646 .75 .925 r
.38154 .63145 .38715 .6365 .39643 .63393 .39084 .62891 Mtetra
.647 .752 .925 r
.39084 .62891 .39643 .63393 .40575 .6313 .40018 .62632 Mtetra
.651 .755 .925 r
.40018 .62632 .40575 .6313 .41511 .62855 .40955 .62363 Mtetra
.657 .76 .925 r
.40955 .62363 .41511 .62855 .4245 .62564 .41896 .62079 Mtetra
.668 .766 .924 r
.41896 .62079 .4245 .62564 .43393 .62246 .42841 .61769 Mtetra
.682 .773 .92 r
.42841 .61769 .43393 .62246 .4434 .61895 .4379 .61424 Mtetra
.699 .78 .914 r
.4379 .61424 .4434 .61895 .45291 .61502 .44744 .61033 Mtetra
.718 .784 .905 r
.44744 .61033 .45291 .61502 .46245 .61061 .457 .60586 Mtetra
.733 .785 .894 r
.457 .60586 .46245 .61061 .47203 .60576 .46661 .60088 Mtetra
.746 .783 .883 r
.46661 .60088 .47203 .60576 .48163 .60049 .47624 .59541 Mtetra
.749 .778 .876 r
.47624 .59541 .48163 .60049 .49125 .59504 .48589 .58976 Mtetra
.746 .771 .874 r
.48589 .58976 .49125 .59504 .5009 .5896 .49556 .58418 Mtetra
.728 .764 .881 r
.49556 .58418 .5009 .5896 .51056 .58456 .50525 .5792 Mtetra
.696 .759 .901 r
.50525 .5792 .51056 .58456 .52024 .58026 .51495 .57527 Mtetra
.64 .759 .935 r
.51495 .57527 .52024 .58026 .52995 .57697 .52468 .57271 Mtetra
.533 .754 .977 r
.52468 .57271 .52995 .57697 .53969 .57491 .53446 .57174 Mtetra
.353 .724 .987 r
.53446 .57174 .53969 .57491 .54949 .57402 .54429 .57206 Mtetra
.084 .608 .876 r
.54429 .57206 .54949 .57402 .55934 .57421 .55418 .57338 Mtetra
0 .488 .706 r
.55418 .57338 .55934 .57421 .56926 .57513 .56413 .5749 Mtetra
.142 0 0 r
.56413 .5749 .56926 .57513 .57924 .57652 .57414 .57615 Mtetra
.085 0 0 r
.57414 .57615 .57924 .57652 .58928 .57818 .58421 .57713 Mtetra
.079 .629 .829 r
.58421 .57713 .58928 .57818 .59939 .57971 .59432 .57762 Mtetra
.314 .752 .967 r
.59432 .57762 .59939 .57971 .60954 .58034 .60448 .57735 Mtetra
.499 .805 1 r
.60448 .57735 .60954 .58034 .6197 .57953 .61466 .57601 Mtetra
.634 .831 .976 r
.61466 .57601 .6197 .57953 .62985 .57656 .62484 .57302 Mtetra
.714 .851 .947 r
.62484 .57302 .62985 .57656 .63996 .57142 .635 .56838 Mtetra
.753 .88 .936 r
.635 .56838 .63996 .57142 .65005 .56482 .64516 .56265 Mtetra
.776 .92 .933 r
.64516 .56265 .65005 .56482 .66011 .55731 .6553 .55615 Mtetra
.78 .96 .925 r
.6553 .55615 .66011 .55731 .67017 .54965 .66544 .54914 Mtetra
.773 .98 .911 r
.66544 .54914 .67017 .54965 .68026 .54225 .67558 .54184 Mtetra
.78 .984 .903 r
.67558 .54184 .68026 .54225 .69038 .53529 .68572 .53426 Mtetra
.79 .968 .916 r
.68572 .53426 .69038 .53529 .70055 .52907 .69588 .52686 Mtetra
.77 .925 .938 r
.69588 .52686 .70055 .52907 .7108 .52394 .7061 .52046 Mtetra
.728 .864 .945 r
.7061 .52046 .7108 .52394 .72115 .51998 .71642 .51536 Mtetra
.667 .799 .945 r
.71642 .51536 .72115 .51998 .73161 .51728 .72686 .51187 Mtetra
.609 .746 .942 r
.72686 .51187 .73161 .51728 .74217 .51561 .73742 .50979 Mtetra
.562 .71 .94 r
.73742 .50979 .74217 .51561 .75284 .51469 .74811 .50876 Mtetra
.53 .692 .942 r
.74811 .50876 .75284 .51469 .76359 .51419 .75889 .50838 Mtetra
.523 .694 .946 r
.75889 .50838 .76359 .51419 .7744 .51372 .76974 .50807 Mtetra
.529 .704 .951 r
.76974 .50807 .7744 .51372 .78525 .51306 .78063 .50758 Mtetra
.552 .722 .953 r
.78063 .50758 .78525 .51306 .79613 .51199 .79154 .50659 Mtetra
.576 .737 .952 r
.79154 .50659 .79613 .51199 .80702 .51046 .80246 .50508 Mtetra
.604 .751 .948 r
.80246 .50508 .80702 .51046 .81792 .50844 .81339 .50301 Mtetra
.625 .758 .942 r
.81339 .50301 .81792 .50844 .82883 .50599 .82432 .50046 Mtetra
.641 .761 .935 r
.82432 .50046 .82883 .50599 .83975 .50319 .83527 .49754 Mtetra
.652 .762 .93 r
.83527 .49754 .83975 .50319 .85069 .50013 .84623 .49435 Mtetra
.658 .76 .925 r
.84623 .49435 .85069 .50013 .86166 .49688 .85722 .491 Mtetra
.662 .759 .922 r
.85722 .491 .86166 .49688 .87266 .49351 .86824 .48755 Mtetra
.664 .757 .92 r
.86824 .48755 .87266 .49351 .88369 .49008 .8793 .48404 Mtetra
.664 .756 .918 r
.8793 .48404 .88369 .49008 .89476 .48659 .8904 .48051 Mtetra
.664 .755 .918 r
.8904 .48051 .89476 .48659 .90587 .4831 .90154 .47698 Mtetra
.664 .754 .917 r
.90154 .47698 .90587 .4831 .91702 .47959 .91272 .47345 Mtetra
.663 .754 .918 r
.91272 .47345 .91702 .47959 .92822 .47607 .92394 .46992 Mtetra
.662 .754 .918 r
.92394 .46992 .92822 .47607 .93945 .47256 .93521 .46639 Mtetra
.649 .75 .923 r
.32977 .63908 .33552 .6441 .34466 .64156 .33893 .6365 Mtetra
.649 .748 .922 r
.33893 .6365 .34466 .64156 .35383 .63903 .34813 .63392 Mtetra
.648 .747 .922 r
.34813 .63392 .35383 .63903 .36303 .6365 .35735 .63135 Mtetra
.647 .746 .922 r
.35735 .63135 .36303 .6365 .37227 .63397 .36661 .6288 Mtetra
.646 .745 .922 r
.36661 .6288 .37227 .63397 .38154 .63145 .37589 .62627 Mtetra
.645 .745 .922 r
.37589 .62627 .38154 .63145 .39084 .62891 .38521 .62373 Mtetra
.645 .747 .923 r
.38521 .62373 .39084 .62891 .40018 .62632 .39457 .62119 Mtetra
.647 .75 .924 r
.39457 .62119 .40018 .62632 .40955 .62363 .40396 .61859 Mtetra
.651 .755 .925 r
.40396 .61859 .40955 .62363 .41896 .62079 .41339 .61587 Mtetra
.661 .763 .925 r
.41339 .61587 .41896 .62079 .42841 .61769 .42286 .61292 Mtetra
.675 .772 .924 r
.42286 .61292 .42841 .61769 .4379 .61424 .43237 .60962 Mtetra
.693 .783 .92 r
.43237 .60962 .4379 .61424 .44744 .61033 .44192 .60584 Mtetra
.716 .793 .912 r
.44192 .60584 .44744 .61033 .457 .60586 .45151 .60142 Mtetra
.736 .799 .902 r
.45151 .60142 .457 .60586 .46661 .60088 .46114 .59639 Mtetra
.753 .8 .89 r
.46114 .59639 .46661 .60088 .47624 .59541 .4708 .59075 Mtetra
.759 .795 .882 r
.4708 .59075 .47624 .59541 .48589 .58976 .48049 .58486 Mtetra
.755 .786 .879 r
.48049 .58486 .48589 .58976 .49556 .58418 .49019 .57901 Mtetra
.731 .774 .887 r
.49019 .57901 .49556 .58418 .50525 .5792 .4999 .57396 Mtetra
.686 .762 .909 r
.4999 .57396 .50525 .5792 .51495 .57527 .50963 .57029 Mtetra
.603 .748 .947 r
.50963 .57029 .51495 .57527 .52468 .57271 .51938 .56844 Mtetra
.434 .712 .982 r
.51938 .56844 .52468 .57271 .53446 .57174 .52918 .56868 Mtetra
.165 .619 .935 r
.52918 .56868 .53446 .57174 .54429 .57206 .53904 .5704 Mtetra
0 .433 .721 r
.53904 .5704 .54429 .57206 .55418 .57338 .54897 .57306 Mtetra
.234 0 0 r
.54897 .57306 .55418 .57338 .56413 .5749 .55896 .5751 Mtetra
.119 0 0 r
.55896 .5751 .56413 .5749 .57414 .57615 .56899 .57577 Mtetra
.128 .674 .809 r
.56899 .57577 .57414 .57615 .58421 .57713 .57907 .57526 Mtetra
.446 .83 .987 r
.57907 .57526 .58421 .57713 .59432 .57762 .58918 .57365 Mtetra
.591 .796 .978 r
.58918 .57365 .59432 .57762 .60448 .57735 .59932 .57156 Mtetra
.632 .734 .922 r
.59932 .57156 .60448 .57735 .61466 .57601 .60949 .56915 Mtetra
.656 .707 .885 r
.60949 .56915 .61466 .57601 .62484 .57302 .6197 .56614 Mtetra
.675 .714 .878 r
.6197 .56614 .62484 .57302 .635 .56838 .62991 .56253 Mtetra
.688 .753 .901 r
.62991 .56253 .635 .56838 .64516 .56265 .64016 .55859 Mtetra
.706 .829 .941 r
.64016 .55859 .64516 .56265 .6553 .55615 .65041 .55416 Mtetra
.731 .925 .956 r
.65041 .55416 .6553 .55615 .66544 .54914 .66066 .54862 Mtetra
.744 .977 .921 r
.66066 .54862 .66544 .54914 .67558 .54184 .67087 .54188 Mtetra
.786 .992 .881 r
.67087 .54188 .67558 .54184 .68572 .53426 .68103 .53374 Mtetra
.827 .981 .882 r
.68103 .53374 .68572 .53426 .69588 .52686 .69117 .52495 Mtetra
.816 .938 .908 r
.69117 .52495 .69588 .52686 .7061 .52046 .70136 .51709 Mtetra
.772 .877 .923 r
.70136 .51709 .7061 .52046 .71642 .51536 .71165 .51073 Mtetra
.697 .809 .934 r
.71165 .51073 .71642 .51536 .72686 .51187 .72207 .50647 Mtetra
.622 .753 .94 r
.72207 .50647 .72686 .51187 .73742 .50979 .73265 .50408 Mtetra
.557 .714 .945 r
.73265 .50408 .73742 .50979 .74811 .50876 .74336 .50309 Mtetra
.509 .694 .952 r
.74336 .50309 .74811 .50876 .75889 .50838 .75419 .50294 Mtetra
.499 .699 .959 r
.75419 .50294 .75889 .50838 .76974 .50807 .76508 .50284 Mtetra
.507 .713 .964 r
.76508 .50284 .76974 .50807 .78063 .50758 .77601 .50248 Mtetra
.54 .735 .965 r
.77601 .50248 .78063 .50758 .79154 .50659 .78695 .50151 Mtetra
.574 .751 .961 r
.78695 .50151 .79154 .50659 .80246 .50508 .79789 .49991 Mtetra
.608 .762 .953 r
.79789 .49991 .80246 .50508 .81339 .50301 .80884 .49766 Mtetra
.632 .766 .944 r
.80884 .49766 .81339 .50301 .82432 .50046 .81979 .49491 Mtetra
.648 .765 .934 r
.81979 .49491 .82432 .50046 .83527 .49754 .83075 .4918 Mtetra
.658 .762 .927 r
.83075 .4918 .83527 .49754 .84623 .49435 .84173 .48844 Mtetra
.663 .758 .921 r
.84173 .48844 .84623 .49435 .85722 .491 .85274 .48497 Mtetra
.665 .756 .918 r
.85274 .48497 .85722 .491 .86824 .48755 .86378 .48142 Mtetra
.665 .753 .916 r
.86378 .48142 .86824 .48755 .8793 .48404 .87487 .47786 Mtetra
.665 .752 .915 r
.87487 .47786 .8793 .48404 .8904 .48051 .88599 .4743 Mtetra
.664 .751 .915 r
.88599 .4743 .8904 .48051 .90154 .47698 .89717 .47076 Mtetra
.663 .751 .916 r
.89717 .47076 .90154 .47698 .91272 .47345 .90838 .46722 Mtetra
.662 .752 .917 r
.90838 .46722 .91272 .47345 .92394 .46992 .91964 .4637 Mtetra
.661 .753 .918 r
.91964 .4637 .92394 .46992 .93521 .46639 .93095 .46018 Mtetra
.652 .75 .922 r
.32399 .63404 .32977 .63908 .33893 .6365 .33318 .63139 Mtetra
.651 .748 .921 r
.33318 .63139 .33893 .6365 .34813 .63392 .34239 .62875 Mtetra
.65 .746 .92 r
.34239 .62875 .34813 .63392 .35735 .63135 .35163 .62612 Mtetra
.649 .744 .919 r
.35163 .62612 .35735 .63135 .36661 .6288 .36091 .62352 Mtetra
.647 .743 .919 r
.36091 .62352 .36661 .6288 .37589 .62627 .37022 .62094 Mtetra
.646 .741 .919 r
.37022 .62094 .37589 .62627 .38521 .62373 .37956 .6184 Mtetra
.644 .741 .92 r
.37956 .6184 .38521 .62373 .39457 .62119 .38893 .61588 Mtetra
.644 .743 .921 r
.38893 .61588 .39457 .62119 .40396 .61859 .39834 .61334 Mtetra
.645 .746 .923 r
.39834 .61334 .40396 .61859 .41339 .61587 .40778 .61076 Mtetra
.652 .754 .924 r
.40778 .61076 .41339 .61587 .42286 .61292 .41727 .60799 Mtetra
.664 .765 .925 r
.41727 .60799 .42286 .61292 .43237 .60962 .42679 .60494 Mtetra
.683 .78 .924 r
.42679 .60494 .43237 .60962 .44192 .60584 .43636 .6014 Mtetra
.708 .795 .919 r
.43636 .6014 .44192 .60584 .45151 .60142 .44598 .59719 Mtetra
.733 .808 .911 r
.44598 .59719 .45151 .60142 .46114 .59639 .45563 .59227 Mtetra
.757 .815 .899 r
.45563 .59227 .46114 .59639 .4708 .59075 .46532 .58657 Mtetra
.768 .815 .89 r
.46532 .58657 .4708 .59075 .48049 .58486 .47504 .58045 Mtetra
.769 .807 .884 r
.47504 .58045 .48049 .58486 .49019 .57901 .48477 .57423 Mtetra
.742 .791 .893 r
.48477 .57423 .49019 .57901 .4999 .57396 .49452 .5689 Mtetra
.686 .771 .916 r
.49452 .5689 .4999 .57396 .50963 .57029 .50427 .56521 Mtetra
.576 .737 .952 r
.50427 .56521 .50963 .57029 .51938 .56844 .51404 .56385 Mtetra
.348 .656 .97 r
.51404 .56385 .51938 .56844 .52918 .56868 .52386 .56517 Mtetra
.015 .5 .872 r
.52386 .56517 .52918 .56868 .53904 .5704 .53374 .56838 Mtetra
.302 0 0 r
.53374 .56838 .53904 .5704 .54897 .57306 .54371 .5726 Mtetra
.284 0 0 r
.54371 .5726 .54897 .57306 .55896 .5751 .55373 .5752 Mtetra
.027 .599 .715 r
.55373 .5752 .55896 .5751 .56899 .57577 .56379 .57491 Mtetra
.488 .883 .958 r
.56379 .57491 .56899 .57577 .57907 .57526 .57387 .57205 Mtetra
.726 .865 .947 r
.57387 .57205 .57907 .57526 .58918 .57365 .58395 .56711 Mtetra
.718 .737 .866 r
.58395 .56711 .58918 .57365 .59932 .57156 .59405 .56208 Mtetra
.678 .651 .816 r
.59405 .56208 .59932 .57156 .60949 .56915 .6042 .55787 Mtetra
.643 .603 .795 r
.6042 .55787 .60949 .56915 .6197 .56614 .6144 .55484 Mtetra
.614 .589 .802 r
.6144 .55484 .6197 .56614 .62991 .56253 .62469 .55297 Mtetra
.59 .611 .841 r
.62469 .55297 .62991 .56253 .64016 .55859 .63504 .55194 Mtetra
.577 .686 .915 r
.63504 .55194 .64016 .55859 .65041 .55416 .64544 .55083 Mtetra
.635 .846 .981 r
.64544 .55083 .65041 .55416 .66066 .54862 .65581 .54762 Mtetra
.711 .959 .946 r
.65581 .54762 .66066 .54862 .67087 .54188 .66611 .54182 Mtetra
.813 .991 .875 r
.66611 .54182 .67087 .54188 .68103 .53374 .6763 .53308 Mtetra
.873 .969 .852 r
.6763 .53308 .68103 .53374 .69117 .52495 .68641 .52267 Mtetra
.855 .919 .874 r
.68641 .52267 .69117 .52495 .70136 .51709 .69657 .51327 Mtetra
.802 .861 .893 r
.69657 .51327 .70136 .51709 .71165 .51073 .70683 .50576 Mtetra
.716 .801 .918 r
.70683 .50576 .71165 .51073 .72207 .50647 .71725 .50098 Mtetra
.623 .751 .938 r
.71725 .50098 .72207 .50647 .73265 .50408 .72786 .49856 Mtetra
.538 .714 .954 r
.72786 .49856 .73265 .50408 .74336 .50309 .73861 .49782 Mtetra
.474 .695 .965 r
.73861 .49782 .74336 .50309 .75419 .50294 .74949 .498 Mtetra
.467 .707 .973 r
.74949 .498 .75419 .50294 .76508 .50284 .76042 .49809 Mtetra
.487 .727 .977 r
.76042 .49809 .76508 .50284 .77601 .50248 .77138 .49776 Mtetra
.537 .752 .975 r
.77138 .49776 .77601 .50248 .78695 .50151 .78234 .49664 Mtetra
.581 .766 .966 r
.78234 .49664 .78695 .50151 .79789 .49991 .7933 .49479 Mtetra
.619 .771 .953 r
.7933 .49479 .79789 .49991 .80884 .49766 .80425 .49224 Mtetra
.644 .77 .939 r
.80425 .49224 .80884 .49766 .81979 .49491 .81521 .4892 Mtetra
.657 .764 .928 r
.81521 .4892 .81979 .49491 .83075 .4918 .82618 .48585 Mtetra
.665 .759 .92 r
.82618 .48585 .83075 .4918 .84173 .48844 .83717 .48231 Mtetra
.666 .753 .915 r
.83717 .48231 .84173 .48844 .85274 .48497 .8482 .47872 Mtetra
.667 .75 .913 r
.8482 .47872 .85274 .48497 .86378 .48142 .85927 .47511 Mtetra
.665 .748 .912 r
.85927 .47511 .86378 .48142 .87487 .47786 .87039 .47153 Mtetra
.664 .748 .912 r
.87039 .47153 .87487 .47786 .88599 .4743 .88155 .46796 Mtetra
.663 .748 .913 r
.88155 .46796 .88599 .4743 .89717 .47076 .89276 .46443 Mtetra
.661 .749 .915 r
.89276 .46443 .89717 .47076 .90838 .46722 .90401 .46092 Mtetra
.66 .75 .916 r
.90401 .46092 .90838 .46722 .91964 .4637 .91531 .45742 Mtetra
.66 .751 .918 r
.91531 .45742 .91964 .4637 .93095 .46018 .92665 .45393 Mtetra
.654 .751 .921 r
.31818 .62896 .32399 .63404 .33318 .63139 .32738 .62624 Mtetra
.654 .749 .92 r
.32738 .62624 .33318 .63139 .34239 .62875 .33662 .62352 Mtetra
.653 .746 .918 r
.33662 .62352 .34239 .62875 .35163 .62612 .34589 .62081 Mtetra
.652 .743 .917 r
.34589 .62081 .35163 .62612 .36091 .62352 .35518 .61812 Mtetra
.65 .741 .916 r
.35518 .61812 .36091 .62352 .37022 .62094 .36451 .61547 Mtetra
.648 .738 .915 r
.36451 .61547 .37022 .62094 .37956 .6184 .37387 .61287 Mtetra
.645 .736 .915 r
.37387 .61287 .37956 .6184 .38893 .61588 .38327 .61032 Mtetra
.643 .735 .916 r
.38327 .61032 .38893 .61588 .39834 .61334 .39269 .60781 Mtetra
.64 .736 .918 r
.39269 .60781 .39834 .61334 .40778 .61076 .40215 .60535 Mtetra
.643 .742 .921 r
.40215 .60535 .40778 .61076 .41727 .60799 .41164 .6028 Mtetra
.65 .752 .925 r
.41164 .6028 .41727 .60799 .42679 .60494 .42118 .60007 Mtetra
.667 .77 .927 r
.42118 .60007 .42679 .60494 .43636 .6014 .43076 .59691 Mtetra
.692 .792 .926 r
.43076 .59691 .43636 .6014 .44598 .59719 .44039 .59311 Mtetra
.722 .814 .922 r
.44039 .59311 .44598 .59719 .45563 .59227 .45007 .58849 Mtetra
.755 .831 .91 r
.45007 .58849 .45563 .59227 .46532 .58657 .45979 .58292 Mtetra
.775 .837 .9 r
.45979 .58292 .46532 .58657 .47504 .58045 .46954 .57665 Mtetra
.785 .832 .889 r
.46954 .57665 .47504 .58045 .48477 .57423 .47931 .56996 Mtetra
.76 .814 .895 r
.47931 .56996 .48477 .57423 .49452 .5689 .48909 .56409 Mtetra
.702 .785 .916 r
.48909 .56409 .49452 .5689 .50427 .56521 .49887 .55996 Mtetra
.574 .73 .948 r
.49887 .55996 .50427 .56521 .51404 .56385 .50867 .55867 Mtetra
.306 .608 .953 r
.50867 .55867 .51404 .56385 .52386 .56517 .5185 .56078 Mtetra
0 .403 .831 r
.5185 .56078 .52386 .56517 .53374 .56838 .5284 .56543 Mtetra
.395 0 0 r
.5284 .56543 .53374 .56838 .54371 .5726 .53839 .57146 Mtetra
.283 0 0 r
.53839 .57146 .54371 .5726 .55373 .5752 .54845 .5747 Mtetra
.288 .781 .887 r
.54845 .5747 .55373 .5752 .56379 .57491 .55853 .57315 Mtetra
.76 .929 .943 r
.55853 .57315 .56379 .57491 .57387 .57205 .5686 .56705 Mtetra
.828 .802 .827 r
.5686 .56705 .57387 .57205 .58395 .56711 .57864 .55735 Mtetra
.765 .68 .769 r
.57864 .55735 .58395 .56711 .59405 .56208 .58867 .54809 Mtetra
.696 .596 .74 r
.58867 .54809 .59405 .56208 .6042 .55787 .59876 .54126 Mtetra
.626 .534 .731 r
.59876 .54126 .6042 .55787 .6144 .55484 .60896 .5382 Mtetra
.555 .492 .74 r
.60896 .5382 .6144 .55484 .62469 .55297 .61931 .5389 Mtetra
.481 .476 .775 r
.61931 .5389 .62469 .55297 .63504 .55194 .62979 .54206 Mtetra
.402 .505 .849 r
.62979 .54206 .63504 .55194 .64544 .55083 .64036 .54568 Mtetra
.479 .703 .967 r
.64036 .54568 .64544 .55083 .65581 .54762 .65088 .54571 Mtetra
.672 .919 .975 r
.65088 .54571 .65581 .54762 .66611 .54182 .66127 .54114 Mtetra
.847 .974 .873 r
.66127 .54114 .66611 .54182 .6763 .53308 .67148 .53172 Mtetra
.906 .934 .82 r
.67148 .53172 .6763 .53308 .68641 .52267 .68156 .51945 Mtetra
.873 .878 .837 r
.68156 .51945 .68641 .52267 .69657 .51327 .69169 .50854 Mtetra
.812 .828 .863 r
.69169 .50854 .69657 .51327 .70683 .50576 .70194 .5002 Mtetra
.717 .78 .902 r
.70194 .5002 .70683 .50576 .71725 .50098 .71239 .4953 Mtetra
.605 .738 .939 r
.71239 .4953 .71725 .50098 .72786 .49856 .72305 .49328 Mtetra
.498 .708 .964 r
.72305 .49328 .72786 .49856 .73861 .49782 .73386 .49306 Mtetra
.418 .691 .976 r
.73386 .49306 .73861 .49782 .74949 .498 .7448 .49369 Mtetra
.427 .718 .985 r
.7448 .49369 .74949 .498 .76042 .49809 .75576 .49389 Mtetra
.474 .747 .989 r
.75576 .49389 .76042 .49809 .77138 .49776 .76675 .49339 Mtetra
.546 .774 .983 r
.76675 .49339 .77138 .49776 .78234 .49664 .77771 .49191 Mtetra
.601 .782 .967 r
.77771 .49191 .78234 .49664 .7933 .49479 .78867 .4896 Mtetra
.639 .778 .947 r
.78867 .4896 .7933 .49479 .80425 .49224 .79962 .48663 Mtetra
.66 .769 .931 r
.79962 .48663 .80425 .49224 .81521 .4892 .81057 .4832 Mtetra
.667 .758 .919 r
.81057 .4832 .81521 .4892 .82618 .48585 .82155 .47959 Mtetra
.67 .751 .911 r
.82155 .47959 .82618 .48585 .83717 .48231 .83256 .47588 Mtetra
.668 .745 .908 r
.83256 .47588 .83717 .48231 .8482 .47872 .84362 .47222 Mtetra
.666 .743 .907 r
.84362 .47222 .8482 .47872 .85927 .47511 .85472 .46859 Mtetra
.664 .742 .908 r
.85472 .46859 .85927 .47511 .87039 .47153 .86587 .46503 Mtetra
.662 .742 .91 r
.86587 .46503 .87039 .47153 .88155 .46796 .87707 .4615 Mtetra
.66 .744 .912 r
.87707 .4615 .88155 .46796 .89276 .46443 .88831 .45801 Mtetra
.659 .746 .914 r
.88831 .45801 .89276 .46443 .90401 .46092 .8996 .45454 Mtetra
.658 .748 .916 r
.8996 .45454 .90401 .46092 .91531 .45742 .91094 .45109 Mtetra
.657 .75 .918 r
.91094 .45109 .91531 .45742 .92665 .45393 .92232 .44763 Mtetra
.656 .751 .92 r
.31232 .62385 .31818 .62896 .32738 .62624 .32155 .62106 Mtetra
.656 .75 .919 r
.32155 .62106 .32738 .62624 .33662 .62352 .33081 .61826 Mtetra
.656 .747 .917 r
.33081 .61826 .33662 .62352 .34589 .62081 .3401 .61547 Mtetra
.655 .745 .916 r
.3401 .61547 .34589 .62081 .35518 .61812 .34942 .61269 Mtetra
.654 .742 .914 r
.34942 .61269 .35518 .61812 .36451 .61547 .35877 .60993 Mtetra
.651 .738 .913 r
.35877 .60993 .36451 .61547 .37387 .61287 .36816 .60722 Mtetra
.648 .734 .911 r
.36816 .60722 .37387 .61287 .38327 .61032 .37757 .60458 Mtetra
.644 .73 .911 r
.37757 .60458 .38327 .61032 .39269 .60781 .38702 .60203 Mtetra
.638 .727 .912 r
.38702 .60203 .39269 .60781 .40215 .60535 .39649 .59961 Mtetra
.637 .729 .915 r
.39649 .59961 .40215 .60535 .41164 .6028 .406 .59721 Mtetra
.637 .735 .919 r
.406 .59721 .41164 .6028 .42118 .60007 .41555 .59479 Mtetra
.649 .75 .924 r
.41555 .59479 .42118 .60007 .43076 .59691 .42514 .59206 Mtetra
.669 .773 .928 r
.42514 .59206 .43076 .59691 .44039 .59311 .43478 .58882 Mtetra
.701 .803 .929 r
.43478 .58882 .44039 .59311 .45007 .58849 .44447 .58476 Mtetra
.74 .833 .922 r
.44447 .58476 .45007 .58849 .45979 .58292 .45421 .57963 Mtetra
.774 .853 .91 r
.45421 .57963 .45979 .58292 .46954 .57665 .46399 .57347 Mtetra
.799 .858 .894 r
.46399 .57347 .46954 .57665 .47931 .56996 .47381 .5664 Mtetra
.783 .844 .898 r
.47381 .5664 .47931 .56996 .48909 .56409 .48362 .55983 Mtetra
.733 .814 .915 r
.48362 .55983 .48909 .56409 .49887 .55996 .49344 .55483 Mtetra
.603 .746 .945 r
.49344 .55483 .49887 .55996 .50867 .55867 .50326 .55294 Mtetra
.334 .601 .945 r
.50326 .55294 .50867 .55867 .5185 .56078 .51311 .55508 Mtetra
0 .367 .829 r
.51311 .55508 .5185 .56078 .5284 .56543 .52302 .56076 Mtetra
0 .122 .598 r
.52302 .56076 .5284 .56543 .53839 .57146 .53302 .56867 Mtetra
0 .358 .726 r
.53302 .56867 .53839 .57146 .54845 .5747 .54311 .57285 Mtetra
.527 .868 .992 r
.54311 .57285 .54845 .5747 .55853 .57315 .55322 .57037 Mtetra
.852 .88 .859 r
.55322 .57037 .55853 .57315 .5686 .56705 .56329 .56079 Mtetra
.867 .766 .748 r
.56329 .56079 .5686 .56705 .57864 .55735 .57327 .54553 Mtetra
.798 .665 .717 r
.57327 .54553 .57864 .55735 .58867 .54809 .58324 .53116 Mtetra
.717 .583 .704 r
.58324 .53116 .58867 .54809 .59876 .54126 .59326 .52103 Mtetra
.617 .504 .702 r
.59326 .52103 .59876 .54126 .60896 .5382 .60344 .51793 Mtetra
.496 .429 .71 r
.60344 .51793 .60896 .5382 .61931 .5389 .61384 .52187 Mtetra
.355 .365 .732 r
.61384 .52187 .61931 .5389 .62979 .54206 .62445 .53011 Mtetra
.174 .321 .773 r
.62445 .53011 .62979 .54206 .64036 .54568 .63521 .53928 Mtetra
.273 .541 .921 r
.63521 .53928 .64036 .54568 .65088 .54571 .64587 .54276 Mtetra
.647 .87 .982 r
.64587 .54276 .65088 .54571 .66127 .54114 .65634 .5391 Mtetra
.873 .922 .856 r
.65634 .5391 .66127 .54114 .67148 .53172 .66655 .52869 Mtetra
.911 .869 .785 r
.66655 .52869 .67148 .53172 .68156 .51945 .67659 .51447 Mtetra
.864 .818 .803 r
.67659 .51447 .68156 .51945 .69169 .50854 .68671 .50249 Mtetra
.797 .783 .839 r
.68671 .50249 .69169 .50854 .70194 .5002 .69699 .49407 Mtetra
.696 .756 .897 r
.69699 .49407 .70194 .5002 .71239 .4953 .7075 .48973 Mtetra
.559 .724 .951 r
.7075 .48973 .71239 .4953 .72305 .49328 .71824 .48858 Mtetra
.427 .7 .978 r
.71824 .48858 .72305 .49328 .73386 .49306 .72912 .48902 Mtetra
.342 .686 .98 r
.72912 .48902 .73386 .49306 .7448 .49369 .74011 .49 Mtetra
.399 .735 .991 r
.74011 .49 .7448 .49369 .75576 .49389 .7511 .49005 Mtetra
.49 .774 .995 r
.7511 .49005 .75576 .49389 .76675 .49339 .76208 .48906 Mtetra
.58 .792 .98 r
.76208 .48906 .76675 .49339 .77771 .49191 .77304 .48697 Mtetra
.634 .787 .955 r
.77304 .48697 .77771 .49191 .78867 .4896 .78398 .48403 Mtetra
.661 .772 .932 r
.78398 .48403 .78867 .4896 .79962 .48663 .79492 .48057 Mtetra
.673 .759 .915 r
.79492 .48057 .79962 .48663 .81057 .4832 .80587 .47679 Mtetra
.673 .747 .906 r
.80587 .47679 .81057 .4832 .82155 .47959 .81687 .47298 Mtetra
.672 .741 .902 r
.81687 .47298 .82155 .47959 .83256 .47588 .8279 .46918 Mtetra
.667 .737 .902 r
.8279 .46918 .83256 .47588 .84362 .47222 .83899 .46552 Mtetra
.664 .736 .904 r
.83899 .46552 .84362 .47222 .85472 .46859 .85013 .46195 Mtetra
.661 .738 .907 r
.85013 .46195 .85472 .46859 .86587 .46503 .86132 .45845 Mtetra
.659 .74 .91 r
.86132 .45845 .86587 .46503 .87707 .4615 .87255 .45499 Mtetra
.657 .743 .913 r
.87255 .45499 .87707 .4615 .88831 .45801 .88384 .45156 Mtetra
.656 .745 .915 r
.88384 .45156 .88831 .45801 .8996 .45454 .89517 .44814 Mtetra
.656 .747 .917 r
.89517 .44814 .8996 .45454 .91094 .45109 .90654 .44471 Mtetra
.656 .749 .919 r
.90654 .44471 .91094 .45109 .92232 .44763 .91796 .44128 Mtetra
.657 .752 .92 r
.30643 .61871 .31232 .62385 .32155 .62106 .31568 .61587 Mtetra
.658 .751 .919 r
.31568 .61587 .32155 .62106 .33081 .61826 .32496 .61302 Mtetra
.658 .749 .917 r
.32496 .61302 .33081 .61826 .3401 .61547 .33427 .61015 Mtetra
.658 .747 .916 r
.33427 .61015 .3401 .61547 .34942 .61269 .34362 .60728 Mtetra
.658 .745 .914 r
.34362 .60728 .34942 .61269 .35877 .60993 .353 .60439 Mtetra
.657 .74 .911 r
.353 .60439 .35877 .60993 .36816 .60722 .36241 .60152 Mtetra
.655 .735 .908 r
.36241 .60152 .36816 .60722 .37757 .60458 .37185 .59871 Mtetra
.65 .728 .906 r
.37185 .59871 .37757 .60458 .38702 .60203 .38131 .59602 Mtetra
.642 .721 .905 r
.38131 .59602 .38702 .60203 .39649 .59961 .39081 .5935 Mtetra
.636 .717 .906 r
.39081 .5935 .39649 .59961 .406 .59721 .40034 .59112 Mtetra
.629 .716 .909 r
.40034 .59112 .406 .59721 .41555 .59479 .40989 .5889 Mtetra
.631 .724 .915 r
.40989 .5889 .41555 .59479 .42514 .59206 .41949 .5866 Mtetra
.64 .743 .924 r
.41949 .5866 .42514 .59206 .43478 .58882 .42913 .58406 Mtetra
.667 .778 .933 r
.42913 .58406 .43478 .58882 .44447 .58476 .43883 .58083 Mtetra
.708 .821 .935 r
.43883 .58083 .44447 .58476 .45421 .57963 .44858 .57654 Mtetra
.758 .863 .927 r
.44858 .57654 .45421 .57963 .46399 .57347 .45839 .57089 Mtetra
.804 .883 .903 r
.45839 .57089 .46399 .57347 .47381 .5664 .46824 .5637 Mtetra
.807 .879 .899 r
.46824 .5637 .47381 .5664 .48362 .55983 .4781 .55639 Mtetra
.778 .851 .906 r
.4781 .55639 .48362 .55983 .49344 .55483 .48796 .55002 Mtetra
.667 .781 .934 r
.48796 .55002 .49344 .55483 .50326 .55294 .49782 .54672 Mtetra
.44 .636 .939 r
.49782 .54672 .50326 .55294 .51311 .55508 .50769 .5478 Mtetra
.08 .387 .848 r
.50769 .5478 .51311 .55508 .52302 .56076 .5176 .55374 Mtetra
0 .114 .649 r
.5176 .55374 .52302 .56076 .53302 .56867 .52761 .56342 Mtetra
0 .366 .821 r
.52761 .56342 .53302 .56867 .54311 .57285 .53771 .56897 Mtetra
.618 .812 .975 r
.53771 .56897 .54311 .57285 .55322 .57037 .54785 .56634 Mtetra
.876 .827 .796 r
.54785 .56634 .55322 .57037 .56329 .56079 .55793 .55366 Mtetra
.889 .746 .699 r
.55793 .55366 .56329 .56079 .57327 .54553 .56788 .53255 Mtetra
.825 .665 .684 r
.56788 .53255 .57327 .54553 .58324 .53116 .57777 .51256 Mtetra
.742 .587 .683 r
.57777 .51256 .58324 .53116 .59326 .52103 .58772 .49865 Mtetra
.613 .49 .689 r
.58772 .49865 .59326 .52103 .60344 .51793 .59787 .49551 Mtetra
.428 .371 .692 r
.59787 .49551 .60344 .51793 .61384 .52187 .60833 .50318 Mtetra
.192 .242 .686 r
.60833 .50318 .61384 .52187 .62445 .53011 .61907 .51698 Mtetra
0 .113 .656 r
.61907 .51698 .62445 .53011 .63521 .53928 .62999 .53198 Mtetra
.072 .381 .844 r
.62999 .53198 .63521 .53928 .64587 .54276 .64078 .53855 Mtetra
.662 .82 .959 r
.64078 .53855 .64587 .54276 .65634 .5391 .65128 .535 Mtetra
.872 .845 .815 r
.65128 .535 .65634 .5391 .66655 .52869 .66148 .52317 Mtetra
.891 .797 .749 r
.66148 .52317 .66655 .52869 .67659 .51447 .67148 .50712 Mtetra
.834 .754 .775 r
.67148 .50712 .67659 .51447 .68671 .50249 .68162 .49482 Mtetra
.759 .73 .826 r
.68162 .49482 .68671 .50249 .69699 .49407 .69198 .48743 Mtetra
.647 .722 .903 r
.69198 .48743 .69699 .49407 .7075 .48973 .7026 .4845 Mtetra
.465 .697 .968 r
.7026 .4845 .7075 .48973 .71824 .48858 .71344 .48469 Mtetra
.31 .676 .976 r
.71344 .48469 .71824 .48858 .72912 .48902 .7244 .48586 Mtetra
.259 .679 .965 r
.7244 .48586 .72912 .48902 .74011 .49 .73543 .48692 Mtetra
.403 .767 .994 r
.73543 .48692 .74011 .49 .7511 .49005 .74642 .48642 Mtetra
.545 .81 .995 r
.74642 .48642 .7511 .49005 .76208 .48906 .75737 .48451 Mtetra
.63 .803 .966 r
.75737 .48451 .76208 .48906 .77304 .48697 .76829 .48153 Mtetra
.669 .781 .933 r
.76829 .48153 .77304 .48697 .78398 .48403 .7792 .47783 Mtetra
.678 .757 .91 r
.7792 .47783 .78398 .48403 .79492 .48057 .79014 .47388 Mtetra
.68 .741 .897 r
.79014 .47388 .79492 .48057 .80587 .47679 .8011 .46985 Mtetra
.674 .732 .893 r
.8011 .46985 .80587 .47679 .81687 .47298 .81212 .46597 Mtetra
.669 .728 .894 r
.81212 .46597 .81687 .47298 .8279 .46918 .82319 .46223 Mtetra
.663 .728 .898 r
.82319 .46223 .8279 .46918 .83899 .46552 .83432 .45868 Mtetra
.658 .731 .903 r
.83432 .45868 .83899 .46552 .85013 .46195 .8455 .45524 Mtetra
.656 .735 .908 r
.8455 .45524 .85013 .46195 .86132 .45845 .85673 .45185 Mtetra
.654 .739 .912 r
.85673 .45185 .86132 .45845 .87255 .45499 .86801 .44849 Mtetra
.654 .743 .915 r
.86801 .44849 .87255 .45499 .88384 .45156 .87933 .44511 Mtetra
.654 .746 .917 r
.87933 .44511 .88384 .45156 .89517 .44814 .8907 .44172 Mtetra
.654 .748 .919 r
.8907 .44172 .89517 .44814 .90654 .44471 .90211 .43832 Mtetra
.654 .75 .92 r
.90211 .43832 .90654 .44471 .91796 .44128 .91357 .43489 Mtetra
.657 .752 .92 r
.3005 .61354 .30643 .61871 .31568 .61587 .30977 .61069 Mtetra
.658 .752 .92 r
.30977 .61069 .31568 .61587 .32496 .61302 .31907 .60782 Mtetra
.659 .752 .919 r
.31907 .60782 .32496 .61302 .33427 .61015 .3284 .60492 Mtetra
.66 .752 .918 r
.3284 .60492 .33427 .61015 .34362 .60728 .33777 .60197 Mtetra
.662 .751 .916 r
.33777 .60197 .34362 .60728 .353 .60439 .34717 .59898 Mtetra
.662 .748 .914 r
.34717 .59898 .353 .60439 .36241 .60152 .35661 .59596 Mtetra
.662 .743 .91 r
.35661 .59596 .36241 .60152 .37185 .59871 .36608 .59294 Mtetra
.658 .735 .906 r
.36608 .59294 .37185 .59871 .38131 .59602 .37558 .59001 Mtetra
.652 .726 .903 r
.37558 .59001 .38131 .59602 .39081 .5935 .3851 .58724 Mtetra
.643 .715 .9 r
.3851 .58724 .39081 .5935 .40034 .59112 .39465 .58469 Mtetra
.631 .706 .9 r
.39465 .58469 .40034 .59112 .40989 .5889 .40423 .58242 Mtetra
.623 .703 .902 r
.40423 .58242 .40989 .5889 .41949 .5866 .41383 .58034 Mtetra
.616 .708 .911 r
.41383 .58034 .41949 .5866 .42913 .58406 .42347 .5784 Mtetra
.629 .735 .924 r
.42347 .5784 .42913 .58406 .43883 .58083 .43317 .57609 Mtetra
.658 .779 .938 r
.43317 .57609 .43883 .58083 .44858 .57654 .44291 .57301 Mtetra
.719 .842 .94 r
.44291 .57301 .44858 .57654 .45839 .57089 .45273 .56839 Mtetra
.789 .889 .917 r
.45273 .56839 .45839 .57089 .46824 .5637 .46261 .56174 Mtetra
.817 .909 .903 r
.46261 .56174 .46824 .5637 .4781 .55639 .47252 .55411 Mtetra
.819 .897 .897 r
.47252 .55411 .4781 .55639 .48796 .55002 .48244 .54636 Mtetra
.747 .843 .923 r
.48244 .54636 .48796 .55002 .49782 .54672 .49234 .54094 Mtetra
.581 .717 .936 r
.49234 .54094 .49782 .54672 .50769 .5478 .50224 .53956 Mtetra
.242 .458 .869 r
.50224 .53956 .50769 .5478 .5176 .55374 .51216 .54436 Mtetra
0 .16 .7 r
.51216 .54436 .5176 .55374 .52761 .56342 .52216 .55486 Mtetra
.068 .339 .816 r
.52216 .55486 .52761 .56342 .53771 .56897 .53227 .56206 Mtetra
.575 .679 .91 r
.53227 .56206 .53771 .56897 .54785 .56634 .54243 .56098 Mtetra
.867 .789 .772 r
.54243 .56098 .54785 .56634 .55793 .55366 .55254 .54722 Mtetra
.91 .754 .676 r
.55254 .54722 .55793 .55366 .56788 .53255 .5625 .52211 Mtetra
.869 .702 .672 r
.5625 .52211 .56788 .53255 .57777 .51256 .57237 .49775 Mtetra
.794 .637 .688 r
.57237 .49775 .57777 .51256 .58772 .49865 .58227 .48053 Mtetra
.622 .52 .717 r
.58227 .48053 .58772 .49865 .59787 .49551 .59241 .47736 Mtetra
.276 .302 .708 r
.59241 .47736 .59787 .49551 .60833 .50318 .60292 .48828 Mtetra
0 .033 .595 r
.60292 .48828 .60833 .50318 .61907 .51698 .61375 .50641 Mtetra
0 0 .435 r
.61375 .50641 .61907 .51698 .62999 .53198 .62477 .52539 Mtetra
0 .296 .789 r
.62477 .52539 .62999 .53198 .64078 .53855 .6356 .533 Mtetra
.724 .784 .9 r
.6356 .533 .64078 .53855 .65128 .535 .64607 .52785 Mtetra
.848 .76 .764 r
.64607 .52785 .65128 .535 .66148 .52317 .65624 .5143 Mtetra
.855 .728 .723 r
.65624 .5143 .66148 .52317 .67148 .50712 .66624 .49738 Mtetra
.792 .698 .761 r
.66624 .49738 .67148 .50712 .68162 .49482 .67646 .48618 Mtetra
.698 .686 .835 r
.67646 .48618 .68162 .49482 .69198 .48743 .68697 .48125 Mtetra
.549 .699 .938 r
.68697 .48125 .69198 .48743 .7026 .4845 .69773 .48042 Mtetra
.283 .652 .969 r
.69773 .48042 .7026 .4845 .71344 .48469 .70867 .48199 Mtetra
.164 .638 .929 r
.70867 .48199 .71344 .48469 .7244 .48586 .71968 .48345 Mtetra
.243 .702 .95 r
.71968 .48345 .7244 .48586 .73543 .48692 .73071 .48392 Mtetra
.49 .815 1 r
.73071 .48392 .73543 .48692 .74642 .48642 .74166 .48232 Mtetra
.633 .824 .974 r
.74166 .48232 .74642 .48642 .75737 .48451 .75256 .47914 Mtetra
.679 .787 .931 r
.75256 .47914 .75737 .48451 .76829 .48153 .76345 .47516 Mtetra
.692 .756 .901 r
.76345 .47516 .76829 .48153 .7792 .47783 .77434 .4708 Mtetra
.685 .733 .887 r
.77434 .4708 .7792 .47783 .79014 .47388 .78528 .46658 Mtetra
.678 .722 .883 r
.78528 .46658 .79014 .47388 .8011 .46985 .79627 .46254 Mtetra
.668 .719 .887 r
.79627 .46254 .8011 .46985 .81212 .46597 .80733 .4588 Mtetra
.661 .721 .894 r
.80733 .4588 .81212 .46597 .82319 .46223 .81845 .45528 Mtetra
.655 .727 .902 r
.81845 .45528 .82319 .46223 .83432 .45868 .82963 .45193 Mtetra
.651 .732 .909 r
.82963 .45193 .83432 .45868 .8455 .45524 .84086 .44866 Mtetra
.651 .739 .914 r
.84086 .44866 .8455 .45524 .85673 .45185 .85213 .44539 Mtetra
.651 .744 .918 r
.85213 .44539 .85673 .45185 .86801 .44849 .86345 .4421 Mtetra
.652 .748 .92 r
.86345 .4421 .86801 .44849 .87933 .44511 .87481 .43874 Mtetra
.653 .75 .921 r
.87481 .43874 .87933 .44511 .8907 .44172 .88622 .43535 Mtetra
.654 .751 .921 r
.88622 .43535 .8907 .44172 .90211 .43832 .89766 .43192 Mtetra
.655 .751 .921 r
.89766 .43192 .90211 .43832 .91357 .43489 .90915 .42846 Mtetra
.29453 .60833 .3005 .61354 .30977 .61069 .30382 .60552 Mtetra
.655 .753 .922 r
.30382 .60552 .30977 .61069 .31907 .60782 .31313 .60268 Mtetra
.657 .756 .923 r
.31313 .60268 .31907 .60782 .3284 .60492 .32249 .5998 Mtetra
.659 .758 .923 r
.32249 .5998 .3284 .60492 .33777 .60197 .33187 .59685 Mtetra
.663 .759 .922 r
.33187 .59685 .33777 .60197 .34717 .59898 .3413 .5938 Mtetra
.666 .758 .919 r
.3413 .5938 .34717 .59898 .35661 .59596 .35076 .59067 Mtetra
.669 .756 .915 r
.35076 .59067 .35661 .59596 .36608 .59294 .36026 .58744 Mtetra
.669 .749 .91 r
.36026 .58744 .36608 .59294 .37558 .59001 .36979 .58421 Mtetra
.666 .738 .904 r
.36979 .58421 .37558 .59001 .3851 .58724 .37935 .58103 Mtetra
.658 .723 .897 r
.37935 .58103 .3851 .58724 .39465 .58469 .38894 .57806 Mtetra
.645 .706 .891 r
.38894 .57806 .39465 .58469 .40423 .58242 .39854 .57541 Mtetra
.628 .689 .888 r
.39854 .57541 .40423 .58242 .41383 .58034 .40817 .57322 Mtetra
.605 .677 .892 r
.40817 .57322 .41383 .58034 .42347 .5784 .41781 .5716 Mtetra
.596 .684 .903 r
.41781 .5716 .42347 .5784 .43317 .57609 .4275 .57013 Mtetra
.596 .714 .927 r
.4275 .57013 .43317 .57609 .44291 .57301 .43723 .56851 Mtetra
.652 .789 .948 r
.43723 .56851 .44291 .57301 .45273 .56839 .44704 .5655 Mtetra
.739 .873 .943 r
.44704 .5655 .45273 .56839 .46261 .56174 .45692 .56029 Mtetra
.801 .932 .919 r
.45692 .56029 .46261 .56174 .47252 .55411 .46686 .55312 Mtetra
.845 .941 .886 r
.46686 .55312 .47252 .55411 .48244 .54636 .47684 .54434 Mtetra
.825 .909 .896 r
.47684 .54434 .48244 .54636 .49234 .54094 .48681 .53634 Mtetra
.739 .807 .906 r
.48681 .53634 .49234 .54094 .50224 .53956 .49677 .53103 Mtetra
.45 .567 .881 r
.49677 .53103 .50224 .53956 .51216 .54436 .50671 .53288 Mtetra
.061 .257 .75 r
.50671 .53288 .51216 .54436 .52216 .55486 .51669 .54257 Mtetra
.162 .308 .766 r
.51669 .54257 .52216 .55486 .53227 .56206 .52679 .55143 Mtetra
.452 .519 .837 r
.52679 .55143 .53227 .56206 .54243 .56098 .53697 .55402 Mtetra
.827 .752 .781 r
.53697 .55402 .54243 .56098 .55254 .54722 .54714 .54234 Mtetra
.927 .777 .674 r
.54714 .54234 .55254 .54722 .5625 .52211 .55715 .51663 Mtetra
.924 .768 .67 r
.55715 .51663 .5625 .52211 .57237 .49775 .56705 .49046 Mtetra
.881 .747 .709 r
.56705 .49046 .57237 .49775 .58227 .48053 .57697 .47118 Mtetra
.652 .645 .83 r
.57697 .47118 .58227 .48053 .59241 .47736 .58712 .46799 Mtetra
0 .058 .621 r
.58712 .46799 .59241 .47736 .60292 .48828 .59766 .48092 Mtetra
.75 .312 0 r
.59766 .48092 .60292 .48828 .61375 .50641 .60852 .50083 Mtetra
.799 .34 0 r
.60852 .50083 .61375 .50641 .62477 .52539 .61956 .52037 Mtetra
0 .391 .836 r
.61956 .52037 .62477 .52539 .6356 .533 .63033 .52584 Mtetra
.791 .751 .817 r
.63033 .52584 .6356 .533 .64607 .52785 .6407 .51693 Mtetra
.819 .69 .722 r
.6407 .51693 .64607 .52785 .65624 .5143 .65084 .50165 Mtetra
.809 .667 .707 r
.65084 .50165 .65624 .5143 .66624 .49738 .66089 .48548 Mtetra
.732 .643 .76 r
.66089 .48548 .66624 .49738 .67646 .48618 .67126 .47724 Mtetra
.58 .628 .864 r
.67126 .47724 .67646 .48618 .68697 .48125 .68198 .47625 Mtetra
.327 .636 .963 r
.68198 .47625 .68697 .48125 .69773 .48042 .6929 .47803 Mtetra
0 .528 .844 r
.6929 .47803 .69773 .48042 .70867 .48199 .70393 .48061 Mtetra
.064 .611 .838 r
.70393 .48061 .70867 .48199 .71968 .48345 .71495 .48155 Mtetra
.35 .787 .964 r
.71495 .48155 .71968 .48345 .73071 .48392 .72592 .48052 Mtetra
.623 .853 .986 r
.72592 .48052 .73071 .48392 .74166 .48232 .73681 .47722 Mtetra
.706 .807 .928 r
.73681 .47722 .74166 .48232 .75256 .47914 .74763 .47249 Mtetra
.706 .753 .888 r
.74763 .47249 .75256 .47914 .76345 .47516 .75848 .46761 Mtetra
.697 .722 .869 r
.75848 .46761 .76345 .47516 .77434 .4708 .76938 .46287 Mtetra
.678 .705 .868 r
.76938 .46287 .77434 .4708 .78528 .46658 .78035 .45872 Mtetra
.665 .702 .875 r
.78035 .45872 .78528 .46658 .79627 .46254 .7914 .45503 Mtetra
.655 .709 .887 r
.7914 .45503 .79627 .46254 .80733 .4588 .80252 .45168 Mtetra
.647 .718 .9 r
.80252 .45168 .80733 .4588 .81845 .45528 .8137 .44853 Mtetra
.644 .73 .911 r
.8137 .44853 .81845 .45528 .82963 .45193 .82493 .44545 Mtetra
.643 .74 .919 r
.82493 .44545 .82963 .45193 .84086 .44866 .83621 .44235 Mtetra
.646 .748 .924 r
.83621 .44235 .84086 .44866 .85213 .44539 .84753 .43916 Mtetra
.649 .753 .926 r
.84753 .43916 .85213 .44539 .86345 .4421 .85889 .43588 Mtetra
.652 .756 .926 r
.85889 .43588 .86345 .4421 .87481 .43874 .87028 .43249 Mtetra
.654 .756 .925 r
.87028 .43249 .87481 .43874 .88622 .43535 .88171 .42903 Mtetra
.656 .756 .923 r
.88171 .42903 .88622 .43535 .89766 .43192 .89318 .42552 Mtetra
.657 .754 .922 r
.89318 .42552 .89766 .43192 .90915 .42846 .90469 .42197 Mtetra
.651 .75 .922 r
.28853 .60308 .29453 .60833 .30382 .60552 .29782 .60034 Mtetra
.651 .753 .924 r
.29782 .60034 .30382 .60552 .31313 .60268 .30715 .59757 Mtetra
.653 .757 .926 r
.30715 .59757 .31313 .60268 .32249 .5998 .31652 .59476 Mtetra
.655 .761 .927 r
.31652 .59476 .32249 .5998 .33187 .59685 .32593 .59187 Mtetra
.66 .765 .928 r
.32593 .59187 .33187 .59685 .3413 .5938 .33537 .58886 Mtetra
.665 .769 .927 r
.33537 .58886 .3413 .5938 .35076 .59067 .34485 .58571 Mtetra
.672 .771 .924 r
.34485 .58571 .35076 .59067 .36026 .58744 .35438 .58239 Mtetra
.677 .769 .92 r
.35438 .58239 .36026 .58744 .36979 .58421 .36394 .57893 Mtetra
.681 .762 .912 r
.36394 .57893 .36979 .58421 .37935 .58103 .37354 .57535 Mtetra
.678 .748 .903 r
.37354 .57535 .37935 .58103 .38894 .57806 .38317 .57184 Mtetra
.67 .728 .893 r
.38317 .57184 .38894 .57806 .39854 .57541 .39282 .56853 Mtetra
.648 .701 .885 r
.39282 .56853 .39854 .57541 .40817 .57322 .40248 .56577 Mtetra
.616 .673 .882 r
.40248 .56577 .40817 .57322 .41781 .5716 .41215 .56388 Mtetra
.587 .654 .883 r
.41215 .56388 .41781 .5716 .4275 .57013 .42184 .56271 Mtetra
.554 .65 .898 r
.42184 .56271 .4275 .57013 .43723 .56851 .43155 .56221 Mtetra
.578 .698 .924 r
.43155 .56221 .43723 .56851 .44704 .5655 .44133 .56098 Mtetra
.646 .789 .951 r
.44133 .56098 .44704 .5655 .45692 .56029 .4512 .55806 Mtetra
.742 .903 .95 r
.4512 .55806 .45692 .56029 .46686 .55312 .46115 .5526 Mtetra
.831 .96 .894 r
.46115 .5526 .46686 .55312 .47684 .54434 .47117 .54418 Mtetra
.866 .962 .863 r
.47117 .54418 .47684 .54434 .48681 .53634 .48121 .53429 Mtetra
.859 .9 .863 r
.48121 .53429 .48681 .53634 .49677 .53103 .49125 .52465 Mtetra
.649 .723 .903 r
.49125 .52465 .49677 .53103 .50671 .53288 .50123 .52179 Mtetra
.278 .406 .813 r
.50123 .52179 .50671 .53288 .51669 .54257 .51122 .52783 Mtetra
.242 .32 .744 r
.51122 .52783 .51669 .54257 .52679 .55143 .52129 .53683 Mtetra
.319 .372 .76 r
.52129 .53683 .52679 .55143 .53697 .55402 .53147 .54413 Mtetra
.71 .661 .8 r
.53147 .54413 .53697 .55402 .54714 .54234 .54169 .53822 Mtetra
.922 .803 .71 r
.54169 .53822 .54714 .54234 .55715 .51663 .55181 .51756 Mtetra
.976 .885 .674 r
.55181 .51756 .55715 .51663 .56705 .49046 .56183 .49445 Mtetra
.933 .959 .651 r
.56183 .49445 .56705 .49046 .57697 .47118 .57184 .47598 Mtetra
.134 0 0 r
.57184 .47598 .57697 .47118 .58712 .46799 .58205 .47278 Mtetra
.754 .319 .218 r
.58205 .47278 .58712 .46799 .59766 .48092 .59261 .48488 Mtetra
.81 .387 .24 r
.59261 .48488 .59766 .48092 .60852 .50083 .60342 .50168 Mtetra
.801 .328 .1 r
.60342 .50168 .60852 .50083 .61956 .52037 .61433 .51611 Mtetra
.461 .742 .989 r
.61433 .51611 .61956 .52037 .63033 .52584 .62495 .51572 Mtetra
.814 .7 .739 r
.62495 .51572 .63033 .52584 .6407 .51693 .63518 .502 Mtetra
.783 .636 .698 r
.63518 .502 .6407 .51693 .65084 .50165 .64532 .48652 Mtetra
.755 .621 .71 r
.64532 .48652 .65084 .50165 .66089 .48548 .65554 .474 Mtetra
.649 .611 .798 r
.65554 .474 .66089 .48548 .67126 .47724 .66613 .47048 Mtetra
.295 .546 .919 r
.66613 .47048 .67126 .47724 .68198 .47625 .67708 .47386 Mtetra
0 .427 .767 r
.67708 .47386 .68198 .47625 .6929 .47803 .68812 .47751 Mtetra
.186 0 0 r
.68812 .47751 .6929 .47803 .70393 .48061 .69917 .4797 Mtetra
.216 .73 .876 r
.69917 .4797 .70393 .48061 .71495 .48155 .71013 .47886 Mtetra
.606 .878 .991 r
.71013 .47886 .71495 .48155 .72592 .48052 .721 .47543 Mtetra
.721 .812 .922 r
.721 .47543 .72592 .48052 .73681 .47722 .7318 .47027 Mtetra
.732 .752 .868 r
.7318 .47027 .73681 .47722 .74763 .47249 .74258 .46435 Mtetra
.706 .71 .851 r
.74258 .46435 .74763 .47249 .75848 .46761 .75343 .4591 Mtetra
.685 .693 .852 r
.75343 .4591 .75848 .46761 .76938 .46287 .76437 .4546 Mtetra
.661 .69 .866 r
.76437 .4546 .76938 .46287 .78035 .45872 .77541 .45098 Mtetra
.644 .698 .885 r
.77541 .45098 .78035 .45872 .7914 .45503 .78653 .44794 Mtetra
.636 .715 .905 r
.78653 .44794 .7914 .45503 .80252 .45168 .79773 .4451 Mtetra
.631 .732 .92 r
.79773 .4451 .80252 .45168 .8137 .44853 .80897 .44233 Mtetra
.634 .747 .93 r
.80897 .44233 .8137 .44853 .82493 .44545 .82025 .43943 Mtetra
.638 .757 .934 r
.82025 .43943 .82493 .44545 .83621 .44235 .83157 .4364 Mtetra
.645 .762 .934 r
.83157 .4364 .83621 .44235 .84753 .43916 .84292 .43317 Mtetra
.65 .764 .933 r
.84292 .43317 .84753 .43916 .85889 .43588 .85431 .4298 Mtetra
.654 .764 .93 r
.85431 .4298 .85889 .43588 .87028 .43249 .86572 .42631 Mtetra
.657 .762 .927 r
.86572 .42631 .87028 .43249 .88171 .42903 .87718 .42273 Mtetra
.659 .759 .924 r
.87718 .42273 .88171 .42903 .89318 .42552 .88867 .4191 Mtetra
.66 .756 .921 r
.88867 .4191 .89318 .42552 .90469 .42197 .90021 .41544 Mtetra
.647 .749 .924 r
.28248 .59781 .28853 .60308 .29782 .60034 .29179 .59512 Mtetra
.646 .752 .926 r
.29179 .59512 .29782 .60034 .30715 .59757 .30113 .59245 Mtetra
.647 .756 .929 r
.30113 .59245 .30715 .59757 .31652 .59476 .31051 .58974 Mtetra
.649 .762 .932 r
.31051 .58974 .31652 .59476 .32593 .59187 .31993 .58698 Mtetra
.652 .768 .934 r
.31993 .58698 .32593 .59187 .33537 .58886 .32939 .58412 Mtetra
.658 .776 .936 r
.32939 .58412 .33537 .58886 .34485 .58571 .33889 .5811 Mtetra
.667 .784 .936 r
.33889 .5811 .34485 .58571 .35438 .58239 .34843 .57786 Mtetra
.678 .79 .934 r
.34843 .57786 .35438 .58239 .36394 .57893 .35802 .57435 Mtetra
.692 .791 .927 r
.35802 .57435 .36394 .57893 .37354 .57535 .36766 .57049 Mtetra
.698 .783 .916 r
.36766 .57049 .37354 .57535 .38317 .57184 .37733 .56643 Mtetra
.701 .764 .901 r
.37733 .56643 .38317 .57184 .39282 .56853 .38704 .56225 Mtetra
.683 .732 .887 r
.38704 .56225 .39282 .56853 .40248 .56577 .39675 .5585 Mtetra
.652 .692 .875 r
.39675 .5585 .40248 .56577 .41215 .56388 .40647 .5556 Mtetra
.608 .649 .865 r
.40647 .5556 .41215 .56388 .42184 .56271 .41619 .55391 Mtetra
.549 .61 .866 r
.41619 .55391 .42184 .56271 .43155 .56221 .4259 .55375 Mtetra
.524 .608 .879 r
.4259 .55375 .43155 .56221 .44133 .56098 .43565 .55406 Mtetra
.518 .653 .919 r
.43565 .55406 .44133 .56098 .4512 .55806 .44547 .55406 Mtetra
.607 .803 .975 r
.44547 .55406 .4512 .55806 .46115 .5526 .45538 .55166 Mtetra
.748 .952 .943 r
.45538 .55166 .46115 .5526 .47117 .54418 .46541 .54551 Mtetra
.847 .995 .835 r
.46541 .54551 .47117 .54418 .48121 .53429 .47551 .53533 Mtetra
.919 .962 .792 r
.47551 .53533 .48121 .53429 .49125 .52465 .48564 .52197 Mtetra
.839 .883 .873 r
.48564 .52197 .49125 .52465 .50123 .52179 .49571 .5131 Mtetra
.576 .627 .866 r
.49571 .5131 .50123 .52179 .51122 .52783 .50574 .51224 Mtetra
.358 .383 .75 r
.50574 .51224 .51122 .52783 .52129 .53683 .5158 .51896 Mtetra
.207 .261 .698 r
.5158 .51896 .52129 .53683 .53147 .54413 .52595 .53076 Mtetra
.463 .479 .789 r
.52595 .53076 .53147 .54413 .54169 .53822 .5362 .53387 Mtetra
.83 .831 .849 r
.5362 .53387 .54169 .53822 .55181 .51756 .54646 .52458 Mtetra
.608 .833 .447 r
.54646 .52458 .55181 .51756 .56183 .49445 .55666 .51048 Mtetra
.059 0 .137 r
.55666 .51048 .56183 .49445 .57184 .47598 .56684 .4966 Mtetra
.465 .153 .352 r
.56684 .4966 .57184 .47598 .58205 .47278 .57716 .4934 Mtetra
.622 .297 .4 r
.57716 .4934 .58205 .47278 .59261 .48488 .58772 .5009 Mtetra
.636 .288 .365 r
.58772 .5009 .59261 .48488 .60342 .50168 .59839 .50865 Mtetra
.545 .098 .14 r
.59839 .50865 .60342 .50168 .61433 .51611 .60905 .51161 Mtetra
.833 .837 .849 r
.60905 .51161 .61433 .51611 .62495 .51572 .61944 .50209 Mtetra
.815 .661 .692 r
.61944 .50209 .62495 .51572 .63518 .502 .62955 .48377 Mtetra
.74 .591 .69 r
.62955 .48377 .63518 .502 .64532 .48652 .63977 .47053 Mtetra
.665 .566 .733 r
.63977 .47053 .64532 .48652 .65554 .474 .65027 .46495 Mtetra
.426 .547 .875 r
.65027 .46495 .65554 .474 .66613 .47048 .66113 .46748 Mtetra
.4 0 0 r
.66113 .46748 .66613 .47048 .67708 .47386 .67227 .4746 Mtetra
.441 0 0 r
.67227 .4746 .67708 .47386 .68812 .47751 .68336 .47852 Mtetra
.098 0 0 r
.68336 .47852 .68812 .47751 .69917 .4797 .69434 .47835 Mtetra
.577 .916 .968 r
.69434 .47835 .69917 .4797 .71013 .47886 .70517 .47435 Mtetra
.764 .844 .912 r
.70517 .47435 .71013 .47886 .721 .47543 .7159 .46789 Mtetra
.747 .74 .846 r
.7159 .46789 .721 .47543 .7318 .47027 .72663 .4611 Mtetra
.722 .693 .821 r
.72663 .4611 .7318 .47027 .74258 .46435 .7374 .45478 Mtetra
.685 .669 .829 r
.7374 .45478 .74258 .46435 .75343 .4591 .74831 .45002 Mtetra
.655 .668 .85 r
.74831 .45002 .75343 .4591 .76437 .4546 .75934 .4465 Mtetra
.63 .682 .881 r
.75934 .4465 .76437 .4546 .77541 .45098 .77048 .44386 Mtetra
.611 .704 .911 r
.77048 .44386 .77541 .45098 .78653 .44794 .7817 .44168 Mtetra
.61 .735 .934 r
.7817 .44168 .78653 .44794 .79773 .4451 .79297 .43935 Mtetra
.614 .757 .947 r
.79297 .43935 .79773 .4451 .80897 .44233 .80427 .43683 Mtetra
.627 .773 .951 r
.80427 .43683 .80897 .44233 .82025 .43943 .81559 .43395 Mtetra
.638 .779 .949 r
.81559 .43395 .82025 .43943 .83157 .4364 .82694 .43079 Mtetra
.649 .779 .943 r
.82694 .43079 .83157 .4364 .84292 .43317 .83831 .42739 Mtetra
.656 .776 .937 r
.83831 .42739 .84292 .43317 .85431 .4298 .8497 .42381 Mtetra
.66 .771 .932 r
.8497 .42381 .85431 .4298 .86572 .42631 .86114 .42015 Mtetra
.662 .766 .927 r
.86114 .42015 .86572 .42631 .87718 .42273 .87261 .41641 Mtetra
.663 .762 .923 r
.87261 .41641 .87718 .42273 .88867 .4191 .88413 .41263 Mtetra
.663 .758 .921 r
.88413 .41263 .88867 .4191 .90021 .41544 .89569 .40886 Mtetra
.646 .749 .924 r
.27639 .59249 .28248 .59781 .29179 .59512 .28572 .58983 Mtetra
.644 .75 .926 r
.28572 .58983 .29179 .59512 .30113 .59245 .29508 .58719 Mtetra
.643 .752 .928 r
.29508 .58719 .30113 .59245 .31051 .58974 .30447 .58456 Mtetra
.643 .755 .931 r
.30447 .58456 .31051 .58974 .31993 .58698 .3139 .58192 Mtetra
.642 .76 .934 r
.3139 .58192 .31993 .58698 .32939 .58412 .32337 .57925 Mtetra
.646 .77 .938 r
.32337 .57925 .32939 .58412 .33889 .5811 .33288 .57647 Mtetra
.653 .781 .942 r
.33288 .57647 .33889 .5811 .34843 .57786 .34243 .57351 Mtetra
.666 .796 .944 r
.34243 .57351 .34843 .57786 .35802 .57435 .35203 .57021 Mtetra
.686 .81 .941 r
.35203 .57021 .35802 .57435 .36766 .57049 .36169 .56644 Mtetra
.705 .817 .935 r
.36169 .56644 .36766 .57049 .37733 .56643 .37139 .5622 Mtetra
.724 .813 .92 r
.37139 .5622 .37733 .56643 .38704 .56225 .38115 .55742 Mtetra
.722 .791 .907 r
.38115 .55742 .38704 .56225 .39675 .5585 .39094 .55266 Mtetra
.704 .753 .89 r
.39094 .55266 .39675 .5585 .40647 .5556 .40073 .54831 Mtetra
.658 .696 .873 r
.40073 .54831 .40647 .5556 .41619 .55391 .41051 .54518 Mtetra
.591 .631 .86 r
.41051 .54518 .41619 .55391 .4259 .55375 .42026 .54394 Mtetra
.527 .576 .848 r
.42026 .54394 .4259 .55375 .43565 .55406 .43001 .54444 Mtetra
.451 .542 .859 r
.43001 .54444 .43565 .55406 .44547 .55406 .43978 .5465 Mtetra
.474 .613 .908 r
.43978 .5465 .44547 .55406 .45538 .55166 .44964 .54743 Mtetra
.59 .789 .975 r
.44964 .54743 .45538 .55166 .46541 .54551 .45962 .54535 Mtetra
.789 .976 .909 r
.45962 .54535 .46541 .54551 .47551 .53533 .46973 .5378 Mtetra
.903 .985 .763 r
.46973 .5378 .47551 .53533 .48564 .52197 .47993 .52422 Mtetra
.902 .985 .769 r
.47993 .52422 .48564 .52197 .49571 .5131 .4901 .51088 Mtetra
.849 .901 .873 r
.4901 .51088 .49571 .5131 .50574 .51224 .50022 .50166 Mtetra
.52 .558 .835 r
.50022 .50166 .50574 .51224 .5158 .51896 .5103 .50249 Mtetra
.175 .255 .707 r
.5103 .50249 .5158 .51896 .52595 .53076 .52042 .51395 Mtetra
.254 .304 .722 r
.52042 .51395 .52595 .53076 .5362 .53387 .53067 .52391 Mtetra
.37 .493 .852 r
.53067 .52391 .5362 .53387 .54646 .52458 .541 .5277 Mtetra
.109 0 0 r
.541 .5277 .54646 .52458 .55666 .51048 .55137 .52578 Mtetra
.334 0 .237 r
.55137 .52578 .55666 .51048 .56684 .4966 .56175 .51951 Mtetra
.473 .168 .367 r
.56175 .51951 .56684 .4966 .57716 .4934 .57218 .51631 Mtetra
.522 .212 .382 r
.57218 .51631 .57716 .4934 .58772 .5009 .58271 .51619 Mtetra
.391 .05 .262 r
.58271 .51619 .58772 .5009 .59839 .50865 .59321 .51171 Mtetra
.701 .96 .705 r
.59321 .51171 .59839 .50865 .60905 .51161 .6036 .50147 Mtetra
.836 .706 .72 r
.6036 .50147 .60905 .51161 .61944 .50209 .61383 .48499 Mtetra
.785 .622 .679 r
.61383 .48499 .61944 .50209 .62955 .48377 .62396 .46695 Mtetra
.685 .57 .72 r
.62396 .46695 .62955 .48377 .63977 .47053 .63439 .45961 Mtetra
.445 .514 .836 r
.63439 .45961 .63977 .47053 .65027 .46495 .64521 .46244 Mtetra
.445 0 0 r
.64521 .46244 .65027 .46495 .66113 .46748 .65628 .46947 Mtetra
.641 .109 0 r
.65628 .46947 .66113 .46748 .67227 .4746 .66746 .47679 Mtetra
.325 0 0 r
.66746 .47679 .67227 .4746 .68336 .47852 .67848 .478 Mtetra
.544 .921 .929 r
.67848 .478 .68336 .47852 .69434 .47835 .68929 .47364 Mtetra
.789 .84 .891 r
.68929 .47364 .69434 .47835 .70517 .47435 .69998 .46619 Mtetra
.776 .734 .814 r
.69998 .46619 .70517 .47435 .7159 .46789 .71061 .45757 Mtetra
.726 .672 .797 r
.71061 .45757 .7159 .46789 .72663 .4611 .72134 .45054 Mtetra
.69 .652 .808 r
.72134 .45054 .72663 .4611 .7374 .45478 .73221 .44527 Mtetra
.648 .655 .843 r
.73221 .44527 .7374 .45478 .74831 .45002 .74323 .44194 Mtetra
.609 .674 .887 r
.74323 .44194 .74831 .45002 .75934 .4465 .75439 .43988 Mtetra
.584 .71 .93 r
.75439 .43988 .75934 .4465 .77048 .44386 .76563 .43824 Mtetra
.568 .742 .958 r
.76563 .43824 .77048 .44386 .7817 .44168 .77694 .43662 Mtetra
.586 .774 .969 r
.77694 .43662 .7817 .44168 .79297 .43935 .78825 .43445 Mtetra
.607 .791 .969 r
.78825 .43445 .79297 .43935 .80427 .43683 .79958 .43179 Mtetra
.632 .796 .961 r
.79958 .43179 .80427 .43683 .81559 .43395 .81091 .42864 Mtetra
.65 .793 .951 r
.81091 .42864 .81559 .43395 .82694 .43079 .82226 .42515 Mtetra
.659 .784 .94 r
.82226 .42515 .82694 .43079 .83831 .42739 .83364 .42145 Mtetra
.665 .776 .932 r
.83364 .42145 .83831 .42739 .8497 .42381 .84505 .41764 Mtetra
.666 .768 .926 r
.84505 .41764 .8497 .42381 .86114 .42015 .85651 .41379 Mtetra
.666 .763 .922 r
.85651 .41379 .86114 .42015 .87261 .41641 .868 .40993 Mtetra
.666 .759 .92 r
.868 .40993 .87261 .41641 .88413 .41263 .87954 .40607 Mtetra
.664 .756 .919 r
.87954 .40607 .88413 .41263 .89569 .40886 .89113 .40224 Mtetra
.648 .749 .924 r
.27027 .58715 .27639 .59249 .28572 .58983 .27962 .58442 Mtetra
.645 .747 .923 r
.27962 .58442 .28572 .58983 .29508 .58719 .289 .58174 Mtetra
.643 .745 .923 r
.289 .58174 .29508 .58719 .30447 .58456 .29841 .5791 Mtetra
.64 .745 .925 r
.29841 .5791 .30447 .58456 .3139 .58192 .30785 .57652 Mtetra
.635 .747 .929 r
.30785 .57652 .3139 .58192 .32337 .57925 .31733 .57403 Mtetra
.634 .754 .935 r
.31733 .57403 .32337 .57925 .33288 .57647 .32684 .57153 Mtetra
.633 .765 .943 r
.32684 .57153 .33288 .57647 .34243 .57351 .33639 .56901 Mtetra
.641 .786 .951 r
.33639 .56901 .34243 .57351 .35203 .57021 .34598 .56622 Mtetra
.658 .812 .957 r
.34598 .56622 .35203 .57021 .36169 .56644 .35564 .563 Mtetra
.686 .84 .957 r
.35564 .563 .36169 .56644 .37139 .5622 .36536 .55911 Mtetra
.723 .861 .946 r
.36536 .55911 .37139 .5622 .38115 .55742 .37515 .55431 Mtetra
.747 .862 .933 r
.37515 .55431 .38115 .55742 .39094 .55266 .38499 .54888 Mtetra
.762 .837 .909 r
.38499 .54888 .39094 .55266 .40073 .54831 .39488 .54294 Mtetra
.734 .777 .887 r
.39488 .54294 .40073 .54831 .41051 .54518 .40475 .53764 Mtetra
.678 .697 .861 r
.40475 .53764 .41051 .54518 .42026 .54394 .41461 .53382 Mtetra
.588 .6 .832 r
.41461 .53382 .42026 .54394 .43001 .54444 .42441 .53269 Mtetra
.468 .506 .815 r
.42441 .53269 .43001 .54444 .43978 .5465 .43417 .53501 Mtetra
.409 .479 .821 r
.43417 .53501 .43978 .5465 .44964 .54743 .44396 .53854 Mtetra
.374 .522 .877 r
.44396 .53854 .44964 .54743 .45962 .54535 .45384 .54159 Mtetra
.56 .802 .989 r
.45384 .54159 .45962 .54535 .46973 .5378 .46389 .53972 Mtetra
.772 .997 .824 r
.46389 .53972 .46973 .5378 .47993 .52422 .47408 .53065 Mtetra
.731 .916 .556 r
.47408 .53065 .47993 .52422 .4901 .51088 .48435 .51621 Mtetra
.884 .964 .635 r
.48435 .51621 .4901 .51088 .50022 .50166 .49461 .49915 Mtetra
.825 .898 .892 r
.49461 .49915 .50022 .50166 .5103 .50249 .50476 .49096 Mtetra
.362 .451 .818 r
.50476 .49096 .5103 .50249 .52042 .51395 .51489 .49558 Mtetra
.228 .271 .699 r
.51489 .49558 .52042 .51395 .53067 .52391 .5251 .50704 Mtetra
.043 .163 .665 r
.5251 .50704 .53067 .52391 .541 .5277 .53545 .52161 Mtetra
0 .042 .558 r
.53545 .52161 .541 .5277 .55137 .52578 .54592 .53189 Mtetra
.531 .066 .094 r
.54592 .53189 .55137 .52578 .56175 .51951 .55645 .53469 Mtetra
.423 .075 .268 r
.55645 .53469 .56175 .51951 .57218 .51631 .56698 .53149 Mtetra
.224 0 .186 r
.56698 .53149 .57218 .51631 .58271 .51619 .57745 .52226 Mtetra
.786 .921 .543 r
.57745 .52226 .58271 .51619 .59321 .51171 .58779 .5055 Mtetra
.907 .775 .704 r
.58779 .5055 .59321 .51171 .6036 .50147 .59798 .48437 Mtetra
.785 .622 .679 r
.59798 .48437 .6036 .50147 .61383 .48499 .60817 .46631 Mtetra
.718 .576 .695 r
.60817 .46631 .61383 .48499 .62396 .46695 .61851 .45512 Mtetra
.496 .526 .818 r
.61851 .45512 .62396 .46695 .63439 .45961 .62924 .45685 Mtetra
.642 .096 0 r
.62924 .45685 .63439 .45961 .64521 .46244 .64037 .46758 Mtetra
.673 .208 .139 r
.64037 .46758 .64521 .46244 .65628 .46947 .65153 .47571 Mtetra
.522 .053 .083 r
.65153 .47571 .65628 .46947 .66746 .47679 .66258 .47842 Mtetra
.334 .803 .713 r
.66258 .47842 .66746 .47679 .67848 .478 .67338 .47381 Mtetra
.84 .861 .86 r
.67338 .47381 .67848 .478 .68929 .47364 .68398 .46417 Mtetra
.784 .709 .781 r
.68398 .46417 .68929 .47364 .69998 .46619 .69455 .45401 Mtetra
.74 .649 .76 r
.69455 .45401 .69998 .46619 .71061 .45757 .70518 .44507 Mtetra
.68 .617 .778 r
.70518 .44507 .71061 .45757 .72134 .45054 .71602 .43965 Mtetra
.627 .617 .821 r
.71602 .43965 .72134 .45054 .73221 .44527 .72707 .43699 Mtetra
.575 .653 .889 r
.72707 .43699 .73221 .44527 .74323 .44194 .73826 .43585 Mtetra
.516 .699 .953 r
.73826 .43585 .74323 .44194 .75439 .43988 .74956 .43537 Mtetra
.5 .759 .988 r
.74956 .43537 .75439 .43988 .76563 .43824 .76088 .43438 Mtetra
.517 .798 .997 r
.76088 .43438 .76563 .43824 .77694 .43662 .77222 .43274 Mtetra
.578 .825 .991 r
.77222 .43274 .77694 .43662 .78825 .43445 .78354 .43016 Mtetra
.626 .827 .978 r
.78354 .43016 .78825 .43445 .79958 .43179 .79486 .4269 Mtetra
.656 .812 .959 r
.79486 .4269 .79958 .43179 .81091 .42864 .80618 .42318 Mtetra
.67 .795 .942 r
.80618 .42318 .81091 .42864 .82226 .42515 .81753 .41918 Mtetra
.673 .778 .929 r
.81753 .41918 .82226 .42515 .83364 .42145 .82891 .41514 Mtetra
.673 .766 .921 r
.82891 .41514 .83364 .42145 .84505 .41764 .84034 .41109 Mtetra
.669 .758 .917 r
.84034 .41109 .84505 .41764 .85651 .41379 .85181 .40714 Mtetra
.667 .754 .915 r
.85181 .40714 .85651 .41379 .868 .40993 .86334 .40323 Mtetra
.665 .752 .916 r
.86334 .40323 .868 .40993 .87954 .40607 .87492 .39938 Mtetra
.663 .753 .917 r
.87492 .39938 .87954 .40607 .89113 .40224 .88655 .39556 Mtetra
.654 .751 .921 r
.2641 .58177 .27027 .58715 .27962 .58442 .27348 .57889 Mtetra
.652 .746 .918 r
.27348 .57889 .27962 .58442 .289 .58174 .28289 .57604 Mtetra
.649 .74 .916 r
.28289 .57604 .289 .58174 .29841 .5791 .29233 .57327 Mtetra
.644 .734 .915 r
.29233 .57327 .29841 .5791 .30785 .57652 .3018 .5706 Mtetra
.636 .73 .916 r
.3018 .5706 .30785 .57652 .31733 .57403 .31129 .5681 Mtetra
.63 .728 .918 r
.31129 .5681 .31733 .57403 .32684 .57153 .32081 .56575 Mtetra
.621 .731 .926 r
.32081 .56575 .32684 .57153 .33639 .56901 .33035 .56356 Mtetra
.62 .744 .935 r
.33035 .56356 .33639 .56901 .34598 .56622 .33994 .56133 Mtetra
.623 .767 .949 r
.33994 .56133 .34598 .56622 .35564 .563 .34958 .55892 Mtetra
.645 .807 .961 r
.34958 .55892 .35564 .563 .36536 .55911 .35928 .55594 Mtetra
.682 .854 .964 r
.35928 .55594 .36536 .55911 .37515 .55431 .36906 .55201 Mtetra
.726 .896 .956 r
.36906 .55201 .37515 .55431 .38499 .54888 .37892 .54695 Mtetra
.779 .912 .931 r
.37892 .54695 .38499 .54888 .39488 .54294 .38886 .54051 Mtetra
.794 .892 .914 r
.38886 .54051 .39488 .54294 .40475 .53764 .39884 .53361 Mtetra
.78 .831 .892 r
.39884 .53361 .40475 .53764 .41461 .53382 .40882 .52692 Mtetra
.695 .722 .87 r
.40882 .52692 .41461 .53382 .42441 .53269 .41873 .5226 Mtetra
.564 .591 .839 r
.41873 .5226 .42441 .53269 .43417 .53501 .42857 .52214 Mtetra
.457 .482 .797 r
.42857 .52214 .43417 .53501 .44396 .53854 .43837 .52501 Mtetra
.347 .407 .781 r
.43837 .52501 .44396 .53854 .45384 .54159 .44818 .53066 Mtetra
.383 .478 .833 r
.44818 .53066 .45384 .54159 .46389 .53972 .45812 .53445 Mtetra
.547 .734 .962 r
.45812 .53445 .46389 .53972 .47408 .53065 .46822 .53332 Mtetra
.741 .987 .779 r
.46822 .53332 .47408 .53065 .48435 .51621 .47849 .52388 Mtetra
.78 .909 .517 r
.47849 .52388 .48435 .51621 .49461 .49915 .48884 .50628 Mtetra
.668 .872 .493 r
.48884 .50628 .49461 .49915 .50476 .49096 .49912 .49175 Mtetra
.66 .972 .883 r
.49912 .49175 .50476 .49096 .51489 .49558 .50933 .48542 Mtetra
.361 .483 .848 r
.50933 .48542 .51489 .49558 .5251 .50704 .51954 .48936 Mtetra
.137 .218 .685 r
.51954 .48936 .5251 .50704 .53545 .52161 .52984 .50246 Mtetra
.216 .257 .69 r
.52984 .50246 .53545 .52161 .54592 .53189 .54029 .51477 Mtetra
.388 .39 .741 r
.54029 .51477 .54592 .53189 .55645 .53469 .55082 .52122 Mtetra
.634 .578 .774 r
.55082 .52122 .55645 .53469 .56698 .53149 .56135 .51799 Mtetra
.773 .645 .721 r
.56135 .51799 .56698 .53149 .57745 .52226 .57179 .50504 Mtetra
.789 .624 .676 r
.57179 .50504 .57745 .52226 .58779 .5055 .5821 .48618 Mtetra
.781 .608 .666 r
.5821 .48618 .58779 .5055 .59798 .48437 .59233 .46646 Mtetra
.716 .58 .702 r
.59233 .46646 .59798 .48437 .60817 .46631 .60272 .45592 Mtetra
.553 .586 .841 r
.60272 .45592 .60817 .46631 .61851 .45512 .61338 .45573 Mtetra
.653 .107 0 r
.61338 .45573 .61851 .45512 .62924 .45685 .62435 .46384 Mtetra
.72 .293 .234 r
.62435 .46384 .62924 .45685 .64037 .46758 .63554 .4751 Mtetra
.542 .096 .142 r
.63554 .4751 .64037 .46758 .65153 .47571 .64657 .47813 Mtetra
.325 .782 .642 r
.64657 .47813 .65153 .47571 .66258 .47842 .65734 .47273 Mtetra
.834 .81 .827 r
.65734 .47273 .66258 .47842 .67338 .47381 .66793 .4623 Mtetra
.789 .679 .743 r
.66793 .4623 .67338 .47381 .68398 .46417 .67842 .44995 Mtetra
.731 .621 .736 r
.67842 .44995 .68398 .46417 .69455 .45401 .68903 .44041 Mtetra
.686 .606 .761 r
.68903 .44041 .69455 .45401 .70518 .44507 .69982 .43426 Mtetra
.614 .613 .826 r
.69982 .43426 .70518 .44507 .71602 .43965 .71087 .43205 Mtetra
.506 .641 .915 r
.71087 .43205 .71602 .43965 .72707 .43699 .72211 .4323 Mtetra
.401 .701 .982 r
.72211 .4323 .72707 .43699 .73826 .43585 .73344 .43276 Mtetra
.335 .736 .982 r
.73344 .43276 .73826 .43585 .74956 .43537 .74481 .43277 Mtetra
.427 .809 .991 r
.74481 .43277 .74956 .43537 .76088 .43438 .75615 .43136 Mtetra
.544 .849 .998 r
.75615 .43136 .76088 .43438 .77222 .43274 .76746 .42878 Mtetra
.634 .844 .981 r
.76746 .42878 .77222 .43274 .78354 .43016 .77875 .42522 Mtetra
.674 .818 .952 r
.77875 .42522 .78354 .43016 .79486 .4269 .79003 .42105 Mtetra
.684 .787 .928 r
.79003 .42105 .79486 .4269 .80618 .42318 .80134 .41671 Mtetra
.685 .766 .912 r
.80134 .41671 .80618 .42318 .81753 .41918 .81268 .41231 Mtetra
.678 .75 .905 r
.81268 .41231 .81753 .41918 .82891 .41514 .82408 .40808 Mtetra
.673 .743 .903 r
.82408 .40808 .82891 .41514 .84034 .41109 .83554 .404 Mtetra
.667 .74 .905 r
.83554 .404 .84034 .41109 .85181 .40714 .84705 .40008 Mtetra
.663 .74 .908 r
.84705 .40008 .85181 .40714 .86334 .40323 .85862 .39628 Mtetra
.66 .743 .912 r
.85862 .39628 .86334 .40323 .87492 .39938 .87025 .39254 Mtetra
.658 .747 .916 r
.87025 .39254 .87492 .39938 .88655 .39556 .88193 .38884 Mtetra
.662 .753 .918 r
.25789 .57635 .2641 .58177 .27348 .57889 .26731 .57325 Mtetra
.662 .746 .912 r
.26731 .57325 .27348 .57889 .28289 .57604 .27675 .57014 Mtetra
.659 .737 .907 r
.27675 .57014 .28289 .57604 .29233 .57327 .28623 .5671 Mtetra
.654 .727 .903 r
.28623 .5671 .29233 .57327 .3018 .5706 .29573 .56418 Mtetra
.646 .717 .899 r
.29573 .56418 .3018 .5706 .31129 .5681 .30525 .56144 Mtetra
.635 .706 .898 r
.30525 .56144 .31129 .5681 .32081 .56575 .3148 .55896 Mtetra
.62 .698 .9 r
.3148 .55896 .32081 .56575 .33035 .56356 .32435 .55685 Mtetra
.607 .697 .907 r
.32435 .55685 .33035 .56356 .33994 .56133 .33393 .55502 Mtetra
.59 .705 .923 r
.33393 .55502 .33994 .56133 .34958 .55892 .34354 .55348 Mtetra
.59 .738 .946 r
.34354 .55348 .34958 .55892 .35928 .55594 .3532 .55176 Mtetra
.6 .793 .973 r
.3532 .55176 .35928 .55594 .36906 .55201 .36293 .54954 Mtetra
.641 .876 .985 r
.36293 .54954 .36906 .55201 .37892 .54695 .37275 .54605 Mtetra
.712 .946 .956 r
.37275 .54605 .37892 .54695 .38886 .54051 .38269 .54066 Mtetra
.771 .978 .914 r
.38269 .54066 .38886 .54051 .39884 .53361 .39272 .53351 Mtetra
.839 .966 .886 r
.39272 .53351 .39884 .53361 .40882 .52692 .40282 .52465 Mtetra
.828 .896 .889 r
.40282 .52465 .40882 .52692 .41873 .5226 .4129 .5164 Mtetra
.744 .756 .863 r
.4129 .5164 .41873 .5226 .42857 .52214 .42293 .5104 Mtetra
.599 .579 .802 r
.42293 .5104 .42857 .52214 .43837 .52501 .43285 .50884 Mtetra
.444 .431 .75 r
.43285 .50884 .43837 .52501 .44818 .53066 .44267 .51296 Mtetra
.359 .362 .727 r
.44267 .51296 .44818 .53066 .45812 .53445 .45251 .52012 Mtetra
.258 .341 .758 r
.45251 .52012 .45812 .53445 .46822 .53332 .46244 .52798 Mtetra
.379 .657 .967 r
.46244 .52798 .46822 .53332 .47849 .52388 .47257 .52906 Mtetra
0 0 0 r
.47257 .52906 .47849 .52388 .48884 .50628 .4829 .5201 Mtetra
.4829 .5201 .48884 .50628 .49912 .49175 .49329 .50488 Mtetra
.49329 .50488 .49912 .49175 .50933 .48542 .50366 .48681 Mtetra
.861 .995 .816 r
.50366 .48681 .50933 .48542 .51954 .48936 .51396 .47566 Mtetra
.597 .552 .775 r
.51396 .47566 .51954 .48936 .52984 .50246 .52424 .47408 Mtetra
.531 .414 .665 r
.52424 .47408 .52984 .50246 .54029 .51477 .53459 .47622 Mtetra
.534 .39 .632 r
.53459 .47622 .54029 .51477 .55082 .52122 .54501 .47878 Mtetra
.585 .42 .625 r
.54501 .47878 .55082 .52122 .56135 .51799 .55545 .47549 Mtetra
.627 .45 .623 r
.55545 .47549 .56135 .51799 .57179 .50504 .56585 .46634 Mtetra
.63 .458 .63 r
.56585 .46634 .57179 .50504 .5821 .48618 .57627 .45758 Mtetra
.617 .471 .661 r
.57627 .45758 .5821 .48618 .59233 .46646 .58676 .45255 Mtetra
.41 .444 .785 r
.58676 .45255 .59233 .46646 .60272 .45592 .5975 .45716 Mtetra
.75 .251 .04 r
.5975 .45716 .60272 .45592 .61338 .45573 .6085 .46879 Mtetra
.655 .279 .322 r
.6085 .46879 .61338 .45573 .62435 .46384 .61957 .47759 Mtetra
.547 .176 .289 r
.61957 .47759 .62435 .46384 .63554 .4751 .63055 .48009 Mtetra
0 0 0 r
.63055 .48009 .63554 .4751 .64657 .47813 .64126 .4724 Mtetra
.881 .806 .772 r
.64126 .4724 .64657 .47813 .65734 .47273 .65171 .45782 Mtetra
.772 .635 .709 r
.65171 .45782 .65734 .47273 .66793 .4623 .66216 .44389 Mtetra
.717 .58 .7 r
.66216 .44389 .66793 .4623 .67842 .44995 .67272 .43304 Mtetra
.651 .554 .732 r
.67272 .43304 .67842 .44995 .68903 .44041 .68355 .42797 Mtetra
.567 .561 .806 r
.68355 .42797 .68903 .44041 .69982 .43426 .69465 .42743 Mtetra
.397 .611 .936 r
.69465 .42743 .69982 .43426 .71087 .43205 .70595 .42921 Mtetra
.057 .562 .883 r
.70595 .42921 .71087 .43205 .72211 .4323 .71736 .43165 Mtetra
0 .574 .756 r
.71736 .43165 .72211 .4323 .73344 .43276 .72875 .43233 Mtetra
.176 .71 .824 r
.72875 .43233 .73344 .43276 .74481 .43277 .7401 .43122 Mtetra
.491 .878 .967 r
.7401 .43122 .74481 .43277 .75615 .43136 .75137 .42815 Mtetra
.66 .886 .98 r
.75137 .42815 .75615 .43136 .76746 .42878 .76259 .42376 Mtetra
.704 .825 .94 r
.76259 .42376 .76746 .42878 .77875 .42522 .77381 .41884 Mtetra
.709 .777 .905 r
.77381 .41884 .77875 .42522 .79003 .42105 .78505 .41373 Mtetra
.695 .742 .887 r
.78505 .41373 .79003 .42105 .80134 .41671 .79635 .40892 Mtetra
.685 .725 .88 r
.79635 .40892 .80134 .41671 .81268 .41231 .80771 .4044 Mtetra
.673 .717 .882 r
.80771 .4044 .81268 .41231 .82408 .40808 .81915 .40024 Mtetra
.664 .716 .887 r
.81915 .40024 .82408 .40808 .83554 .404 .83066 .39636 Mtetra
.658 .721 .895 r
.83066 .39636 .83554 .404 .84705 .40008 .84223 .39266 Mtetra
.654 .726 .902 r
.84223 .39266 .84705 .40008 .85862 .39628 .85386 .38909 Mtetra
.651 .734 .91 r
.85386 .38909 .85862 .39628 .87025 .39254 .86554 .38558 Mtetra
.65 .742 .916 r
.86554 .38558 .87025 .39254 .88193 .38884 .87727 .38207 Mtetra
.669 .754 .915 r
.25164 .57089 .25789 .57635 .26731 .57325 .26109 .56761 Mtetra
.67 .749 .91 r
.26109 .56761 .26731 .57325 .27675 .57014 .27057 .56428 Mtetra
.669 .742 .904 r
.27057 .56428 .27675 .57014 .28623 .5671 .28009 .56095 Mtetra
.666 .732 .899 r
.28009 .56095 .28623 .5671 .29573 .56418 .28963 .55769 Mtetra
.662 .721 .893 r
.28963 .55769 .29573 .56418 .30525 .56144 .2992 .55453 Mtetra
.651 .705 .886 r
.2992 .55453 .30525 .56144 .3148 .55896 .30878 .55162 Mtetra
.636 .688 .882 r
.30878 .55162 .3148 .55896 .32435 .55685 .31838 .54911 Mtetra
.617 .67 .879 r
.31838 .54911 .32435 .55685 .33393 .55502 .32798 .54709 Mtetra
.59 .655 .882 r
.32798 .54709 .33393 .55502 .34354 .55348 .33759 .54575 Mtetra
.572 .654 .892 r
.33759 .54575 .34354 .55348 .3532 .55176 .34722 .54478 Mtetra
.552 .67 .916 r
.34722 .54478 .3532 .55176 .36293 .54954 .35689 .54407 Mtetra
.57 .732 .952 r
.35689 .54407 .36293 .54954 .37275 .54605 .36663 .54266 Mtetra
.618 .834 .983 r
.36663 .54266 .37275 .54605 .38269 .54066 .37649 .53983 Mtetra
.686 .945 .96 r
.37649 .53983 .38269 .54066 .39272 .53351 .38648 .53476 Mtetra
.767 .994 .873 r
.38648 .53476 .39272 .53351 .40282 .52465 .3966 .52678 Mtetra
.805 1 .825 r
.3966 .52678 .40282 .52465 .4129 .5164 .40679 .51713 Mtetra
.866 .979 .85 r
.40679 .51713 .4129 .5164 .42293 .5104 .417 .50676 Mtetra
.799 .851 .889 r
.417 .50676 .42293 .5104 .43285 .50884 .42712 .49936 Mtetra
.617 .631 .843 r
.42712 .49936 .43285 .50884 .44267 .51296 .43711 .49725 Mtetra
.454 .444 .757 r
.43711 .49725 .44267 .51296 .45251 .52012 .447 .5009 Mtetra
.314 .32 .706 r
.447 .5009 .45251 .52012 .46244 .52798 .45687 .50994 Mtetra
.335 .345 .722 r
.45687 .50994 .46244 .52798 .47257 .52906 .46687 .51789 Mtetra
.435 .507 .834 r
.46687 .51789 .47257 .52906 .4829 .5201 .47704 .52066 Mtetra
.698 .98 .898 r
.47704 .52066 .4829 .5201 .49329 .50488 .4874 .51395 Mtetra
.618 .812 .396 r
.4874 .51395 .49329 .50488 .50366 .48681 .49786 .4974 Mtetra
0 0 0 r
.49786 .4974 .50366 .48681 .51396 .47566 .50828 .48022 Mtetra
.809 .968 .656 r
.50828 .48022 .51396 .47566 .52424 .47408 .51864 .46634 Mtetra
.789 .736 .803 r
.51864 .46634 .52424 .47408 .53459 .47622 .52898 .45707 Mtetra
.635 .524 .711 r
.52898 .45707 .53459 .47622 .54501 .47878 .53934 .4526 Mtetra
.603 .469 .672 r
.53934 .4526 .54501 .47878 .55545 .47549 .54975 .44927 Mtetra
.588 .46 .673 r
.54975 .44927 .55545 .47549 .56585 .46634 .5602 .44708 Mtetra
.505 .445 .723 r
.5602 .44708 .56585 .46634 .57627 .45758 .57077 .44972 Mtetra
.005 .329 .814 r
.57077 .44972 .57627 .45758 .58676 .45255 .5815 .45702 Mtetra
.726 .267 .161 r
.5815 .45702 .58676 .45255 .5975 .45716 .59241 .46768 Mtetra
.683 .288 .292 r
.59241 .46768 .5975 .45716 .6085 .46879 .60344 .47776 Mtetra
.456 .03 .14 r
.60344 .47776 .6085 .46879 .61957 .47759 .61432 .47793 Mtetra
.807 .997 .858 r
.61432 .47793 .61957 .47759 .63055 .48009 .62499 .4685 Mtetra
.81 .686 .727 r
.62499 .4685 .63055 .48009 .64126 .4724 .63547 .45378 Mtetra
.761 .603 .682 r
.63547 .45378 .64126 .4724 .65171 .45782 .64589 .43792 Mtetra
.703 .563 .693 r
.64589 .43792 .65171 .45782 .66216 .44389 .65648 .42752 Mtetra
.645 .555 .739 r
.65648 .42752 .66216 .44389 .67272 .43304 .66732 .42295 Mtetra
.508 .575 .858 r
.66732 .42295 .67272 .43304 .68355 .42797 .67845 .4238 Mtetra
.035 .493 .883 r
.67845 .4238 .68355 .42797 .69465 .42743 .68981 .42769 Mtetra
.337 0 0 r
.68981 .42769 .69465 .42743 .70595 .42921 .70123 .43088 Mtetra
.299 0 0 r
.70123 .43088 .70595 .42921 .71736 .43165 .71264 .43238 Mtetra
0 0 0 r
.71264 .43238 .71736 .43165 .72875 .43233 .72395 .43089 Mtetra
.543 .905 .966 r
.72395 .43089 .72875 .43233 .7401 .43122 .73516 .42709 Mtetra
.714 .863 .952 r
.73516 .42709 .7401 .43122 .75137 .42815 .74632 .42182 Mtetra
.735 .786 .894 r
.74632 .42182 .75137 .42815 .76259 .42376 .75746 .41582 Mtetra
.717 .732 .863 r
.75746 .41582 .76259 .42376 .77381 .41884 .76865 .41008 Mtetra
.701 .705 .85 r
.76865 .41008 .77381 .41884 .78505 .41373 .7799 .40472 Mtetra
.682 .692 .853 r
.7799 .40472 .78505 .41373 .79635 .40892 .79124 .40005 Mtetra
.669 .69 .861 r
.79124 .40005 .79635 .40892 .80771 .4044 .80266 .39589 Mtetra
.658 .696 .873 r
.80266 .39589 .80771 .4044 .81915 .40024 .81417 .39213 Mtetra
.65 .704 .886 r
.81417 .39213 .81915 .40024 .83066 .39636 .82574 .38864 Mtetra
.647 .715 .897 r
.82574 .38864 .83066 .39636 .84223 .39266 .83737 .38526 Mtetra
.644 .724 .907 r
.83737 .38526 .84223 .39266 .85386 .38909 .84906 .38194 Mtetra
.643 .733 .914 r
.84906 .38194 .85386 .38909 .86554 .38558 .8608 .37862 Mtetra
.644 .741 .919 r
.8608 .37862 .86554 .38558 .87727 .38207 .87259 .37524 Mtetra
.671 .755 .914 r
.24535 .5654 .25164 .57089 .26109 .56761 .25482 .56205 Mtetra
.674 .754 .911 r
.25482 .56205 .26109 .56761 .27057 .56428 .26434 .5586 Mtetra
.677 .751 .907 r
.26434 .5586 .27057 .56428 .28009 .56095 .27389 .55507 Mtetra
.678 .745 .902 r
.27389 .55507 .28009 .56095 .28963 .55769 .28347 .55148 Mtetra
.679 .735 .893 r
.28347 .55148 .28963 .55769 .2992 .55453 .29309 .54782 Mtetra
.674 .719 .883 r
.29309 .54782 .2992 .55453 .30878 .55162 .30273 .54425 Mtetra
.664 .698 .871 r
.30273 .54425 .30878 .55162 .31838 .54911 .3124 .5409 Mtetra
.645 .669 .859 r
.3124 .5409 .31838 .54911 .32798 .54709 .32206 .53806 Mtetra
.617 .639 .85 r
.32206 .53806 .32798 .54709 .33759 .54575 .33172 .53601 Mtetra
.585 .609 .843 r
.33172 .53601 .33759 .54575 .34722 .54478 .34136 .53486 Mtetra
.542 .586 .848 r
.34136 .53486 .34722 .54478 .35689 .54407 .351 .53484 Mtetra
.515 .59 .867 r
.351 .53484 .35689 .54407 .36663 .54266 .36066 .5353 Mtetra
.484 .63 .917 r
.36066 .5353 .36663 .54266 .37649 .53983 .37038 .53582 Mtetra
.501 .77 .992 r
.37038 .53582 .37649 .53983 .38648 .53476 .38022 .53479 Mtetra
.52 .911 .926 r
.38022 .53479 .38648 .53476 .3966 .52678 .39023 .53099 Mtetra
.469 .849 .625 r
.39023 .53099 .3966 .52678 .40679 .51713 .4004 .52356 Mtetra
.6 .871 .541 r
.4004 .52356 .40679 .51713 .417 .50676 .41072 .512 Mtetra
.753 .956 .651 r
.41072 .512 .417 .50676 .42712 .49936 .42106 .49951 Mtetra
.886 .96 .841 r
.42106 .49951 .42712 .49936 .43711 .49725 .43135 .48832 Mtetra
.723 .686 .814 r
.43135 .48832 .43711 .49725 .447 .5009 .44149 .48213 Mtetra
.537 .466 .723 r
.44149 .48213 .447 .5009 .45687 .50994 .4515 .48315 Mtetra
.43 .35 .665 r
.4515 .48315 .45687 .50994 .46687 .51789 .46145 .49067 Mtetra
.328 .279 .65 r
.46145 .49067 .46687 .51789 .47704 .52066 .47142 .50297 Mtetra
.323 .343 .727 r
.47142 .50297 .47704 .52066 .4874 .51395 .48158 .51107 Mtetra
.385 .77 .99 r
.48158 .51107 .4874 .51395 .49786 .4974 .49194 .51047 Mtetra
.087 0 .063 r
.49194 .51047 .49786 .4974 .50828 .48022 .50241 .50054 Mtetra
.016 0 .15 r
.50241 .50054 .50828 .48022 .51864 .46634 .51292 .48293 Mtetra
0 0 .056 r
.51292 .48293 .51864 .46634 .52898 .45707 .52337 .46628 Mtetra
0 0 0 r
.52337 .46628 .52898 .45707 .53934 .4526 .53379 .45478 Mtetra
.53379 .45478 .53934 .4526 .54975 .44927 .54424 .45143 Mtetra
.557 .012 0 r
.54424 .45143 .54975 .44927 .5602 .44708 .55481 .45627 Mtetra
.691 .286 .275 r
.55481 .45627 .5602 .44708 .57077 .44972 .56554 .4663 Mtetra
.668 .315 .366 r
.56554 .4663 .57077 .44972 .5815 .45702 .57641 .47734 Mtetra
.563 .23 .363 r
.57641 .47734 .5815 .45702 .59241 .46768 .58727 .4807 Mtetra
.288 0 .163 r
.58727 .4807 .59241 .46768 .60344 .47776 .59801 .47465 Mtetra
.913 .872 .784 r
.59801 .47465 .60344 .47776 .61432 .47793 .60855 .4598 Mtetra
.787 .62 .673 r
.60855 .4598 .61432 .47793 .62499 .4685 .61893 .44064 Mtetra
.7 .528 .652 r
.61893 .44064 .62499 .4685 .63547 .45378 .62941 .42629 Mtetra
.646 .494 .663 r
.62941 .42629 .63547 .45378 .64589 .43792 .64008 .41849 Mtetra
.567 .485 .722 r
.64008 .41849 .64589 .43792 .65648 .42752 .65106 .41803 Mtetra
.307 .476 .863 r
.65106 .41803 .65648 .42752 .66732 .42295 .66231 .42269 Mtetra
.505 0 0 r
.66231 .42269 .66732 .42295 .67845 .4238 .67372 .4287 Mtetra
.58 .083 .04 r
.67372 .4287 .67845 .4238 .68981 .42769 .6852 .4338 Mtetra
.434 0 .008 r
.6852 .4338 .68981 .42769 .70123 .43088 .69656 .43468 Mtetra
.094 0 0 r
.69656 .43468 .70123 .43088 .71264 .43238 .70779 .43185 Mtetra
.623 .954 .921 r
.70779 .43185 .71264 .43238 .72395 .43089 .7189 .42616 Mtetra
.781 .853 .905 r
.7189 .42616 .72395 .43089 .73516 .42709 .72993 .41886 Mtetra
.749 .735 .839 r
.72993 .41886 .73516 .42709 .74632 .42182 .74099 .41161 Mtetra
.721 .682 .811 r
.74099 .41161 .74632 .42182 .75746 .41582 .7521 .40484 Mtetra
.692 .655 .809 r
.7521 .40484 .75746 .41582 .76865 .41008 .76332 .39923 Mtetra
.672 .648 .818 r
.76332 .39923 .76865 .41008 .7799 .40472 .77464 .39455 Mtetra
.655 .655 .837 r
.77464 .39455 .7799 .40472 .79124 .40005 .78607 .39068 Mtetra
.643 .668 .859 r
.78607 .39068 .79124 .40005 .80266 .39589 .79759 .38734 Mtetra
.638 .687 .88 r
.79759 .38734 .80266 .39589 .81417 .39213 .80917 .38422 Mtetra
.634 .704 .897 r
.80917 .38422 .81417 .39213 .82574 .38864 .82082 .38121 Mtetra
.636 .72 .909 r
.82082 .38121 .82574 .38864 .83737 .38526 .83251 .37811 Mtetra
.637 .731 .917 r
.83251 .37811 .83737 .38526 .84906 .38194 .84425 .37496 Mtetra
.639 .739 .921 r
.84425 .37496 .84906 .38194 .8608 .37862 .85604 .37172 Mtetra
.642 .743 .923 r
.85604 .37172 .8608 .37862 .87259 .37524 .86786 .36837 Mtetra
.665 .754 .916 r
.23902 .55988 .24535 .5654 .25482 .56205 .2485 .55665 Mtetra
.669 .76 .918 r
.2485 .55665 .25482 .56205 .26434 .5586 .25802 .55332 Mtetra
.674 .766 .92 r
.25802 .55332 .26434 .5586 .27389 .55507 .26759 .54985 Mtetra
.68 .77 .919 r
.26759 .54985 .27389 .55507 .28347 .55148 .2772 .5462 Mtetra
.689 .771 .913 r
.2772 .5462 .28347 .55148 .29309 .54782 .28686 .5423 Mtetra
.693 .764 .906 r
.28686 .5423 .29309 .54782 .30273 .54425 .29655 .53827 Mtetra
.696 .749 .893 r
.29655 .53827 .30273 .54425 .3124 .5409 .30629 .5341 Mtetra
.684 .722 .878 r
.30629 .5341 .3124 .5409 .32206 .53806 .31604 .53016 Mtetra
.665 .686 .86 r
.31604 .53016 .32206 .53806 .33172 .53601 .32579 .52669 Mtetra
.631 .64 .841 r
.32579 .52669 .33172 .53601 .34136 .53486 .33552 .52417 Mtetra
.585 .591 .825 r
.33552 .52417 .34136 .53486 .351 .53484 .34522 .52303 Mtetra
.54 .548 .812 r
.34522 .52303 .351 .53484 .36066 .5353 .35489 .52327 Mtetra
.484 .515 .814 r
.35489 .52327 .36066 .5353 .37038 .53582 .36455 .52501 Mtetra
.466 .53 .839 r
.36455 .52501 .37038 .53582 .38022 .53479 .37426 .52685 Mtetra
.47 .608 .906 r
.37426 .52685 .38022 .53479 .39023 .53099 .38409 .52774 Mtetra
.562 .828 .995 r
.38409 .52774 .39023 .53099 .4004 .52356 .39409 .52554 Mtetra
.632 .962 .828 r
.39409 .52554 .4004 .52356 .41072 .512 .40431 .51871 Mtetra
0 0 0 r
.40431 .51871 .41072 .512 .42106 .49951 .41466 .50799 Mtetra
.568 .811 .428 r
.41466 .50799 .42106 .49951 .43135 .48832 .42511 .49408 Mtetra
.722 .935 .61 r
.42511 .49408 .43135 .48832 .44149 .48213 .4355 .48124 Mtetra
.84 .951 .889 r
.4355 .48124 .44149 .48213 .4515 .48315 .44578 .47232 Mtetra
.598 .599 .823 r
.44578 .47232 .4515 .48315 .46145 .49067 .45591 .4707 Mtetra
.397 .369 .71 r
.45591 .4707 .46145 .49067 .47142 .50297 .46593 .47738 Mtetra
.378 .322 .667 r
.46593 .47738 .47142 .50297 .48158 .51107 .47602 .48684 Mtetra
.389 .337 .678 r
.47602 .48684 .48158 .51107 .49194 .51047 .48623 .49541 Mtetra
.511 .49 .77 r
.48623 .49541 .49194 .51047 .50241 .50054 .49662 .497 Mtetra
.778 .871 .917 r
.49662 .497 .50241 .50054 .51292 .48293 .50712 .49023 Mtetra
0 0 0 r
.50712 .49023 .51292 .48293 .52337 .46628 .51765 .48099 Mtetra
.213 0 .156 r
.51765 .48099 .52337 .46628 .53379 .45478 .52818 .47243 Mtetra
.428 .091 .29 r
.52818 .47243 .53379 .45478 .54424 .45143 .53874 .46908 Mtetra
.538 .193 .331 r
.53874 .46908 .54424 .45143 .55481 .45627 .54937 .47096 Mtetra
.547 .181 .298 r
.54937 .47096 .55481 .45627 .56554 .4663 .56009 .47354 Mtetra
.424 0 .057 r
.56009 .47354 .56554 .4663 .57641 .47734 .57086 .47366 Mtetra
.815 .876 .891 r
.57086 .47366 .57641 .47734 .58727 .4807 .58155 .46535 Mtetra
.781 .636 .7 r
.58155 .46535 .58727 .4807 .59801 .47465 .5921 .44998 Mtetra
.729 .557 .658 r
.5921 .44998 .59801 .47465 .60855 .4598 .60259 .43367 Mtetra
.701 .534 .659 r
.60259 .43367 .60855 .4598 .61893 .44064 .61311 .42013 Mtetra
.638 .52 .704 r
.61311 .42013 .61893 .44064 .62941 .42629 .62386 .41498 Mtetra
.461 .524 .836 r
.62386 .41498 .62941 .42629 .64008 .41849 .6349 .41724 Mtetra
.475 0 0 r
.6349 .41724 .64008 .41849 .65106 .41803 .64617 .42352 Mtetra
.647 .173 .115 r
.64617 .42352 .65106 .41803 .66231 .42269 .65759 .43092 Mtetra
.568 .127 .162 r
.65759 .43092 .66231 .42269 .67372 .4287 .66899 .43511 Mtetra
.409 0 .006 r
.66899 .43511 .67372 .4287 .6852 .4338 .6803 .43534 Mtetra
.318 .795 .714 r
.6803 .43534 .6852 .4338 .69656 .43468 .69144 .43082 Mtetra
.795 .886 .911 r
.69144 .43082 .69656 .43468 .70779 .43185 .70244 .42311 Mtetra
.771 .73 .815 r
.70244 .42311 .70779 .43185 .7189 .42616 .7134 .41442 Mtetra
.74 .663 .775 r
.7134 .41442 .7189 .42616 .72993 .41886 .72437 .40581 Mtetra
.704 .628 .769 r
.72437 .40581 .72993 .41886 .74099 .41161 .73545 .39873 Mtetra
.68 .619 .78 r
.73545 .39873 .74099 .41161 .7521 .40484 .74665 .39305 Mtetra
.657 .625 .806 r
.74665 .39305 .7521 .40484 .76332 .39923 .75799 .38881 Mtetra
.638 .642 .837 r
.75799 .38881 .76332 .39923 .77464 .39455 .76944 .38555 Mtetra
.627 .67 .872 r
.76944 .38555 .77464 .39455 .78607 .39068 .78098 .38277 Mtetra
.617 .697 .901 r
.78098 .38277 .78607 .39068 .79759 .38734 .7926 .38023 Mtetra
.619 .723 .921 r
.7926 .38023 .79759 .38734 .80917 .38422 .80426 .37756 Mtetra
.622 .741 .932 r
.80426 .37756 .80917 .38422 .82082 .38121 .81596 .37474 Mtetra
.63 .753 .936 r
.81596 .37474 .82082 .38121 .83251 .37811 .82769 .37166 Mtetra
.637 .757 .935 r
.82769 .37166 .83251 .37811 .84425 .37496 .83946 .36839 Mtetra
.643 .756 .931 r
.83946 .36839 .84425 .37496 .85604 .37172 .85126 .36497 Mtetra
.647 .753 .927 r
.85126 .36497 .85604 .37172 .86786 .36837 .8631 .36144 Mtetra
.651 .75 .922 r
.23264 .55431 .23902 .55988 .2485 .55665 .24212 .55139 Mtetra
.652 .762 .93 r
.24212 .55139 .2485 .55665 .25802 .55332 .25163 .54841 Mtetra
.658 .777 .937 r
.25163 .54841 .25802 .55332 .26759 .54985 .26119 .54528 Mtetra
.667 .793 .942 r
.26119 .54528 .26759 .54985 .2772 .5462 .27081 .54189 Mtetra
.681 .807 .942 r
.27081 .54189 .2772 .5462 .28686 .5423 .28048 .53816 Mtetra
.697 .817 .939 r
.28048 .53816 .28686 .5423 .29655 .53827 .29021 .53403 Mtetra
.716 .816 .927 r
.29021 .53403 .29655 .53827 .30629 .5341 .3 .52939 Mtetra
.725 .8 .911 r
.3 .52939 .30629 .5341 .31604 .53016 .30984 .52446 Mtetra
.726 .767 .886 r
.30984 .52446 .31604 .53016 .32579 .52669 .31971 .51932 Mtetra
.703 .713 .857 r
.31971 .51932 .32579 .52669 .33552 .52417 .32959 .5146 Mtetra
.666 .65 .825 r
.32959 .5146 .33552 .52417 .34522 .52303 .33944 .51077 Mtetra
.613 .579 .792 r
.33944 .51077 .34522 .52303 .35489 .52327 .34924 .50857 Mtetra
.55 .513 .767 r
.34924 .50857 .35489 .52327 .36455 .52501 .35896 .50867 Mtetra
.497 .463 .75 r
.35896 .50867 .36455 .52501 .37426 .52685 .36865 .51081 Mtetra
.431 .427 .754 r
.36865 .51081 .37426 .52685 .38409 .52774 .37831 .51492 Mtetra
.393 .451 .802 r
.37831 .51492 .38409 .52774 .39409 .52554 .38806 .51892 Mtetra
.32 .58 .935 r
.38806 .51892 .39409 .52554 .40431 .51871 .39796 .52121 Mtetra
0 0 0 r
.39796 .52121 .40431 .51871 .41466 .50799 .40808 .51903 Mtetra
.047 0 0 r
.40808 .51903 .41466 .50799 .42511 .49408 .41845 .51064 Mtetra
.033 0 .088 r
.41845 .51064 .42511 .49408 .4355 .48124 .42895 .4976 Mtetra
0 0 0 r
.42895 .4976 .4355 .48124 .44578 .47232 .43953 .4812 Mtetra
.618 .826 .425 r
.43953 .4812 .44578 .47232 .45591 .4707 .45004 .46564 Mtetra
.851 .806 .806 r
.45004 .46564 .45591 .4707 .46593 .47738 .46043 .45399 Mtetra
.611 .486 .685 r
.46043 .45399 .46593 .47738 .47602 .48684 .47068 .4503 Mtetra
.491 .362 .633 r
.47068 .4503 .47602 .48684 .48623 .49541 .48085 .45584 Mtetra
.432 .314 .619 r
.48085 .45584 .48623 .49541 .49662 .497 .49105 .4666 Mtetra
.344 .279 .639 r
.49105 .4666 .49662 .497 .50712 .49023 .50137 .47952 Mtetra
0 .24 .751 r
.50137 .47952 .50712 .49023 .51765 .48099 .51184 .4891 Mtetra
.553 .116 .164 r
.51184 .4891 .51765 .48099 .52818 .47243 .52245 .49248 Mtetra
.441 .115 .315 r
.52245 .49248 .52818 .47243 .53874 .46908 .53311 .48913 Mtetra
.272 0 .251 r
.53311 .48913 .53874 .46908 .54937 .47096 .54379 .47904 Mtetra
.635 .83 .423 r
.54379 .47904 .54937 .47096 .56009 .47354 .5544 .46269 Mtetra
.852 .706 .699 r
.5544 .46269 .56009 .47354 .57086 .47366 .56493 .44293 Mtetra
.711 .528 .639 r
.56493 .44293 .57086 .47366 .58155 .46535 .57543 .4253 Mtetra
.65 .469 .625 r
.57543 .4253 .58155 .46535 .5921 .44998 .58597 .41289 Mtetra
.584 .428 .636 r
.58597 .41289 .5921 .44998 .60259 .43367 .5967 .40977 Mtetra
.471 .396 .69 r
.5967 .40977 .60259 .43367 .61311 .42013 .60768 .41473 Mtetra
0 .145 .639 r
.60768 .41473 .61311 .42013 .62386 .41498 .61888 .42368 Mtetra
.684 .263 .24 r
.61888 .42368 .62386 .41498 .6349 .41724 .63023 .43353 Mtetra
.607 .245 .33 r
.63023 .43353 .6349 .41724 .64617 .42352 .6416 .44001 Mtetra
.529 .172 .306 r
.6416 .44001 .64617 .42352 .65759 .43092 .65289 .44178 Mtetra
.298 0 .112 r
.65289 .44178 .65759 .43092 .66899 .43511 .664 .4372 Mtetra
.657 .957 .745 r
.664 .4372 .66899 .43511 .6803 .43534 .67493 .42805 Mtetra
.823 .777 .809 r
.67493 .42805 .6803 .43534 .69144 .43082 .68578 .41712 Mtetra
.755 .644 .738 r
.68578 .41712 .69144 .43082 .70244 .42311 .69661 .40605 Mtetra
.705 .586 .72 r
.69661 .40605 .70244 .42311 .7134 .41442 .70755 .39697 Mtetra
.675 .567 .726 r
.70755 .39697 .7134 .41442 .72437 .40581 .71863 .38999 Mtetra
.646 .566 .75 r
.71863 .38999 .72437 .40581 .73545 .39873 .72987 .38537 Mtetra
.622 .583 .789 r
.72987 .38537 .73545 .39873 .74665 .39305 .74127 .38242 Mtetra
.603 .62 .842 r
.74127 .38242 .74665 .39305 .75799 .38881 .75278 .3804 Mtetra
.583 .666 .895 r
.75278 .3804 .75799 .38881 .76944 .38555 .76439 .37882 Mtetra
.579 .719 .939 r
.76439 .37882 .76944 .38555 .78098 .38277 .77604 .37703 Mtetra
.579 .757 .963 r
.77604 .37703 .78098 .38277 .7926 .38023 .78773 .37493 Mtetra
.597 .784 .97 r
.78773 .37493 .7926 .38023 .80426 .37756 .79943 .37231 Mtetra
.616 .795 .968 r
.79943 .37231 .80426 .37756 .81596 .37474 .81116 .36927 Mtetra
.635 .795 .959 r
.81116 .36927 .81596 .37474 .82769 .37166 .8229 .36586 Mtetra
.648 .788 .949 r
.8229 .36586 .82769 .37166 .83946 .36839 .83466 .3622 Mtetra
.656 .778 .938 r
.83466 .3622 .83946 .36839 .85126 .36497 .84646 .35836 Mtetra
.659 .765 .928 r
.84646 .35836 .85126 .36497 .8631 .36144 .85831 .35446 Mtetra
.635 .746 .928 r
.22623 .54871 .23264 .55431 .24212 .55139 .23569 .54612 Mtetra
.633 .758 .938 r
.23569 .54612 .24212 .55139 .25163 .54841 .24519 .54353 Mtetra
.634 .774 .948 r
.24519 .54353 .25163 .54841 .26119 .54528 .25474 .54086 Mtetra
.639 .795 .957 r
.25474 .54086 .26119 .54528 .27081 .54189 .26433 .538 Mtetra
.648 .818 .965 r
.26433 .538 .27081 .54189 .28048 .53816 .27399 .53485 Mtetra
.664 .846 .97 r
.27399 .53485 .28048 .53816 .29021 .53403 .28371 .53126 Mtetra
.69 .873 .967 r
.28371 .53126 .29021 .53403 .3 .52939 .2935 .52703 Mtetra
.717 .892 .96 r
.2935 .52703 .3 .52939 .30984 .52446 .30337 .52213 Mtetra
.751 .896 .943 r
.30337 .52213 .30984 .52446 .31971 .51932 .31332 .51643 Mtetra
.765 .875 .927 r
.31332 .51643 .31971 .51932 .32959 .5146 .3233 .51037 Mtetra
.764 .825 .9 r
.3233 .51037 .32959 .5146 .33944 .51077 .33332 .50417 Mtetra
.724 .743 .867 r
.33332 .50417 .33944 .51077 .34924 .50857 .34331 .49883 Mtetra
.661 .646 .825 r
.34331 .49883 .34924 .50857 .35896 .50867 .35323 .49513 Mtetra
.586 .548 .779 r
.35323 .49513 .35896 .50867 .36865 .51081 .36307 .49386 Mtetra
.505 .463 .743 r
.36307 .49386 .36865 .51081 .37831 .51492 .37281 .49576 Mtetra
.452 .41 .721 r
.37281 .49576 .37831 .51492 .38806 .51892 .38252 .49998 Mtetra
.399 .379 .72 r
.38252 .49998 .38806 .51892 .39796 .52121 .39225 .50589 Mtetra
.412 .427 .765 r
.39225 .50589 .39796 .52121 .40808 .51903 .40212 .51029 Mtetra
.495 .601 .888 r
.40212 .51029 .40808 .51903 .41845 .51064 .41221 .5109 Mtetra
.567 .934 .916 r
.41221 .5109 .41845 .51064 .42895 .4976 .42252 .50621 Mtetra
0 0 0 r
.42252 .50621 .42895 .4976 .43953 .4812 .43303 .49541 Mtetra
.43303 .49541 .43953 .4812 .45004 .46564 .44363 .48063 Mtetra
.44363 .48063 .45004 .46564 .46043 .45399 .45423 .46411 Mtetra
.45423 .46411 .46043 .45399 .47068 .4503 .46472 .45196 Mtetra
.444 .875 .787 r
.46472 .45196 .47068 .4503 .48085 .45584 .47507 .44702 Mtetra
.424 .562 .889 r
.47507 .44702 .48085 .45584 .49105 .4666 .48538 .44898 Mtetra
.341 .356 .731 r
.48538 .44898 .49105 .4666 .50137 .47952 .4957 .4564 Mtetra
.421 .366 .691 r
.4957 .4564 .50137 .47952 .51184 .4891 .50614 .46313 Mtetra
.511 .411 .678 r
.50614 .46313 .51184 .4891 .52245 .49248 .5167 .46596 Mtetra
.6 .468 .673 r
.5167 .46596 .52245 .49248 .53311 .48913 .52733 .46256 Mtetra
.666 .511 .664 r
.52733 .46256 .53311 .48913 .54379 .47904 .53797 .45294 Mtetra
.702 .535 .659 r
.53797 .45294 .54379 .47904 .5544 .46269 .54859 .43937 Mtetra
.72 .557 .667 r
.54859 .43937 .5544 .46269 .56493 .44293 .55918 .42507 Mtetra
.697 .573 .711 r
.55918 .42507 .56493 .44293 .57543 .4253 .56981 .41624 Mtetra
.601 .648 .868 r
.56981 .41624 .57543 .4253 .58597 .41289 .58057 .41435 Mtetra
.552 0 0 r
.58057 .41435 .58597 .41289 .5967 .40977 .59153 .41976 Mtetra
.679 .272 .268 r
.59153 .41976 .5967 .40977 .60768 .41473 .6027 .42963 Mtetra
.634 .263 .323 r
.6027 .42963 .60768 .41473 .61888 .42368 .61396 .43779 Mtetra
.571 .194 .287 r
.61396 .43779 .61888 .42368 .63023 .43353 .62521 .44194 Mtetra
.344 0 .05 r
.62521 .44194 .63023 .43353 .6416 .44001 .63635 .43988 Mtetra
.72 .984 .897 r
.63635 .43988 .6416 .44001 .65289 .44178 .64734 .43242 Mtetra
.803 .725 .779 r
.64734 .43242 .65289 .44178 .664 .4372 .65819 .42107 Mtetra
.755 .62 .71 r
.65819 .42107 .664 .4372 .67493 .42805 .66896 .40814 Mtetra
.712 .57 .694 r
.66896 .40814 .67493 .42805 .68578 .41712 .67979 .39691 Mtetra
.684 .553 .699 r
.67979 .39691 .68578 .41712 .69661 .40605 .69074 .38805 Mtetra
.653 .55 .726 r
.69074 .38805 .69661 .40605 .70755 .39697 .70187 .38242 Mtetra
.622 .567 .772 r
.70187 .38242 .70755 .39697 .71863 .38999 .71318 .37929 Mtetra
.585 .61 .844 r
.71318 .37929 .71863 .38999 .72987 .38537 .72464 .37785 Mtetra
.53 .668 .925 r
.72464 .37785 .72987 .38537 .74127 .38242 .73623 .3773 Mtetra
.482 .737 .983 r
.73623 .3773 .74127 .38242 .75278 .3804 .74787 .37663 Mtetra
.45 .779 .998 r
.74787 .37663 .75278 .3804 .76439 .37882 .75956 .37558 Mtetra
.484 .819 .999 r
.75956 .37558 .76439 .37882 .77604 .37703 .77125 .37371 Mtetra
.536 .842 .999 r
.77125 .37371 .77604 .37703 .78773 .37493 .78295 .37115 Mtetra
.594 .848 .993 r
.78295 .37115 .78773 .37493 .79943 .37231 .79464 .36792 Mtetra
.633 .84 .98 r
.79464 .36792 .79943 .37231 .81116 .36927 .80635 .36422 Mtetra
.655 .822 .963 r
.80635 .36422 .81116 .36927 .8229 .36586 .81808 .36023 Mtetra
.668 .804 .948 r
.81808 .36023 .8229 .36586 .83466 .3622 .82984 .35603 Mtetra
.673 .787 .935 r
.82984 .35603 .83466 .3622 .84646 .35836 .84163 .35172 Mtetra
.672 .771 .924 r
.84163 .35172 .84646 .35836 .85831 .35446 .85348 .34743 Mtetra
.624 .743 .932 r
.21976 .54307 .22623 .54871 .23569 .54612 .22923 .54069 Mtetra
.617 .75 .941 r
.22923 .54069 .23569 .54612 .24519 .54353 .23872 .53841 Mtetra
.612 .76 .95 r
.23872 .53841 .24519 .54353 .25474 .54086 .24825 .53616 Mtetra
.608 .776 .961 r
.24825 .53616 .25474 .54086 .26433 .538 .25782 .53388 Mtetra
.6 .799 .976 r
.25782 .53388 .26433 .538 .27399 .53485 .26744 .53157 Mtetra
.599 .834 .988 r
.26744 .53157 .27399 .53485 .28371 .53126 .27711 .52898 Mtetra
.599 .874 .993 r
.27711 .52898 .28371 .53126 .2935 .52703 .28685 .52595 Mtetra
.607 .916 .977 r
.28685 .52595 .2935 .52703 .30337 .52213 .29668 .52216 Mtetra
.632 .95 .943 r
.29668 .52216 .30337 .52213 .31332 .51643 .30662 .51731 Mtetra
.669 .971 .906 r
.30662 .51731 .31332 .51643 .3233 .51037 .31664 .51134 Mtetra
.748 .987 .896 r
.31664 .51134 .3233 .51037 .33332 .50417 .32677 .50405 Mtetra
.807 .968 .906 r
.32677 .50405 .33332 .50417 .34331 .49883 .33694 .49612 Mtetra
.821 .88 .888 r
.33694 .49612 .34331 .49883 .35323 .49513 .34714 .48796 Mtetra
.756 .736 .834 r
.34714 .48796 .35323 .49513 .36307 .49386 .35729 .48093 Mtetra
.667 .599 .769 r
.35729 .48093 .36307 .49386 .37281 .49576 .36734 .47612 Mtetra
.585 .49 .713 r
.36734 .47612 .37281 .49576 .38252 .49998 .37728 .47449 Mtetra
.514 .412 .676 r
.37728 .47449 .38252 .49998 .39225 .50589 .3871 .47687 Mtetra
.463 .363 .656 r
.3871 .47687 .39225 .50589 .40212 .51029 .39686 .4826 Mtetra
.403 .328 .657 r
.39686 .4826 .40212 .51029 .41221 .5109 .40662 .49106 Mtetra
.343 .336 .707 r
.40662 .49106 .41221 .5109 .42252 .50621 .4165 .499 Mtetra
.084 .419 .866 r
.4165 .499 .42252 .50621 .43303 .49541 .42658 .50409 Mtetra
.46 .025 .125 r
.42658 .50409 .43303 .49541 .44363 .48063 .43686 .50465 Mtetra
.416 .107 .331 r
.43686 .50465 .44363 .48063 .45423 .46411 .44735 .49933 Mtetra
.37 .101 .37 r
.44735 .49933 .45423 .46411 .46472 .45196 .45799 .48765 Mtetra
.277 .025 .34 r
.45799 .48765 .46472 .45196 .47507 .44702 .46872 .47027 Mtetra
.006 0 .16 r
.46872 .47027 .47507 .44702 .48538 .44898 .47943 .45069 Mtetra
.961 .933 .714 r
.47943 .45069 .48538 .44898 .4957 .4564 .49007 .43158 Mtetra
.719 .549 .659 r
.49007 .43158 .4957 .4564 .50614 .46313 .50062 .41652 Mtetra
.618 .436 .614 r
.50062 .41652 .50614 .46313 .5167 .46596 .51111 .40726 Mtetra
.571 .39 .598 r
.51111 .40726 .5167 .46596 .52733 .46256 .5216 .4038 Mtetra
.534 .363 .596 r
.5216 .4038 .52733 .46256 .53797 .45294 .53214 .40615 Mtetra
.477 .336 .609 r
.53214 .40615 .53797 .45294 .54859 .43937 .54279 .41435 Mtetra
.304 .278 .664 r
.54279 .41435 .54859 .43937 .55918 .42507 .5536 .42666 Mtetra
.767 .281 .078 r
.5536 .42666 .55918 .42507 .56981 .41624 .56456 .4395 Mtetra
.639 .308 .395 r
.56456 .4395 .56981 .41624 .58057 .41435 .57564 .45019 Mtetra
.568 .273 .428 r
.57564 .45019 .58057 .41435 .59153 .41976 .58674 .45515 Mtetra
.507 .22 .412 r
.58674 .45515 .59153 .41976 .6027 .42963 .59781 .4537 Mtetra
.384 .082 .324 r
.59781 .4537 .6027 .42963 .61396 .43779 .60878 .44628 Mtetra
0 0 0 r
.60878 .44628 .61396 .43779 .62521 .44194 .61963 .43424 Mtetra
.861 .768 .758 r
.61963 .43424 .62521 .44194 .63635 .43988 .63038 .41927 Mtetra
.747 .586 .677 r
.63038 .41927 .63635 .43988 .64734 .43242 .64107 .40372 Mtetra
.685 .516 .652 r
.64107 .40372 .64734 .43242 .65819 .42107 .65183 .39092 Mtetra
.651 .49 .652 r
.65183 .39092 .65819 .42107 .66896 .40814 .66271 .38153 Mtetra
.62 .482 .672 r
.66271 .38153 .66896 .40814 .67979 .39691 .67379 .37622 Mtetra
.589 .492 .713 r
.67379 .37622 .67979 .39691 .69074 .38805 .68507 .37416 Mtetra
.541 .531 .793 r
.68507 .37416 .69074 .38805 .70187 .38242 .69652 .3744 Mtetra
.438 .604 .916 r
.69652 .3744 .70187 .38242 .71318 .37929 .70812 .37582 Mtetra
.231 .664 .957 r
.70812 .37582 .71318 .37929 .72464 .37785 .71978 .37702 Mtetra
.033 .599 .784 r
.71978 .37702 .72464 .37785 .73623 .3773 .73149 .37756 Mtetra
.056 .622 .715 r
.73149 .37756 .73623 .3773 .74787 .37663 .74318 .37676 Mtetra
.192 .723 .783 r
.74318 .37676 .74787 .37663 .75956 .37558 .75486 .37479 Mtetra
.398 .849 .909 r
.75486 .37479 .75956 .37558 .77125 .37371 .76652 .37173 Mtetra
.555 .901 .977 r
.76652 .37173 .77125 .37371 .78295 .37115 .77816 .36787 Mtetra
.639 .888 .986 r
.77816 .36787 .78295 .37115 .79464 .36792 .78982 .36355 Mtetra
.675 .857 .969 r
.78982 .36355 .79464 .36792 .80635 .36422 .80149 .35894 Mtetra
.684 .824 .951 r
.80149 .35894 .80635 .36422 .81808 .36023 .8132 .35427 Mtetra
.686 .801 .936 r
.8132 .35427 .81808 .36023 .82984 .35603 .82496 .34958 Mtetra
.685 .783 .925 r
.82496 .34958 .82984 .35603 .84163 .35172 .83676 .34492 Mtetra
.681 .77 .918 r
.83676 .34492 .84163 .35172 .85348 .34743 .84861 .34035 Mtetra
.629 .745 .931 r
.21326 .53739 .21976 .54307 .22923 .54069 .22275 .53489 Mtetra
.623 .739 .93 r
.22275 .53489 .22923 .54069 .23872 .53841 .23227 .53251 Mtetra
.616 .734 .931 r
.23227 .53251 .23872 .53841 .24825 .53616 .24181 .53028 Mtetra
.607 .733 .934 r
.24181 .53028 .24825 .53616 .25782 .53388 .25139 .52821 Mtetra
.592 .737 .944 r
.25139 .52821 .25782 .53388 .26744 .53157 .26098 .52637 Mtetra
.583 .752 .958 r
.26098 .52637 .26744 .53157 .27711 .52898 .27061 .52458 Mtetra
.569 .78 .978 r
.27061 .52458 .27711 .52898 .28685 .52595 .28029 .52277 Mtetra
.563 .83 .996 r
.28029 .52277 .28685 .52595 .29668 .52216 .29004 .52055 Mtetra
.553 .885 .988 r
.29004 .52055 .29668 .52216 .30662 .51731 .29988 .51763 Mtetra
.534 .919 .92 r
.29988 .51763 .30662 .51731 .31664 .51134 .30983 .51355 Mtetra
.527 .917 .805 r
.30983 .51355 .31664 .51134 .32677 .50405 .31991 .50789 Mtetra
.522 .893 .694 r
.31991 .50789 .32677 .50405 .33694 .49612 .3301 .50067 Mtetra
.603 .92 .676 r
.3301 .50067 .33694 .49612 .34714 .48796 .3404 .49178 Mtetra
.707 .971 .744 r
.3404 .49178 .34714 .48796 .35729 .48093 .35074 .48225 Mtetra
.825 .994 .859 r
.35074 .48225 .35729 .48093 .36734 .47612 .36107 .47279 Mtetra
.807 .865 .891 r
.36107 .47279 .36734 .47612 .37728 .47449 .37132 .46503 Mtetra
.688 .667 .824 r
.37132 .46503 .37728 .47449 .3871 .47687 .38146 .46023 Mtetra
.57 .506 .744 r
.38146 .46023 .3871 .47687 .39686 .4826 .39145 .45946 Mtetra
.476 .399 .69 r
.39145 .45946 .39686 .4826 .40662 .49106 .40133 .4634 Mtetra
.437 .351 .661 r
.40133 .4634 .40662 .49106 .4165 .499 .41119 .47015 Mtetra
.416 .332 .654 r
.41119 .47015 .4165 .499 .42658 .50409 .42111 .4783 Mtetra
.423 .352 .672 r
.42111 .4783 .42658 .50409 .43686 .50465 .43117 .4853 Mtetra
.468 .423 .724 r
.43117 .4853 .43686 .50465 .44735 .49933 .44141 .48894 Mtetra
.63 .63 .832 r
.44141 .48894 .44735 .49933 .45799 .48765 .45189 .48612 Mtetra
.861 .932 .87 r
.45189 .48612 .45799 .48765 .46872 .47027 .46255 .47596 Mtetra
.767 .946 .614 r
.46255 .47596 .46872 .47027 .47943 .45069 .47327 .46161 Mtetra
0 0 0 r
.47327 .46161 .47943 .45069 .49007 .43158 .48398 .44557 Mtetra
.48398 .44557 .49007 .43158 .50062 .41652 .49463 .43222 Mtetra
.222 0 .165 r
.49463 .43222 .50062 .41652 .51111 .40726 .50522 .42366 Mtetra
.405 .055 .255 r
.50522 .42366 .51111 .40726 .5216 .4038 .51581 .4202 Mtetra
.525 .168 .303 r
.51581 .4202 .5216 .4038 .53214 .40615 .52644 .42184 Mtetra
.609 .245 .326 r
.52644 .42184 .53214 .40615 .54279 .41435 .53717 .4283 Mtetra
.653 .277 .321 r
.53717 .4283 .54279 .41435 .5536 .42666 .54802 .43751 Mtetra
.638 .235 .263 r
.54802 .43751 .5536 .42666 .56456 .4395 .55898 .44507 Mtetra
.525 .034 .034 r
.55898 .44507 .56456 .4395 .57564 .45019 .57 .44843 Mtetra
.594 .911 .979 r
.57 .44843 .57564 .45019 .58674 .45515 .58098 .44439 Mtetra
.776 .691 .769 r
.58098 .44439 .58674 .45515 .59781 .4537 .59187 .4338 Mtetra
.738 .585 .685 r
.59187 .4338 .59781 .4537 .60878 .44628 .60268 .41977 Mtetra
.713 .541 .655 r
.60268 .41977 .60878 .44628 .61963 .43424 .61342 .40453 Mtetra
.689 .516 .648 r
.61342 .40453 .61963 .43424 .63038 .41927 .62417 .39069 Mtetra
.67 .507 .655 r
.62417 .39069 .63038 .41927 .64107 .40372 .63498 .37967 Mtetra
.638 .503 .683 r
.63498 .37967 .64107 .40372 .65183 .39092 .64598 .37343 Mtetra
.594 .52 .741 r
.64598 .37343 .65183 .39092 .66271 .38153 .65717 .37132 Mtetra
.495 .574 .864 r
.65717 .37132 .66271 .38153 .67379 .37622 .66855 .37225 Mtetra
.122 .572 .921 r
.66855 .37225 .67379 .37622 .68507 .37416 .68009 .37492 Mtetra
.327 0 0 r
.68009 .37492 .68507 .37416 .69652 .3744 .69173 .3777 Mtetra
.406 0 0 r
.69173 .3777 .69652 .3744 .70812 .37582 .70343 .37984 Mtetra
.332 0 0 r
.70343 .37984 .70812 .37582 .71978 .37702 .71512 .38027 Mtetra
.18 0 0 r
.71512 .38027 .71978 .37702 .73149 .37756 .72678 .3791 Mtetra
0 0 0 r
.72678 .3791 .73149 .37756 .74318 .37676 .7384 .37629 Mtetra
.454 .883 .899 r
.7384 .37629 .74318 .37676 .75486 .37479 .74999 .37229 Mtetra
.639 .916 .979 r
.74999 .37229 .75486 .37479 .76652 .37173 .76157 .36755 Mtetra
.698 .871 .963 r
.76157 .36755 .76652 .37173 .77816 .36787 .77316 .36237 Mtetra
.705 .822 .938 r
.77316 .36237 .77816 .36787 .78982 .36355 .78478 .35717 Mtetra
.703 .79 .919 r
.78478 .35717 .78982 .36355 .80149 .35894 .79645 .35201 Mtetra
.693 .77 .91 r
.79645 .35201 .80149 .35894 .8132 .35427 .80818 .34708 Mtetra
.687 .76 .907 r
.80818 .34708 .8132 .35427 .82496 .34958 .81996 .34232 Mtetra
.682 .756 .908 r
.81996 .34232 .82496 .34958 .83676 .34492 .8318 .3377 Mtetra
.677 .757 .911 r
.8318 .3377 .83676 .34492 .84861 .34035 .8437 .33321 Mtetra
.649 .75 .923 r
.20671 .53168 .21326 .53739 .22275 .53489 .21626 .52872 Mtetra
.645 .734 .914 r
.21626 .52872 .22275 .53489 .23227 .53251 .22584 .52586 Mtetra
.637 .716 .905 r
.22584 .52586 .23227 .53251 .24181 .53028 .23543 .52321 Mtetra
.624 .7 .899 r
.23543 .52321 .24181 .53028 .25139 .52821 .24504 .52085 Mtetra
.606 .685 .898 r
.24504 .52085 .25139 .52821 .26098 .52637 .25466 .51891 Mtetra
.588 .676 .901 r
.25466 .51891 .26098 .52637 .27061 .52458 .26428 .51738 Mtetra
.561 .675 .915 r
.26428 .51738 .27061 .52458 .28029 .52277 .27392 .51635 Mtetra
.538 .693 .939 r
.27392 .51635 .28029 .52277 .29004 .52055 .28358 .51554 Mtetra
.498 .733 .977 r
.28358 .51554 .29004 .52055 .29988 .51763 .29329 .51486 Mtetra
.436 .798 .996 r
.29329 .51486 .29988 .51763 .30983 .51355 .30307 .51372 Mtetra
.284 .784 .85 r
.30307 .51372 .30983 .51355 .31991 .50789 .31296 .5117 Mtetra
0 0 0 r
.31296 .5117 .31991 .50789 .3301 .50067 .32299 .50816 Mtetra
.002 0 0 r
.32299 .50816 .3301 .50067 .3404 .49178 .33318 .50249 Mtetra
.025 0 0 r
.33318 .50249 .3404 .49178 .35074 .48225 .34351 .49464 Mtetra
0 0 0 r
.34351 .49464 .35074 .48225 .36107 .47279 .35397 .48444 Mtetra
.35397 .48444 .36107 .47279 .37132 .46503 .36449 .47287 Mtetra
.544 .821 .469 r
.36449 .47287 .37132 .46503 .38146 .46023 .37503 .46064 Mtetra
.887 .964 .838 r
.37503 .46064 .38146 .46023 .39145 .45946 .38552 .44916 Mtetra
.764 .68 .77 r
.38552 .44916 .39145 .45946 .40133 .4634 .39593 .4396 Mtetra
.64 .503 .679 r
.39593 .4396 .40133 .4634 .41119 .47015 .40621 .4334 Mtetra
.57 .416 .633 r
.40621 .4334 .41119 .47015 .42111 .4783 .41637 .43151 Mtetra
.533 .373 .61 r
.41637 .43151 .42111 .4783 .43117 .4853 .42646 .43327 Mtetra
.505 .347 .6 r
.42646 .43327 .43117 .4853 .44141 .48894 .43654 .43848 Mtetra
.475 .327 .6 r
.43654 .43848 .44141 .48894 .45189 .48612 .44663 .44681 Mtetra
.418 .304 .617 r
.44663 .44681 .45189 .48612 .46255 .47596 .45678 .45772 Mtetra
.114 .203 .679 r
.45678 .45772 .46255 .47596 .47327 .46161 .46704 .47056 Mtetra
.731 .33 .291 r
.46704 .47056 .47327 .46161 .48398 .44557 .47743 .4837 Mtetra
.602 .307 .441 r
.47743 .4837 .48398 .44557 .49463 .43222 .48801 .49329 Mtetra
.551 .285 .465 r
.48801 .49329 .49463 .43222 .50522 .42366 .49876 .49712 Mtetra
.513 .26 .468 r
.49876 .49712 .50522 .42366 .51581 .4202 .50963 .4937 Mtetra
.472 .226 .459 r
.50963 .4937 .51581 .4202 .52644 .42184 .52056 .48302 Mtetra
.413 .17 .433 r
.52056 .48302 .52644 .42184 .53717 .4283 .53147 .46651 Mtetra
.26 .018 .343 r
.53147 .46651 .53717 .4283 .54802 .43751 .54232 .44639 Mtetra
.727 .858 .432 r
.54232 .44639 .54802 .43751 .55898 .44507 .55311 .42651 Mtetra
.778 .614 .677 r
.55311 .42651 .55898 .44507 .57 .44843 .56385 .40852 Mtetra
.668 .481 .622 r
.56385 .40852 .57 .44843 .58098 .44439 .57457 .39309 Mtetra
.628 .438 .606 r
.57457 .39309 .58098 .44439 .59187 .4338 .58532 .38079 Mtetra
.606 .42 .604 r
.58532 .38079 .59187 .4338 .60268 .41977 .59612 .37195 Mtetra
.587 .412 .612 r
.59612 .37195 .60268 .41977 .61342 .40453 .60703 .36681 Mtetra
.558 .408 .634 r
.60703 .36681 .61342 .40453 .62417 .39069 .6181 .36604 Mtetra
.509 .418 .688 r
.6181 .36604 .62417 .39069 .63498 .37967 .62935 .36871 Mtetra
.333 .464 .843 r
.62935 .36871 .63498 .37967 .64598 .37343 .64076 .37337 Mtetra
.472 0 0 r
.64076 .37337 .64598 .37343 .65717 .37132 .6523 .37882 Mtetra
.573 .113 .124 r
.6523 .37882 .65717 .37132 .66855 .37225 .66392 .38363 Mtetra
.546 .136 .215 r
.66392 .38363 .66855 .37225 .68009 .37492 .67559 .38705 Mtetra
.491 .09 .207 r
.67559 .38705 .68009 .37492 .69173 .3777 .68723 .38809 Mtetra
.408 0 .131 r
.68723 .38809 .69173 .3777 .70343 .37984 .69884 .38688 Mtetra
.228 0 0 r
.69884 .38688 .70343 .37984 .71512 .38027 .71038 .38348 Mtetra
0 0 0 r
.71038 .38348 .71512 .38027 .72678 .3791 .72187 .37851 Mtetra
.615 .953 .916 r
.72187 .37851 .72678 .3791 .7384 .37629 .73335 .37261 Mtetra
.742 .9 .949 r
.73335 .37261 .7384 .37629 .74999 .37229 .74482 .36624 Mtetra
.739 .812 .909 r
.74482 .36624 .74999 .37229 .76157 .36755 .75633 .35997 Mtetra
.723 .759 .881 r
.75633 .35997 .76157 .36755 .77316 .36237 .76789 .35394 Mtetra
.704 .728 .869 r
.76789 .35394 .77316 .36237 .78478 .35717 .77952 .34841 Mtetra
.691 .715 .868 r
.77952 .34841 .78478 .35717 .79645 .35201 .79123 .3433 Mtetra
.678 .712 .874 r
.79123 .3433 .79645 .35201 .80818 .34708 .80301 .33862 Mtetra
.67 .716 .883 r
.80301 .33862 .80818 .34708 .81996 .34232 .81486 .33425 Mtetra
.665 .726 .895 r
.81486 .33425 .81996 .34232 .8318 .3377 .82678 .33008 Mtetra
.661 .739 .908 r
.82678 .33008 .8318 .3377 .8437 .33321 .83876 .32602 Mtetra
.674 .756 .912 r
.20012 .52592 .20671 .53168 .21626 .52872 .20974 .52234 Mtetra
.671 .735 .898 r
.20974 .52234 .21626 .52872 .22584 .52586 .2194 .51877 Mtetra
.664 .712 .884 r
.2194 .51877 .22584 .52586 .23543 .52321 .22908 .51536 Mtetra
.652 .688 .871 r
.22908 .51536 .23543 .52321 .24504 .52085 .23877 .51222 Mtetra
.636 .663 .859 r
.23877 .51222 .24504 .52085 .25466 .51891 .24846 .50947 Mtetra
.617 .636 .848 r
.24846 .50947 .25466 .51891 .26428 .51738 .25815 .50726 Mtetra
.592 .611 .84 r
.25815 .50726 .26428 .51738 .27392 .51635 .26782 .50574 Mtetra
.568 .59 .836 r
.26782 .50574 .27392 .51635 .28358 .51554 .27749 .5049 Mtetra
.538 .576 .841 r
.27749 .5049 .28358 .51554 .29329 .51486 .28715 .50482 Mtetra
.517 .58 .857 r
.28715 .50482 .29329 .51486 .30307 .51372 .29684 .50513 Mtetra
.491 .606 .894 r
.29684 .50513 .30307 .51372 .31296 .5117 .30658 .50563 Mtetra
.477 .685 .958 r
.30658 .50563 .31296 .5117 .32299 .50816 .31641 .50556 Mtetra
.429 .804 .993 r
.31641 .50556 .32299 .50816 .33318 .50249 .32637 .50432 Mtetra
.246 .752 .716 r
.32637 .50432 .33318 .50249 .34351 .49464 .33649 .50116 Mtetra
0 0 0 r
.33649 .50116 .34351 .49464 .35397 .48444 .34678 .49539 Mtetra
.008 0 0 r
.34678 .49539 .35397 .48444 .36449 .47287 .35723 .48709 Mtetra
.008 0 .009 r
.35723 .48709 .36449 .47287 .37503 .46064 .36781 .47622 Mtetra
0 0 .022 r
.36781 .47622 .37503 .46064 .38552 .44916 .37846 .46363 Mtetra
0 0 0 r
.37846 .46363 .38552 .44916 .39593 .4396 .38913 .45011 Mtetra
.38913 .45011 .39593 .4396 .40621 .4334 .39972 .43791 Mtetra
.604 .914 .657 r
.39972 .43791 .40621 .4334 .41637 .43151 .4102 .42851 Mtetra
.76 .889 .936 r
.4102 .42851 .41637 .43151 .42646 .43327 .42057 .42232 Mtetra
.612 .61 .824 r
.42057 .42232 .42646 .43327 .43654 .43848 .43086 .42004 Mtetra
.485 .441 .732 r
.43086 .42004 .43654 .43848 .44663 .44681 .44106 .42271 Mtetra
.397 .343 .68 r
.44106 .42271 .44663 .44681 .45678 .45772 .45123 .43021 Mtetra
.368 .307 .657 r
.45123 .43021 .45678 .45772 .46704 .47056 .46147 .44011 Mtetra
.385 .307 .645 r
.46147 .44011 .46704 .47056 .47743 .4837 .47182 .45028 Mtetra
.457 .348 .642 r
.47182 .45028 .47743 .4837 .48801 .49329 .48235 .45711 Mtetra
.53 .392 .637 r
.48235 .45711 .48801 .49329 .49876 .49712 .49304 .45881 Mtetra
.582 .424 .632 r
.49304 .45881 .49876 .49712 .50963 .4937 .50384 .45534 Mtetra
.626 .454 .63 r
.50384 .45534 .50963 .4937 .52056 .48302 .5147 .44668 Mtetra
.668 .487 .631 r
.5147 .44668 .52056 .48302 .53147 .46651 .52557 .43284 Mtetra
.698 .513 .633 r
.52557 .43284 .53147 .46651 .54232 .44639 .53639 .41561 Mtetra
.707 .525 .64 r
.53639 .41561 .54232 .44639 .55311 .42651 .54717 .39861 Mtetra
.702 .529 .651 r
.54717 .39861 .55311 .42651 .56385 .40852 .55793 .38398 Mtetra
.674 .524 .673 r
.55793 .38398 .56385 .40852 .57457 .39309 .56872 .3742 Mtetra
.636 .532 .719 r
.56872 .3742 .57457 .39309 .58532 .38079 .57959 .36941 Mtetra
.564 .585 .832 r
.57959 .36941 .58532 .38079 .59612 .37195 .59059 .36857 Mtetra
.072 .562 .895 r
.59059 .36857 .59612 .37195 .60703 .36681 .60172 .37102 Mtetra
.575 .062 0 r
.60172 .37102 .60703 .36681 .6181 .36604 .61302 .37633 Mtetra
.617 .198 .226 r
.61302 .37633 .6181 .36604 .62935 .36871 .62447 .38302 Mtetra
.593 .209 .285 r
.62447 .38302 .62935 .36871 .64076 .37337 .63601 .3888 Mtetra
.562 .187 .288 r
.63601 .3888 .64076 .37337 .6523 .37882 .6476 .39285 Mtetra
.507 .123 .246 r
.6476 .39285 .6523 .37882 .66392 .38363 .65917 .39429 Mtetra
.41 0 .136 r
.65917 .39429 .66392 .38363 .67559 .38705 .67072 .39314 Mtetra
.149 0 0 r
.67072 .39314 .67559 .38705 .68723 .38809 .68219 .38932 Mtetra
.461 .882 .78 r
.68219 .38932 .68723 .38809 .69884 .38688 .69361 .38351 Mtetra
.765 .913 .939 r
.69361 .38351 .69884 .38688 .71038 .38348 .705 .37648 Mtetra
.767 .787 .869 r
.705 .37648 .71038 .38348 .72187 .37851 .71637 .36885 Mtetra
.738 .71 .825 r
.71637 .36885 .72187 .37851 .73335 .37261 .72777 .36139 Mtetra
.717 .671 .804 r
.72777 .36139 .73335 .37261 .74482 .36624 .73922 .35433 Mtetra
.697 .651 .8 r
.73922 .35433 .74482 .36624 .75633 .35997 .75075 .34804 Mtetra
.682 .644 .805 r
.75075 .34804 .75633 .35997 .76789 .35394 .76236 .34245 Mtetra
.669 .646 .818 r
.76236 .34245 .76789 .35394 .77952 .34841 .77407 .33758 Mtetra
.659 .654 .834 r
.77407 .33758 .77952 .34841 .79123 .3433 .78586 .33325 Mtetra
.651 .668 .853 r
.78586 .33325 .79123 .3433 .80301 .33862 .79774 .32934 Mtetra
.645 .685 .873 r
.79774 .32934 .80301 .33862 .81486 .33425 .80969 .32571 Mtetra
.641 .703 .892 r
.80969 .32571 .81486 .33425 .82678 .33008 .82171 .32223 Mtetra
.64 .724 .909 r
.82171 .32223 .82678 .33008 .83876 .32602 .83378 .31877 Mtetra
.695 .76 .902 r
.19348 .52013 .20012 .52592 .20974 .52234 .20318 .51595 Mtetra
.694 .742 .887 r
.20318 .51595 .20974 .52234 .2194 .51877 .21292 .51169 Mtetra
.69 .721 .873 r
.21292 .51169 .2194 .51877 .22908 .51536 .22269 .50744 Mtetra
.682 .697 .857 r
.22269 .50744 .22908 .51536 .23877 .51222 .23248 .5033 Mtetra
.672 .67 .84 r
.23248 .5033 .23877 .51222 .24846 .50947 .24229 .49933 Mtetra
.655 .638 .821 r
.24229 .49933 .24846 .50947 .25815 .50726 .25209 .49575 Mtetra
.634 .605 .803 r
.25209 .49575 .25815 .50726 .26782 .50574 .26188 .49273 Mtetra
.609 .57 .785 r
.26188 .49273 .26782 .50574 .27749 .5049 .27165 .4905 Mtetra
.58 .536 .771 r
.27165 .4905 .27749 .5049 .28715 .50482 .28139 .48927 Mtetra
.552 .507 .76 r
.28139 .48927 .28715 .50482 .29684 .50513 .2911 .48909 Mtetra
.52 .484 .757 r
.2911 .48909 .29684 .50513 .30658 .50563 .30079 .49006 Mtetra
.493 .474 .765 r
.30079 .49006 .30658 .50563 .31641 .50556 .31049 .49185 Mtetra
.458 .48 .794 r
.31049 .49185 .31641 .50556 .32637 .50432 .32022 .49424 Mtetra
.416 .531 .865 r
.32022 .49424 .32637 .50432 .33649 .50116 .33003 .49646 Mtetra
.269 .64 .965 r
.33003 .49646 .33649 .50116 .34678 .49539 .33996 .49787 Mtetra
.212 0 0 r
.33996 .49787 .34678 .49539 .35723 .48709 .35003 .49778 Mtetra
.359 0 .111 r
.35003 .49778 .35723 .48709 .36781 .47622 .36027 .49555 Mtetra
.384 .048 .267 r
.36027 .49555 .36781 .47622 .37846 .46363 .37067 .49092 Mtetra
.384 .084 .328 r
.37067 .49092 .37846 .46363 .38913 .45011 .38121 .48365 Mtetra
.381 .1 .356 r
.38121 .48365 .38913 .45011 .39972 .43791 .39186 .47414 Mtetra
.365 .092 .361 r
.39186 .47414 .39972 .43791 .4102 .42851 .40258 .4627 Mtetra
.328 .057 .341 r
.40258 .4627 .4102 .42851 .42057 .42232 .41334 .44984 Mtetra
.241 0 .276 r
.41334 .44984 .42057 .42232 .43086 .42004 .42411 .43602 Mtetra
0 0 .017 r
.42411 .43602 .43086 .42004 .44106 .42271 .43487 .42187 Mtetra
.921 .918 .796 r
.43487 .42187 .44106 .42271 .45123 .43021 .4456 .4075 Mtetra
.739 .57 .664 r
.4456 .4075 .45123 .43021 .46147 .44011 .45634 .39119 Mtetra
.661 .464 .606 r
.45634 .39119 .46147 .44011 .47182 .45028 .46706 .3735 Mtetra
.614 .41 .581 r
.46706 .3735 .47182 .45028 .48235 .45711 .4777 .35802 Mtetra
.584 .379 .569 r
.4777 .35802 .48235 .45711 .49304 .45881 .48825 .34696 Mtetra
.554 .353 .562 r
.48825 .34696 .49304 .45881 .50384 .45534 .49873 .34337 Mtetra
.527 .332 .56 r
.49873 .34337 .50384 .45534 .5147 .44668 .50922 .34727 Mtetra
.507 .32 .562 r
.50922 .34727 .5147 .44668 .52557 .43284 .51978 .35564 Mtetra
.484 .313 .572 r
.51978 .35564 .52557 .43284 .53639 .41561 .53047 .36626 Mtetra
.464 .321 .602 r
.53047 .36626 .53639 .41561 .54717 .39861 .54129 .37555 Mtetra
.398 .354 .692 r
.54129 .37555 .54717 .39861 .55793 .38398 .55223 .38291 Mtetra
.553 0 0 r
.55223 .38291 .55793 .38398 .56872 .3742 .56328 .39009 Mtetra
.609 .239 .315 r
.56328 .39009 .56872 .3742 .57959 .36941 .57445 .39699 Mtetra
.578 .259 .391 r
.57445 .39699 .57959 .36941 .59059 .36857 .58571 .40293 Mtetra
.56 .257 .412 r
.58571 .40293 .59059 .36857 .60172 .37102 .59706 .40748 Mtetra
.541 .245 .414 r
.59706 .40748 .60172 .37102 .61302 .37633 .60845 .41008 Mtetra
.518 .219 .399 r
.60845 .41008 .61302 .37633 .62447 .38302 .61987 .41042 Mtetra
.476 .166 .361 r
.61987 .41042 .62447 .38302 .63601 .3888 .63128 .40808 Mtetra
.394 .058 .274 r
.63128 .40808 .63601 .3888 .6476 .39285 .64265 .40327 Mtetra
.153 0 .015 r
.64265 .40327 .6476 .39285 .65917 .39429 .65398 .39626 Mtetra
.615 .944 .753 r
.65398 .39626 .65917 .39429 .67072 .39314 .66526 .38769 Mtetra
.82 .842 .866 r
.66526 .38769 .67072 .39314 .68219 .38932 .67651 .37828 Mtetra
.762 .692 .784 r
.67651 .37828 .68219 .38932 .69361 .38351 .68776 .36866 Mtetra
.72 .621 .746 r
.68776 .36866 .69361 .38351 .705 .37648 .69904 .35965 Mtetra
.694 .588 .732 r
.69904 .35965 .705 .37648 .71637 .36885 .71038 .35145 Mtetra
.674 .572 .732 r
.71038 .35145 .71637 .36885 .72777 .36139 .72182 .34445 Mtetra
.66 .568 .741 r
.72182 .34445 .72777 .36139 .73922 .35433 .73334 .3385 Mtetra
.647 .573 .757 r
.73334 .3385 .73922 .35433 .75075 .34804 .74498 .3336 Mtetra
.638 .585 .778 r
.74498 .3336 .75075 .34804 .76236 .34245 .75671 .32951 Mtetra
.631 .603 .804 r
.75671 .32951 .76236 .34245 .77407 .33758 .76854 .326 Mtetra
.625 .624 .83 r
.76854 .326 .77407 .33758 .78586 .33325 .78045 .3229 Mtetra
.622 .648 .855 r
.78045 .3229 .78586 .33325 .79774 .32934 .79243 .31997 Mtetra
.619 .671 .878 r
.79243 .31997 .79774 .32934 .80969 .32571 .80448 .31715 Mtetra
.617 .694 .898 r
.80448 .31715 .80969 .32571 .82171 .32223 .8166 .31435 Mtetra
.618 .715 .915 r
.8166 .31435 .82171 .32223 .83378 .31877 .82876 .31146 Mtetra
.699 .761 .899 r
.18679 .51429 .19348 .52013 .20318 .51595 .19653 .50996 Mtetra
.703 .757 .894 r
.19653 .50996 .20318 .51595 .21292 .51169 .20632 .50546 Mtetra
.706 .751 .887 r
.20632 .50546 .21292 .51169 .22269 .50744 .21614 .50084 Mtetra
.706 .74 .878 r
.21614 .50084 .22269 .50744 .23248 .5033 .226 .49612 Mtetra
.706 .724 .864 r
.226 .49612 .23248 .5033 .24229 .49933 .2359 .49127 Mtetra
.698 .7 .848 r
.2359 .49127 .24229 .49933 .25209 .49575 .24582 .48649 Mtetra
.685 .669 .828 r
.24582 .48649 .25209 .49575 .26188 .49273 .25575 .48188 Mtetra
.664 .631 .806 r
.25575 .48188 .26188 .49273 .27165 .4905 .26568 .47773 Mtetra
.638 .589 .783 r
.26568 .47773 .27165 .4905 .28139 .48927 .27558 .4743 Mtetra
.608 .546 .759 r
.27558 .4743 .28139 .48927 .2911 .48909 .28544 .47185 Mtetra
.575 .504 .738 r
.28544 .47185 .2911 .48909 .30079 .49006 .29526 .47068 Mtetra
.544 .468 .72 r
.29526 .47068 .30079 .49006 .31049 .49185 .30504 .47083 Mtetra
.514 .437 .707 r
.30504 .47083 .31049 .49185 .32022 .49424 .31479 .47245 Mtetra
.491 .418 .701 r
.31479 .47245 .32022 .49424 .33003 .49646 .32453 .47514 Mtetra
.47 .408 .705 r
.32453 .47514 .33003 .49646 .33996 .49787 .33431 .47862 Mtetra
.46 .418 .725 r
.33431 .47862 .33996 .49787 .35003 .49778 .34416 .48212 Mtetra
.456 .454 .768 r
.34416 .48212 .35003 .49778 .36027 .49555 .35413 .485 Mtetra
.453 .542 .858 r
.35413 .485 .36027 .49555 .37067 .49092 .36423 .48666 Mtetra
.407 .733 .991 r
.36423 .48666 .37067 .49092 .38121 .48365 .37449 .48648 Mtetra
0 0 0 r
.37449 .48648 .38121 .48365 .39186 .47414 .38492 .48364 Mtetra
.106 0 0 r
.38492 .48364 .39186 .47414 .40258 .4627 .39552 .47766 Mtetra
.172 0 .103 r
.39552 .47766 .40258 .4627 .41334 .44984 .40623 .46921 Mtetra
.192 0 .18 r
.40623 .46921 .41334 .44984 .42411 .43602 .41702 .45853 Mtetra
.175 0 .207 r
.41702 .45853 .42411 .43602 .43487 .42187 .42788 .4454 Mtetra
.124 0 .196 r
.42788 .4454 .43487 .42187 .4456 .4075 .43879 .42995 Mtetra
.017 0 .141 r
.43879 .42995 .4456 .4075 .45634 .39119 .4497 .41218 Mtetra
0 0 .092 r
.4497 .41218 .45634 .39119 .46706 .3735 .46059 .39344 Mtetra
.034 0 .127 r
.46059 .39344 .46706 .3735 .4777 .35802 .47137 .37784 Mtetra
.227 0 .211 r
.47137 .37784 .4777 .35802 .48825 .34696 .48203 .36748 Mtetra
.423 .092 .297 r
.48203 .36748 .48825 .34696 .49873 .34337 .49263 .36389 Mtetra
.55 .209 .343 r
.49263 .36389 .49873 .34337 .50922 .34727 .50322 .36708 Mtetra
.622 .275 .361 r
.50322 .36708 .50922 .34727 .51978 .35564 .51388 .37556 Mtetra
.656 .309 .372 r
.51388 .37556 .51978 .35564 .53047 .36626 .52466 .38723 Mtetra
.643 .298 .373 r
.52466 .38723 .53047 .36626 .54129 .37555 .53559 .39799 Mtetra
.614 .275 .372 r
.53559 .39799 .54129 .37555 .55223 .38291 .54664 .40644 Mtetra
.585 .251 .369 r
.54664 .40644 .55223 .38291 .56328 .39009 .55779 .41261 Mtetra
.554 .217 .352 r
.55779 .41261 .56328 .39009 .57445 .39699 .56903 .41632 Mtetra
.517 .168 .313 r
.56903 .41632 .57445 .39699 .58571 .40293 .58032 .41778 Mtetra
.448 .072 .232 r
.58032 .41778 .58571 .40293 .59706 .40748 .59164 .41676 Mtetra
.243 0 .008 r
.59164 .41676 .59706 .40748 .60845 .41008 .60295 .41254 Mtetra
.465 .869 .703 r
.60295 .41254 .60845 .41008 .61987 .41042 .61422 .4056 Mtetra
.812 .858 .883 r
.61422 .4056 .61987 .41042 .63128 .40808 .62546 .39677 Mtetra
.766 .687 .776 r
.62546 .39677 .63128 .40808 .64265 .40327 .63667 .38667 Mtetra
.729 .608 .722 r
.63667 .38667 .64265 .40327 .65398 .39626 .64785 .37591 Mtetra
.704 .566 .696 r
.64785 .37591 .65398 .39626 .66526 .38769 .65903 .36514 Mtetra
.684 .542 .686 r
.65903 .36514 .66526 .38769 .67651 .37828 .67024 .35517 Mtetra
.67 .53 .686 r
.67024 .35517 .67651 .37828 .68776 .36866 .68151 .34627 Mtetra
.655 .526 .694 r
.68151 .34627 .68776 .36866 .69904 .35965 .69287 .33887 Mtetra
.644 .529 .708 r
.69287 .33887 .69904 .35965 .71038 .35145 .70432 .33283 Mtetra
.633 .538 .729 r
.70432 .33283 .71038 .35145 .72182 .34445 .71589 .3281 Mtetra
.623 .554 .756 r
.71589 .3281 .72182 .34445 .73334 .3385 .72756 .32438 Mtetra
.615 .577 .788 r
.72756 .32438 .73334 .3385 .74498 .3336 .73934 .3214 Mtetra
.607 .603 .822 r
.73934 .3214 .74498 .3336 .75671 .32951 .7512 .3189 Mtetra
.603 .633 .854 r
.7512 .3189 .75671 .32951 .76854 .326 .76314 .31658 Mtetra
.599 .661 .881 r
.76314 .31658 .76854 .326 .78045 .3229 .77515 .31434 Mtetra
.601 .686 .901 r
.77515 .31434 .78045 .3229 .79243 .31997 .78721 .31197 Mtetra
.603 .704 .915 r
.78721 .31197 .79243 .31997 .80448 .31715 .79933 .30949 Mtetra
.606 .717 .923 r
.79933 .30949 .80448 .31715 .8166 .31435 .81149 .30688 Mtetra
.61 .726 .928 r
.81149 .30688 .8166 .31435 .82876 .31146 .82371 .3041 Mtetra
.688 .758 .906 r
.18006 .50842 .18679 .51429 .19653 .50996 .18979 .5044 Mtetra
.694 .771 .911 r
.18979 .5044 .19653 .50996 .20632 .50546 .19957 .5002 Mtetra
.703 .783 .914 r
.19957 .5002 .20632 .50546 .21614 .50084 .2094 .49577 Mtetra
.713 .792 .913 r
.2094 .49577 .21614 .50084 .226 .49612 .21928 .49105 Mtetra
.726 .795 .907 r
.21928 .49105 .226 .49612 .2359 .49127 .22923 .48594 Mtetra
.733 .788 .896 r
.22923 .48594 .2359 .49127 .24582 .48649 .23923 .48051 Mtetra
.737 .768 .878 r
.23923 .48051 .24582 .48649 .25575 .48188 .24928 .47476 Mtetra
.731 .735 .855 r
.24928 .47476 .25575 .48188 .26568 .47773 .25936 .46892 Mtetra
.715 .691 .825 r
.25936 .46892 .26568 .47773 .27558 .4743 .26946 .46312 Mtetra
.689 .637 .792 r
.26946 .46312 .27558 .4743 .28544 .47185 .27955 .45769 Mtetra
.658 .583 .759 r
.27955 .45769 .28544 .47185 .29526 .47068 .28962 .45293 Mtetra
.625 .53 .726 r
.28962 .45293 .29526 .47068 .30504 .47083 .29965 .44914 Mtetra
.592 .483 .698 r
.29965 .44914 .30504 .47083 .31479 .47245 .30963 .44666 Mtetra
.564 .444 .674 r
.30963 .44666 .31479 .47245 .32453 .47514 .31956 .44561 Mtetra
.538 .412 .656 r
.31956 .44561 .32453 .47514 .33431 .47862 .32945 .44616 Mtetra
.522 .392 .644 r
.32945 .44616 .33431 .47862 .34416 .48212 .33933 .44796 Mtetra
.509 .378 .638 r
.33933 .44796 .34416 .48212 .35413 .485 .34922 .45079 Mtetra
.497 .37 .638 r
.34922 .45079 .35413 .485 .36423 .48666 .35915 .45445 Mtetra
.486 .369 .645 r
.35915 .45445 .36423 .48666 .37449 .48648 .36914 .45864 Mtetra
.484 .384 .665 r
.36914 .45864 .37449 .48648 .38492 .48364 .37923 .46242 Mtetra
.484 .42 .71 r
.37923 .46242 .38492 .48364 .39552 .47766 .38945 .46531 Mtetra
.419 .488 .824 r
.38945 .46531 .39552 .47766 .40623 .46921 .39974 .46819 Mtetra
.274 0 0 r
.39974 .46819 .40623 .46921 .41702 .45853 .41012 .47121 Mtetra
.519 .125 .233 r
.41012 .47121 .41702 .45853 .42788 .4454 .4206 .4733 Mtetra
.521 .206 .375 r
.4206 .4733 .42788 .4454 .43879 .42995 .43119 .47438 Mtetra
.534 .25 .43 r
.43119 .47438 .43879 .42995 .4497 .41218 .44183 .47626 Mtetra
.54 .273 .459 r
.44183 .47626 .4497 .41218 .46059 .39344 .45253 .47918 Mtetra
.538 .282 .474 r
.45253 .47918 .46059 .39344 .47137 .37784 .46332 .48197 Mtetra
.532 .282 .482 r
.46332 .48197 .47137 .37784 .48203 .36748 .47421 .48331 Mtetra
.517 .272 .483 r
.47421 .48331 .48203 .36748 .49263 .36389 .48524 .4798 Mtetra
.5 .258 .479 r
.48524 .4798 .49263 .36389 .50322 .36708 .49635 .47143 Mtetra
.49 .247 .473 r
.49635 .47143 .50322 .36708 .51388 .37556 .50749 .46157 Mtetra
.479 .233 .462 r
.50749 .46157 .51388 .37556 .52466 .38723 .51862 .45157 Mtetra
.466 .211 .442 r
.51862 .45157 .52466 .38723 .53559 .39799 .52976 .4426 Mtetra
.441 .17 .406 r
.52976 .4426 .53559 .39799 .54664 .40644 .54091 .4344 Mtetra
.358 .063 .322 r
.54091 .4344 .54664 .40644 .55779 .41261 .55207 .42517 Mtetra
.043 0 .008 r
.55207 .42517 .55779 .41261 .56903 .41632 .56322 .41498 Mtetra
.846 .964 .88 r
.56322 .41498 .56903 .41632 .58032 .41778 .57438 .4049 Mtetra
.751 .657 .757 r
.57438 .4049 .58032 .41778 .59164 .41676 .58553 .39479 Mtetra
.698 .553 .686 r
.58553 .39479 .59164 .41676 .60295 .41254 .59667 .38374 Mtetra
.672 .509 .655 r
.59667 .38374 .60295 .41254 .61422 .4056 .60779 .37226 Mtetra
.653 .483 .641 r
.60779 .37226 .61422 .4056 .62546 .39677 .61891 .36129 Mtetra
.641 .47 .636 r
.61891 .36129 .62546 .39677 .63667 .38667 .63005 .35114 Mtetra
.632 .464 .637 r
.63005 .35114 .63667 .38667 .64785 .37591 .64124 .34203 Mtetra
.625 .463 .642 r
.64124 .34203 .64785 .37591 .65903 .36514 .65248 .33418 Mtetra
.616 .465 .654 r
.65248 .33418 .65903 .36514 .67024 .35517 .66381 .32796 Mtetra
.608 .473 .672 r
.66381 .32796 .67024 .35517 .68151 .34627 .67525 .3232 Mtetra
.6 .488 .697 r
.67525 .3232 .68151 .34627 .69287 .33887 .68679 .31979 Mtetra
.592 .51 .731 r
.68679 .31979 .69287 .33887 .70432 .33283 .69844 .31739 Mtetra
.583 .542 .774 r
.69844 .31739 .70432 .33283 .71589 .3281 .71019 .31567 Mtetra
.574 .582 .823 r
.71019 .31567 .71589 .3281 .72756 .32438 .72202 .31434 Mtetra
.567 .628 .872 r
.72202 .31434 .72756 .32438 .73934 .3214 .73394 .31307 Mtetra
.561 .672 .913 r
.73394 .31307 .73934 .3214 .7512 .3189 .74591 .3117 Mtetra
.564 .711 .94 r
.74591 .3117 .7512 .3189 .76314 .31658 .75793 .31 Mtetra
.571 .738 .954 r
.75793 .31 .76314 .31658 .77515 .31434 .76999 .30798 Mtetra
.587 .754 .958 r
.76999 .30798 .77515 .31434 .78721 .31197 .78209 .30556 Mtetra
.601 .759 .954 r
.78209 .30556 .78721 .31197 .79933 .30949 .79422 .30282 Mtetra
.613 .756 .947 r
.79422 .30282 .79933 .30949 .81149 .30688 .80639 .29985 Mtetra
.622 .749 .937 r
.80639 .29985 .81149 .30688 .82371 .3041 .81861 .29669 Mtetra
.657 .752 .92 r
.17328 .5025 .18006 .50842 .18979 .5044 .18295 .49926 Mtetra
.66 .781 .938 r
.18295 .49926 .18979 .5044 .19957 .5002 .19267 .4959 Mtetra
.667 .814 .954 r
.19267 .4959 .19957 .5002 .2094 .49577 .20245 .49229 Mtetra
.677 .848 .965 r
.20245 .49229 .2094 .49577 .21928 .49105 .21229 .48834 Mtetra
.691 .88 .969 r
.21229 .48834 .21928 .49105 .22923 .48594 .22221 .48393 Mtetra
.706 .908 .966 r
.22221 .48393 .22923 .48594 .23923 .48051 .2322 .479 Mtetra
.727 .927 .957 r
.2322 .479 .23923 .48051 .24928 .47476 .24227 .47347 Mtetra
.747 .935 .948 r
.24227 .47347 .24928 .47476 .25936 .46892 .25241 .46741 Mtetra
.771 .929 .937 r
.25241 .46741 .25936 .46892 .26946 .46312 .2626 .46085 Mtetra
.784 .903 .925 r
.2626 .46085 .26946 .46312 .27955 .45769 .27284 .45401 Mtetra
.783 .853 .903 r
.27284 .45401 .27955 .45769 .28962 .45293 .2831 .44708 Mtetra
.76 .78 .87 r
.2831 .44708 .28962 .45293 .29965 .44914 .29336 .44039 Mtetra
.722 .698 .826 r
.29336 .44039 .29965 .44914 .30963 .44666 .3036 .43425 Mtetra
.676 .615 .78 r
.3036 .43425 .30963 .44666 .31956 .44561 .3138 .42905 Mtetra
.631 .544 .739 r
.3138 .42905 .31956 .44561 .32945 .44616 .32395 .42513 Mtetra
.595 .489 .703 r
.32395 .42513 .32945 .44616 .33933 .44796 .33405 .42251 Mtetra
.566 .447 .677 r
.33405 .42251 .33933 .44796 .34922 .45079 .34412 .42128 Mtetra
.543 .416 .657 r
.34412 .42128 .34922 .45079 .35915 .45445 .35417 .42144 Mtetra
.524 .392 .643 r
.35417 .42144 .35915 .45445 .36914 .45864 .36422 .42298 Mtetra
.514 .379 .634 r
.36422 .42298 .36914 .45864 .37923 .46242 .37429 .42538 Mtetra
.507 .371 .63 r
.37429 .42538 .37923 .46242 .38945 .46531 .38441 .42843 Mtetra
.494 .362 .63 r
.38441 .42843 .38945 .46531 .39974 .46819 .39458 .43249 Mtetra
.479 .354 .633 r
.39458 .43249 .39974 .46819 .41012 .47121 .40479 .43759 Mtetra
.471 .355 .64 r
.40479 .43759 .41012 .47121 .4206 .4733 .41509 .44293 Mtetra
.458 .358 .653 r
.41509 .44293 .4206 .4733 .43119 .47438 .42549 .44856 Mtetra
.38 .326 .671 r
.42549 .44856 .43119 .47438 .44183 .47626 .43591 .45686 Mtetra
.216 .265 .699 r
.43591 .45686 .44183 .47626 .45253 .47918 .44639 .46754 Mtetra
.01 .252 .757 r
.44639 .46754 .45253 .47918 .46332 .48197 .45704 .4768 Mtetra
0 .383 .814 r
.45704 .4768 .46332 .48197 .47421 .48331 .46789 .48189 Mtetra
.53 .895 .971 r
.46789 .48189 .47421 .48331 .48524 .4798 .47897 .47836 Mtetra
.888 .938 .842 r
.47897 .47836 .48524 .4798 .49635 .47143 .49018 .46618 Mtetra
.896 .819 .764 r
.49018 .46618 .49635 .47143 .50749 .46157 .5014 .44978 Mtetra
.835 .699 .713 r
.5014 .44978 .50749 .46157 .51862 .45157 .51259 .4319 Mtetra
.753 .597 .684 r
.51259 .4319 .51862 .45157 .52976 .4426 .52373 .41638 Mtetra
.695 .532 .662 r
.52373 .41638 .52976 .4426 .54091 .4344 .53484 .4035 Mtetra
.675 .504 .647 r
.53484 .4035 .54091 .4344 .55207 .42517 .54593 .39089 Mtetra
.662 .487 .637 r
.54593 .39089 .55207 .42517 .56322 .41498 .55701 .37849 Mtetra
.648 .472 .632 r
.55701 .37849 .56322 .41498 .57438 .4049 .56808 .36711 Mtetra
.637 .462 .629 r
.56808 .36711 .57438 .4049 .58553 .39479 .57916 .35673 Mtetra
.632 .458 .629 r
.57916 .35673 .58553 .39479 .59667 .38374 .59026 .34699 Mtetra
.627 .457 .633 r
.59026 .34699 .59667 .38374 .60779 .37226 .60138 .33812 Mtetra
.621 .459 .641 r
.60138 .33812 .60779 .37226 .61891 .36129 .61254 .33062 Mtetra
.615 .465 .654 r
.61254 .33062 .61891 .36129 .63005 .35114 .62377 .32454 Mtetra
.608 .475 .674 r
.62377 .32454 .63005 .35114 .64124 .34203 .63508 .31987 Mtetra
.6 .493 .703 r
.63508 .31987 .64124 .34203 .65248 .33418 .64649 .31654 Mtetra
.586 .519 .746 r
.64649 .31654 .65248 .33418 .66381 .32796 .65799 .31451 Mtetra
.567 .56 .805 r
.65799 .31451 .66381 .32796 .67525 .3232 .66961 .31346 Mtetra
.536 .618 .881 r
.66961 .31346 .67525 .3232 .68679 .31979 .68132 .31298 Mtetra
.483 .683 .954 r
.68132 .31298 .68679 .31979 .69844 .31739 .69312 .31276 Mtetra
.415 .735 .991 r
.69312 .31276 .69844 .31739 .71019 .31567 .70499 .31245 Mtetra
.354 .759 .983 r
.70499 .31245 .71019 .31567 .72202 .31434 .71692 .31188 Mtetra
.345 .78 .967 r
.71692 .31188 .72202 .31434 .73394 .31307 .72889 .31078 Mtetra
.378 .805 .968 r
.72889 .31078 .73394 .31307 .74591 .3117 .7409 .30914 Mtetra
.449 .836 .984 r
.7409 .30914 .74591 .3117 .75793 .31 .75293 .30688 Mtetra
.519 .852 .996 r
.75293 .30688 .75793 .31 .76999 .30798 .76499 .30408 Mtetra
.58 .85 .995 r
.76499 .30408 .76999 .30798 .78209 .30556 .77706 .30079 Mtetra
.62 .833 .982 r
.77706 .30079 .78209 .30556 .79422 .30282 .78916 .29715 Mtetra
.643 .808 .962 r
.78916 .29715 .79422 .30282 .80639 .29985 .8013 .29325 Mtetra
.653 .779 .941 r
.8013 .29325 .80639 .29985 .81861 .29669 .81347 .28921 Mtetra
.61 .739 .937 r
.16646 .49655 .17328 .5025 .18295 .49926 .17604 .49428 Mtetra
.603 .774 .962 r
.17604 .49428 .18295 .49926 .19267 .4959 .18568 .49197 Mtetra
.594 .813 .983 r
.18568 .49197 .19267 .4959 .20245 .49229 .19536 .48951 Mtetra
.582 .854 .995 r
.19536 .48951 .20245 .49229 .21229 .48834 .20512 .48679 Mtetra
.56 .889 .987 r
.20512 .48679 .21229 .48834 .22221 .48393 .21494 .4837 Mtetra
.527 .908 .946 r
.21494 .4837 .22221 .48393 .2322 .479 .22485 .48012 Mtetra
.487 .902 .872 r
.22485 .48012 .2322 .479 .24227 .47347 .23486 .47588 Mtetra
.444 .874 .778 r
.23486 .47588 .24227 .47347 .25241 .46741 .24495 .47093 Mtetra
.424 .847 .697 r
.24495 .47093 .25241 .46741 .2626 .46085 .25514 .46517 Mtetra
.424 .833 .645 r
.25514 .46517 .2626 .46085 .27284 .45401 .26541 .45865 Mtetra
.468 .854 .643 r
.26541 .45865 .27284 .45401 .2831 .44708 .27576 .45138 Mtetra
.549 .903 .692 r
.27576 .45138 .2831 .44708 .29336 .44039 .28616 .44355 Mtetra
.673 .97 .79 r
.28616 .44355 .29336 .44039 .3036 .43425 .2966 .43531 Mtetra
.782 .991 .885 r
.2966 .43531 .3036 .43425 .3138 .42905 .30706 .42703 Mtetra
.815 .915 .906 r
.30706 .42703 .3138 .42905 .32395 .42513 .3175 .419 Mtetra
.775 .779 .856 r
.3175 .419 .32395 .42513 .33405 .42251 .32793 .41148 Mtetra
.715 .655 .789 r
.32793 .41148 .33405 .42251 .34412 .42128 .33832 .40474 Mtetra
.665 .565 .732 r
.33832 .40474 .34412 .42128 .35417 .42144 .34869 .39876 Mtetra
.627 .501 .689 r
.34869 .39876 .35417 .42144 .36422 .42298 .35904 .39362 Mtetra
.598 .454 .657 r
.35904 .39362 .36422 .42298 .37429 .42538 .36937 .38951 Mtetra
.577 .422 .634 r
.36937 .38951 .37429 .42538 .38441 .42843 .37969 .38647 Mtetra
.566 .402 .619 r
.37969 .38647 .38441 .42843 .39458 .43249 .39002 .38395 Mtetra
.559 .388 .606 r
.39002 .38395 .39458 .43249 .40479 .43759 .40039 .38176 Mtetra
.552 .375 .595 r
.40039 .38176 .40479 .43759 .41509 .44293 .41079 .38005 Mtetra
.545 .364 .586 r
.41079 .38005 .41509 .44293 .42549 .44856 .42122 .37913 Mtetra
.53 .348 .579 r
.42122 .37913 .42549 .44856 .43591 .45686 .43164 .3806 Mtetra
.518 .335 .573 r
.43164 .3806 .43591 .45686 .44639 .46754 .44208 .38424 Mtetra
.523 .336 .569 r
.44208 .38424 .44639 .46754 .45704 .4768 .45262 .38704 Mtetra
.536 .343 .567 r
.45262 .38704 .45704 .4768 .46789 .48189 .4633 .38741 Mtetra
.552 .354 .566 r
.4633 .38741 .46789 .48189 .47897 .47836 .4741 .38377 Mtetra
.569 .367 .567 r
.4741 .38377 .47897 .47836 .49018 .46618 .48501 .37612 Mtetra
.58 .377 .57 r
.48501 .37612 .49018 .46618 .5014 .44978 .49595 .36601 Mtetra
.587 .384 .574 r
.49595 .36601 .5014 .44978 .51259 .4319 .50689 .35503 Mtetra
.582 .383 .578 r
.50689 .35503 .51259 .4319 .52373 .41638 .51782 .34621 Mtetra
.574 .381 .582 r
.51782 .34621 .52373 .41638 .53484 .4035 .52877 .33979 Mtetra
.573 .385 .588 r
.52877 .33979 .53484 .4035 .54593 .39089 .53974 .33416 Mtetra
.575 .392 .596 r
.53974 .33416 .54593 .39089 .55701 .37849 .55075 .32901 Mtetra
.578 .402 .606 r
.55075 .32901 .55701 .37849 .56808 .36711 .56179 .32419 Mtetra
.58 .412 .619 r
.56179 .32419 .56808 .36711 .57916 .35673 .57288 .31989 Mtetra
.576 .421 .634 r
.57288 .31989 .57916 .35673 .59026 .34699 .58404 .31668 Mtetra
.571 .436 .658 r
.58404 .31668 .59026 .34699 .60138 .33812 .59526 .31451 Mtetra
.566 .462 .695 r
.59526 .31451 .60138 .33812 .61254 .33062 .60657 .31321 Mtetra
.554 .501 .751 r
.60657 .31321 .61254 .33062 .62377 .32454 .61796 .31269 Mtetra
.52 .561 .838 r
.61796 .31269 .62377 .32454 .63508 .31987 .62945 .31298 Mtetra
.421 .646 .951 r
.62945 .31298 .63508 .31987 .64649 .31654 .64104 .3138 Mtetra
.15 .645 .915 r
.64104 .3138 .64649 .31654 .65799 .31451 .65272 .3149 Mtetra
.143 0 0 r
.65272 .3149 .65799 .31451 .66961 .31346 .66449 .31597 Mtetra
.257 0 0 r
.66449 .31597 .66961 .31346 .68132 .31298 .67632 .31663 Mtetra
.276 0 0 r
.67632 .31663 .68132 .31298 .69312 .31276 .6882 .31672 Mtetra
.239 0 0 r
.6882 .31672 .69312 .31276 .70499 .31245 .70012 .31606 Mtetra
.164 0 0 r
.70012 .31606 .70499 .31245 .71692 .31188 .71208 .31462 Mtetra
.035 0 0 r
.71208 .31462 .71692 .31188 .72889 .31078 .72404 .31233 Mtetra
0 0 0 r
.72404 .31233 .72889 .31078 .7409 .30914 .73602 .3093 Mtetra
.345 .823 .827 r
.73602 .3093 .7409 .30914 .75293 .30688 .74802 .3056 Mtetra
.512 .902 .942 r
.74802 .3056 .75293 .30688 .76499 .30408 .76002 .30137 Mtetra
.615 .91 .982 r
.76002 .30137 .76499 .30408 .77706 .30079 .77205 .29675 Mtetra
.666 .881 .978 r
.77205 .29675 .77706 .30079 .78916 .29715 .7841 .29185 Mtetra
.687 .841 .957 r
.7841 .29185 .78916 .29715 .8013 .29325 .79618 .28679 Mtetra
.692 .801 .933 r
.79618 .28679 .8013 .29325 .81347 .28921 .8083 .28168 Mtetra
.572 .727 .947 r
.15958 .49055 .16646 .49655 .17604 .49428 .16912 .48895 Mtetra
.559 .748 .966 r
.16912 .48895 .17604 .49428 .18568 .49197 .17869 .48739 Mtetra
.545 .773 .983 r
.17869 .48739 .18568 .49197 .19536 .48951 .18831 .4858 Mtetra
.526 .802 .996 r
.18831 .4858 .19536 .48951 .20512 .48679 .19799 .4841 Mtetra
.497 .83 .999 r
.19799 .4841 .20512 .48679 .21494 .4837 .20772 .48225 Mtetra
.455 .851 .975 r
.20772 .48225 .21494 .4837 .22485 .48012 .21754 .48007 Mtetra
.391 .845 .904 r
.21754 .48007 .22485 .48012 .23486 .47588 .22743 .47746 Mtetra
.305 .796 .774 r
.22743 .47746 .23486 .47588 .24495 .47093 .23742 .47425 Mtetra
0 0 0 r
.23742 .47425 .24495 .47093 .25514 .46517 .24751 .47031 Mtetra
.24751 .47031 .25514 .46517 .26541 .45865 .2577 .46556 Mtetra
.2577 .46556 .26541 .45865 .27576 .45138 .26799 .45992 Mtetra
.26799 .45992 .27576 .45138 .28616 .44355 .27837 .45343 Mtetra
.27837 .45343 .28616 .44355 .2966 .43531 .28882 .44608 Mtetra
.28882 .44608 .2966 .43531 .30706 .42703 .29934 .43809 Mtetra
.29934 .43809 .30706 .42703 .3175 .419 .3099 .42964 Mtetra
.3099 .42964 .3175 .419 .32793 .41148 .32048 .42105 Mtetra
.32048 .42105 .32793 .41148 .33832 .40474 .33105 .4126 Mtetra
.33105 .4126 .33832 .40474 .34869 .39876 .34163 .40422 Mtetra
.437 .812 .561 r
.34163 .40422 .34869 .39876 .35904 .39362 .35221 .39599 Mtetra
.645 .965 .812 r
.35221 .39599 .35904 .39362 .36937 .38951 .36276 .38848 Mtetra
.751 .956 .94 r
.36276 .38848 .36937 .38951 .37969 .38647 .37329 .38182 Mtetra
.772 .835 .9 r
.37329 .38182 .37969 .38647 .39002 .38395 .38385 .37496 Mtetra
.745 .708 .817 r
.38385 .37496 .39002 .38395 .40039 .38176 .39444 .36753 Mtetra
.7 .608 .751 r
.39444 .36753 .40039 .38176 .41079 .38005 .40505 .36022 Mtetra
.662 .54 .705 r
.40505 .36022 .41079 .38005 .42122 .37913 .41566 .3533 Mtetra
.631 .49 .671 r
.41566 .3533 .42122 .37913 .43164 .3806 .42628 .34695 Mtetra
.606 .448 .641 r
.42628 .34695 .43164 .3806 .44208 .38424 .4369 .3412 Mtetra
.592 .419 .617 r
.4369 .3412 .44208 .38424 .45262 .38704 .44754 .33542 Mtetra
.581 .4 .601 r
.44754 .33542 .45262 .38704 .4633 .38741 .45821 .32986 Mtetra
.564 .382 .593 r
.45821 .32986 .4633 .38741 .4741 .38377 .46888 .32616 Mtetra
.551 .373 .592 r
.46888 .32616 .4741 .38377 .48501 .37612 .47956 .32431 Mtetra
.552 .379 .6 r
.47956 .32431 .48501 .37612 .49595 .36601 .49029 .32268 Mtetra
.556 .393 .616 r
.49029 .32268 .49595 .36601 .50689 .35503 .50108 .32104 Mtetra
.554 .412 .642 r
.50108 .32104 .50689 .35503 .51782 .34621 .51193 .32 Mtetra
.55 .437 .677 r
.51193 .32 .51782 .34621 .52877 .33979 .52283 .31955 Mtetra
.544 .468 .72 r
.52283 .31955 .52877 .33979 .53974 .33416 .53381 .31951 Mtetra
.535 .521 .786 r
.53381 .31951 .53974 .33416 .55075 .32901 .54485 .31959 Mtetra
.533 .622 .886 r
.54485 .31959 .55075 .32901 .56179 .32419 .55597 .31912 Mtetra
.465 .739 .987 r
.55597 .31912 .56179 .32419 .57288 .31989 .56714 .31843 Mtetra
.123 .659 .857 r
.56714 .31843 .57288 .31989 .58404 .31668 .5784 .31864 Mtetra
.252 0 0 r
.5784 .31864 .58404 .31668 .59526 .31451 .58975 .31959 Mtetra
.391 0 0 r
.58975 .31959 .59526 .31451 .60657 .31321 .60119 .3207 Mtetra
.44 0 .031 r
.60119 .3207 .60657 .31321 .61796 .31269 .61271 .3219 Mtetra
.465 .017 .101 r
.61271 .3219 .61796 .31269 .62945 .31298 .62432 .32326 Mtetra
.47 .036 .133 r
.62432 .32326 .62945 .31298 .64104 .3138 .63601 .3245 Mtetra
.458 .03 .137 r
.63601 .3245 .64104 .3138 .65272 .3149 .64777 .32527 Mtetra
.434 .002 .117 r
.64777 .32527 .65272 .3149 .66449 .31597 .65959 .32539 Mtetra
.391 0 .069 r
.65959 .32539 .66449 .31597 .67632 .31663 .67144 .32465 Mtetra
.327 0 0 r
.67144 .32465 .67632 .31663 .6882 .31672 .68333 .32304 Mtetra
.225 0 0 r
.68333 .32304 .6882 .31672 .70012 .31606 .69523 .3205 Mtetra
.07 0 0 r
.69523 .3205 .70012 .31606 .71208 .31462 .70715 .31713 Mtetra
0 0 0 r
.70715 .31713 .71208 .31462 .72404 .31233 .71907 .313 Mtetra
.392 .849 .8 r
.71907 .313 .72404 .31233 .73602 .3093 .731 .30824 Mtetra
.571 .932 .932 r
.731 .30824 .73602 .3093 .74802 .3056 .74295 .30302 Mtetra
.664 .931 .971 r
.74295 .30302 .74802 .3056 .76002 .30137 .75492 .29746 Mtetra
.702 .897 .967 r
.75492 .29746 .76002 .30137 .77205 .29675 .76691 .29172 Mtetra
.716 .86 .95 r
.76691 .29172 .77205 .29675 .7841 .29185 .77893 .28586 Mtetra
.718 .827 .932 r
.77893 .28586 .7841 .29185 .79618 .28679 .79098 .27995 Mtetra
.715 .798 .916 r
.79098 .27995 .79618 .28679 .8083 .28168 .80308 .27409 Mtetra
.56 .723 .95 r
.15266 .48451 .15958 .49055 .16912 .48895 .16219 .48309 Mtetra
.55 .727 .957 r
.16219 .48309 .16912 .48895 .17869 .48739 .17175 .48177 Mtetra
.539 .733 .964 r
.17175 .48177 .17869 .48739 .18831 .4858 .18135 .48054 Mtetra
.525 .742 .974 r
.18135 .48054 .18831 .4858 .19799 .4841 .19099 .47939 Mtetra
.504 .756 .986 r
.19099 .47939 .19799 .4841 .20772 .48225 .20067 .47832 Mtetra
.477 .777 .997 r
.20067 .47832 .20772 .48225 .21754 .48007 .21041 .47722 Mtetra
.431 .798 .995 r
.21041 .47722 .21754 .48007 .22743 .47746 .2202 .47602 Mtetra
.354 .803 .95 r
.2202 .47602 .22743 .47746 .23742 .47425 .23006 .47459 Mtetra
.232 .751 .818 r
.23006 .47459 .23742 .47425 .24751 .47031 .24001 .4728 Mtetra
0 0 0 r
.24001 .4728 .24751 .47031 .2577 .46556 .25004 .47052 Mtetra
.062 0 0 r
.25004 .47052 .2577 .46556 .26799 .45992 .26017 .46763 Mtetra
.159 0 0 r
.26017 .46763 .26799 .45992 .27837 .45343 .27039 .46406 Mtetra
.218 0 .004 r
.27039 .46406 .27837 .45343 .28882 .44608 .28071 .4597 Mtetra
.258 0 .099 r
.28071 .4597 .28882 .44608 .29934 .43809 .29112 .45456 Mtetra
.281 0 .161 r
.29112 .45456 .29934 .43809 .3099 .42964 .30161 .44862 Mtetra
.302 0 .206 r
.30161 .44862 .3099 .42964 .32048 .42105 .31216 .44215 Mtetra
.319 0 .237 r
.31216 .44215 .32048 .42105 .33105 .4126 .32275 .43533 Mtetra
.324 .001 .254 r
.32275 .43533 .33105 .4126 .34163 .40422 .33339 .42801 Mtetra
.323 .006 .263 r
.33339 .42801 .34163 .40422 .35221 .39599 .34407 .42021 Mtetra
.332 .017 .271 r
.34407 .42021 .35221 .39599 .36276 .38848 .35476 .41256 Mtetra
.34 .024 .274 r
.35476 .41256 .36276 .38848 .37329 .38182 .36545 .40524 Mtetra
.313 0 .258 r
.36545 .40524 .37329 .38182 .38385 .37496 .3762 .39707 Mtetra
.261 0 .225 r
.3762 .39707 .38385 .37496 .39444 .36753 .387 .38763 Mtetra
.215 0 .186 r
.387 .38763 .39444 .36753 .40505 .36022 .39784 .37775 Mtetra
.144 0 .121 r
.39784 .37775 .40505 .36022 .41566 .3533 .40868 .36746 Mtetra
0 0 0 r
.40868 .36746 .41566 .3533 .42628 .34695 .41959 .3553 Mtetra
.557 .814 .444 r
.41959 .3553 .42628 .34695 .4369 .3412 .43052 .34158 Mtetra
.905 .967 .812 r
.43052 .34158 .4369 .3412 .44754 .33542 .44142 .32846 Mtetra
.818 .776 .813 r
.44142 .32846 .44754 .33542 .45821 .32986 .45223 .31795 Mtetra
.642 .616 .808 r
.45223 .31795 .45821 .32986 .46888 .32616 .46291 .31422 Mtetra
.399 .487 .833 r
.46291 .31422 .46888 .32616 .47956 .32431 .47351 .31727 Mtetra
.001 .38 .842 r
.47351 .31727 .47956 .32431 .49029 .32268 .48417 .32296 Mtetra
.562 0 0 r
.48417 .32296 .49029 .32268 .50108 .32104 .49494 .32929 Mtetra
.571 .121 .143 r
.49494 .32929 .50108 .32104 .51193 .32 .50582 .33407 Mtetra
.532 .141 .245 r
.50582 .33407 .51193 .32 .52283 .31955 .51681 .33701 Mtetra
.527 .16 .287 r
.51681 .33701 .52283 .31955 .53381 .31951 .5279 .33954 Mtetra
.521 .169 .31 r
.5279 .33954 .53381 .31951 .54485 .31959 .53907 .34165 Mtetra
.502 .161 .32 r
.53907 .34165 .54485 .31959 .55597 .31912 .55032 .3425 Mtetra
.491 .156 .326 r
.55032 .3425 .55597 .31912 .56714 .31843 .56164 .3425 Mtetra
.497 .164 .332 r
.56164 .3425 .56714 .31843 .5784 .31864 .57303 .34283 Mtetra
.5 .166 .333 r
.57303 .34283 .5784 .31864 .58975 .31959 .58451 .34335 Mtetra
.491 .157 .327 r
.58451 .34335 .58975 .31959 .60119 .3207 .59606 .34338 Mtetra
.481 .143 .315 r
.59606 .34338 .60119 .3207 .61271 .3219 .60767 .34291 Mtetra
.47 .124 .297 r
.60767 .34291 .61271 .3219 .62432 .32326 .61934 .34209 Mtetra
.451 .095 .269 r
.61934 .34209 .62432 .32326 .63601 .3245 .63106 .34074 Mtetra
.417 .046 .224 r
.63106 .34074 .63601 .3245 .64777 .32527 .64283 .33857 Mtetra
.366 0 .154 r
.64283 .33857 .64777 .32527 .65959 .32539 .65462 .3356 Mtetra
.281 0 .04 r
.65462 .3356 .65959 .32539 .67144 .32465 .66644 .33182 Mtetra
.14 0 0 r
.66644 .33182 .67144 .32465 .68333 .32304 .67827 .32732 Mtetra
0 0 0 r
.67827 .32732 .68333 .32304 .69523 .3205 .69011 .32219 Mtetra
.377 .828 .72 r
.69011 .32219 .69523 .3205 .70715 .31713 .70197 .31655 Mtetra
.599 .948 .91 r
.70197 .31655 .70715 .31713 .71907 .313 .71384 .31053 Mtetra
.699 .943 .96 r
.71384 .31053 .71907 .313 .731 .30824 .72574 .30424 Mtetra
.73 .9 .955 r
.72574 .30424 .731 .30824 .74295 .30302 .73766 .29785 Mtetra
.737 .86 .938 r
.73766 .29785 .74295 .30302 .75492 .29746 .74961 .29142 Mtetra
.733 .829 .924 r
.74961 .29142 .75492 .29746 .76691 .29172 .7616 .28505 Mtetra
.729 .808 .914 r
.7616 .28505 .76691 .29172 .77893 .28586 .77363 .27876 Mtetra
.724 .793 .907 r
.77363 .27876 .77893 .28586 .79098 .27995 .7857 .27255 Mtetra
.719 .783 .903 r
.7857 .27255 .79098 .27995 .80308 .27409 .79782 .26643 Mtetra
.593 .734 .942 r
.14569 .47843 .15266 .48451 .16219 .48309 .1553 .47642 Mtetra
.591 .714 .929 r
.1553 .47642 .16219 .48309 .17175 .48177 .16494 .47453 Mtetra
.585 .694 .917 r
.16494 .47453 .17175 .48177 .18135 .48054 .1746 .4728 Mtetra
.577 .676 .907 r
.1746 .4728 .18135 .48054 .19099 .47939 .18429 .47129 Mtetra
.565 .662 .902 r
.18429 .47129 .19099 .47939 .20067 .47832 .194 .47004 Mtetra
.553 .652 .901 r
.194 .47004 .20067 .47832 .21041 .47722 .20373 .46905 Mtetra
.538 .65 .907 r
.20373 .46905 .21041 .47722 .2202 .47602 .21349 .46833 Mtetra
.522 .659 .921 r
.21349 .46833 .2202 .47602 .23006 .47459 .22328 .46779 Mtetra
.5 .68 .946 r
.22328 .46779 .23006 .47459 .24001 .4728 .23312 .46739 Mtetra
.464 .717 .979 r
.23312 .46739 .24001 .4728 .25004 .47052 .24301 .46698 Mtetra
.388 .756 .992 r
.24301 .46698 .25004 .47052 .26017 .46763 .25297 .46647 Mtetra
.23 .736 .894 r
.25297 .46647 .26017 .46763 .27039 .46406 .26301 .4657 Mtetra
0 0 0 r
.26301 .4657 .27039 .46406 .28071 .4597 .27313 .46452 Mtetra
.165 0 0 r
.27313 .46452 .28071 .4597 .29112 .45456 .28335 .46273 Mtetra
.251 0 0 r
.28335 .46273 .29112 .45456 .30161 .44862 .29368 .46016 Mtetra
.305 0 .076 r
.29368 .46016 .30161 .44862 .31216 .44215 .30409 .45695 Mtetra
.337 0 .16 r
.30409 .45695 .31216 .44215 .32275 .43533 .31459 .45317 Mtetra
.35 0 .211 r
.31459 .45317 .32275 .43533 .33339 .42801 .32516 .44864 Mtetra
.357 .018 .246 r
.32516 .44864 .33339 .42801 .34407 .42021 .33582 .44338 Mtetra
.376 .048 .277 r
.33582 .44338 .34407 .42021 .35476 .41256 .34651 .43798 Mtetra
.393 .074 .301 r
.34651 .43798 .35476 .41256 .36545 .40524 .35723 .43265 Mtetra
.391 .08 .313 r
.35723 .43265 .36545 .40524 .3762 .39707 .36802 .42664 Mtetra
.385 .082 .323 r
.36802 .42664 .3762 .39707 .387 .38763 .37887 .41969 Mtetra
.395 .098 .339 r
.37887 .41969 .387 .38763 .39784 .37775 .38975 .41256 Mtetra
.401 .111 .352 r
.38975 .41256 .39784 .37775 .40868 .36746 .40066 .40502 Mtetra
.367 .087 .351 r
.40066 .40502 .40868 .36746 .41959 .3553 .4117 .39441 Mtetra
.329 .059 .343 r
.4117 .39441 .41959 .3553 .43052 .34158 .42283 .38078 Mtetra
.333 .063 .346 r
.42283 .38078 .43052 .34158 .44142 .32846 .43394 .3673 Mtetra
.371 .095 .358 r
.43394 .3673 .44142 .32846 .45223 .31795 .44496 .35638 Mtetra
.465 .174 .387 r
.44496 .35638 .45223 .31795 .46291 .31422 .45581 .35266 Mtetra
.54 .241 .408 r
.45581 .35266 .46291 .31422 .47351 .31727 .46658 .35613 Mtetra
.563 .261 .414 r
.46658 .35613 .47351 .31727 .48417 .32296 .4774 .36221 Mtetra
.564 .262 .415 r
.4774 .36221 .48417 .32296 .49494 .32929 .48833 .36847 Mtetra
.537 .238 .407 r
.48833 .36847 .49494 .32929 .50582 .33407 .4994 .37172 Mtetra
.507 .209 .395 r
.4994 .37172 .50582 .33407 .51681 .33701 .51058 .3719 Mtetra
.501 .197 .384 r
.51058 .3719 .51681 .33701 .5279 .33954 .52183 .37168 Mtetra
.496 .186 .371 r
.52183 .37168 .5279 .33954 .53907 .34165 .53315 .37128 Mtetra
.48 .166 .355 r
.53315 .37128 .53907 .34165 .55032 .3425 .54454 .36995 Mtetra
.465 .146 .339 r
.54454 .36995 .55032 .3425 .56164 .3425 .55598 .36792 Mtetra
.461 .135 .326 r
.55598 .36792 .56164 .3425 .57303 .34283 .56749 .36597 Mtetra
.452 .117 .306 r
.56749 .36597 .57303 .34283 .58451 .34335 .57906 .3639 Mtetra
.426 .081 .275 r
.57906 .3639 .58451 .34335 .59606 .34338 .59067 .36107 Mtetra
.389 .03 .23 r
.59067 .36107 .59606 .34338 .60767 .34291 .60232 .35748 Mtetra
.339 0 .163 r
.60232 .35748 .60767 .34291 .61934 .34209 .61401 .3533 Mtetra
.252 0 .051 r
.61401 .3533 .61934 .34209 .63106 .34074 .62572 .34846 Mtetra
.085 0 0 r
.62572 .34846 .63106 .34074 .64283 .33857 .63745 .34281 Mtetra
0 0 0 r
.63745 .34281 .64283 .33857 .65462 .3356 .64919 .33653 Mtetra
.55 .929 .821 r
.64919 .33653 .65462 .3356 .66644 .33182 .66094 .32981 Mtetra
.726 .958 .945 r
.66094 .32981 .66644 .33182 .67827 .32732 .67271 .32281 Mtetra
.761 .884 .934 r
.67271 .32281 .67827 .32732 .69011 .32219 .68451 .31568 Mtetra
.755 .815 .9 r
.68451 .31568 .69011 .32219 .70197 .31655 .69632 .30855 Mtetra
.741 .767 .874 r
.69632 .30855 .70197 .31655 .71384 .31053 .70818 .30153 Mtetra
.729 .737 .858 r
.70818 .30153 .71384 .31053 .72574 .30424 .72007 .2947 Mtetra
.718 .721 .852 r
.72007 .2947 .72574 .30424 .73766 .29785 .73201 .28813 Mtetra
.71 .714 .852 r
.73201 .28813 .73766 .29785 .74961 .29142 .74401 .28182 Mtetra
.704 .716 .858 r
.74401 .28182 .74961 .29142 .7616 .28505 .75606 .27578 Mtetra
.701 .723 .867 r
.75606 .27578 .7616 .28505 .77363 .27876 .76816 .26995 Mtetra
.699 .735 .879 r
.76816 .26995 .77363 .27876 .7857 .27255 .78032 .26428 Mtetra
.698 .751 .892 r
.78032 .26428 .7857 .27255 .79782 .26643 .79252 .25872 Mtetra
.646 .749 .924 r
.13868 .4723 .14569 .47843 .1553 .47642 .14842 .46919 Mtetra
.642 .714 .9 r
.14842 .46919 .1553 .47642 .16494 .47453 .1582 .46618 Mtetra
.632 .68 .877 r
.1582 .46618 .16494 .47453 .1746 .4728 .16799 .46337 Mtetra
.62 .649 .857 r
.16799 .46337 .1746 .4728 .18429 .47129 .17779 .46083 Mtetra
.605 .62 .84 r
.17779 .46083 .18429 .47129 .194 .47004 .18759 .45869 Mtetra
.588 .595 .827 r
.18759 .45869 .194 .47004 .20373 .46905 .19739 .457 Mtetra
.569 .574 .818 r
.19739 .457 .20373 .46905 .21349 .46833 .20719 .45586 Mtetra
.551 .558 .814 r
.20719 .45586 .21349 .46833 .22328 .46779 .21698 .45525 Mtetra
.531 .547 .816 r
.21698 .45525 .22328 .46779 .23312 .46739 .22678 .45519 Mtetra
.512 .544 .825 r
.22678 .45519 .23312 .46739 .24301 .46698 .23661 .45556 Mtetra
.491 .549 .843 r
.23661 .45556 .24301 .46698 .25297 .46647 .24646 .45629 Mtetra
.469 .567 .872 r
.24646 .45629 .25297 .46647 .26301 .4657 .25636 .45721 Mtetra
.439 .6 .913 r
.25636 .45721 .26301 .4657 .27313 .46452 .26633 .45817 Mtetra
.399 .656 .962 r
.26633 .45817 .27313 .46452 .28335 .46273 .27638 .45886 Mtetra
.328 .716 .982 r
.27638 .45886 .28335 .46273 .29368 .46016 .28654 .45901 Mtetra
.161 .69 .86 r
.28654 .45901 .29368 .46016 .30409 .45695 .29679 .45868 Mtetra
.046 0 0 r
.29679 .45868 .30409 .45695 .31459 .45317 .30714 .45782 Mtetra
.183 0 0 r
.30714 .45782 .31459 .45317 .32516 .44864 .31759 .45632 Mtetra
.263 0 0 r
.31759 .45632 .32516 .44864 .33582 .44338 .32813 .45419 Mtetra
.334 0 .069 r
.32813 .45419 .33582 .44338 .34651 .43798 .33873 .45191 Mtetra
.384 0 .165 r
.33873 .45191 .34651 .43798 .35723 .43265 .34937 .44974 Mtetra
.413 .046 .228 r
.34937 .44974 .35723 .43265 .36802 .42664 .36007 .44758 Mtetra
.438 .092 .281 r
.36007 .44758 .36802 .42664 .37887 .41969 .37081 .44549 Mtetra
.469 .142 .329 r
.37081 .44549 .37887 .41969 .38975 .41256 .38158 .44412 Mtetra
.484 .174 .364 r
.38158 .44412 .38975 .41256 .40066 .40502 .39239 .44307 Mtetra
.457 .164 .378 r
.39239 .44307 .40066 .40502 .4117 .39441 .40338 .43906 Mtetra
.43 .152 .387 r
.40338 .43906 .4117 .39441 .42283 .38078 .41452 .43155 Mtetra
.434 .162 .401 r
.41452 .43155 .42283 .38078 .43394 .3673 .42571 .42304 Mtetra
.449 .181 .414 r
.42571 .42304 .43394 .3673 .44496 .35638 .4369 .41527 Mtetra
.486 .215 .428 r
.4369 .41527 .44496 .35638 .45581 .35266 .448 .41157 Mtetra
.515 .24 .435 r
.448 .41157 .45581 .35266 .46658 .35613 .45907 .41195 Mtetra
.519 .241 .432 r
.45907 .41195 .46658 .35613 .4774 .36221 .4702 .4131 Mtetra
.511 .229 .422 r
.4702 .4131 .4774 .36221 .48833 .36847 .48142 .41325 Mtetra
.476 .191 .401 r
.48142 .41325 .48833 .36847 .4994 .37172 .49275 .40989 Mtetra
.431 .141 .371 r
.49275 .40989 .4994 .37172 .51058 .3719 .50415 .40354 Mtetra
.414 .112 .341 r
.50415 .40354 .51058 .3719 .52183 .37168 .51558 .3975 Mtetra
.4 .081 .304 r
.51558 .3975 .52183 .37168 .53315 .37128 .52704 .39218 Mtetra
.369 .03 .253 r
.52704 .39218 .53315 .37128 .54454 .36995 .53854 .38693 Mtetra
.33 0 .192 r
.53854 .38693 .54454 .36995 .55598 .36792 .55007 .38168 Mtetra
.285 0 .118 r
.55007 .38168 .55598 .36792 .56749 .36597 .56165 .37653 Mtetra
.202 0 .001 r
.56165 .37653 .56749 .36597 .57906 .3639 .57326 .37123 Mtetra
.026 0 0 r
.57326 .37123 .57906 .3639 .59067 .36107 .5849 .36527 Mtetra
0 0 0 r
.5849 .36527 .59067 .36107 .60232 .35748 .59656 .35866 Mtetra
.582 .942 .82 r
.59656 .35866 .60232 .35748 .61401 .3533 .60823 .35149 Mtetra
.756 .964 .933 r
.60823 .35149 .61401 .3533 .62572 .34846 .61991 .3438 Mtetra
.794 .879 .909 r
.61991 .3438 .62572 .34846 .63745 .34281 .6316 .33555 Mtetra
.782 .795 .863 r
.6316 .33555 .63745 .34281 .64919 .33653 .64329 .327 Mtetra
.759 .733 .828 r
.64329 .327 .64919 .33653 .66094 .32981 .655 .31847 Mtetra
.739 .689 .803 r
.655 .31847 .66094 .32981 .67271 .32281 .66674 .31012 Mtetra
.721 .659 .788 r
.66674 .31012 .67271 .32281 .68451 .31568 .67851 .30213 Mtetra
.706 .64 .781 r
.67851 .30213 .68451 .31568 .69632 .30855 .69032 .29457 Mtetra
.693 .628 .779 r
.69032 .29457 .69632 .30855 .70818 .30153 .70219 .28757 Mtetra
.683 .624 .783 r
.70219 .28757 .70818 .30153 .72007 .2947 .71413 .2811 Mtetra
.674 .625 .792 r
.71413 .2811 .72007 .2947 .73201 .28813 .72613 .27519 Mtetra
.669 .633 .805 r
.72613 .27519 .73201 .28813 .74401 .28182 .7382 .26975 Mtetra
.665 .647 .823 r
.7382 .26975 .74401 .28182 .75606 .27578 .75035 .26471 Mtetra
.662 .666 .843 r
.75035 .26471 .75606 .27578 .76816 .26995 .76256 .25996 Mtetra
.662 .691 .867 r
.76256 .25996 .76816 .26995 .78032 .26428 .77484 .2554 Mtetra
.662 .721 .892 r
.77484 .2554 .78032 .26428 .79252 .25872 .78718 .25095 Mtetra
.693 .759 .903 r
.13161 .46613 .13868 .4723 .14842 .46919 .14152 .46179 Mtetra
.684 .722 .878 r
.14152 .46179 .14842 .46919 .1582 .46618 .15145 .45752 Mtetra
.672 .686 .855 r
.15145 .45752 .1582 .46618 .16799 .46337 .16139 .45344 Mtetra
.657 .653 .835 r
.16139 .45344 .16799 .46337 .17779 .46083 .17133 .44965 Mtetra
.639 .622 .817 r
.17133 .44965 .17779 .46083 .18759 .45869 .18127 .44628 Mtetra
.621 .593 .801 r
.18127 .44628 .18759 .45869 .19739 .457 .19119 .44339 Mtetra
.601 .566 .786 r
.19119 .44339 .19739 .457 .20719 .45586 .20109 .44111 Mtetra
.584 .541 .773 r
.20109 .44111 .20719 .45586 .21698 .45525 .21098 .43937 Mtetra
.567 .519 .761 r
.21098 .43937 .21698 .45525 .22678 .45519 .22087 .4382 Mtetra
.556 .501 .749 r
.22087 .4382 .22678 .45519 .23661 .45556 .23078 .43744 Mtetra
.548 .485 .738 r
.23078 .43744 .23661 .45556 .24646 .45629 .24071 .43699 Mtetra
.543 .473 .726 r
.24071 .43699 .24646 .45629 .25636 .45721 .25068 .43674 Mtetra
.541 .463 .716 r
.25068 .43674 .25636 .45721 .26633 .45817 .26071 .43656 Mtetra
.544 .457 .707 r
.26071 .43656 .26633 .45817 .27638 .45886 .2708 .43624 Mtetra
.55 .454 .699 r
.2708 .43624 .27638 .45886 .28654 .45901 .28098 .43561 Mtetra
.554 .452 .694 r
.28098 .43561 .28654 .45901 .29679 .45868 .29124 .43478 Mtetra
.556 .452 .69 r
.29124 .43478 .29679 .45868 .30714 .45782 .30156 .43377 Mtetra
.56 .454 .69 r
.30156 .43377 .30714 .45782 .31759 .45632 .31196 .43254 Mtetra
.563 .458 .692 r
.31196 .43254 .31759 .45632 .32813 .45419 .32242 .43113 Mtetra
.563 .462 .697 r
.32242 .43113 .32813 .45419 .33873 .45191 .33293 .42978 Mtetra
.558 .465 .705 r
.33293 .42978 .33873 .45191 .34937 .44974 .34349 .42872 Mtetra
.547 .466 .715 r
.34349 .42872 .34937 .44974 .36007 .44758 .35407 .42827 Mtetra
.526 .467 .733 r
.35407 .42827 .36007 .44758 .37081 .44549 .36467 .42873 Mtetra
.473 .462 .765 r
.36467 .42873 .37081 .44549 .38158 .44412 .37526 .43082 Mtetra
.388 .464 .817 r
.37526 .43082 .38158 .44412 .39239 .44307 .38588 .43425 Mtetra
.392 .576 .912 r
.38588 .43425 .39239 .44307 .40338 .43906 .39666 .436 Mtetra
.375 .776 .985 r
.39666 .436 .40338 .43906 .41452 .43155 .40761 .4351 Mtetra
.014 0 0 r
.40761 .4351 .41452 .43155 .42571 .42304 .41868 .43253 Mtetra
.229 0 0 r
.41868 .43253 .42571 .42304 .4369 .41527 .42984 .4288 Mtetra
.322 0 .122 r
.42984 .4288 .4369 .41527 .448 .41157 .44105 .42509 Mtetra
.323 0 .122 r
.44105 .42509 .448 .41157 .45907 .41195 .4523 .42141 Mtetra
.166 0 0 r
.4523 .42141 .45907 .41195 .4702 .4131 .46361 .41655 Mtetra
.383 .814 .647 r
.46361 .41655 .4702 .4131 .48142 .41325 .475 .41002 Mtetra
.825 .909 .897 r
.475 .41002 .48142 .41325 .49275 .40989 .48644 .40079 Mtetra
.8 .742 .799 r
.48644 .40079 .49275 .40989 .50415 .40354 .49791 .38986 Mtetra
.737 .647 .759 r
.49791 .38986 .50415 .40354 .51558 .3975 .50936 .38025 Mtetra
.688 .584 .734 r
.50936 .38025 .51558 .3975 .52704 .39218 .52082 .37228 Mtetra
.661 .547 .716 r
.52082 .37228 .52704 .39218 .53854 .38693 .5323 .36521 Mtetra
.644 .525 .704 r
.5323 .36521 .53854 .38693 .55007 .38168 .54381 .35875 Mtetra
.635 .513 .697 r
.54381 .35875 .55007 .38168 .56165 .37653 .55536 .35257 Mtetra
.631 .505 .69 r
.55536 .35257 .56165 .37653 .57326 .37123 .56693 .34645 Mtetra
.63 .5 .685 r
.56693 .34645 .57326 .37123 .5849 .36527 .57854 .34012 Mtetra
.632 .5 .683 r
.57854 .34012 .5849 .36527 .59656 .35866 .59017 .33357 Mtetra
.634 .501 .683 r
.59017 .33357 .59656 .35866 .60823 .35149 .60182 .32682 Mtetra
.638 .506 .685 r
.60182 .32682 .60823 .35149 .61991 .3438 .6135 .31986 Mtetra
.645 .514 .689 r
.6135 .31986 .61991 .3438 .6316 .33555 .6252 .31256 Mtetra
.651 .523 .695 r
.6252 .31256 .6316 .33555 .64329 .327 .63692 .3051 Mtetra
.654 .532 .702 r
.63692 .3051 .64329 .327 .655 .31847 .64866 .29771 Mtetra
.657 .541 .711 r
.64866 .29771 .655 .31847 .66674 .31012 .66044 .2905 Mtetra
.658 .55 .721 r
.66044 .2905 .66674 .31012 .67851 .30213 .67226 .2836 Mtetra
.657 .559 .732 r
.67226 .2836 .67851 .30213 .69032 .29457 .68412 .27712 Mtetra
.653 .567 .745 r
.68412 .27712 .69032 .29457 .70219 .28757 .69606 .27121 Mtetra
.648 .576 .76 r
.69606 .27121 .70219 .28757 .71413 .2811 .70806 .26587 Mtetra
.642 .587 .777 r
.70806 .26587 .71413 .2811 .72613 .27519 .72015 .26114 Mtetra
.636 .6 .796 r
.72015 .26114 .72613 .27519 .7382 .26975 .73232 .25692 Mtetra
.631 .617 .819 r
.73232 .25692 .7382 .26975 .75035 .26471 .74458 .25312 Mtetra
.626 .639 .843 r
.74458 .25312 .75035 .26471 .76256 .25996 .75691 .24963 Mtetra
.623 .666 .871 r
.75691 .24963 .76256 .25996 .77484 .2554 .76932 .24633 Mtetra
.62 .698 .9 r
.76932 .24633 .77484 .2554 .78718 .25095 .7818 .24311 Mtetra
.725 .765 .884 r
.12449 .45992 .13161 .46613 .14152 .46179 .13455 .4545 Mtetra
.716 .733 .865 r
.13455 .4545 .14152 .46179 .15145 .45752 .14462 .44914 Mtetra
.704 .703 .847 r
.14462 .44914 .15145 .45752 .16139 .45344 .15471 .44392 Mtetra
.69 .674 .83 r
.15471 .44392 .16139 .45344 .17133 .44965 .16479 .43894 Mtetra
.674 .646 .814 r
.16479 .43894 .17133 .44965 .18127 .44628 .17487 .4343 Mtetra
.657 .617 .798 r
.17487 .4343 .18127 .44628 .19119 .44339 .18494 .43003 Mtetra
.64 .589 .781 r
.18494 .43003 .19119 .44339 .20109 .44111 .19499 .4262 Mtetra
.625 .562 .764 r
.19499 .4262 .20109 .44111 .21098 .43937 .20505 .42272 Mtetra
.612 .536 .745 r
.20505 .42272 .21098 .43937 .22087 .4382 .21511 .41953 Mtetra
.603 .513 .726 r
.21511 .41953 .22087 .4382 .23078 .43744 .22521 .41649 Mtetra
.596 .493 .706 r
.22521 .41649 .23078 .43744 .24071 .43699 .23534 .41347 Mtetra
.59 .473 .688 r
.23534 .41347 .24071 .43699 .25068 .43674 .24551 .41047 Mtetra
.585 .457 .672 r
.24551 .41047 .25068 .43674 .26071 .43656 .25573 .40744 Mtetra
.58 .443 .659 r
.25573 .40744 .26071 .43656 .2708 .43624 .26599 .40438 Mtetra
.577 .432 .647 r
.26599 .40438 .2708 .43624 .28098 .43561 .2763 .40126 Mtetra
.572 .421 .638 r
.2763 .40126 .28098 .43561 .29124 .43478 .28664 .39829 Mtetra
.566 .412 .632 r
.28664 .39829 .29124 .43478 .30156 .43377 .29701 .3956 Mtetra
.562 .406 .627 r
.29701 .3956 .30156 .43377 .31196 .43254 .3074 .39315 Mtetra
.558 .4 .623 r
.3074 .39315 .31196 .43254 .32242 .43113 .31783 .39097 Mtetra
.555 .397 .621 r
.31783 .39097 .32242 .43113 .33293 .42978 .32829 .38903 Mtetra
.551 .393 .62 r
.32829 .38903 .33293 .42978 .34349 .42872 .33879 .38742 Mtetra
.542 .386 .618 r
.33879 .38742 .34349 .42872 .35407 .42827 .34929 .38662 Mtetra
.529 .376 .617 r
.34929 .38662 .35407 .42827 .36467 .42873 .3598 .38704 Mtetra
.505 .358 .616 r
.3598 .38704 .36467 .42873 .37526 .43082 .37026 .38966 Mtetra
.478 .34 .615 r
.37026 .38966 .37526 .43082 .38588 .43425 .38072 .39447 Mtetra
.474 .342 .62 r
.38072 .39447 .38588 .43425 .39666 .436 .39127 .3994 Mtetra
.484 .357 .631 r
.39127 .3994 .39666 .436 .40761 .4351 .40196 .40331 Mtetra
.503 .385 .651 r
.40196 .40331 .40761 .4351 .41868 .43253 .41281 .40553 Mtetra
.54 .429 .677 r
.41281 .40553 .41868 .43253 .42984 .4288 .42381 .40531 Mtetra
.6 .486 .696 r
.42381 .40531 .42984 .4288 .44105 .42509 .43499 .40156 Mtetra
.648 .516 .689 r
.43499 .40156 .44105 .42509 .4523 .42141 .4463 .39427 Mtetra
.662 .509 .666 r
.4463 .39427 .4523 .42141 .46361 .41655 .45768 .38451 Mtetra
.66 .491 .645 r
.45768 .38451 .46361 .41655 .475 .41002 .4691 .37303 Mtetra
.653 .475 .63 r
.4691 .37303 .475 .41002 .48644 .40079 .48052 .3605 Mtetra
.644 .461 .621 r
.48052 .3605 .48644 .40079 .49791 .38986 .49193 .34805 Mtetra
.624 .445 .619 r
.49193 .34805 .49791 .38986 .50936 .38025 .50331 .33779 Mtetra
.606 .431 .618 r
.50331 .33779 .50936 .38025 .52082 .37228 .51468 .32974 Mtetra
.596 .423 .618 r
.51468 .32974 .52082 .37228 .5323 .36521 .52607 .32291 Mtetra
.589 .419 .619 r
.52607 .32291 .5323 .36521 .54381 .35875 .5375 .31689 Mtetra
.587 .418 .62 r
.5375 .31689 .54381 .35875 .55536 .35257 .54895 .3112 Mtetra
.585 .418 .622 r
.54895 .3112 .55536 .35257 .56693 .34645 .56044 .30575 Mtetra
.584 .419 .624 r
.56044 .30575 .56693 .34645 .57854 .34012 .57198 .30056 Mtetra
.583 .42 .627 r
.57198 .30056 .57854 .34012 .59017 .33357 .58356 .29562 Mtetra
.582 .424 .631 r
.58356 .29562 .59017 .33357 .60182 .32682 .59519 .29095 Mtetra
.584 .43 .638 r
.59519 .29095 .60182 .32682 .6135 .31986 .60686 .28644 Mtetra
.588 .439 .647 r
.60686 .28644 .6135 .31986 .6252 .31256 .61858 .28186 Mtetra
.593 .452 .658 r
.61858 .28186 .6252 .31256 .63692 .3051 .63035 .27724 Mtetra
.599 .466 .671 r
.63035 .27724 .63692 .3051 .64866 .29771 .64216 .27259 Mtetra
.606 .483 .687 r
.64216 .27259 .64866 .29771 .66044 .2905 .65401 .26796 Mtetra
.613 .503 .704 r
.65401 .26796 .66044 .2905 .67226 .2836 .66592 .26334 Mtetra
.617 .522 .723 r
.66592 .26334 .67226 .2836 .68412 .27712 .67788 .25887 Mtetra
.619 .54 .744 r
.67788 .25887 .68412 .27712 .69606 .27121 .6899 .2547 Mtetra
.618 .558 .765 r
.6899 .2547 .69606 .27121 .70806 .26587 .702 .25088 Mtetra
.613 .575 .787 r
.702 .25088 .70806 .26587 .72015 .26114 .71418 .24753 Mtetra
.607 .593 .811 r
.71418 .24753 .72015 .26114 .73232 .25692 .72645 .24456 Mtetra
.6 .611 .835 r
.72645 .24456 .73232 .25692 .74458 .25312 .73881 .24195 Mtetra
.593 .632 .86 r
.73881 .24195 .74458 .25312 .75691 .24963 .75125 .23958 Mtetra
.586 .656 .885 r
.75125 .23958 .75691 .24963 .76932 .24633 .76377 .23737 Mtetra
.58 .683 .911 r
.76377 .23737 .76932 .24633 .7818 .24311 .77637 .23521 Mtetra
.736 .766 .877 r
.11732 .45366 .12449 .45992 .13455 .4545 .12746 .44778 Mtetra
.732 .753 .869 r
.12746 .44778 .13455 .4545 .14462 .44914 .13762 .44191 Mtetra
.727 .739 .861 r
.13762 .44191 .14462 .44914 .15471 .44392 .14779 .43609 Mtetra
.72 .723 .852 r
.14779 .43609 .15471 .44392 .16479 .43894 .15798 .43035 Mtetra
.711 .703 .84 r
.15798 .43035 .16479 .43894 .17487 .4343 .16818 .42473 Mtetra
.702 .679 .825 r
.16818 .42473 .17487 .4343 .18494 .43003 .17839 .4192 Mtetra
.69 .652 .807 r
.17839 .4192 .18494 .43003 .19499 .4262 .18862 .41375 Mtetra
.679 .621 .784 r
.18862 .41375 .19499 .4262 .20505 .42272 .19888 .40832 Mtetra
.668 .591 .76 r
.19888 .40832 .20505 .42272 .21511 .41953 .20917 .40283 Mtetra
.655 .56 .736 r
.20917 .40283 .21511 .41953 .22521 .41649 .21948 .39732 Mtetra
.644 .534 .714 r
.21948 .39732 .22521 .41649 .23534 .41347 .22983 .39178 Mtetra
.631 .509 .696 r
.22983 .39178 .23534 .41347 .24551 .41047 .24018 .38645 Mtetra
.617 .488 .683 r
.24018 .38645 .24551 .41047 .25573 .40744 .25053 .38151 Mtetra
.605 .472 .673 r
.25053 .38151 .25573 .40744 .26599 .40438 .26087 .37703 Mtetra
.594 .459 .666 r
.26087 .37703 .26599 .40438 .2763 .40126 .2712 .3731 Mtetra
.585 .449 .663 r
.2712 .3731 .2763 .40126 .28664 .39829 .28152 .36975 Mtetra
.576 .442 .661 r
.28152 .36975 .28664 .39829 .29701 .3956 .29184 .36698 Mtetra
.572 .439 .661 r
.29184 .36698 .29701 .3956 .3074 .39315 .30219 .36453 Mtetra
.57 .438 .661 r
.30219 .36453 .3074 .39315 .31783 .39097 .31258 .36219 Mtetra
.572 .439 .661 r
.31258 .36219 .31783 .39097 .32829 .38903 .32302 .35964 Mtetra
.576 .439 .658 r
.32302 .35964 .32829 .38903 .33879 .38742 .33354 .35678 Mtetra
.573 .433 .653 r
.33354 .35678 .33879 .38742 .34929 .38662 .3441 .354 Mtetra
.563 .421 .645 r
.3441 .354 .34929 .38662 .3598 .38704 .35468 .35177 Mtetra
.537 .395 .635 r
.35468 .35177 .3598 .38704 .37026 .38966 .36521 .35145 Mtetra
.508 .368 .625 r
.36521 .35145 .37026 .38966 .38072 .39447 .3757 .35348 Mtetra
.492 .35 .616 r
.3757 .35348 .38072 .39447 .39127 .3994 .3862 .35702 Mtetra
.485 .343 .612 r
.3862 .35702 .39127 .3994 .40196 .40331 .39677 .36123 Mtetra
.496 .352 .615 r
.39677 .36123 .40196 .40331 .41281 .40553 .40748 .36453 Mtetra
.522 .373 .62 r
.40748 .36453 .41281 .40553 .42381 .40531 .41835 .36548 Mtetra
.572 .411 .625 r
.41835 .36548 .42381 .40531 .43499 .40156 .42944 .36167 Mtetra
.615 .441 .624 r
.42944 .36167 .43499 .40156 .4463 .39427 .44071 .35308 Mtetra
.631 .45 .62 r
.44071 .35308 .4463 .39427 .45768 .38451 .45204 .34213 Mtetra
.635 .451 .616 r
.45204 .34213 .45768 .38451 .4691 .37303 .46338 .33023 Mtetra
.629 .446 .616 r
.46338 .33023 .4691 .37303 .48052 .3605 .47471 .31899 Mtetra
.621 .442 .619 r
.47471 .31899 .48052 .3605 .49193 .34805 .48601 .30924 Mtetra
.606 .437 .626 r
.48601 .30924 .49193 .34805 .50331 .33779 .49729 .30184 Mtetra
.593 .434 .635 r
.49729 .30184 .50331 .33779 .51468 .32974 .50859 .29637 Mtetra
.592 .44 .645 r
.50859 .29637 .51468 .32974 .52607 .32291 .51992 .29144 Mtetra
.594 .448 .652 r
.51992 .29144 .52607 .32291 .5375 .31689 .53129 .2866 Mtetra
.601 .456 .657 r
.53129 .2866 .5375 .31689 .54895 .3112 .5427 .28143 Mtetra
.604 .46 .659 r
.5427 .28143 .54895 .3112 .56044 .30575 .55414 .27605 Mtetra
.603 .46 .66 r
.55414 .27605 .56044 .30575 .57198 .30056 .56563 .27078 Mtetra
.599 .457 .66 r
.56563 .27078 .57198 .30056 .58356 .29562 .57716 .26582 Mtetra
.592 .452 .661 r
.57716 .26582 .58356 .29562 .59519 .29095 .58874 .26145 Mtetra
.585 .449 .663 r
.58874 .26145 .59519 .29095 .60686 .28644 .60039 .25767 Mtetra
.579 .448 .667 r
.60039 .25767 .60686 .28644 .61858 .28186 .6121 .25445 Mtetra
.575 .452 .675 r
.6121 .25445 .61858 .28186 .63035 .27724 .62388 .25171 Mtetra
.571 .459 .687 r
.62388 .25171 .63035 .27724 .64216 .27259 .63574 .24937 Mtetra
.571 .472 .703 r
.63574 .24937 .64216 .27259 .65401 .26796 .64767 .24726 Mtetra
.575 .493 .724 r
.64767 .24726 .65401 .26796 .66592 .26334 .65967 .24512 Mtetra
.58 .517 .75 r
.65967 .24512 .66592 .26334 .67788 .25887 .67174 .24295 Mtetra
.584 .546 .778 r
.67174 .24295 .67788 .25887 .6899 .2547 .68387 .24073 Mtetra
.586 .576 .808 r
.68387 .24073 .6899 .2547 .702 .25088 .69607 .23853 Mtetra
.585 .603 .837 r
.69607 .23853 .702 .25088 .71418 .24753 .70834 .23642 Mtetra
.581 .628 .863 r
.70834 .23642 .71418 .24753 .72645 .24456 .72069 .23441 Mtetra
.574 .648 .885 r
.72069 .23441 .72645 .24456 .73881 .24195 .73313 .23252 Mtetra
.568 .664 .903 r
.73313 .23252 .73881 .24195 .75125 .23958 .74564 .23072 Mtetra
.562 .678 .917 r
.74564 .23072 .75125 .23958 .76377 .23737 .75823 .22897 Mtetra
.557 .691 .929 r
.75823 .22897 .76377 .23737 .77637 .23521 .7709 .22725 Mtetra
.733 .766 .879 r
.1101 .44736 .11732 .45366 .12746 .44778 .12025 .4416 Mtetra
.734 .77 .882 r
.12025 .4416 .12746 .44778 .13762 .44191 .13042 .43581 Mtetra
.736 .774 .883 r
.13042 .43581 .13762 .44191 .14779 .43609 .14063 .42995 Mtetra
.739 .774 .881 r
.14063 .42995 .14779 .43609 .15798 .43035 .15087 .42397 Mtetra
.741 .768 .874 r
.15087 .42397 .15798 .43035 .16818 .42473 .16115 .41783 Mtetra
.742 .754 .862 r
.16115 .41783 .16818 .42473 .17839 .4192 .17148 .41145 Mtetra
.742 .733 .843 r
.17148 .41145 .17839 .4192 .18862 .41375 .18186 .40475 Mtetra
.736 .703 .82 r
.18186 .40475 .18862 .41375 .19888 .40832 .1923 .39775 Mtetra
.729 .672 .794 r
.1923 .39775 .19888 .40832 .20917 .40283 .20278 .39041 Mtetra
.715 .638 .771 r
.20278 .39041 .20917 .40283 .21948 .39732 .21329 .383 Mtetra
.699 .608 .751 r
.21329 .383 .21948 .39732 .22983 .39178 .2238 .37569 Mtetra
.679 .579 .737 r
.2238 .37569 .22983 .39178 .24018 .38645 .23428 .36893 Mtetra
.656 .554 .728 r
.23428 .36893 .24018 .38645 .25053 .38151 .2447 .36309 Mtetra
.635 .535 .724 r
.2447 .36309 .25053 .38151 .26087 .37703 .25506 .35822 Mtetra
.615 .52 .724 r
.25506 .35822 .26087 .37703 .2712 .3731 .26536 .35443 Mtetra
.599 .512 .728 r
.26536 .35443 .2712 .3731 .28152 .36975 .27564 .35146 Mtetra
.587 .508 .734 r
.27564 .35146 .28152 .36975 .29184 .36698 .28591 .34914 Mtetra
.584 .511 .739 r
.28591 .34914 .29184 .36698 .30219 .36453 .29622 .34698 Mtetra
.59 .518 .742 r
.29622 .34698 .30219 .36453 .31258 .36219 .3066 .34457 Mtetra
.607 .528 .739 r
.3066 .34457 .31258 .36219 .32302 .35964 .31708 .34133 Mtetra
.627 .533 .729 r
.31708 .34133 .32302 .35964 .33354 .35678 .32768 .33692 Mtetra
.637 .528 .713 r
.32768 .33692 .33354 .35678 .3441 .354 .33837 .33151 Mtetra
.636 .51 .693 r
.33837 .33151 .3441 .354 .35468 .35177 .34913 .32548 Mtetra
.608 .473 .672 r
.34913 .32548 .35468 .35177 .36521 .35145 .35986 .32059 Mtetra
.572 .432 .652 r
.35986 .32059 .36521 .35145 .3757 .35348 .37052 .31774 Mtetra
.537 .394 .633 r
.37052 .31774 .3757 .35348 .3862 .35702 .38112 .31732 Mtetra
.512 .366 .62 r
.38112 .31732 .3862 .35702 .39677 .36123 .39169 .31899 Mtetra
.51 .361 .614 r
.39169 .31899 .39677 .36123 .40748 .36453 .40234 .32086 Mtetra
.526 .369 .612 r
.40234 .32086 .40748 .36453 .41835 .36548 .41312 .32134 Mtetra
.567 .399 .613 r
.41312 .32134 .41835 .36548 .42944 .36167 .42412 .31747 Mtetra
.604 .425 .613 r
.42412 .31747 .42944 .36167 .44071 .35308 .43528 .30924 Mtetra
.615 .433 .613 r
.43528 .30924 .44071 .35308 .45204 .34213 .44649 .2996 Mtetra
.616 .436 .616 r
.44649 .2996 .45204 .34213 .46338 .33023 .45771 .29014 Mtetra
.603 .431 .622 r
.45771 .29014 .46338 .33023 .47471 .31899 .46889 .28278 Mtetra
.587 .428 .634 r
.46889 .28278 .47471 .31899 .48601 .30924 .48006 .27785 Mtetra
.571 .431 .652 r
.48006 .27785 .48601 .30924 .49729 .30184 .49124 .27497 Mtetra
.56 .442 .675 r
.49124 .27497 .49729 .30184 .50859 .29637 .50247 .27325 Mtetra
.575 .472 .7 r
.50247 .27325 .50859 .29637 .51992 .29144 .51377 .27092 Mtetra
.598 .504 .719 r
.51377 .27092 .51992 .29144 .53129 .2866 .52512 .26757 Mtetra
.623 .531 .73 r
.52512 .26757 .53129 .2866 .5427 .28143 .53653 .26303 Mtetra
.64 .547 .733 r
.53653 .26303 .5427 .28143 .55414 .27605 .54797 .25764 Mtetra
.644 .55 .733 r
.54797 .25764 .55414 .27605 .56563 .27078 .55944 .25199 Mtetra
.64 .544 .73 r
.55944 .25199 .56563 .27078 .57716 .26582 .57095 .2465 Mtetra
.627 .532 .728 r
.57095 .2465 .57716 .26582 .58874 .26145 .58252 .24166 Mtetra
.61 .519 .726 r
.58252 .24166 .58874 .26145 .60039 .25767 .59414 .23766 Mtetra
.59 .505 .727 r
.59414 .23766 .60039 .25767 .6121 .25445 .60585 .23477 Mtetra
.571 .497 .733 r
.60585 .23477 .6121 .25445 .62388 .25171 .61764 .23287 Mtetra
.553 .494 .744 r
.61764 .23287 .62388 .25171 .63574 .24937 .62954 .23193 Mtetra
.539 .501 .762 r
.62954 .23193 .63574 .24937 .64767 .24726 .64153 .23156 Mtetra
.534 .52 .786 r
.64153 .23156 .64767 .24726 .65967 .24512 .65361 .2313 Mtetra
.532 .548 .816 r
.65361 .2313 .65967 .24512 .67174 .24295 .66577 .23099 Mtetra
.538 .585 .85 r
.66577 .23099 .67174 .24295 .68387 .24073 .67799 .23033 Mtetra
.541 .623 .883 r
.67799 .23033 .68387 .24073 .69607 .23853 .69028 .22936 Mtetra
.546 .659 .91 r
.69028 .22936 .69607 .23853 .70834 .23642 .70263 .22807 Mtetra
.549 .686 .93 r
.70263 .22807 .70834 .23642 .72069 .23441 .71505 .22654 Mtetra
.551 .704 .941 r
.71505 .22654 .72069 .23441 .73313 .23252 .72753 .22485 Mtetra
.554 .712 .946 r
.72753 .22485 .73313 .23252 .74564 .23072 .74007 .22303 Mtetra
.556 .714 .946 r
.74007 .22303 .74564 .23072 .75823 .22897 .75269 .22114 Mtetra
.558 .711 .943 r
.75269 .22114 .75823 .22897 .7709 .22725 .76539 .21923 Mtetra
.71 .762 .893 r
.10283 .44102 .1101 .44736 .12025 .4416 .1129 .43604 Mtetra
.716 .789 .909 r
.1129 .43604 .12025 .4416 .13042 .43581 .12301 .43097 Mtetra
.724 .814 .921 r
.12301 .43097 .13042 .43581 .14063 .42995 .13317 .42572 Mtetra
.735 .837 .928 r
.13317 .42572 .14063 .42995 .15087 .42397 .14339 .4202 Mtetra
.748 .854 .928 r
.14339 .4202 .15087 .42397 .16115 .41783 .15368 .41429 Mtetra
.762 .863 .924 r
.15368 .41429 .16115 .41783 .17148 .41145 .16404 .40795 Mtetra
.777 .865 .914 r
.16404 .40795 .17148 .41145 .18186 .40475 .17448 .40109 Mtetra
.786 .86 .905 r
.17448 .40109 .18186 .40475 .1923 .39775 .18497 .39387 Mtetra
.792 .853 .896 r
.18497 .39387 .1923 .39775 .20278 .39041 .19552 .38633 Mtetra
.789 .848 .895 r
.19552 .38633 .20278 .39041 .21329 .383 .20607 .37886 Mtetra
.78 .848 .902 r
.20607 .37886 .21329 .383 .2238 .37569 .2166 .37173 Mtetra
.763 .855 .919 r
.2166 .37173 .2238 .37569 .23428 .36893 .22709 .36527 Mtetra
.729 .866 .945 r
.22709 .36527 .23428 .36893 .2447 .36309 .23751 .35978 Mtetra
.693 .875 .967 r
.23751 .35978 .2447 .36309 .25506 .35822 .24789 .35505 Mtetra
.652 .873 .981 r
.24789 .35505 .25506 .35822 .26536 .35443 .25825 .35103 Mtetra
.629 .86 .986 r
.25825 .35103 .26536 .35443 .27564 .35146 .26861 .34744 Mtetra
.626 .837 .981 r
.26861 .34744 .27564 .35146 .28591 .34914 .27899 .34407 Mtetra
.637 .803 .962 r
.27899 .34407 .28591 .34914 .29622 .34698 .28941 .3407 Mtetra
.654 .766 .931 r
.28941 .3407 .29622 .34698 .3066 .34457 .2999 .33706 Mtetra
.685 .737 .89 r
.2999 .33706 .3066 .34457 .31708 .34133 .31049 .33249 Mtetra
.714 .712 .846 r
.31049 .33249 .31708 .34133 .32768 .33692 .32121 .32655 Mtetra
.736 .687 .804 r
.32121 .32655 .32768 .33692 .33837 .33151 .33205 .31891 Mtetra
.74 .653 .764 r
.33205 .31891 .33837 .33151 .34913 .32548 .34301 .30977 Mtetra
.71 .604 .736 r
.34301 .30977 .34913 .32548 .35986 .32059 .35394 .30097 Mtetra
.666 .547 .71 r
.35394 .30097 .35986 .32059 .37052 .31774 .36482 .29362 Mtetra
.609 .484 .685 r
.36482 .29362 .37052 .31774 .38112 .31732 .37558 .28904 Mtetra
.558 .432 .664 r
.37558 .28904 .38112 .31732 .39169 .31899 .38624 .28733 Mtetra
.539 .407 .649 r
.38624 .28733 .39169 .31899 .40234 .32086 .39692 .28676 Mtetra
.542 .401 .639 r
.39692 .28676 .40234 .32086 .41312 .32134 .40768 .28593 Mtetra
.577 .422 .635 r
.40768 .28593 .41312 .32134 .42412 .31747 .4186 .28201 Mtetra
.609 .444 .634 r
.4186 .28201 .42412 .31747 .43528 .30924 .42967 .27499 Mtetra
.614 .451 .638 r
.42967 .27499 .43528 .30924 .44649 .2996 .44076 .2677 Mtetra
.607 .453 .647 r
.44076 .2677 .44649 .2996 .45771 .29014 .45185 .26154 Mtetra
.579 .446 .664 r
.45185 .26154 .45771 .29014 .46889 .28278 .46291 .25828 Mtetra
.541 .441 .69 r
.46291 .25828 .46889 .28278 .48006 .27785 .47397 .25779 Mtetra
.508 .452 .728 r
.47397 .25779 .48006 .27785 .49124 .27497 .48509 .2588 Mtetra
.488 .481 .776 r
.48509 .2588 .49124 .27497 .50247 .27325 .49628 .26015 Mtetra
.525 .55 .823 r
.49628 .26015 .50247 .27325 .51377 .27092 .50757 .26 Mtetra
.579 .622 .859 r
.50757 .26 .51377 .27092 .52512 .26757 .51894 .25814 Mtetra
.627 .68 .881 r
.51894 .25814 .52512 .26757 .53653 .26303 .53037 .25489 Mtetra
.661 .73 .901 r
.53037 .25489 .53653 .26303 .54797 .25764 .54185 .25069 Mtetra
.672 .772 .925 r
.54185 .25069 .54797 .25764 .55944 .25199 .55337 .24622 Mtetra
.67 .812 .951 r
.55337 .24622 .55944 .25199 .57095 .2465 .56494 .24174 Mtetra
.651 .844 .975 r
.56494 .24174 .57095 .2465 .58252 .24166 .57656 .23749 Mtetra
.616 .855 .989 r
.57656 .23749 .58252 .24166 .59414 .23766 .58823 .23368 Mtetra
.567 .844 .997 r
.58823 .23368 .59414 .23766 .60585 .23477 .59998 .23058 Mtetra
.519 .817 .999 r
.59998 .23058 .60585 .23477 .61764 .23287 .6118 .22827 Mtetra
.461 .774 .997 r
.6118 .22827 .61764 .23287 .62954 .23193 .62373 .22697 Mtetra
.423 .741 .993 r
.62373 .22697 .62954 .23193 .64153 .23156 .63575 .22635 Mtetra
.405 .723 .989 r
.63575 .22635 .64153 .23156 .65361 .2313 .64787 .22611 Mtetra
.398 .72 .988 r
.64787 .22611 .65361 .2313 .66577 .23099 .66007 .22594 Mtetra
.414 .735 .991 r
.66007 .22594 .66577 .23099 .67799 .23033 .67235 .22545 Mtetra
.433 .753 .995 r
.67235 .22545 .67799 .23033 .69028 .22936 .68469 .22459 Mtetra
.465 .775 .997 r
.68469 .22459 .69028 .22936 .70263 .22807 .69708 .2232 Mtetra
.496 .788 .997 r
.69708 .2232 .70263 .22807 .71505 .22654 .70952 .22138 Mtetra
.529 .793 .994 r
.70952 .22138 .71505 .22654 .72753 .22485 .72201 .21915 Mtetra
.556 .787 .985 r
.72201 .21915 .72753 .22485 .74007 .22303 .73456 .21663 Mtetra
.577 .771 .971 r
.73456 .21663 .74007 .22303 .75269 .22114 .74716 .21393 Mtetra
.589 .749 .954 r
.74716 .21393 .75269 .22114 .76539 .21923 .75983 .21113 Mtetra
.668 .754 .915 r
.09551 .43462 .10283 .44102 .1129 .43604 .10545 .43082 Mtetra
.674 .795 .939 r
.10545 .43082 .1129 .43604 .12301 .43097 .11544 .42688 Mtetra
.681 .837 .958 r
.11544 .42688 .12301 .43097 .13317 .42572 .12551 .42267 Mtetra
.69 .876 .968 r
.12551 .42267 .13317 .42572 .14339 .4202 .13565 .41808 Mtetra
.704 .909 .967 r
.13565 .41808 .14339 .4202 .15368 .41429 .14588 .41297 Mtetra
.714 .935 .96 r
.14588 .41297 .15368 .41429 .16404 .40795 .1562 .40737 Mtetra
.725 .955 .948 r
.1562 .40737 .16404 .40795 .17448 .40109 .1666 .40122 Mtetra
.717 .969 .934 r
.1666 .40122 .17448 .40109 .18497 .39387 .17706 .39481 Mtetra
.688 .975 .911 r
.17706 .39481 .18497 .39387 .19552 .38633 .18754 .38832 Mtetra
.606 .954 .858 r
.18754 .38832 .19552 .38633 .20607 .37886 .19802 .38209 Mtetra
.443 .866 .739 r
.19802 .38209 .20607 .37886 .2166 .37173 .20847 .37646 Mtetra
0 0 0 r
.20847 .37646 .2166 .37173 .22709 .36527 .21889 .3714 Mtetra
.21889 .3714 .22709 .36527 .23751 .35978 .22927 .36701 Mtetra
.048 0 0 r
.22927 .36701 .23751 .35978 .24789 .35505 .23967 .36279 Mtetra
.064 0 0 r
.23967 .36279 .24789 .35505 .25825 .35103 .25013 .35841 Mtetra
.027 0 0 r
.25013 .35841 .25825 .35103 .26861 .34744 .26064 .35381 Mtetra
0 0 0 r
.26064 .35381 .26861 .34744 .27899 .34407 .27121 .34885 Mtetra
.27121 .34885 .27899 .34407 .28941 .3407 .28182 .34386 Mtetra
.339 .8 .684 r
.28182 .34386 .28941 .3407 .2999 .33706 .29246 .33887 Mtetra
.528 .92 .832 r
.29246 .33887 .2999 .33706 .31049 .33249 .30319 .33318 Mtetra
.689 .977 .903 r
.30319 .33318 .31049 .33249 .32121 .32655 .31402 .32632 Mtetra
.812 .976 .897 r
.31402 .32632 .32121 .32655 .33205 .31891 .325 .3174 Mtetra
.871 .931 .86 r
.325 .3174 .33205 .31891 .34301 .30977 .33613 .30628 Mtetra
.867 .874 .84 r
.33613 .30628 .34301 .30977 .35394 .30097 .34727 .29472 Mtetra
.83 .8 .823 r
.34727 .29472 .35394 .30097 .36482 .29362 .35837 .2839 Mtetra
.752 .708 .811 r
.35837 .2839 .36482 .29362 .37558 .28904 .36932 .27572 Mtetra
.661 .61 .787 r
.36932 .27572 .37558 .28904 .38624 .28733 .38015 .27069 Mtetra
.607 .54 .754 r
.38015 .27069 .38624 .28733 .39692 .28676 .39093 .26748 Mtetra
.583 .501 .728 r
.39093 .26748 .39692 .28676 .40768 .28593 .40172 .26506 Mtetra
.607 .504 .711 r
.40172 .26506 .40768 .28593 .4186 .28201 .41263 .2611 Mtetra
.632 .519 .707 r
.41263 .2611 .4186 .28201 .42967 .27499 .42363 .25559 Mtetra
.625 .526 .722 r
.42363 .25559 .42967 .27499 .44076 .2677 .43464 .25088 Mtetra
.598 .535 .755 r
.43464 .25088 .44076 .2677 .45185 .26154 .44564 .24799 Mtetra
.51 .531 .814 r
.44564 .24799 .45185 .26154 .46291 .25828 .45663 .24828 Mtetra
.338 .513 .883 r
.45663 .24828 .46291 .25828 .47397 .25779 .46764 .25123 Mtetra
.127 .499 .906 r
.46764 .25123 .47397 .25779 .48509 .2588 .47874 .25496 Mtetra
0 .483 .841 r
.47874 .25496 .48509 .2588 .49628 .26015 .48994 .25826 Mtetra
.043 .593 .831 r
.48994 .25826 .49628 .26015 .50757 .26 .50126 .25936 Mtetra
.168 .703 .83 r
.50126 .25936 .50757 .26 .51894 .25814 .51268 .25838 Mtetra
.217 .741 .797 r
.51268 .25838 .51894 .25814 .53037 .25489 .52417 .25622 Mtetra
.19 .716 .71 r
.52417 .25622 .53037 .25489 .54185 .25069 .53571 .25335 Mtetra
0 0 0 r
.53571 .25335 .54185 .25069 .55337 .24622 .54732 .2505 Mtetra
.051 0 0 r
.54732 .2505 .55337 .24622 .56494 .24174 .55898 .24759 Mtetra
.117 0 0 r
.55898 .24759 .56494 .24174 .57656 .23749 .5707 .24434 Mtetra
.151 0 0 r
.5707 .24434 .57656 .23749 .58823 .23368 .58247 .24085 Mtetra
.156 0 0 r
.58247 .24085 .58823 .23368 .59998 .23058 .59429 .2372 Mtetra
.144 0 0 r
.59429 .2372 .59998 .23058 .6118 .22827 .60618 .23372 Mtetra
.135 0 0 r
.60618 .23372 .6118 .22827 .62373 .22697 .61814 .23093 Mtetra
.098 0 0 r
.61814 .23093 .62373 .22697 .63575 .22635 .63018 .22874 Mtetra
.044 0 0 r
.63018 .22874 .63575 .22635 .64787 .22611 .64232 .22717 Mtetra
0 0 0 r
.64232 .22717 .64787 .22611 .66007 .22594 .65454 .22587 Mtetra
.139 .685 .776 r
.65454 .22587 .66007 .22594 .67235 .22545 .66683 .22449 Mtetra
.243 .753 .869 r
.66683 .22449 .67235 .22545 .68469 .22459 .67919 .22285 Mtetra
.357 .812 .937 r
.67919 .22285 .68469 .22459 .69708 .2232 .6916 .22064 Mtetra
.452 .846 .978 r
.6916 .22064 .69708 .2232 .70952 .22138 .70405 .21793 Mtetra
.534 .86 .996 r
.70405 .21793 .70952 .22138 .72201 .21915 .71653 .21466 Mtetra
.59 .849 .993 r
.71653 .21466 .72201 .21915 .73456 .21663 .72905 .211 Mtetra
.624 .822 .977 r
.72905 .211 .73456 .21663 .74716 .21393 .74161 .20707 Mtetra
.64 .786 .952 r
.74161 .20707 .74716 .21393 .75983 .21113 .75422 .20298 Mtetra
.609 .739 .937 r
.08813 .42819 .09551 .43462 .10545 .43082 .09792 .4257 Mtetra
.608 .785 .966 r
.09792 .4257 .10545 .43082 .11544 .42688 .10777 .42302 Mtetra
.607 .832 .986 r
.10777 .42302 .11544 .42688 .12551 .42267 .11771 .42006 Mtetra
.603 .875 .992 r
.11771 .42006 .12551 .42267 .13565 .41808 .12773 .41671 Mtetra
.601 .911 .981 r
.12773 .41671 .13565 .41808 .14588 .41297 .13785 .41282 Mtetra
.576 .928 .949 r
.13785 .41282 .14588 .41297 .1562 .40737 .14806 .40852 Mtetra
.528 .921 .887 r
.14806 .40852 .1562 .40737 .1666 .40122 .15835 .40382 Mtetra
.411 .856 .77 r
.15835 .40382 .1666 .40122 .17706 .39481 .16868 .39907 Mtetra
0 0 0 r
.16868 .39907 .17706 .39481 .18754 .38832 .17902 .39453 Mtetra
.17902 .39453 .18754 .38832 .19802 .38209 .18935 .3904 Mtetra
.155 0 0 r
.18935 .3904 .19802 .38209 .20847 .37646 .19964 .38696 Mtetra
.252 0 0 r
.19964 .38696 .20847 .37646 .21889 .3714 .20994 .38385 Mtetra
.304 0 .07 r
.20994 .38385 .21889 .3714 .22927 .36701 .22028 .3809 Mtetra
.307 0 .101 r
.22028 .3809 .22927 .36701 .23967 .36279 .23069 .37749 Mtetra
.281 0 .102 r
.23069 .37749 .23967 .36279 .25013 .35841 .24124 .37316 Mtetra
.254 0 .088 r
.24124 .37316 .25013 .35841 .26064 .35381 .25187 .36819 Mtetra
.223 0 .065 r
.25187 .36819 .26064 .35381 .27121 .34885 .26258 .3627 Mtetra
.221 0 .054 r
.26258 .3627 .27121 .34885 .28182 .34386 .27331 .35738 Mtetra
.24 0 .058 r
.27331 .35738 .28182 .34386 .29246 .33887 .28403 .35256 Mtetra
.228 0 .055 r
.28403 .35256 .29246 .33887 .30319 .33318 .29481 .34738 Mtetra
.195 0 .049 r
.29481 .34738 .30319 .33318 .31402 .32632 .3057 .34126 Mtetra
.1 0 .015 r
.3057 .34126 .31402 .32632 .325 .3174 .31676 .33284 Mtetra
0 0 0 r
.31676 .33284 .325 .3174 .33613 .30628 .328 .3217 Mtetra
.328 .3217 .33613 .30628 .34727 .29472 .33931 .30939 Mtetra
.33931 .30939 .34727 .29472 .35837 .2839 .3506 .29709 Mtetra
.3506 .29709 .35837 .2839 .36932 .27572 .36176 .28696 Mtetra
.055 0 0 r
.36176 .28696 .36932 .27572 .38015 .27069 .37278 .27982 Mtetra
.107 0 0 r
.37278 .27982 .38015 .27069 .39093 .26748 .38372 .27477 Mtetra
.131 0 0 r
.38372 .27477 .39093 .26748 .40172 .26506 .39464 .27117 Mtetra
.04 0 0 r
.39464 .27117 .40172 .26506 .41263 .2611 .40562 .26719 Mtetra
.009 0 0 r
.40562 .26719 .41263 .2611 .42363 .25559 .41666 .26283 Mtetra
.183 0 0 r
.41666 .26283 .42363 .25559 .43464 .25088 .4277 .25992 Mtetra
.354 0 .01 r
.4277 .25992 .43464 .25088 .44564 .24799 .43872 .25912 Mtetra
.488 .054 .141 r
.43872 .25912 .44564 .24799 .45663 .24828 .44975 .26133 Mtetra
.548 .134 .209 r
.44975 .26133 .45663 .24828 .46764 .25123 .46082 .26576 Mtetra
.548 .145 .23 r
.46082 .26576 .46764 .25123 .47874 .25496 .472 .27021 Mtetra
.523 .125 .228 r
.472 .27021 .47874 .25496 .48994 .25826 .4833 .27352 Mtetra
.458 .062 .199 r
.4833 .27352 .48994 .25826 .50126 .25936 .49473 .27409 Mtetra
.39 0 .159 r
.49473 .27409 .50126 .25936 .51268 .25838 .50626 .27234 Mtetra
.351 0 .127 r
.50626 .27234 .51268 .25838 .52417 .25622 .51785 .26963 Mtetra
.332 0 .108 r
.51785 .26963 .52417 .25622 .53571 .25335 .52951 .26657 Mtetra
.347 0 .111 r
.52951 .26657 .53571 .25335 .54732 .2505 .54122 .26401 Mtetra
.358 0 .121 r
.54122 .26401 .54732 .2505 .55898 .24759 .553 .26163 Mtetra
.347 0 .127 r
.553 .26163 .55898 .24759 .5707 .24434 .56484 .25872 Mtetra
.33 0 .127 r
.56484 .25872 .5707 .24434 .58247 .24085 .57673 .25516 Mtetra
.298 0 .113 r
.57673 .25516 .58247 .24085 .59429 .2372 .58865 .25066 Mtetra
.268 0 .083 r
.58865 .25066 .59429 .2372 .60618 .23372 .60061 .24567 Mtetra
.244 0 .038 r
.60061 .24567 .60618 .23372 .61814 .23093 .61263 .24085 Mtetra
.208 0 0 r
.61263 .24085 .61814 .23093 .63018 .22874 .6247 .23636 Mtetra
.168 0 0 r
.6247 .23636 .63018 .22874 .64232 .22717 .63685 .23257 Mtetra
.095 0 0 r
.63685 .23257 .64232 .22717 .65454 .22587 .64907 .22921 Mtetra
0 0 0 r
.64907 .22921 .65454 .22587 .66683 .22449 .66137 .22608 Mtetra
.66137 .22608 .66683 .22449 .67919 .22285 .67372 .22288 Mtetra
.334 .817 .833 r
.67372 .22288 .67919 .22285 .6916 .22064 .68612 .21928 Mtetra
.476 .886 .937 r
.68612 .21928 .6916 .22064 .70405 .21793 .69856 .21524 Mtetra
.586 .907 .98 r
.69856 .21524 .70405 .21793 .71653 .21466 .71102 .21063 Mtetra
.649 .89 .983 r
.71102 .21063 .71653 .21466 .72905 .211 .7235 .20561 Mtetra
.681 .854 .965 r
.7235 .20561 .72905 .211 .74161 .20707 .73602 .20029 Mtetra
.693 .811 .938 r
.73602 .20029 .74161 .20707 .75422 .20298 .74857 .19475 Mtetra
.538 .715 .954 r
.0807 .4217 .08813 .42819 .09792 .4257 .09034 .42041 Mtetra
.531 .757 .979 r
.09034 .42041 .09792 .4257 .10777 .42302 .10006 .41892 Mtetra
.52 .797 .996 r
.10006 .41892 .10777 .42302 .11771 .42006 .10987 .41716 Mtetra
.504 .834 .999 r
.10987 .41716 .11771 .42006 .12773 .41671 .11976 .41508 Mtetra
.485 .863 .981 r
.11976 .41508 .12773 .41671 .13785 .41282 .12976 .41253 Mtetra
.422 .859 .925 r
.12976 .41253 .13785 .41282 .14806 .40852 .13983 .40974 Mtetra
.311 .802 .809 r
.13983 .40974 .14806 .40852 .15835 .40382 .14996 .40679 Mtetra
0 0 0 r
.14996 .40679 .15835 .40382 .16868 .39907 .16012 .40402 Mtetra
.085 0 0 r
.16012 .40402 .16868 .39907 .17902 .39453 .17026 .40173 Mtetra
.235 0 0 r
.17026 .40173 .17902 .39453 .18935 .3904 .18041 .39992 Mtetra
.334 0 .009 r
.18041 .39992 .18935 .3904 .19964 .38696 .19054 .3987 Mtetra
.367 0 .088 r
.19054 .3987 .19964 .38696 .20994 .38385 .20074 .39742 Mtetra
.368 0 .126 r
.20074 .39742 .20994 .38385 .22028 .3809 .21104 .39565 Mtetra
.34 0 .131 r
.21104 .39565 .22028 .3809 .23069 .37749 .22149 .39282 Mtetra
.286 0 .11 r
.22149 .39282 .23069 .37749 .24124 .37316 .23213 .38846 Mtetra
.252 0 .091 r
.23213 .38846 .24124 .37316 .25187 .36819 .24288 .38331 Mtetra
.233 0 .078 r
.24288 .38331 .25187 .36819 .26258 .3627 .25369 .37779 Mtetra
.263 0 .095 r
.25369 .37779 .26258 .3627 .27331 .35738 .26448 .37292 Mtetra
.321 0 .133 r
.26448 .37292 .27331 .35738 .28403 .35256 .27521 .36925 Mtetra
.341 0 .162 r
.27521 .36925 .28403 .35256 .29481 .34738 .28598 .36574 Mtetra
.341 0 .184 r
.28598 .36574 .29481 .34738 .3057 .34126 .29682 .36167 Mtetra
.291 0 .184 r
.29682 .36167 .3057 .34126 .31676 .33284 .30787 .35528 Mtetra
.222 0 .174 r
.30787 .35528 .31676 .33284 .328 .3217 .31914 .34589 Mtetra
.195 0 .179 r
.31914 .34589 .328 .3217 .33931 .30939 .33053 .33475 Mtetra
.192 0 .189 r
.33053 .33475 .33931 .30939 .3506 .29709 .34195 .32286 Mtetra
.243 0 .216 r
.34195 .32286 .3506 .29709 .36176 .28696 .35328 .31245 Mtetra
.305 0 .241 r
.35328 .31245 .36176 .28696 .37278 .27982 .36449 .30445 Mtetra
.348 .016 .253 r
.36449 .30445 .37278 .27982 .38372 .27477 .37562 .29844 Mtetra
.381 .041 .259 r
.37562 .29844 .38372 .27477 .39464 .27117 .3867 .29409 Mtetra
.385 .041 .255 r
.3867 .29409 .39464 .27117 .40562 .26719 .39782 .2901 Mtetra
.394 .049 .258 r
.39782 .2901 .40562 .26719 .41666 .26283 .40896 .28648 Mtetra
.433 .088 .279 r
.40896 .28648 .41666 .26283 .4277 .25992 .4201 .28452 Mtetra
.473 .129 .301 r
.4201 .28452 .4277 .25992 .43872 .25912 .43124 .28457 Mtetra
.513 .169 .321 r
.43124 .28457 .43872 .25912 .44975 .26133 .44239 .28707 Mtetra
.534 .189 .329 r
.44239 .28707 .44975 .26133 .46082 .26576 .4536 .29107 Mtetra
.524 .177 .321 r
.4536 .29107 .46082 .26576 .472 .27021 .46493 .29434 Mtetra
.496 .146 .303 r
.46493 .29434 .472 .27021 .4833 .27352 .4764 .29587 Mtetra
.437 .084 .267 r
.4764 .29587 .4833 .27352 .49473 .27409 .48798 .29436 Mtetra
.374 .016 .223 r
.48798 .29436 .49473 .27409 .50626 .27234 .49966 .29051 Mtetra
.341 0 .185 r
.49966 .29051 .50626 .27234 .51785 .26963 .51139 .2861 Mtetra
.328 0 .155 r
.51139 .2861 .51785 .26963 .52951 .26657 .52317 .28184 Mtetra
.353 0 .146 r
.52317 .28184 .52951 .26657 .54122 .26401 .535 .2788 Mtetra
.368 0 .144 r
.535 .2788 .54122 .26401 .553 .26163 .54689 .27643 Mtetra
.357 0 .139 r
.54689 .27643 .553 .26163 .56484 .25872 .55885 .27369 Mtetra
.334 0 .133 r
.55885 .27369 .56484 .25872 .57673 .25516 .57086 .27013 Mtetra
.283 0 .113 r
.57086 .27013 .57673 .25516 .58865 .25066 .5829 .265 Mtetra
.234 0 .082 r
.5829 .265 .58865 .25066 .60061 .24567 .59495 .25878 Mtetra
.188 0 .038 r
.59495 .25878 .60061 .24567 .61263 .24085 .60704 .25203 Mtetra
.131 0 0 r
.60704 .25203 .61263 .24085 .6247 .23636 .61915 .24522 Mtetra
.077 0 0 r
.61915 .24522 .6247 .23636 .63685 .23257 .63132 .239 Mtetra
0 0 0 r
.63132 .239 .63685 .23257 .64907 .22921 .64354 .23327 Mtetra
.64354 .23327 .64907 .22921 .66137 .22608 .65583 .22803 Mtetra
.295 .776 .686 r
.65583 .22803 .66137 .22608 .67372 .22288 .66818 .22297 Mtetra
.465 .891 .856 r
.66818 .22297 .67372 .22288 .68612 .21928 .68057 .21775 Mtetra
.588 .934 .945 r
.68057 .21775 .68612 .21928 .69856 .21524 .69299 .21225 Mtetra
.671 .931 .97 r
.69299 .21225 .69856 .21524 .71102 .21063 .70543 .20627 Mtetra
.712 .9 .963 r
.70543 .20627 .71102 .21063 .7235 .20561 .71789 .19994 Mtetra
.73 .861 .943 r
.71789 .19994 .7235 .20561 .73602 .20029 .73037 .19331 Mtetra
.735 .821 .918 r
.73037 .19331 .73602 .20029 .74857 .19475 .74288 .18646 Mtetra
.483 .694 .961 r
.07322 .41517 .0807 .4217 .09034 .42041 .08277 .41464 Mtetra
.478 .72 .977 r
.08277 .41464 .09034 .42041 .10006 .41892 .0924 .41393 Mtetra
.471 .747 .989 r
.0924 .41393 .10006 .41892 .10987 .41716 .10211 .41302 Mtetra
.46 .775 .997 r
.10211 .41302 .10987 .41716 .11976 .41508 .1119 .4119 Mtetra
.445 .802 .997 r
.1119 .4119 .11976 .41508 .12976 .41253 .12178 .41048 Mtetra
.384 .807 .971 r
.12178 .41048 .12976 .41253 .13983 .40974 .13173 .409 Mtetra
.268 .766 .889 r
.13173 .409 .13983 .40974 .14996 .40679 .14171 .40762 Mtetra
.08 .639 .709 r
.14171 .40762 .14996 .40679 .16012 .40402 .15171 .40655 Mtetra
.13 0 0 r
.15171 .40655 .16012 .40402 .17026 .40173 .1617 .40605 Mtetra
.253 0 0 r
.1617 .40605 .17026 .40173 .18041 .39992 .17172 .40583 Mtetra
.322 0 0 r
.17172 .40583 .18041 .39992 .19054 .3987 .18179 .4058 Mtetra
.309 0 0 r
.18179 .4058 .19054 .3987 .20074 .39742 .19198 .40512 Mtetra
.239 0 0 r
.19198 .40512 .20074 .39742 .21104 .39565 .20236 .40317 Mtetra
.111 0 0 r
.20236 .40317 .21104 .39565 .22149 .39282 .21294 .39967 Mtetra
0 0 0 r
.21294 .39967 .22149 .39282 .23213 .38846 .22375 .39431 Mtetra
.22375 .39431 .23213 .38846 .24288 .38331 .23463 .38835 Mtetra
.23463 .38835 .24288 .38331 .25369 .37779 .24553 .38261 Mtetra
.24553 .38261 .25369 .37779 .26448 .37292 .25633 .37835 Mtetra
.145 0 0 r
.25633 .37835 .26448 .37292 .27521 .36925 .267 .37632 Mtetra
.288 0 0 r
.267 .37632 .27521 .36925 .28598 .36574 .27764 .37533 Mtetra
.356 0 .018 r
.27764 .37533 .28598 .36574 .29682 .36167 .28832 .37458 Mtetra
.325 0 .082 r
.28832 .37458 .29682 .36167 .30787 .35528 .2992 .372 Mtetra
.27 0 .121 r
.2992 .372 .30787 .35528 .31914 .34589 .31032 .36659 Mtetra
.257 0 .167 r
.31032 .36659 .31914 .34589 .33053 .33475 .3216 .35912 Mtetra
.262 0 .206 r
.3216 .35912 .33053 .33475 .34195 .32286 .333 .35024 Mtetra
.309 0 .249 r
.333 .35024 .34195 .32286 .35328 .31245 .34437 .34193 Mtetra
.357 .039 .282 r
.34437 .34193 .35328 .31245 .36449 .30445 .35568 .33508 Mtetra
.389 .071 .301 r
.35568 .33508 .36449 .30445 .37562 .29844 .36695 .32955 Mtetra
.412 .094 .313 r
.36695 .32955 .37562 .29844 .3867 .29409 .37819 .32524 Mtetra
.418 .099 .315 r
.37819 .32524 .3867 .29409 .39782 .2901 .38947 .32125 Mtetra
.424 .104 .317 r
.38947 .32125 .39782 .2901 .40896 .28648 .40078 .31759 Mtetra
.443 .121 .324 r
.40078 .31759 .40896 .28648 .4201 .28452 .4121 .31515 Mtetra
.463 .137 .328 r
.4121 .31515 .4201 .28452 .43124 .28457 .42343 .31405 Mtetra
.482 .151 .328 r
.42343 .31405 .43124 .28457 .44239 .28707 .43479 .31442 Mtetra
.489 .15 .318 r
.43479 .31442 .44239 .28707 .4536 .29107 .44622 .31539 Mtetra
.46 .112 .287 r
.44622 .31539 .4536 .29107 .46493 .29434 .45776 .31495 Mtetra
.404 .042 .233 r
.45776 .31495 .46493 .29434 .4764 .29587 .46942 .31243 Mtetra
.286 0 .132 r
.46942 .31243 .4764 .29587 .48798 .29436 .48117 .30705 Mtetra
.127 0 0 r
.48117 .30705 .48798 .29436 .49966 .29051 .49299 .2998 Mtetra
.009 0 0 r
.49299 .2998 .49966 .29051 .51139 .2861 .50483 .29277 Mtetra
0 0 0 r
.50483 .29277 .51139 .2861 .52317 .28184 .5167 .2868 Mtetra
.016 0 0 r
.5167 .2868 .52317 .28184 .535 .2788 .52861 .2831 Mtetra
.099 0 0 r
.52861 .2831 .535 .2788 .54689 .27643 .54059 .28091 Mtetra
.129 0 0 r
.54059 .28091 .54689 .27643 .55885 .27369 .55263 .27895 Mtetra
.126 0 0 r
.55263 .27895 .55885 .27369 .57086 .27013 .56474 .27639 Mtetra
.044 0 0 r
.56474 .27639 .57086 .27013 .5829 .265 .57688 .27191 Mtetra
0 0 0 r
.57688 .27191 .5829 .265 .59495 .25878 .58904 .26583 Mtetra
.58904 .26583 .59495 .25878 .60704 .25203 .6012 .25842 Mtetra
.6012 .25842 .60704 .25203 .61915 .24522 .61338 .25035 Mtetra
.61338 .25035 .61915 .24522 .63132 .239 .62559 .24244 Mtetra
.385 .805 .613 r
.62559 .24244 .63132 .239 .64354 .23327 .63783 .23481 Mtetra
.496 .897 .768 r
.63783 .23481 .64354 .23327 .65583 .22803 .65012 .22776 Mtetra
.6 .951 .888 r
.65012 .22776 .65583 .22803 .66818 .22297 .66247 .22102 Mtetra
.674 .956 .948 r
.66247 .22102 .66818 .22297 .68057 .21775 .67485 .21437 Mtetra
.714 .931 .961 r
.67485 .21437 .68057 .21775 .69299 .21225 .68727 .20764 Mtetra
.74 .899 .95 r
.68727 .20764 .69299 .21225 .70543 .20627 .6997 .2006 Mtetra
.751 .867 .933 r
.6997 .2006 .70543 .20627 .71789 .19994 .71216 .19332 Mtetra
.755 .839 .915 r
.71216 .19332 .71789 .19994 .73037 .19331 .72464 .18581 Mtetra
.755 .813 .898 r
.72464 .18581 .73037 .19331 .74288 .18646 .73713 .1781 Mtetra
.459 .684 .963 r
.06568 .40859 .07322 .41517 .08277 .41464 .0752 .40834 Mtetra
.463 .696 .968 r
.0752 .40834 .08277 .41464 .0924 .41393 .0848 .40794 Mtetra
.463 .709 .975 r
.0848 .40794 .0924 .41393 .10211 .41302 .09447 .40743 Mtetra
.459 .722 .982 r
.09447 .40743 .10211 .41302 .1119 .4119 .10421 .40684 Mtetra
.45 .739 .99 r
.10421 .40684 .1119 .4119 .12178 .41048 .11402 .40613 Mtetra
.409 .747 .994 r
.11402 .40613 .12178 .41048 .13173 .409 .12387 .40555 Mtetra
.325 .737 .978 r
.12387 .40555 .13173 .409 .14171 .40762 .13375 .40526 Mtetra
.195 .692 .916 r
.13375 .40526 .14171 .40762 .15171 .40655 .14364 .40534 Mtetra
.018 .586 .781 r
.14364 .40534 .15171 .40655 .1617 .40605 .15353 .40595 Mtetra
.076 0 0 r
.15353 .40595 .1617 .40605 .17172 .40583 .16349 .40656 Mtetra
.097 0 0 r
.16349 .40656 .17172 .40583 .18179 .4058 .17356 .40684 Mtetra
0 0 0 r
.17356 .40684 .18179 .4058 .19198 .40512 .18381 .40595 Mtetra
.307 .8 .825 r
.18381 .40595 .19198 .40512 .20236 .40317 .19433 .40313 Mtetra
.569 .929 .937 r
.19433 .40313 .20236 .40317 .21294 .39967 .20507 .39847 Mtetra
.735 .949 .949 r
.20507 .39847 .21294 .39967 .22375 .39431 .21603 .39189 Mtetra
.758 .918 .943 r
.21603 .39189 .22375 .39431 .23463 .38835 .22704 .3851 Mtetra
.726 .891 .955 r
.22704 .3851 .23463 .38835 .24553 .38261 .23799 .37926 Mtetra
.605 .864 .992 r
.23799 .37926 .24553 .38261 .25633 .37835 .24876 .37572 Mtetra
.264 .73 .947 r
.24876 .37572 .25633 .37835 .267 .37632 .25932 .37539 Mtetra
.127 0 0 r
.25932 .37539 .267 .37632 .27764 .37533 .26979 .377 Mtetra
.38 0 0 r
.26979 .377 .27764 .37533 .28832 .37458 .28026 .37969 Mtetra
.395 0 0 r
.28026 .37969 .28832 .37458 .2992 .372 .29089 .38125 Mtetra
.343 0 0 r
.29089 .38125 .2992 .372 .31032 .36659 .30178 .38043 Mtetra
.32 0 .092 r
.30178 .38043 .31032 .36659 .3216 .35912 .31287 .37748 Mtetra
.311 0 .16 r
.31287 .37748 .3216 .35912 .333 .35024 .32414 .37266 Mtetra
.342 0 .22 r
.32414 .37266 .333 .35024 .34437 .34193 .33546 .36751 Mtetra
.374 .037 .259 r
.33546 .36751 .34437 .34193 .35568 .33508 .3468 .36273 Mtetra
.395 .064 .282 r
.3468 .36273 .35568 .33508 .36695 .32955 .35816 .3584 Mtetra
.408 .08 .294 r
.35816 .3584 .36695 .32955 .37819 .32524 .36954 .35453 Mtetra
.408 .082 .297 r
.36954 .35453 .37819 .32524 .38947 .32125 .38098 .35054 Mtetra
.407 .08 .296 r
.38098 .35054 .38947 .32125 .40078 .31759 .39247 .34644 Mtetra
.413 .085 .296 r
.39247 .34644 .40078 .31759 .4121 .31515 .40398 .3428 Mtetra
.417 .084 .29 r
.40398 .3428 .4121 .31515 .42343 .31405 .41554 .33961 Mtetra
.417 .075 .276 r
.41554 .33961 .42343 .31405 .43479 .31442 .42714 .33679 Mtetra
.395 .041 .242 r
.42714 .33679 .43479 .31442 .44622 .31539 .43881 .33365 Mtetra
.313 0 .163 r
.43881 .33365 .44622 .31539 .45776 .31495 .45057 .32862 Mtetra
.148 0 .009 r
.45057 .32862 .45776 .31495 .46942 .31243 .46243 .32143 Mtetra
0 0 0 r
.46243 .32143 .46942 .31243 .48117 .30705 .47435 .31181 Mtetra
.582 .898 .632 r
.47435 .31181 .48117 .30705 .49299 .2998 .4863 .30101 Mtetra
.737 .992 .836 r
.4863 .30101 .49299 .2998 .50483 .29277 .49824 .29129 Mtetra
.742 .969 .932 r
.49824 .29129 .50483 .29277 .5167 .2868 .51018 .28354 Mtetra
.62 .893 .988 r
.51018 .28354 .5167 .2868 .52861 .2831 .52214 .27904 Mtetra
.487 .814 1 r
.52214 .27904 .52861 .2831 .54059 .28091 .53416 .2769 Mtetra
.406 .776 .994 r
.53416 .2769 .54059 .28091 .55263 .27895 .54625 .27574 Mtetra
.38 .788 .982 r
.54625 .27574 .55263 .27895 .56474 .27639 .55842 .27437 Mtetra
.475 .87 .967 r
.55842 .27437 .56474 .27639 .57688 .27191 .57064 .27103 Mtetra
.552 .925 .929 r
.57064 .27103 .57688 .27191 .58904 .26583 .58288 .26579 Mtetra
.633 .963 .886 r
.58288 .26579 .58904 .26583 .6012 .25842 .59512 .25857 Mtetra
.69 .981 .869 r
.59512 .25857 .6012 .25842 .61338 .25035 .60737 .2501 Mtetra
.722 .987 .879 r
.60737 .2501 .61338 .25035 .62559 .24244 .61962 .24129 Mtetra
.753 .985 .904 r
.61962 .24129 .62559 .24244 .63783 .23481 .6319 .23246 Mtetra
.761 .965 .93 r
.6319 .23246 .63783 .23481 .65012 .22776 .64421 .22416 Mtetra
.765 .933 .94 r
.64421 .22416 .65012 .22776 .66247 .22102 .65656 .21622 Mtetra
.761 .896 .937 r
.65656 .21622 .66247 .22102 .67485 .21437 .66896 .20859 Mtetra
.758 .864 .927 r
.66896 .20859 .67485 .21437 .68727 .20764 .68139 .20105 Mtetra
.759 .84 .913 r
.68139 .20105 .68727 .20764 .6997 .2006 .69384 .1934 Mtetra
.758 .822 .902 r
.69384 .1934 .6997 .2006 .71216 .19332 .70632 .18563 Mtetra
.759 .809 .893 r
.70632 .18563 .71216 .19332 .72464 .18581 .71882 .17774 Mtetra
.76 .799 .885 r
.71882 .17774 .72464 .18581 .73713 .1781 .73134 .16968 Mtetra
.486 .695 .961 r
.05808 .40196 .06568 .40859 .0752 .40834 .06767 .40135 Mtetra
.499 .689 .952 r
.06767 .40135 .0752 .40834 .0848 .40794 .07732 .40063 Mtetra
.507 .682 .945 r
.07732 .40063 .0848 .40794 .09447 .40743 .08703 .39987 Mtetra
.51 .676 .939 r
.08703 .39987 .09447 .40743 .10421 .40684 .0968 .39911 Mtetra
.51 .671 .936 r
.0968 .39911 .10421 .40684 .11402 .40613 .10663 .39837 Mtetra
.498 .665 .937 r
.10663 .39837 .11402 .40613 .12387 .40555 .11648 .39782 Mtetra
.472 .656 .941 r
.11648 .39782 .12387 .40555 .13375 .40526 .12635 .39765 Mtetra
.446 .649 .945 r
.12635 .39765 .13375 .40526 .14364 .40534 .13624 .39779 Mtetra
.413 .637 .948 r
.13624 .39779 .14364 .40534 .15353 .40595 .14615 .39833 Mtetra
.431 .644 .947 r
.14615 .39833 .15353 .40595 .16349 .40656 .15615 .39866 Mtetra
.48 .658 .939 r
.15615 .39866 .16349 .40656 .17356 .40684 .16629 .39838 Mtetra
.564 .676 .915 r
.16629 .39838 .17356 .40684 .18381 .40595 .17663 .39672 Mtetra
.646 .688 .875 r
.17663 .39672 .18381 .40595 .19433 .40313 .18725 .39302 Mtetra
.69 .684 .839 r
.18725 .39302 .19433 .40313 .20507 .39847 .19809 .38761 Mtetra
.718 .679 .811 r
.19809 .38761 .20507 .39847 .21603 .39189 .20911 .38061 Mtetra
.711 .669 .808 r
.20911 .38061 .21603 .39189 .22704 .3851 .22013 .37381 Mtetra
.679 .658 .822 r
.22013 .37381 .22704 .3851 .23799 .37926 .23105 .3685 Mtetra
.602 .638 .858 r
.23105 .3685 .23799 .37926 .24876 .37572 .24175 .36593 Mtetra
.426 .578 .901 r
.24175 .36593 .24876 .37572 .25932 .37539 .25219 .36697 Mtetra
.199 .495 .903 r
.25219 .36697 .25932 .37539 .26979 .377 .26252 .3704 Mtetra
0 .375 .822 r
.26252 .3704 .26979 .377 .28026 .37969 .27282 .37535 Mtetra
0 .366 .752 r
.27282 .37535 .28026 .37969 .29089 .38125 .28327 .37968 Mtetra
.165 0 0 r
.28327 .37968 .29089 .38125 .30178 .38043 .29396 .38208 Mtetra
.158 0 0 r
.29396 .38208 .30178 .38043 .31287 .37748 .30488 .38242 Mtetra
.144 0 0 r
.30488 .38242 .31287 .37748 .32414 .37266 .31602 .38069 Mtetra
.201 0 0 r
.31602 .38069 .32414 .37266 .33546 .36751 .32727 .37801 Mtetra
.247 0 0 r
.32727 .37801 .33546 .36751 .3468 .36273 .33861 .3749 Mtetra
.273 0 .025 r
.33861 .3749 .3468 .36273 .35816 .3584 .35001 .37155 Mtetra
.284 0 .054 r
.35001 .37155 .35816 .3584 .36954 .35453 .36147 .36803 Mtetra
.271 0 .055 r
.36147 .36803 .36954 .35453 .38098 .35054 .37301 .36403 Mtetra
.251 0 .045 r
.37301 .36403 .38098 .35054 .39247 .34644 .38462 .35955 Mtetra
.237 0 .029 r
.38462 .35955 .39247 .34644 .40398 .3428 .39628 .35489 Mtetra
.203 0 0 r
.39628 .35489 .40398 .3428 .41554 .33961 .408 .34999 Mtetra
.131 0 0 r
.408 .34999 .41554 .33961 .42714 .33679 .41978 .34466 Mtetra
0 0 0 r
.41978 .34466 .42714 .33679 .43881 .33365 .43162 .33837 Mtetra
.436 .828 .608 r
.43162 .33837 .43881 .33365 .45057 .32862 .44356 .32996 Mtetra
.774 .997 .834 r
.44356 .32996 .45057 .32862 .46243 .32143 .45556 .31946 Mtetra
.88 .947 .851 r
.45556 .31946 .46243 .32143 .47435 .31181 .4676 .30697 Mtetra
.876 .871 .829 r
.4676 .30697 .47435 .31181 .4863 .30101 .47964 .29382 Mtetra
.833 .811 .829 r
.47964 .29382 .4863 .30101 .49824 .29129 .49164 .28219 Mtetra
.775 .757 .836 r
.49164 .28219 .49824 .29129 .51018 .28354 .50363 .27297 Mtetra
.683 .693 .854 r
.50363 .27297 .51018 .28354 .52214 .27904 .51562 .26742 Mtetra
.598 .633 .857 r
.51562 .26742 .52214 .27904 .53416 .2769 .52765 .26467 Mtetra
.547 .596 .854 r
.52765 .26467 .53416 .2769 .54625 .27574 .53976 .26343 Mtetra
.539 .591 .855 r
.53976 .26343 .54625 .27574 .55842 .27437 .55194 .26242 Mtetra
.592 .627 .855 r
.55194 .26242 .55842 .27437 .57064 .27103 .56418 .25979 Mtetra
.646 .668 .857 r
.56418 .25979 .57064 .27103 .58288 .26579 .57647 .25539 Mtetra
.706 .712 .854 r
.57647 .25539 .58288 .26579 .59512 .25857 .58876 .24887 Mtetra
.744 .743 .851 r
.58876 .24887 .59512 .25857 .60737 .2501 .60105 .24094 Mtetra
.762 .763 .853 r
.60105 .24094 .60737 .2501 .61962 .24129 .61336 .23234 Mtetra
.769 .771 .854 r
.61336 .23234 .61962 .24129 .6319 .23246 .62567 .22352 Mtetra
.761 .77 .86 r
.62567 .22352 .6319 .23246 .64421 .22416 .63803 .21509 Mtetra
.753 .765 .863 r
.63803 .21509 .64421 .22416 .65656 .21622 .65041 .20697 Mtetra
.743 .758 .865 r
.65041 .20697 .65656 .21622 .66896 .20859 .66285 .19922 Mtetra
.737 .755 .866 r
.66285 .19922 .66896 .20859 .68139 .20105 .67532 .19167 Mtetra
.737 .755 .867 r
.67532 .19167 .68139 .20105 .69384 .1934 .68782 .18412 Mtetra
.738 .759 .87 r
.68782 .18412 .69384 .1934 .70632 .18563 .70035 .17655 Mtetra
.741 .766 .873 r
.70035 .17655 .70632 .18563 .71882 .17774 .71291 .16892 Mtetra
.746 .776 .878 r
.71291 .16892 .71882 .17774 .73134 .16968 .7255 .16118 Mtetra
.544 .717 .953 r
.05043 .39529 .05808 .40196 .06767 .40135 .06015 .39382 Mtetra
.555 .694 .933 r
.06015 .39382 .06767 .40135 .07732 .40063 .06992 .3923 Mtetra
.56 .672 .913 r
.06992 .3923 .07732 .40063 .08703 .39987 .07975 .39078 Mtetra
.56 .652 .897 r
.07975 .39078 .08703 .39987 .0968 .39911 .08962 .38932 Mtetra
.557 .633 .882 r
.08962 .38932 .0968 .39911 .10663 .39837 .09952 .38796 Mtetra
.549 .615 .871 r
.09952 .38796 .10663 .39837 .11648 .39782 .10946 .38682 Mtetra
.534 .595 .861 r
.10946 .38682 .11648 .39782 .12635 .39765 .1194 .38605 Mtetra
.525 .578 .851 r
.1194 .38605 .12635 .39765 .13624 .39779 .12937 .38552 Mtetra
.517 .561 .839 r
.12937 .38552 .13624 .39779 .14615 .39833 .13937 .38523 Mtetra
.532 .554 .823 r
.13937 .38523 .14615 .39833 .15615 .39866 .14947 .38462 Mtetra
.559 .553 .803 r
.14947 .38462 .15615 .39866 .16629 .39838 .15972 .38328 Mtetra
.595 .557 .781 r
.15972 .38328 .16629 .39838 .17663 .39672 .17017 .38062 Mtetra
.634 .566 .76 r
.17017 .38062 .17663 .39672 .18725 .39302 .18086 .37611 Mtetra
.657 .569 .745 r
.18086 .37611 .18725 .39302 .19809 .38761 .19174 .37021 Mtetra
.673 .574 .735 r
.19174 .37021 .19809 .38761 .20911 .38061 .20277 .36318 Mtetra
.664 .569 .738 r
.20277 .36318 .20911 .38061 .22013 .37381 .21376 .35666 Mtetra
.635 .556 .748 r
.21376 .35666 .22013 .37381 .23105 .3685 .22462 .35186 Mtetra
.574 .528 .766 r
.22462 .35186 .23105 .3685 .24175 .36593 .23526 .34982 Mtetra
.464 .472 .782 r
.23526 .34982 .24175 .36593 .25219 .36697 .24565 .35131 Mtetra
.359 .417 .785 r
.24565 .35131 .25219 .36697 .26252 .3704 .25591 .35521 Mtetra
.265 .368 .782 r
.25591 .35521 .26252 .3704 .27282 .37535 .26614 .36078 Mtetra
.266 .381 .794 r
.26614 .36078 .27282 .37535 .28327 .37968 .27649 .36611 Mtetra
.328 .439 .822 r
.27649 .36611 .28327 .37968 .29396 .38208 .28706 .37 Mtetra
.399 .513 .858 r
.28706 .37 .29396 .38208 .30488 .38242 .29786 .37211 Mtetra
.48 .6 .895 r
.29786 .37211 .30488 .38242 .31602 .38069 .30888 .37224 Mtetra
.524 .674 .932 r
.30888 .37224 .31602 .38069 .32727 .37801 .32005 .37114 Mtetra
.554 .738 .962 r
.32005 .37114 .32727 .37801 .33861 .3749 .33135 .36915 Mtetra
.576 .786 .978 r
.33135 .36915 .33861 .3749 .35001 .37155 .34274 .36647 Mtetra
.599 .818 .984 r
.34274 .36647 .35001 .37155 .36147 .36803 .35423 .3632 Mtetra
.635 .838 .979 r
.35423 .3632 .36147 .36803 .37301 .36403 .36581 .35917 Mtetra
.671 .848 .968 r
.36581 .35917 .37301 .36403 .38462 .35955 .37747 .35438 Mtetra
.696 .845 .954 r
.37747 .35438 .38462 .35955 .39628 .35489 .3892 .34899 Mtetra
.722 .828 .931 r
.3892 .34899 .39628 .35489 .408 .34999 .40101 .34291 Mtetra
.743 .798 .896 r
.40101 .34291 .408 .34999 .41978 .34466 .41288 .33592 Mtetra
.759 .758 .852 r
.41288 .33592 .41978 .34466 .43162 .33837 .42482 .32767 Mtetra
.775 .721 .802 r
.42482 .32767 .43162 .33837 .44356 .32996 .43683 .3174 Mtetra
.782 .693 .766 r
.43683 .3174 .44356 .32996 .45556 .31946 .4489 .30532 Mtetra
.784 .673 .741 r
.4489 .30532 .45556 .31946 .4676 .30697 .46099 .29175 Mtetra
.778 .658 .731 r
.46099 .29175 .4676 .30697 .47964 .29382 .47307 .27789 Mtetra
.754 .64 .735 r
.47307 .27789 .47964 .29382 .49164 .28219 .4851 .2657 Mtetra
.717 .617 .744 r
.4851 .2657 .49164 .28219 .50363 .27297 .4971 .25595 Mtetra
.656 .58 .757 r
.4971 .25595 .50363 .27297 .51562 .26742 .50909 .24978 Mtetra
.598 .541 .762 r
.50909 .24978 .51562 .26742 .52765 .26467 .52112 .24642 Mtetra
.557 .511 .76 r
.52112 .24642 .52765 .26467 .53976 .26343 .53321 .24482 Mtetra
.544 .501 .758 r
.53321 .24482 .53976 .26343 .55194 .26242 .54538 .24376 Mtetra
.57 .516 .755 r
.54538 .24376 .55194 .26242 .56418 .25979 .55762 .24154 Mtetra
.601 .539 .757 r
.55762 .24154 .56418 .25979 .57647 .25539 .56991 .23789 Mtetra
.641 .57 .759 r
.56991 .23789 .57647 .25539 .58876 .24887 .58222 .23233 Mtetra
.671 .597 .764 r
.58222 .23233 .58876 .24887 .60105 .24094 .59455 .22541 Mtetra
.692 .62 .772 r
.59455 .22541 .60105 .24094 .61336 .23234 .60689 .21772 Mtetra
.704 .639 .781 r
.60689 .21772 .61336 .23234 .62567 .22352 .61925 .20967 Mtetra
.706 .652 .793 r
.61925 .20967 .62567 .22352 .63803 .21509 .63165 .20187 Mtetra
.706 .663 .804 r
.63165 .20187 .63803 .21509 .65041 .20697 .64409 .1943 Mtetra
.703 .671 .816 r
.64409 .1943 .65041 .20697 .66285 .19922 .65657 .1871 Mtetra
.702 .682 .827 r
.65657 .1871 .66285 .19922 .67532 .19167 .6691 .18012 Mtetra
.704 .694 .838 r
.6691 .18012 .67532 .19167 .68782 .18412 .68167 .17323 Mtetra
.708 .711 .85 r
.68167 .17323 .68782 .18412 .70035 .17655 .69428 .16638 Mtetra
.713 .73 .864 r
.69428 .16638 .70035 .17655 .71291 .16892 .70693 .15953 Mtetra
.72 .754 .879 r
.70693 .15953 .71291 .16892 .7255 .16118 .71961 .15261 Mtetra
.614 .74 .936 r
.04273 .38856 .05043 .39529 .06015 .39382 .05264 .38582 Mtetra
.617 .703 .906 r
.05264 .38582 .06015 .39382 .06992 .3923 .0626 .38305 Mtetra
.615 .669 .879 r
.0626 .38305 .06992 .3923 .07975 .39078 .07261 .38031 Mtetra
.609 .639 .855 r
.07261 .38031 .07975 .39078 .08962 .38932 .08264 .37766 Mtetra
.601 .611 .834 r
.08264 .37766 .08962 .38932 .09952 .38796 .0927 .37515 Mtetra
.591 .586 .816 r
.0927 .37515 .09952 .38796 .10946 .38682 .10278 .37287 Mtetra
.577 .561 .8 r
.10278 .37287 .10946 .38682 .1194 .38605 .11286 .37094 Mtetra
.569 .54 .783 r
.11286 .37094 .1194 .38605 .12937 .38552 .12297 .36922 Mtetra
.561 .521 .768 r
.12297 .36922 .12937 .38552 .13937 .38523 .1331 .36771 Mtetra
.567 .511 .752 r
.1331 .36771 .13937 .38523 .14947 .38462 .14332 .36593 Mtetra
.579 .507 .738 r
.14332 .36593 .14947 .38462 .15972 .38328 .15367 .36351 Mtetra
.599 .51 .725 r
.15367 .36351 .15972 .38328 .17017 .38062 .16419 .36001 Mtetra
.624 .518 .714 r
.16419 .36001 .17017 .38062 .18086 .37611 .17493 .355 Mtetra
.639 .524 .707 r
.17493 .355 .18086 .37611 .19174 .37021 .18581 .34888 Mtetra
.652 .53 .703 r
.18581 .34888 .19174 .37021 .20277 .36318 .19682 .34186 Mtetra
.646 .527 .705 r
.19682 .34186 .20277 .36318 .21376 .35666 .20781 .33525 Mtetra
.624 .513 .708 r
.20781 .33525 .21376 .35666 .22462 .35186 .21869 .32999 Mtetra
.584 .486 .709 r
.21869 .32999 .22462 .35186 .23526 .34982 .2294 .32692 Mtetra
.525 .442 .704 r
.2294 .32692 .23526 .34982 .24565 .35131 .2399 .32664 Mtetra
.481 .402 .69 r
.2399 .32664 .24565 .35131 .25591 .35521 .2503 .32837 Mtetra
.453 .37 .673 r
.2503 .32837 .25591 .35521 .26614 .36078 .26066 .33156 Mtetra
.457 .362 .659 r
.26066 .33156 .26614 .36078 .27649 .36611 .27111 .33483 Mtetra
.477 .367 .65 r
.27111 .33483 .27649 .36611 .28706 .37 .28172 .33725 Mtetra
.498 .377 .645 r
.28172 .33725 .28706 .37 .29786 .37211 .2925 .33852 Mtetra
.52 .39 .643 r
.2925 .33852 .29786 .37211 .30888 .37224 .30346 .33839 Mtetra
.534 .399 .643 r
.30346 .33839 .30888 .37224 .32005 .37114 .31456 .33728 Mtetra
.545 .407 .643 r
.31456 .33728 .32005 .37114 .33135 .36915 .32578 .33536 Mtetra
.555 .414 .644 r
.32578 .33536 .33135 .36915 .34274 .36647 .33711 .33272 Mtetra
.563 .42 .645 r
.33711 .33272 .34274 .36647 .35423 .3632 .34853 .32942 Mtetra
.573 .427 .645 r
.34853 .32942 .35423 .3632 .36581 .35917 .36005 .32533 Mtetra
.582 .433 .644 r
.36005 .32533 .36581 .35917 .37747 .35438 .37165 .32046 Mtetra
.59 .438 .644 r
.37165 .32046 .37747 .35438 .3892 .34899 .38333 .31492 Mtetra
.597 .443 .643 r
.38333 .31492 .3892 .34899 .40101 .34291 .39508 .30866 Mtetra
.606 .448 .642 r
.39508 .30866 .40101 .34291 .41288 .33592 .40689 .30156 Mtetra
.616 .455 .641 r
.40689 .30156 .41288 .33592 .42482 .32767 .41877 .29347 Mtetra
.63 .465 .64 r
.41877 .29347 .42482 .32767 .43683 .3174 .43071 .28395 Mtetra
.644 .476 .642 r
.43071 .28395 .43683 .3174 .4489 .30532 .44269 .27324 Mtetra
.657 .489 .645 r
.44269 .27324 .4489 .30532 .46099 .29175 .4547 .26166 Mtetra
.664 .5 .653 r
.4547 .26166 .46099 .29175 .47307 .27789 .4667 .25012 Mtetra
.658 .505 .666 r
.4667 .25012 .47307 .27789 .4851 .2657 .47867 .24006 Mtetra
.643 .506 .681 r
.47867 .24006 .4851 .2657 .4971 .25595 .49063 .23201 Mtetra
.61 .495 .698 r
.49063 .23201 .4971 .25595 .50909 .24978 .50259 .2268 Mtetra
.576 .481 .71 r
.50259 .2268 .50909 .24978 .52112 .24642 .51459 .22382 Mtetra
.551 .469 .715 r
.51459 .22382 .52112 .24642 .53321 .24482 .52665 .22223 Mtetra
.542 .464 .717 r
.52665 .22223 .53321 .24482 .54538 .24376 .53879 .22106 Mtetra
.56 .474 .715 r
.53879 .22106 .54538 .24376 .55762 .24154 .551 .21897 Mtetra
.581 .489 .715 r
.551 .21897 .55762 .24154 .56991 .23789 .56327 .21575 Mtetra
.608 .509 .716 r
.56327 .21575 .56991 .23789 .58222 .23233 .57558 .21097 Mtetra
.629 .527 .72 r
.57558 .21097 .58222 .23233 .59455 .22541 .58792 .20507 Mtetra
.644 .545 .727 r
.58792 .20507 .59455 .22541 .60689 .21772 .60029 .19851 Mtetra
.654 .561 .737 r
.60029 .19851 .60689 .21772 .61925 .20967 .61269 .19165 Mtetra
.657 .575 .75 r
.61269 .19165 .61925 .20967 .63165 .20187 .62513 .18499 Mtetra
.66 .589 .765 r
.62513 .18499 .63165 .20187 .64409 .1943 .63761 .17855 Mtetra
.659 .603 .781 r
.63761 .17855 .64409 .1943 .65657 .1871 .65016 .17246 Mtetra
.661 .62 .798 r
.65016 .17246 .65657 .1871 .6691 .18012 .66275 .1666 Mtetra
.664 .641 .816 r
.66275 .1666 .6691 .18012 .68167 .17323 .67541 .16088 Mtetra
.669 .665 .837 r
.67541 .16088 .68167 .17323 .69428 .16638 .68811 .15524 Mtetra
.675 .693 .859 r
.68811 .15524 .69428 .16638 .70693 .15953 .70087 .14962 Mtetra
.682 .727 .884 r
.70087 .14962 .70693 .15953 .71961 .15261 .71368 .14397 Mtetra
.675 .756 .912 r
.03496 .38178 .04273 .38856 .05264 .38582 .04511 .37759 Mtetra
.669 .714 .882 r
.04511 .37759 .05264 .38582 .0626 .38305 .05529 .3734 Mtetra
.66 .677 .855 r
.05529 .3734 .0626 .38305 .07261 .38031 .0655 .36926 Mtetra
.65 .644 .831 r
.0655 .36926 .07261 .38031 .08264 .37766 .07574 .36522 Mtetra
.639 .615 .81 r
.07574 .36522 .08264 .37766 .0927 .37515 .08599 .36132 Mtetra
.626 .588 .791 r
.08599 .36132 .0927 .37515 .10278 .37287 .09625 .35764 Mtetra
.613 .562 .774 r
.09625 .35764 .10278 .37287 .11286 .37094 .10651 .35425 Mtetra
.602 .54 .757 r
.10651 .35425 .11286 .37094 .12297 .36922 .11679 .35107 Mtetra
.593 .519 .741 r
.11679 .35107 .12297 .36922 .1331 .36771 .12709 .34808 Mtetra
.592 .506 .726 r
.12709 .34808 .1331 .36771 .14332 .36593 .13745 .34494 Mtetra
.596 .498 .713 r
.13745 .34494 .14332 .36593 .15367 .36351 .14791 .34139 Mtetra
.605 .496 .703 r
.14791 .34139 .15367 .36351 .16419 .36001 .1585 .3371 Mtetra
.619 .5 .695 r
.1585 .3371 .16419 .36001 .17493 .355 .16924 .33177 Mtetra
.63 .505 .692 r
.16924 .33177 .17493 .355 .18581 .34888 .1801 .32565 Mtetra
.64 .511 .69 r
.1801 .32565 .18581 .34888 .19682 .34186 .19106 .31884 Mtetra
.638 .511 .692 r
.19106 .31884 .19682 .34186 .20781 .33525 .20203 .3122 Mtetra
.626 .504 .694 r
.20203 .3122 .20781 .33525 .21869 .32999 .21294 .30637 Mtetra
.602 .486 .693 r
.21294 .30637 .21869 .32999 .2294 .32692 .22375 .30191 Mtetra
.568 .456 .686 r
.22375 .30191 .2294 .32692 .2399 .32664 .23444 .29925 Mtetra
.541 .426 .671 r
.23444 .29925 .2399 .32664 .2503 .32837 .24505 .29796 Mtetra
.52 .399 .654 r
.24505 .29796 .2503 .32837 .26066 .33156 .25563 .29776 Mtetra
.516 .383 .639 r
.25563 .29776 .26066 .33156 .27111 .33483 .26626 .2978 Mtetra
.519 .376 .627 r
.26626 .2978 .27111 .33483 .28172 .33725 .27699 .29755 Mtetra
.525 .374 .619 r
.27699 .29755 .28172 .33725 .2925 .33852 .28783 .29679 Mtetra
.532 .375 .613 r
.28783 .29679 .2925 .33852 .30346 .33839 .29878 .29532 Mtetra
.537 .376 .61 r
.29878 .29532 .30346 .33839 .31456 .33728 .30984 .29332 Mtetra
.542 .378 .608 r
.30984 .29332 .31456 .33728 .32578 .33536 .32099 .29083 Mtetra
.546 .38 .608 r
.32099 .29083 .32578 .33536 .33711 .33272 .33223 .28784 Mtetra
.551 .383 .607 r
.33223 .28784 .33711 .33272 .34853 .32942 .34356 .28431 Mtetra
.557 .387 .607 r
.34356 .28431 .34853 .32942 .36005 .32533 .35497 .28016 Mtetra
.563 .391 .607 r
.35497 .28016 .36005 .32533 .37165 .32046 .36647 .27539 Mtetra
.568 .395 .608 r
.36647 .27539 .37165 .32046 .38333 .31492 .37803 .27008 Mtetra
.573 .399 .608 r
.37803 .27008 .38333 .31492 .39508 .30866 .38966 .26426 Mtetra
.578 .404 .609 r
.38966 .26426 .39508 .30866 .40689 .30156 .40134 .25793 Mtetra
.584 .409 .611 r
.40134 .25793 .40689 .30156 .41877 .29347 .41308 .25107 Mtetra
.592 .418 .615 r
.41308 .25107 .41877 .29347 .43071 .28395 .42487 .24349 Mtetra
.601 .428 .62 r
.42487 .24349 .43071 .28395 .44269 .27324 .4367 .23537 Mtetra
.609 .44 .627 r
.4367 .23537 .44269 .27324 .4547 .26166 .44856 .22694 Mtetra
.614 .452 .638 r
.44856 .22694 .4547 .26166 .4667 .25012 .46044 .21875 Mtetra
.612 .461 .652 r
.46044 .21875 .4667 .25012 .47867 .24006 .47232 .21165 Mtetra
.603 .467 .669 r
.47232 .21165 .47867 .24006 .49063 .23201 .48421 .20593 Mtetra
.583 .465 .685 r
.48421 .20593 .49063 .23201 .50259 .2268 .49612 .20204 Mtetra
.563 .461 .696 r
.49612 .20204 .50259 .2268 .51459 .22382 .50808 .19955 Mtetra
.549 .455 .701 r
.50808 .19955 .51459 .22382 .52665 .22223 .52011 .19789 Mtetra
.545 .453 .702 r
.52011 .19789 .52665 .22223 .53879 .22106 .53221 .19641 Mtetra
.557 .459 .699 r
.53221 .19641 .53879 .22106 .551 .21897 .54438 .19424 Mtetra
.571 .468 .698 r
.54438 .19424 .551 .21897 .56327 .21575 .55662 .19125 Mtetra
.589 .481 .699 r
.55662 .19125 .56327 .21575 .57558 .21097 .56891 .18719 Mtetra
.602 .494 .703 r
.56891 .18719 .57558 .21097 .58792 .20507 .58125 .18237 Mtetra
.613 .508 .711 r
.58125 .18237 .58792 .20507 .60029 .19851 .59363 .17712 Mtetra
.62 .522 .722 r
.59363 .17712 .60029 .19851 .61269 .19165 .60605 .17171 Mtetra
.622 .536 .736 r
.60605 .17171 .61269 .19165 .62513 .18499 .61853 .16649 Mtetra
.624 .552 .753 r
.61853 .16649 .62513 .18499 .63761 .17855 .63107 .16147 Mtetra
.624 .568 .771 r
.63107 .16147 .63761 .17855 .65016 .17246 .64367 .15676 Mtetra
.625 .587 .791 r
.64367 .15676 .65016 .17246 .66275 .1666 .65634 .15226 Mtetra
.627 .609 .813 r
.65634 .15226 .66275 .1666 .67541 .16088 .66908 .14791 Mtetra
.63 .635 .837 r
.66908 .14791 .67541 .16088 .68811 .15524 .68189 .14366 Mtetra
.633 .666 .864 r
.68189 .14366 .68811 .15524 .70087 .14962 .69476 .13946 Mtetra
.636 .702 .893 r
.69476 .13946 .70087 .14962 .71368 .14397 .70769 .13525 Mtetra
.719 .764 .888 r
.02714 .37496 .03496 .38178 .04511 .37759 .03752 .36936 Mtetra
.709 .725 .863 r
.03752 .36936 .04511 .37759 .05529 .3734 .04793 .3638 Mtetra
.697 .691 .841 r
.04793 .3638 .05529 .3734 .0655 .36926 .05835 .35831 Mtetra
.685 .66 .82 r
.05835 .35831 .0655 .36926 .07574 .36522 .06878 .35291 Mtetra
.673 .632 .801 r
.06878 .35291 .07574 .36522 .08599 .36132 .07923 .34764 Mtetra
.66 .607 .784 r
.07923 .34764 .08599 .36132 .09625 .35764 .08968 .34254 Mtetra
.647 .582 .768 r
.08968 .34254 .09625 .35764 .10651 .35425 .10014 .33765 Mtetra
.636 .559 .751 r
.10014 .33765 .10651 .35425 .11679 .35107 .11061 .33293 Mtetra
.625 .538 .736 r
.11061 .33293 .11679 .35107 .12709 .34808 .12109 .32838 Mtetra
.619 .521 .721 r
.12109 .32838 .12709 .34808 .13745 .34494 .13161 .32381 Mtetra
.616 .509 .709 r
.13161 .32381 .13745 .34494 .14791 .34139 .14219 .31909 Mtetra
.617 .502 .7 r
.14219 .31909 .14791 .34139 .1585 .3371 .15283 .31405 Mtetra
.621 .5 .693 r
.15283 .31405 .1585 .3371 .16924 .33177 .16357 .30851 Mtetra
.627 .502 .691 r
.16357 .30851 .16924 .33177 .1801 .32565 .17439 .30256 Mtetra
.633 .507 .692 r
.17439 .30256 .1801 .32565 .19106 .31884 .18528 .29623 Mtetra
.635 .512 .696 r
.18528 .29623 .19106 .31884 .20203 .3122 .19619 .28991 Mtetra
.631 .512 .699 r
.19619 .28991 .20203 .3122 .21294 .30637 .2071 .28388 Mtetra
.621 .504 .699 r
.2071 .28388 .21294 .30637 .22375 .30191 .21798 .27846 Mtetra
.604 .488 .694 r
.21798 .27846 .22375 .30191 .23444 .29925 .22882 .27385 Mtetra
.587 .466 .682 r
.22882 .27385 .23444 .29925 .24505 .29796 .23963 .26993 Mtetra
.572 .443 .666 r
.23963 .26993 .24505 .29796 .25563 .29776 .25043 .26661 Mtetra
.562 .424 .651 r
.25043 .26661 .25563 .29776 .26626 .2978 .26126 .26356 Mtetra
.557 .41 .637 r
.26126 .26356 .26626 .2978 .27699 .29755 .27214 .26057 Mtetra
.554 .4 .627 r
.27214 .26057 .27699 .29755 .28783 .29679 .28307 .25752 Mtetra
.552 .394 .62 r
.28307 .25752 .28783 .29679 .29878 .29532 .29406 .25434 Mtetra
.552 .39 .615 r
.29406 .25434 .29878 .29532 .30984 .29332 .30512 .25106 Mtetra
.552 .387 .612 r
.30512 .25106 .30984 .29332 .32099 .29083 .31623 .24764 Mtetra
.553 .386 .609 r
.31623 .24764 .32099 .29083 .33223 .28784 .32741 .24401 Mtetra
.555 .386 .608 r
.32741 .24401 .33223 .28784 .34356 .28431 .33866 .24012 Mtetra
.557 .388 .607 r
.33866 .24012 .34356 .28431 .35497 .28016 .34997 .23591 Mtetra
.56 .39 .608 r
.34997 .23591 .35497 .28016 .36647 .27539 .36135 .23138 Mtetra
.563 .393 .608 r
.36135 .23138 .36647 .27539 .37803 .27008 .37278 .22658 Mtetra
.566 .395 .61 r
.37278 .22658 .37803 .27008 .38966 .26426 .38427 .22158 Mtetra
.568 .399 .612 r
.38427 .22158 .38966 .26426 .40134 .25793 .39581 .21643 Mtetra
.571 .403 .616 r
.39581 .21643 .40134 .25793 .41308 .25107 .4074 .21117 Mtetra
.574 .409 .62 r
.4074 .21117 .41308 .25107 .42487 .24349 .41903 .20577 Mtetra
.578 .418 .627 r
.41903 .20577 .42487 .24349 .4367 .23537 .43071 .20032 Mtetra
.583 .428 .637 r
.43071 .20032 .4367 .23537 .44856 .22694 .44242 .19492 Mtetra
.586 .44 .65 r
.44242 .19492 .44856 .22694 .46044 .21875 .45417 .18979 Mtetra
.585 .452 .666 r
.45417 .18979 .46044 .21875 .47232 .21165 .46596 .18527 Mtetra
.58 .462 .682 r
.46596 .18527 .47232 .21165 .48421 .20593 .47778 .18144 Mtetra
.571 .467 .697 r
.47778 .18144 .48421 .20593 .49612 .20204 .48965 .17844 Mtetra
.562 .467 .705 r
.48965 .17844 .49612 .20204 .50808 .19955 .50158 .17606 Mtetra
.556 .465 .707 r
.50158 .17606 .50808 .19955 .52011 .19789 .51358 .17398 Mtetra
.555 .462 .704 r
.51358 .17398 .52011 .19789 .53221 .19641 .52564 .17192 Mtetra
.561 .462 .7 r
.52564 .17192 .53221 .19641 .54438 .19424 .53778 .16947 Mtetra
.567 .465 .697 r
.53778 .16947 .54438 .19424 .55662 .19125 .54999 .16661 Mtetra
.576 .471 .698 r
.54999 .16661 .55662 .19125 .56891 .18719 .56226 .16323 Mtetra
.583 .481 .703 r
.56226 .16323 .56891 .18719 .58125 .18237 .57458 .15952 Mtetra
.588 .492 .712 r
.57458 .15952 .58125 .18237 .59363 .17712 .58697 .15565 Mtetra
.592 .505 .725 r
.58697 .15565 .59363 .17712 .60605 .17171 .59942 .15177 Mtetra
.594 .52 .741 r
.59942 .15177 .60605 .17171 .61853 .16649 .61193 .14806 Mtetra
.594 .536 .759 r
.61193 .14806 .61853 .16649 .63107 .16147 .62452 .14452 Mtetra
.594 .553 .779 r
.62452 .14452 .63107 .16147 .64367 .15676 .63718 .1412 Mtetra
.593 .573 .8 r
.63718 .1412 .64367 .15676 .65634 .15226 .64992 .13805 Mtetra
.592 .594 .823 r
.64992 .13805 .65634 .15226 .66908 .14791 .66273 .13503 Mtetra
.591 .619 .848 r
.66273 .13503 .66908 .14791 .68189 .14366 .67563 .13212 Mtetra
.59 .647 .875 r
.67563 .13212 .68189 .14366 .69476 .13946 .6886 .12928 Mtetra
.587 .679 .905 r
.6886 .12928 .69476 .13946 .70769 .13525 .70165 .12647 Mtetra
.748 .767 .869 r
.01926 .36808 .02714 .37496 .03752 .36936 .02984 .36134 Mtetra
.736 .737 .852 r
.02984 .36134 .03752 .36936 .04793 .3638 .04043 .35468 Mtetra
.725 .71 .836 r
.04043 .35468 .04793 .3638 .05835 .35831 .05103 .34811 Mtetra
.714 .686 .821 r
.05103 .34811 .05835 .35831 .06878 .35291 .06164 .34163 Mtetra
.704 .663 .807 r
.06164 .34163 .06878 .35291 .07923 .34764 .07226 .33524 Mtetra
.693 .641 .793 r
.07226 .33524 .07923 .34764 .08968 .34254 .08288 .32894 Mtetra
.683 .619 .778 r
.08288 .32894 .08968 .34254 .10014 .33765 .09353 .32272 Mtetra
.672 .597 .763 r
.09353 .32272 .10014 .33765 .11061 .33293 .10418 .31659 Mtetra
.662 .576 .748 r
.10418 .31659 .11061 .33293 .12109 .32838 .11485 .31054 Mtetra
.652 .556 .734 r
.11485 .31054 .12109 .32838 .13161 .32381 .12554 .30459 Mtetra
.643 .54 .722 r
.12554 .30459 .13161 .32381 .14219 .31909 .13624 .29871 Mtetra
.636 .527 .713 r
.13624 .29871 .14219 .31909 .15283 .31405 .14696 .29293 Mtetra
.631 .518 .707 r
.14696 .29293 .15283 .31405 .16357 .30851 .1577 .28723 Mtetra
.629 .516 .706 r
.1577 .28723 .16357 .30851 .17439 .30256 .16846 .28161 Mtetra
.629 .519 .71 r
.16846 .28161 .17439 .30256 .18528 .29623 .17924 .27608 Mtetra
.631 .526 .717 r
.17924 .27608 .18528 .29623 .19619 .28991 .19005 .27063 Mtetra
.633 .535 .725 r
.19005 .27063 .19619 .28991 .2071 .28388 .20088 .26527 Mtetra
.634 .542 .732 r
.20088 .26527 .2071 .28388 .21798 .27846 .21173 .26 Mtetra
.633 .543 .734 r
.21173 .26 .21798 .27846 .22882 .27385 .22261 .2548 Mtetra
.629 .535 .729 r
.22261 .2548 .22882 .27385 .23963 .26993 .23352 .2497 Mtetra
.622 .522 .719 r
.23352 .2497 .23963 .26993 .25043 .26661 .24445 .24468 Mtetra
.614 .504 .705 r
.24445 .24468 .25043 .26661 .26126 .26356 .25542 .23974 Mtetra
.606 .487 .692 r
.25542 .23974 .26126 .26356 .27214 .26057 .26642 .23488 Mtetra
.598 .472 .68 r
.26642 .23488 .27214 .26057 .28307 .25752 .27745 .23012 Mtetra
.592 .46 .669 r
.27745 .23012 .28307 .25752 .29406 .25434 .28851 .22543 Mtetra
.587 .45 .662 r
.28851 .22543 .29406 .25434 .30512 .25106 .29961 .22083 Mtetra
.582 .442 .655 r
.29961 .22083 .30512 .25106 .31623 .24764 .31075 .21631 Mtetra
.579 .435 .65 r
.31075 .21631 .31623 .24764 .32741 .24401 .32192 .21188 Mtetra
.576 .431 .647 r
.32192 .21188 .32741 .24401 .33866 .24012 .33314 .20754 Mtetra
.574 .428 .645 r
.33314 .20754 .33866 .24012 .34997 .23591 .34439 .20327 Mtetra
.572 .427 .645 r
.34439 .20327 .34997 .23591 .36135 .23138 .35569 .1991 Mtetra
.572 .428 .647 r
.35569 .1991 .36135 .23138 .37278 .22658 .36703 .19501 Mtetra
.572 .431 .65 r
.36703 .19501 .37278 .22658 .38427 .22158 .37841 .191 Mtetra
.573 .435 .655 r
.37841 .191 .38427 .22158 .39581 .21643 .38984 .18708 Mtetra
.574 .441 .662 r
.38984 .18708 .39581 .21643 .4074 .21117 .40132 .18324 Mtetra
.575 .449 .67 r
.40132 .18324 .4074 .21117 .41903 .20577 .41285 .17949 Mtetra
.577 .459 .681 r
.41285 .17949 .41903 .20577 .43071 .20032 .42443 .17582 Mtetra
.58 .471 .694 r
.42443 .17582 .43071 .20032 .44242 .19492 .43606 .17224 Mtetra
.583 .485 .709 r
.43606 .17224 .44242 .19492 .45417 .18979 .44775 .16875 Mtetra
.586 .5 .724 r
.44775 .16875 .45417 .18979 .46596 .18527 .45949 .16534 Mtetra
.587 .511 .736 r
.45949 .16534 .46596 .18527 .47778 .18144 .47129 .16203 Mtetra
.586 .516 .742 r
.47129 .16203 .47778 .18144 .48965 .17844 .48315 .15879 Mtetra
.584 .512 .74 r
.48315 .15879 .48965 .17844 .50158 .17606 .49506 .15565 Mtetra
.58 .503 .733 r
.49506 .15565 .50158 .17606 .51358 .17398 .50705 .15259 Mtetra
.576 .493 .724 r
.50705 .15259 .51358 .17398 .52564 .17192 .51909 .14962 Mtetra
.572 .484 .717 r
.51909 .14962 .52564 .17192 .53778 .16947 .5312 .14674 Mtetra
.569 .479 .714 r
.5312 .14674 .53778 .16947 .54999 .16661 .54338 .14395 Mtetra
.567 .479 .715 r
.54338 .14395 .54999 .16661 .56226 .16323 .55563 .14125 Mtetra
.567 .485 .722 r
.55563 .14125 .56226 .16323 .57458 .15952 .56795 .13864 Mtetra
.567 .495 .733 r
.56795 .13864 .57458 .15952 .58697 .15565 .58035 .13612 Mtetra
.567 .508 .748 r
.58035 .13612 .58697 .15565 .59942 .15177 .59282 .13369 Mtetra
.568 .524 .767 r
.59282 .13369 .59942 .15177 .61193 .14806 .60537 .13135 Mtetra
.568 .542 .786 r
.60537 .13135 .61193 .14806 .62452 .14452 .618 .12911 Mtetra
.566 .56 .806 r
.618 .12911 .62452 .14452 .63718 .1412 .63071 .12695 Mtetra
.564 .579 .827 r
.63071 .12695 .63718 .1412 .64992 .13805 .6435 .12489 Mtetra
.561 .598 .847 r
.6435 .12489 .64992 .13805 .66273 .13503 .65638 .12293 Mtetra
.556 .618 .869 r
.65638 .12293 .66273 .13503 .67563 .13212 .66935 .12106 Mtetra
.55 .639 .892 r
.66935 .12106 .67563 .13212 .6886 .12928 .68241 .11929 Mtetra
.54 .663 .916 r
.68241 .11929 .6886 .12928 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Nooooo`;oS:?T1?n:ZNX00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo057ooooo001Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool07Oooool3o`0000;ooooo00?o0000ooooooooool0Dooo
ool2ohnIf0GoSYkN1On<Xn@3ohZYjP03o`000?n:ZN[ooooo01Gooooo00?o0000ooooooooool0D?oo
ool0063ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00007?ooool2o`0005Oooooo0_n@
U=<5ohnIf0GoSYkN1On<Xn@2ohZYjP03o`000?nF[NOooooo01Cooooo00?o0000ooooool00000DOoo
ool0063ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001[ooooo
0ol0001Aooooo`;oTH[91?n@Slh5oi2Dd`CoSiWH1_n>W]h2ohbSi0;oUjGO0_nF[NL00ol0003oUZgW
oiJ]i`0Fooooo`03o`000?oooooooooo04oooooo001Pooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool0000Hooooo`;o0000D?ooool2oi66a0GoTH[91?n@Slh4oi2Dd`Go
SiWH0on>W]h2oiNNf@GoUjGO00?oUZgWo`000?nF[NL00_nF[NLFooooo`03o`000?oooooooooo04ko
oooo001Pooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Eooooo`?o
00000_ooool00ol0003oooooooooo`15ooooo`;oTGjk1?nAP[l5oi66a0CoTH[91?n@Slh5oi2Dd`;o
SiWH0_nGV=86oiNNf@CoUjGO00GoUZgWo`000?nF[NOoUZgWoj:ci00Fooooo`03o`000?oooooooooo
04kooooo001Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000Coooo
o`;o0000BOooool2oi5l^0CoTGjk1OnAP[l4oi66a0CoTH[91On@Slh2oi2Dd`;oUi;<1OnGV=85oiNN
f@GoUjGO00?o0000oj:ci?nR/n@00_nR/n@Fooooo`03o`000?oooooooooo04gooooo001Pooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0?ooooo`?o0000B?ooool00onA
N[OoTGbhoi5l^002oi5l^0GoTGjk1?nAP[l4oi66a0GoTH[90_n@Slh2oiR=a`GoUi;<1?nGV=86oiNN
f@;oUjGO0_nRZ]d00ol0003oX[?Toj:ci003oj:ci1Kooooo00?o0000ooooooooool0C?ooool008;o
oooo0_l00017ooooo`;oTGZf1?nAN[L4oi5l^0CoTGjk1?nAP[l5oi66a0;oTH[90_nHRL85oiR=a`Co
Ui;<1OnGV=83oiNNf@;oXJ;F1?nRZ]d00ol0003oX[?Toj:ci002oj:ci003ojjjh_oooooooooo01Co
oooo00?o0000ooooooooool0C?ooool007oooooo0ol00002ooooo`03o`000?oooooooooo043ooooo
0_nBNkL4oi5j]PCoTGZg1?nAO;P4oi5n^`GoTH:o0_nAQ/@2oiR5_@GoV8W21?nHSLL4oiNBc0CoUiSB
00?oX9_@oj6Re_nQX]H00onQX]H4oj:Zg@03o`000?nRZ]goX[?T00Co[[[R5?ooool3o`0004gooooo
001looooo`?o0000A?ooool2oi=n^@CoTW^g1OnAN[H4oi5j]`?oTGbh1OnAO[/3oi62_`03oiN1^OnH
QKgoV8Fm00?oV8Fm1?nHRL84oiR=a`GoUi;<00?oUiSBoj2Kd?nPVm000_nPVm05oj6ReP?oXZ[M00?o
0000ojbafon^^^801?n^^^8Gooooo`03o`000?oooooooooo04[ooooo001jooooo`;o0000@oooool2
oiB0^`CoTgji1OnBNkL4oi5j]PCoTGZg1?nAO;P4oi5n^`04oi62_onGPKWoUh6ioiN1^@GoV8Fm1?nH
RL85oiR=a`;oUi;<0_nOU/X5oj2Kd0GoXJ;F00KoXZ[Mojbafon//M_o[;7Ko`000?n//M/3ojjjhP;o
^<7Q5_ooool00ol0003oooooooooo`1:ooooo`00Moooool3o`00047ooooo0_nEPkd5oiB0^`CoTgji
1?nBNkL4oi5j]PCoTGZg1?nAO;P2oi5n^`;oUWff1OnGPKT4oiR5_@GoV8W20onHSLL00onOTLGoWiK:
oinFbP03oinFbPGoX9_@0_nQX]H2oj^ZePCo[;7K00?o0000ojbafon^^^801Onh`N4Fooooo`03o`00
0?oooooooooo04Wooooo001eooooo`;o00000_ooool00ol0003oooooooooo`0looooo`03oiJ4_OnE
PkgoUH>m00?oUH>m1?nDP;/4oi=n^@CoTW^g1OnAN[H4oi5j]`;oTGbh00?oUG^coiIm]_nFOKH00onF
OKH4oiN1^@GoV8Fm1?nHRL800onHSLOoWi75oinAa@02oinAa@CoWiK:1?nPVm000onYY=3oZj[Foj^Z
eP03oj^ZeP?o[;7K00?o0000okJjgOnh`N401?nh`N400onna^3oooooooooo`0Eooooo`03o`000?oo
oooooooo04Sooooo001booooo`?o00001Oooool00ol0003oooooooooo`0gooooo`;oUX:l1?nFQ;d4
oiF3_@CoU82k1?nCO[T5oi9k]`CoTGZf0_nAN[L2oi=h/PCoUG^c1?nFOKH4oiN1^@GoV8Fm0_nHRL82
oin=`0GoWi751OnOU/X00onPVm3oZJC@ojVTd002ojVTd0GoZj[F00?o[;7KokJjgOl000000_nf^]d3
okS1h@?o_/KP5_ooool00ol0003oooooooooo`18ooooo`00L?ooool2o`0003kooooo0_nFOkT5oiJ2
_0?oUXBm1?nEPkd5oiB0^`CoTgji1?nBNkL2oi5j]P;oTGNb1?nCN;84oiEk/`GoUWff1?nGPKT3oiR5
_@03oin9_?nOSL3oWhg000?oWhg01?nOTLD4oinFbP03ojVNc?nYY=3oZJC@00?oZJC@1?n[Z]H01?ne
]]Wo][[MokJjgOl00003okJjg@03okS1hOnna^3o_/KP00?o_/KP5_ooool00ol0003oooooooooo`17
ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00008?ooool3
o`0003gooooo00?oUGbeoiIo^OnFOkT00onFOkT4oiJ2_0CoUXBm1?nEPkd4oiB0^`CoTgji0_nBNkL2
ohmf/`CoTGNb1OnCN;84oiEk/`CoUWff1?nGPKT00onHQKgoWhVloin9_002oin9_0CoWhg01OnOTLD0
0onOU/[oZIk<ojVNc002ojVNc0GoZJC@00?oZj[FokFffOne]]T00_ne]]T01Onf^]go0000okJjgOnf
^]go_LCO00Go_/KP00?o`/cRooooooooool04oooool3o`0004Sooooo000hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Nooooo`;o0000
0oooool00ol0003oooooooooo`0fooooo`;oU7Ra1?nEO;D4oiIo^@CoUX:l1?nFQ;d4oiF3_@;oU82k
0_n>Mk@4ohif]0CoSgJc1OnAMk84oi=h/PCoUG^c1OnFOKH2oiN1^@03oij5^?nORKcoWhVl00?oWhVl
1?nOSL04oinAa@03ojRJaonYW/coZIk<00?oZIk<1?nYY=000ond/MKo]KKIokFff@04okFff@03o`00
0?nma=oo_LCO00;o_LCO0onna^03ol;<hQKooooo00?o0000ooooooooool01_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:Oooool003Sooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^01cooooo0ol0000jooooo`;o
TgF^1?nDN;44oiEl]@CoUWni1OnFP[`4oiJ4_@;oUH>m00?oSgNdohig]?n>Mk@00_n>Mk@4ohif]0Go
SgJc1?nAMk84oi=h/PCoUG^c1?nFOKH00onLP[KoWXFhoij5^002oij5^0GoWhVl1?nOSL000onOTLGo
Z9[7ojRJa`02ojRJa`GoZIk<00?oZJC@okBae_nd/MH00_nd/MH4okFff@03okc2g_l0003o_LCO00Co
_LCO00?o_/KPol;<h_o2c>800oo2c>8Fooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Zooooo`00>?ooool01Ol0003o
oooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h06?ooool3o`0003[ooooo00?oTg:[oi=e
[_nCMJh00_nCMJh5oiAh/@?oUGbe1OnFOkT4oiJ2_0;oUXBm0_nBMk83ohmg]0GoSWNd1?n>M[@4ohmf
/`CoTGNb1?nCN;85oiEk/`04oiIm]_nLP[KoW8:foib2]PCoWXFh1OnORK`3oin=`003ojRF`onXV/Oo
Z9[700?oZ9[71?nYW/`00onc[]?o];7FokBaeP03okBaeP?o]KKI0_nl`]h00ol0003o_LCOokg4g`02
okg4g`;o`/oT1?o2c>82ol7@iAKooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol0000[ooooo`00>?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool05Oooool3o`0003Wooooo00CoTW2Yoi=bZonCLZ_oTg:[1OnCMJh4oiAh/@CoUGbe
1?nFOkT2oiJ2_0;oU7J^1?nBMk84ohmg]0CoSWNd1?n>M[@4ohmf/`CoTGNb1OnCN;83oiEk/`03oiYn
/onLP[KoW8:f00?oW8:f1?nNQKP5oin9_004oin=`?nXU/?oZ9K3ojRF``CoZ9[70onYW/`3ok>^d`Go
];7F00Oo]KKIokc2g_nl`]ko_<;No`000?nl`]ko_LCO00Go`/oT00?o`/cRol7@iOo1d>D00oo1d>DE
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oM
gMgoooooo`0002cooooo000hooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Aooooo`?o00000oooool00ol0003oooooooooo`0dooooo`?oTW2Y1?nCLZ/4oi=e[PCoU7Ra
1?nEO;D2oiIo^@;oUG>Z1?nDMZh5oi9g/P?oSgNd1?n>Mk@4ohif]0CoSgJc1OnAMk84oi=h/P04oiEk
/onJO[?oVWjcoiYn/`GoW8:f1?nNQKP4oin9_003ojRC_onXU/?oZ9K300?oZ9K31?nXV/L00onYW/co
/jkCok>^d`02ok>^d`Co];7F00?o_<7Mokc2g_nl`]h00_nl`]h00ol0003o`];Vol;?i004ol;?i003
ol7Fj_o1d>Go`M3U00?o`M3U00?o_=;[ooooooooool05?ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000/ooooo`00>?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Aooooo`;o0000>_oo
ool2oi9_Y`CoTW2Y1?nCLZ/4oi=e[PGoU7Ra0_nEO;D00onFL:KoUG>ZoiEcZP02oiEcZPGoU7J^1?nB
Mk83ohmg]0CoSWNd1?n>M[@5ohmf/`CoTGNb0_nCN;82oiIk/PGoVWjc1?nLP[H5oij5^003oin9_?nX
TkooZ9>o00;oZ9>o1?nXU/<3ojRJa`03ok>[d?nc[]?o/jkC00Co/jkC00?o];7Fokc1gOnl`Md00_nl
`Md3okc2gP03o`000?o2d^Ko`];V00?o`/oT0oo1e^X3ol7@i@?o_=;[5_ooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000/ooooo`00>?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00>ooooo`?o
0000>Oooool00onBKZKoTVnWoi9_Y`02oi9_Y`CoTW2Y1?nCLZ/4oi=e[PGoU7Ra00?oUGbeoiI`Y_nF
L:H01OnELjX4oiAf[PCoTWNb0on?Mk@5ohig]0CoSWJd1?n?M[<2oi5g/P;oTWNb1?nFNk85oiYn/`Go
W8:f0onNQKP00onWSkcoZ9>oojRC_`03ojRC_`GoZ9K300CoZ9[7ok>[d?ncZm3o/j_@1?nc[]<7okc1
g@03okc2g_o2d^Ko000000?o`];V00?o`/oTol7Fj_o1e^X00oo1e^X00oo1d>Go_=;[okcBj`03okcB
jaCooooo0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000/
ooooo`00FOooool3o`0003Oooooo0_nBKJD3oi9^YPGoTVnW1?nBL:T3oi=bZ`GoTgF^0onDN;400onE
KJ?oUW2VoiI`YP02oiI`YPCoUG>Z1?nDMZh5oi9g/P?oSgNd1?n>Mk@4ohif]0;oSgJc0_n>MK84oi9g
/PGoUW^b1?nJO[<5oib2]P03oij5^?nWSkcoYhnl00;oYhnl1?nXTkl4ojRF``03okBYcOncZm3o/j_@
00?o/j_@00?o/jkCokc1gOnl`Md01_nl`Md2ol;Gj@04ol;Bi_l0003o`];Vol;BiP;o`=g^1?o1e^X2
ok[Ll@Co_=;[00?o/Lo`ooooooooool04Oooool01?l0003oooooooooool00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0[ooooo`00E_ooool3o`0000?ooooo00?o
0000ooooooooool0<Oooool5oi9]Y@CoTVjV1?nBKjL4oi9`Z@?oTg:[1OnCMJh01?nDN;7oUFfSoiE]
XonEKJ<4oiI`YPCoUG>Z1?nDMZh5oi9g/P?oSgNd0_n>Mk@2ohad/`CoRg>c1?n>MK85oi9g/PCoUW^b
1OnJO[<3oib2]P03ojB;^_nWSkcoYhnl00?oYhnl1OnXTkl00onXU/?o]:W=okBYc@02okBYc@Co/j_@
1onl`Md5ol;Gj@03o`000?o0gNko`=g^00?o`=g^00?o`MKZok[LlOnjg?400onjg?400onld^_o/Lo`
ok7?l002ok7?l1Kooooo00?o0000ooooooooool0@?ooool005Cooooo0_l0000hooooo`OoTVfU1?nB
KZH4oi9_Y`CoTW2Y1?nCLZ/3oi=e[P03oi=[X?nEKJ?oUFfS00?oUFfS0onFL:H4oiEcZPGoU7J^0onB
Mk801?nEMjooT7Jboi1f/_n@M[84ohad/`CoRg>c1On>MK84oi9g/PCoUW^b1OnJO[<00onLP[KoY8^j
ojB;^P02ojB;^PCoYhnl1?nXTkl00ondY/_o]:W=okBYc@03okBYc@?o/j_@0_nn`]d4okc1g@;o`]g]
1?o2enT00onmi_?o0000ol3MkP03ol3MkP?o]^Kf0_njg?42ojkJm`Go/Lo`5_ooool00ol0003ooooo
ooooo`10ooooo`00DOooool3o`0003Sooooo2OnBKJD4oi9^YPCoTVnW1?nBL:T4oi=bZ`04oi=e[_nC
Jj3oTf^Poi=[X0GoUFfS0onFL:H5oiEcZPCoU7J^00CoTWNboiEg[onEMjooUGN_0on@M[85ohad/`Co
Rg>c1?n>MK84oi9g/PGoUW^b0onJO[<00onQQ[SoY8^jojB;^P03ojB;^PGoYhnl0_nXTkl3okBVb`Go
]:W=00?o/j_@okk2gOnn`]d00_nn`]d00onl`Mgo`]g]ol;Mk@03ol;Mk@07ol;GjOnmi_?o_NKcokgV
lol0003o_NKcol3MkP04okKVmP03ojKSnon^f_Oo[][g00?o[][g0_naco03oj?9laKooooo00?o0000
ooooooooool0?oooool004kooooo1Ol0000eooooo`;oTfjU2onBKJD4oi9^YPCoTVnW1?nBL:T2oi=b
Z`;oTVRN1?nCJj05oiE]X`?oUW2V1OnELjX2oiAf[P;oVWN[1OnEMjl3oi1f/PCoS7Bc1?n;Lk<4ohie
/PCoTWNb1OnFNk801?nJO[?oXHJhoj66^?nQQ[P5ojB;^PGoYhnl00?oZ9>ookBVbondY//00_ndY//4
okBYc@03ol33g?nn`]go_/;M00;o_/;M0_o2iNl4ol;Mk@;o]^kf0onmi_<01Ol0003oZnkhoj_^n?n[
k_So]^Kf00CoY^?k0_n^f_L3oioBnPGoXlWc5_ooool00ol0003oooooooooo`0nooooo`00C?ooool2
o`0000Gooooo00?o0000ooooooooool0;oooool00onDKjKoTfjUoi=^Y@02oi=^Y@coTVfU0onBKZH5
oi9_Y`;oTW2Y00?oTVNMoi9XW_nBJ9h00_nBJ9h5oi=[X0CoUFfS1?nFL:H3oiEcZP03oiafY_nJMj_o
VWN[00;oVWN[1OnEMjl3oi1f/PCoS7Bc1?n;Lk<4ohie/PGoTWNb0onFNk800onKP[OoXHJhoj66^003
oj66^0GoY8^j0onWSk`00ondXlOo]:K;okBVb`03okBVb`?o]:W=0oo0`m`2okk2g@Co`^G_00?o`]g]
okK^m_nfk_H00onfk_H00onmi_?oZnkho`000002oj_^n0;oU^Sj0_nVho/3oiOIoPGoWm;j0_nSbO<2
oiJom1Kooooo00?o0000ooooooooool0?_ooool004Wooooo0ol0000hooooo`;oU6nV1OnCKZD;oi9]
Y@CoTVjV1?nBKjL00onBL:WoTVNMoi9WW@04oi9XWPGoTf^P1?nEKJ<4oiI`YP;oUG>Z0_nLMZH5oiYg
Z`CoUGN_0on@M[84ohad/`GoRg>c1?n>MK84oi9g/P04oiIk/_nKP[OoVh:goi^2]`GoXHJh1OnTRkX0
0onWSkco]:?7okBSa`02okBSa`Go]:K;00?o]:W=ol33g?o0`m`00_o0`m`00onn`]go`^G_ol;Uk`02
ol;Uk`?o[?Cb0_nfk_H4oiK_l@04oj_^n?l0003oU^SjoiKXnP;oR=cn1OnGfOh2oioBnP?oTlGh1?nF
_o@Dooooo`?o0000?oooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Pooooo`;o0000>?oo
ool2oiAaY`?oU6nV1OnCKZD;oi9]Y@CoTVjV0onBKjL01?nAIYcoTVNMoi9WWOnBIid5oi9XWPCoTf^P
1OnEKJ<3oiI`YP03oiEcZ_nLMZKoW7JV00;oW7JV1?nJMj/4oiEg[`CoT7Jb1?n<M;<4oh]c/`CoSWFb
0_nBMk82oiAm]`GoVh:g1?nQQ[P4ojB;^P03ok6NaOndXlOo]:?700?o]:?71?ndY//2ol;5g0?o`<?L
0oo3k_000oo2iNoo[?CbojcdlP02ojcdlP?oMnCK0_nFko42ogWRk`03og?Hn_l0003oR=cn00CoR=cn
0_nGfOh3ohk9o0GoTlGh1?nF_o@Eooooo`03o`000?oooooooooo03gooooo000Rooooo`05ogMgMonH
V9SooooooiRHV?mgMgL07Oooool3o`0000;ooooo00?o0000ooooooooool0<_ooool00onFLjWoU76W
oiAaY`02oiAaY`CoU6nV1?nCKZD;oi9]Y@CoTVjV00CoTVnWoi5VW?nAIYcoTFJL1?nBIid4oi9XWPCo
Tf^P1OnEKJ<2oiI`YP03oiecXonLMZKoW7JV00?oW7JV1?nJMj/5oiEg[`?oT7Jb1?n<M;<2oh]c/`;o
RWJg1?n?NKL4oiAm]`GoVh:g1OnQQ[P2ojB;^P?o/Ik51OndXlL00ondY/_o`/GLol;5g003ol;5g004
ol33g?o3k_3o`nk`ol?^l0?oVO?S00Co[?CbogOTfomgi=_oMnCK0_mEdMD3oe_?k`;oLmSj00Co0000
og?Hn_n8g?koR=cn0on7boh5ohk9o0;oTlGh0_n>]_85ohjflAGooooo00?o0000ooooooooool0??oo
ool002;ooooo00Go410@oooooooooooooooooa0@400Kooooo`;o0000>Oooool2oiIcZ@GoU76W0onD
KjH4oi=^Y@_oTVfU0_nBKZH2oi1UW0CoTFJL1?nBIid4oi9XWPCoTf^P1OnEKJ<00onFL:KoWG>Soiec
X`05oiafYPCoVWN[1OnEMjl2oi1f/P03oi=k]On=N;OoSGRg00;oSGRg1?n:M[L4ohmi]`GoU7fg1?nK
P[L5oj66^003ojB;^_naW/Go/Ik500;o/Ik51?ndXlL00oo4aM[o`/GLol;5g003ol;5g004ol;gk_o3
k_3o`nk`ol?^l0?oVO?S00?oBlJ_ob>_a_ln`=h00oln`=h2oe_?k`?oMlKo00?oO/Woo`000?mnbOl0
0_mnbOl4ohO;oP;oS/Wl0on=]_84ohjflPGoS[Ka5Oooool00ol0003oooooooooo`0kooooo`008_oo
ool01Ol0003ooooooooooooooooo000001Sooooo0ol0000hooooo`;oUgF[1?nFLjT4oiAaY`?oU6nV
1?nCKZD:oi9]Y@03oi1TVon@IIcoT6FL00;oT6FL1OnAIY`3oi9WW@CoTVRN1OnCJj03oiE]X`03oi]`
X?nMLj?oWG>S00;oWG>S1?nLMZH5oiYgZ`?oUGN_00?oW7jboi=k]OnCNkD00_nCNkD3oheh]`GoRWJg
1?n?NKL4oiAm]`GoVh:g0onQQ[P00on[V<?o/Ik5ok6Na@03ok6Na@?o]:?70oo4aMX3ol;5g0?o`_O^
00Co`nk`oiWchonIln?oIKSl1OmY_?d4ofk0oPCoMlKo00Co0000ogk9oon<[nkoS:o^1On=]?05ohff
lPCoS[Kb0_n>]_42ohj`kAGooooo00?o0000ooooooooool0>oooool002;ooooo00Go0000oooooooo
ooooooooo`00000Fooooo`?o0000=oooool00onIN:koUgF[oiMeZ`02oiMeZ`CoUW>Y1?nDLJL3oiA_
YPGoTfjU2?nBKJD2oi1TV`CoT6FL1OnAIY`3oi9WW@CoTVRN1OnCJj02oiE]X`;oVg2P1?nMLj<4oiaf
YPGoVWN[00CoUGN_oian/_nLO[;oW7jb1?nCNkD4oheh]`CoRWJg1?n?NKL4oiAm]`GoVh:g00?oXHJh
oj^H`on[V<<00_n[V<<5ok6Na@03okBSaoo4aM[oa<GJ00?oa<GJ00Go`/GLol;gk_o2mnko`_O^ogkU
a002ofNio@?oIKSl0_mY_?d2ohVEf@CoRYoR1?n;Z>P00ol0003oS:o^ohb_kP02ohb_kPGoSKC`0_n=
]_82oi6Yi`CoSjgZ1On>/>dEooooo`03o`000?oooooooooo03[ooooo000Rooooo`05oa0@4?oooooo
ooooooooool@41004oooool3o`0000;ooooo00?o0000ooooooooool0=?ooool2oiUh[PGoUgF[0onF
LjT4oiAaY`?oU6nV1OnCKZD5oi9]Y@;oSf>K0on@I9/5oi1UW0CoTFJL0onBIid4oi9XWPGoTf^P00Co
UFfSoi]`X?nKL:3oVg2P1?nMLj<5oiafYP?oVWN[00?oY86^oian/_nLO[800onLO[84oi=k]@?oSGRg
1?n:M[L4ohmi]`GoU7fg0onKP[L00onTTL;oZiS3oj^H``03oj^H``Co/Ik500?o`l?JolC5f_o4aMX0
0oo4aMX3ol3li`03ol;gk_n8QLWoR8G900;oR8G90on8S=05ohVEf@CoRYoR0on;Z>P00ol0003oRjSX
ohb_kP03ohb_kP;oSKC`0_nBYN85oi6Yi`CoSjgZ1?n>/>dFooooo`03o`000?oooooooooo03Wooooo
000Rooooo`05ogMgMonHV9SooooooiRHV?mgMgL04?ooool3o`0003Wooooo0_nKO;44oiUh[PCoUgF[
0onFLjT4oiAaY`CoU6nV1?nCKZD2oi9]Y@03ohiSVon?Hi_oSf>K00;oSf>K1?n@I9/4oi1UW0CoTFJL
0onBIid5oi9XWP?oTf^P00?oVFfNoi]`X?nKL:000_nKL:04oiecX`GoW7JV00CoVWN[ojB1[_nTPJko
Y86^1OnLO[84oi=k]@?oSGRg1?n:M[L5ohmi]`CoU7fg00?oVh:gojBA`_nTTL800_nTTL84oj^H``?o
/Ik50oo3`mX3olC5fP?o`?cW0on9P<<3ohR5b@CoR8c@1?n9UMT5ohZOhP;oRjSX00?o0000oiFJe_nD
X=`00onDX=`5oi:UhPGoTJWW0on?[NX2ohj`k@?oU:kY5?ooool2o`0003_ooooo000Rooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03_ooool2o`0003Wooooo00?oWH6doi]l/OnKO;400_nKO;44oiUh[PCo
UgF[0onFLjT5oiAaY`?oU6nV0onCKZD01?n>HY_oSV>KohiSVon>Hi/4ohmSV`CoT6BK1?n@II`4oi5V
W0?oTVNM1OnBJ9h2oi=[X0;oVFfN1?nKL:04oiecX`GoW7JV1OnTPJh4oian/PCoTg^e1?n=N;L4ohYf
]`CoSgVg0_nDOKL2oiV9`@GoY9721On[V<<00onaW/Go`l?Jol?3fP03ol?3fP04olC5f_o0o>Oo`?cW
ohen_PCoRH331?n8QLT4ohR<d0CoRIGI0_n:Wn82oiJCcP;oUI[F00?o0000oiFJe_nEV]H01?nDX=`5
oi:UhP;oTJWW0_nGXM`4oiJWhPGoU:kY5Oooool00ol0003oooooooooo`0hooooo`00<_ooool5o`00
03Sooooo0_nMPK@5oi]l/@?oVGR^1?nGMJ/4oiIcZ@CoU76W0onDKjH01?nCKZGoSV:KohiRVon>HY/3
ohiSV`CoSf>K1?n@I9/4oi1UW0CoTFJL1?nBIid4oi9XWP04oi=[X?nIKIkoVFfNoiU]WPGoVg2P1?nM
Lj<3oiafYP03ojR1Z_nTPJkoY86^00?oY86^1?nLO[85oi=k]@?oSGRg1?n:M[L2ohmi]`;oTHC11OnI
RL44ojBA`PCoZiS300?o_[kIol?3f_o3`mX00oo3`mX2okSlh@?oSGjn1?n9P<<4ohR5b@;oR8c@0_nD
Q;l4oiF;a`GoUY?>0_l00002oiFJePGoU:3L0_nBYN82oiVLe@GoUj7L1?nFYn82oiB^j@;oW[;V5_oo
ool00ol0003oooooooooo`0gooooo`00<?ooool2o`0003[ooooo0_nOQKP4oif1]0CoVgba0onIN:h4
oiMeZ`CoUW>Y1?nDLJL2oiA_YP03oheRVon>HY_oSV:K00;oSV:K1?n>Hi/3ohmSV`CoT6BK1?n@II`4
oi5VW0CoTVNM0onBJ9h00onGJigoVFfNoiU]WP03oiU]WPCoVg2P1?nMLj<2oiafYP?oZ86Z1?nTPJh5
oian/P?oTg^e00CoVH[3ohj2`_n>P/;oSX;21?n;P<85oi64`@CoVHW11OnTTL800on[V<?o_[kIokjn
f@02okjnf@?o`l?J0_nho>400onBOk_oSGjnohen_P02ohen_PCoRH330_n8QLT00onCO[WoU8BooiB4
_`03oiB4_`CoUH_700KoUY?>o`000?l0003o0000oiFJe_l00003oiFJeP;oU:3L0_nKUll4oiVLe@Go
Uj7L0_nFYn82oinZgPGoW[;V5Oooool00ol0003oooooooooo`0gooooo`00;Oooool3o`0003Wooooo
00?oXHRjoin5^?nOQKP00_nOQKP4oif1]0CoVgba0onIN:h5oiMeZ`?oUW>Y0_nDLJL2oheSW0?oSF:K
1?n>HY/4ohiSV`?oSf>K1?n@I9/4oi1UW0GoTFJL0onBIid01?nBJ9koUf^MoiM[WOnGJid5oiU]WPCo
Vg2P1?nMLj<00onLMZKoZ86ZojR1ZP02ojR1ZPGoY86^1?nLO[800onCNkGoVH[3oiV:``02oiV:``?o
SX;21?n;P<84oi64`@CoVHW11?nTTL800ond]][o_[kIokjnf@04okjnf@03ol?3f_nho>7o^?cQ00;o
TWnk0_n=O[h2oi9e[`CoTWRc1?nCO[T4oiB4_`;oUH_70ol00004oiJCcP04oiFJe_l0003oW9?9oibC
b@GoViO?1?nIW=D3oiNQg003oj2SeonOZ]koWj[N00?oWj[N1OnN/^HEooooo`03o`000?oooooooooo
03Kooooo000/ooooo`;o0000>_ooool2oj68^PGoWhFh0onMPK@4oi]l/@CoVGR^1?nGMJ/2oiIcZ@03
oheSWOn=HicoSF>L00;oSF>L0on=HY/4ohiRV`CoSV>K0on?Hi/4oi1TV`CoT6FL1OnAIY`2oi9WW@03
oiEXW?nGJigoUf^M00;oUf^M1OnIKIh4oi]`X0?oWG>S00?oZGnWojR1Z_nXPJX00onXPJX5ojB1[P;o
W7jb0_nWU<45oiV:``?oSX;21?n;P<84oi64`@GoVHW100?oY972okBff_nd]]X00_nd]]X4okjnf@;o
/?_N0_nBOk/2oi=c[0CoTWF_1OnBN;<3oi=n^@?oU8Bo0ol00003oiF;a`;oUY?>0_nNS/<2oibCb@03
o`000?nLTlWoW9?900CoViO?1?nIW=D00onGXMcoX:?Goj2Se`02oj2Se`GoWj[N0_nN/^H3ojVhi1Go
oooo00?o0000ooooooooool0=Oooool002cooooo0ol0000gooooo`03oj:;^onQR;[oXHRj00;oXHRj
1?nOQKP3oif1]0GoVgba0onIN:h2oiMeZ`;oSFBN0on=Hid4oheSW0CoSF:K0on>HY/4ohiSV`CoSf>K
0on@I9/5oi1UW0CoTFJL00?oTVNMoiEXW?nEJ9`01OnGJid4oiU]WPCoVg2P0_nMLj<2ojUoY`GoZ86Z
1OnTPJh5ojND`@CoVH[30on>P/84oh^0`PGoTHC10onIRL400onUZm_o];KJokBffP04okBffP05okjn
fOn`nmko/?_NoiN1^_nDLZX01?nCLj`5oi9e[`CoTWRc0onCO[T3o`0000;oU8Bo0_nERlL2oij:_PGo
WXk30_nLTlT00ol0003oW9?9oi^Gc`04oi^Gc`;oVIcE00?oXIgAoj2SeonPXmL00onPXmL4oinZgP03
ojV`gOnY^>CoZKST00CoZKST5?ooool00ol0003oooooooooo`0eooooo`00;?ooool01?l0003ooooo
o`000?l0000dooooo`CoXX^k0onQR;X4oin5^0CoWH6d1?nKO;42oiUh[P03oheVX?n=I9koSFBN00;o
SFBN0on=Hid4oheSW0CoSF:K0on>HY/4ohiSV`CoSf>K1?n@I9/4oi1UW0?oTFJL00CoTfNKoiEXW?nE
J9coUFRL1OnGJid4oiU]WPCoVg2P00?oWG>SojUoYonYOjL00_nYOjL4ojR1ZPCoY86^0_ngWKh4ojND
`@GoVH[30on>P/84oh^0`PCoTHC100?oVHW1ojF[fonUZm/00_nUZm/4okBffP;oX_KR00CoUG:YoiAb
Z_nDLZ[oU7:Z1OnCLj`4oi9e[`CoTWRc0ol000001OnCO[WoU8BooiB4_onDQ;ooWHFi00GoWXZn1?nN
S/<2oibCb@03o`000?nLTlWoW9?900;oViO?0_nRVL/4oj6Md@GoX:?G00?oWj[NojV`gOnY/=d00_nY
/=d4ojVhi003ok;0i?oooooooooo017ooooo00?o0000ooooool000002?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`06Oooool002cooooo
0_l00002ooooo`03o`000?oooooooooo02oooooo00?oXXZkoj:;^onRRk/00onRRk/3oj68^PGoWhFh
0onMPK@2oi]l/@;oSVRS0on=IZ04oheTWPCoSF>M0on=Hi`4oheRV`CoSV:K0on>Hi/4ohmSV`CoT6BK
1?n@II`01?nAIYcoTfNKoi=WVonCIi/4oiEXW0CoUf^M1?nIKIh4oi]`X0GoZGnW1OnXPJX2ojB1[P?o
]ifn1?nWU<45oiV:``?oSX;21?n;P<82oi64`@;oUj3J1OnUZm/3okBffP;oX_KR0_nELZT4oiAbZPCo
Tg>/1?nBMJl01OnBN;?o0000o`000?l0003oTWRc00?oTgji00?oU8Booif5^OnMQKT00_nMQKT4oij:
_PCoWXk30onLTlT00ol0003oY9K6oj:Ib`03oj:Ib`GoXIgA0_nPXmL2ojVZe`KoZK3M00?oZKSTok;0
i?nb`>@00_nb`>@Eooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q01Wooooo000[ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0:oooool00onRR;WoXXZkoj::^`02oj::^`CoXX^k1?nQR;X4
oin5^0;oWH6d00?oSfbVohiXXon>J:<00_n>J:<3oheVX0CoSFBN1?n=Hid3oheSW0CoSF:K1?n>HY/3
ohiSV`CoSf>K1?n@I9/3oi1UW003oi9VVonCIi_oTfNK00;oTfNK1?nEJ9`4oiM[W@GoVFfN0onKL:05
ojUoY`GoZ86Z00?oY86^okNM__ngWKh00_ngWKh5ojND`@;oVH[30_nIX]/3ohbHfPCoRIOJ1OnGX=X5
ojF[f`03okBff_nRm^;oX_KR00CoUG:Y0onDLZX4oi=c[0?oTWF_0_l00004oi9h/`;oTgji00?oW82d
oif5^OnMQKT00onMQKT4oij:_PGoWXk300GoW9?9ojBFa_nTU/Ko0000ojBFaP04oj:Ib`?oXIgA00?o
ZZGBojVZeonYZ]L00onYZ]L4ojV`g@03ok:lhOnb`>Co//3T00?o//3T5Oooool00ol0003ooooooooo
o`05ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001Wo
oooo000[ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:Oooool3oj:8^@?oXXZk
1OnRRk/3oj68^P;oWhFh0_nBLJX3ohm/YPCoSVRS1?n=IZ03oheTWPCoSF>M0on=Hi`4oheRV`CoSV:K
1?n>Hi/3ohmSV`CoT6BK00CoT6FLoi9VVonBIY_oTVJK1?nCIi/4oiEXW0CoUf^M1OnIKIh2oi]`X0;o
Z7fU1?nYOjL4ojR1ZP03ol6S_?ngWKko]ifn00Co]ifn0onWU<400on^/M[oVJ;KoiVRf`03oiVRf`?o
S9SJ1?n9UmX5oiNPfP;oYJ_K0on=k>d2oiMcZ@CoUG:Y0onDLZX4oi=c[0?o00000_nBMJl3oi9h/`03
oi]k[onLP;CoW82d00;oW82d1?nMQKT5oij:_P;oWXk30_nUTl83ojBFaP03o`000?nTU/KoXYW;00?o
XYW;00?oXIgAojZUd_nZYM800_nZYM85ojVZe`03ojV`gOnb_>7o/[cQ00;o/[cQ0onb`>@2okS8iaGo
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRH
V?ooooooV9RHob4Q8@0Iooooo`00:oooool3o`0000Gooooo00?o0000ooooooooool09_ooool00onQ
Q[OoXXRioj:8^@02oj:8^@?oXXZk1OnRRk/2oj68^P03oiIg[_nBLJ[oTW6Z00;oTW6Z0on?K:H4ohiX
X`CoSFJP0on=I9h4oheSW@CoSF>L0on=HY/4ohiRV`CoSV>K0on?Hi/3oi1TV`03oi5UVonBIY_oTVJK
00;oTVJK1?nCIi/4oiEXW0CoUf^M1OnIKIh01?nKL:3oZ7fUojQmYOnXOJD5ojUoY`;oZ86Z0oo1Xk`5
okNM_P03ojND`On^/M[o[[7J00;o[[7J1?nIX]/3ohbHfPGoRIOJ0_nGX=X4ogWNm`03ohg/kOnGLjWo
Ug>Y00;oUg>Y1?nELZT3oiAbZP05oi=c[?l0003o0000o`000?nCLj`01?nBMJl01?nBN;?oVg^_oi]k
[onKNjl4oib0]0GoWHFi0onNR[h00onWTKkoYI?2ojFC`P03ojFC`P?oY9K600Go0000oj:IbonRVL_o
XYW;oj^RcP05ojZUdPCoZJ[G00?o/kWMok:lhOnb_>400onb_>400onb`>Co^<SWokS8i`03okS8iaGo
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEE
EOl0003o410@olc<c00Iooooo`00:oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02?ooooo0onQQ[L4oj:8^@CoXXZk0onRRk/01?nJO;7oUWN^oiIg[_nFMjh4oi9aZPCoSfbV0on>J:<4
oheVX0CoSFBN0on=Hid4oheSW0?oSF:K1?n>HY/4ohiSV`?oSf>K00CoT6BKoi5UVonAII_oTFFK1OnB
IY/3oi=WV`CoUFRL1OnGJid3oiU]WP03ojAiY?nXOJGoZ7fU00;oZ7fU1OnYOjL00onXPJ[o`J>lol6S
_002ol6S_0Co]ifn00?oa/7Fojjaf_n^/MX00on^/MX5oiVRf`?oS9SJ0_n9UmX4of79n`;oNMkg0onI
M:P4oiMcZ@CoUG:Y00CoU7:Zo`000?l0003o00001?nCLj`2oi9e[`;oVGN[1OnKNjl3oib0]0GoWHFi
00?oWXZnojNA__nWTKh00_nWTKh4ojFC`PCoY9K600?o0000oj:Ibon[X/h00_n[X/h5ojZUdP03ojVZ
eonc^Mgo/kWM00;o/kWM0onb_>42okW;j0Co^<SW00?o]lcZooooooooool04oooool00ol0003ooooo
ooooo`03ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Kooooo`00
:oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo023ooooo00?oXHBeoj66]onQQ[L0
0_nQQ[L5oj:8^@?oXXZk00CoXX^koiYl/OnJO;7oVWba1?nFMjh3oi9aZPCoSfbV0on>J:<4oheVX0Co
SFBN0on=Hid4oheSW0CoSF:K0on>HY/4ohiSV`;oSf>K00?oT6BKoi5UVonAII/00_nAII/5oi9VV`?o
TfNK1?nEJ9`5oiM[W@;oVFfN0_nTNJ@4ojQmY@GoZGnW1Oo1Xk`3okNM_P?oa/7F1On^/MX2oiVRf`Co
O=3o1?mWa_h2of79n`?oVWFX0onIM:P4oiMcZ@;oUG:Y0ol00003oiAbZP?oTg>/00?oUg>XoiUgZonI
Mj/00_nIMj/5oi]k[`CoW82d0onMQKT00onXSk_oYi6nojNA_P03ojNA_PGoYI?20_nTU/H2ojbObP04
o`000?n[X/koZj;>oj^RcPCoZZGB00?o];OKok>igOnc^Md01?nc^Md00onb_>7o^L_XokW;j002okW;
j003okS8iongc>[o]lcZ00;o]lcZ4oooool3o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`03omgMgOl@413oV9RH01_ooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool07_ooool3oj64]@CoXHJg1?nRR;T2oj::^`03oij1/_nJO;7oVWba00?oVWba0onFMjh3
oi9aZPCoSfbV1?n>J:<3oheVX0CoSFBN0on=Hid4oheSW0CoSF:K0on>HY/4ohiSV`?oT6BK1OnAII/4
oi9VV`CoTfNK0onEJ9`5oiM[W@03oiU]W_nTNJCoY7VT00;oY7VT0onXOJD5ojUoY`03olNX^oo1Xkco
`J>l00?o`J>l00?o]ifnolK1e_o6`MH00oo6`MH2ojjafPCoW^Cl0_mld?l2oin7^P03oj><^onJMJSo
VWFX00KoVWFX0onIM:P3oiMcZ@?o00000onELZT3oiAbZP04oi=c[?nGLjSoUg>XoiMcZ0GoVGN[1?nK
Njl4oib0]003oif5^OnXSk_oZ8nk00;oZ8nk1?nWTKh4ojFC`P03ojjOb?n/Wl[o[9o:00;o[9o:00?o
0000oj^Rc_n[X/h00_n[X/h00onZYM;o];OKokBgf`02okBgf`Co/kWM00?o^/kYokW;j?nibnP00_ni
bnP2okOCkPGo]lcZ5Oooool02Ol0003oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`04olc<c?m4A4Co0000oa0@41Wooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool01?ooool3o`0000[ooooo00?o0000ooooooooool06_ooool2
oj64]0CoXHBe1?nQQ[L3oj:8^@04oj63/_nNPK;oWX6boij1/PGoVWba0onFMjh4oi9aZP?oSfbV1?n>
J:<3oheVX0CoSFBN1?n=Hid3oheSW0CoSF:K0_n>HY/00on=HY_oSV>KohiSV`02ohiSV`?oT6BK1OnA
II/4oi9VV`CoTfNK1?nEJ9`3oiM[W@03oj5gXonTNJCoY7VT00?oY7VT1?nXOJD3ojUoY`;oajRk1?o1
Xk`00ooEcmCoa/7FolK1eP03olK1eP?o_OS^0_nNi?`3oiV1^0;oWhNj00?oVGBXoiYeZ?nJMJP01onJ
MJP3oiUdZ0?o00000_nGLjT4oiEbZ@;oU7:Z00?oUW2UoiMcZ?nGLjP00onGLjP4oiUgZ`GoVg^_0_nL
P;@00onXS;SoZ8nkojR?^`03ojR?^`GoYi6n00?oYI?2ojjOb?n^WlP00_n^WlP4ojbObP04o`000?n[
X/koZj;>okFffPKo];OK00?o/kWMok[>jOnjc^T00_njc^T00onibnSo]m?^okOCkP03okOCkP;o]lcZ
0_nacNhEooooo`03o`000?oooooooooo02oooooo0008ooooo`Ko00000_ooool01Ol@413ooooooooo
oooooooo410@00_ooooo1Ol00005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
5_ooool6oj64]0?oXHBe1?nQQ[L01?nRR;WoXH>boj63/_nQPk84oij1/PCoVWba0onFMjh4oi9aZP?o
SfbV1?n>J:<4oheVX0?oSFBN1?n=Hid3oheSW0CoSF:K00?oSV:KoheRVon=HY/01?n>Hi/4oi1TV`Co
TFFK1?nBIY/4oi=WV`CoUFRL0_nGJid2oj5gX`GoY7VT1?nXOJD2ojUoY`?oajRk0oo1Xk`3omG?e0?o
a/7F0onmn>h2oi=h/`?oVH6h00CoV7:VoiUdZ?nIM:SoVGBX2OnJMJP00onIM:So0000o`000005oiMc
Z@?oUG:Y00?oUFjSoiI`YOnFL:D00_nFL:D4oiMcZ0CoVGN[1OnKNjl01?nLP;CoZ8bhojR<^?nXS;P4
ojR?^`CoYi6n00?o/J37ojjOb?n^WlP00on^WlP4ojbObP03oj^Rc_l0003o]KKJ00;o]KKJ1?nd]m/0
0onke>co^/kYok[>j@02ok[>j@;o]mcc1?ngdnh00on_eoCo/Lg^ok7=kP03ok7=kQGooooo00?o0000
ooooooooool0;_ooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgo
ooooo`0000Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Dooooo`OoXHBd1?nQ
Q;D2oj66]`03oj:3/_nQPk;oXH>b00?oXH>b0onNPK84oiYl/@?oUWN^1?nBLJX4ohm/YP?oSVRS1?n=
IZ03oheTWPCoSF>M0on=Hi`2oheRV`;oRf6K0on=HY/4ohiSV`CoT6BK1?nAII/4oi9VV`CoTfNK1?nE
J9`01?nGJigoXGNSoj5gXonQMj<5ojAiY0CoZ7fU00?oZGnWolNX^oo7Z;/00oo7Z;/00oo1XkcoeLoD
omG?e003omG?e004olK1e_nmn>ko_OS^ohma[0?oTgRc00CoVH6hoiQbY_nHLZKoV7:V1?nIM:P6oiYe
Z0?o00000onIM:P4oiMcZ@04oiEbZOnEKZ?oUFjSoiE^X`CoUW2U1?nGLjP4oiUgZ`CoVg^_00?oZ8Zf
ojR<^?nXS;P00_nXS;P5ojR?^`;oYi6n0onaX<L4ojjOb0?o[9o:00?o]kSJokFff_l000001?ne]]X0
0ond]m_o^mC/ok_Dk002ok_Dk003ok[>jOngg??o]mcc00?o]mcc00?o]m?^ojoGm?n_eo@00_n_eo@2
ok7=kP?oYlO`5Oooool00ol0003oooooooooo`0]ooooo`004?ooool01Ol0003ooooooooooooooooo
000000_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo017ooooo00?oXXJfoj64]?nQQ;@01_nQQ;@4oj64]@03oj66]onRPk;oXX>b00GoXH>b0onN
PK85oiYl/@?oUWN^0onBLJX4ohm/YP?oSVRS1?n=IZ03oheTWP;oSF>M0_n9H9`3ohYPV`CoRf6K0on=
HY/4ohiSV`CoT6BK1?nAII/4oi9VV`CoTfNK0onEJ9`00onMM:CoXGNSoj5gX`03oj5gX`CoY7VT1?nX
OJD6olNX^`GoeLoD0_nloMH3ohma[0;oTgRc00?oUg2UoiQbY_nHLZH00onHLZH3oiUdZ0?oVWFX0ol0
0003oiYeZ0?oVGBX0_nGLjT2oiA/X@CoUFjS1?nFL:D4oiMcZ0GoVGN[0_nKNjl2ojR:]PCoZ8bh1OnX
Sk/00onWTKko/J37ok6Pa`02ok6Pa`Go[Yo800Ko[9o:okNhf_ng^=[o]kSJokFff_l00002okFffP;o
_=c`0onke>`3ok?Um`;o]mcc0onZhOX3ojoGm0;oY<kf1OnWao0Dooooo`03o`000?oooooooooo02go
oooo000@ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`;o
00003oooool2o`0000oooooo0onRQ[H9oj64]0;oXHBe00?oXX6aoj:3/_nRPk800_nRPk84oj63/PCo
WX6b1?nJO;43oiIg[P?oTW6Z1?n?K:H3ohiXX`;oSFJP0_n6Gih3ohQOW0CoRF2L0on:H9/4oh]QV`Co
SF:K0on>Hi/4oi1TV`CoTFFK1OnBIY/3oi=WV`;oUFRL0_nMM:@5oj5gX`GoY7VT0onXOJD00oo8[;go
ajRkolNX^`03olNX^`04on3Ne?oEcmCoeLoDomG?e0;o_?gF0on?LJ`01?nGKj;oUg2UoiM`YOnGL:D5
oiQbYP?oVGBX0ol00006oiYeZ0;oVGBX00?oUF^PoiA/XOnDK:400_nDK:45oiE^X`CoUW2U0onGLjP5
oiUgZ`03oi]k[onXR[KoZ8Zf00;oZ8Zf1?nXS;P3ojR?^`03okBSaonaX<Oo/J3700?o/J371?n^WlP0
0onj_=_o]kSJokNhfP03okNhfP03okFff_l0003o_=c`00?o_=c`00Co^mC/ok?UmonciOOo/nGg0_nM
j?/5oj[QnP03ojoGm?nTc_KoY<kf00;oY<kf0_nWao02oinokaGooooo00?o0000ooooooooool0;?oo
ool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0:ooooo`03ojB:^?nRQ[KoXXJf00?oXXJf2?nQ
Q;@00onQQ;GoXX6aoj:1/@04oj:3/PGoXH>b0onNPK82oiYl/@;oTGB_0on:KJ/3ohEVY`CoQ6:S0on4
H:04ohIOWP?oR5nL1?n9H9`3ohYPV`CoRf6K1?n=HY/3ohiSV`CoT6BK1?nAII/5oi9VV`?oTfNK00Co
UFRLoiedY?nMM:CoWGBT1OnQMj<5ojAiY0;oZ7fU0oo8[;d3olNX^`?oh=kD00GoeLoDokcme_nBKZKo
TVjVohma[003oiM_XPCoUg2U1?nHLZH3o`0000WoVWFX00?oVGBXoiE[X?nEJj001?nDK:45oiE^X`Co
UW2U1?nGLjP3oiUgZ`03ojN8/onXR[KoZ8Zf00?oZ8Zf1?nXS;P00onXSk_o]:?7okBSa`02okBSa`Go
/J3700?o[Yo8okZlfonj_=/00_nj_=/3okNhfP?o^^Kd00?o0000okcLl?nYk_P00_nYk_P00onciOOo
WNSkoigXn`03oigXn`;oZ^7j0onNeO/2ojC>mP;oW<7b1OnO_nlCooooo`;o0000;_ooool0013ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`08ooooo`?oY8Zh1?nRQ[H7oj64]003oj20/?nRPK7oXX6a00;o
XX6a0onRPk85oj63/P;oWX6b00?oVWbaoi5d[onAM:l00_nAM:l3ohY]Z`?oQFJW1?n4HZ<3ohAPX0Co
QUnN0on8Gi`4ohUPW0CoRV2K0on;HI/4oheRV`CoSV>K0on@I9/5oi5UV`CoTVJK0_nCIi/00onKLZCo
WGBToiedY003oiedY0CoXGNS1OnTNJ@00onXOJGob:bmolR/_@02olR/_@;oajRk1?oPg]@01?nDiJ7o
TVjVoi9^Y_nKKj04oiM_XPCoUg2U00CoV7:Vo`000?l0003o00000onIM:P7oiYeZ0;oUF^O0onEJj05
oiA/X@CoUFjS1?nFL:D4oiMcZ003oiUgZonWR;?oYhRc00;oYhRc1?nXR[H4ojR<^0Go]:?71?naX<L0
0onma=oo^[cKokZlf`03okZlf`03okNhf_nji_Co^^Kd00;o^^Kd00CoT^k^o`000?nYk_SoZNkh1?n3
i_42oigXn`?oU=Wn0_nNeO/3oiW2m0CoW<7b1?nO_nlEooooo`03o`000?oooooooooo02_ooooo000Y
ooooo`;o00005?ooool00ol0003oooooooooo`05ooooo`03ojJ>^onTR[SoY8Zh00;oY8Zh1?nRQ[H5
oj64]0?oX82`1?nRPK44oj:3/P?oXH>b00CoX86aoiYl/OnJO;7oVWba1?nAM:l4ohY]Z`?oQFJW0on4
HZ<3ohAPX0CoQUnN0on8Gi`4ohUPW0CoRV2K0on;HI/4oheRV`CoSV>K0on@I9/5oi5UV`CoTVJK00?o
TfNKoi]bY?nKLZ@01OnMM:@4oj5gX`GoY7VT1_o8[;d01_o7Z;_oh=kDon3Ne?oPg]CoU>FQoi9^YP?o
VfnP1?nGKj82oiM`Y@?o00000onHLZH4oiUdZ0?oVWFX1OnEJil4oiE[X0CoU6bQ1?nEKZ<5oiI`Y@;o
Ug>X00?oYXFaojN8/onWR;<00onWR;<5ojR:]P;oZ8bh0_nhZ<T5okBSa`03ok6Paonma=oo_LCO00;o
_LCO0onj_=/3ok;am@07ok[Vm?nBk^koT^k^oi;^k_mHd]?o0000oeSBd`02oh?Vl@?oQ=[n0_nDfOh3
oiK1m@GoVL;d1?nL`O82oinok`;oW;W]5Oooool00ol0003oooooooooo`0Zooooo`00:Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo0onVS[/3ojB:^0GoXXJf0_nQQ;@00onN
Ok7oX82`oj20/002oj20/0CoXX6a1?nRPk801?nQPk;oX86aoj21/OnPPK44oiYl/@?oTGB_1?n:KJ/3
ohEVY`?oQ6:S1?n4H:03ohIOWP?oR5nL1?n9H9`4ohYPV`?oRf6K1?n=HY/4ohiSV`CoT6BK1?nAII/3
oi9VV`04oiQaY?nKLZCoVg:Toi]bY0GoWGBT1OnQMj<3ojAiY0;ob;741Oo8[;d2on7bf@03on3Ne?nF
KJ;oUVfR00CoVfnP1?nGKj82o`0000;oUg2U1OnHLZH3oiUdZ003oiYeZ?nEJiooUF^O00GoUF^O1?nE
Jj04oiA/X@CoUFjS1OnFL:D00onGLjSoYXFaojJ5/@05ojN8/`GoZ8Zf00CoZ8bhokRXbOnhZ<Wo^:S9
1?ndXlL00oo1d>Ko_LCOokg4g`04okg4g`06okZlfonblOGo/_7eok;amOmTfLco00001?mPc_L01?mb
e__o0000og;Fnombe_/2ohCJoP;oT[cd1OnF`OD2oiW2m0;oV[CZ1?nK]n`5oibikACooooo00?o0000
ooooooooool0:_ooool002Wooooo00?o0000ooooooooool05Oooool01?l0003ooooooooooonYTkl4
ojJ>^`CoY8Zh1?nRQ[H00onQQ;CoWWnaoiio/@04oj20/0GoXX6a0_nRPk800onSP[7oX86aoj21/@03
oj21/@?oVWba1?nAM:l3ohY]Z`?oQFJW0on4HZ<4ohAPX0?oQUnN0on8Gi`4ohUPW0CoRV2K1?n;HI/3
oheRV`CoSV>K1?n@I9/4oi5UV`04oi9VVonHLJCoV76ToiQaY0CoVg:T1?nMM:@5oj5gX`;oY7VT0oo8
/L@4olR/_@;ohO;I00CoVVjOoiI]X_nFKJ;oWW6N1OnKKj03o`000004oiM_X_nGL:GoUg2UoiM`Y@Go
V7:V0_nIM:P00onFJikoUF^OoiE[W`07oiE[W`?oUF^P1?nDK:45oiE^X`?oUW2U00?oYH>`ojJ5/OnV
QK400_nVQK45ojN8/`?oZ8Zf00?o_K3=okRXbOnhZ<T00onhZ<T00ondXlOo`M3Vol7@iP02ol7@iPCo
_LCO0_nIl^P00onblOGoF<OgoeS7m`02oeS7m`;oH<kg0_n?[>T2oi2fl003o`000?n@]_3oT[cd00Co
T[cd0_nF`OD2oiV_iPGoV[CZ1?nK]n`2oibik@?oW[OZ5?ooool00ol0003oooooooooo`0Yooooo`00
:Oooool00ol0003oooooooooo`0Fooooo`CoZI>o0onVS[/4ojB:^0;oXXJf0_nMP;<4oiio/@CoX82`
1?nRPK400onRPk;oXh:aoj>2/@05oj21/@?oVWba1?nAM:l3ohY]Z`?oQFJW1?n4HZ<3ohAPX0?oQUnN
0on8Gi`5ohUPW0?oRV2K1?n;HI/3oheRV`CoSV>K1?n@I9/3oi5UV`03oiM`Y?nHLJCoV76T00;oV76T
1?nKLZ@4oiedY0GoXGNS00?oY7VTolRaa?o8/L@00_o8/L@3olR/_@;ohO;I0_nJKYl00onFKJ;oWW6N
oiiaWP02oi]_X0?o00001?nGKj84oiM`Y@CoV7:V00?oVGBXoiI[W_nFJih02OnEJil3oiE[X0CoU6bQ
1OnEKZ<2oiI`Y@;oYH>`1?nVQK45ojN8/`03ojR:]_nm/<go_K3=00;o_K3=1?nhZ<T00oo2h^oo`M3V
ol7@iP03ol7@iP04okg4gonIl^SoVO;XoiWbj0;oTYCB1OnAX=l4ohn/j@04oi2fl?l0003oT;K`oi2f
l0;oT[cd0_nIZN45oiV_iPCoV[CZ0_nK]n`3oifai@GoW[OZ5?ooool00ol0003oooooooooo`0Xoooo
o`00:Oooool3o`0001Cooooo00?o[9S3ojVC_onYTkl00onYTkl4ojJ>^`;oY8Zh00?oWH:eoif0/onM
P;<00_nMP;<4oiio/@CoX82`0onRPK400onSP[3oXh:aoj>2/@02oj>2/@CoX86a0onJO;44oi5d[`?o
RVf[0on5IZL4ohARX`?oQ62P1?n6Gih3ohQOW0CoRF2L0on:H9/4oh]QV`CoSF:K0on>Hi/4oi1TV`04
oi5UVonGL:CoUg2ToiM`Y0CoV76T1?nKLZ@5oiedY0?oXGNS00?oa[S=olRaa?o8/L@01?o8/L@00oo8
[;gohO;Ion7bf@03oiY^W`;oWW6N0ol00003oi]_X0CoUfnR1?nGL:D3oiQbYPCoUV^N2OnEJil3oiE[
X0GoU6bQ1?nEKZ<00onFL:GoYH>`ojF3/002ojF3/0?oYXFa1?nWR;<00oo2^m?o_K3=okf`c@03okf`
c@?o^:S90oo2h^l2ol7@iP;oH=>h0onER/H4oi:DdPGoTJ3O0_n?[>T01OnKV];oVZ;JoiZRf_l0003o
VZ;J00GoVJWQ1OnI[nH2oiZdjP03oij[h?nM/NGoWK7U00CoWK7U0_nN]nX2oj>ij1?ooooo0_l0000Z
ooooo`00:Oooool00ol0003oooooooooo`0Cooooo`?o[9S31?nYTkl4ojJ>^`03ojB:^?nMP[GoWH:e
00GoWH2c0onNOk44oj20/0;oXX6a0_nSP[04oj>2/@CoX86a1?nJO;43oi5d[`CoRVf[0on5IZL3ohAR
X`?oQ62P1?n6Gih3ohQOW0CoRF2L0on:H9/4oh]QV`CoSF:K0on>Hi/2oi1TV`;oU6jT1?nGL:@4oiQa
Y0CoVg:T1OnMM:@2oj5gX`?oa[S=1?o8/L@2olKoe@04oie_WOnJKYooVVjOoiY^W`?o00000_nNLIh4
oi]_X0CoUfnR1?nGL:D00onHLZKoUV^NoiI[WP05oiI[WPSoUF^O0onEJj05oiA/X@?oUFjS00?oXh6_
ojF3/?nUPk000onUPk04ojJ5/@;oYhRc0oo2^m<5okf`c@05okRXbOo2h^oo`^;_ol;Rkol000001?nG
P[/3oiF:aPGoTYCB0_nAX=l2oifCb@CoVi[B0_nJX]X00ol0003oVZ;JoiVYh@04oiVYh@;oVJoV0_nO
YMX4oij[h0CoWK7U00?oY;?Toj>ij?nS^NP00onS^NPDooooo`03o`000?oooooooooo02Oooooo000>
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00005ooooo`03o`000?oo
oooooooo01;ooooo00?o[Yk7ojbH`on/V<<00_n/V<<5ojVC_`;oYXjk00?oWXFhoif2]OnMP[D00_nM
P[D4oif0/`?oWWna1?nPP;000onRPK7oXh:`oj>2/002oj>2/0?oXh:a1OnPPK43oiYl/@?oTGB_1?n:
KJ/3ohEVY`?oQ6:S0on4H:04ohIOWP?oR5nL1?n9H9`4ohYPV`?oRf6K1?n=HY/2ohiSV`03oi9]YOnD
KZCoU6jT00;oU6jT1OnGL:@4oiQaY0?oVg:T1OnMM:@00onQMj?oa[S=olJhc@02olJhc@?ob;740_o6
omD2oie_W@?o000000?oXG:MoiiaW_nNLIh00_nNLIh4oi]_X0CoUfnR0onGL:D00onHK9koUV^NoiI[
WP06oiI[WPSoUF^O1?nEJj04oiA/X@04oiE^XonSPJooXh6_oj>1[`GoYH>`1?nVQK400onWR;?o`[_C
ol:kd`02ol:kd`Co_K3=0_nimO401?o2h^ooVGbboiUl/_nIO;84oiN2^`CoUH[60_nBU=82oin=`@Go
WI?90onKV]82oiZRfP03o`000?nJX][oVZ;J00;oVJWQ0_nOWm@5oinUfPCoWZ_P00?oWK7UojBci?nT
/n@00_nT/n@4oj>ij1Gooooo00?o0000ooooooooool09_ooool000kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000oooo
ooooool04Oooool3ojjNa`?o[9S31?nYTkl01?nORKcoWXFhoij5^?nNQKP4oif2]@CoWH2c1?nNOk42
oj20/003oj61/OnSP[3oXh:`00?oXh:`0onSP[45oj21/@;oVWba00CoUGbeohIa]?n6LKCoQW6d1?mk
I[03og=N[0?oQ6:S1?n4H:03ohIOWP?oR5nL1?n9H9`4ohYPV`?oRf6K1?n=HY/00on>Hi_oTVfUoi9]
Y@04oiA^Y0GoUg2T1?nHLJ@4oi]bY0?oWGBT00?o`/;JolJhcOo6^<d01?o6^<d00oo8/LCoa_oEolKo
e@03o`000003oiY^WonQLYgoXG:M00;oXG:M0onNLIh5oi]_X0?oUfnR00CoUg2UoiQ/W_nHK9koV6bN
2?nFJih8oiE[W`CoUF^P0onDK:400onRP:koXh6_oj>1[`03oj>1[`CoYH>`1?nVQK46ol:kd`04okf`
cOnimO7o^OGaokWel@GoVGbb1?nGP[/3oiF:aP03oj:9^_nOSL7oWhg100?oWhg11?nMTlT4oi^JdP;o
VZ;J00?o0000oj6JcOnOWm@01?nOWm@4oinUfP;oWZ_P0onU[ml4ojBci0;oXkWX0onY_NPDooooo`03
o`000?oooooooooo02Kooooo0006ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h01_ooool2o`00013ooooo00?o/JC;ojjNaon^W/L00_n^W/L4ojbH``04
ojVC_onORKcoWhVloin9_0CoWXFh0onMP[D5oif0/`?oWWna00?oX82`oj61/OnQPK401OnSP[04oj>2
/@?oX86a00CoWh>eoiEl]OnEO;GoUGbe0on6LK@4og]V/0?oLej/0omdG:P4ohAPX0?oQUnN0on8Gi`4
ohUPW0CoRV2K0on;HI/2oheRV`;oT6^U0onBKJD5oiA^Y0CoUg2T1?nHLJ@4oi]bY0;oWGBT0oo2`]X4
olJhc@04ofoCVonMKYco0000o`0000?oWFnM1OnQLYd3oiiaWPGoVfnP0_nGKj800onKKYkoV6bNoiQ/
WP02oiQ/WPSoUV^N2OnEJil3oiE[X004oiA/XOnRP:koXX2^oj:0[PGoXh6_1OnUPk02ojJ5/@;ob<_L
1?o2^m<3ohc]dP03okWelOnKNJcoVgV/00CoVGbb1OnGP[/01?nER/KoXXVjoj:9^_nRRKX4oin=`@Go
WI?90_nKV]801_nSULOoXI[=oj6JcOnQV/go0000oj6Jc@CoWioD0_nOYMX2ojJ[fPKoYJoO0_nT/n@2
ojZii@GoZKgX5?ooool00ol0003oooooooooo`0Uooooo`003_ooool01Ol0003ooooooooooooooooo
000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`0=ooooo`Co/JC;1?n^W/L2
ojbH``03oj:?`?nORKcoWhVl00?oWhVl0onNQKP3oif2]@GoWH2c0onNOk44oj61/@CoXh:`1?nSP[40
1?nPPK7oWh>eoin3]OnOPkD4oiEl]@?oQW6d0omkI[03og=N[0?oM5bX0omjGJH01?n4H:3oQUnNohIO
W_n6Gih3ohQOW0CoRF2L1?n:H9/2oh]QV`03ohiYY?n@JjGoT6^U00;oT6^U1?nBKJD4oiA^Y0CoUg2T
1?nHLJ@4oi]bY003oiedY?o2`][o`/;J00;o`/;J0oo6^<d3o`0000;oWFjL0onMKid5oj5bW@?oWW6N
1OnKKj000onGKj;oVfjNoi]^WP05oiQ/WPOoUV^N2OnEJil2oiE[X003oj5o[_nRP:koXX2^00?oXX2^
1?nSPJl5ojF3/003ojJ5/Oo8bmcob<_L00;ob<_L00Co`[_Cohc]d_n<kM;oS>gB0_nMMjL3oi]i[0Go
VGbb0onGP[/00onTQkGoXXVjoj:9^P02oj:9^PCoWhg11?nMTlT00onUT/7oXiG7oj>Ea`02oj>Ea`?o
XI[=00Go0000oj6JcOnOWmCoWioDojRWe@05ojJ[fPCoYJoO00?oZkORojZiiOnZ^ND00onZ^ND2ojVm
j0;o[L7Y5Oooool00ol0003oooooooooo`0Tooooo`003_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`0;ooooo`03okBYc_naY<_o/JC;
00?o/JC;0on^W/L00onUU<CoXXo0oj:?`002oj:?`0CoWhVl0onNQKP4oif2]@?oWH2c00CoVWjcoiio
/OnNOk7oWWna1?nQPK45oj>2/0;oXh:a00?oYHJdoin3]OnOPkD00_nOPkD4oiEl]@?oQW6d0omkI[04
og=N[0;oM5bX1?mjGJH3ogmPY@?oR5nL0_n9H9`2ohQVY0CoRfRT0on>JJ@5oi1[Y@?oTVfU1?nDKZ@4
oiM`Y0CoV76T0onKLZ@00onnc>Go`/;Jol;2fP03ol;2fP?o00001OnMKY`2oie_W@03oj9cWOnQLYgo
XG:M00?oXG:M0onNLIh5oi]_X0?oVfjN1OnHK9h7oiI[WPWoUF^O00?oUF^Poj5o[_nQOjh01OnRP:h5
oj>1[`?oYH>`00?obn7XolS;g?o8bm`00_o8bm`00ol0003oWgJToiegY`04oiegY`?oVgV/1OnIO;80
0onGP[_oY8NeojB7]@02ojB7]@?oXXVj1OnOSL401?nMTlWoYI;1ojFB`OnUT/44oj>Ea`?oXI[=00?o
0000oj^UdOnXYmD00onXYmD5ojJ[fP03ojF_gon[]n;oZkOR00;oZkOR0onZ^ND00on^`NSo[L7Yojg1
j@03ojg1jA?ooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
00Goc<c<ob4Q8Ol0003o8B4Qolc<c009ooooo`003_ooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool00oooool2o`0000_ooooo0ondZLh5ok6Tb`04ojjNaonUU<CoYIC4ojFD
a0?oXXo01?nORK`4oij5^0?oWH:e00CoWH2coiYn/onJO[?oVWjc1?nNOk43oj61/@GoXh:`00CoXh:a
ojF6]?nUQ[CoYHJd1?nOPkD3oiEl]@?oQW6d1?mkI[03og=N[0?oM5bX0omjGJH3ogmPY@?oQF>T1?n8
IZ@4oh]XY0?oSVVT1On@JjD3oi9]Y@CoU6jT1OnGL:@3oiQaY003oi]bY?nnc>Go_/cU00;o_/cU00Co
`/;Jo`000?l0003o00001?nJK9`4oie^W004oie_WOnRLigoXW>Moj9cW@CoXG:M1?nNLIh3oi]_X003
oimaW_nKKYkoVfjN00;oVfjN1?nHK9h7oiI[WPSoUF^O00?oXGn_oj5o[_nQOjh00_nQOjh4oj:0[PGo
Xh6_00?oYH>`ol_Qj?o;hNP00_o;hNP00oo8bmcoVgV/oiUn/`03oimfY0CoWGNW1?nKNJ`3oiUl/P03
ojN6/OnTQkGoY8Ne00?oY8Ne1?nRRKX3oin=`@03ojRA_OnUT/7oYI;100?oYI;11?nSULL01?nQV/go
ZjGAoj^UdOl00005ojRWe@;oYZ_J0on]]]l4oj^ghP03ojZiiOn^`NSo[/7X00;o[/7X0on]`NT2ojk5
jaCooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B402Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool2o`0000[ooooo00?o]ZoBokBYc_ndZLh0
0_ndZLh4ok6Tb`03ojRKb?nUU<CoYIC400;oYIC40onRSl05oin9_0?oWXFh0_nMP[D00onHOkKoVWjc
oiYn/`02oiYn/`CoWWna1?nQPK43oj>2/003ojJ7/onUQ[CoYHJd00;oYHJd1?nOPkD4oiEl]@;oQW6d
1?mkI[03og=N[0?oM5bX0omjGJH3ogmPY@?oQF>T1?n8IZ@4oh]XY0CoSVVT1?n@JjD3oi9]Y@CoU6jT
1OnGL:@2oiQaY0?o^=?^00Go_/cUo`000?l0003o0000ol;2fP02oi5VW0CoVVbL0onMKY`00onQLiko
XW>Moj9cW@02oj9cW@CoXG:M1?nNLIh2oi]_X0;oWg6N1?nKKYh4oiQ/WPSoUV^N1OnEJil3oj5o[`Co
XGn^1?nRP:h4oj>1[`;o`OK^0oo;hNP2oi]i[003oj5fXonOMZCoWgJT00;oWgJT1?nMMjL4oi]i[003
oiUl/_nWQ[7oYhJa00;oYhJa1?nTQkD4oj:9^P03oin=`OnXTKgoZ96m00;oZ96m1?nUT/43oj>Ea`03
ojjTc_n[YM7oZjGA00;oZjGA00Go0000ojRWeOnXYmGoZ:OEok2ggP06ojffg`;oZkOR0_n_`^P5ojk1
j003ojg1jOn^aN_o[/G[00;o[/G[5?ooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000000Wooooo000>ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo00?o0000ooooooooool0
1oooool4okJ_dPCo]:W>00?o/JC;ojRKb?nXVlP00_nXVlP3ojFDa0CoXXo01?nORK`2oij5^004oiN1
^OnHOkKoV7nfoiQo]PGoVWjc0onNOk44oj61/@03oj>2/?nVQk?oYXNc00;oYXNc0onUQ[@4oin3]@Co
UGbe0on6LK@3og]V/0?oLej/0omdG:P3ogYMYPCoOf2U0on5Hj@4ohQVY0?oRfRT1?n>JJ@4oi1[Y@?o
TVfU1OnDKZ@4oiM`Y003oiQaY?nhdnko^=?^00?o00000_nnc>D4oi5VW0CoVVbL0_nMKY`2oj5cWPCo
XW>M1?nQLYd4oiiaWP03oi]_X?nOLIkoWg6N00;oWg6N0onKKYh4oiQ/WPSoUV^N0onEJil00onQPK3o
XGn_oj5o[`03oj5o[`?oXGn^1OnRP:h2oj>1[`Co`OK^00?obn7Xoi]i[?nKNJ`00_nQMZ<4oimfY0Co
WGNW1?nKNJ`5ojN6/@GoY8Ne0_nRRKX00on/T[_oZ96mojRA_@03ojRA_@CoYI;100?oXiG7ojjTc_n^
Y<h00_n^Y<h4oj^Ud@03o`000?n`]mko/;ON00;o/;ON1?n]]]l00onaaNSo[l;Xojo2j003ojo2j0;o
[/7X0_n_b>`4ojk5j`03ojc5k?oooooooooo01;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P09ooooo`009oooool00ol0
003oooooooooo`05ooooo`;o^KGF1Onf[m82okBYcP03ojbQcOnXVlSoZ9_800?oZ9_81?nUU<@3oj:?
`0;oWhVl0_nGQ;d4oiN1^@?oV7nf1?nJO[<4oiio/@;oXH6a00?oXhJdojJ7/onVQk<00onVQk<4ojF6
]0?oWh>e0_nEO;D2oi:7a0?oMWS80omkI[03og=N[0?oM5bX0omjGJH4ogmPY@?oQF>T1?n8IZ@3oh]X
Y0CoSVVT1?n@JjD4oi9]Y@CoU6jT0onGL:@01?nbf?Co0000o`000?l00002okSCkP?oQUjL1?nAIY`4
oiY/W004oie^W?nQLikoXG>Noj5cWPCoXW>M1OnQLYd3oiiaWPGoWg6N0onKKYh4oiQ/WPSoUV^N00Co
UF^Ooj61/?nQPK3oXH6`1OnQOjl3oj5o[PGoXX2^00CoXh6_ol7fk_o1m^ko`OK^0onMMjL01?nKNJco
XGJSoj5fXonQMZ<4oimfY0GoWGNW0_nKNJ`00on[QjooYhJaojN6/@03ojN6/@GoY8Ne00CoXXVjojbB
^on/T[_o[9:k1?nXTKd3ojFB`@03ok:Vc?n^Y<ko[ZC>00?o[ZC>0on[YM400ond^]ko0000ok2ggP04
ok2ggP03ojffgonaaNSo/LGX00;o/LGX0on_`^P00on_cNoo[lS/ojo8k003ojo8k003ojk5jon/aNco
[<G/00;o[<G/5?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000002ooo
ool01Oo<c<co0000o`000?l0003oc<c<00Wooooo000Wooooo`;o00001Oooool4okVeeP?o]ZoB00?o
[jSAojbQcOn/XLd00_n/XLd4ojRKb0CoYIC40_nRSl000onJR/7oUhBmoiN4_@02oiN4_@CoUh6i0onH
OkH4oiYn/`CoWWna00?oXH6aoj>6]?nSQ[@01OnVQk<4ojF6]0;oWh>e00?oXXjooi:7a?nBQl@00onB
Ql@2ogIhb0?oFf[81?mcGZ`2ogALZ0CoNUfV0omoH:D3ohESY0CoR6JT1?n;J:@3ohiYY0GoT6^U0onB
KJD4oiA^Y004oiM`Y?nbf?Co0000o`0000;o/]Sd00?o^=?^oh9LWOn2G9d01?n6GY`3oi5VW0?oVVbL
00?oWG2Ooj5cW_nQLih00_nQLih4oj9cW@GoXG:M0onNLIh5oimaWP?oVfjN1?nHK9h7oiI[WP03oj:3
/_nQPK3oXH6`00?oXH6`1?nQOjl4oj5o[P?oXX2^0_nDlM43oiieY0?oWGNW1OnQMZ<3oimfY0GoWGNW
00CoVgV/oj^7[on[QjooZhN_1OnWQ[43ojB7]@03ok6F^on/T[_o[9:k00;o[9:k1OnXTKd01?nUT/7o
/ZK<ok:Vc?nbY/`5ojjTcP05oj^UdOnd^]ko];[NokBjg_l000000on`]mh00oncb^_o/LGXok75j003
ok75j003ojo2j?n_cNoo[lg_00;o[lg_0_n_b>`3ojc9k`Co[<G/5Oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Wooooo
000Wooooo`03o`000?oooooooooo00;ooooo00?o_;cJokVee_ni]MH01?ni]MH01?nf[m;o[jSAojnX
dOn_Z=44ojbQc@CoZ9_80_nUU<@00onLSlKoVX[1oiZ:`@02oiZ:`@?oUhBm1?nGPKT3oiQo]PCoVWjc
0_nNOk42oin4]PCoXhJd1OnVQk<2ojF6]003ojVA_?nRS[ooXXjo00;oXXjo1?nBQl@3ogIhb0;oFf[8
0_m3G/P2og=N[0?oM5bX0omjGJH3ogmPY@?oQF>T1?n8IZ@4oh]XY0?oSVVT1On@JjD3oi9]Y@;oU6jT
00CoZmWgo`000?l0003o00000_nbf?@2oh=MWP?oPUbM1?n6GY`3oi5VW0;oVVbL0_nML9l4oj5cWPCo
XW>M1OnQLYd2oiiaWP03ojAfW_nOLIkoWg6N00?oWg6N0onKKYh5oiQ/WPGoUV^N0_nRPk85oj61/0Co
XGn_1?nQOjh00onRP:koU?7AoiCad@05oiieY0;oWGNW00?oY7RRoj5fXonQMZ<00onQMZ<4oimfY0?o
WGNW00?o[hZ_oj^7[on[Qjl00_n[Qjl5ojN6/@04ojB7]OnaU[_o/IJkok6F^`Co[9:k1?nXTKd00ong
Zlgo/ZK<ok:Vc003ok:Vc0;o[ZC>0_ni`^45okBjgP03o`000?ncb^_o/l[[00;o/l[[0_naaNP3ojoB
l`?o[lg_0_n[cO85ojc9k`;o[<G/0_nX`ndBooooo`?o00001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000009ooooo`009oooool01?l0003ooooooooooooo
ool3okblfPCo^KGF00?o/[3GojnXdOn_Z=400_n_Z=45ojbQc@;oZ9_800?oX9K:oib?a_nLSlH00_nL
SlH3oiZ:`@CoUhBm1?nGPKT3oiQo]P;oVWjc00?oVH:ioin4]_nOQ;H00_nOQ;H4oj>6]0GoYXNc00Co
YHJdojVA_?nYTKcoZI6l1?nRS[l3oi:7a0?oMWS80omKJ/P3od=Nb0?oM5bX0omjGJH3ogmPY@?oQF>T
1?n8IZ@4oh]XY0CoSVVT1?n@JjD2oi9]Y@04oj;Fn_l0003o0000o`0000;oZmWg0_mmFId3ogaGW0?o
PUbM1?n6GY`3oi5VW004oiY/W?nML9ooWG2Ooie`W`CoXG>N1?nRLid5oj5bW@04oiiaW_nTMYkoY7JN
ojAfWPCoWg6N0onKKYh5oiQ/WP?oUV^N00?oY8Jdoj:3/_nRPk800_nRPk84oj61/0GoXGn_0_nQOjh2
o`0000;oX7BR1OnNMJ@00onMMjOoY7RRojAhXP05oj5fX`CoWgJT0_nMMjL2ojn:[`CoZhN_1?nWQ[40
0onhW[ko/IJkok6F^`03ok6F^`Co[9:k00?oZ96mokN[cOngZld00_ngZld3ok:Vc003okg?j?ni`^7o
^L;Q00?o^L;Q0_nd^]h2okCBl004o`000?ncb^_o/l[[ok?:j`;o[=_h1On_d_<00on_cNooZlgboj_=
lP02oj_=lP;o[<W_0_nWao05ojS3kACooooo00Wo0000ooooooooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Wooooo000Vooooo`?o00000_noa=h4okbl
fP03okVee_nb/=Oo/[3G00;o/[3G1?n_Z=42ojbQc@;oXig?1?nPU/X3oib?aP?oVX[11?nGQ;d4oiN1
^@?oV7nf00?oVWjcoiV2^OnIP[T01OnOQ;H3oj>6]0CoYXNc00?o[9:lojVA_?nYTK`00_nYTK`4oj:>
_`CoTXO40_mfN<P4oe]Zb0;o@ek80om4HL/3ogYMYPCoOf2U0on5Hj@4ohQVY0?oRfRT1?n>JJ@3oi1[
Y@04oiWAnol0003o0000o`0000?oX]Kj00CoZmWgogeIWOmmFIgoOEVM0omlEi`3ogiJW@CoQUjL0_nA
IY`00onBJIooWG2Ooie`W`03oie`W`CoXG>N1?nRLid4oj5bW@CoY7JN1?nOLIh4oi]^WPCoV6bN00Co
UV^NojB6]?nTQ[CoY8Jd1?nRPk84oj61/0GoXGn_00?oXGn^oj5eXOnPM:801?nPM:83oiieY003ojMk
Y?nTN:;oY7RR00;oY7RR1?nQMZ<4oimfY003oiegYon_RZoo[hZ_00;o[hZ_1?n[Qjl2ojN6/@?o^9jn
1?naU[/3ojbB^`03okbedongZlgo]j_=00?o]j_=00?o/ZK<okg?j?nmcnP00_nmcnP3okW2h@;o/]kf
1?ndd_000ol0003o/l[[ojcKn003ojcKn0;o[m;c0onWd_H2oj_=lP;oYLWb1OnWao02ojS3k@;oYL3]
5Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003o_lCNoko4gP03oko4gP;o_;cJ0_ne
^M`5ok:`e`;o[jSA00?oYZCDoj>MconSWLl00onSWLl3oj2FbP?oW8o61?nJR/43oiN4_@;oUh6i0_nA
P/03oiB1_0CoVH:i1?nOQ;H4oj>6]0;oYXNc0on/T[`3ojVA_0GoXXjo0_nBQl@01?nJXm_oKI?VoffC
i_m]TnH3oe]Zb0?o@ek80_m4HL/2oe=`dP03ogYMY_moH:GoOf2U00;oOf2U0on5Hj@4ohQVY0?oRfRT
1?n>JJ@01?n@JjGo0000o`000?l00002oiWAn`;oX]Kj0on2GYl3ogeIW@?oO5NL0omnFYd4ohEOWP?o
TVVO1OnML9l4oj5cWPCoXW>M0onQLYd00onWNJ7oY7JNojAfWP02ojAfWPCoWg6N1?nKKYh3oiQ/WP03
ojV<]onTQ[CoY8Jd00?oY8Jd0onRPk85oj61/0?oXGn_0onQMJ45oj1dXP;oWWFT0_nWNj@4ojAhXPCo
XGJS1?nOMZ@5ojn:[`CoZhN_00?oYhJaokRN__nhW[h00_nhW[h4ok6F^`03ojbB^onl]M?o_;GC00;o
_;GC0ongZld2okgVlPGo_LoX00?o^L;Qok;Nm_nbg_H00_nbg_H2okCBl0;oXn?l00?o0000ojcKn?n/
foP01?nReoX2ojOBmP;oX/_e1?nUbO82ojO7l0?oY<7^1?nU`>dDooooo`03o`000?oooooooooo01ko
oooo000Kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooooko4gP02oko4gP;o
^<?S1?ne^M`3ok:`e`03ojR]f_nVY=CoYZCD00;oYZCD1?nSWLl3oj2FbPCoW8o60_nJR/401?nAR/So
ShG4ohn5a?n?QL@5oi62`0?oU86l0onIP[T4oin4]PCoXhJd00?oYXNcojbB_?n/T[`00_n/T[`4ojVA
_0?oXXjo00?o[JSBoiZSfonJXm/00_nJXm/3offCiP;o<WkW00?oFf[8od=Nb?m3G/P00om4HL/2oe=`
dPCoOf2U0on5Hj@4ohQVY0;oRfRT0on=_?H3o`000004oi?9n_nIdO_oVM7koi1[Y@?oRFFR0on2GYl3
ogeIW@?oO5NL0omnFYd4ohEOWP?oTVVO1OnML9l4oj5cWPCoXW>M0_nQLYd2ojMiX@CoY7JN1OnOLIh3
oi]^WP04oiQ/W_nYS;OoZHbgojV<]`GoY8Jd0onRPk85oj61/003oj5o[onSMZ7oXgJQ00?oXGFQ1OnP
M:801?nNMJCoYg^TojMkY?nWNj@4ojAhXPGoXGJS0onOMZ@5ojn:[`CoZhN_1OnhW[h4ok6F^`Ko_;GC
00?o]j_=okgVl_nmi_800_nmi_82okg?j0?oXn[j0_nbg_H4ohkVnP;oXn?l00?oV=Wno`000?nHfOh0
0_nReoX2oig;m`GoX/_e0_nUbO82oj?1k`GoY<7^0_nU`>d2ojBnk1Cooooo00?o0000ooooooooool0
7Oooool001_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`04o`000?oooooooooooko4gPCo
^<?S1?ne^M`01?nb/=OoZ:gJojR]f_nX[MX3ojJTe0GoXig?0onPU/X2oib?aP03oi>?c?nAR/SoTH[8
00;oTH[80on?QL@4oi62`0?oU86l0onIP[T5oin4]P;oXhJd00?oZ96nojbB_?n/T[`00on/T[`4ojVA
_003oj:>_on]Z=;o[JSB00;o[JSB1?nJXm/3offCiP?o<WkW0_l0Gm82odAQb`;oDg3B1?mVPm/3ogZI
i@GoQZc^00GoSKcfo`000?l0003o0000ohflmP02oi?9nPCoT6^U0on9IJ83oh9NW`?oOEVM1?mlEi`2
ogiJW@CoQEnN1?nBJIl4oie`W`CoXG>N1?nRLid00onQLYgoYgVQojMiX@02ojMiX@?oY7JN1OnOLIh3
oi]^WPGoZHbg1?nTQ[@4oj:3/P?oXH6`1?nSMZ43oj5eX@GoX7BR1OnWNj@3ojAhXPGoXGJS0_nOMZ@2
okB@/PGo[hZ_0_n[Qjl2ol>ab0Go^9jn0_naU[/2olC9gPCo_;GC00?oWO?ZokgVl_nmi_800_nmi_83
ogCRiP;oXn[j0omUfNP2ohkVnP?oRMOo0_nHfOh00ol0003oV<Shoig;m`04oig;m`;oX/_e0_nQ`>l5
oj?1k`;oY<7^0_nS_N/5ojBnk1?ooooo0_l0000Nooooo`006oooool01Ol@413ooooooooooooooooo
410@00Kooooo0_l00002ooooo`Go^<?S0_ne^M`00on[]^7oZ:gJojR]fP02ojR]fPCoYZCD0_nSWLl2
oiVLe@?oUiK@1?nCSl`3oi6:b0?oShG41?nAP/03oiB1_0CoVH:i1?nOQ;H01?nSQ[CoZ96nojRA__nX
TKh5ojbB_0;oZI6l00?o]Z_>ojfXd_n]Z=800on]Z=83oiZSf`CoV]gm0om3^_801?lbO^Oo05oBo`1O
d_l0GL03oe=`dPCoIX?K0omjVND2ohJ/kP?o00000_n=_?H01?nCL:SoTVjWoi9^YonBKZL4oi1[Y@?o
RFFR0on2GYl3ogeIW@CoO5NL0omnFYd4ohEOWP?oTVVO1?nML9l4oj5cWP?oXW>M00?oZ7fUojMiXOnW
NJ400onWNJ43ojAfWPGoWg6N0_nKKYh00on`UK_oZHbgojV<]`03ojV<]`GoY8Jd0onRPk800onQPK3o
YGRQoj=fX@04oj=fX@CoXGFQ0onPM:800on/PZOoYg^TojMkY003ojMkY0?oY7RR1OnQMZ<01?nOMZCo
]92bokB@/_ndT;85ojn:[`04oj^7[oo3/LSo`k78ol>ab0Go^9jn00?o/IJkolC9g_o4bMh00_o4bMh0
0onl]M?oWO?ZoigcjP02oigcjP05okgVl_mdh^KoM>;VogCRi_la^LP01?mcaol3og_Ao`;oRMOo0onD
`OH2oiS8n004o`000?nHb?SoWL_goig;m`?oWkg^1?nQ`>l2oj?1k`?oXk_Z1?nS_N/2ojBnk0;oY;g[
4_ooool00ol0003oooooo`00000Nooooo`006oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00_ooool2okS3h`;o[<7Y1?n[]^44ojR]fP;oYZCD00?oVj?JoiVLeOnIW=D0
0onIW=D3oiNFd0?oTho<0onAR/P3ohn5a0GoTH;00onDPK`3oiV2^@;oWhBf0_nRT<84ojRA_PGo[9:l
00CoZI6lokJ[c_nfZlko]Z_>1On]Z=800onJXm_oV]gmoi[Mo@02oi[Mo@03oj:8^OnJN:coV7FZ00;o
V7FZ0onELZT01?l0GL3oDg3Boe=`d_mCL=83ofJ3f`?oNYWU0_l000000on6[>koTW2Yoi9`Z@04oi=`
Z0?oTVjW0on@JjD3ohUUXP?oPUjO1?mmFId3ogaGW0?oOUZM1?n5Gih3oi9YW`CoWG2O1?nQLih2oj9c
W@;oZ7fU1OnWNJ43ojAfWPGoWg6N00CoVfjNok2E^on`UK_o/9Fk1?nYS;L5ojB6]0;oXX>b1?nUN:44
oj=fX@CoXGFQ0_nPM:82ojb2Y`GoYg^T1?nTN:83oj5fX`03okZK^?ndT;;o]92b00;o]92b1?n_RZl0
0ooAemgo`k78ol>ab002ol>ab0Co^9jn0_o3jO03olC9gP?o00000_nMlnX00on7ZncoNkckog^ln`03
og^ln`;oLlOo0_nEZ^D4oiBhl0GoU<7f0_nHb?P00ol0003oW[W[oinmkP04oinmkP;oXL3_0_nR^>P5
oj>kjP;oXkg[00?oY;_YojBmjonT_N/00onT_N/Dooooo`03o`000?oooooooooo01_ooooo000Koooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`Co[<7Y1?n[]^42
ojR]fP;oWJ_Q0onKXmX4oiVLe@?oUiK@0onCSl`4oi6:b0?oShG41?nAP/03oiB1_0;oVH:i00?oV8k7
oj:@`_nRT<800onRT<83ojRA_PCo[9:l00?o]jg?okJ[c_nfZlh00onfZlh2ojfXdPCo^NCd00?oV]gm
oiel[_nJN:`00_nJN:`4oiQeZP?oUG:Y1?nCLJT2oi9`Z@?o000000?oTG2Yoi9`ZOnBL:T00_nBL:T4
oi=`Z0?oTVjW0on@JjD4ohUUXP;oPUjO1?mmFId3ogaGW0?oOUZM1?n5Gih3oi9YW`CoWG2O1?nQLih0
1?nRLigoZ7fUojQmYOnXOJD5ojMiX@CoY7JN0onOLIh00onlYL;o/9Fkok2E^`02ok2E^`GoZHbg0onT
Q[@2oi=TV003ojUlXonUN:7oYGRQ00;oYGRQ1?nSMZ44oj5eX@03oj1dX_n/PZOo[8:W00;o[8:W1?nW
Nj@4ojAhXP;oXGJS0onjVkP4okB@/P;o[hZ_0ooAemd4ol>ab003okRN__o3jO3o`nW`00?o`nW`00?o
a<WNoiFLf?nEW=P00_nEW=P4ohN[k0;oNkck0_nJW]L5oiFZi@CoU;S`0_nD`OH2oifbiP;oW[W[00?o
0000oijijonN^N/00_nO_Nh2oj:di@GoX[SX0_nS^nX2ojBij0CoY;_Y0onT_N/00onV_N[ooooooooo
o`0Cooooo`03o`000?oooooooooo01[ooooo000Kooooo`05oa0@4?ooooooooooooooool@41001Ooo
ool00ol0003oooooooooo`05ooooo`Co[<7Y0_n[]^400onM/nOoWJ_Qoif[h@03oif[h@?oVj?J1?nI
W=D3oiNFd0?oTho<0onAR/P2ohn5a003ohB?e_n8SM;oR8gB00;oR8gB0on?SLd4oiR>a`CoXY321?nX
TKh00on/T[co]jg?okN]c`02okN]c`Co]Z_>0oo2jo42okWTm0?oWGb^1?nJN:`3oiQeZPCoUG:Y0_nC
LJT3o`000003oi9`ZOnAL:WoTG2Y00;oTG2Y0onBL:T4oi=`Z0?oTVjW0on@JjD4ohUUXP?oPUjO0omm
FId3ogaGW0?oOUZM1?n5Gih3oi9YW`GoWG2O0onQLih5ojQmY@CoYgVQ1?nTMYh2oimaWP?o_:G20on`
UK/5ojV<]`04ojB6]?nBHYKoTfBHoi=TV0;oZGbS1?nUN:45oj=fX@?oXGFQ1On/PZL4ojMkY0CoY7RR
00?oXGJSokZK^?njVkP00_njVkP4okB@/P03ojn:[ooAemgodMOM00;odMOM0oo3/LP3ogKQa`;o`nW`
0onOTLD5oiFLf0;oQj_/00?oWiG9oiZNeonJW]L00onJW]L4oiFZi@;oU;S`0onPZml4oifbiP;oW[W[
00?o0000oj>_hOnR]>D01?nR]>D3oj:hj003ojFgiOnT^NSoY;WX00?oY;WX1?nT^nT01?nT_N_oY[gZ
ojJmj_nV_NXDooooo`03o`000?oooooooooo01[ooooo000Kooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2o`0000Oooooo0_n/`NT2oifmk`?oWK?W1OnMZn43oi^SfP;oVIcE00CoSZ;QohbMg_n<
WMkoS9gN0on8V=`3ohJCf@CoQ8oF1?n8SM83ohn=c@?oV8k71?nRT<83ojRA_P03ok2_e_ng[Loo]jg?
00?o]jg?0onfZlh3ol;[l@03ojfD_?nQP[;oWGb^00?oWGb^1?nJN:`3oiQeZP?oUG:Y0ol000000onC
LJWoTW2Yoi9`Z@02oi9`Z@?oTG2Y0onBL:T2oi=`Z0;oSFBN0on:HYh3ohMPW@?oPE^M00CoRFFRoh9N
Won2GYooPUjO0ommFId3ogaGW0?oOUZM1?n5Gih3oi9YW`GoWG2O0_nQLih00onYPZ[oZ7fUojQmY@03
ojQmY@CoYgVQ1?nTMYh00onOLIko_:G2okbU`P02okbU`PCo/9Fk0onYS;L3oi9RUP03oi=TV?nYO:?o
ZGbS00;oZGbS0onUN:45oj=fX@;oXGFQ00?o/Xf_ojb2Yon/PZL00on/PZL5ojMkY0?oY7RR1OnjVkP4
okB@/P03oiga`?oAemgodMOM00?odMOM00?o`k78oiIm]_nWS;T01?nWS;T4oinAa@;oUIcH0_nUT;l4
oinEb@GoVYkG0_nEZ^D2oj>TePGoX:_O0_nM/^H01_nTZm_oXjoQoj>_hOnS[n7o0000oj>_h@CoX[CU
00?oX[SXojFgiOnU]nD00_nU]nD4ojBij0;oY;_Y0_nV^nP5ojJmjQCooooo00?o0000ooooooooool0
6Oooool001_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo00Oooooo
1?nM_Nl3oifci`;oWJ_Q0_n?[>T3ohnVi@CoSZ;Q0on<WMh3ohRHg0?oQY?I1?n4SmH3ohR=dP?oShg=
0onHS/L5oj:@`P04ojRA__n`[mKo/:oFok2_ePGo]jg?00Go]Z_>ol;[lOo2jo7o/Y_0ojfD_002oj62
/PCoWGb^1?nJN:`3oiQeZP?o000000CoUG:Yoi=aZOnCLJWoTg6Y1?nBL:T2oi5`Z@04ohiVWon>IIko
SVFNohiUWPCoSFBN0on:HYh3ohMPW@CoPE^M0omjEid3ogeIW@?oO5NL0omnFYd4ohEOWP?oTVVO1OnM
L9l01?nQLikoZH:ZojV2Z_nYPZX4ojQmY@GoYgVQ0onTMYh5okbU`PCo/9Fk00?oZHbgoi9QU?nBHI@0
0onBHYH5ojUlX`?oYGRQ1OnSMZ401?nQMJ7o/Xf_ok:=[onbSJl4ojb2Y`GoYg^T0_nTN:82olB_aPGo
^Y^h0_ndT;83oiga`0;odMOM00?oWW^/oiIm]_nFOKH00_n_SK84ojN<^@?oWi7500?o[96iojF@_onU
T;l00_nUT;l5oinEb@;oVYkG0_nXWlh5oj>TeP;oX:_O0_nWYmH4ojB[f`?oXjoQ00?o0000oj:diOnR
]>D00onV]>84ojFgi@;oY;WX0onW^NH4ojJkj0;oY[gZ0_nX_nXDooooo`03o`000?oooooooooo01Wo
oooo000Uooooo`03o`000?oooooooooo00Sooooo0_nM_Nl2oh^gl`CoS[7^0on?[>T3ohnVi@?oSZ;Q
1?n<WMh3ohRHg0?oQY?I0on4SmH3ohR=dP?oShg=1?nHS/L2oj:@`P;oYK3O1?n`[mH4okN]c`;o_?;b
0_nbVl000onTR;KoXH:boj62/P02oj62/PCoWGb^0onJN:`3o`0000CoUG:Y0onCLJT2oi9`Z@;oSfNP
0on>IYl3ohiUWPCoSFBN0on:HYh3ohMPW@CoPE^M0omjEid2ogUGWP03ogeIWOmlEicoO5NL00;oO5NL
0_mnFYd4ohEOWPCoTVVO0onML9l00onUQ;3oZH:ZojV2ZP02ojV2ZPCoZ7fU1OnWNJ42ojAfWP;oc;g<
1OnlYL82ok2E^`CoTV6D0onBHYH5ojUlX`?oYGRQ1OnSMZ44ok:=[`Co[8:W1OnWNj@01?nTN:;oa:o6
olB_a_o4[lH5okZK^003okB@/_nVOJKoYWfV00GoWW^/00CoUWffojn=/_n_SK;o[hfb1OnWS;T01?nO
TLGo[96iojbA^On/TKT4ojF@_`?oWiG900?o[Yk7ojROc_nXWlh00onXWlh3oj>TeP03ojbUdOnWYmKo
YjOF00?oYjOF1?nTZm/2oj>_h@03o`000?nX/]ooY[CR00CoY[CR0_nU]nD2ojRhi@GoYkWV0_nV^nP2
ojRnj@CoZ;oZ4_ooool00ol0003oooooo`00000Jooooo`009Oooool00ol0003oooooooooo`0:oooo
o`?oRkOc1?n>/Nh3ohn/j@?oSjKU0on>X^42ohbMgP;oOj[_0omhYo03og:Vl@;oJJ?b00CoQ8oFohR=
d_n8SM;oR8gB0on?SLd2oiR>a`;oT:gZ1?nU/=l4ok2_eP05okN]conll_;o_?;bokcbl_nWSk`01?nT
R;H3oj62/PCoWGb^0ol00004oiQeZP?oUG:Y0_nCLJT00on@JJ7oSfNPohmWX002ohmWX0?oSVJO0on>
IIh4oheTWPCoRV:N0on7H9d3oh5KW@?oNUNM0omiEih4ogaGW0?oOUZM1?n5Gih3oi9YW`;oWG2O0_nU
Q;04ojV2ZPCoZ7fU1OnWNJ401?nTMYkoc;g<olbmc?o<_L`4okbU`P?oU6:C1?nBHI@2oi9RUP03ojb1
YOnYO:?oZGbS00?oZGbS1?nUN:43oj=fX@03ol2X`OnbSJoo/Xf_00;o/Xf_1On/PZL3ojMkY003oloK
h_o4[lKoa:o600;oa:o61?njVkP01?n_Q:KoYWfVojImY_nVOJH5oiik[0Co[hfb1?nWS;T00ondU[So
[96iojbA^@02ojbA^@CoYI2o00?oWiG9ojjNaon^W/L00_n^W/L4ojROcP03oj>Te_n/YM7o[:GA00;o
[:GA1?nWYmH2ojB[f`;oZk3L0onX/]l01?l0003oZ;;OojJdh_nV]>82ojVgh`GoZ;SU0_nW^NH2ojVm
j0GoZ;kY0_nX_nX2ojW0jQCooooo00?o0000ooooooooool05oooool002Gooooo0_l0000<ooooo`?o
RkOc0_n>/Nh01?mo/??oPJkaoh6^lOn1[_44oh:]l0?oPZ__1?moZ^l3ogRWl0?oLZKa0omYXo83ofjT
lP?oNZS`1?n@[NX4ojF`g`;o/:oF0_nAkNl00onj[<_o]j?5ojN?_002ojN?_0?oY8Rf0onQP[82oiel
[P;o00001?nJN:`3oiQeZP;oUG:Y00CoTV^Soi1YXOn@JJ7oT6VQ1?n?Ij04ohiVW`?oSVFN0on=I9h4
ohYRWP?oQf2M0on1Fid3ogYGW@?oNENN0omkFj401?mlEicoOUZMogiJWOmnFYd4ohEOWP?oTVVO00?o
WG2OojF4/?nUQ;000_nUQ;03ojV2ZPGoZ7fU0onWNJ400ooCj>Goc;g<olbmc003olbmc003okbU`_nF
HY;oU6:C00?oU6:C1?nBHI@01?nBHYKo[86Uojb1YOn/PJD4ojUlX`CoYGRQ0_nSMZ43ol2X`@?o/Xf_
1On/PZL2ojMkY0;ocm_R1Oo4[lH01?njVkSo[hBVojn4Y_n_Q:H3ojImYPCoWW^/00?o]Y6aojn=/_n_
SK800on_SK82ojN<^@?o]9Jh0on/TKT3ojF@_`03okBPa?n^W/Oo[Yk700?o[Yk70onXWlh00onaYloo
[:GAojbUd@03ojbUd@?oYjOF00?o[[7Joj^`g?n[/=`00on[/=`3ojRbg`03o`000?nY]n?oZKOS00?o
ZKOS0_nX^>D2ojZmi`GoZKgX0_nX_^T2oj[0jPGoZL3Z4oooool00ol0003oooooooooo`0Gooooo`00
9?ooool00ol0003oooooooooo`0=ooooo`?oO;7f0omo/?<3oh6^l@CoPZg`0on2Znl4ognZk`?oN:O`
0ombY_43ofVSlP?oKZCb0omjZ?04oi2]jP;oYK3O0_m>c=<3okZ/b`03oj^G`_nWSkcoYhnl00;oYhnl
0onTR;H2oj62/P?o00000_nMO:h4oiYh[0;oV7FZ00CoTfjUoi9[XonBJj?oTV^S0on@JJ44ohmWX0Co
SVJO0on>IIh3oheTWPCoRV:N0on7H9d3oh5KW@CoNUNM0_miEih4og]KX@?oP6:V1?n5Gih2oi9YW`03
oiUl/_nUQ;3oYHB`00?oYHB`0onYPZX5ojQmY@;oYgVQ0ooCj>D3olbmc0?oUV:B1?nDHY<4oi9QU0Co
[86U1?nYO:<4ojEhX@03oj=fXOo0Z<7o`:S100;o`:S10onbSJl5ojb2Y`03ojMkY?o?fn;ocm_R00;o
cm_R0oo4[lH00on[PJOo[hBVojn4YP02ojn4YPCoYWfV0_nNNj`3okJA/@Co[hfb00?oYhbiokBF^?nd
U[P00_ndU[P4ojbA^@04ojF@_ondX<Co]:34okBPa0Go[Yk700CoZ9o>ok6WconaYloo/JO?1On/YM40
1?nWYmKo[[7Jojjaf_n^/MX4oj^`g005ojRbgon/]n7o[;OQojbghOl000000onY]n<00on/_^OoZ[gW
ojZmi`03ojZmi`;oZKgX0onZ`NX4oj[0jP;oZL3Z0_nY`N/Dooooo`03o`000?oooooooooo01Kooooo
000Tooooo`03o`000?oooooooooo00kooooo0oml/OH3ogn`l`?oPJka0_n2[O03ogFhn`CoLkgm0omX
_oh3oe>lnP;o<K7Z00?oClg?ohO[honfkoD00_nfkoD00onim?;oa]gYolKMj@02olKMj@03okfkeonl
/m7o_;?A00?o_;?A00Co^Zc;oj^G`_n[Ul;oZiO21?nWSk`2ojB8]P?o00000_nQP[83oiel[P;oVWR/
0_nDLJP3oi=^Y@?oTV^S1?n@JJ43ohmWX0CoSVJO0on>IIh4oheTWP?oRV:N0on7H9d3oh5KW@CoNUNM
0_miEih4og]KX@?oP6:V1?n:KJd3oiUl/PGoYHB`1?nYPZX4ojQmY@03ojMiXOoCj>GodnSU00?odnSU
00?oc;g<oiAPTOnFHY800_nFHY84oiART`?oTV6D00?o/HRYojb1YOn/PJD00_n/PJD5ojUlX`?oYGRQ
1Oo0Z<44ok:=[`?o[8:W0omgg[<3oloKhP04olB_a_n[PJOoZh6Woj^1Y`Co[hBV1?nVOJH00onNNjco
]Y6aokJA/@02okJA/@Co[hfb1OndU[P4ojbA^@Co]:341?n^W/L00onh[/oo/JO?ok6Wc`03ok6Wc`;o
[:GA0_nc]=T5ojjafP;oZk3L0_n_^N43ojbgh@03o`000?n/]n7oZKOS00?o[;kW0onZ_NL00on[`^[o
Z/7Zoj[1jP04oj[1jP;oZ/3Z0_nZ`^/4ojW1jaCooooo00?o0000ooooooooool05Oooool002Cooooo
0ol0000?ooooo`CoMJof0omf/_L4ogJen@?oMKSk0_mc_Od3og7=o`;oH/kh0om/fn`2oi?]lP?o]^oe
1?o3g>`01?o6gNWo_K_Gokfkeonm^mL3okbcd@03ojfNb?n[Ul;oZiO200?oZiO20_nWSk`3o`0000;o
Y8Rf0_nQP[801?nGNK3oUGB/oiEd[?nEM:`4oiAaZ0?oTfjU1?nBJj<3oi1YX@?oSfNP1?n>IYl3ohiU
WPCoSFBN0on:HYh3ohMPW@CoPE^M0omjEid3ogUGWPCoNe^Q0_n0HZH4ohY][@CoVGbb1?nUQ;04ojV2
ZP?oZ7fU0omRd:D2om?Xi@CoU62A0onFHY84oiART`;oTV6D0onaR:T3ojb1Y@GoZGbS0_nUN:42omSf
h@Go`:S10onbSJl01?n/PZOoUVVLoiIYW?nfRZL4ok24Y@CoZh6W0_noUZd3ojn4YPCoYWfV1OnfTK44
ojn=/P03ol6T_?ndU[So]9Jh00?o]9Jh0_n/TKT2okfYaPCo]:3400?o[Yk7okR^conh[/l00_nh[/l3
ok6Wc`03okNkg?nc]=Wo/kCI00?o/kCI0on^/MX00ona_N?o[kWQojnih@03ojnih@;o[;OQ00?o[KoW
o`000?n/_^L01?n/_^L01?nZ_NOoZl;Zoj_2j_n[`^X4oj[1jP03oj[3k?nZ`^_oZ/;[00?oZ/;[0_nY
`N/2ojW2ja;ooooo0_l00009ooooo`Co000000?o410@ooooooooool01oooool002Cooooo00?o0000
ooooooooool04?ooool4ogF_mP?oM[;g0_mf]OT2ogRoo@CoMLKo0_macOl3ogcLn`?oVNWk0ondj?L0
0onfkoGo`mc/ol?Lk002ol?Lk0;o_L7L1?nm^mL01?nl/m7o[Ik8ojfNb?n]W/P3oj^G`P?o00000_nW
Sk`2ojB8]P04oiQn]?nGNK3oUgV`oiMi/0?oUGB/1?nDLJP3oi=^Y@CoTV^S0on@JJ44ohmWX0?oSVJO
0on>IIh4oheTWP?oRV:N0on7H9d4oh5KW@?oNUNM0omiEih4og]KX@?oP6:V1?n:KJd3oiUl/PCoYHB`
1?nYPZX01?nXOJGoSEZ@oheJT?n=FY04oi5MT@CoU62A1?nFHY83oiART`03oi9QU?naR:Wo/HRY00;o
/HRY0on/PJD5ojUlX`04ojEhXOoHm^7of?KQomSfh@Go`:S10_nbSJl00onKJi[oUVVLoiIYW003okJ:
Y`Co/8BU0_n[PJL3oknF[@Co[hBV0onVOJH00oo1W[Go]Y6aokJA/@03okJA/@;o[hfb0_o1Y;`5okBF
^004ojbA^OnmZLKo_JW6okfYaP?o]:3400?o_kcFokR^conh[/l00onh[/l00onaYloo]k_LokNkg002
okNkg0Co/kCI00?o[[7Jok6mhona_N<00_na_N<2ojnih@?o[lCY0on]_nL00ol0003o[;kWojbni`02
ojc4j`GoZl;Z00?oZ/7Zoj[3k?nZ`n`00_nZ`n`2oj[2j`;oZL?/1OnY`^/Cooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02Oooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool04_ooool3og^amPCoN[Sj0omh_od2
ogG6o`?oPMGo0onJgod00onIjO_o]>SgokCXm`02okCXm`?o_m[]00?o`mc/okg1g?nm`M`00onm`M`2
okfke`03ok2Vc_n]W/So[Ik800;o[Ik80ol000000on[Ul;oYhnlojN?_002oiZ3^@?oV7jd1?nGNK03
oiEd[0?oU76X0onCKZD4oi9[X`?oT6VQ1?n?Ij03ohiVW`?oSVFN1?n=I9h3ohYRWP?oQf2M1?n1Fid3
ogYGW@?oNENN1?mkFj43oh1RYPCoRVf]0onIO;85ojF4/0;oZH:Z0_n9Ei43oheJT0CoTEfA1?nDH944
oiIRTP?oU6:C1OnaR:T4ojb1Y@?oZGbS00?oaif]oj]kWon[Nil00_n[Nil01?nPL9_o`:S1ol2X`OnP
L9/4oi][VP03oiIYW?nfRZOo]XZW00;o]XZW1?n`Q:D00on[PJOo_iJ]oknF[@02oknF[@Co[hBV0_nV
OJH2ol6N]@Go]Y6a00Co[hfbol6T_?o1Y;co`JBl1?ndU[P00oo5^]3o_JW6okfYaP03okfYaP04okBP
a?no_=Ko_kcFoknleP?o^:k?00?o_<WTokNkg?ng^m`01?ng^m`2ok>df@;o]LKW0ona_N<2ojo9k@Go
[lCY0_n]_nL00ol0003o[<O]ojc4j`03ojc4j`;oZl;Z0_nZa>d4oj[3k003ojW4kOnY`ncoZL?/00?o
ZL?/0_nY`^/2ojS1jaCooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`00
2Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01_ooool00ol0003oooooooooo`0Cooooo`?oNk7f0_mj^?X3ohO1nPCoQLcn00CoPMGooi[O
oOnJgogoV]om1?n`h?L01?ndj?Oo_m[]okoJkOnof^d3okg4g`?o_L7L00?o/jgCok2Vc_n`Y/h00_n`
Y/h3o`000004ojfNb?n[Ul;oZiO2oib9_PCoVX>i1?nHO[@3oiMi/0?oUGB/0onDLJP4oi=^Y@?oTV^S
0on@JJ44ohmWX0?oSVJO0on>IIh4oheTWPCoRV:N0on7H9d3oh5KW@?oNUNM0omiEih4og]KX@?oP6:V
1?n:KJd4oiUl/PCoYHB`00CoZH:ZohUGTOn9Ei7oRENA0on=FY04oi5MT@CoU62A1?nFHY83oiART`Go
/HRY1?n/PJD2ojUlX`03ok>7Y_o7WJgoaif]00CoZg^O0onPL9/4oi][VPGo]XZW1?n`Q:D5oknF[@Co
[hBV00CoYWfVol6N]Oo1W[Go`Ije1?nfTK400ooBa/oo`JBlol6T_003ol6T_003okBF^?o5^]3oaK[@
00;oaK[@0onmZLH00oo7f^Oo_kcFoknleP03oknleP04okR^conlbNCo_<WTokc9i0Co]k_L00?o]=?`
okG6ionea^L00onea^L00ona_N?o[lW]ojo9k@02ojo9k@;o[lCY0_n[bo43ojc7k@04o`000?n/ango
[<C[ojc4j`;oZ/K^1?nZa>d00onZ`ncoZLC]ojW4k@02ojW4k@;oZL?/0onX`^`4ojS1ja?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`002Oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0Eooooo`CoRKOd0_n7
`OX3oi_8m`?oVmCl0on^e_D2ok3Pm`Co_=K]00?o_m[]okg4gonma=l00onma=l01Onm`Mco/jgCok>]
donc[M?o/:K>00;o000000Co/:K>ojfNb?n]W/SoWho31?nLRKh3oiZ3^@CoV7jd0onGNK03oiEd[0Co
U76X0onCKZD3oi9[X`?oT6VQ1?n?Ij04ohiVW`?oSVFN0on=I9h4ohYRWP?oQf2M0on1Fid3ogYGW@?o
NENN1?mkFj43oh1RYPGoRVf]0onIO;82ojF4/0;oQEJA1?n9Ei43oheJT0CoTEfA1?nDH944oiIRTP;o
U6:C0_o0V:l4ok68Z@Co[86U00?oZGbSok>7Y_o7WJd00_o7WJd4oj]kW`CoX72K0onKJiX5okJ:Y`Co
/8BU1OnoUZd4ojn4YPGo`Ije0_nfTK43om;6c`Co`JBl1Oo5^]000onmZLKoam[WolOJi`02olOJi`?o
_kcF0_nfg?<4okc9i003okNkg?nddo3o]=?`00;o]=?`0_nea^L2ojcAl`Co[lW]00?oYloeoj_;lOn[
bo400on[bo42ojc7k@03ojS8l?l0003oZ/K^00CoZ/K^0_nZa>d3ojS5kP;oZLC]0_nX`nd5ojS2k0;o
Z<7[0_nX`N`Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool000Wooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0ol0000Fooooo`;o
RKOd0onK_Nl4oi_8m`04oi_Do?n^e_Go[]KeojkFm@?o^M3[0onle^d2okg6h@Co_LCO00?o][?Gok>]
donc[M<00ol00002ok2VcP03oj>FaonOSl?oWho300;oWho30onLRKh4oiZ3^@?oV7jd0onGNK03oiEd
[0CoU76X0onCKZD4oi9[X`?oT6VQ0on?Ij04ohiVW`?oSVFN0on=I9h4ohYRWP?oQf2M0on1Fid4ogYG
W@;oNENN1OmkFj43oh1RYPCoRVf]0_nIO;82ohAETP?oQEJA1?n9Ei43oheJT0CoTEfA1?nDH944oiIR
TP04oiARToo0V:oo`9R_ol2H[`Go/HRY0on/PJD00ondQZ?o/hNVolNM[@02olNM[@CoZg^O1?nPL9/2
oi][VP;o_9F_1?nfRZL3ok24Y@;og<C21OnoUZd2ojn4YP;ocKW71?o1W[D00onfTK7od/K?om;6c`02
om;6c`?o`JBl0_o;h^T3olFjd0;oWoC[1?o7f^L00ono_=Ko]]ccokKLl`03okKLl`;o_<WT0onXh_X2
okCCl0;oX]Sk1?n/dO<00on_bNgoYloeojO?m@02ojO?m@;oZl_a0onVbo<3ojS8l003o`000?nZa^ko
Z/K^00;oYlK_1?nXaNh00onW`nkoZ<?]ojS3k@03ojS3k@;oZ<;/0_nW`N`5ojS1k17ooooo0ol00007
ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo01Sooooo1?nK_Nl2oi_8m`?o[<_`00?o[]Ke
okW@jonid>/00onid>/00onle^go_LKQokg6h@02okg6h@03okg4gonf/mOo][?G00?o00000onc[M<0
1?n`Y/koXiK7oj>FaonSU/L3oin?``?oW8Vn1?nJPkT3oiQn]0?oUgV`0onEM:`4oiAaZ0?oTfjU1?nB
Jj<3oi1YX@?oSfNP1?n>IYl3ohiUWP;oSFBN00?oSWNdohag]on<MkL00_n<MkL3ohIg^`?oNGK31?mj
Eid3ogUGWPCoNe^Q0on0HZH2ohY][@?oQeVD0on4EI83ohEFT@CoRENA0on=FY04oi5MT@CoU62A1?nF
HY801?nDHY?o`9R_ol2H[oo0V:l5ok68Z@;o[86U0_ndQZ<4olNM[@CoZg^O1?nPL9/01?nKJi[o_9F_
okbE[onlUJl5okJ:Y`04ok24YOoLa<;og<C2omc4`PGo_iJ]00Co[hBVolfiaoo=^LOocKW71?o1W[D0
0onXm;kod/K?om;6c`03om;6c`03ol6T_?o;h^Wobn;Y00;obn;Y00?oaK[@oiodjonOm>/00_nOm>/2
olOJi`?oRnOg0_nfg?<3oggPm`;oZ>;j0_n;fOl5oj;Hn`;o[=7c0onPdoX2ojO?m@;oXL_f1OnVbo<2
ojS8l003o`000?nVao7oYlK_00?oYlK_00?oZ<G^ojO3k_nW`nh00_nW`nh2ojS3k@OoYl7/0_nX`N`2
ojO0j`kooooo1?l000000ooooooo0000ooooo`06ooooo`03o`000?oooooooooo00Wooooo0009oooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01Wooooo0_nK_Nl2oj_1jP?o[<_`0ongbNP3okW@j`;o_<KR0onma^401?nh^M[o0000o`000?l0
0003okJce`;o/jgC00?oZ9g<oj>FaonSU/L00_nSU/L3oin?``CoW8Vn0onJPkT4oiQn]0?oUgV`0onE
M:`3oiAaZ0?oTfjU1?nBJj<3oi1YX@;oSfNP00?oSgB`oi1e/On@MK400_n@MK43oi1f/P?oSWNd1?n<
MkL4ohIg^`;oNGK30omSM]401?mjEigoNENNogUGW_miEih4og]KX@;oP6:V0on;GIH3ohMIU0?oQ5FB
1?n5EY43ohUGT@CoSEZ@0onAGI44oiAPT@CoUV:B1?o0V:l5ok68Z@05ojb1YOndQZ?o]8JSokB6Xonj
ffh00oo7WJd4oj]kW`CoX72K00CoVf^JokbE[onlUJoo_9F_1OnfRZL01?n`Q:Gog<C2omc4`_oLa<84
oknF[@03okSkiOo=^LOocKW700;ocKW70oo1W[D3ojSd_P;od/K?0omAbkH2ol_Rj@03ofFLkonMW=?o
WIcC00CoPJCZ0_mV/o/01?l0T/7o;KGBobfed_l]]M82oggPm`CoKLom0on;fOl2oj;Hn`?oTm?m0_nP
doX2oi_:n0GoXL_f0_nVbo<2oj?7lP?oY/Oa00Co0000ojK7lOnWa^ooYlK_0_nV`nh3ojO3kP;oY/7]
1_nW`N`7ojO0j`[ooooo0ol00005ooooo`03o`000?oooooooooo00?ooooo00?oEEEEofIVI_l00000
2oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41001Oooool2o`0001_ooooo1?n[`NX00on/bo3o]lWXokO9j003okO9j003okW@jonla^;o_<KR00;o
_<KR0ol00003okRifP;o][?G00?o[:G@ojRMc?nXWL`00_nXWL`3oj>Fa`CoWho30onLRKh3oiZ3^@Co
V7jd0onGNK03oiEd[0?oU76X0_nCKZD00on<M;;oSG>aohec/@02ohec/@?oSW>`0on?M;04oi1e/@?o
T7Jb1?n>Mk@3ohag]`CoQWNk0omiM/<3of=fd@?oI9?Y0_mkFj42oeo6o0;oSEnH0on;GIH3ohMIU0?o
Q5FB1?n5EY43ohUGT@CoSEZ@0onAGI44oiAPT@CoUV:B1?o0V:l4ok68Z@Co]8JS0_njffh3olNM[@Go
Zg^O0onPL9/4okbE[`Go]XZW00?o0000omc4`_oLa<800_oLa<82oknF[@?o^?_U1?o=^LL00oo1W[Go
YHjmokND/`04ojJ=^`?oTHo>00?o[i_2oifLdonMW=<00onMW=<4oh6TjP?oI[?k0_mE_?/2ohBbl`Go
Ol;l1?n4c?l2oi?Co@;oU/Kh1?nKb_P2oj7;mP;oX<Gc1OnSao82ojK7l@03ojG3kol0003oY/?^00Co
Y/?^00?oYl?^ojK1kOnV`Nd00_nV`Nd2ojO1k0;oYko[1_nW`>/2ojNoj`Kooooo1?l00008ooooo`03
o`000?oooooooooo017ooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool06oooool2oj_1jP?o]L?T0_ngbNP4ok_5
h@?o000000?o^[gLokRif_nh^MX00_nh^MX00on`[=Co[:G@ojbUd002ojbUd0?oZ9g<1?nSU/L3oin?
``;oW8Vn00CoTHC2ohj0_on>P;ooSX2o1?n<O;`3oh]i^@?oRWJg0on;M;@3ohad/PCoSG>a0on>Lk04
ohmd/0?oT7Fa1?n@M[83ohig]0CoS7Ng0on6Mk/3ogUf``CoHgKA1?mTTnT01?mOa_coN5ZSogQJXon=
GiP3oh]MUP?oQeVD0on4EI84ohEFT@?oRENA1?n=FY03oi5MT@CoU62A0onFHY82omFb]PCo`9R_0_na
R:T2ok:3XP;o]8JS00?oCDNYokR>Z_njffh00oo7WJd5oj]kW`;oX72K0_o6/<@3okbE[`Co]XZW00?o
/hRXoj>5]?l000000ooLa<800onoUZgo^?_UokSki@02okSki@;ocKW70onUS[d2okND/`GoYXfk00Co
THo>ojnK`_n_Vl;o[i_21?nMW=<2oh6TjP;oX9gB1OnCYn<3ohBbl`;oOl;l0onE]Nh4oi6mm@CoU/Kh
0_nKb_P2oig1lPCoX<Gc0_nSao82oj?1k`?oYL?_00Co0000ojG3konV`nkoY/?^0onV`>d2ojK1k@;o
Y[o[1OnW_n/2ojO0j`KoYko[0_ooool3o`0000cooooo00?o0000ooooooooool04Oooool002;ooooo
00?o0000ooooooooool07Oooool3okG3i0?o^lCQ00Co^lGQo`000?l0003o00001Onj_M`00onh^M[o
/:cDok2/e002ok2/e0?o[:G@1?nXWL`2oj>Fa`04oiV@bOnER/GoUH[5oiF:a@CoTHC20on>P;l3ohal
_0CoRgVi0_n:M[L3oh]d]0CoS7Bb0on=Lk44ohic/0?oSgB`1?n@MK43oi1f/P?oSWNd1?n<MkL4ohIg
^`?oNGK31?mSM]42ofBCj@;oNUZR0omhFZ<3oh]MUP?oQeVD0on4EI84ohEFT@?oRENA1?n=FY03oi5M
T@CoU62A0_nFHY83omFb]PCo`9R_00Co/HRYok:3X_nbPj;o/X>R0_ndQZ<4okR>ZP?oaif]1?n[Nil0
1?nPL9_oa[34olJ`a?o6/<@4okbE[`;o]XZW0_ncR:P4ok>7YPCoYGjY00?o`YZ^ok>@/OncT;400_nc
T;400onUS[go]iBcokND/`02okND/`?oYXfk00?o^ijlojnK`_n_Vl800on_Vl82oifLd`03ojjMaonP
WM;oX9gB00?oX9gB0onCYn<00onUYmOoVjcSoi^/h`02oi^/h`GoUKG^0_nA_OD2oibdj@CoW;c_1?nM
`O82oj35l`;oX[o^1?nS`Nl2ojG3k`03ojFok?l0003oY/3]00?oY/3]00?oY[k[ojJojonV_n/00onV
_n/2ojNoj`;oYkkZ2OnW_n/00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo013ooooo000R
ooooo`03o`000?oooooooooo01kooooo00Co]L?Tok_4hOnka>7o^lCQ0_l000001?nkaN7o^l3Nok_0
g_nk`=h3okZmg003okBcf?n`[=Co/:cD00?o/:cD1?n/YM02ojRMc003oijGcOnIT<WoVI3900;oVI39
0onER/D3oi64`P?oSX2o0on<O;`4oh]i^@?oRWJg0on;M;@3ohad/P?oSG>a1?n>Lk03ohmd/0CoT7Fa
0on@M[84ohig]0?oS7Ng1?n6Mk/2ogUf``?oPEjQ0omnG:43ogYJXP?oN5ZS0_meFjL01?n;GIKoQeVD
ohMIU?n7FI@3ohAETPCoQEJA0on9Ei44oheJT0CoTEfA0onDH942oiIRTP?oeK:f1?o0V:l4ok:3XP03
okB6XomjEY_o^8jZ00Co^8jZ00?o]XNSolNM[On[Nil00_n[Nil00onHjO[oa[34olJ`a002olJ`a0Co
_9F_00Co]XZWok>8Z?ncR:So/hRX1?ncQjH3ojEnZ@;o`YZ^1?ncT;45okND/`;oYXfk0onkW[`4ojnK
`PCo[Yg71?nPWM800onCYn?oYJOGojFWe`02ojFWe`CoVjcS0_nE]Nh2oj6^h@GoW;CY0_nL_>l00onR
]nOoXK_[oj6kj`02oj6kj`GoX[o^0_nS`Nl2ojBmj`?oYKo/00?o0000ojK0kOnV_^/00onV_^/3ojJo
j`KoYkkZ0_nW_n/2ojNojPGoYko[4?ooool00ol0003oooooooooo`0@ooooo`008_ooool2o`00023o
oooo0ol000000onka>7o_<CPokc4h004ok_0gP04okZmg?nd/mSo];?HokBcf0Go/:cD0_n/YM000onS
Wm7oWYO=oijGc@02oijGc@?oVI390onER/D3oi64`P?oSX2o1?n<O;`3oh]i^@?oRWJg0on;M;@3ohad
/PCoSG>a0on>Lk03ohmd/0CoT7Fa1?n@M[83ohig]0;oS7Ng00CoRfZXohITY?n6I:CoQVBT0on3HJ83
oh5NX@?oOUbQ0omjFZ83ogQJX`?oME^W0on7FI@4ohAETP?oQEJA0on9Ei44oheJT0CoTEfA0onDH940
0onFHY;oeK:fomFb]P03omFb]P;o`9R_00?oZgbQok:3X_nbPj800_nbPj800omjEY_o/hRXok>8Z004
okR>ZP;o]XNS00CoZg^OoiSYn_nHjO[oV>Wj1Oo6/<@2okbE[`Co/hRX00?obIj/ok>7Y_ncQjH00onc
QjH01?nUOZWo`YZ^ol:J[_o2VZh4ok>@/@03olFR]OngU;?o]iBc00;o]iBc00?oYXfkok^N_?nkW[`0
0_nkW[`3ojnK`P;o_JK21?n^WLL2oj2MdP03ok2Vc_nUYmOoYJOG00CoYJOG0_nK[><2ojN[f@CoXJkQ
0_nL]>T2ojBbhPCoX[OW1?nQ^n/2oj:okP;oY;[Y1OnT_N/2ojFok003ojJmjOl0003oY[k[00CoY[k[
00?oY[o[ojNnj_nW_^X01_nW_^X4ojNojP;oYko[0_nX_n/@ooooo`03o`000?oooooooooo013ooooo
000Rooooo`03o`000?oooooooooo01cooooo0ol000000ooooooo^lCQokc4h004okc4h0;o^l3N0_ng
^md4okBcf0;o/:cD0_nXYmD4oj>Od@?oWYO=0onIT<T3oiF:a@CoTHC20on>P;l3ohal_0CoRgVi0_n:
M[L3oh]d]0?oS7Bb1?n=Lk44ohic/0?oSgB`0on@MK44oi1f/P;oSWNd00CoPV2SogmNXomoGZ?oOejS
0on6I:@3oh=QXP?oPEjQ0omnG:43ogYJXPCoN5ZS0_meFjL2of5CZ`03ohMIU?n4EI;oQ5FB00;oQ5FB
0on5EY43ohUGT@CoSEZ@1?nAGI43oiAPT@KoeK:f00?o`9R_oj]lXOn[O:401?nbPj83ok>8Z0?o^8jZ
0_oJ];84okJ7X`03ojIhWonHjO[oa[3400?oa[3400?o_9F_okZ>Z?ncR:P00_ncR:P2olVN[0Go/hNV
00?oYGjYol:J[_o2VZh00_o2VZh2ok>@/@;oaJ:e1?ngU;<6ok^N_004ojnK`_nmY/;o_JK2okfV`P?o
[Yg700?o^Jc<ok2Vc_n`Y/h00_n`Y/h4ojFWe`03ojn[e?nWZmWoYj_I00?oYj_I0_nQ[^400onY/=go
Y;;RojBbhP03ojBbhPCoX[OW0_nQ^n/2ojFgiPCoY;[Y0_nT_N/2ojJkj0?oY[gY00Co0000ojJmjOnV
_^_oY[k[0_nW_NT4ojNnjP03ojRnjOnW_^[oYkkZ00?oYkkZ0_nW_nX2ojRojPCoZ;o[3oooool00ol0
003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0Iooooo`?o00001_ooool3okc4h003
okW3h_ng^mgo]k_M00?o]k_M0_nd/mP2ojb_fPCoZ:OE0onSWm44oijGc@?oVI390onER/D3oi64`P?o
SX2o0on<O;`4oh]i^@?oRWJg0on;M;@3ohad/P?oSG>a1?n>Lk03ohmd/0;oT7Fa0_n9JJL3ohETY0?o
PV2S0omoGZ<2ogaNY@03ohITY?n3HJ;oPf6R00;oPf6R0_n1GZ43ogiLX@CoNUZR0omhFZ<2ogEKY`?o
HE>[1?n4EI83ohEFT@?oRENA1?n=FY04oi5MT@?oU62A00?oiM73omFb]_oE/[H00_oE/[H4oj]lX@?o
/X>R1?ncR:P3okR>ZP;of[Bb1?nfQj<2ojIhW`;oa[341OnjSZP2ok>8Z0?obIj/1?ncQjH5ol:J[P04
ok>@/Oo5X[GoaJ:eolFR]@Co]iBc00?obJfnok^N_?nkW[`00_nkW[`00oo8]LOo_JK2okfV`P03okfV
`P04ojjMaoni[<co^Jc<okV/c0Co/:K>00?oYJOGojn[e?n_Zm@00_n_Zm@3ojN[f@03ojnaf_nY/=go
ZK3M00;oZK3M1?nT/^82oj:gi`;oYkGS1OnU]nH2ojBjj@;oYk[V1?nV^nP2ojJmj@03ojNlj?l0003o
YkgY00CoYkgY00?oYkkZojRnjOnX_^T00_nX_^T3ojNnjP03ojRnjOnX_n[oZ;oZ00?oZ;oZ0_nX_n/0
0onX`>_oooooooooo`0=ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo
01Kooooo0ol0000:ooooo`04okc4h?ni`n;o^L?RokW3hP?o]k_M00?o[kSPojb_f_n/[mX00on/[mX4
ojRWe@?oXioA0_nNUld01?nFV=?oTI;Aoi6BdOnAT]43ohf>d0?oQhc@0on3Rm<3ogf<e`CoN97O0om`
VNT3oh]d]0?oS7Bb0on=Lk42ohic/0?oUg^b0on@LJ`3ohUYY`?oQFBT0on2H:<3ogmNX`?oO5jU1?n3
HJ83oh5NX@;oOUbQ1?mjFZ83ogQJX`?oME^W0_mQDj/01?lg@k;oQ5FBohAET_n4EI83ohEFT@CoRENA
0on=FY04oi5MT@;oU62A0_oUdL<3omFb]P03oj1dXOn[O:7oZgbQ00?oZgbQ0_nbPj85ok>8Z004okR>
Z_oJ];;of[BbomZd/PGo]XNS0_nVN9l2olNR/`Co^XjX00?o/hRXolVN[?o9WZ`00_o9WZ`4ok>7YP03
oln_^_o2VZko`YZ^00;o`YZ^1Oo5X[D2okND/`;obJfn0onkW[`2olRea`Co_JK200?oa[_@okV/c?ni
[<`00_ni[<`3ok2VcP03okRad_n_ZmCo[j_D00?o[j_D00?oYj_Iojnaf_n_/MX00_n_/MX4ojV`g@;o
Y;;R0_nZ/ml4ojNeh`;oYKOV0_nY^>@5ojNjiP;oY[_X0_nX^nL3ojNlj003o`000?nW_NWoYkgY00;o
Z;gX1OnX_^T00onW_^[oZ;kYojRnj@02ojRnj@CoZ;oZ1?nX`>/>ooooo`03o`000?oooooooooo013o
oooo000Rooooo`;o00005?ooool3o`0000kooooo1?ni`n801?ng^mgo[kSPojnhh?n_^>05ojb_fP;o
Z:OE00CoWZKKoiZNeonJW]OoVYkG1?nFV=<3oi6Bd@?oSHk@0on7S=03oh>;d`?oOHcG1?mhTMl3og2I
j@CoIZOf0_mC]o/01?nXUL;oWhNioin7^OnOQkT3oiMk/PCoT76/0_n9JJL3ohETY0CoPV2S0_moGZ<3
ogaNY@?oNf:Z00CoPf6Roh5NXOn1GZ7oPEjQ0omnG:43ogYJXP?oN5ZS0omeFjL3of5CZ`03ocM3/_n4
EI;oQ5FB00?oQEJA1?n9Ei43oheJT0CoTEfA00?oU62AonGA`ooUdL<00_oUdL<00ooE/[KoX7BQoj1d
X@05oj]lX@03ok:3X_nZPZWoZX:Y00Co/hRX00Co^8jZomZd/_oJ];;of[Bb1OnfQj<01?nVN9ooaj:c
olNR/oo7X[<4okZ>Z0GobIj/0oncQjH2oln_^PCo`YZ^00?ohLk5olFR]Oo5X[D00_o5X[D00ongU;?o
bJfnolV]_P02olV]_P03ok^N_?o8]LOob;G700;ob;G70_nmY/82olJkd0Go^Jc<00Co/:K>okRad_nh
/M;o^;7B0on_Zm@00ond]MWo[k7JojnafP03ojnafP;oZK3M0_n]]=h5ojZcg`;oYkGS0_n[^><4ojVh
i0;oYk[V0_nY^^D5ojRki`;oYkcX00?oZKcXo`000?nX_NP00onX_NP8ojRnj@03ojVoj_nX_n[oZ;oZ
00?oZ;oZ0_nX`>/2ojW0j`gooooo00?o0000ooooooooool04?ooool0027ooooo0_l0000Booooo`?o
00004_ooool2okW3hP;o/L;W1?n_^>02ojb_fP;oXJkP1?nNY]/3oiZNe`?oUYSC0onAT]43ohf>d0?o
Qhc@1?n3Rm<3ogf<e`CoN97O0om`VNT2ofJWmP04ok2Sb_nXUL;oZ9G2ojRE`P?oWhNi0onGNk84oi1a
[0?oRFVW0on5I:@3oh9PX`?oOejS0_mlGZD4og]RZP?oNf^e0omnG:43ogYJXP?oN5ZS0omeFjL3of5C
Z`;o=d>b00CoQ5FBohEFTOn5EY7oQEJA1?n9Ei43oheJT0CoTEfA00?oU62AonGA`ooUdL<00_oUdL<3
oj1dX@GoZgbQ00?o/X>RojZ2ZOnZPZT01?ncR:P4omZd/PGo]XNS00CoYWROolNR/oo7X[?oaj:c1?nj
SZP00ooYglSobIj/olVN[002olVN[0;o/hNV0oo?[kX3ol:J[P;ohLk51?o5X[D5olV]_PGob;G700?o
_JK2olJkd?o6^m000_o6^m03okV/c003oknmf?nh/M;o^;7B00?o^;7B00Co[j_DokBefOnd]MWo];GI
0on_/MX00onb^=ko[KCNojfdgP03ojfdgP;oZ[?O0_n]^>85oj^hh`;oZKST0_n[^^@4ojVji@;oZ;_W
0_nY_>L3ojVlj004o`000?nY_>SoZ;gXojRmj0;oZKgX1OnX_^T4ojVojP;oZ;oZ0_nY`>X5ojW0j`co
oooo00?o0000ooooooooool04?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool03oooool2o`0001Ko
oooo1?na`^L2ojnhh0;oY;KV1?nQ[^03oijVf`CoVYkG0onFV=<3oi6Bd@?oSHk@0on7S=02oh>;d`?o
M[Oj1?mS`Od01?lj_>Co]k3CokN`dong/=<3ok2SbPCoZ9G20onOQkT3oiMk/P?oT76/0on9JJL3ohET
Y0?oPV2S0omoGZ<3ogaNY@?oNf:Z0omkJkD3of]ldP?oNUZR1?mhFZ<2ogEKY`?oHE>[0olg@k83ohEF
T@CoRENA0on=FY04oi5MT@05on?`eooUdL?oiM73onGA`onDK:400onPM:45oj]lX@?oZX:Y1?ncR:P0
0onRe6cof[BbomZd/P02omZd/P?o]XNS00?od>3TolNR/oo7X[<00_o7X[<3okZ>Z0;ojMo81?o9WZ`0
0oncQjKocjnjoln_^P03oln_^P04ol:J[_oQc/GohLk5on7>a@?oaJ:e0_oEcm<4olV]_P03omOLg?o8
]LOob;G700;ob;G71Oo6^m000oni[<co_kgHoknmf002oknmf0;o^;7B0_nk`=h5okBef@04ojnaf_nb
^=ko/[SNok:hgP?o[KCN00?o[k_Sojfhh_n]^>800on]^>82oj^hh`;o[;_T1On[^^@2ojVji@;oZ[cV
1?nY_>L2ojVlj003ojVmj?l0003oZKgX00CoZKgX0_nX_^T2ojVoj@?oZKoZ1_nY`>X2ojW0j`;oZL7[
3Oooool00ol0003oooooooooo`0?ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool3o`0001Wooooo
0_na`^L3ojFok0?oY;KV1?nQ[^03oijVf`;oVYkG00CoT:WVohfVi_n=Y^KoSJKV1?n9Y^P3ohFXj`Co
Ojkb1?mf]oX2of?1o@03ok^lf_ng/=?o]k3C00;o]k3C1?n`XlX3ojRE`P?oWhNi0onGNk83oi1a[0?o
RFVW0on5I:@3oh9PX`?oOejS0omlGZD3og]RZPCoNf^e1?m[O=800om_FJWoN5ZSogQJX`02ogQJX`?o
ME^W0omQDj/2ocM3/P03o`90`On5EY7oQEJA00CoRENA0on=FY03oi5MT@?oho3G00?oiM73oiA/XOnD
K:400onPM:45oj]lX@?oZX:Y0oncR:P3oj;DK0?of[Bb0_nfQj<3om3Pi0Coaj:c00Co^XjXonWOb?oY
glSojMo81?o9WZ`6oln_^P03ol:J[_oQc/GohLk500;ohLk500CoaJ:eomG?dooEcm?oeLoC0oo9[Kh2
omOLg0?ob;G70_o9en@3olJkd0;o`mSY0ono_MP00onhcnco^l3Nok_0gP03ok_0gP;o];GI0_nd`><5
ok:hgP04ojfdg_n_^n?o[k_Sojnkh`?o[KSR0_n^_ND4ojbki0;oZk[T0_n/_NH5ojZliP;oZKcW0_nZ
_^P3ojVmj003o`000?nY_NSoZKgX00OoZKoY00?oZKoZojW0j_nY`>X01?nY`>X6ojW1j`cooooo00?o
0000ooooooooool03oooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001Ooo
ool2o`0000[ooooo0ol0000Mooooo`GoYKo/0onT]^H2oj6^h003oiFaj_nC[NSoTjgX00;oTjgX0on@
ZNH3ohfViPCoRJKX0on5Z>/2ogn^lP;o>l3A0_njkO@00onoko;o^kcJok^lfP02ok^lfPCo]k3C0_n`
XlX01?nKRl;oTh6loi>1_?nCPK`3oh]g^0?oPfnd0ommJk<3ohUYY`?oQFBT0on2H:<3ogmNX`?oO5jU
1?mkHZX3og][]@?oJgcB0om_FJT2ofYDY`04oi5ZX_n8GicoR5nLohQOW0?oHE>[0olg@k800ol2@<7o
QEJAohUGT@03ohUGT@?oSEZ@0_nAGI43on?`e`CoU6bQ1?nPM:43oj]lX@GoZX:Y00Co/hRXoiYh[?nJ
N:coUWF/0onPLil00onQMJ7o]XNSom3Pi003om3Pi0Coaj:c00?o^XjXonWOb?oYglP00_oYglP2olVN
[0;oc_oK1?o?[kX00ol0003ohLk5on7>a@02on7>a@03oe?8Y?oEcm?oeLoC00?oeLoC00?obJfnomOL
g?oGg=`00_oGg=`00oo8]LOobMOTolWGi002olWGi003olJkd?o3f>Wo`mSY00;o`mSY00Co_kgHokS?
k?nhcnco^<o/0onk`=h2okC>k@Co]<3S0_nb^=h2ok71iPGo[k_S00?o[KSRojjmiOn^_ND00_n^_ND2
ojbki0;o[;oW1?n/_NH2ojZliP;oZkkX1OnZ_^P2ojVmj003o`000?nZ_nWoZKoY00GoZKoY1_nY`>X0
0onY`N[oZL7[ojW1j`07ojW1j`_ooooo00?o0000ooooooooool03oooool000Oooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000ooooooooool01_oo
ool3o`00027ooooo0_nU_n`3oiNkl@?oUkK]0onE/NX4oi>]j0?oT:WV0on=Y^H2ohVVj0?oK/cn0_mJ
cO<01?mli]oo^^gdok[]m?njkO@2okc4h0Go^kcJ0_ng/=<00onSU/SoVh_2oi^;`P02oi^;`P?oTh6l
0on;MkP2oh=_]0?oOF^c0omhJ;@3ohETY0CoPV2S0_moGZ<3ogaNY@CoNf:Z1?mkJkD00om[O=;oNFJ`
ogUV/002ofmIZ@?oJUBW0on8Gi`3oh5HV@?oNE>I00?o=d>bo`90`On9Ei400on9Ei43oheJT003oi5M
TOoSl=Ooho3G00;oQfBS1?nDK:44oj1dX@;oZgbQ00?oVGN/ojZ2ZOnZPZT00onZPZT00oncR:SoVWR/
oiE[W`05oj1cW`;oXGFQ0oo@h>@3olNR/`?o]iBc0ooYglP01?o9WZcoc_oKolkofoo>om/3oln_^P04
ojnA^?nmUk3oZY2kon7>a@;oZY2k0_nVW<`2omG?d`03ojJLc?m;Rn_oBh_[00;oemcL0on;jnd2olWG
i0?oTn[g0_o3f>T2oi_Po@Go^<o/00?o^l3NokC>kOndc^d00_ndc^d2okC0h`;o[LW^1?na`NH2ojnk
h`;o[L7X1?n^_ND00on/`^[o[;oWojboi`03ojboi`;o[;gV0_n[`>T4oj^nj0;oZ[kX1OnZ_nT01?l0
003oZ[oYojVojOnY_nT2oj[0jPGoZL3Z1?nY`NX9ojW1j`[ooooo00?o0000ooooooooool03oooool0
00Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o
0000ooooooooool00oooool3o`0002Kooooo1?nG^o43oiNfk@?oUK7Z0_nC[NP2ohJmn@CoPL7l0omj
a_l2ofk<oP;oI=SW0ondj?L00onjkOCo_<CPokc4h002okc4h0;o^kcJ0_nYXLh3oj>Fb0CoVh_20onC
PK`3oh]g^0?oPfnd0_mmJk<3ogQX]0?oMF^i1?n2H:<3ogmNX`;oO5jU1?mkHZX3og][]@04ogILYomi
I[3oNFJ`ogUV/0;oKeVY0omZE:L2ofaJ[004ohQOW?n1F9WoPERIoh5HV@CoNE>I0_m[CId00ooLk]ko
06;@ohUGT@02oheJT0;oQnGh00?oM5VTohMTXon7I:<00_n7I:<3oiA/X@CoX7BQ00?oZgbQoiUg[?nI
Mj`01?nZPZT01?n8Hj7oUF^OoiE[WonEJil5oj1cW`CoXGFQ00?oWGRYom3Pi?o7X[<00_o7VjX00ong
U;?ob9n]olRO[@02olRO[@03okNC/Oo8Wjgob9n]00;ob9n]00CocjnjojnA^?nmUk3o_IN`1?nZT;/0
1?o1W[GoYYc<ojJLc?nVW<`2ok^T`PCoU:3M1?mCX_H00ol0QmSo=k[PocNjh002ocNjh0?oVn3m0_nh
cn`3oioJo0;o]<k]0_nRd_T5ojg9kP;o/L7V0_n[anh4ojg1j003ojjmiOn/`^[o[<;Z00;o[<;Z0on/
_nL00onZ`^_oZl3Yoj_0j@03oj_0j@;oZkkX0_nZ`>X6ojZoj@03oj[0j_l0003oZ/3Z00CoZ/3Z0_nY
`>X2ojW1j`?oZL7Z2_nY`N/:ooooo`03o`000?oooooooooo00oooooo0007ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00omgMgOoc<c<o`000005ooooo`04o`000?ooooooooooooooo`?o0000
:_ooool2oiNkl@;oSkWc0on<^_@4ohVkmP?oQ[gi0_n1`O`3ogoDo`;oM=Wi0_n6j?83okCXm`;o^lWU
0onla>000on_Zm?oZJ7>ojVQcP02ojVQcPCoXiK80onKRl83oi>1_0?oRgNh0on3Kk@3oge[/`?oN6Rd
0_meJkT3ogAda004oh9PXomoGZ?oOejSogmNX`?oO5jU0omkHZX01OmkJkGoMUbWogILYomfG:OoIe>X
00;oNFJ`0_m_FJT3ofYDY`?oK5Z/0on1F9T4ogUCV@04of]=WOoLk]kog>kNofEN]@;oH5:Z00Co06;@
ohOUn?mdFJCoM5VT1?n7I:<3oiA/X@CoX7BQ1?nIMj`2ojZ2Z@;oR6>Q0onEJil5oj1cW`CoXGFQ00?o
WGRYolNKZ_o7VjX00_o7VjX00ongU;?ob9n]olRO[@02olRO[@03okNC/Oo8Wjgob9n]00;ob9n]00Co
[i6hokfG/?nmUk3o_IN`0onZT;/3ol6N]@03ojJLc?nkY<;o^jC200;o^jC20_nDX=d2ok:_e@CoS;;`
1?m8Y_P00olYXngoFLWfoeW9mP02oeW9mP;oWm[l0_mmd?l4oj;Bn@;o[LW^0_nQcOL5oj_7kP;o[L7X
0_nYaNh4ojc2jP03ojboionZ`^_oZ/;[00;oZ/;[0_n[`>T2oj[2j`GoZ/3Z0_nZ_nT2oj[1j`?oZ/3Z
00?o0000oj[0j_nZ`>X01onY`N/00onY`N[oZL7[ojW1j`0:ojW1j`Wooooo00?o0000ooooooooool0
3oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Gooooo
1?l0000^ooooo`CoSkWc0on<^_@2ohVkmP;oRlGk1?n6cOh2ogoDo`?oSn?l0_n`hOP2okW;j0Co^lWU
00Co_<CPojn[don_Zm?o[j_C1?nYXLh3oj>Fb0CoVh_20onCPK`3oh]g^0;oPfnd0ommJk<3ogQX]0?o
MF^i0omdM<@3og>:f`?oO5jU0_mkHZX3oh=Y[@;oMUbW0_mWDjP01?miI[3oKeVYofmIZOm_FJT3ofYD
Y`;oK5Z/0omgK;T2ogUCV@CoXJ7D00?og>kNofEN]OmUG[D00_mPDZX2ogeLXP;oM5VT0on7I:<4oiA/
X@?oX7BQ00KoPVV]oiUg[?nIMjcoVGN/ojZ2ZOn7JJX2ohQSX@CoUF^O1?nPLil4oj5eX@Goai^Z2_o8
Wjd5okfG/003ojZ@^oo1W[Go`Ije00;o`Ije1OnkY<85ok:_e@;oS;;`0_nU^>L4ogNbm`?oCjgi0_m2
[OL4ogg@o`;oX];i0on;coh3oj7=m`;oZlO^0_nRbO@5ojW5kP;o[<;Z0onXa>h2oj[2j`;oZ<?]1?nZ
`^/2oj[0jP;oZL;[1OnZ`N/2oj[0jP03o`000?nY`N_oZL7[01CoZL7[2Oooool00ol0003ooooooooo
o`0?ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01?oo
ool2o`00037ooooo0_n?^O<2oi:jlPCoSkog0on;aO/2ohK=oP;oU=[n1?n]fOL00on`hOSo^L_XokW;
j002okW;j0;o^lWU00?o/[?Iojn[don_Zm<00_n_Zm<4ojVQcP;oXiK800?oU8W5ohf1`_n=PL800_n=
PL83ohEk`@?oRgNh0on3Kk@2oge[/`?oN6Rd0omeJkT4ogAda0CoLh[K00?oJ;_moiEm]_nEOKH00on3
JJd3ogILY`;oIe>X0om_FJT3ofYDY`?oK5Z/0_mgK;T6oj6Qe003ofiIZ_mUG[GoIEje00;oH5:Z0_mS
EZd00ommG:;oM5VTohMTX`02ohMTX`CoU6bQ0_nPM:401?mLNmWoV8g6oiUg[?nIMj`3ohMYZP?oR6>Q
0onEJil4oj1cW`CoXGFQ1Oo7VjX00ooXa[Cob9n]olRO[@02olRO[@03omJd^?o8Wjgob9n]00;ob9n]
00?od:VaokfG/?nmUk000_nmUk05ol6N]@03olnZ]?nkY<;o^jC200;o^jC200Gob[;2ok:_eOnb[mGo
/ZoEol:jd`05ojFhi`;oMk;g0_n?^O<3offcnP;oEjoj00Co@ZggofO4o_mWa?koIlCn0_n;coh2ogg6
oPGoU<[j0onRbO@2ojW5kP?oXlOb0_nXa>h2ojC5l0GoZ<?]0_nZ`^/2ojS3k@CoZL;[0_nZ`N/2ojW2
k0?oZL7[00Go0000ojW1jonY`N_oZL7[ojW2j`04ojW1j`03ojW2jonY`N_oZL7[00_oZL7[2?ooool0
0ol0003oooooooooo`0?ooooo`008_ooool00ol0003oooooooooo`0_ooooo`CoT[[b0_n?_oL2oi[6
mP?oV=3k0onZd?@3ojgIm`;o]/[Y0onibnP00ond^Mgo/[?Iok:cf@02ok:cf@Co[j_C0_nYXLh00onK
TLSoU8W5oiB9a@02oiB9a@?oSH720on5Nl43ogii``?oMG[;0ommJk<3ogQX]0;oMF^i1OmdM<@2og>:
f`04ojZIa?nEOKKoUGffoiEm]P?oPfV]0omfG:L2ofMCZ003oeMF]?m_FJWoKeVY00?oJUBW0om/FZ`3
ogM/^@CoXJ7D0_m^FJX2ofEN]@;oH5:Z0omSEZd01?m^D9koQfBSohMTXon7I:<4oiA/X@04oj1dXOnX
n>;oG7_Ioeakf@;oV8g60on7JJX3ohQSX@?oUF^O1?nPLil3oj5eX@;obIn]0oo7VjX2onS6]0?ob9n]
0_oF];P3olRO[@;od:Va1?nmUk001?o8X[;o`Ijeol6N]Oo1W[D2olnZ]0?o^jC20_o://800onb[mGo
`[[Col:jd`02ol:jd`;oYKSW0onb`ND4ohnil`?oKK?j0omG[oX4ofJlo@?oOLKn0_nDb_X2oh_6n`Go
VLSg0_nSao82oik5l`CoY<G`0_nX`nd2ojG3k`GoZ<?]0_nY`^/2ojS2k0CoZL;/0_nY`N/00onY`^co
0000ojW2j`03ojW2j`03ojW1jonY`^_oZL;[00;oZL;[3?nY`N/9ooooo`03o`000?oooooooooo00ko
oooo000Sooooo`03o`000?oooooooooo02oooooo0_nB^_82oibmk`CoV/Kf00?oV=3koj[@m?nZd?@0
0onZd?@00on]fOOo]/[YokK:j@02okK:j@04okW;j?nd^Mgo];WMokBig@Co/[?I0_n_Zm<00onRV/go
Vi78oi^Ab002oi^Ab0?oU8W51?n=PL82ohEk`@CoOWW30_meN//3ofZ7g@?oN6Rd0omeJkT2ogAda0;o
UXc70on1M[h4oiEm]P;oPfV]0omfG:L3ofMCZ003oeMF]?m_FJWoJUBW00;oJUBW0om/FZ`3ogM/^@?o
XJ7D0om^FJX00omCAjKoIEjeof1BZP02of1BZP;oHeJ]0on2OLD01?m^D9koU6bQoiA/XOo7g^X3oeac
d@;oG7_I00?o8cN_oiR=a_n7JJX00_n7JJX3ohQSX@?oUF^O1OnPLil2oj5eX@;obIn]0oo7VjX2onS6
]0;ob9n]0ooF];P3olRO[@;od:Va0onmUk02olRR/P;o`Ije1?o?Z[@01?nkY<;ob[;2olZb`_o://85
ol:jd`04olc8e_nb`NGo//7Uok;1i@;o]lOV1?nJ_?03ognemPCoJk3i0om]]o`4ogVoo@?oRlKk0_nI
b?L2oiC4m`GoW/Gc0_nTaO02oj74l@CoYL?_0_nX`nd2ojK3kPGoZ<;/0_nY`^`01_nX`^coZL;/ojW2
k?nY`^co0000ojW2k0;oZL;[0onY`^`2ojW2j`;oZL;/3?nY`N/8ooooo`03o`000?oooooooooo00ko
oooo000Tooooo`03o`000?oooooooooo02oooooo1?nL_Nl2oi[6mPCoZ<O`0_nZd?@3ok?8j@;o]/[Y
0_nd_N04okBig@;o/[?I00?oYj?Boj:JcOnRV/d00_nRV/d3oi^Ab0?oU8W51?n=PL83ohEk`@?oOWW3
0omeN//4ofZ7g@03odBSmoni_]goZJGC00?oZJGC0onFS<L2oh5f_P?oLfRh00?oUGffoh=Y[On3JJd0
0omfG:L3ofMCZ0;oEeJd1?mZE:L3ofaJ[0?oMfbi00?oXJ7DohUg^Om^FJX00_m^FJX2oe=7YP03ofEN
]OmPDZ[oH5:Z00?oHeJ]1On2OLD02?o7g^[oG7?AoeacdOmLLm7o>TFboeakfOlS=jooV8g60on7JJX3
ohQSX@?oUF^O1OnPLil01?nQMJ7obIn]olVO[Oo9Wjd2olNKZPCoj<Jd00?ob9n]omJd^?oF];P00_oF
];P00oo8Wjgod:Vaom2Y/@02om2Y/@03okfG/?o8X[;ob::b00;ob::b00?o`IjeolnZ]?o?Z[@00_o?
Z[@4olZb`P04omG1a_o2^]?o`[[Col:jd`?oc<SF00?o//7UokO7i_nganH00_nganH2oiZll0;oWl3`
0on9]_@3ogVam`CoMkCi0oml^_X5ohW0n@?oU<Cg0_nNaO<2oi_3l`GoXLCa0_nU`nl2ojC2k`CoY/?^
0_nX`^`2ojO2k@CoZ<;/0_nY`^`00onX`^co0000ojS2k009ojW2k0[oZL7[0_nX`N/7ooooo`03o`00
0?oooooooooo00kooooo000Uooooo`;o0000<?ooool2oibmk`?oZ<3[0_nXao03ok75j@?o/lSY0_nd
`><4okBmh0;o];WM00?o[:_GojNSd_nWXm800_nWXm83oj:Jc@CoVi780onDRLD3ohf1`P?oQG_10omn
NL<4ogEjb`;oJXOM00Co?/2gokVngOni_]go^KkM0onYYM<3oiJ<a`?oPGJn0omcJ;P2ofIQ^003oh=Y
[OmfG:OoMUbW00?oIe>X0omGE[@2oaE[g@04ofYDYom/FZcoK5Z/ofaJ[0;oMfbi00?oM771oe1A]?n9
MkT00om^FJX3oe=7YP;oH5:Z0omSEZd4oh9ma@?oQHkE0_mLLm42ocY5/P03oeakfOlS=jooQfVZ00;o
QfVZ0on8Hj43oiE[W`GoX7>O00?oXGFQolVO[Oo9Wjd00_o9Wjd00oo7Vj[oj<JdonS6]002onS6]0Go
e[Bh00?ob9n]om2Y/Oo@ZK400_o@ZK45olRR/PGocjZd00?of[ZiolZb`_o://800ooE`LH00oo2^]?o
c<SFolc8eP02olc8ePCo]lOV00?o]lg[oio0l?nO`?000onO`?03ohVfm0?oNK7g1?mg]?T3ogbjnP;o
RL3i0_n:_?L5oi;0mP?oVl?c0_nQa?42oio2l@GoY<;_0_nV`nh00onU`^koYl;]ojO2k@03ojO2k@Oo
Z<;/00?o0000ojS2k?nY`^`01OnY`^`2ojS2k0KoZL7[1onX`N/6ooooo`03o`000?oooooooooo00ko
oooo000Wooooo`03o`000?oooooooooo02kooooo0onX`>/3ok32i`Co/LGY00?o/lSYokC0hond`><0
0_nd`><2okBmh003ojjbfon/ZmOo[:_G00;o[:_G1?nWXm83oj:Jc@;oVi7800CoTIOFohVCeon9TmOo
RI?G0on4U=/3ogfKi0CoOWW30_meN//2ofg=oP;o`m?V0oni_]d3ojVUd`?oUXc70on1M[h3og=X^0?o
IV6h0omfG:L3ofMCZ0?oEeJd00?o5F_MolcIhoo<fN<00onMXML3ogAa`@03oe1A]?n9MkWoKUVZ00;o
KUVZ0_mCAjH2oe9G^P03of1BZ_mSEZgoHeJ]00?oPWg50_oIi]l2ohF>e@03oba1]?mLLm7oG7?A00;o
>TFb00Co8cN_ocM1/?n7JJ[oQfVZ0on8Hj43oiE[W`GoX7>O1Oo9Wjd01Oo7Vj[oj<JdonS6]?oXa[Co
/oFd00Coe[Bh00?oeMKIom2Y/Oo@ZK400oo@ZK45olRR/PCocjZd0_oJ^[T00oo://;oeL76omG1aP02
omG1aP04omgAcOo<b=Koc<SFolc8eP;ocm?L00?o]lOVokO=jongcN/00_ngcN/4oio0l0CoS[Ka0on2
/O<4ognbm@CoPKKf0on:_?L2oi;0mP;oTkcc1?nJ`?84oio2l@;oY<;_0_nS`Nl4ojG2kPCoYl;]1?nX
`^`01_nW`^coZ<;/ojS2k?nX`^co0000ojS2k0;oZL;/1_nX`^`2ojW1j`[oZ<7[1_ooool00ol0003o
ooooooooo`0>ooooo`00:?ooool00ol0003oooooooooo`0^ooooo`03ojS0jon``^Oo/<;W00?o/<;W
0_naaNT2ok?1i0?o]<3S00?o/;SOojjbfon^/]/00_n^/]/4ojb[e`;oYj?B00CoWJ;IoiNLeonGW=Oo
UicG1?nAUmH3ohVCe`?oQ9CK1?mmVn@3ogZ_m@;o_ocU1?o3dnH3okVng@?oZJGC0onFS<L2oh5f_P?o
LfRh0omVHKP3ofU]``?oIe>X0_mGE[@00onAkn[oc=WSolcIh`02olcIh`;oWJ7G0omdLL42oe1A]0?o
KUVZ0omCAjH2oe9G^P?oHeJ]00CoPWg5omWVgooIi]oofNKO0on5S]D01?l/@KCoG7?AocY5/_ljAK82
ob<g[`03ocM1/?n7JJ[oQfVZ00;oR6>Q1?nEJil4oj1cW`GobIn]0ooXa[@3ok?e]0;oe[Bh0_oEe]T4
om2Y/@;od;>m0oo8X[82om6`^0;ocjZd0ooJ^[T01?oTc;ooeL76omG1a_oE`LH3omgAc@03olc8e_o?
dmcocm?L00?ocMcT0_ngcN/2ok;?k`CoWl3`1?n>]_43oh:al`;oOk;e0_n5/O83ohNdl`CoSKSc1?nC
_?<4oi[0lP;oWl;a0_nO`?04oj?1k`;oYL;^0_nU`Nh4ojO2k@03ojS2k?nW`^coYl;/00;oYl;/0_nX
`^`00ol0003oZ<;/ojS2k005ojS2k0;oZ<7/3OnX`N/5ooooo`03o`000?oooooooooo00kooooo000Y
ooooo`03o`000?oooooooooo02oooooo0_n``^L3ok;2iPCo/l7T00Co]<3Sok2hgon`^=oo/;SO1?n^
/]/2ojb[e`03oj:YfonMX]WoWJ;I00;oWJ;I0onGW=L3oi6GeP?oRI?G1?n4U=/4ogfKi003ogZ_mOn[
n>Oo`mo]00;o`mo]0_o3dnH01?nZY]?oW9C:oibDb_nLU<X3ohb3a0?oOgJo0_m^KL401?n1M[koLfRh
og=X^?mcJ;P2ofIQ^0?oJFg31OmnVN<00onn`McoVIC=oiVDc@02oiVDc@?oLFjo0_mdLL42oe1A]003
oeEH^?m^FJ[oKUVZ00?oDdNV1?mBEkX00omRaOgoi_c4omWVg`03omWVg`;oQHkE0_l/@K@3ocY5/P04
ob<g[olg@K3o=d6`ohMYZP?oR6>Q0onEJil3oj1cW`03olFU^?o9WjgobIn]00?obIn]00CobN^;onS6
]?nLOK3oW7f`0_m]G[400ooF];SoeMKIomGFf@02omGFf@;od:Va0oo@/kd2olRR/P?odK2h00?ocjZd
omZj^OoJ^[T00_oJ^[T2onC<_`04omG1a_oMdLgogM7=omgAc@;ogn3F00Gocm?LolgLi?o=g>CocMcT
olGPk005ok;?k`;oWl3`0_nK__43ohnel0CoQk7a1?n5/O83ohNdl`CoSKSc0_nC_?<2oiFjl@CoV[ga
1?nO`?02oj?1k`;oXl3^1?nU`Nh2ojO2k@?oY/7]0_nW`^`2ojO1k0;oZ<;/00Co0000ojS2k?nX`^co
Z<;/1_nX`N`;ojS1j`;oZ<3[1?ooool00ol0003oooooooooo`0>ooooo`00:_ooool2o`00037ooooo
1?nb`^H2ok?1i0;o/KgS1?n`^=l2ojjbf`;oY[3N0onRZM/4oifRf@?oUicG0onAUmH3ohVCe`;oQ9CK
0_m_c?h01?n8jn_oZoSWoj_hion[n>L3ol?Ok@03ok>ffonZY]?oZZKC00;oZZKC0onLU<X3ohb3a0?o
OgJo0_m^KL43og=X^0?oIV6h0omYKL<3ogjIh`?o_/7L0onIU<d3og5^_`;oFebj00GoM771oe1A]?m@
DKCoEERhofiIZP03oe=7YP?oDUNj00?o/_[Uok_ZS_oVo<@01?nCX=d2oe]R_`;o;46d0_m1CKP00olj
AK;o2bVZocM1/002ocM1/0?oR6>Q0onEJil2oj1cW`?oaJFh0oo9Wjd00oo9jh_o_IJ^oiam/003oiam
/0;oKEja00Go<Cf_omGFfOoEe]WoeMKIom2Y/@04om2c_@03olRR/_oA/;SodK2h00;odK2h1?oJ^[T3
onC<_`?ogM7=0ooOh=H2om[[g`04olgLi?o5h>coaN3/olGPk0;o//o_0onZc?44oi^nl@?oSkG`0_n7
/O45ohZ`k`CoRk;`1?n@]_44oiFjl@;oV[ga0_nK_>l4oinnk`;oXl3^0_nS_nd4ojG1k@;oY/7]0_nV
`N`5ojO1k0;oZ<;/00?o0000ojS1k?nX`N`01onX`N`9ojS1j`CoZ<3[0oooool00ol0003ooooooooo
o`0>ooooo`00;?ooool00ol0003oooooooooo`0_ooooo`;o//;V0_na`^H4ok6mh`;o/;SO0_nY]^84
ojJ`gP?oXZWK0_nMX]T00onF[NKoSjcZohn/jP02ohn/jPCoRK7`0_mo^oX2ohgRo0?oXO?a0oo0iO40
1?o3gngo/kKKok>ffonc]]/3ojZVd`?oW9C:0on<Pl@3ogmf_`;oKVg10omTLld3ofIQ^0CoJFg300?o
OYWSom?Uhonn`M`00_nn`M`4oiVDc@;oLFjo0omKG;X2oe1A]0;oEERh1?mCAjH01?mBEk[o/_[Uok_Z
S_oVo<@2omKRg`?oTj3M0omKH[l2oba1]0;o@Dfh00Co2bVZob<g[olg@K3o=d6`0_mSHkd01On8Hj7o
UF^OoiE[WonEJiooX7>O00CoaJFh0_o9Wjd3okfF[PCoW7f`0om]G[42oc4m[`03ogJmoOo@/kgod;>m
00?od;>m1OoA/;P00ooI`/?of[ZiomZj^@04onC<_`03onWNb?oMdLgogn3F00;ogn3F0_oJjml2om3`
j0;oaN3/0onjgO42oj[<l@;oX/Oc0onG^o05ohnck`KoR[3_1?n;/_02oi2fl@;oTkG^0onG^>l5oi^l
k`;oWkk_00?oX;g]oj>okOnS_nd00onS_nd2ojG1k@;oYL3]1?nV`N`4ojO1k0?oZ<7/00?o0000ojS1
k?nX`N`01onX`N`7ojS1j`KoZ<3[0oooool00ol0003oooooooooo`0=ooooo`00;Oooool00ol0003o
ooooooooo`0_ooooo`Co/L;V0_na_N<2oj^li@CoZKKR0_nV/=h00onO/nKoVjoUoi^_i@02oi^_i@?o
UZgV1?n?[>X2ohVal0?oT=Cn00?oSN;loj7clOnQlo401?o0iO42okW4hP?o/kKK1?nZY]<3oibDbP;o
S8?40omoM[l3ofi]`@?oI7?=0_mAU>l2ofU]``;oc_oC0ooCiN<3okk1g0?oVIC=0_maK[l3oe]L^P04
od9G`_m@DKCoEERhoeEH^0GoKh7E00?o_Oc7onKla?oFh]l00ooFh]l3oi>Pg@;oFf:o0_l/@K@3od5=
^003o`/YZ_lg@K3o=d6`00?oHf>m0_nEJil00onRTlKoaJFholFU^003olFU^003olVO[OnmUZko_IJ^
00;o_IJ^0_nLOK02oif1/`?oOVfe0_la?Jl2o`1TeP?od;>m0_o:`=43om6`^0?ofL;300Cof[ZionC<
_ooTc;ooi<bo0_oYg/P2onO_d@03omoPe_oJjmoof^_O00;od?3X0oo5k?02ok[Ml@03ojkFm?nRao?o
X/Oc00?oX/Oc0onG^o02ohnck`;oS[7]0on<[^d4ohf_k@?oSk7^1OnC]Nh3oiNhk`;oVkc_0_nM^nd4
oj2mk@CoXko]1OnU`>d2ojK1k0KoYl7/0_nX`N`00ol0003oZ<7/ojS1k007ojS1k0GoZ<7[2?nX`>/3
ooooo`03o`000?oooooooooo00gooooo000^ooooo`03o`000?oooooooooo02oooooo0_na`^H2ojc1
j@CoZkcU0_nY]^82oj>gi`?oWk?V1?nK[nD3oiJ]iP;oSjcZ0onAaoX2oi3DoP;oVn[j1?ngi?D00oo0
iO7o^LCRokW4hP02okW4hP?o/kKK0_nZY]<01?nEUm?oRXc?ohZ<con:S<l3og^3d0?oOgJo0_m^KL44
ofAcc@04oe6Dkon?dokoc_oColkod`?odnGS00Co/KSNoi2Ge_n@UmKoT9OF0omdNl`3og5^_`?oFebj
00Co@UO2oe1A]?mEF;SoEERh0om_PMD01?nmo<Ooioc3on_fb_o[m/X2omKRg`04ojJiiom7Im3oAfO@
oi>Pg@?oFf:o00Co;46dod5=^?m1CKSo@Dfh0_mNO]X2ocM1/0;oHf>m1?nRTlH4olFU^003om>Z[onm
UZko_IJ^00;o_IJ^1?nMPK<3ogi]]@;oFUfk00Co<Cf_o`1Te_l0I=Kod;>m0oo:`=42om6`^0CofL;3
00?ogmS@onC<_ooTc;l00ooYg/P2onO_d@04omohf_oJjmood?3Xom3`j0?oaNc`00?o^NCdojkFm?n^
e_@00_n^e_@2oj;7l`;oVkoa1?nC]^l4ohjak@?oS:k]1?n=[nd3ohnakP;oTkG^0_nE]>d3oiVhk@Go
WK_]0_nP_Nd2oj6mk@CoXko]0_nU`>d2ojK0k0SoYl7/0onX`N`00ol0003oZ<7/ojS1k007ojS1k0Go
Z<7[2?nX`>/2ooooo`03o`000?oooooooooo00gooooo000_ooooo`03o`000?oooooooooo02oooooo
1?n/`NT2oj^li@;oYK_Y1?nS]nL3oinciP;oVjoU0_nG_?44oiG0m@;oTLOj0_nIgoh3ok3Om`;o]nCe
0onic>T2okW4hP;oZZoL0onQXmL4oiFGd`?oRXc?0_mkPm03ogN7eP?oN9_W0_mTLld2ohoCoP04olCn
gooFmn;oe_ORomKghPCo/KSN0on@UmH2ogAkc0;oF6S700CoLFjooe]L^_mKG;[oFebj0_m2El83oeEH
^004ofn1eOnmo<Ooioc3onOl``;ojoK:00CofnKLojJiionV^NOoY[WW0_m7Im03oe]R_`04ocA2/_l/
@KCo@Dfhod5=^0?oGWkJ00Co=d6`of=S_OmSHkgoHf>m0onRTlH3olFU^0?odjZ_0_nmUZh2okNE]0?o
WH6c1?mnKKD2oeYM^`03o`0LYol0BlWo06CF00Cob/3A00?odK2homW2`ooI`/<00_oI`/<2omoHd003
onC<_ooYg/SojMk800;oinoA0_oOn=X2om?kh@03ol[gj_o5k?3o^NCd00?o^NCd0_n^e_@3ojG;l`?o
Vkoa1?nC]^l2ohjak@03ohj^k?n=[N_oSJg[00;oSJg[0on?[^`4oi6ak0CoUKC]0onI^>d2oifkk@;o
W[_/1OnQ_Nd2oj>ok@;oY;k/1?nV`>`8ojO1k0?oZ<7/00?o0000ojS1k?nX`N`01?nX`N`5ojS1j`So
Z<3[0_nW`>/2ooooo`03o`000?oooooooooo00gooooo000`ooooo`;o0000<?ooool2ojc1j@;oY[o/
1?nU^nT2oj>gi`;oWK_^0onK^nl4oiNll@;oUL3e0onIeO`01?nIgoko/=ogok3Omon`goL2okO@k@?o
^LcY00?o[kSPojZ_g?nZ[m`00onZ[m`3oj6Se`?oUIOC0on:S<l3og^3d0?oMhOF1?mhVnL00on?doko
a?kOomKghP02omKghP;oamCT1?na^=h2oi2GeP?oM7_<0_mHJ<L3oe]L^PCo@UO200CoHJSgokglaonm
o<Ooioc30_o[m/X3om_Vg0?oY[WW00CoAfO@oceA__lmDKkoFf:o0_ld@[83od5=^0;oGWkJ00Coe=CI
of=S_OmSHkgoHf>m1?nRTlH00oo5YKSodjZ_om>Z[`02om>Z[`04okfF[_ngUKCo]iFdokNE]0CoWH6c
0omnKKD2oeYM^`;o;5;50_l0BlT2ol[0d@;o^LSV0ooI`/<2omoHd0;ogncK00?ojMk8onO_dOoWkm40
0_oOn=X2om?kh@04ol[gj_o2l?7o`_3aol;`l@;o^NCd0on`eo@2ojG;l`03oik0l?nF]nooU[O_00;o
U[O_0on@/Nd4ohj^k0CoSJg[0on?[^`4oi6ak0;oUKC]0_nH]>`4oi^hk0?oW[_/0_nQ_Nd2oj:mk0Go
Y;k/0onV`>`9ojO1k0;oZ<7/00?o0000ojS1k?nX`N`01?nX`N`3ojS1j`OoZ<3[1_nW`>/00ooooooo
0000ooooo`0>ooooo`00<_ooool00ol0003oooooooooo`0^ooooo`CoY[o/0_nU^nT2oinmkPCoWK_^
0onK^nl2oiNll@?oVLci0_nIeO`3ojWHn003ok3Omongd>go]m3]00;o]m3]00Co^LcYojnhh?n_^>3o
[kSP1?nZ[m`4oj6Se`?oUIOC0on:S<l3og^3d0?oMhOF0_mhVnL01On5jNgo[o7eolGjjOo5n^Woe_OR
00CoamCT0_na^=h01?nFVMCoMh7@ogN1d?mgPM02ogAkc0;oF6S70omRN]D00omKG;[o@UO2od9G`P02
ohbkmP04olGod_oWo<?ojoK:on_fbP?ofnKL0_nmc^L2og>Ah@06o`m1_om7Im3o?E6noceA__mKH[oo
=4:b0omfN/T00omNO][oe=CIomCDf@02onc=]@05ong6[?mSHkgoXY?6oj:Ca_oX`Jd01OoCZZl4okNE
]0CoWH6c0omnKKD3oeYM^`;o;5;500?o4V7HokW8i_nib>H00onib>H00ooI`/?ogmS@omoHd003omo/
f`;of?WO00God?gOomohf_oCnn7odo_Qol[gjP03ol;`l@;o^n?c0_n`eo@2ojW:l@CoW/3`1?nF]nl3
oi2ak@?oSZk/0_n=[N/2ohj/jPCoTJkZ0onD/N/5oiRdk0;oVkS/00?oWKS[oj2kk?nP^n`00_nP^n`4
oj:mk0;oY;k/0_nU_n`4ojK0k0WoYl7/0_nX`N`00ol0003oZ<7/ojS1k003ojS1k0CoZ<7[0_nX`>/:
ojO0j`03ooooool0003ooooo00kooooo000cooooo`03o`000?oooooooooo02kooooo0_nV_n`2oj6n
kPCoWkg^0_nM^nh2oic2l`CoVlKf0_nIc?T3ojGAm`;oZMSh0onbdO02okO@k@;o/[oT1?n_^>02ojZ_
g003oifSfOnEVmOoUI_G00;oUI_G0on:U]T4oh>Gg@CoNj7Z0_n0aOd2ojoam@;oaO[Y0oo;i>T2olOD
i003ojfbg?nFVMCoUYWD00;oUYWD0_mgPM03ofQjdP;oF6S71?mRN]D01?n<^oKoaOoBolGod_o9nNP2
omSne@03omgfg?oCj>Go_LkW00Co_LkW0_mcTN401?l?@Koo?E6noceA__lmDKh2ocA2/PCoMW[900?o
e=CIonc=]Oo/cKD00_o]aZ`3onS1[@03on>n/_oCZZoodjZ_00;odjZ_00?oc:ZgokNE]?ngUK@00_ng
UK@3oif1/`CoOVfe0_mJGK/3obaBa@03oa9Qf?nib>Ko^LSV00?oZM7e00CogmS@omo/fooOk=_ogncK
0_oHnMl01?o@oMoobOgQolWmhOo7nnL3olKfk@03ol;`lOnkho?o^n?c00;o]MC`1?nYb_42oik0l0;o
V[K[0onC/>/4ohn]jPOoSZcZ1?nA[^X3oiBaj`;oV;C/0_nJ]N/4oifhj`CoX;_/0_nR_N`2oj>mk0Co
YKo/1OnV`>`8ojO1k0;oZ<7/00?o0000ojS1k?nX`N`00onX`N`2ojS1j`koYl3[00?o0000oooooooo
ool03Oooool003Cooooo00?o0000ooooooooool0;_ooool4oj6nkP;oWkg^0_nM_o04oic2l`;oVlKf
0onSbo@2ojGAm`?o[/ka0_nbdO02ok73i`Co/[oT0_n_^>000onUZm_oWJ?IoifSf@02oifSf@CoUI_G
0on:U]T4oh>Gg@;oNj7Z0onNeO/00on_lOGoaO[YolGjj@02ol_Tj@;o^lKS1?n]/]`3oiJIe0?oMh7@
0_mXN]83oen5h0;oHW[E0_n?cOd2olWij0;of?kE00CogOKLom?XiOoCj>GodnSU0_nmc^L2oiBgk`;o
?GGN0_l?@Kl2oceA_P;oDEo20omfN/T3okFYc003onc=]Oo]aZcokLJ/00;oj<6]0_oS_[83om>Z[`;o
c:Zg1?ngUK@2oif1/`03oj28^on>OKgoSWfm00;oSWfm0omkNLH2obaBa@?oAH[[0_nYdOD3ojGNn`04
omo/fooHnMoof?WOom3mg`;obOgQ00Coao_WolKfkOo6m^goa_K]0_o5jnl00onkho?o]MC`okGDl002
okGDl0;oZL[a0_nT_N`4oiZfj`?oTk3[1?n?[NX5ohj/jP;oT:cX0onC[^T4oiJajPCoV[G[0_nM^>/2
oijij`CoXK_[1?nS_N`4ojFok0;oY/3/0_nW`>`8ojO1k0?oZ<7/00Go0000ojS1k?nX`NcoZ<7/ojO1
k00?ojO0j`03ooooool0003ooooo00kooooo000eooooo`;o0000;oooool2oj6nkP?oWkk^0onM_o02
oic2l`?oX/Kb0_nSbo@2oj[;l@?o[/ka0_n`aNT4ok73i`;o/[oT0_nY/]h3ojF[f`CoWJ?I0onEVmL3
ohZFf@;oPiOM0onA^o<2oikEn`?o]_;d00?oanW^ol?Fj?o3e^P01?nka^<4ojfbg0?oUYWD0_mgPM03
ofQjdPCoGhGP00?oSlgmolWij?o9nNP00_oHo]D01?oMm]codnSUom?XiOoCj>D2okoGk0CoU;O_0_lm
MMh00ol?@Koo:Dk4oceA_P03oe5O`P03ogIjbOneZLco]JW<00;o]JW<0_o]aZ`3onS1[@?ohkjb00Co
djZ_olbZ]oo<Z[Ooc:Zg0ongUK@00onbV;goX8Rkoj28^`02oj28^`?oSWfm0omkNLH3ofJ1f@CoAH[[
0_nUg_/2ojc[n@03okKel_nnn^_o__[[00;oaO[Y00?ob_SYolKfkOo5jnl00_o5jnl3ol3NkP;o]MC`
0_n_a^/4ojBmk0;oV[K[00?oV:kVoi>[ionCZnL00_nCZnL3ohnYi`?oSj[X1On@[>P3oi>^j@CoU[7Z
0_nJ]N/00onL]^[oW[W[oijij`03oijij`;oXK_[0_nR_>/4ojBnj`;oYKo/0_nV_n`4ojO0k0SoYl7/
0_nX`N`00ol0003oYl7/ojO1k003ojO1k0[oYl3[1_ooool00ol0003oooooooooo`0<ooooo`00=ooo
ool00ol0003oooooooooo`0^ooooo`;oWkk^0_nR_^d4oj;2l0;oX/Kb0_nXa^l4oj[;l@03ojk>lOn`
aNWo/<GY00;o/<GY0_na`nL2ojbhhPCoZK;N0onUZm/2oifSf@03oiNWhOnBYnCoTZOT00;oTZOT0on=
ZnX3oi6kl`?oY>3l00?o]_;dolOYk_o7jNh01?o3e^P2ok_6h`03ojRbgonGXMcoUj7L00;oUj7L0on6
TmT3og>:f`?oJ7[B0_mOQN02oiO9n@?o_o?a00Coe?GTomS`h_oHl>;odnSU1?noen`3oiBgk`;o?GGN
00Co02Rco`m1_olYC/Co?E6n0_mAGl85okFYc004om?0aoo]aZcoj<6]onS1[@Cohkjb1Oo<Z[L01?ng
UKCo/YRmok:H_OnbV;d3oj28^`CoSWfm0omkNLH3ofJ1f@CoN[?g00Co[>_iokKel_nfmO;o__[[0oo5
n^T00oo:n>Woc?3[olc`j`02olWUj`;o`=k^0onjcnT2ojo6j`;oZk[U0onQ]>H4oiR^iPCoTj_W0on?
ZNL3ohnZj0;oT:cX0_nBZnL4oiF_j0?oV;;Y1?nL]^X2oijij`;oX;W[1OnR_>/2ojBnj`03ojFnjonV
_ncoY[o/00?oY[o/0onW`>`;ojO1k004o`000?nW`NcoYl7/ojO1k0;oYl3/1_nW`>/9ooooo`03o`00
0?oooooooooo00cooooo000hooooo`03o`000?oooooooooo02kooooo1?nR_^d2oj;2l0;oY/?^1?nX
a^l2oj[;l@?o[/G[0_n`aNT2ojfli0Co[;SR0_nY/]h00onR/>7oWJ_Qoif[h@02oif[h@?oUjOQ1?nB
Yn@3ohf[jP04oi6klonTh?coY>3lojCPo0;o^NGd0_nog>h3ol?Fj0;o]<3S0onX/]l4oiNQg0?oQY?I
0omcR]/4ogVLj005oiO9nOnolo7o_o?aokoclOoDmN@00_oHl>83om7Ui@;o_mO/0_nZanl3og2Rl003
oaASfOlmMMko02Rc00;o:Dk40omAGl83okFYc0;odl3700?ogLW5onS1[OoX`Jd01?oS_[800ooMa;oo
c:ZgolbZ]`02olbZ]`Co/YRm0onPR;/4ohim_@CoNgW60omVPMT2ogZcm`;oX]Sk0_nkk?@2olOek004
olGjjOo:n>Woc?3[olc`j`;obNG[0_o4enP3ok[?j@;o]<;T1?n[^^D3oj6diP;oV:kV00?oVJWRoiBW
honDYn<00_nDYn<4oi6Wi0?oTJWV1?nBZnL4oiF_j0?oV;;Y0_nL]^X2oifgjPCoX;W[0_nR_>/2oj>l
j`CoYKk[1?nV_n`4ojO0k0_oYl7/00?o0000ojO0k?nW`>`00onW`>`2ojO0j`cooooo00?o0000oooo
ooooool03?ooool003Wooooo00?o0000ooooooooool0;_ooool2oj:nk@;oY[o/1?nV`nh2ojS6k`?o
[<C[0_n^aN/2ojfniPCo[KcT0_n/^>800onV]>;oX[3Qoj:`h@02oj:`h@CoWJ_Q0onGYn42oi:Wi0;o
Ukcb0onIboT3ojkJmP03okWUm?nog>ko_mc^00;o_mc^00?o`mKXokC0hond`><00_nd`><3ojRbg`?o
Uj7L0on6TmT4og>:f`;oNIcX0onKcOT01?nolo7oe?GTomS`h_oHl>83om7Ui@?oamWW0onZanl3og2R
l004oaASfOl0:;?o02RcobU>a0?oLhCF00?oDEo2okFYc?oC`<L00_oC`<L2omg9a@04onS1[OoS_[;o
hkjbon>n/P;ogLBo0oo<Z[L2ol>^a0?o/YRm1?nPR;/3ohim_@;oNgW60_nGW=L5oi>_jP03oj;Hnonk
k?Co^ncd00;oaoG/00KocOOXolocj?o?lnSoco?Xolk/jOo9iN/4olCGj003ok[?jOnd`^Co]<;T00;o
]<;T0_n[^^D00onW/MooWjcPoin/h002oin/h0?oVJWR1?nDYn<4oi6Wi0?oTJWV0onBZnL2oiF_j0;o
V:oW0onK/nT5oifgjP;oX;W[0_nR^^/4oj>lj`;oYKk[0_nV_n/4ojJok0CoYl3/2onW`N`00ol0003o
Yl3/ojO0k00@ooooo`03o`000?oooooooooo00cooooo000jooooo`;o0000;oooool4ojJok0;oY/?^
0on[`^/2ojc4j`;o[L3X1?n]_^H2ojfli0;oZKST0onV]>84oj:`h@;oWJ_Q0_nK/^P3oiNdk0CoUkcb
00CoVL_iojkJm_n^f_Ko[][f0onig?82okoLkP?o^<[X0_nd`><01?nV/MooVjKMoi^VgOnKY]d3ohbL
g@CoQY_Q1?n4Yn/2oi_=n@;o_NOc0_o=k^/3om7Xi`05om7UiOo7fNOoamWWolOIionkd>X01OnJ__42
oeFIl@04o`1Me?l07JKo4EK@obU>a0?oLhCF0ooC`<L3omg9a@03on3CbooS_[;ohkjb00CogLBo00Co
c:Zgol>^a?o3[/Co`jk41?nbV;d2oj28^`04ojBJbonMU/goWIK=oifFc@GoUicG0_nC[nX3okCDl004
ok_/m?o7mNcoaoG/olggj0?oco?X00?oc^cYol[Nj?o:g^P00oo4enP00onmb^Co]<;TokC2i002okC2
i003ok2gg_nW/MooYk7O00;oYk7O1?nO[>03oiVYhP;oU:OS00?oUZGOoiBVh_nDY^800_nDY^83oiBX
i0CoUJcV1?nH[nL3oi^cj@;oWKOZ0_nO^>T5oj:jj`;oXkc[00?oY;g[ojJojonV_n/00onV_n/2ojJo
k0KoYl3/2_nW`N`00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo000looooo`03
o`000?oooooooooo02gooooo0_nV_n`2oj[1jP?oZl;[0_n/`NT4ojg0j0;o[KkV0_nZ^nH4ojVhi0?o
Y[CR0_nR/>42oijbiPCoVk;X0onG]>`2oiNllP?oYLkf00Co[][fokWLl_nig?;o^Mcb0_nid>/3okS:
j003ojjkhonV/MooY[7O00;oY[7O0onKY]d3ohbLg@CoQY_Q0_n4Yn/3ojG9l`03okgWloo=k^_ocNk[
00?odNSW0oo>hNH01?o7fNOo^m3Zok_@j_nkd>X2oiZnl@;oT[[b0om>Vo<00ol0GMCo01fVoa5Fd004
og>4eP03om?0aooMbLGogLW500;ogLW50_oPdl/00ooS_[;ogLBoomg4_`02omg4_`Co`jk40onbV;d0
0on]Y]3oY9[;ojBJb`02ojBJb`?oWIK=0onGW=L2ok30iP?o]=C`0_o6jnh2olgej@;ocoGX00?oco?X
olk/jOo:g^P00oo:g^P01Oo4enSo_L[Tokg:i?nmb^Co]<;T00Co/;ON0onW/Ml2oin/h0;oWjOL0onJ
YMd4oiJUg`CoU:KR0onDZ>@4oiF/iP;oV:oW00?oVk3Voifdj?nM]>P00onM]>P3oinhj@;oX[[[0_nS
^nX4ojBmj`CoY[o[1_nW`>`8ojO1k0Gooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0<ooooo`00?Oooool00ol0003oooooooooo`0]ooooo`CoZ/7Z00?oZl;[ojc1jOn/`NT00_n/`NT2
ojg0j0;oZkgW1?nZ^nH2ojVhi0;oYKOV0onR]>D4oijbiP;oVk;X0_nN_^l4oio4lP;oYLkf0on_eo@0
0onig?;o^M3[okW@j`02okW@j`04okS:j?n^^n?o[[_Sojjkh`CoY[7O0onKY]d3ohbLg@;oQY_Q0_nC
/^`3ojG9l`?o_Moa0_o9hnX01?oAj>Ooc^7VolkQi_o>hNH2olSHi@;o^m3Z0_ncb>X4oi:jlP;oCY_c
0_l0Im@01?l07JKo4EK@og>4e_mcQ=H2oi>]j0?ogLW50ooPdl/01?oJhM_ogLBoomg4_ooMa;l2om?=
d`Co`jk400Co/YRmojfVd?n]Y]3o[JK@0onTV//4oifFc@03oiNLeon``>Ko/<3V00;o/<3V00?o]=C`
olK[k_o=mNT00_o=mNT2oloej0;oco7Y0_o<i^T2ol[Nj0;o`m7U0_nmb^@2okNmgPCo/;ON0_nW/Ml2
ojF[f`CoWjOL0onJYMd4oiJUg`;oU:KR00?oV:KOoiRYh_nHZN800_nHZN83oiV/i0CoVk3V0_nM]>P2
oj2ei`CoX[WY1?nS^nX2ojBmj`;oYKk[1?nV_n/5ojO0k0GoYl7/2Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00cooooo000nooooo`03o`000?oooooooooo02gooooo0_nZ`NX3oj_1
j@;o[<7Y0_n[_nP4oj^mi`;oZ[_V0_nW^^L4ojFgiP?oX[CU0_nN/^H2oijkk@CoW[k_0_nOa?83ojS?
m0;o[mOd0onddNl2okW@j`;o/l?V1?n^^n<2ojJag`03oif/hOnFYn;oUZOR00;oUZOR0on=Y^D4oi>b
k004ojG9lonmgo7o_MoaokgOl@;obN?Z0oo=h^L00oo>hNKob=SUolSHi@02ol;@i@Co/lSZ0_nB^_82
oi>ll`;oFJOh0_l0Im@2o`1MdPCoTjgX00CogLW5on3CbooPdl_oh=?;0ooJhM/01?oMa;oodlgCom?=
dooCcM<2ol>^a0;o]kcM1?n]Y]04ojBJb`;oWIK=0_n/]^03ok30iP;o`>7_0_o5lnl00oo=mNWocoGX
oloaj@02oloaj@;oc>KY00Coa]WXol?AiOo3dNGo`m7U0_nla>04okNmgP;o/;ON0_n/[mX4ojF[f`?o
WjOL0_nJYMd00onLXm[oVJCMoiVTg@02oiVTg@CoV:KO1?nHZN83oiV/i0;oVk3V0_nN/ND4oj2ei`Co
X[WY0_nS^nX00onU_>[oYKk[ojFnj`03ojFnj`;oY[o[0_nW_n/2ojO0k13ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0<ooooo`00?oooool2o`0002oooooo0_n[`NT2oj_1jPCoZkoX
0_n[_NL2ojRlj0CoYk[W0_nU]nH2oj:jjP?oXK[[1?nN^nd2oijnk`?oY<Wc0_nXco@3ojo?l0;o]=7_
0_nbb>X4ok?3iP;o[[_S0_nU/n83oif/h@CoUZOR0on=Y^D2oi>bk0?oY/Wb00?o_MoaolWSj_o9hnX0
0oo=h^L2olcKi003olSHiOo2d>Go`]3U00;o`]3U0_ncb>X3ojo5jP?oTkcc0omIYoP00ol3Omoo05gB
o`1MdP02oi>]j0?oW/oi00Goh=?;om[QfooJhM_of^7Kol;]l@03om?=d`;o^Mgb1?ng_=d4ojfVd0;o
Y9[;00?oYkCRojbfh?n/]^000on/]^000on``>Ko`>7_ol3Qk`02olGck`06olGgkOo5mNkoaOG^olGe
k_o?lNWoc>KY1?o6fNP00oo3dNGo_<CPokc4h002okc4h0;o]kgN00?o/[CJojb_f_n/[mX00on/[mX2
ojF[f`03ojBVeonPY=SoX:CH00;oX:CH0onLXmX4oiVTg@CoV:KO0_nHZN800onLZN3oW:gSoib]h`02
oib]h`CoW[7U0_nP]NL2oj:fi`CoY;WX0onU_>X2ojFnj`?oY[k[0_nW_n/Dooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool02oooool0047ooooo00?o0000ooooooooool0;Oooool4oj_1
jP;oZkoX0_nY_^T4ojRlj0;oYk[W0_nT^nX4oj:jjP?oXK[[0_nN^nd3oj;3l@;oY<Wc0onZbo42ojo?
l0;o/L[]1?nbb>X2ok?3iP;oZk[T1?nU/n83oif/h@;oUZOR0_nH[nL4oiRfk@;oY/Wb0_nheo02ol;L
k@04olgRioo<fnCoc=_TolcKi0?ob=CS0_o2d>D3okg:i0;o[lGZ0_n_`nP4oiZolP?oKkKk00Co:Yk_
o`1K^OnNcoWoW/oi0on6g_d00ooJhM_o`^gaol;]l@02ol;]l@03om?=donigO;o^Mgb00;o^Mgb0ong
_=d2ojfVd0;oXK_/1?nW]>82ojbfh0?o]]Wb00Co`>7_olGckoo5lnooaOO]0oo5mNh00oo4jnoo`Mk^
ol7NkP03olKIj0;o_l[S0onla>000onf^]co/[CJok:dfP02ok:dfP;o[:oJ0_nYZMH4ojBVe`CoX:CH
0onLXmX2oiVTg@03oibTf_nKY]goVjKM00;oVjKM1?nLZN04oib]h`;oW[7U00?oXK?Toj:fionR]^L0
0onR]^L2ojBij003ojJjj?nV_>WoY[cY00?oY[cY0_nV_^/Hooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02oooool004;ooooo00?o0000ooooooooool0;Oooool2oj_1jP;oZL3[1?nY
_^T2ojRlj0;oY[gZ1?nT^nX2oj:jjP;oX[o]1?nR`Nl2oj;3l@;oYlOa0onZbo42ojg:k`Co/L[]0_nb
b>X2ojfoi`CoZk[T0_nU/n800onP/>?oVZgToiZ]i002oiZ]i0CoV:oW0_nH]^d3ojS7l003okSGl?o2
g>go`]c]00?oa][X00Coc=_TolSDhoo8e>?ob=CS0_o4c^83okg:i003ok_6hon_`nSo[l?X00?o[l?X
0_nJ_o82oj?2k`?oR<7j0_mJ^O`00omoa_koQ]kmohKNo@03odW7h`;o`^ga0omlh_D2okWMlP?oL]Cl
0onGboX3oj6kk0;oYkCR0onRe?T2okKIlP;o/o3f00Ko[_Ccojgclon]lo?o[O?colGek_o4jnl4ol7N
kP03olKIj?nob^?o_l[S00;o_l[S00Co_<CPokJjg?nf^]co][[L0_nb]=X00on^[MOoZJWFojVYeP03
ojVYeP?oY:KG0_nPY=P2oj6ReP?oWZ;H1?nLY=X4oi^Vg@;oW:WP00?oWj_Ooj2_h_nP[n800_nP[n84
oj6ci0;oX[KW0_nU]nH4ojJjj0;oY[cY7Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo0013ooooo`03o`000?oooooooooo02gooooo1?nY`>/2ojVnj@;oY[k[1?nV_NX2ojBk
jP;oXkk/1?nR_nd2oj;1k`;oYLG`1?nWao400onZbo7o[L[_ojg:k`02ojg:k`;o/L[]0_n^`nT4ojfo
i`;oZk[T00?oYKCToj2`honP/><00_nP/><4oiZ]i0;oV:oW0_nQ_>`2ojS7l0?o]M;_00Co`]c]olKJ
j?o6f^Soa][X0oo6e^H00oo8e>?oa<kRolC>hP02olC>hP04okg:i?nka^?o^lKSok_6h`;o[l?X0onb
`^H2oj?2k`;o[<?[1?nKaOD2ogo6oP?oV<Og0omkaOh3odninP?o7Z7U0olDXM@4oe30m`?oOlko0_nR
e?T3oh_Sn`03ok?`m_n^m??o[O?c00;o[O?c00Co/ncgokGPmOneh?Go]N3e0_o1g^h2okc?j0;o_l[S
0_ni_mh3okJjg003ok6af?n^[MOo[ZgG00;o[ZgG1?nYZMH2ojBVe`03ojBSe?nQX]KoXJ;F00?oXJ;F
0onNX]P4oibTfP;oVjKM00?oWjOKoin[gonOZml00_nOZml4oj2_hP;oXK?T0_nU]><4ojFgiP;oY[[X
8?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0014ooooo`03o`000?oo
oooooooo02gooooo0_nY`>/2ojO0j`CoY[k[0_nV_NX2ojBnk0CoXkk/0_nR_nd2ojC2k`CoYLG`0_nW
ao43oj[8k`;o[L[_0_n]a>/4ojk3j@;o[KoW00?oZ;WUojFdi?nU]>@00_nU]>@2oj2`h`;oWk?V0onM
]NT3oj6lk0;oZ/O^0oned^l3okgEk004olKJj?o6e^Koa]KVolKFiP;oa=3S0oo4c^801?o1bN7o^lKS
ok_6honka^<2ok[3h@?o//;V0_ne`N<4ojc3j`;oVlGe0onXa>d2oiS7m`03ojG3k_nC`oOoTl?g00;o
Tl?g1?mf_od3odjbnP?o::;]00?o49ONo`JFcOl6U/d00om;a>l2oh_Sn`;oON;d00GoO^?doi7RoOnA
h_goTN;mok?/m`03okGPm@04okC@k_nlcnSo_<oXokc?j0;o]l;S1?ni_mh01?nf^]co/K7Hok6af?na
/MP4ojj]e`;oZJWF00?oZ:GDojBSe?nTXm@00_nTXm@4oj6ReP;oWZ;H00?oXJ;Foj2TfOnPY=T00_nP
Y=T4oinWf`CoWj_O0_nP[n800onT/>7oYKCSojFdh`03ojFdh`;oYKOV9?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00_ooooo0015ooooo`;o0000;oooool3ojO0j`;oY[k[0_nU_n`4
ojBnk0;oXkk/0onT`Nh3ojC2k`;oYLG`0onXa^l2oj[8k`;o[<G/1?n]a>/2ojk3j@03ojZlionX^NGo
Z;WU00;oZ;WU0_nU]>@2oj6diPCoWk?V0onM]NT00onQ_>coZ/O^oj[7kP02oj[7kP04okGBkonmeNco
_MG/okgEk0?o`MCX00?oa]KVolC@hoo4d><00_o4d><01Oo4c^;o`LWQol79hOo1bN7o^lKS00Co^/?Q
00?o//;VokG1hone`N<00_ne`N<2ojc3j`?o//7U0_nXa>d00on``NKoYL?^ojG3kP02ojG3kP;oTl?g
0onO_>d3ohfjm0?oM;Kj0omJ/O/4odJ^n0?oCKWi0omWcO`2oi7Ro@?oW][l00Go]N3eokC@k_ndd>ko
]=3^okc?j004okO2h`;o^KoN0_nc]MX4ok6af0;o[ZgG00?oZjSDojRUe?nXYM@00_nXYM@4ojBSe0;o
XJ;F00?oXZ;Doj6Re_nQX]H00_nQX]H4oj2Tf@;oWjOK00?oXjSJojB/gOnT[=d00_nT[=d4ojB`h@;o
YKCS:Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo0017ooooo`03o`00
0?oooooooooo02gooooo1onU_n`2ojBnk0?oY<3]0_nT`Nh2ojK3kPCoY/C_0_nXa^l00onZa>go[<G/
ojc5k003ojc5k0;o[LC[0_n[_nP3ojZli`;oZ;WU0_nT]nH4oj6diP;oWk?V0_nQ^NX4oj>nk0;oZ/O^
0onccNd01?nmeNco`MCXol7Dj?o1e>P2ol7@iP?oa=3S0_o2bn42ol79h@?o_/GO0_nj`n43ok[1g`;o
]L7S0_nh_n03ok;1i@03okJohOn``NKo/<7V00;o/<7V0_nU`nh3ojbliP;oWkc]0_nU]^@3oiVdj`Co
RK;a0omi/_L3offdnP?oLKkm0_n3cOl2oiG3m`CoYLcd0_ndd>h3ok73i`;o]l;S0_nb^=d4ok>efP;o
/K7H00?o[JcEoj^Xe?n[Z=@00_n[Z=@4ojRUe0;oY:?D00?oY:;Coj:Re?nRX]@00_nRX]@4oj6ReP;o
X:CI00?oXjGGoj>Xf_nSZ=X00_nSZ=X4ojB/g@;oY;3Q;?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00_ooooo0018ooooo`03o`000?oooooooooo02gooooo1?nU_n`4ojBok@;oY<3]
0_nU`Nd4ojK3kP;oY/C_00?oZ<?]oj[4kOnZa>d00_nZa>d2ojc5k0?oZl7Z0_n[_nP2ojRli`?oY[WW
1?nT]nH2oj6diP;oXKOX1?nQ^NX2oj>nk0?oZlG]0_nccNd3okS@k003ol7Dj?o1d>Ko`M3V00;o`M3V
00?oa=3Sol;;hOo2bn400_noan03okk5g`;o_L;N0onj`Ml2ok^og@Co^;oP00Co//7UokJohOnf_n7o
][oQ0_n``NH3ok>lh0;o[;cV0_n^]ml4ojFfi0?oVKC[0_n9/_400onE[NOoS:k/ohb^k002ohb^k0?o
Q[7a1?n9^OD3oiG3m`;oYLcd0_nW`>/3ok73i`03ojjhhOnb^=go/[SM00?o/[SM0_nc]MX00on_[mOo
[JcEojf/e@02ojf/e@CoZjSD0_nXYM@00onWXm;oY:;CojBRd`02ojBRd`CoXZ;D0_nQX]H00onTXmGo
XjGGoj>Ue`02oj>Ue`CoXjSJ0_nT[=d`ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02oooool004Wooooo00?o0000ooooooooool0;Oooool4ojFok0;oY;o]0_nU`>d4ojG1k@;oY/?^
0_nW`^d3ojS3k@;oZ/C]0onZ`^/2oj_1jP;oZKkX1?nX_>L3ojJii`;oY;OV0_nR]nL4oj6gj0;oXKWZ
0_nV_n`3oj_5k@;o/L[]0onhd>`3ok_>j@;o`M3V0_o0c><00oo2bn7o_lOPoko7h002oko7h003okk5
gonm`]ko_L;N00;o_L;N00?o^/7Ook^ogOnk_md00_nk_md2okRoh0;o^KkM0_nf_n42okRlg@?o/kcP
0_nd^=`4ojjgg`;oYKKT00CoZ;3Moin^h_nO[^;oWjkR1?nE[NL4ohb^k0?oQ[7a0_n9^OD00onF/^_o
WK[]oifjk@03oifjk@?oYl3[00Co/L?WojjhhOn^^>7o[[SQ0_nb^=d2ojj`fPCo[joG0on][=D2oj^X
e0;oZJGC1?nWXm83ojBRd`;oXZ;D0_nTX]<4ojBSe@CoXjGG0_nSZ=Xdooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02_ooool004[ooooo0_l0000^ooooo`CoYKo/1?nU`>d2ojG1k@;o
Yl7]1?nW`^d01?nX`ngoZL;/ojW2k?nY`^`2oj[2j`;oZKoY1?nY_^P2ojRli`;oY[[W1?nT^>L3oj:g
i`;oXKOX0_nS_>/4ojJok003oj_5kOnab^go/L[]00;o/L[]00Go^=3/ok_>jOnkc^Wo^lkYokc<iP03
ol3<h`;o_/SR0onoan02okg3gP?o_L;N00?o_<3Mok^ogOnk_md00_nk_md01?nk_]co^KkMokVngOni
_]d2okZlf`Co^;cM00?o/kcPokBhg?nd^=`00_nd^=`2ojjgg`03ojnbf_nX/=goZ;3M00;oZ;3M0onO
[^82oiF]i`03oi^XgonFZN?oUZWS00;oUZWS0onC[>P4oiJbj`;oWK[]0_nQ/N@3ojRfh`?o[[SQ00?o
[;7Lojj`f_n^/=X00on^/=X3ojn_e`;o[JcE0_n[Z=@4ojVUd`;oYj?B00?oYZ;BojFRd_nUX]800_nU
X]84ojBRd`?oY:?E0_nSYMLiooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_oo
ool004cooooo00?o0000ooooooooool0;?ooool4ojFok0;oYL3]0onV`>`3ojO1k@;oYl;]0_nX`^`2
ojW2k0;oZL3Z1?nY_nT2ojVnj0;oYkcX1?nV^^L2ojBhi`;oXk[Y1?nS^^X3oj>lj`;oY[o/0onZaNd2
ok7:k@;o]L_[00?o^lkYokc<i_nlc>H00_nlc>H00oo0c>?o_/SRokk8hP02okk8hP03oko7h?nm`mko
_L?N00;o_L?N00Go_L;Nokc0gOnl`=go_<3Mok^og@04ok^ng003okVngOnj_=_o^[cK00;o^[cK0_nh
_=d2okRifP?o];SL00?o];CHojnbf_n_/]X00_n_/]X2ojR`g@03ojV/fOnSZM_oXjWK00;oXjWK0onK
Z=l4oiJYh`?oTjcX0_nF/^/2oib]hPCoXK7T0onX]^<01?n^^>7o[;7Lojbag?n//M`4ojj`fP;o[joG
0_n/Z]H4oj^Xe0;oZJGC00?oYj?BojJRd_nVX]800_nVX]84ojFRdP?oY:;C0_nTXmDlooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02_ooool004gooooo00?o0000ooooooooool0;?oo
ool2ojFok0?oY[o/0_nV`>`00onW`>coZ<7/ojS1k002ojS1k0;oZ<;/0_nX`>/4ojW0jP;oZKoY0_nX
_NT4ojNlj0;oY[[W0_nT^^T4oj>jj@;oXk[Z0_nT_N/4ojK0k0;oZ/G]0_n^an`2okG;j`?o]l_Y0_nl
c>H3ok_8i0;o_/SR0onmaN02okg3gP04okc1g_nl`=go_<3Mokc0g@Go^kkL0_nk_=/3okZlf`03okZj
fOnh^M[o^;WJ00?o^;WJ00Co];SLokBdf?nd]=So];CH0_n_/]X00on_[]OoZJcIojV/f@02ojV/f@Co
XjWK0onKZ=l2oiJYh`;oW:KL0onJZ>04oib]hP;oXK7T00?oXjcMojR_gOnX[md00_nX[md4ojbag0;o
[[3J0_n[[=L4ojbZeP;oZjSD00?oZ:GCojNSd_nWXm800_nWXm84ojJRdP;oYJ;B@oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00[ooooo001>ooooo`03o`000?oooooooooo02gooooo
0_nV_n`00onW`>_oYl3/ojO0k002ojO0k0;oZ<7/1_nX`>/2ojW0jP;oZ;kY1?nX_NT2ojNlj0;oYK_Y
1?nT^^T2oj>jj@;oXkc[1?nT_N/2ojK0k004ojW3k?n^anco[/O/ojk7k0;o/LS[0ongbnT2okO8i`?o
^lST0_nja^<3okg5h003ok_2h?nl`Mko_<7N00;o_<7N00?o_<3Mok^ng?nk_]`00onk_]`4ok^lf`04
okZlfonj^]Wo^[[IokZjf@;o^;WJ0_ng]]P4okBdf004ojnbf_n_[]Oo[jkGojn^e`CoZJcI0_nSZM/0
0onUY]OoWjGIoinUf@02oinUf@CoW:KL0onJZ>02oib]hP;oX:SL0onS[=d4ojR_g@;o[;7L00?oZZcI
oj^/eon[[=L00on[[=L2ojbZeP03ojVWeOnXYM?oZ:GC00;oZ:GC1?nWXm82ojJRdTOooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`00Coooool2o`0002kooooo0onW`>/2ojO0
k0SoZ<3[0_nX_nX4ojRnj@;oZ;gY0_nV_>T4ojFkj@;oY;[Y0_nT_>X4oj>lj`;oY;g[00?oY/7/ojW3
k?nY`n`00_nY`n`00on^anco/LS[ok78j`02ok78j`03okO;jOngb>Oo]lSW00;o]lSW00?o^lSTok[6
honja^<00_nja^<01?nmaN3o^l;Pok_2h?nk`^02okc1gP?o^koM0_nk_]`2ok^mf`?o^kcK00Go^[_J
okZjfOnj^]Wo^[[IokVhf005okNff0;o];CH0_nc/MH4ojn^e`;oZJcI00?oZJSEojFVeonUY]L00_nU
Y]L4oinUf@;oW:KL00CoX:?HoinUf_nOYM[oWjGJ1OnPZ=`3oj>/g@;oZ:oM00?oYj_JojZ/fOnZ[=T0
0_nZ[=T2oj^/e`;oZJWF1?nYYmD3ojRUd`;oYj?BC?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00[ooooo001Aooooo`03o`000?oooooooooo02cooooo00?oYl3[ojS0jonX`>/01_nX
`>/6ojRojP;oZ;kY0onW_NT3ojJlj@;oYK_Y0_nU_>X4ojBljP;oXkc[00?oYKk/ojK1k?nV`N`00_nV
`N`2ojW3k0?o[<G/0_nab>/3ok;7j@;o]lSW0_nga^H3ok[6h`04okS3h_nk`^3o^l;Pok_2h0;o^L3O
0onk_md2okZng@Co^kgK00Go^kcKokZkf_nj^m[o^[_JokZjf@03okVhf0?o]kKH0_nf/mL4ok>aeP;o
[jkG00?o[Z_EojVXeOnYZ=D00_nYZ=D4ojFVe`;oWjGI00?oXZ?Foj2Sf?nPXmP00_nPXmP3oinUfP;o
X:SL0_nSY]P3ojFYfPCoYj_J0_nZ[=T00onXZMSoZJWFojVYeP03ojVYeP?oZJOE0_nXYM=?ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool005;ooooo00?o0000ooooooooool0
:oooool9ojS0j`;oZ;oZ0_nW_nX4ojNnjP;oYkgY0_nV_NX7ojFljP;oY;cZ0_nT_^/3ojFnk0;oY/7/
0onY`n`2ojc5k0;o[/G[0onbanT2ok?6j0Co]lKV00Go^/KSokS3h_nh`n;o^<?Rok_2h004okW0g`03
ok^ogOnj_]go^[kM00;o^[kM0_nk_M/01?nj_=_o^[_JokZkf_nj^mX2okVjfPCo^KSH00?o]kKHokJc
eonf/mL00_nf/mL2ok>aeP03ok6^eOn^ZmGo[Z_E00;o[Z_E0_nYZ=D00onYY]?oYJCDojFTe002ojFT
e0CoXZ?F0onPXmP2oinUfP03oj:TeonSY]SoXjKH00?oXjKH0onUZMX2ojN[fP03ojNYf?nXZMSoZ:WH
00;oZ:WH1?nYZMH2ojVWeE?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:oooo
o`00Doooool00ol0003oooooooooo`0[ooooo`OoZ<3[0_nW_n/4ojNojP;oYkkZ0_nV_^X4ojJmjP;o
YKcZ00?oYKg[ojBmjonT_N/00_nT_N/2ojBnj`;oYKo/1?nV`N`2ojW3k0;oZlC/1?n^aN/00onbanWo
/lKXok?6j002ok?6j0;o]lKV0_nfa>D2okS3hP;o]l7R0oni`=l2okRog`?o^[kM00?o^KgMokZlfonj
_=/00_nj_=/00onj^m[o^K[JokVjfP02okVjfP;o^KSH0_ng]]P3okJce`03okBae_na[]Go/JkE00;o
/JkE0_n^ZmD00on/Z=?oZJKCojVVd`02ojVVd`CoYJCD0onRXmH2oj2Sf003oj:ReOnRY=OoXZCG00;o
XZCG1?nSY]P2ojFYfP03ojJXeonWZMSoYjWH00;oYjWH1?nXZMP2ojVYeUOooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`09ooooo`00E?ooool2o`0002gooooo0_nX`>/2ojO0j`CoYko[
0_nW_nX2ojNnj`CoY[kZ0_nV_NX00onU_^_oYKg[ojFmj`02ojFmj`;oY;g[1_nU_n`2ojK1k0;oZ<;/
1?n[a>`2ojk5j`?o[lGZ0_nca^P2ok;4i`;o]/CU0_nd`^D4okO1hP03okW0gonh_moo^;oO00;o^;oO
00Co^[kMokVmgOni_Mgo^KgM0_nj_=/2okVkg0?o^K[J0_nh^MX4okNff004okJceond/MKo];7FokBa
eP?o/JkE00Co[Z_EojbXdon/Z=?o[:SC1?nYY]<2ojFTe003ojJRd_nTX]?oY:;C00;oY:;C0onRX]D4
oj:Te`;oXjKH0_nUY]H3ojJXe`CoYjWH0_nXZMQJooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02Oooool005Kooooo00?o0000ooooooooool0:oooool4ojO0j`CoYko[1?nW_^/2ojJn
jP;oY[k[0onU_^/2ojFmj`;oYKk/1_nU_n`2ojK1k0CoZ<;/0_n[a>`3ojc4k0;o[lGZ00Co[lCYok;4
ionba>Oo//CW0_na`nL4okC2i@;o]l7R0onf`>82okRog`04okNnh?ni_Mgo^KgMokVmg@;o]kgN1?ni
^m`00oni^][o^;WJokRifP02okRifP;o]kKH00?o]KCHokBae_nd/MH00_nd/MH2ok6^e@;o[jcD1?n/
Z=<2ojVVd`03ojRTd_nVX];oYZ;B00;oYZ;B1?nTX]<3oj:Re@;oXZCG00?oY:CDojFVe_nUY]H00onU
Y]H3ojJXe`;oYjWHG_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo001G
ooooo`03o`000?oooooooooo02_ooooo1?nW`>/4ojNoj`;oYkk[1_nV_^/00onU_^_oYKk/ojFnk004
ojFnk0;oYKo/0onU`>`3ojK1k0;oZ<;/0onY`n`2ojc4k003ojc3jon_a>Wo[lCY00;o[lCY00?o//CW
ok73iona`nL00_na`nL2okC2i@;o/l7U0onf`>800ond_n?o]kkPokNnh002okNnh003okVmgOng_Mko
]kgN00;o]kgN0_ni^m`2okNkg0?o^;WJ00?o]KOJokFdf?ne]=P00_ne]=P2okBaeP;o/JoF1?n_[=@2
ojbXd`03oj^WdonXY=;oZ:CB00;oZ:CB1?nVX]82ojBRd`04ojFRd_nUX]?oYJ;CojFRd`CoY:CD0_nU
Y]IVooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool005Sooooo00?o0000
ooooooooool0;?ooool3ojO0j`;oYko[0onV_n/5ojJnj`OoYKk/0onU_n`2ojG0k0;oY/7]1?nW`^d3
ojW3k0Co[<?[0_n_a>T3ojk3j@;o/L?W0_n``^L4ok?1i@04okK0h_nd_n?o];oSokBoh`;o]kkP0_ne
_^43okNmgP;o][cO1?ng^m`01?nh^M[o]KOJokFgf_ne]mX2okFdf0;o/[;H1?na[mH2ojn/e003ojfZ
e?n[Ym?oZjOC00;oZjOC1?nXY=83ojJRdPCoYJ;B0onUX]<2ojBTe6[ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`00FOooool00ol0003oooooooooo`0/ooooo`CoY[o/0_nV_n/00onV_ncoYKo/
ojFok002ojFok0;oYKk/2?nU_n`2ojG0k@CoY/7]0_nW`^d00onX`^coZL?/ojW3k002ojW3k0Go[<?[
0_n^`nT2ojk2j@Co/<;W0_nc`ND2ok70i@;o];oS0_nc_n<4okFnh@03okNmg_nf_=oo][cO00;o][cO
0_ng^m`01One^]go]KOJokFgf_ne]m[o/kKK00Go/[;H0_na[mH00on^[MOo[J[DojfZe002ojfZe0Co
ZjOC0_nXY=800onWXm;oYZ;BojJRdP02ojJRdP?oYJ;B0_nUX]=]ooooo`05o`000?oooooooooooooo
ool000002oooool005[ooooo0_l0000]ooooo`OoY[o/2_nU_n`6ojG0k@?oY/7]1?nX`^`2ojW3k0?o
ZL;/0_n/`n/2oj_2jPCo[/;Y0_n``^L2ojo1i`;o/L3U0_n``>H4ok>oh`;o]KkQ0onc_^82okJlg`03
ok>lh?ne^]go]K[M00;o]K[M00Co]KOJok>ffonc]]_o/kKK0onb/]P00on_/MWo[ZgGojj]e`02ojj]
e`Co[J[D0_n[Ym<00onXYM?oYj?BojNSdP02ojNSdP?oYZ;B0_nUX]9aooooo`04o`000?oooooooooo
o`0000_ooooo001Looooo`03o`000?oooooooooo02_ooooo1OnV_n`:ojFok0KoYL3]1OnV`Nd5ojS2
k0;oZL;/0_nY`^/4oj_2jP;o[/;Y00Co[L7Yojo1ion_`NOo[l7W0_n^`NP4ok30iP;o/koS0_na_n@3
ok>nhP03ok:nhonc_>3o/kcP00;o/kcP0_ne^]d2ok:igPCo/kKK00Co/[;HojnafOn_/MWo[k7I1?n^
[ML2ojfZe003ojZXeOnXYM?oZ:GC00;oZ:GC0onWXm82ojJRdWGooooo00?o0000ooooool000002ooo
ool005gooooo00?o0000ooooooooool0:oooool2ojJok0goYKo/1OnU`>d3ojK1k@CoYl7]1?nX`^`4
ojW2j`;oZl;Z0_n[`NX3ojg1j@03ojo1ion^`NSo[/7X00;o[/7X0_n``>H2ojo0iPCo/KoT00Co/kkR
ok:nhonb_^?o/[kS0_nc_>02ok6kh@Co/[WN0_nc]]/00on_]=co[k7Iojnaf@02ojnaf@;o[ZgG0_n[
[=P4ojZXe@?oZ:GC0_nWXm9hooooo`04o`000?ooooooooooo`0000[ooooo001Nooooo`03o`000?oo
oooooooo02_ooooo2_nU_n`6ojG0k0;oYL3]1OnV`Nd2ojO1k@;oYl7/1?nX`^`2ojW2j`;oZL7[0_n[
`NX2oj[1jPCo[<7Y0_n^`NP2ojg0j0Co[l3V0_na_n@2ok2oi@;o/[kS0_n`_N@4ok6kh@;o/[WN00?o
[kSOojndg?n_]=`00_n_]=`2ojnaf@;o[:oK1?n[[=P3ojZXe@;oZ:GCO?ooool00ol0003oooooo`00
000:ooooo`00Goooool2o`0002cooooo2?nU_n`6ojG0k003ojK0k?nV`NgoY/7]00CoY/7]0onV`N`3
ojO1k0;oZ<;/0onX`N`3ojW1j`CoZ/7Z0_n/`NT2oj_1j@Co[L3X0_n_`>H2ojk0i`;o/;oU0_n^_nH4
ok2mi0;o/K_Q00?o[[[Rojnhgon_^=l00_n_^=l2ojndg0;o[;?N1?n/[m/2oj^/f8?ooooo0_l0000:
ooooo`00HOooool00ol0003oooooooooo`0Zooooo`SoYKo/1?nU`>`3ojK0k0;oY/7]1OnV`N`6ojO1
k0?oZ<7/1?nY`N/2oj[1jP;oZL7[1?n[`NT2ojg0j0;o[<3Y0_n^`>L2ojboj0Co[[oV0_n`_N@2ojfm
i@?o[[[R0_n_^=l2ojbgh@Co[;?N0_n/[m^5ooooo`?o00002_ooool006;ooooo00?o0000oooooooo
ool0:oooool2ojFok0;oY[o/1OnU`>`6ojK0k0CoY/7/1onW`N`4ojS1k0;oZL7[0_nX`N/4ojW1j`;o
Zl7Y0_nZ`NX2ojc0j@;oZl3Y1?n/_nP2ojjoiP;o[;kW1?n]_ND00on^^^;oZkWToj^ii004ojbgh@;o
[;?NQ?ooool4o`0000gooooo001Sooooo`03o`000?oooooooooo02_ooooo1?nV_n`2ojG0k0WoY/3/
1?nV`N`7ojO1k0GoZ<7/0onX`N/4ojW1j`;oZ/7Z0_nY`N/4oj_0j@;o[;oX0_n[_nT4ojbni`;o[KgU
00?oZkcVoj^ii?n[^N@00_n[^N@2ojbghH?ooooo1?l0000Aooooo`00I?ooool2o`0002cooooo0onV
_n`<ojK0k0CoY/7/2?nW`N`2ojS1k0;oYl7/1?nX`N/00onY`N_oZ<7[ojS1j`04ojW1j`;oZl3Y0_nY
`>X4oj^oj@;o[;kW0_nZ_^P3oj^liP;oZkWTPoooool3o`0001Gooooo001Vooooo`03o`000?oooooo
oooo02_ooooo0_nV_n`=ojK0k003ojK1k?nW`>coYl3/00coYl7/0_nX`N/00onX`NcoZ<7[ojS1j`02
ojS1j`GoZL7[0onY`>X2oj^oj@;oZKoY0_nZ_^R5ooooo`Co00006?ooool006Oooooo00?o0000oooo
ooooool0:_ooool4ojJok0[oY/3/1OnW`>`<ojO1k0?oZ<7/1OnX`N/2ojW1j`GoZ<3[0_nY_nV4oooo
o`Co00007?ooool006Sooooo00?o0000ooooooooool0:_ooool2ojJok0SoY/3/2_nW`>`?ojO1k0;o
Z<7[00?oZ<7/ojS0jonX`>/01?nX`>^3ooooo`Co00008?ooool006Wooooo0_l0000/ooooo`GoY/3/
4OnW`>`;ojO1k0CoZ<7/0_nX`>^2ooooo`Co00009?ooool006_ooooo00?o0000ooooooooool0:_oo
ool4ojO0ja;oYl3/2onW`N`2ojS1k8;ooooo0ol0000Xooooo`00K?ooool00ol0003oooooooooo`0Z
ooooo`?oYl3[4onW`>`7ojO1k8?ooooo1?l0000[ooooo`00KOooool00ol0003oooooooooo`0[oooo
o`;oYl3[0_nW`>`3ojO0j`ooYl3/0_nW`Nb2ooooo`Co0000;oooool006kooooo00?o0000oooooooo
ool0:_ooool;ojO0j`;oYl3/0_nW`>/6ojO0k87ooooo1?l0000cooooo`00Koooool2o`0002_ooooo
3onW`>/2ojO0k83ooooo1?l0000gooooo`00LOooool00ol0003oooooooooo`0Zooooo`WoYl3[P_oo
ool4o`0003_ooooo001booooo`03o`000?oooooooooo02[ooooo1OnW`>^2ooooo`?o0000?oooool0
07?ooooo00?o0000ooooooooool0:_ooool00onW`>_oooooooooo`1oooooo`Co0000@_ooool007Co
oooo0_l0000Zooooo`03o`000?oooooooooo07_ooooo1?l00016ooooo`00M_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo07Sooooo1?l0001:ooooo`00Moooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo07Cooooo1?l0001>ooooo`00N?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo077ooooo0ol0001Booooo`00NOooool2o`0002Cooooo00?o0000oooo
ooooool0KOooool4o`0005Gooooo001kooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool0JOooool4o`0005Wooooo001looooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
IOooool4o`0005gooooo001mooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0HOoo
ool4o`00067ooooo001nooooo`;o00007oooool00ol0003oooooooooo`1Mooooo`Co0000IOooool0
083ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Jooooo`?o0000JOooool0087o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Fooooo`Co0000K?ooool008;ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Booooo`Co0000L?ooool008?ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`1>ooooo`Co0000M?ooool008Cooooo0_l0000I
ooooo`03o`000?oooooooooo04[ooooo1?l0001hooooo`00Q_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo04Kooooo1?l0001looooo`00Qoooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo04?ooooo0ol00020ooooo`00R?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo03oooooo1?l00023ooooo`00ROooool2o`0001Cooooo00?o0000ooooooooool0>ooo
ool4o`0008Oooooo002;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0=oooool4
o`0008_ooooo002<ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<oooool4o`00
08oooooo002=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<?ooool3o`0009?o
oooo002>ooooo`;o00003oooool00ol0003oooooooooo`0/ooooo`Co0000U_ooool0093ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Xooooo`Co0000V_ooool0097ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Tooooo`Co0000W_ooool009;ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Qooooo`Co0000X_ooool009?ooooo0_l00009ooooo`03
o`000?oooooooooo01gooooo1?l0002Vooooo`00UOooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo01[ooooo0ol0002Zooooo`00U_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01Kooooo1?l0002]ooooo`00Uoooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01;ooooo1?l0002aooooo`00V?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00kooooo1?l0002eooooo`00VOooool2o`0000?ooooo00?o0000ooooooooool02_ooool4o`000;Wo
oooo002Kooooo`04o`000?ooooooooooo`0000Wooooo0ol0002mooooo`00W?ooool00ol0003ooooo
o`000005ooooo`Co0000`?ooool009gooooo0_l000000ooooooo0000o`000002o`000<Cooooo002N
ooooo`;o0000b?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:kooooo00GoV9RHo`000?l0003o
A4A4okZj^P09ooooo`Go00001Oooool2o`000003oa0@4?oooooooooo00?ooooo0_lQ8B6Hooooo`00
[_ooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo1_l000001_ooooooV9RHob4Q8Oo^k^kooooo
odA4A0Kooooo00?o0000ooooooooool01?ooool2ob4Q8ISooooo002^ooooo`03o`000?oooooooooo
00cooooo00?oV9RHob4Q8Oo^k^h01?ooool5o`0009oooooo002^ooooo`03o`000?oooooooooo00Co
oooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00CoA4A4omgMgOoooooo0000X?ooool00:ko
oooo00?o0000ooooooooool03_ooool00omgMgOoIVIVooooo`02ooooo`04omgMgOmEEEGoooooo`00
0:3ooooo002/ooooo`03oa0@4?l0003o000000?o00003_ooool00ol0003oooooooooo`02ooooo`03
ogMgMoo<c<co00000:3ooooo002^ooooo`03o`000?oooooooooo00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4004ooooo`03onk^k_m4A4Co00000:3ooooo002^ooooo`03o`000?oooooooooo00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03ogMgMol0003ooooo09oooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -20 0 ]
[.5 .82364 20 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(24.8) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69468 Mtetra
.656 .752 .92 r
.4053 .69468 .41061 .69934 .41957 .69681 .41427 .69214 Mtetra
.41427 .69214 .41957 .69681 .42855 .69428 .42327 .68958 Mtetra
.657 .752 .92 r
.42327 .68958 .42855 .69428 .43756 .69174 .43231 .687 Mtetra
.658 .751 .919 r
.43231 .687 .43756 .69174 .4466 .68919 .44137 .6844 Mtetra
.659 .75 .917 r
.44137 .6844 .4466 .68919 .45567 .68663 .45046 .68175 Mtetra
.661 .747 .914 r
.45046 .68175 .45567 .68663 .46478 .68407 .45958 .67906 Mtetra
.663 .744 .91 r
.45958 .67906 .46478 .68407 .47391 .68149 .46874 .67633 Mtetra
.665 .738 .905 r
.46874 .67633 .47391 .68149 .48307 .67891 .47792 .67353 Mtetra
.666 .732 .899 r
.47792 .67353 .48307 .67891 .49227 .67632 .48714 .67069 Mtetra
.668 .724 .891 r
.48714 .67069 .49227 .67632 .50149 .67371 .49639 .66779 Mtetra
.669 .714 .882 r
.49639 .66779 .50149 .67371 .51075 .6711 .50566 .66484 Mtetra
.669 .704 .874 r
.50566 .66484 .51075 .6711 .52004 .66849 .51497 .66187 Mtetra
.667 .693 .865 r
.51497 .66187 .52004 .66849 .52936 .66586 .5243 .65891 Mtetra
.665 .683 .858 r
.5243 .65891 .52936 .66586 .53871 .66322 .53367 .65597 Mtetra
.662 .674 .852 r
.53367 .65597 .53871 .66322 .54809 .66058 .54306 .6531 Mtetra
.658 .668 .848 r
.54306 .6531 .54809 .66058 .55751 .65792 .55249 .65033 Mtetra
.654 .663 .847 r
.55249 .65033 .55751 .65792 .56695 .65526 .56195 .64767 Mtetra
.65 .663 .849 r
.56195 .64767 .56695 .65526 .57643 .65259 .57145 .64515 Mtetra
.646 .666 .854 r
.57145 .64515 .57643 .65259 .58595 .6499 .58098 .64274 Mtetra
.644 .673 .863 r
.58098 .64274 .58595 .6499 .59549 .64721 .59055 .64041 Mtetra
.643 .683 .873 r
.59055 .64041 .59549 .64721 .60507 .64451 .60015 .63809 Mtetra
.644 .696 .884 r
.60015 .63809 .60507 .64451 .61468 .6418 .60979 .63574 Mtetra
.647 .71 .893 r
.60979 .63574 .61468 .6418 .62432 .63908 .61946 .6333 Mtetra
.651 .722 .9 r
.61946 .6333 .62432 .63908 .634 .63636 .62917 .63073 Mtetra
.655 .729 .904 r
.62917 .63073 .634 .63636 .64371 .63362 .6389 .62804 Mtetra
.658 .733 .905 r
.6389 .62804 .64371 .63362 .65345 .63087 .64866 .62524 Mtetra
.659 .732 .903 r
.64866 .62524 .65345 .63087 .66323 .62811 .65846 .62241 Mtetra
.659 .73 .902 r
.65846 .62241 .66323 .62811 .67304 .62535 .66829 .61958 Mtetra
.657 .728 .901 r
.66829 .61958 .67304 .62535 .68289 .62257 .67816 .61678 Mtetra
.655 .727 .902 r
.67816 .61678 .68289 .62257 .69277 .61979 .68807 .61403 Mtetra
.655 .729 .903 r
.68807 .61403 .69277 .61979 .70269 .61699 .69801 .61127 Mtetra
.656 .731 .905 r
.69801 .61127 .70269 .61699 .71264 .61418 .70798 .60848 Mtetra
.66 .733 .904 r
.70798 .60848 .71264 .61418 .72262 .61137 .71799 .60558 Mtetra
.664 .733 .901 r
.71799 .60558 .72262 .61137 .73264 .60854 .72802 .60256 Mtetra
.668 .728 .894 r
.72802 .60256 .73264 .60854 .7427 .60571 .73808 .5994 Mtetra
.67 .718 .885 r
.73808 .5994 .7427 .60571 .75279 .60286 .74816 .59615 Mtetra
.67 .706 .874 r
.74816 .59615 .75279 .60286 .76291 .60001 .75828 .59287 Mtetra
.668 .693 .864 r
.75828 .59287 .76291 .60001 .77308 .59714 .76844 .5896 Mtetra
.664 .681 .856 r
.76844 .5896 .77308 .59714 .78328 .59427 .77863 .58641 Mtetra
.66 .671 .85 r
.77863 .58641 .78328 .59427 .79351 .59138 .78887 .58333 Mtetra
.656 .665 .847 r
.78887 .58333 .79351 .59138 .80378 .58849 .79916 .58038 Mtetra
.652 .663 .847 r
.79916 .58038 .80378 .58849 .81409 .58558 .80949 .57755 Mtetra
.649 .664 .851 r
.80949 .57755 .81409 .58558 .82443 .58267 .81987 .57483 Mtetra
.647 .668 .856 r
.81987 .57483 .82443 .58267 .83482 .57974 .8303 .57217 Mtetra
.646 .676 .864 r
.8303 .57217 .83482 .57974 .84523 .5768 .84077 .56954 Mtetra
.646 .685 .873 r
.84077 .56954 .84523 .5768 .85569 .57385 .85128 .56692 Mtetra
.647 .696 .882 r
.85128 .56692 .85569 .57385 .86618 .57089 .86183 .56426 Mtetra
.648 .707 .89 r
.86183 .56426 .86618 .57089 .87672 .56792 .87242 .56157 Mtetra
.649 .717 .898 r
.87242 .56157 .87672 .56792 .88729 .56494 .88304 .55881 Mtetra
.65 .726 .905 r
.88304 .55881 .88729 .56494 .89789 .56195 .89369 .556 Mtetra
.651 .734 .91 r
.89369 .556 .89789 .56195 .90854 .55895 .90438 .55313 Mtetra
.652 .74 .914 r
.90438 .55313 .90854 .55895 .91923 .55594 .91511 .55021 Mtetra
.653 .745 .917 r
.91511 .55021 .91923 .55594 .92995 .55292 .92587 .54724 Mtetra
.654 .748 .919 r
.92587 .54724 .92995 .55292 .94071 .54988 .93667 .54423 Mtetra
.655 .75 .92 r
.93667 .54423 .94071 .54988 .95152 .54684 .9475 .54118 Mtetra
.655 .751 .92 r
.9475 .54118 .95152 .54684 .96236 .54378 .95837 .53811 Mtetra
.656 .752 .92 r
.95837 .53811 .96236 .54378 .97324 .54071 .96929 .53502 Mtetra
.96929 .53502 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.655 .751 .921 r
.391 .69252 .39636 .6972 .4053 .69468 .39996 .68999 Mtetra
.655 .752 .921 r
.39996 .68999 .4053 .69468 .41427 .69214 .40895 .68744 Mtetra
.656 .752 .921 r
.40895 .68744 .41427 .69214 .42327 .68958 .41797 .68487 Mtetra
.657 .752 .92 r
.41797 .68487 .42327 .68958 .43231 .687 .42702 .68226 Mtetra
.659 .752 .919 r
.42702 .68226 .43231 .687 .44137 .6844 .4361 .6796 Mtetra
.662 .751 .917 r
.4361 .6796 .44137 .6844 .45046 .68175 .44522 .67688 Mtetra
.665 .75 .914 r
.44522 .67688 .45046 .68175 .45958 .67906 .45436 .67408 Mtetra
.668 .747 .909 r
.45436 .67408 .45958 .67906 .46874 .67633 .46354 .67118 Mtetra
.672 .742 .903 r
.46354 .67118 .46874 .67633 .47792 .67353 .47274 .66819 Mtetra
.675 .736 .896 r
.47274 .66819 .47792 .67353 .48714 .67069 .48198 .66509 Mtetra
.678 .729 .888 r
.48198 .66509 .48714 .67069 .49639 .66779 .49125 .66189 Mtetra
.68 .72 .88 r
.49125 .66189 .49639 .66779 .50566 .66484 .50055 .65862 Mtetra
.68 .71 .871 r
.50055 .65862 .50566 .66484 .51497 .66187 .50987 .65529 Mtetra
.678 .699 .862 r
.50987 .65529 .51497 .66187 .5243 .65891 .51922 .65197 Mtetra
.674 .688 .855 r
.51922 .65197 .5243 .65891 .53367 .65597 .5286 .64872 Mtetra
.668 .678 .85 r
.5286 .64872 .53367 .65597 .54306 .6531 .53801 .64562 Mtetra
.661 .67 .848 r
.53801 .64562 .54306 .6531 .55249 .65033 .54746 .64273 Mtetra
.653 .664 .848 r
.54746 .64273 .55249 .65033 .56195 .64767 .55693 .64009 Mtetra
.644 .661 .852 r
.55693 .64009 .56195 .64767 .57145 .64515 .56645 .63773 Mtetra
.636 .663 .859 r
.56645 .63773 .57145 .64515 .58098 .64274 .576 .63561 Mtetra
.63 .669 .869 r
.576 .63561 .58098 .64274 .59055 .64041 .58559 .63368 Mtetra
.627 .681 .881 r
.58559 .63368 .59055 .64041 .60015 .63809 .59522 .63179 Mtetra
.628 .695 .893 r
.59522 .63179 .60015 .63809 .60979 .63574 .60488 .62984 Mtetra
.633 .712 .903 r
.60488 .62984 .60979 .63574 .61946 .6333 .61458 .6277 Mtetra
.642 .727 .91 r
.61458 .6277 .61946 .6333 .62917 .63073 .62431 .62531 Mtetra
.651 .737 .912 r
.62431 .62531 .62917 .63073 .6389 .62804 .63407 .62268 Mtetra
.659 .743 .912 r
.63407 .62268 .6389 .62804 .64866 .62524 .64385 .61983 Mtetra
.661 .742 .91 r
.64385 .61983 .64866 .62524 .65846 .62241 .65367 .61691 Mtetra
.661 .739 .908 r
.65367 .61691 .65846 .62241 .66829 .61958 .66352 .61401 Mtetra
.657 .736 .908 r
.66352 .61401 .66829 .61958 .67816 .61678 .67341 .61119 Mtetra
.653 .735 .909 r
.67341 .61119 .67816 .61678 .68807 .61403 .68334 .60848 Mtetra
.652 .737 .911 r
.68334 .60848 .68807 .61403 .69801 .61127 .69331 .60577 Mtetra
.654 .74 .912 r
.69331 .60577 .69801 .61127 .70798 .60848 .70331 .60298 Mtetra
.662 .744 .911 r
.70331 .60298 .70798 .60848 .71799 .60558 .71333 .59999 Mtetra
.671 .744 .905 r
.71333 .59999 .71799 .60558 .72802 .60256 .72338 .59676 Mtetra
.68 .74 .896 r
.72338 .59676 .72802 .60256 .73808 .5994 .73344 .59325 Mtetra
.685 .73 .885 r
.73344 .59325 .73808 .5994 .74816 .59615 .74352 .58956 Mtetra
.685 .716 .873 r
.74352 .58956 .74816 .59615 .75828 .59287 .75364 .58581 Mtetra
.681 .702 .862 r
.75364 .58581 .75828 .59287 .76844 .5896 .76378 .58209 Mtetra
.674 .687 .854 r
.76378 .58209 .76844 .5896 .77863 .58641 .77397 .57856 Mtetra
.666 .675 .849 r
.77397 .57856 .77863 .58641 .78887 .58333 .78421 .57527 Mtetra
.657 .666 .848 r
.78421 .57527 .78887 .58333 .79916 .58038 .79452 .57227 Mtetra
.649 .662 .849 r
.79452 .57227 .79916 .58038 .80949 .57755 .80488 .56952 Mtetra
.643 .662 .853 r
.80488 .56952 .80949 .57755 .81987 .57483 .81529 .56699 Mtetra
.638 .665 .86 r
.81529 .56699 .81987 .57483 .8303 .57217 .82577 .56461 Mtetra
.635 .673 .868 r
.82577 .56461 .8303 .57217 .84077 .56954 .83629 .5623 Mtetra
.635 .682 .877 r
.83629 .5623 .84077 .56954 .85128 .56692 .84685 .56001 Mtetra
.636 .693 .886 r
.84685 .56001 .85128 .56692 .86183 .56426 .85745 .55766 Mtetra
.637 .704 .895 r
.85745 .55766 .86183 .56426 .87242 .56157 .86809 .55523 Mtetra
.64 .716 .902 r
.86809 .55523 .87242 .56157 .88304 .55881 .87877 .5527 Mtetra
.643 .725 .908 r
.87877 .5527 .88304 .55881 .89369 .556 .88947 .55006 Mtetra
.646 .734 .913 r
.88947 .55006 .89369 .556 .90438 .55313 .9002 .54732 Mtetra
.648 .74 .916 r
.9002 .54732 .90438 .55313 .91511 .55021 .91097 .54447 Mtetra
.651 .745 .919 r
.91097 .54447 .91511 .55021 .92587 .54724 .92176 .54155 Mtetra
.653 .749 .92 r
.92176 .54155 .92587 .54724 .93667 .54423 .93259 .53856 Mtetra
.654 .751 .921 r
.93259 .53856 .93667 .54423 .9475 .54118 .94346 .53551 Mtetra
.655 .752 .921 r
.94346 .53551 .9475 .54118 .95837 .53811 .95436 .53242 Mtetra
.656 .752 .921 r
.95436 .53242 .95837 .53811 .96929 .53502 .9653 .5293 Mtetra
.656 .752 .92 r
.9653 .5293 .96929 .53502 .98024 .53192 .97628 .52616 Mtetra
.654 .751 .921 r
.38561 .68781 .391 .69252 .39996 .68999 .39458 .68528 Mtetra
.655 .752 .921 r
.39458 .68528 .39996 .68999 .40895 .68744 .40359 .68273 Mtetra
.656 .753 .921 r
.40359 .68273 .40895 .68744 .41797 .68487 .41263 .68015 Mtetra
.658 .753 .92 r
.41263 .68015 .41797 .68487 .42702 .68226 .4217 .67751 Mtetra
.66 .754 .919 r
.4217 .67751 .42702 .68226 .4361 .6796 .4308 .67481 Mtetra
.664 .753 .917 r
.4308 .67481 .4361 .6796 .44522 .67688 .43994 .67202 Mtetra
.668 .752 .914 r
.43994 .67202 .44522 .67688 .45436 .67408 .4491 .66912 Mtetra
.673 .75 .909 r
.4491 .66912 .45436 .67408 .46354 .67118 .4583 .66609 Mtetra
.678 .747 .903 r
.4583 .66609 .46354 .67118 .47274 .66819 .46753 .66291 Mtetra
.683 .742 .895 r
.46753 .66291 .47274 .66819 .48198 .66509 .47679 .65957 Mtetra
.688 .735 .887 r
.47679 .65957 .48198 .66509 .49125 .66189 .48608 .65608 Mtetra
.69 .727 .878 r
.48608 .65608 .49125 .66189 .50055 .65862 .4954 .65247 Mtetra
.691 .717 .869 r
.4954 .65247 .50055 .65862 .50987 .65529 .50474 .64879 Mtetra
.688 .705 .861 r
.50474 .64879 .50987 .65529 .51922 .65197 .51412 .64511 Mtetra
.683 .694 .854 r
.51412 .64511 .51922 .65197 .5286 .64872 .52351 .64154 Mtetra
.675 .683 .85 r
.52351 .64154 .5286 .64872 .53801 .64562 .53294 .63819 Mtetra
.664 .673 .848 r
.53294 .63819 .53801 .64562 .54746 .64273 .5424 .63517 Mtetra
.652 .666 .85 r
.5424 .63517 .54746 .64273 .55693 .64009 .55189 .63256 Mtetra
.637 .661 .856 r
.55189 .63256 .55693 .64009 .56645 .63773 .56142 .63039 Mtetra
.624 .661 .866 r
.56142 .63039 .56645 .63773 .576 .63561 .57099 .6286 Mtetra
.612 .667 .878 r
.57099 .6286 .576 .63561 .58559 .63368 .5806 .62712 Mtetra
.606 .679 .893 r
.5806 .62712 .58559 .63368 .59522 .63179 .59025 .62572 Mtetra
.606 .696 .907 r
.59025 .62572 .59522 .63179 .60488 .62984 .59995 .62423 Mtetra
.616 .718 .918 r
.59995 .62423 .60488 .62984 .61458 .6277 .60968 .62245 Mtetra
.631 .737 .924 r
.60968 .62245 .61458 .6277 .62431 .62531 .61944 .62025 Mtetra
.647 .751 .925 r
.61944 .62025 .62431 .62531 .63407 .62268 .62922 .61766 Mtetra
.66 .758 .922 r
.62922 .61766 .63407 .62268 .64385 .61983 .63903 .61474 Mtetra
.664 .757 .919 r
.63903 .61474 .64385 .61983 .65367 .61691 .64886 .61171 Mtetra
.663 .753 .917 r
.64886 .61171 .65367 .61691 .66352 .61401 .65874 .60871 Mtetra
.656 .747 .917 r
.65874 .60871 .66352 .61401 .67341 .61119 .66865 .60588 Mtetra
.649 .745 .92 r
.66865 .60588 .67341 .61119 .68334 .60848 .67861 .60321 Mtetra
.647 .747 .923 r
.67861 .60321 .68334 .60848 .69331 .60577 .6886 .60058 Mtetra
.65 .752 .924 r
.6886 .60058 .69331 .60577 .70331 .60298 .69863 .59784 Mtetra
.664 .759 .921 r
.69863 .59784 .70331 .60298 .71333 .59999 .70867 .59477 Mtetra
.679 .761 .914 r
.70867 .59477 .71333 .59999 .72338 .59676 .71873 .59129 Mtetra
.693 .758 .901 r
.71873 .59129 .72338 .59676 .73344 .59325 .7288 .5874 Mtetra
.701 .747 .887 r
.7288 .5874 .73344 .59325 .74352 .58956 .73887 .5832 Mtetra
.701 .731 .873 r
.73887 .5832 .74352 .58956 .75364 .58581 .74897 .57891 Mtetra
.696 .713 .862 r
.74897 .57891 .75364 .58581 .76378 .58209 .75911 .5747 Mtetra
.684 .695 .854 r
.75911 .5747 .76378 .58209 .77397 .57856 .76929 .57079 Mtetra
.672 .681 .85 r
.76929 .57079 .77397 .57856 .78421 .57527 .77954 .56726 Mtetra
.658 .669 .849 r
.77954 .56726 .78421 .57527 .79452 .57227 .78986 .5642 Mtetra
.646 .663 .852 r
.78986 .5642 .79452 .57227 .80488 .56952 .80024 .56154 Mtetra
.636 .661 .858 r
.80024 .56154 .80488 .56952 .81529 .56699 .8107 .55922 Mtetra
.628 .664 .865 r
.8107 .55922 .81529 .56699 .82577 .56461 .82122 .55713 Mtetra
.624 .671 .874 r
.82122 .55713 .82577 .56461 .83629 .5623 .83179 .55515 Mtetra
.622 .68 .884 r
.83179 .55515 .83629 .5623 .84685 .56001 .84241 .55318 Mtetra
.624 .692 .893 r
.84241 .55318 .84685 .56001 .85745 .55766 .85307 .55114 Mtetra
.626 .704 .901 r
.85307 .55114 .85745 .55766 .86809 .55523 .86376 .54898 Mtetra
.631 .716 .908 r
.86376 .54898 .86809 .55523 .87877 .5527 .87448 .54665 Mtetra
.636 .726 .913 r
.87448 .54665 .87877 .5527 .88947 .55006 .88523 .54417 Mtetra
.641 .735 .917 r
.88523 .54417 .88947 .55006 .9002 .54732 .896 .54153 Mtetra
.645 .741 .919 r
.896 .54153 .9002 .54732 .91097 .54447 .9068 .53875 Mtetra
.649 .746 .921 r
.9068 .53875 .91097 .54447 .92176 .54155 .91764 .53586 Mtetra
.652 .75 .921 r
.91764 .53586 .92176 .54155 .93259 .53856 .9285 .53287 Mtetra
.654 .752 .922 r
.9285 .53287 .93259 .53856 .94346 .53551 .9394 .52981 Mtetra
.655 .753 .921 r
.9394 .52981 .94346 .53551 .95436 .53242 .95033 .5267 Mtetra
.657 .753 .921 r
.95033 .5267 .95436 .53242 .9653 .5293 .9613 .52355 Mtetra
.657 .753 .92 r
.9613 .52355 .9653 .5293 .97628 .52616 .9723 .52037 Mtetra
.653 .751 .921 r
.38018 .68308 .38561 .68781 .39458 .68528 .38917 .68055 Mtetra
.654 .752 .922 r
.38917 .68055 .39458 .68528 .40359 .68273 .3982 .678 Mtetra
.655 .753 .922 r
.3982 .678 .40359 .68273 .41263 .68015 .40726 .67542 Mtetra
.658 .754 .921 r
.40726 .67542 .41263 .68015 .4217 .67751 .41635 .67277 Mtetra
.661 .755 .92 r
.41635 .67277 .4217 .67751 .4308 .67481 .42547 .67004 Mtetra
.665 .756 .918 r
.42547 .67004 .4308 .67481 .43994 .67202 .43462 .6672 Mtetra
.671 .755 .914 r
.43462 .6672 .43994 .67202 .4491 .66912 .44381 .66422 Mtetra
.677 .755 .91 r
.44381 .66422 .4491 .66912 .4583 .66609 .45303 .66107 Mtetra
.684 .752 .903 r
.45303 .66107 .4583 .66609 .46753 .66291 .46229 .65772 Mtetra
.691 .748 .896 r
.46229 .65772 .46753 .66291 .47679 .65957 .47157 .65417 Mtetra
.697 .743 .887 r
.47157 .65417 .47679 .65957 .48608 .65608 .48088 .6504 Mtetra
.7 .735 .878 r
.48088 .6504 .48608 .65608 .4954 .65247 .49022 .64648 Mtetra
.702 .725 .868 r
.49022 .64648 .4954 .65247 .50474 .64879 .49959 .64243 Mtetra
.699 .714 .86 r
.49959 .64243 .50474 .64879 .51412 .64511 .50898 .6384 Mtetra
.693 .702 .854 r
.50898 .6384 .51412 .64511 .52351 .64154 .5184 .63449 Mtetra
.683 .69 .851 r
.5184 .63449 .52351 .64154 .53294 .63819 .52784 .63088 Mtetra
.669 .679 .851 r
.52784 .63088 .53294 .63819 .5424 .63517 .53731 .62772 Mtetra
.651 .669 .854 r
.53731 .62772 .5424 .63517 .55189 .63256 .54682 .62513 Mtetra
.63 .662 .862 r
.54682 .62513 .55189 .63256 .56142 .63039 .55636 .62317 Mtetra
.609 .66 .874 r
.55636 .62317 .56142 .63039 .57099 .6286 .56595 .62177 Mtetra
.588 .664 .89 r
.56595 .62177 .57099 .6286 .5806 .62712 .57559 .62081 Mtetra
.577 .677 .908 r
.57559 .62081 .5806 .62712 .59025 .62572 .58527 .61999 Mtetra
.576 .698 .925 r
.58527 .61999 .59025 .62572 .59995 .62423 .595 .61905 Mtetra
.59 .726 .938 r
.595 .61905 .59995 .62423 .60968 .62245 .60476 .61768 Mtetra
.615 .754 .944 r
.60476 .61768 .60968 .62245 .61944 .62025 .61454 .61571 Mtetra
.641 .772 .943 r
.61454 .61571 .61944 .62025 .62922 .61766 .62435 .61314 Mtetra
.663 .781 .936 r
.62435 .61314 .62922 .61766 .63903 .61474 .63418 .61008 Mtetra
.669 .778 .931 r
.63418 .61008 .63903 .61474 .64886 .61171 .64404 .60688 Mtetra
.667 .771 .927 r
.64404 .60688 .64886 .61171 .65874 .60871 .65393 .60375 Mtetra
.655 .762 .928 r
.65393 .60375 .65874 .60871 .66865 .60588 .66387 .6009 Mtetra
.642 .758 .933 r
.66387 .6009 .66865 .60588 .67861 .60321 .67386 .59833 Mtetra
.637 .761 .938 r
.67386 .59833 .67861 .60321 .6886 .60058 .68388 .59584 Mtetra
.642 .769 .94 r
.68388 .59584 .6886 .60058 .69863 .59784 .69394 .5932 Mtetra
.663 .781 .937 r
.69394 .5932 .69863 .59784 .70867 .59477 .70401 .59006 Mtetra
.687 .786 .926 r
.70401 .59006 .70867 .59477 .71873 .59129 .71408 .58633 Mtetra
.709 .783 .91 r
.71408 .58633 .71873 .59129 .7288 .5874 .72415 .58198 Mtetra
.721 .77 .891 r
.72415 .58198 .7288 .5874 .73887 .5832 .73422 .57719 Mtetra
.721 .75 .875 r
.73422 .57719 .73887 .5832 .74897 .57891 .74431 .57227 Mtetra
.713 .728 .862 r
.74431 .57227 .74897 .57891 .75911 .5747 .75443 .56748 Mtetra
.697 .706 .855 r
.75443 .56748 .75911 .5747 .76929 .57079 .7646 .56314 Mtetra
.679 .688 .851 r
.7646 .56314 .76929 .57079 .77954 .56726 .77485 .55936 Mtetra
.66 .674 .852 r
.77485 .55936 .77954 .56726 .78986 .5642 .78518 .55623 Mtetra
.643 .665 .857 r
.78518 .55623 .78986 .5642 .80024 .56154 .7956 .55367 Mtetra
.628 .662 .864 r
.7956 .55367 .80024 .56154 .8107 .55922 .80609 .55157 Mtetra
.617 .663 .872 r
.80609 .55157 .8107 .55922 .82122 .55713 .81666 .54979 Mtetra
.611 .67 .882 r
.81666 .54979 .82122 .55713 .83179 .55515 .82728 .54814 Mtetra
.609 .68 .892 r
.82728 .54814 .83179 .55515 .84241 .55318 .83795 .54651 Mtetra
.611 .693 .901 r
.83795 .54651 .84241 .55318 .85307 .55114 .84867 .54475 Mtetra
.615 .705 .909 r
.84867 .54475 .85307 .55114 .86376 .54898 .85941 .54283 Mtetra
.622 .718 .915 r
.85941 .54283 .86376 .54898 .87448 .54665 .87017 .54069 Mtetra
.629 .728 .919 r
.87017 .54069 .87448 .54665 .88523 .54417 .88097 .53835 Mtetra
.636 .737 .921 r
.88097 .53835 .88523 .54417 .896 .54153 .89178 .53579 Mtetra
.642 .744 .923 r
.89178 .53579 .896 .54153 .9068 .53875 .90262 .53306 Mtetra
.647 .748 .923 r
.90262 .53306 .9068 .53875 .91764 .53586 .91348 .53018 Mtetra
.651 .751 .923 r
.91348 .53018 .91764 .53586 .9285 .53287 .92438 .52719 Mtetra
.654 .753 .923 r
.92438 .52719 .9285 .53287 .9394 .52981 .9353 .5241 Mtetra
.656 .754 .922 r
.9353 .5241 .9394 .52981 .95033 .5267 .94626 .52095 Mtetra
.657 .754 .921 r
.94626 .52095 .95033 .5267 .9613 .52355 .95726 .51776 Mtetra
.658 .753 .92 r
.95726 .51776 .9613 .52355 .9723 .52037 .96829 .51454 Mtetra
.652 .751 .922 r
.37472 .67831 .38018 .68308 .38917 .68055 .38373 .6758 Mtetra
.653 .752 .922 r
.38373 .6758 .38917 .68055 .3982 .678 .39277 .67326 Mtetra
.654 .753 .923 r
.39277 .67326 .3982 .678 .40726 .67542 .40185 .67068 Mtetra
.657 .755 .922 r
.40185 .67068 .40726 .67542 .41635 .67277 .41096 .66804 Mtetra
.66 .756 .921 r
.41096 .66804 .41635 .67277 .42547 .67004 .4201 .6653 Mtetra
.665 .758 .919 r
.4201 .6653 .42547 .67004 .43462 .6672 .42928 .66243 Mtetra
.672 .759 .916 r
.42928 .66243 .43462 .6672 .44381 .66422 .43849 .65939 Mtetra
.68 .759 .911 r
.43849 .65939 .44381 .66422 .45303 .66107 .44773 .65616 Mtetra
.688 .759 .905 r
.44773 .65616 .45303 .66107 .46229 .65772 .45701 .65267 Mtetra
.697 .756 .898 r
.45701 .65267 .46229 .65772 .47157 .65417 .46631 .64894 Mtetra
.705 .752 .888 r
.46631 .64894 .47157 .65417 .48088 .6504 .47565 .64492 Mtetra
.71 .745 .879 r
.47565 .64492 .48088 .6504 .49022 .64648 .48502 .6407 Mtetra
.713 .736 .869 r
.48502 .6407 .49022 .64648 .49959 .64243 .49441 .6363 Mtetra
.71 .725 .861 r
.49441 .6363 .49959 .64243 .50898 .6384 .50382 .63189 Mtetra
.704 .713 .855 r
.50382 .63189 .50898 .6384 .5184 .63449 .51326 .62763 Mtetra
.691 .699 .853 r
.51326 .62763 .5184 .63449 .52784 .63088 .52272 .62374 Mtetra
.673 .686 .854 r
.52272 .62374 .52784 .63088 .53731 .62772 .5322 .62043 Mtetra
.65 .674 .859 r
.5322 .62043 .53731 .62772 .54682 .62513 .54172 .61786 Mtetra
.62 .663 .87 r
.54172 .61786 .54682 .62513 .55636 .62317 .55129 .61615 Mtetra
.589 .658 .886 r
.55129 .61615 .55636 .62317 .56595 .62177 .56089 .6152 Mtetra
.555 .659 .905 r
.56089 .6152 .56595 .62177 .57559 .62081 .57055 .61488 Mtetra
.534 .674 .927 r
.57055 .61488 .57559 .62081 .58527 .61999 .58027 .61475 Mtetra
.526 .699 .949 r
.58027 .61475 .58527 .61999 .595 .61905 .59002 .61448 Mtetra
.546 .738 .964 r
.59002 .61448 .595 .61905 .60476 .61768 .59982 .61361 Mtetra
.587 .777 .97 r
.59982 .61361 .60476 .61768 .61454 .61571 .60964 .61188 Mtetra
.63 .803 .966 r
.60964 .61188 .61454 .61571 .62435 .61314 .61947 .60932 Mtetra
.666 .814 .954 r
.61947 .60932 .62435 .61314 .63418 .61008 .62932 .60605 Mtetra
.676 .808 .946 r
.62932 .60605 .63418 .61008 .64404 .60688 .6392 .6026 Mtetra
.671 .796 .942 r
.6392 .6026 .64404 .60688 .65393 .60375 .64911 .59928 Mtetra
.651 .783 .944 r
.64911 .59928 .65393 .60375 .66387 .6009 .65908 .59641 Mtetra
.628 .776 .951 r
.65908 .59641 .66387 .6009 .67386 .59833 .6691 .594 Mtetra
.619 .78 .958 r
.6691 .594 .67386 .59833 .68388 .59584 .67916 .59172 Mtetra
.624 .793 .963 r
.67916 .59172 .68388 .59584 .69394 .5932 .68926 .58925 Mtetra
.657 .812 .958 r
.68926 .58925 .69394 .5932 .70401 .59006 .69936 .58608 Mtetra
.695 .822 .943 r
.69936 .58608 .70401 .59006 .71408 .58633 .70945 .58206 Mtetra
.728 .818 .92 r
.70945 .58206 .71408 .58633 .72415 .58198 .71951 .57717 Mtetra
.745 .8 .897 r
.71951 .57717 .72415 .58198 .73422 .57719 .72957 .57167 Mtetra
.744 .774 .877 r
.72957 .57167 .73422 .57719 .74431 .57227 .73964 .56601 Mtetra
.733 .747 .863 r
.73964 .56601 .74431 .57227 .75443 .56748 .74974 .56053 Mtetra
.711 .72 .856 r
.74974 .56053 .75443 .56748 .7646 .56314 .75991 .55569 Mtetra
.688 .698 .854 r
.75991 .55569 .7646 .56314 .77485 .55936 .77015 .55161 Mtetra
.662 .68 .857 r
.77015 .55161 .77485 .55936 .78518 .55623 .7805 .54841 Mtetra
.639 .668 .862 r
.7805 .54841 .78518 .55623 .7956 .55367 .79095 .54597 Mtetra
.619 .663 .871 r
.79095 .54597 .7956 .55367 .80609 .55157 .80148 .54412 Mtetra
.604 .664 .881 r
.80148 .54412 .80609 .55157 .81666 .54979 .81209 .54266 Mtetra
.597 .671 .892 r
.81209 .54266 .81666 .54979 .82728 .54814 .82277 .54135 Mtetra
.594 .682 .902 r
.82277 .54135 .82728 .54814 .83795 .54651 .8335 .54004 Mtetra
.598 .695 .911 r
.8335 .54004 .83795 .54651 .84867 .54475 .84426 .53856 Mtetra
.604 .709 .918 r
.84426 .53856 .84867 .54475 .85941 .54283 .85505 .53686 Mtetra
.614 .722 .923 r
.85505 .53686 .85941 .54283 .87017 .54069 .86586 .53488 Mtetra
.623 .732 .925 r
.86586 .53488 .87017 .54069 .88097 .53835 .87669 .53263 Mtetra
.632 .741 .926 r
.87669 .53263 .88097 .53835 .89178 .53579 .88754 .53013 Mtetra
.64 .747 .926 r
.88754 .53013 .89178 .53579 .90262 .53306 .89842 .52741 Mtetra
.646 .751 .926 r
.89842 .52741 .90262 .53306 .91348 .53018 .90931 .52453 Mtetra
.651 .754 .925 r
.90931 .52453 .91348 .53018 .92438 .52719 .92023 .5215 Mtetra
.654 .755 .924 r
.92023 .5215 .92438 .52719 .9353 .5241 .93119 .51838 Mtetra
.657 .755 .922 r
.93119 .51838 .9353 .5241 .94626 .52095 .94217 .51518 Mtetra
.658 .755 .921 r
.94217 .51518 .94626 .52095 .95726 .51776 .9532 .51193 Mtetra
.659 .754 .92 r
.9532 .51193 .95726 .51776 .96829 .51454 .96426 .50866 Mtetra
.651 .75 .922 r
.36922 .67351 .37472 .67831 .38373 .6758 .37825 .67101 Mtetra
.651 .751 .923 r
.37825 .67101 .38373 .6758 .39277 .67326 .38731 .6685 Mtetra
.653 .753 .923 r
.38731 .6685 .39277 .67326 .40185 .67068 .39641 .66593 Mtetra
.655 .755 .923 r
.39641 .66593 .40185 .67068 .41096 .66804 .40553 .6633 Mtetra
.659 .757 .922 r
.40553 .6633 .41096 .66804 .4201 .6653 .4147 .66056 Mtetra
.665 .759 .921 r
.4147 .66056 .4201 .6653 .42928 .66243 .42389 .65769 Mtetra
.672 .761 .918 r
.42389 .65769 .42928 .66243 .43849 .65939 .43312 .65463 Mtetra
.681 .763 .913 r
.43312 .65463 .43849 .65939 .44773 .65616 .44239 .65134 Mtetra
.691 .764 .907 r
.44239 .65134 .44773 .65616 .45701 .65267 .45169 .64776 Mtetra
.702 .763 .9 r
.45169 .64776 .45701 .65267 .46631 .64894 .46102 .64388 Mtetra
.712 .761 .89 r
.46102 .64388 .46631 .64894 .47565 .64492 .47038 .63965 Mtetra
.719 .755 .881 r
.47038 .63965 .47565 .64492 .48502 .6407 .47977 .63516 Mtetra
.723 .748 .871 r
.47977 .63516 .48502 .6407 .49441 .6363 .48919 .63042 Mtetra
.722 .737 .863 r
.48919 .63042 .49441 .6363 .50382 .63189 .49863 .62566 Mtetra
.715 .725 .858 r
.49863 .62566 .50382 .63189 .51326 .62763 .50808 .62103 Mtetra
.701 .711 .856 r
.50808 .62103 .51326 .62763 .52272 .62374 .51756 .61684 Mtetra
.679 .696 .859 r
.51756 .61684 .52272 .62374 .5322 .62043 .52707 .61335 Mtetra
.649 .681 .866 r
.52707 .61335 .5322 .62043 .54172 .61786 .5366 .6108 Mtetra
.608 .666 .88 r
.5366 .6108 .54172 .61786 .55129 .61615 .54618 .60935 Mtetra
.563 .656 .898 r
.54618 .60935 .55129 .61615 .56089 .6152 .55581 .60891 Mtetra
.509 .65 .921 r
.55581 .60891 .56089 .6152 .57055 .61488 .5655 .60932 Mtetra
.47 .661 .945 r
.5655 .60932 .57055 .61488 .58027 .61475 .57524 .61001 Mtetra
.45 .689 .968 r
.57524 .61001 .58027 .61475 .59002 .61448 .58503 .61052 Mtetra
.479 .74 .985 r
.58503 .61052 .59002 .61448 .59982 .61361 .59486 .61022 Mtetra
.546 .796 .991 r
.59486 .61022 .59982 .61361 .60964 .61188 .60471 .60874 Mtetra
.618 .834 .983 r
.60471 .60874 .60964 .61188 .61947 .60932 .61457 .6061 Mtetra
.674 .846 .965 r
.61457 .6061 .61947 .60932 .62932 .60605 .62444 .60248 Mtetra
.688 .834 .953 r
.62444 .60248 .62932 .60605 .6392 .6026 .63434 .59864 Mtetra
.681 .815 .947 r
.63434 .59864 .6392 .6026 .64911 .59928 .64427 .59503 Mtetra
.649 .794 .952 r
.64427 .59503 .64911 .59928 .65908 .59641 .65426 .59215 Mtetra
.61 .781 .963 r
.65426 .59215 .65908 .59641 .6691 .594 .66432 .58999 Mtetra
.591 .787 .974 r
.66432 .58999 .6691 .594 .67916 .59172 .67443 .58806 Mtetra
.594 .806 .981 r
.67443 .58806 .67916 .59172 .68926 .58925 .68457 .58592 Mtetra
.643 .838 .975 r
.68457 .58592 .68926 .58925 .69936 .58608 .6947 .58279 Mtetra
.701 .857 .956 r
.6947 .58279 .69936 .58608 .70945 .58206 .70481 .57849 Mtetra
.75 .854 .927 r
.70481 .57849 .70945 .58206 .71951 .57717 .71488 .57299 Mtetra
.773 .831 .898 r
.71488 .57299 .71951 .57717 .72957 .57167 .72492 .56665 Mtetra
.77 .799 .876 r
.72492 .56665 .72957 .57167 .73964 .56601 .73496 .56012 Mtetra
.755 .766 .862 r
.73496 .56012 .73964 .56601 .74974 .56053 .74504 .55386 Mtetra
.727 .735 .857 r
.74504 .55386 .74974 .56053 .75991 .55569 .7552 .54847 Mtetra
.697 .709 .857 r
.7552 .54847 .75991 .55569 .77015 .55161 .76545 .54407 Mtetra
.664 .687 .862 r
.76545 .54407 .77015 .55161 .7805 .54841 .77581 .54082 Mtetra
.633 .673 .87 r
.77581 .54082 .7805 .54841 .79095 .54597 .78629 .53851 Mtetra
.608 .667 .881 r
.78629 .53851 .79095 .54597 .80148 .54412 .79687 .53693 Mtetra
.589 .666 .893 r
.79687 .53693 .80148 .54412 .81209 .54266 .80753 .53581 Mtetra
.58 .674 .904 r
.80753 .53581 .81209 .54266 .82277 .54135 .81826 .53483 Mtetra
.577 .685 .914 r
.81826 .53483 .82277 .54135 .8335 .54004 .82904 .53382 Mtetra
.584 .699 .922 r
.82904 .53382 .8335 .54004 .84426 .53856 .83985 .53258 Mtetra
.593 .713 .927 r
.83985 .53258 .84426 .53856 .85505 .53686 .85069 .53106 Mtetra
.606 .727 .93 r
.85069 .53106 .85505 .53686 .86586 .53488 .86154 .52919 Mtetra
.618 .737 .931 r
.86154 .52919 .86586 .53488 .87669 .53263 .8724 .527 Mtetra
.63 .745 .931 r
.8724 .527 .87669 .53263 .88754 .53013 .88329 .52452 Mtetra
.639 .75 .929 r
.88329 .52452 .88754 .53013 .89842 .52741 .89419 .52179 Mtetra
.646 .754 .928 r
.89419 .52179 .89842 .52741 .90931 .52453 .90511 .51887 Mtetra
.652 .756 .926 r
.90511 .51887 .90931 .52453 .92023 .5215 .91606 .5158 Mtetra
.655 .756 .924 r
.91606 .5158 .92023 .5215 .93119 .51838 .92705 .51263 Mtetra
.658 .756 .922 r
.92705 .51263 .93119 .51838 .94217 .51518 .93806 .50938 Mtetra
.66 .756 .921 r
.93806 .50938 .94217 .51518 .9532 .51193 .94911 .50608 Mtetra
.66 .754 .92 r
.94911 .50608 .9532 .51193 .96426 .50866 .9602 .50275 Mtetra
.649 .75 .923 r
.36369 .66869 .36922 .67351 .37825 .67101 .37274 .6662 Mtetra
.65 .751 .924 r
.37274 .6662 .37825 .67101 .38731 .6685 .38182 .6637 Mtetra
.651 .753 .924 r
.38182 .6637 .38731 .6685 .39641 .66593 .39093 .66116 Mtetra
.654 .755 .924 r
.39093 .66116 .39641 .66593 .40553 .6633 .40008 .65854 Mtetra
.657 .757 .924 r
.40008 .65854 .40553 .6633 .4147 .66056 .40926 .65583 Mtetra
.663 .76 .922 r
.40926 .65583 .4147 .66056 .42389 .65769 .41847 .65297 Mtetra
.671 .763 .92 r
.41847 .65297 .42389 .65769 .43312 .65463 .42772 .64992 Mtetra
.681 .767 .916 r
.42772 .64992 .43312 .65463 .44239 .65134 .43701 .64661 Mtetra
.693 .769 .91 r
.43701 .64661 .44239 .65134 .45169 .64776 .44633 .64299 Mtetra
.705 .771 .903 r
.44633 .64299 .45169 .64776 .46102 .64388 .45569 .63901 Mtetra
.717 .77 .894 r
.45569 .63901 .46102 .64388 .47038 .63965 .46508 .63463 Mtetra
.727 .767 .885 r
.46508 .63463 .47038 .63965 .47977 .63516 .47449 .62991 Mtetra
.734 .761 .874 r
.47449 .62991 .47977 .63516 .48919 .63042 .48394 .62487 Mtetra
.733 .751 .867 r
.48394 .62487 .48919 .63042 .49863 .62566 .4934 .61976 Mtetra
.727 .739 .861 r
.4934 .61976 .49863 .62566 .50808 .62103 .50288 .61476 Mtetra
.711 .725 .86 r
.50288 .61476 .50808 .62103 .51756 .61684 .51238 .61025 Mtetra
.686 .708 .865 r
.51238 .61025 .51756 .61684 .52707 .61335 .52191 .60655 Mtetra
.649 .69 .875 r
.52191 .60655 .52707 .61335 .5366 .6108 .53146 .604 Mtetra
.595 .67 .892 r
.53146 .604 .5366 .6108 .54618 .60935 .54105 .60283 Mtetra
.529 .651 .913 r
.54105 .60283 .54618 .60935 .55581 .60891 .5507 .60295 Mtetra
.443 .633 .936 r
.5507 .60295 .55581 .60891 .5655 .60932 .56041 .60419 Mtetra
.372 .634 .956 r
.56041 .60419 .5655 .60932 .57524 .61001 .57018 .60584 Mtetra
.327 .656 .971 r
.57018 .60584 .57524 .61001 .58503 .61052 .58001 .60728 Mtetra
.368 .724 .988 r
.58001 .60728 .58503 .61052 .59486 .61022 .58988 .60763 Mtetra
.481 .809 1 r
.58988 .60763 .59486 .61022 .60471 .60874 .59976 .60639 Mtetra
.601 .867 .993 r
.59976 .60639 .60471 .60874 .61457 .6061 .60965 .60356 Mtetra
.69 .882 .969 r
.60965 .60356 .61457 .6061 .62444 .60248 .61954 .59939 Mtetra
.709 .861 .954 r
.61954 .59939 .62444 .60248 .63434 .59864 .62945 .59497 Mtetra
.696 .832 .948 r
.62945 .59497 .63434 .59864 .64427 .59503 .6394 .59094 Mtetra
.646 .802 .957 r
.6394 .59094 .64427 .59503 .65426 .59215 .64942 .58804 Mtetra
.583 .78 .973 r
.64942 .58804 .65426 .59215 .66432 .58999 .65952 .58626 Mtetra
.544 .784 .987 r
.65952 .58626 .66432 .58999 .67443 .58806 .66968 .58489 Mtetra
.538 .809 .996 r
.66968 .58489 .67443 .58806 .68457 .58592 .67988 .58326 Mtetra
.612 .862 .99 r
.67988 .58326 .68457 .58592 .6947 .58279 .69005 .58029 Mtetra
.701 .895 .967 r
.69005 .58029 .6947 .58279 .70481 .57849 .70018 .57571 Mtetra
.772 .893 .93 r
.70018 .57571 .70481 .57849 .71488 .57299 .71025 .56952 Mtetra
.803 .866 .895 r
.71025 .56952 .71488 .57299 .72492 .56665 .72027 .56221 Mtetra
.799 .827 .873 r
.72027 .56221 .72492 .56665 .73496 .56012 .73029 .55467 Mtetra
.78 .788 .859 r
.73029 .55467 .73496 .56012 .74504 .55386 .74035 .54753 Mtetra
.745 .751 .858 r
.74035 .54753 .74504 .55386 .7552 .54847 .75049 .54152 Mtetra
.707 .721 .861 r
.75049 .54152 .7552 .54847 .76545 .54407 .76074 .5368 Mtetra
.665 .697 .87 r
.76074 .5368 .76545 .54407 .77581 .54082 .77112 .5335 Mtetra
.627 .68 .881 r
.77112 .5335 .77581 .54082 .78629 .53851 .78164 .53137 Mtetra
.595 .671 .893 r
.78164 .53137 .78629 .53851 .79687 .53693 .79226 .53008 Mtetra
.571 .67 .906 r
.79226 .53008 .79687 .53693 .80753 .53581 .80297 .5293 Mtetra
.561 .678 .917 r
.80297 .5293 .80753 .53581 .81826 .53483 .81375 .52864 Mtetra
.559 .69 .927 r
.81375 .52864 .81826 .53483 .82904 .53382 .82458 .5279 Mtetra
.57 .706 .934 r
.82458 .5279 .82904 .53382 .83985 .53258 .83544 .52685 Mtetra
.583 .72 .937 r
.83544 .52685 .83985 .53258 .85069 .53106 .84631 .52545 Mtetra
.6 .733 .938 r
.84631 .52545 .85069 .53106 .86154 .52919 .8572 .52364 Mtetra
.615 .743 .937 r
.8572 .52364 .86154 .52919 .8724 .527 .8681 .52146 Mtetra
.629 .75 .935 r
.8681 .52146 .8724 .527 .88329 .52452 .87901 .51896 Mtetra
.639 .754 .932 r
.87901 .51896 .88329 .52452 .89419 .52179 .88994 .51619 Mtetra
.647 .756 .929 r
.88994 .51619 .89419 .52179 .90511 .51887 .90089 .51321 Mtetra
.653 .758 .926 r
.90089 .51321 .90511 .51887 .91606 .5158 .91187 .51008 Mtetra
.657 .757 .924 r
.91187 .51008 .91606 .5158 .92705 .51263 .92287 .50685 Mtetra
.659 .757 .922 r
.92287 .50685 .92705 .51263 .93806 .50938 .93391 .50354 Mtetra
.661 .756 .921 r
.93391 .50354 .93806 .50938 .94911 .50608 .94499 .50018 Mtetra
.661 .755 .92 r
.94499 .50018 .94911 .50608 .9602 .50275 .9561 .4968 Mtetra
.648 .75 .923 r
.35813 .66383 .36369 .66869 .37274 .6662 .36719 .66136 Mtetra
.648 .751 .924 r
.36719 .66136 .37274 .6662 .38182 .6637 .37629 .65887 Mtetra
.65 .752 .924 r
.37629 .65887 .38182 .6637 .39093 .66116 .38542 .65634 Mtetra
.652 .754 .924 r
.38542 .65634 .39093 .66116 .40008 .65854 .39458 .65375 Mtetra
.655 .756 .924 r
.39458 .65375 .40008 .65854 .40926 .65583 .40378 .65106 Mtetra
.661 .76 .923 r
.40378 .65106 .40926 .65583 .41847 .65297 .41302 .64823 Mtetra
.669 .763 .921 r
.41302 .64823 .41847 .65297 .42772 .64992 .42229 .64521 Mtetra
.679 .768 .918 r
.42229 .64521 .42772 .64992 .43701 .64661 .43159 .64193 Mtetra
.692 .772 .913 r
.43159 .64193 .43701 .64661 .44633 .64299 .44094 .6383 Mtetra
.706 .775 .906 r
.44094 .6383 .44633 .64299 .45569 .63901 .45032 .63429 Mtetra
.721 .777 .897 r
.45032 .63429 .45569 .63901 .46508 .63463 .45973 .62982 Mtetra
.732 .776 .888 r
.45973 .62982 .46508 .63463 .47449 .62991 .46918 .62494 Mtetra
.742 .773 .878 r
.46918 .62494 .47449 .62991 .48394 .62487 .47865 .61966 Mtetra
.743 .765 .871 r
.47865 .61966 .48394 .62487 .4934 .61976 .48814 .61425 Mtetra
.739 .755 .865 r
.48814 .61425 .4934 .61976 .50288 .61476 .49765 .60889 Mtetra
.723 .741 .866 r
.49765 .60889 .50288 .61476 .51238 .61025 .50717 .60405 Mtetra
.695 .724 .872 r
.50717 .60405 .51238 .61025 .52191 .60655 .51671 .60011 Mtetra
.65 .702 .885 r
.51671 .60011 .52191 .60655 .53146 .604 .52628 .59751 Mtetra
.58 .675 .905 r
.52628 .59751 .53146 .604 .54105 .60283 .5359 .59659 Mtetra
.487 .644 .926 r
.5359 .59659 .54105 .60283 .5507 .60295 .54556 .59728 Mtetra
.356 .602 .941 r
.54556 .59728 .5507 .60295 .56041 .60419 .55529 .59942 Mtetra
.24 .579 .943 r
.55529 .59942 .56041 .60419 .57018 .60584 .5651 .60211 Mtetra
.163 .582 .935 r
.5651 .60211 .57018 .60584 .58001 .60728 .57496 .60458 Mtetra
.228 .671 .954 r
.57496 .60458 .58001 .60728 .58988 .60763 .58486 .60562 Mtetra
.413 .805 .987 r
.58486 .60562 .58988 .60763 .59976 .60639 .59478 .60456 Mtetra
.604 .892 .989 r
.59478 .60456 .59976 .60639 .60965 .60356 .6047 .60134 Mtetra
.726 .903 .957 r
.6047 .60134 .60965 .60356 .61954 .59939 .6146 .5963 Mtetra
.744 .867 .937 r
.6146 .5963 .61954 .59939 .62945 .59497 .62452 .59101 Mtetra
.721 .826 .93 r
.62452 .59101 .62945 .59497 .6394 .59094 .63448 .58637 Mtetra
.651 .783 .944 r
.63448 .58637 .6394 .59094 .64942 .58804 .64453 .58345 Mtetra
.559 .75 .967 r
.64453 .58345 .64942 .58804 .65952 .58626 .65467 .58224 Mtetra
.492 .749 .986 r
.65467 .58224 .65952 .58626 .66968 .58489 .6649 .58171 Mtetra
.467 .78 .998 r
.6649 .58171 .66968 .58489 .67988 .58326 .67516 .58092 Mtetra
.569 .863 .996 r
.67516 .58092 .67988 .58326 .69005 .58029 .68539 .57832 Mtetra
.698 .918 .969 r
.68539 .57832 .69005 .58029 .70018 .57571 .69555 .57353 Mtetra
.793 .921 .923 r
.69555 .57353 .70018 .57571 .71025 .56952 .70562 .5666 Mtetra
.832 .889 .883 r
.70562 .5666 .71025 .56952 .72027 .56221 .71562 .55821 Mtetra
.827 .846 .862 r
.71562 .55821 .72027 .56221 .73029 .55467 .72561 .54958 Mtetra
.804 .805 .852 r
.72561 .54958 .73029 .55467 .74035 .54753 .73564 .54148 Mtetra
.762 .766 .857 r
.73564 .54148 .74035 .54753 .75049 .54152 .74577 .53486 Mtetra
.717 .735 .865 r
.74577 .53486 .75049 .54152 .76074 .5368 .75603 .52985 Mtetra
.665 .707 .879 r
.75603 .52985 .76074 .5368 .77112 .5335 .76644 .52655 Mtetra
.617 .688 .894 r
.76644 .52655 .77112 .5335 .78164 .53137 .77699 .52462 Mtetra
.578 .678 .908 r
.77699 .52462 .78164 .53137 .79226 .53008 .78766 .52363 Mtetra
.549 .676 .921 r
.78766 .52363 .79226 .53008 .80297 .5293 .79842 .52318 Mtetra
.54 .684 .932 r
.79842 .52318 .80297 .5293 .81375 .52864 .80925 .52279 Mtetra
.541 .696 .94 r
.80925 .52279 .81375 .52864 .82458 .5279 .82012 .52226 Mtetra
.557 .713 .944 r
.82012 .52226 .82458 .5279 .83544 .52685 .83102 .52134 Mtetra
.575 .727 .946 r
.83102 .52134 .83544 .52685 .84631 .52545 .84193 .51999 Mtetra
.597 .739 .944 r
.84193 .51999 .84631 .52545 .8572 .52364 .85285 .51818 Mtetra
.615 .748 .94 r
.85285 .51818 .8572 .52364 .8681 .52146 .86377 .51596 Mtetra
.63 .753 .936 r
.86377 .51596 .8681 .52146 .87901 .51896 .87471 .5134 Mtetra
.641 .756 .932 r
.87471 .5134 .87901 .51896 .88994 .51619 .88566 .51055 Mtetra
.649 .758 .929 r
.88566 .51055 .88994 .51619 .90089 .51321 .89664 .50751 Mtetra
.655 .758 .926 r
.89664 .50751 .90089 .51321 .91187 .51008 .90764 .50431 Mtetra
.658 .758 .923 r
.90764 .50431 .91187 .51008 .92287 .50685 .91867 .50101 Mtetra
.661 .757 .921 r
.91867 .50101 .92287 .50685 .93391 .50354 .92974 .49765 Mtetra
.662 .756 .92 r
.92974 .49765 .93391 .50354 .94499 .50018 .94084 .49423 Mtetra
.662 .755 .919 r
.94084 .49423 .94499 .50018 .9561 .4968 .95198 .4908 Mtetra
.647 .749 .924 r
.35253 .65894 .35813 .66383 .36719 .66136 .36161 .65647 Mtetra
.647 .75 .924 r
.36161 .65647 .36719 .66136 .37629 .65887 .37073 .65398 Mtetra
.649 .751 .924 r
.37073 .65398 .37629 .65887 .38542 .65634 .37987 .65146 Mtetra
.651 .752 .924 r
.37987 .65146 .38542 .65634 .39458 .65375 .38906 .64889 Mtetra
.654 .755 .924 r
.38906 .64889 .39458 .65375 .40378 .65106 .39827 .64623 Mtetra
.659 .758 .923 r
.39827 .64623 .40378 .65106 .41302 .64823 .40753 .64344 Mtetra
.666 .762 .922 r
.40753 .64344 .41302 .64823 .42229 .64521 .41682 .64047 Mtetra
.676 .767 .919 r
.41682 .64047 .42229 .64521 .43159 .64193 .42614 .63724 Mtetra
.689 .773 .915 r
.42614 .63724 .43159 .64193 .44094 .6383 .43551 .63367 Mtetra
.704 .778 .909 r
.43551 .63367 .44094 .6383 .45032 .63429 .44491 .62969 Mtetra
.721 .783 .901 r
.44491 .62969 .45032 .63429 .45973 .62982 .45435 .62521 Mtetra
.735 .786 .893 r
.45435 .62521 .45973 .62982 .46918 .62494 .46382 .62026 Mtetra
.748 .785 .883 r
.46382 .62026 .46918 .62494 .47865 .61966 .47332 .61482 Mtetra
.752 .781 .876 r
.47332 .61482 .47865 .61966 .48814 .61425 .48284 .60917 Mtetra
.751 .773 .871 r
.48284 .60917 .48814 .61425 .49765 .60889 .49237 .60348 Mtetra
.735 .76 .873 r
.49237 .60348 .49765 .60889 .50717 .60405 .50192 .59831 Mtetra
.706 .743 .881 r
.50192 .59831 .50717 .60405 .51671 .60011 .51149 .59409 Mtetra
.653 .719 .897 r
.51149 .59409 .51671 .60011 .52628 .59751 .52108 .5914 Mtetra
.565 .684 .92 r
.52108 .5914 .52628 .59751 .5359 .59659 .53071 .59067 Mtetra
.438 .634 .938 r
.53071 .59067 .5359 .59659 .54556 .59728 .54039 .5919 Mtetra
.245 .555 .932 r
.54039 .5919 .54556 .59728 .55529 .59942 .55015 .59496 Mtetra
.074 .491 .895 r
.55015 .59496 .55529 .59942 .5651 .60211 .55998 .59876 Mtetra
0 .464 .845 r
.55998 .59876 .5651 .60211 .57496 .60458 .56988 .60235 Mtetra
.067 .585 .878 r
.56988 .60235 .57496 .60458 .58486 .60562 .57982 .6041 Mtetra
.351 .792 .961 r
.57982 .6041 .58486 .60562 .59478 .60456 .58977 .6031 Mtetra
.634 .916 .979 r
.58977 .6031 .59478 .60456 .6047 .60134 .59971 .59921 Mtetra
.777 .912 .932 r
.59971 .59921 .6047 .60134 .6146 .5963 .60962 .5929 Mtetra
.784 .858 .905 r
.60962 .5929 .6146 .5963 .62452 .59101 .61953 .58634 Mtetra
.746 .803 .898 r
.61953 .58634 .62452 .59101 .63448 .58637 .62949 .58084 Mtetra
.656 .747 .917 r
.62949 .58084 .63448 .58637 .64453 .58345 .63957 .5779 Mtetra
.53 .698 .946 r
.63957 .5779 .64453 .58345 .65467 .58224 .64977 .57753 Mtetra
.426 .686 .972 r
.64977 .57753 .65467 .58224 .6649 .58171 .66006 .57822 Mtetra
.369 .717 .987 r
.66006 .57822 .6649 .58171 .67516 .58092 .67041 .57868 Mtetra
.507 .843 .997 r
.67041 .57868 .67516 .58092 .68539 .57832 .6807 .57672 Mtetra
.689 .932 .967 r
.6807 .57672 .68539 .57832 .69555 .57353 .6909 .57183 Mtetra
.813 .942 .911 r
.6909 .57183 .69555 .57353 .70562 .5666 .70097 .56416 Mtetra
.859 .907 .865 r
.70097 .56416 .70562 .5666 .71562 .55821 .71095 .5546 Mtetra
.852 .861 .848 r
.71095 .5546 .71562 .55821 .72561 .54958 .72092 .54481 Mtetra
.826 .819 .843 r
.72092 .54481 .72561 .54958 .73564 .54148 .73092 .53573 Mtetra
.778 .781 .855 r
.73092 .53573 .73564 .54148 .74577 .53486 .74105 .52851 Mtetra
.725 .748 .871 r
.74105 .52851 .74577 .53486 .75603 .52985 .75132 .52327 Mtetra
.663 .72 .891 r
.75132 .52327 .75603 .52985 .76644 .52655 .76176 .52003 Mtetra
.604 .698 .91 r
.76176 .52003 .76644 .52655 .77699 .52462 .77235 .51835 Mtetra
.557 .687 .926 r
.77235 .51835 .77699 .52462 .78766 .52363 .78306 .51766 Mtetra
.524 .683 .939 r
.78306 .51766 .78766 .52363 .79842 .52318 .79388 .5175 Mtetra
.518 .692 .948 r
.79388 .5175 .79842 .52318 .80925 .52279 .80475 .51731 Mtetra
.524 .705 .953 r
.80475 .51731 .80925 .52279 .82012 .52226 .81566 .51691 Mtetra
.548 .722 .955 r
.81566 .51691 .82012 .52226 .83102 .52134 .82659 .51602 Mtetra
.572 .735 .953 r
.82659 .51602 .83102 .52134 .84193 .51999 .83753 .51465 Mtetra
.597 .746 .948 r
.83753 .51465 .84193 .51999 .85285 .51818 .84847 .51277 Mtetra
.617 .752 .942 r
.84847 .51277 .85285 .51818 .86377 .51596 .85942 .51045 Mtetra
.633 .756 .936 r
.85942 .51045 .86377 .51596 .87471 .5134 .87038 .50779 Mtetra
.644 .757 .931 r
.87038 .50779 .87471 .5134 .88566 .51055 .88135 .50485 Mtetra
.652 .758 .927 r
.88135 .50485 .88566 .51055 .89664 .50751 .89235 .50173 Mtetra
.657 .757 .924 r
.89235 .50173 .89664 .50751 .90764 .50431 .90338 .49846 Mtetra
.66 .757 .922 r
.90338 .49846 .90764 .50431 .91867 .50101 .91444 .49511 Mtetra
.662 .756 .92 r
.91444 .49511 .91867 .50101 .92974 .49765 .92553 .49169 Mtetra
.663 .756 .919 r
.92553 .49169 .92974 .49765 .94084 .49423 .93666 .48823 Mtetra
.663 .755 .919 r
.93666 .48823 .94084 .49423 .95198 .4908 .94784 .48476 Mtetra
.647 .749 .924 r
.34689 .65403 .35253 .65894 .36161 .65647 .35599 .65154 Mtetra
.35599 .65154 .36161 .65647 .37073 .65398 .36513 .64904 Mtetra
.648 .75 .924 r
.36513 .64904 .37073 .65398 .37987 .65146 .37429 .64651 Mtetra
.65 .751 .923 r
.37429 .64651 .37987 .65146 .38906 .64889 .3835 .64394 Mtetra
.652 .752 .923 r
.3835 .64394 .38906 .64889 .39827 .64623 .39273 .6413 Mtetra
.657 .755 .922 r
.39273 .6413 .39827 .64623 .40753 .64344 .402 .63855 Mtetra
.663 .758 .921 r
.402 .63855 .40753 .64344 .41682 .64047 .41131 .63564 Mtetra
.673 .763 .919 r
.41131 .63564 .41682 .64047 .42614 .63724 .42066 .63248 Mtetra
.685 .77 .916 r
.42066 .63248 .42614 .63724 .43551 .63367 .43004 .629 Mtetra
.7 .777 .911 r
.43004 .629 .43551 .63367 .44491 .62969 .43947 .62511 Mtetra
.718 .785 .905 r
.43947 .62511 .44491 .62969 .45435 .62521 .44893 .6207 Mtetra
.735 .791 .897 r
.44893 .6207 .45435 .62521 .46382 .62026 .45842 .61577 Mtetra
.75 .794 .888 r
.45842 .61577 .46382 .62026 .47332 .61482 .46795 .6103 Mtetra
.758 .794 .882 r
.46795 .6103 .47332 .61482 .48284 .60917 .4775 .60451 Mtetra
.76 .79 .877 r
.4775 .60451 .48284 .60917 .49237 .60348 .48706 .59859 Mtetra
.747 .781 .881 r
.48706 .59859 .49237 .60348 .50192 .59831 .49664 .59312 Mtetra
.718 .766 .891 r
.49664 .59312 .50192 .59831 .51149 .59409 .50623 .58859 Mtetra
.658 .74 .91 r
.50623 .58859 .51149 .59409 .52108 .5914 .51585 .58573 Mtetra
.553 .697 .935 r
.51585 .58573 .52108 .5914 .53071 .59067 .52549 .58507 Mtetra
.387 .624 .947 r
.52549 .58507 .53071 .59067 .54039 .5919 .53519 .58672 Mtetra
.132 .497 .906 r
.53519 .58672 .54039 .5919 .55015 .59496 .54496 .59062 Mtetra
0 .389 .823 r
.54496 .59062 .55015 .59496 .55998 .59876 .55482 .59549 Mtetra
0 .341 .744 r
.55482 .59549 .55998 .59876 .56988 .60235 .56475 .6002 Mtetra
0 .508 .816 r
.56475 .6002 .56988 .60235 .57982 .6041 .57473 .60262 Mtetra
.356 .796 .96 r
.57473 .60262 .57982 .6041 .58977 .6031 .58471 .60153 Mtetra
.702 .928 .965 r
.58471 .60153 .58977 .6031 .59971 .59921 .59467 .59663 Mtetra
.827 .89 .887 r
.59467 .59663 .59971 .59921 .60962 .5929 .60457 .58854 Mtetra
.814 .82 .855 r
.60457 .58854 .60962 .5929 .61953 .58634 .61447 .58024 Mtetra
.762 .757 .848 r
.61447 .58024 .61953 .58634 .62949 .58084 .62443 .57354 Mtetra
.656 .689 .87 r
.62443 .57354 .62949 .58084 .63957 .5779 .63452 .57057 Mtetra
.501 .621 .902 r
.63452 .57057 .63957 .5779 .64977 .57753 .64477 .57136 Mtetra
.362 .591 .932 r
.64477 .57136 .64977 .57753 .66006 .57822 .65515 .57377 Mtetra
.269 .615 .957 r
.65515 .57377 .66006 .57822 .67041 .57868 .6656 .57599 Mtetra
.446 .795 .998 r
.6656 .57599 .67041 .57868 .6807 .57672 .67597 .57501 Mtetra
.688 .928 .969 r
.67597 .57501 .6807 .57672 .6909 .57183 .68621 .57018 Mtetra
.832 .942 .896 r
.68621 .57018 .6909 .57183 .70097 .56416 .69629 .5618 Mtetra
.879 .905 .843 r
.69629 .5618 .70097 .56416 .71095 .5546 .70625 .55107 Mtetra
.87 .862 .829 r
.70625 .55107 .71095 .5546 .72092 .54481 .7162 .54015 Mtetra
.841 .825 .832 r
.7162 .54015 .72092 .54481 .73092 .53573 .72619 .53019 Mtetra
.79 .791 .853 r
.72619 .53019 .73092 .53573 .74105 .52851 .73632 .52249 Mtetra
.73 .762 .878 r
.73632 .52249 .74105 .52851 .75132 .52327 .74661 .51714 Mtetra
.658 .734 .906 r
.74661 .51714 .75132 .52327 .76176 .52003 .75708 .51403 Mtetra
.586 .711 .929 r
.75708 .51403 .76176 .52003 .77235 .51835 .76772 .51263 Mtetra
.532 .698 .945 r
.76772 .51263 .77235 .51835 .78306 .51766 .77849 .5122 Mtetra
.497 .693 .956 r
.77849 .5122 .78306 .51766 .79388 .5175 .78934 .51224 Mtetra
.498 .703 .961 r
.78934 .51224 .79388 .5175 .80475 .51731 .80025 .51216 Mtetra
.513 .715 .963 r
.80025 .51216 .80475 .51731 .81566 .51691 .81119 .51176 Mtetra
.545 .731 .961 r
.81119 .51176 .81566 .51691 .82659 .51602 .82214 .51081 Mtetra
.574 .742 .956 r
.82214 .51081 .82659 .51602 .83753 .51465 .8331 .50932 Mtetra
.602 .75 .948 r
.8331 .50932 .83753 .51465 .84847 .51277 .84406 .50731 Mtetra
.622 .754 .941 r
.84406 .50731 .84847 .51277 .85942 .51045 .85503 .50486 Mtetra
.637 .756 .934 r
.85503 .50486 .85942 .51045 .87038 .50779 .86601 .50208 Mtetra
.648 .756 .928 r
.86601 .50208 .87038 .50779 .88135 .50485 .87701 .49904 Mtetra
.654 .756 .924 r
.87701 .49904 .88135 .50485 .89235 .50173 .88803 .49584 Mtetra
.658 .755 .922 r
.88803 .49584 .89235 .50173 .90338 .49846 .89908 .49251 Mtetra
.661 .755 .92 r
.89908 .49251 .90338 .49846 .91444 .49511 .91017 .48911 Mtetra
.662 .755 .919 r
.91017 .48911 .91444 .49511 .92553 .49169 .92129 .48566 Mtetra
.663 .755 .918 r
.92129 .48566 .92553 .49169 .93666 .48823 .93245 .48218 Mtetra
.93245 .48218 .93666 .48823 .94784 .48476 .94366 .47868 Mtetra
.648 .749 .923 r
.34122 .64908 .34689 .65403 .35599 .65154 .35034 .64656 Mtetra
.35034 .64656 .35599 .65154 .36513 .64904 .3595 .64403 Mtetra
.649 .749 .922 r
.3595 .64403 .36513 .64904 .37429 .64651 .36868 .64148 Mtetra
.65 .749 .922 r
.36868 .64148 .37429 .64651 .3835 .64394 .3779 .63888 Mtetra
.652 .749 .921 r
.3779 .63888 .3835 .64394 .39273 .6413 .38716 .63624 Mtetra
.656 .751 .92 r
.38716 .63624 .39273 .6413 .402 .63855 .39645 .63351 Mtetra
.66 .753 .919 r
.39645 .63351 .402 .63855 .41131 .63564 .40577 .63065 Mtetra
.669 .758 .917 r
.40577 .63065 .41131 .63564 .42066 .63248 .41514 .62757 Mtetra
.68 .764 .915 r
.41514 .62757 .42066 .63248 .43004 .629 .42454 .62421 Mtetra
.694 .773 .912 r
.42454 .62421 .43004 .629 .43947 .62511 .43398 .62046 Mtetra
.712 .782 .907 r
.43398 .62046 .43947 .62511 .44893 .6207 .44347 .61622 Mtetra
.73 .792 .902 r
.44347 .61622 .44893 .6207 .45842 .61577 .45298 .61144 Mtetra
.748 .801 .895 r
.45298 .61144 .45842 .61577 .46795 .6103 .46254 .60607 Mtetra
.76 .807 .89 r
.46254 .60607 .46795 .6103 .4775 .60451 .47211 .60028 Mtetra
.767 .808 .886 r
.47211 .60028 .4775 .60451 .48706 .59859 .48171 .59424 Mtetra
.757 .804 .891 r
.48171 .59424 .48706 .59859 .49664 .59312 .49132 .58854 Mtetra
.73 .793 .902 r
.49132 .58854 .49664 .59312 .50623 .58859 .50094 .5837 Mtetra
.667 .767 .925 r
.50094 .5837 .50623 .58859 .51585 .58573 .51057 .58056 Mtetra
.547 .717 .951 r
.51057 .58056 .51585 .58573 .52549 .58507 .52024 .5798 Mtetra
.345 .618 .953 r
.52024 .5798 .52549 .58507 .53519 .58672 .52995 .58169 Mtetra
.035 .441 .872 r
.52995 .58169 .53519 .58672 .54496 .59062 .53974 .58624 Mtetra
0 .299 .752 r
.53974 .58624 .54496 .59062 .55482 .59549 .54962 .59206 Mtetra
0 .243 .664 r
.54962 .59206 .55482 .59549 .56475 .6002 .55958 .59784 Mtetra
0 .462 .793 r
.55958 .59784 .56475 .6002 .57473 .60262 .56959 .60082 Mtetra
.42 .819 .983 r
.56959 .60082 .57473 .60262 .58471 .60153 .5796 .59945 Mtetra
.776 .914 .933 r
.5796 .59945 .58471 .60153 .59467 .59663 .58956 .59311 Mtetra
.859 .846 .83 r
.58956 .59311 .59467 .59663 .60457 .58854 .59945 .58262 Mtetra
.828 .771 .799 r
.59945 .58262 .60457 .58854 .61447 .58024 .60933 .572 Mtetra
.767 .705 .794 r
.60933 .572 .61447 .58024 .62443 .57354 .61926 .5637 Mtetra
.648 .628 .816 r
.61926 .5637 .62443 .57354 .63452 .57057 .62936 .56072 Mtetra
.47 .537 .844 r
.62936 .56072 .63452 .57057 .64477 .57136 .63968 .56306 Mtetra
.299 .481 .87 r
.63968 .56306 .64477 .57136 .65515 .57377 .65015 .56774 Mtetra
.167 .483 .899 r
.65015 .56774 .65515 .57377 .6656 .57599 .66071 .57234 Mtetra
.378 .717 .988 r
.66071 .57234 .6656 .57599 .67597 .57501 .67117 .57277 Mtetra
.688 .907 .972 r
.67117 .57277 .67597 .57501 .68621 .57018 .68146 .56819 Mtetra
.847 .928 .882 r
.68146 .56819 .68621 .57018 .69629 .5618 .69156 .55921 Mtetra
.892 .892 .822 r
.69156 .55921 .69629 .5618 .70625 .55107 .70151 .54737 Mtetra
.88 .854 .812 r
.70151 .54737 .70625 .55107 .7162 .54015 .71144 .53545 Mtetra
.851 .824 .821 r
.71144 .53545 .7162 .54015 .72619 .53019 .72143 .52478 Mtetra
.797 .798 .853 r
.72143 .52478 .72619 .53019 .73632 .52249 .73158 .51681 Mtetra
.73 .775 .889 r
.73158 .51681 .73632 .52249 .74661 .51714 .74191 .51152 Mtetra
.646 .751 .925 r
.74191 .51152 .74661 .51714 .75708 .51403 .75243 .50865 Mtetra
.56 .726 .952 r
.75243 .50865 .75708 .51403 .76772 .51263 .76311 .50754 Mtetra
.501 .712 .965 r
.76311 .50754 .76772 .51263 .77849 .5122 .77392 .5073 Mtetra
.469 .706 .972 r
.77392 .5073 .77849 .5122 .78934 .51224 .78481 .50743 Mtetra
.483 .717 .974 r
.78481 .50743 .78934 .51224 .80025 .51216 .79574 .5073 Mtetra
.511 .729 .972 r
.79574 .5073 .80025 .51216 .81119 .51176 .8067 .50676 Mtetra
.55 .742 .965 r
.8067 .50676 .81119 .51176 .82214 .51081 .81767 .50562 Mtetra
.583 .749 .956 r
.81767 .50562 .82214 .51081 .8331 .50932 .82864 .50392 Mtetra
.61 .752 .946 r
.82864 .50392 .8331 .50932 .84406 .50731 .83961 .50172 Mtetra
.629 .753 .937 r
.83961 .50172 .84406 .50731 .85503 .50486 .85059 .49911 Mtetra
.642 .753 .929 r
.85059 .49911 .85503 .50486 .86601 .50208 .86159 .4962 Mtetra
.651 .753 .924 r
.86159 .4962 .86601 .50208 .87701 .49904 .87261 .49307 Mtetra
.656 .752 .921 r
.87261 .49307 .87701 .49904 .88803 .49584 .88366 .48981 Mtetra
.659 .752 .919 r
.88366 .48981 .88803 .49584 .89908 .49251 .89475 .48644 Mtetra
.661 .752 .918 r
.89475 .48644 .89908 .49251 .91017 .48911 .90586 .48302 Mtetra
.662 .753 .917 r
.90586 .48302 .91017 .48911 .92129 .48566 .91702 .47955 Mtetra
.663 .753 .917 r
.91702 .47955 .92129 .48566 .93245 .48218 .92821 .47606 Mtetra
.662 .754 .918 r
.92821 .47606 .93245 .48218 .94366 .47868 .93945 .47256 Mtetra
.649 .75 .923 r
.33552 .6441 .34122 .64908 .35034 .64656 .34466 .64153 Mtetra
.649 .749 .922 r
.34466 .64153 .35034 .64656 .3595 .64403 .35383 .63896 Mtetra
.65 .748 .921 r
.35383 .63896 .3595 .64403 .36868 .64148 .36304 .63637 Mtetra
.651 .747 .92 r
.36304 .63637 .36868 .64148 .3779 .63888 .37228 .63374 Mtetra
.652 .747 .919 r
.37228 .63374 .3779 .63888 .38716 .63624 .38155 .63107 Mtetra
.655 .747 .918 r
.38155 .63107 .38716 .63624 .39645 .63351 .39086 .62833 Mtetra
.659 .749 .916 r
.39086 .62833 .39645 .63351 .40577 .63065 .40021 .62549 Mtetra
.666 .752 .915 r
.40021 .62549 .40577 .63065 .41514 .62757 .40959 .62248 Mtetra
.674 .757 .913 r
.40959 .62248 .41514 .62757 .42454 .62421 .41901 .61924 Mtetra
.687 .765 .911 r
.41901 .61924 .42454 .62421 .43398 .62046 .42847 .61565 Mtetra
.703 .776 .908 r
.42847 .61565 .43398 .62046 .44347 .61622 .43797 .61163 Mtetra
.721 .788 .905 r
.43797 .61163 .44347 .61622 .45298 .61144 .44751 .6071 Mtetra
.74 .801 .901 r
.44751 .6071 .45298 .61144 .46254 .60607 .45708 .60197 Mtetra
.756 .813 .898 r
.45708 .60197 .46254 .60607 .47211 .60028 .46668 .59637 Mtetra
.768 .822 .895 r
.46668 .59637 .47211 .60028 .48171 .59424 .47631 .59039 Mtetra
.762 .825 .901 r
.47631 .59039 .48171 .59424 .49132 .58854 .48595 .58459 Mtetra
.741 .821 .913 r
.48595 .58459 .49132 .58854 .50094 .5837 .4956 .57947 Mtetra
.678 .799 .94 r
.4956 .57947 .50094 .5837 .51057 .58056 .50526 .57601 Mtetra
.551 .746 .967 r
.50526 .57601 .51057 .58056 .52024 .5798 .51495 .57493 Mtetra
.324 .626 .96 r
.51495 .57493 .52024 .5798 .52995 .58169 .52468 .57674 Mtetra
0 .412 .852 r
.52468 .57674 .52995 .58169 .53974 .58624 .53449 .58158 Mtetra
0 .255 .723 r
.53449 .58158 .53974 .58624 .54962 .59206 .54438 .58803 Mtetra
0 .202 .653 r
.54438 .58803 .54962 .59206 .55958 .59784 .55436 .59466 Mtetra
0 .471 .84 r
.55436 .59466 .55958 .59784 .56959 .60082 .5644 .59807 Mtetra
.526 .826 .999 r
.5644 .59807 .56959 .60082 .5796 .59945 .57443 .5963 Mtetra
.821 .867 .881 r
.57443 .5963 .5796 .59945 .58956 .59311 .5844 .58824 Mtetra
.871 .798 .776 r
.5844 .58824 .58956 .59311 .59945 .58262 .59427 .57486 Mtetra
.833 .731 .751 r
.59427 .57486 .59945 .58262 .60933 .572 .60411 .56145 Mtetra
.769 .667 .751 r
.60411 .56145 .60933 .572 .61926 .5637 .614 .55119 Mtetra
.639 .581 .774 r
.614 .55119 .61926 .5637 .62936 .56072 .62411 .54818 Mtetra
.432 .465 .794 r
.62411 .54818 .62936 .56072 .63968 .56306 .63448 .55243 Mtetra
.228 .377 .806 r
.63448 .55243 .63968 .56306 .65015 .56774 .64506 .55988 Mtetra
.064 .348 .822 r
.64506 .55988 .65015 .56774 .66071 .57234 .65573 .56733 Mtetra
.313 .618 .957 r
.65573 .56733 .66071 .57234 .67117 .57277 .66629 .56946 Mtetra
.689 .86 .964 r
.66629 .56946 .67117 .57277 .68146 .56819 .67663 .56525 Mtetra
.851 .889 .865 r
.67663 .56525 .68146 .56819 .69156 .55921 .68675 .5558 Mtetra
.892 .86 .802 r
.68675 .5558 .69156 .55921 .70151 .54737 .6967 .54306 Mtetra
.879 .834 .797 r
.6967 .54306 .70151 .54737 .71144 .53545 .70664 .53046 Mtetra
.852 .816 .814 r
.70664 .53046 .71144 .53545 .72143 .52478 .71665 .51946 Mtetra
.797 .802 .856 r
.71665 .51946 .72143 .52478 .73158 .51681 .72684 .51152 Mtetra
.723 .789 .904 r
.72684 .51152 .73158 .51681 .74191 .51152 .73721 .50652 Mtetra
.627 .77 .949 r
.73721 .50652 .74191 .51152 .75243 .50865 .74779 .50395 Mtetra
.527 .743 .974 r
.74779 .50395 .75243 .50865 .76311 .50754 .75852 .50308 Mtetra
.471 .728 .982 r
.75852 .50308 .76311 .50754 .77392 .5073 .76936 .5029 Mtetra
.452 .722 .983 r
.76936 .5029 .77392 .5073 .78481 .50743 .78027 .50294 Mtetra
.483 .733 .981 r
.78027 .50294 .78481 .50743 .79574 .5073 .79122 .50258 Mtetra
.522 .742 .975 r
.79122 .50258 .79574 .5073 .8067 .50676 .80218 .50175 Mtetra
.565 .749 .964 r
.80218 .50175 .8067 .50676 .81767 .50562 .81315 .50031 Mtetra
.597 .751 .951 r
.81315 .50031 .81767 .50562 .82864 .50392 .82413 .49834 Mtetra
.62 .751 .94 r
.82413 .49834 .82864 .50392 .83961 .50172 .83512 .49593 Mtetra
.636 .75 .931 r
.83512 .49593 .83961 .50172 .85059 .49911 .84611 .49316 Mtetra
.646 .749 .924 r
.84611 .49316 .85059 .49911 .86159 .4962 .85713 .49014 Mtetra
.653 .748 .92 r
.85713 .49014 .86159 .4962 .87261 .49307 .86818 .48694 Mtetra
.657 .748 .917 r
.86818 .48694 .87261 .49307 .88366 .48981 .87926 .48365 Mtetra
.659 .749 .916 r
.87926 .48365 .88366 .48981 .89475 .48644 .89037 .48027 Mtetra
.66 .75 .916 r
.89037 .48027 .89475 .48644 .90586 .48302 .90152 .47684 Mtetra
.661 .751 .916 r
.90152 .47684 .90586 .48302 .91702 .47955 .91271 .47338 Mtetra
.662 .752 .917 r
.91271 .47338 .91702 .47955 .92821 .47606 .92394 .46989 Mtetra
.662 .753 .918 r
.92394 .46989 .92821 .47606 .93945 .47256 .93521 .46639 Mtetra
.651 .75 .922 r
.32977 .63908 .33552 .6441 .34466 .64153 .33894 .63647 Mtetra
.651 .749 .921 r
.33894 .63647 .34466 .64153 .35383 .63896 .34813 .63385 Mtetra
.652 .748 .92 r
.34813 .63385 .35383 .63896 .36304 .63637 .35736 .63119 Mtetra
.653 .747 .918 r
.35736 .63119 .36304 .63637 .37228 .63374 .36662 .62851 Mtetra
.654 .745 .917 r
.36662 .62851 .37228 .63374 .38155 .63107 .37591 .62579 Mtetra
.656 .745 .915 r
.37591 .62579 .38155 .63107 .39086 .62833 .38524 .62301 Mtetra
.659 .744 .913 r
.38524 .62301 .39086 .62833 .40021 .62549 .39461 .62015 Mtetra
.664 .746 .911 r
.39461 .62015 .40021 .62549 .40959 .62248 .40401 .61717 Mtetra
.67 .749 .909 r
.40401 .61717 .40959 .62248 .41901 .61924 .41345 .61401 Mtetra
.68 .755 .908 r
.41345 .61401 .41901 .61924 .42847 .61565 .42293 .61058 Mtetra
.693 .765 .907 r
.42293 .61058 .42847 .61565 .43797 .61163 .43244 .60682 Mtetra
.708 .778 .907 r
.43244 .60682 .43797 .61163 .44751 .6071 .442 .60262 Mtetra
.726 .795 .906 r
.442 .60262 .44751 .6071 .45708 .60197 .45159 .5979 Mtetra
.744 .814 .907 r
.45159 .5979 .45708 .60197 .46668 .59637 .46121 .59268 Mtetra
.76 .832 .907 r
.46121 .59268 .46668 .59637 .47631 .59039 .47086 .58699 Mtetra
.761 .845 .915 r
.47086 .58699 .47631 .59039 .48595 .58459 .48053 .58129 Mtetra
.748 .85 .926 r
.48053 .58129 .48595 .58459 .4956 .57947 .49022 .576 Mtetra
.69 .836 .953 r
.49022 .576 .4956 .57947 .50526 .57601 .49991 .57214 Mtetra
.57 .786 .98 r
.49991 .57214 .50526 .57601 .51495 .57493 .50963 .57048 Mtetra
.341 .657 .971 r
.50963 .57048 .51495 .57493 .52468 .57674 .51938 .5718 Mtetra
.009 .431 .863 r
.51938 .5718 .52468 .57674 .53449 .58158 .52919 .57641 Mtetra
0 .269 .748 r
.52919 .57641 .53449 .58158 .54438 .58803 .53909 .58302 Mtetra
0 .219 .701 r
.53909 .58302 .54438 .58803 .55436 .59466 .54909 .59015 Mtetra
.087 .504 .902 r
.54909 .59015 .55436 .59466 .5644 .59807 .55914 .5938 Mtetra
.608 .787 .967 r
.55914 .5938 .5644 .59807 .57443 .5963 .5692 .59157 Mtetra
.835 .808 .824 r
.5692 .59157 .57443 .5963 .5844 .58824 .57917 .58159 Mtetra
.871 .754 .731 r
.57917 .58159 .5844 .58824 .59427 .57486 .58901 .56491 Mtetra
.833 .697 .713 r
.58901 .56491 .59427 .57486 .60411 .56145 .59881 .54825 Mtetra
.769 .637 .716 r
.59881 .54825 .60411 .56145 .614 .55119 .60866 .53569 Mtetra
.63 .544 .739 r
.60866 .53569 .614 .55119 .62411 .54818 .61876 .53265 Mtetra
.395 .403 .751 r
.61876 .53265 .62411 .54818 .63448 .55243 .62919 .53915 Mtetra
.163 .286 .744 r
.62919 .53915 .63448 .55243 .64506 .55988 .63986 .54981 Mtetra
0 .23 .743 r
.63986 .54981 .64506 .55988 .65573 .56733 .65065 .56053 Mtetra
.264 .516 .906 r
.65065 .56053 .65573 .56733 .66629 .56946 .6613 .56456 Mtetra
.681 .79 .932 r
.6613 .56456 .66629 .56946 .67663 .56525 .67169 .56078 Mtetra
.838 .832 .84 r
.67169 .56078 .67663 .56525 .68675 .5558 .68184 .55104 Mtetra
.879 .818 .785 r
.68184 .55104 .68675 .5558 .6967 .54306 .69181 .53774 Mtetra
.867 .804 .786 r
.69181 .53774 .6967 .54306 .70664 .53046 .70178 .52494 Mtetra
.841 .8 .811 r
.70178 .52494 .70664 .53046 .71665 .51946 .71184 .51415 Mtetra
.787 .803 .865 r
.71184 .51415 .71665 .51946 .72684 .51152 .72209 .50667 Mtetra
.704 .803 .926 r
.72209 .50667 .72684 .51152 .73721 .50652 .73253 .50222 Mtetra
.595 .791 .974 r
.73253 .50222 .73721 .50652 .74779 .50395 .74316 .50002 Mtetra
.486 .761 .992 r
.74316 .50002 .74779 .50395 .75852 .50308 .75394 .49928 Mtetra
.445 .749 .993 r
.75394 .49928 .75852 .50308 .76936 .5029 .7648 .49897 Mtetra
.451 .745 .991 r
.7648 .49897 .76936 .5029 .78027 .50294 .77572 .49867 Mtetra
.502 .755 .986 r
.77572 .49867 .78027 .50294 .79122 .50258 .78666 .49788 Mtetra
.548 .756 .974 r
.78666 .49788 .79122 .50258 .80218 .50175 .79762 .49658 Mtetra
.587 .754 .958 r
.79762 .49658 .80218 .50175 .81315 .50031 .80859 .49476 Mtetra
.613 .75 .943 r
.80859 .49476 .81315 .50031 .82413 .49834 .81957 .49249 Mtetra
.63 .746 .931 r
.81957 .49249 .82413 .49834 .83512 .49593 .83057 .48986 Mtetra
.642 .743 .923 r
.83057 .48986 .83512 .49593 .84611 .49316 .84158 .48696 Mtetra
.649 .742 .918 r
.84158 .48696 .84611 .49316 .85713 .49014 .85263 .48388 Mtetra
.654 .743 .915 r
.85263 .48388 .85713 .49014 .86818 .48694 .8637 .48066 Mtetra
.656 .744 .914 r
.8637 .48066 .86818 .48694 .87926 .48365 .87481 .47736 Mtetra
.658 .745 .914 r
.87481 .47736 .87926 .48365 .89037 .48027 .88596 .474 Mtetra
.659 .747 .915 r
.88596 .474 .89037 .48027 .90152 .47684 .89715 .47059 Mtetra
.66 .749 .916 r
.89715 .47059 .90152 .47684 .91271 .47338 .90837 .46715 Mtetra
.66 .751 .917 r
.90837 .46715 .91271 .47338 .92394 .46989 .91964 .46367 Mtetra
.66 .752 .918 r
.91964 .46367 .92394 .46989 .93521 .46639 .93095 .46018 Mtetra
.652 .75 .922 r
.32399 .63404 .32977 .63908 .33894 .63647 .33318 .63139 Mtetra
.652 .75 .921 r
.33318 .63139 .33894 .63647 .34813 .63385 .34239 .62871 Mtetra
.653 .749 .92 r
.34239 .62871 .34813 .63385 .35736 .63119 .35164 .626 Mtetra
.655 .748 .918 r
.35164 .626 .35736 .63119 .36662 .62851 .36092 .62326 Mtetra
.656 .746 .916 r
.36092 .62326 .36662 .62851 .37591 .62579 .37024 .62047 Mtetra
.658 .745 .914 r
.37024 .62047 .37591 .62579 .38524 .62301 .37959 .61762 Mtetra
.661 .744 .912 r
.37959 .61762 .38524 .62301 .39461 .62015 .38898 .61471 Mtetra
.664 .743 .909 r
.38898 .61471 .39461 .62015 .40401 .61717 .3984 .6117 Mtetra
.669 .744 .907 r
.3984 .6117 .40401 .61717 .41345 .61401 .40786 .60856 Mtetra
.675 .748 .905 r
.40786 .60856 .41345 .61401 .42293 .61058 .41735 .60525 Mtetra
.684 .754 .905 r
.41735 .60525 .42293 .61058 .43244 .60682 .42688 .6017 Mtetra
.695 .766 .906 r
.42688 .6017 .43244 .60682 .442 .60262 .43645 .59785 Mtetra
.708 .782 .909 r
.43645 .59785 .442 .60262 .45159 .5979 .44606 .59362 Mtetra
.725 .805 .914 r
.44606 .59362 .45159 .5979 .46121 .59268 .4557 .58895 Mtetra
.743 .83 .918 r
.4557 .58895 .46121 .59268 .47086 .58699 .46537 .58378 Mtetra
.749 .854 .928 r
.46537 .58378 .47086 .58699 .48053 .58129 .47507 .57844 Mtetra
.744 .87 .938 r
.47507 .57844 .48053 .58129 .49022 .576 .48479 .57321 Mtetra
.698 .869 .962 r
.48479 .57321 .49022 .576 .49991 .57214 .49451 .56901 Mtetra
.599 .831 .988 r
.49451 .56901 .49991 .57214 .50963 .57048 .50426 .56658 Mtetra
.396 .713 .986 r
.50426 .56658 .50963 .57048 .51938 .5718 .51403 .56696 Mtetra
.107 .502 .905 r
.51403 .56696 .51938 .5718 .52919 .57641 .52386 .57064 Mtetra
0 .342 .814 r
.52386 .57064 .52919 .57641 .53909 .58302 .53377 .5767 Mtetra
0 .288 .782 r
.53377 .5767 .53909 .58302 .54909 .59015 .54377 .58377 Mtetra
.242 .521 .913 r
.54377 .58377 .54909 .59015 .55914 .5938 .55383 .58748 Mtetra
.635 .716 .906 r
.55383 .58748 .55914 .5938 .5692 .59157 .56391 .58504 Mtetra
.83 .757 .782 r
.56391 .58504 .5692 .59157 .57917 .58159 .57389 .57347 Mtetra
.87 .729 .703 r
.57389 .57347 .57917 .58159 .58901 .56491 .58372 .55379 Mtetra
.84 .686 .691 r
.58372 .55379 .58901 .56491 .59881 .54825 .59348 .53403 Mtetra
.78 .634 .699 r
.59348 .53403 .59881 .54825 .60866 .53569 .60329 .51913 Mtetra
.627 .534 .729 r
.60329 .51913 .60866 .53569 .61876 .53265 .61338 .51606 Mtetra
.333 .353 .732 r
.61338 .51606 .61876 .53265 .62919 .53915 .62385 .52484 Mtetra
.048 .193 .694 r
.62385 .52484 .62919 .53915 .63986 .54981 .6346 .53856 Mtetra
0 .122 .67 r
.6346 .53856 .63986 .54981 .65065 .56053 .64549 .55225 Mtetra
.229 .445 .863 r
.64549 .55225 .65065 .56053 .6613 .56456 .65621 .55784 Mtetra
.673 .723 .887 r
.65621 .55784 .6613 .56456 .67169 .56078 .66663 .55422 Mtetra
.812 .766 .81 r
.66663 .55422 .67169 .56078 .68184 .55104 .67681 .54438 Mtetra
.852 .768 .769 r
.67681 .54438 .68184 .55104 .69181 .53774 .68682 .5311 Mtetra
.843 .769 .78 r
.68682 .5311 .69181 .53774 .70178 .52494 .69685 .51882 Mtetra
.82 .782 .816 r
.69685 .51882 .70178 .52494 .71184 .51415 .707 .50893 Mtetra
.767 .804 .883 r
.707 .50893 .71184 .51415 .72209 .50667 .71733 .50237 Mtetra
.671 .818 .954 r
.71733 .50237 .72209 .50667 .73253 .50222 .72786 .49867 Mtetra
.552 .81 .994 r
.72786 .49867 .73253 .50222 .74316 .50002 .73855 .49677 Mtetra
.453 .78 .998 r
.73855 .49677 .74316 .50002 .75394 .49928 .74935 .49594 Mtetra
.448 .774 .998 r
.74935 .49594 .75394 .49928 .7648 .49897 .76022 .49523 Mtetra
.483 .772 .995 r
.76022 .49523 .7648 .49897 .77572 .49867 .77113 .49434 Mtetra
.541 .772 .983 r
.77113 .49434 .77572 .49867 .78666 .49788 .78206 .49296 Mtetra
.582 .763 .965 r
.78206 .49296 .78666 .49788 .79762 .49658 .793 .49111 Mtetra
.609 .752 .946 r
.793 .49111 .79762 .49658 .80859 .49476 .80397 .48889 Mtetra
.626 .744 .932 r
.80397 .48889 .80859 .49476 .81957 .49249 .81496 .48635 Mtetra
.637 .739 .923 r
.81496 .48635 .81957 .49249 .83057 .48986 .82597 .48357 Mtetra
.644 .738 .917 r
.82597 .48357 .83057 .48986 .84158 .48696 .83701 .48061 Mtetra
.649 .738 .914 r
.83701 .48061 .84158 .48696 .85263 .48388 .84808 .47751 Mtetra
.652 .74 .914 r
.84808 .47751 .85263 .48388 .8637 .48066 .85919 .4743 Mtetra
.654 .742 .914 r
.85919 .4743 .8637 .48066 .87481 .47736 .87034 .47103 Mtetra
.656 .744 .915 r
.87034 .47103 .87481 .47736 .88596 .474 .88152 .46769 Mtetra
.657 .747 .916 r
.88152 .46769 .88596 .474 .89715 .47059 .89274 .46431 Mtetra
.658 .749 .917 r
.89274 .46431 .89715 .47059 .90837 .46715 .904 .46088 Mtetra
.659 .751 .918 r
.904 .46088 .90837 .46715 .91964 .46367 .91531 .45742 Mtetra
.659 .752 .919 r
.91531 .45742 .91964 .46367 .93095 .46018 .92665 .45393 Mtetra
.652 .75 .922 r
.31818 .62896 .32399 .63404 .33318 .63139 .32738 .62628 Mtetra
.653 .75 .921 r
.32738 .62628 .33318 .63139 .34239 .62871 .33661 .62358 Mtetra
.654 .75 .92 r
.33661 .62358 .34239 .62871 .35164 .626 .34588 .62083 Mtetra
.656 .75 .919 r
.34588 .62083 .35164 .626 .36092 .62326 .35519 .61803 Mtetra
.658 .749 .917 r
.35519 .61803 .36092 .62326 .37024 .62047 .36453 .61517 Mtetra
.661 .748 .914 r
.36453 .61517 .37024 .62047 .37959 .61762 .3739 .61224 Mtetra
.664 .746 .911 r
.3739 .61224 .37959 .61762 .38898 .61471 .38331 .60923 Mtetra
.667 .744 .908 r
.38331 .60923 .38898 .61471 .3984 .6117 .39276 .60614 Mtetra
.671 .743 .904 r
.39276 .60614 .3984 .6117 .40786 .60856 .40224 .60294 Mtetra
.674 .742 .902 r
.40224 .60294 .40786 .60856 .41735 .60525 .41175 .59963 Mtetra
.678 .744 .901 r
.41175 .59963 .41735 .60525 .42688 .6017 .4213 .5962 Mtetra
.683 .75 .903 r
.4213 .5962 .42688 .6017 .43645 .59785 .43088 .59265 Mtetra
.688 .763 .909 r
.43088 .59265 .43645 .59785 .44606 .59362 .4405 .58894 Mtetra
.699 .786 .918 r
.4405 .58894 .44606 .59362 .4557 .58895 .45015 .58494 Mtetra
.714 .817 .929 r
.45015 .58494 .4557 .58895 .46537 .58378 .45984 .58056 Mtetra
.723 .852 .943 r
.45984 .58056 .46537 .58378 .47507 .57844 .46956 .57588 Mtetra
.726 .883 .953 r
.46956 .57588 .47507 .57844 .48479 .57321 .4793 .57103 Mtetra
.695 .896 .97 r
.4793 .57103 .48479 .57321 .49451 .56901 .48906 .56665 Mtetra
.635 .877 .986 r
.48906 .56665 .49451 .56901 .50426 .56658 .49885 .56332 Mtetra
.491 .787 .998 r
.49885 .56332 .50426 .56658 .51403 .56696 .50865 .56228 Mtetra
.29 .622 .96 r
.50865 .56228 .51403 .56696 .52386 .57064 .51849 .5642 Mtetra
.154 .465 .889 r
.51849 .5642 .52386 .57064 .53377 .5767 .52841 .56878 Mtetra
.117 .387 .843 r
.52841 .56878 .53377 .5767 .54377 .58377 .5384 .57501 Mtetra
.366 .512 .871 r
.5384 .57501 .54377 .58377 .55383 .58748 .54848 .57857 Mtetra
.625 .64 .845 r
.54848 .57857 .55383 .58748 .56391 .58504 .55857 .57642 Mtetra
.813 .712 .755 r
.55857 .57642 .56391 .58504 .57389 .57347 .56857 .56405 Mtetra
.867 .711 .687 r
.56857 .56405 .57389 .57347 .58372 .55379 .5784 .5422 Mtetra
.849 .684 .678 r
.5784 .5422 .58372 .55379 .59348 .53403 .58814 .51992 Mtetra
.797 .643 .691 r
.58814 .51992 .59348 .53403 .60329 .51913 .59792 .50294 Mtetra
.628 .537 .733 r
.59792 .50294 .60329 .51913 .61338 .51606 .608 .49984 Mtetra
.245 .3 .721 r
.608 .49984 .61338 .51606 .62385 .52484 .61851 .51065 Mtetra
0 .097 .64 r
.61851 .51065 .62385 .52484 .6346 .53856 .62931 .52683 Mtetra
0 .04 .609 r
.62931 .52683 .6346 .53856 .64549 .55225 .64026 .54266 Mtetra
.241 .416 .836 r
.64026 .54266 .64549 .55225 .65621 .55784 .651 .54901 Mtetra
.674 .668 .836 r
.651 .54901 .65621 .55784 .66663 .55422 .66143 .54504 Mtetra
.779 .701 .777 r
.66143 .54504 .66663 .55422 .67681 .54438 .67164 .53531 Mtetra
.813 .713 .755 r
.67164 .53531 .67681 .54438 .68682 .5311 .68172 .52284 Mtetra
.805 .727 .778 r
.68172 .52284 .68682 .5311 .69685 .51882 .69186 .51201 Mtetra
.783 .757 .829 r
.69186 .51201 .69685 .51882 .707 .50893 .70213 .50387 Mtetra
.727 .802 .911 r
.70213 .50387 .707 .50893 .71733 .50237 .71259 .49872 Mtetra
.613 .83 .983 r
.71259 .49872 .71733 .50237 .72786 .49867 .7232 .4959 Mtetra
.499 .825 1 r
.7232 .4959 .72786 .49867 .73855 .49677 .73393 .49415 Mtetra
.445 .806 .996 r
.73393 .49415 .73855 .49677 .74935 .49594 .74474 .4929 Mtetra
.487 .808 1 r
.74474 .4929 .74935 .49594 .76022 .49523 .7556 .49146 Mtetra
.542 .8 .993 r
.7556 .49146 .76022 .49523 .77113 .49434 .76648 .48974 Mtetra
.59 .781 .971 r
.76648 .48974 .77113 .49434 .78206 .49296 .77739 .48762 Mtetra
.616 .761 .949 r
.77739 .48762 .78206 .49296 .793 .49111 .78832 .4852 Mtetra
.627 .744 .931 r
.78832 .4852 .793 .49111 .80397 .48889 .79929 .48262 Mtetra
.634 .734 .92 r
.79929 .48262 .80397 .48889 .81496 .48635 .81029 .47991 Mtetra
.639 .731 .915 r
.81029 .47991 .81496 .48635 .82597 .48357 .82133 .47708 Mtetra
.643 .732 .913 r
.82133 .47708 .82597 .48357 .83701 .48061 .8324 .47414 Mtetra
.646 .735 .913 r
.8324 .47414 .83701 .48061 .84808 .47751 .84351 .47109 Mtetra
.649 .738 .914 r
.84351 .47109 .84808 .47751 .85919 .4743 .85465 .46794 Mtetra
.652 .742 .916 r
.85465 .46794 .85919 .4743 .87034 .47103 .86584 .46471 Mtetra
.654 .745 .917 r
.86584 .46471 .87034 .47103 .88152 .46769 .87706 .4614 Mtetra
.656 .748 .918 r
.87706 .4614 .88152 .46769 .89274 .46431 .88831 .45803 Mtetra
.657 .75 .919 r
.88831 .45803 .89274 .46431 .904 .46088 .89961 .45461 Mtetra
.658 .752 .919 r
.89961 .45461 .904 .46088 .91531 .45742 .91094 .45113 Mtetra
.659 .752 .919 r
.91094 .45113 .91531 .45742 .92665 .45393 .92232 .44763 Mtetra
.651 .75 .922 r
.31232 .62385 .31818 .62896 .32738 .62628 .32154 .62117 Mtetra
.652 .751 .922 r
.32154 .62117 .32738 .62628 .33661 .62358 .3308 .61845 Mtetra
.654 .752 .922 r
.3308 .61845 .33661 .62358 .34588 .62083 .34009 .61569 Mtetra
.656 .753 .921 r
.34009 .61569 .34588 .62083 .35519 .61803 .34941 .61287 Mtetra
.659 .753 .919 r
.34941 .61287 .35519 .61803 .36453 .61517 .35877 .60996 Mtetra
.663 .753 .917 r
.35877 .60996 .36453 .61517 .3739 .61224 .36817 .60697 Mtetra
.667 .752 .914 r
.36817 .60697 .3739 .61224 .38331 .60923 .3776 .60387 Mtetra
.671 .751 .911 r
.3776 .60387 .38331 .60923 .39276 .60614 .38707 .60067 Mtetra
.675 .748 .906 r
.38707 .60067 .39276 .60614 .40224 .60294 .39658 .59733 Mtetra
.677 .745 .902 r
.39658 .59733 .40224 .60294 .41175 .59963 .40611 .59392 Mtetra
.678 .742 .899 r
.40611 .59392 .41175 .59963 .4213 .5962 .41568 .59047 Mtetra
.676 .741 .9 r
.41568 .59047 .4213 .5962 .43088 .59265 .42528 .58706 Mtetra
.673 .746 .906 r
.42528 .58706 .43088 .59265 .4405 .58894 .43491 .58373 Mtetra
.674 .761 .916 r
.43491 .58373 .4405 .58894 .45015 .58494 .44457 .58036 Mtetra
.679 .787 .932 r
.44457 .58036 .45015 .58494 .45984 .58056 .45427 .57685 Mtetra
.685 .826 .951 r
.45427 .57685 .45984 .58056 .46956 .57588 .464 .57309 Mtetra
.689 .868 .966 r
.464 .57309 .46956 .57588 .4793 .57103 .47377 .56903 Mtetra
.678 .902 .975 r
.47377 .56903 .4793 .57103 .48906 .56665 .48356 .56485 Mtetra
.663 .907 .979 r
.48356 .56485 .48906 .56665 .49885 .56332 .49338 .56079 Mtetra
.591 .858 .994 r
.49338 .56079 .49885 .56332 .50865 .56228 .50323 .55812 Mtetra
.489 .746 .986 r
.50323 .55812 .50865 .56228 .51849 .5642 .5131 .55757 Mtetra
.382 .59 .926 r
.5131 .55757 .51849 .5642 .52841 .56878 .52302 .55968 Mtetra
.326 .48 .859 r
.52302 .55968 .52841 .56878 .5384 .57501 .53301 .56399 Mtetra
.443 .502 .825 r
.53301 .56399 .5384 .57501 .54848 .57857 .54308 .56706 Mtetra
.593 .575 .803 r
.54308 .56706 .54848 .57857 .55857 .57642 .55318 .56598 Mtetra
.784 .677 .745 r
.55318 .56598 .55857 .57642 .56857 .56405 .56321 .55444 Mtetra
.865 .709 .686 r
.56321 .55444 .56857 .56405 .5784 .5422 .57309 .53256 Mtetra
.871 .71 .68 r
.57309 .53256 .5784 .5422 .58814 .51992 .58286 .50955 Mtetra
.839 .695 .703 r
.58286 .50955 .58814 .51992 .59792 .50294 .59265 .49149 Mtetra
.643 .6 .79 r
.59265 .49149 .59792 .50294 .608 .49984 .60274 .48836 Mtetra
0 .193 .713 r
.60274 .48836 .608 .49984 .61851 .51065 .61326 .50021 Mtetra
0 0 .513 r
.61326 .50021 .61851 .51065 .62931 .52683 .62407 .51707 Mtetra
0 0 .535 r
.62407 .51707 .62931 .52683 .64026 .54266 .635 .53288 Mtetra
.299 .448 .842 r
.635 .53288 .64026 .54266 .651 .54901 .64571 .53833 Mtetra
.688 .639 .795 r
.64571 .53833 .651 .54901 .66143 .54504 .65611 .53325 Mtetra
.747 .649 .752 r
.65611 .53325 .66143 .54504 .67164 .53531 .66635 .52396 Mtetra
.767 .663 .748 r
.66635 .52396 .67164 .53531 .68172 .52284 .67654 .51338 Mtetra
.756 .689 .787 r
.67654 .51338 .68172 .52284 .69186 .51201 .68683 .50502 Mtetra
.729 .738 .859 r
.68683 .50502 .69186 .51201 .70213 .50387 .69726 .49933 Mtetra
.663 .807 .952 r
.69726 .49933 .70213 .50387 .71259 .49872 .70784 .49581 Mtetra
.536 .835 .999 r
.70784 .49581 .71259 .49872 .7232 .4959 .71854 .49369 Mtetra
.479 .841 .993 r
.71854 .49369 .7232 .4959 .73393 .49415 .72929 .49171 Mtetra
.504 .844 .997 r
.72929 .49171 .73393 .49415 .74474 .4929 .74008 .48961 Mtetra
.57 .834 .995 r
.74008 .48961 .74474 .4929 .7556 .49146 .75091 .48719 Mtetra
.612 .806 .974 r
.75091 .48719 .7556 .49146 .76648 .48974 .76176 .48453 Mtetra
.632 .773 .948 r
.76176 .48453 .76648 .48974 .77739 .48762 .77264 .48172 Mtetra
.638 .75 .929 r
.77264 .48172 .77739 .48762 .78832 .4852 .78357 .47887 Mtetra
.636 .733 .919 r
.78357 .47887 .78832 .4852 .79929 .48262 .79455 .4761 Mtetra
.635 .727 .914 r
.79455 .4761 .79929 .48262 .81029 .47991 .80558 .47337 Mtetra
.636 .728 .914 r
.80558 .47337 .81029 .47991 .82133 .47708 .81666 .47061 Mtetra
.638 .732 .916 r
.81666 .47061 .82133 .47708 .8324 .47414 .82777 .46776 Mtetra
.642 .738 .918 r
.82777 .46776 .8324 .47414 .84351 .47109 .83892 .46478 Mtetra
.646 .743 .92 r
.83892 .46478 .84351 .47109 .85465 .46794 .8501 .46169 Mtetra
.65 .747 .921 r
.8501 .46169 .85465 .46794 .86584 .46471 .86132 .45848 Mtetra
.653 .75 .921 r
.86132 .45848 .86584 .46471 .87706 .4614 .87257 .45518 Mtetra
.655 .752 .921 r
.87257 .45518 .87706 .4614 .88831 .45803 .88386 .45179 Mtetra
.657 .753 .921 r
.88386 .45179 .88831 .45803 .89961 .45461 .89519 .44834 Mtetra
.659 .754 .92 r
.89519 .44834 .89961 .45461 .91094 .45113 .90655 .44483 Mtetra
.66 .753 .92 r
.90655 .44483 .91094 .45113 .92232 .44763 .91796 .44128 Mtetra
.65 .75 .923 r
.30643 .61871 .31232 .62385 .32154 .62117 .31567 .61605 Mtetra
.65 .752 .924 r
.31567 .61605 .32154 .62117 .3308 .61845 .32494 .61336 Mtetra
.652 .754 .924 r
.32494 .61336 .3308 .61845 .34009 .61569 .33425 .61062 Mtetra
.654 .756 .924 r
.33425 .61062 .34009 .61569 .34941 .61287 .34359 .60781 Mtetra
.658 .758 .924 r
.34359 .60781 .34941 .61287 .35877 .60996 .35297 .60492 Mtetra
.662 .76 .923 r
.35297 .60492 .35877 .60996 .36817 .60697 .36239 .60191 Mtetra
.668 .762 .92 r
.36239 .60191 .36817 .60697 .3776 .60387 .37184 .59875 Mtetra
.674 .761 .916 r
.37184 .59875 .3776 .60387 .38707 .60067 .38134 .59543 Mtetra
.682 .76 .91 r
.38134 .59543 .38707 .60067 .39658 .59733 .39087 .5919 Mtetra
.685 .754 .904 r
.39087 .5919 .39658 .59733 .40611 .59392 .40044 .58828 Mtetra
.685 .747 .899 r
.40044 .58828 .40611 .59392 .41568 .59047 .41004 .58461 Mtetra
.679 .739 .896 r
.41004 .58461 .41568 .59047 .42528 .58706 .41966 .58109 Mtetra
.667 .733 .899 r
.41966 .58109 .42528 .58706 .43491 .58373 .42931 .57789 Mtetra
.657 .735 .907 r
.42931 .57789 .43491 .58373 .44457 .58036 .43898 .57494 Mtetra
.645 .748 .924 r
.43898 .57494 .44457 .58036 .45427 .57685 .44868 .57227 Mtetra
.637 .779 .949 r
.44868 .57227 .45427 .57685 .464 .57309 .45841 .56962 Mtetra
.628 .826 .977 r
.45841 .56962 .464 .57309 .47377 .56903 .46819 .56683 Mtetra
.636 .885 .986 r
.46819 .56683 .47377 .56903 .48356 .56485 .478 .56336 Mtetra
.669 .921 .974 r
.478 .56336 .48356 .56485 .49338 .56079 .48787 .55901 Mtetra
.674 .912 .976 r
.48787 .55901 .49338 .56079 .50323 .55812 .49776 .55472 Mtetra
.666 .842 .967 r
.49776 .55472 .50323 .55812 .5131 .55757 .50767 .55116 Mtetra
.59 .697 .917 r
.50767 .55116 .5131 .55757 .52302 .55968 .51761 .54976 Mtetra
.511 .562 .844 r
.51761 .54976 .52302 .55968 .53301 .56399 .5276 .55085 Mtetra
.5 .499 .787 r
.5276 .55085 .53301 .56399 .54308 .56706 .53765 .553 Mtetra
.542 .512 .771 r
.53765 .553 .54308 .56706 .55318 .56598 .54777 .55388 Mtetra
.733 .635 .75 r
.54777 .55388 .55318 .56598 .56321 .55444 .55785 .54539 Mtetra
.856 .716 .706 r
.55785 .54539 .56321 .55444 .57309 .53256 .5678 .52662 Mtetra
.903 .767 .701 r
.5678 .52662 .57309 .53256 .58286 .50955 .57766 .50558 Mtetra
.913 .814 .735 r
.57766 .50558 .58286 .50955 .59265 .49149 .58752 .48802 Mtetra
.639 .838 .977 r
.58752 .48802 .59265 .49149 .60274 .48836 .59764 .48487 Mtetra
.665 .135 0 r
.59764 .48487 .60274 .48836 .61326 .50021 .60816 .49618 Mtetra
.753 .256 0 r
.60816 .49618 .61326 .50021 .62407 .51707 .6189 .51103 Mtetra
0 0 .462 r
.6189 .51103 .62407 .51707 .635 .53288 .62973 .52366 Mtetra
.447 .549 .867 r
.62973 .52366 .635 .53288 .64571 .53833 .64034 .52599 Mtetra
.711 .626 .76 r
.64034 .52599 .64571 .53833 .65611 .53325 .65067 .51887 Mtetra
.715 .605 .733 r
.65067 .51887 .65611 .53325 .66635 .52396 .66096 .51045 Mtetra
.706 .61 .747 r
.66096 .51045 .66635 .52396 .67654 .51338 .67131 .50309 Mtetra
.685 .646 .805 r
.67131 .50309 .67654 .51338 .68683 .50502 .68178 .49824 Mtetra
.637 .713 .902 r
.68178 .49824 .68683 .50502 .69726 .49933 .6924 .49558 Mtetra
.556 .805 .991 r
.6924 .49558 .69726 .49933 .70784 .49581 .70309 .49366 Mtetra
.462 .835 .99 r
.70309 .49366 .70784 .49581 .71854 .49369 .71385 .49181 Mtetra
.521 .873 .987 r
.71385 .49181 .71854 .49369 .72929 .49171 .72459 .48906 Mtetra
.612 .879 .991 r
.72459 .48906 .72929 .49171 .74008 .48961 .73534 .48562 Mtetra
.655 .834 .969 r
.73534 .48562 .74008 .48961 .75091 .48719 .74612 .48203 Mtetra
.664 .788 .94 r
.74612 .48203 .75091 .48719 .76176 .48453 .75694 .47846 Mtetra
.656 .751 .92 r
.75694 .47846 .76176 .48453 .77264 .48172 .76782 .47517 Mtetra
.646 .73 .91 r
.76782 .47517 .77264 .48172 .78357 .47887 .77877 .47215 Mtetra
.634 .721 .91 r
.77877 .47215 .78357 .47887 .79455 .4761 .78978 .46944 Mtetra
.627 .721 .914 r
.78978 .46944 .79455 .4761 .80558 .47337 .80085 .4669 Mtetra
.628 .728 .919 r
.80085 .4669 .80558 .47337 .81666 .47061 .81197 .46431 Mtetra
.63 .736 .924 r
.81197 .46431 .81666 .47061 .82777 .46776 .82313 .46162 Mtetra
.637 .746 .927 r
.82313 .46162 .82777 .46776 .83892 .46478 .83432 .45871 Mtetra
.643 .752 .928 r
.83432 .45871 .83892 .46478 .8501 .46169 .84554 .45564 Mtetra
.649 .756 .928 r
.84554 .45564 .8501 .46169 .86132 .45848 .85679 .45241 Mtetra
.653 .758 .926 r
.85679 .45241 .86132 .45848 .87257 .45518 .86807 .44905 Mtetra
.656 .758 .925 r
.86807 .44905 .87257 .45518 .88386 .45179 .87939 .4456 Mtetra
.659 .757 .923 r
.87939 .4456 .88386 .45179 .89519 .44834 .89074 .44208 Mtetra
.66 .756 .921 r
.89074 .44208 .89519 .44834 .90655 .44483 .90214 .4385 Mtetra
.661 .755 .92 r
.90214 .4385 .90655 .44483 .91796 .44128 .91357 .43489 Mtetra
.648 .749 .924 r
.3005 .61354 .30643 .61871 .31567 .61605 .30976 .6109 Mtetra
.648 .751 .925 r
.30976 .6109 .31567 .61605 .32494 .61336 .31904 .60825 Mtetra
.649 .754 .926 r
.31904 .60825 .32494 .61336 .33425 .61062 .32837 .60555 Mtetra
.651 .757 .927 r
.32837 .60555 .33425 .61062 .34359 .60781 .33773 .6028 Mtetra
.654 .76 .928 r
.33773 .6028 .34359 .60781 .35297 .60492 .34712 .59997 Mtetra
.659 .765 .928 r
.34712 .59997 .35297 .60492 .36239 .60191 .35656 .59702 Mtetra
.666 .769 .927 r
.35656 .59702 .36239 .60191 .37184 .59875 .36604 .59389 Mtetra
.675 .773 .924 r
.36604 .59389 .37184 .59875 .38134 .59543 .37555 .59053 Mtetra
.686 .775 .918 r
.37555 .59053 .38134 .59543 .39087 .5919 .38512 .58687 Mtetra
.693 .772 .912 r
.38512 .58687 .39087 .5919 .40044 .58828 .39471 .58303 Mtetra
.697 .765 .904 r
.39471 .58303 .40044 .58828 .41004 .58461 .40435 .57903 Mtetra
.691 .753 .899 r
.40435 .57903 .41004 .58461 .41966 .58109 .414 .57519 Mtetra
.676 .739 .898 r
.414 .57519 .41966 .58109 .42931 .57789 .42367 .57172 Mtetra
.656 .725 .899 r
.42367 .57172 .42931 .57789 .43898 .57494 .43336 .56878 Mtetra
.628 .716 .91 r
.43336 .56878 .43898 .57494 .44868 .57227 .44307 .56653 Mtetra
.599 .723 .931 r
.44307 .56653 .44868 .57227 .45841 .56962 .45281 .56484 Mtetra
.561 .748 .965 r
.45281 .56484 .45841 .56962 .46819 .56683 .46258 .56353 Mtetra
.58 .822 .99 r
.46258 .56353 .46819 .56683 .478 .56336 .47241 .56135 Mtetra
.648 .897 .983 r
.47241 .56135 .478 .56336 .48787 .55901 .4823 .55757 Mtetra
.714 .932 .961 r
.4823 .55757 .48787 .55901 .49776 .55472 .49223 .5524 Mtetra
.773 .902 .932 r
.49223 .5524 .49776 .55472 .50767 .55116 .50219 .54616 Mtetra
.739 .792 .895 r
.50219 .54616 .50767 .55116 .51761 .54976 .51217 .54077 Mtetra
.66 .654 .833 r
.51217 .54077 .51761 .54976 .5276 .55085 .52217 .53736 Mtetra
.556 .526 .777 r
.52217 .53736 .5276 .55085 .53765 .553 .53221 .53766 Mtetra
.489 .465 .758 r
.53221 .53766 .53765 .553 .54777 .55388 .54233 .54063 Mtetra
.642 .577 .766 r
.54233 .54063 .54777 .55388 .55785 .54539 .55246 .53719 Mtetra
.814 .723 .764 r
.55246 .53719 .55785 .54539 .5678 .52662 .56254 .52527 Mtetra
.932 .891 .767 r
.56254 .52527 .5678 .52662 .57766 .50558 .57254 .50977 Mtetra
.844 .969 .649 r
.57254 .50977 .57766 .50558 .58752 .48802 .58252 .4951 Mtetra
.275 0 .004 r
.58252 .4951 .58752 .48802 .59764 .48487 .59271 .49195 Mtetra
.684 .264 .242 r
.59271 .49195 .59764 .48487 .60816 .49618 .6032 .50033 Mtetra
.712 .251 .156 r
.6032 .50033 .60816 .49618 .6189 .51103 .61383 .50959 Mtetra
.456 0 0 r
.61383 .50959 .6189 .51103 .62973 .52366 .62447 .5153 Mtetra
.642 .668 .859 r
.62447 .5153 .62973 .52366 .64034 .52599 .63492 .51248 Mtetra
.732 .623 .737 r
.63492 .51248 .64034 .52599 .65067 .51887 .64518 .50319 Mtetra
.682 .577 .73 r
.64518 .50319 .65067 .51887 .66096 .51045 .65555 .49659 Mtetra
.627 .565 .765 r
.65555 .49659 .66096 .51045 .67131 .50309 .66609 .49373 Mtetra
.578 .616 .854 r
.66609 .49373 .67131 .50309 .68178 .49824 .67677 .49289 Mtetra
.479 .699 .965 r
.67677 .49289 .68178 .49824 .6924 .49558 .68754 .49291 Mtetra
.426 .796 .994 r
.68754 .49291 .6924 .49558 .70309 .49366 .69832 .49185 Mtetra
.489 .862 .984 r
.69832 .49185 .70309 .49366 .71385 .49181 .70908 .48939 Mtetra
.645 .9 .983 r
.70908 .48939 .71385 .49181 .72459 .48906 .71979 .48528 Mtetra
.716 .861 .951 r
.71979 .48528 .72459 .48906 .73534 .48562 .73048 .48028 Mtetra
.704 .794 .921 r
.73048 .48028 .73534 .48562 .74612 .48203 .74123 .47567 Mtetra
.683 .751 .903 r
.74123 .47567 .74612 .48203 .75694 .47846 .75204 .47162 Mtetra
.657 .726 .9 r
.75204 .47162 .75694 .47846 .76782 .47517 .76295 .46828 Mtetra
.637 .717 .905 r
.76295 .46828 .76782 .47517 .77877 .47215 .77394 .46548 Mtetra
.621 .719 .916 r
.77394 .46548 .77877 .47215 .78978 .46944 .785 .46307 Mtetra
.613 .726 .926 r
.785 .46307 .78978 .46944 .80085 .4669 .79613 .46082 Mtetra
.616 .739 .934 r
.79613 .46082 .80085 .4669 .81197 .46431 .8073 .45842 Mtetra
.623 .75 .938 r
.8073 .45842 .81197 .46431 .82313 .46162 .8185 .45582 Mtetra
.634 .759 .938 r
.8185 .45582 .82313 .46162 .83432 .45871 .82972 .45291 Mtetra
.644 .764 .936 r
.82972 .45291 .83432 .45871 .84554 .45564 .84096 .44976 Mtetra
.651 .765 .933 r
.84096 .44976 .84554 .45564 .85679 .45241 .85224 .44643 Mtetra
.656 .764 .929 r
.85224 .44643 .85679 .45241 .86807 .44905 .86354 .44297 Mtetra
.659 .762 .926 r
.86354 .44297 .86807 .44905 .87939 .4456 .87489 .43942 Mtetra
.661 .76 .923 r
.87489 .43942 .87939 .4456 .89074 .44208 .88627 .4358 Mtetra
.662 .758 .921 r
.88627 .4358 .89074 .44208 .90214 .4385 .89769 .43214 Mtetra
.663 .756 .919 r
.89769 .43214 .90214 .4385 .91357 .43489 .90915 .42846 Mtetra
.646 .749 .924 r
.29453 .60833 .3005 .61354 .30976 .6109 .3038 .60571 Mtetra
.646 .75 .925 r
.3038 .60571 .30976 .6109 .31904 .60825 .31311 .60309 Mtetra
.646 .752 .927 r
.31311 .60309 .31904 .60825 .32837 .60555 .32245 .60045 Mtetra
.646 .755 .928 r
.32245 .60045 .32837 .60555 .33773 .6028 .33182 .59778 Mtetra
.647 .759 .931 r
.33182 .59778 .33773 .6028 .34712 .59997 .34123 .59508 Mtetra
.651 .766 .933 r
.34123 .59508 .34712 .59997 .35656 .59702 .35068 .59226 Mtetra
.658 .774 .935 r
.35068 .59226 .35656 .59702 .36604 .59389 .36017 .58928 Mtetra
.669 .783 .934 r
.36017 .58928 .36604 .59389 .37555 .59053 .36971 .58602 Mtetra
.685 .791 .93 r
.36971 .58602 .37555 .59053 .38512 .58687 .37929 .58237 Mtetra
.698 .794 .925 r
.37929 .58237 .38512 .58687 .39471 .58303 .38892 .57838 Mtetra
.71 .792 .915 r
.38892 .57838 .39471 .58303 .40435 .57903 .39859 .57403 Mtetra
.71 .779 .906 r
.39859 .57403 .40435 .57903 .414 .57519 .40829 .56966 Mtetra
.701 .759 .897 r
.40829 .56966 .414 .57519 .42367 .57172 .41801 .56549 Mtetra
.676 .73 .891 r
.41801 .56549 .42367 .57172 .43336 .56878 .42773 .56199 Mtetra
.637 .7 .891 r
.42773 .56199 .43336 .56878 .44307 .56653 .43746 .55952 Mtetra
.584 .674 .902 r
.43746 .55952 .44307 .56653 .45281 .56484 .4472 .55833 Mtetra
.505 .658 .929 r
.4472 .55833 .45281 .56484 .46258 .56353 .45696 .55848 Mtetra
.503 .716 .967 r
.45696 .55848 .46258 .56353 .47241 .56135 .46678 .5581 Mtetra
.571 .822 .993 r
.46678 .5581 .47241 .56135 .4823 .55757 .47668 .55599 Mtetra
.695 .925 .968 r
.47668 .55599 .4823 .55757 .49223 .5524 .48664 .55119 Mtetra
.819 .942 .906 r
.48664 .55119 .49223 .5524 .50219 .54616 .49666 .54332 Mtetra
.846 .874 .861 r
.49666 .54332 .50219 .54616 .51217 .54077 .5067 .534 Mtetra
.795 .748 .81 r
.5067 .534 .51217 .54077 .52217 .53736 .51673 .52501 Mtetra
.631 .582 .781 r
.51673 .52501 .52217 .53736 .53221 .53766 .52677 .52228 Mtetra
.44 .436 .758 r
.52677 .52228 .53221 .53766 .54233 .54063 .53688 .52677 Mtetra
.469 .473 .779 r
.53688 .52677 .54233 .54063 .55246 .53719 .54705 .52995 Mtetra
.585 .673 .9 r
.54705 .52995 .55246 .53719 .56254 .52527 .55726 .52869 Mtetra
0 0 0 r
.55726 .52869 .56254 .52527 .57254 .50977 .56747 .52274 Mtetra
.183 0 .141 r
.56747 .52274 .57254 .50977 .58252 .4951 .57764 .51385 Mtetra
.46 .142 .338 r
.57764 .51385 .58252 .4951 .59271 .49195 .58793 .5107 Mtetra
.563 .235 .372 r
.58793 .5107 .59271 .49195 .6032 .50033 .59838 .51328 Mtetra
.491 .126 .274 r
.59838 .51328 .6032 .50033 .61383 .50959 .60883 .51294 Mtetra
0 0 0 r
.60883 .51294 .61383 .50959 .62447 .5153 .6192 .5079 Mtetra
.797 .744 .804 r
.6192 .5079 .62447 .5153 .63492 .51248 .62947 .49837 Mtetra
.746 .624 .724 r
.62947 .49837 .63492 .51248 .64518 .50319 .63968 .48748 Mtetra
.635 .55 .742 r
.63968 .48748 .64518 .50319 .65555 .49659 .65016 .48388 Mtetra
.476 .497 .8 r
.65016 .48388 .65555 .49659 .66609 .49373 .66094 .48663 Mtetra
.335 .554 .915 r
.66094 .48663 .66609 .49373 .67677 .49289 .67181 .48972 Mtetra
.187 .635 .942 r
.67181 .48972 .67677 .49289 .68754 .49291 .6827 .49137 Mtetra
.365 .807 .956 r
.6827 .49137 .68754 .49291 .69832 .49185 .6935 .4899 Mtetra
.633 .914 .98 r
.6935 .4899 .69832 .49185 .70908 .48939 .70421 .48569 Mtetra
.752 .872 .934 r
.70421 .48569 .70908 .48939 .71979 .48528 .71485 .47971 Mtetra
.76 .801 .885 r
.71485 .47971 .71979 .48528 .73048 .48028 .72548 .47317 Mtetra
.712 .738 .871 r
.72548 .47317 .73048 .48028 .74123 .47567 .73621 .468 Mtetra
.672 .707 .874 r
.73621 .468 .74123 .47567 .75204 .47162 .74707 .46412 Mtetra
.638 .699 .89 r
.74707 .46412 .75204 .47162 .76295 .46828 .75804 .46132 Mtetra
.611 .705 .911 r
.75804 .46132 .76295 .46828 .77394 .46548 .7691 .4592 Mtetra
.596 .723 .933 r
.7691 .4592 .77394 .46548 .785 .46307 .78024 .45729 Mtetra
.591 .741 .947 r
.78024 .45729 .785 .46307 .79613 .46082 .79143 .45536 Mtetra
.604 .76 .954 r
.79143 .45536 .79613 .46082 .8073 .45842 .80264 .45307 Mtetra
.618 .771 .954 r
.80264 .45307 .8073 .45842 .8185 .45582 .81387 .45042 Mtetra
.636 .778 .949 r
.81387 .45042 .8185 .45582 .82972 .45291 .82511 .44737 Mtetra
.649 .778 .942 r
.82511 .44737 .82972 .45291 .84096 .44976 .83637 .44402 Mtetra
.656 .774 .936 r
.83637 .44402 .84096 .44976 .85224 .44643 .84767 .4405 Mtetra
.661 .769 .93 r
.84767 .4405 .85224 .44643 .86354 .44297 .85899 .43686 Mtetra
.663 .764 .926 r
.85899 .43686 .86354 .44297 .87489 .43942 .87035 .43318 Mtetra
.664 .761 .922 r
.87035 .43318 .87489 .43942 .88627 .4358 .88176 .42946 Mtetra
.664 .758 .92 r
.88176 .42946 .88627 .4358 .89769 .43214 .8932 .42572 Mtetra
.664 .756 .919 r
.8932 .42572 .89769 .43214 .90915 .42846 .90469 .42197 Mtetra
.647 .749 .924 r
.28853 .60308 .29453 .60833 .3038 .60571 .29782 .60044 Mtetra
.645 .749 .924 r
.29782 .60044 .3038 .60571 .31311 .60309 .30714 .59781 Mtetra
.644 .749 .925 r
.30714 .59781 .31311 .60309 .32245 .60045 .3165 .59519 Mtetra
.643 .75 .926 r
.3165 .59519 .32245 .60045 .33182 .59778 .32588 .59258 Mtetra
.642 .752 .929 r
.32588 .59258 .33182 .59778 .34123 .59508 .33531 .58999 Mtetra
.643 .758 .932 r
.33531 .58999 .34123 .59508 .35068 .59226 .34477 .58735 Mtetra
.646 .766 .936 r
.34477 .58735 .35068 .59226 .36017 .58928 .35427 .5846 Mtetra
.657 .779 .938 r
.35427 .5846 .36017 .58928 .36971 .58602 .36382 .5816 Mtetra
.673 .793 .939 r
.36382 .5816 .36971 .58602 .37929 .58237 .37342 .57819 Mtetra
.692 .808 .937 r
.37342 .57819 .37929 .58237 .38892 .57838 .38306 .57432 Mtetra
.714 .817 .929 r
.38306 .57432 .38892 .57838 .39859 .57403 .39277 .56987 Mtetra
.726 .815 .92 r
.39277 .56987 .39859 .57403 .40829 .56966 .4025 .56508 Mtetra
.731 .8 .906 r
.4025 .56508 .40829 .56966 .41801 .56549 .41228 .56007 Mtetra
.712 .767 .896 r
.41228 .56007 .41801 .56549 .42773 .56199 .42205 .55555 Mtetra
.674 .724 .887 r
.42205 .55555 .42773 .56199 .43746 .55952 .43183 .55205 Mtetra
.604 .669 .885 r
.43183 .55205 .43746 .55952 .4472 .55833 .44159 .55042 Mtetra
.496 .609 .894 r
.44159 .55042 .4472 .55833 .45696 .55848 .45135 .55115 Mtetra
.458 .609 .912 r
.45135 .55115 .45696 .55848 .46678 .5581 .46115 .55232 Mtetra
.472 .674 .953 r
.46115 .55232 .46678 .5581 .47668 .55599 .47103 .55264 Mtetra
.615 .834 .984 r
.47103 .55264 .47668 .55599 .48664 .55119 .48101 .54989 Mtetra
.795 .942 .923 r
.48101 .54989 .48664 .55119 .49666 .54332 .49106 .54275 Mtetra
.895 .939 .834 r
.49106 .54275 .49666 .54332 .5067 .534 .50116 .53128 Mtetra
.903 .854 .784 r
.50116 .53128 .5067 .534 .51673 .52501 .51126 .51718 Mtetra
.749 .714 .819 r
.51126 .51718 .51673 .52501 .52677 .52228 .52132 .5102 Mtetra
.442 .484 .808 r
.52132 .5102 .52677 .52228 .53688 .52677 .53141 .51347 Mtetra
.248 .346 .768 r
.53141 .51347 .53688 .52677 .54705 .52995 .54161 .52154 Mtetra
0 .194 .724 r
.54161 .52154 .54705 .52995 .55726 .52869 .55192 .53115 Mtetra
.585 .056 0 r
.55192 .53115 .55726 .52869 .56747 .52274 .5623 .53615 Mtetra
.465 .105 .268 r
.5623 .53615 .56747 .52274 .57764 .51385 .57268 .53482 Mtetra
.469 .159 .357 r
.57268 .53482 .57764 .51385 .58793 .5107 .58307 .53167 Mtetra
.434 .128 .345 r
.58307 .53167 .58793 .5107 .59838 .51328 .59347 .52668 Mtetra
.087 0 .107 r
.59347 .52668 .59838 .51328 .60883 .51294 .60374 .51534 Mtetra
.925 .973 .71 r
.60374 .51534 .60883 .51294 .6192 .5079 .61388 .49932 Mtetra
.838 .729 .743 r
.61388 .49932 .6192 .5079 .62947 .49837 .62402 .48481 Mtetra
.737 .625 .735 r
.62402 .48481 .62947 .49837 .63968 .48748 .63429 .4751 Mtetra
.54 .538 .802 r
.63429 .4751 .63968 .48748 .65016 .48388 .64493 .47574 Mtetra
.031 .327 .811 r
.64493 .47574 .65016 .48388 .66094 .48663 .65593 .48361 Mtetra
0 .317 .71 r
.65593 .48361 .66094 .48663 .67181 .48972 .66692 .48886 Mtetra
.003 .574 .773 r
.66692 .48886 .67181 .48972 .6827 .49137 .67781 .48973 Mtetra
.57 .903 .98 r
.67781 .48973 .6827 .49137 .6935 .4899 .68855 .48614 Mtetra
.776 .872 .919 r
.68855 .48614 .6935 .4899 .70421 .48569 .69916 .47941 Mtetra
.778 .781 .855 r
.69916 .47941 .70421 .48569 .71485 .47971 .70974 .47179 Mtetra
.752 .729 .831 r
.70974 .47179 .71485 .47971 .72548 .47317 .72036 .46461 Mtetra
.692 .693 .846 r
.72036 .46461 .72548 .47317 .73621 .468 .73114 .45984 Mtetra
.639 .681 .874 r
.73114 .45984 .73621 .468 .74707 .46412 .74209 .45698 Mtetra
.598 .694 .91 r
.74209 .45698 .74707 .46412 .75804 .46132 .75316 .45518 Mtetra
.565 .716 .943 r
.75316 .45518 .75804 .46132 .7691 .4592 .76431 .45389 Mtetra
.561 .748 .964 r
.76431 .45389 .7691 .4592 .78024 .45729 .77551 .45237 Mtetra
.571 .77 .972 r
.77551 .45237 .78024 .45729 .79143 .45536 .78674 .45051 Mtetra
.601 .786 .969 r
.78674 .45051 .79143 .45536 .80264 .45307 .79797 .44805 Mtetra
.626 .79 .961 r
.79797 .44805 .80264 .45307 .81387 .45042 .80921 .4451 Mtetra
.647 .787 .949 r
.80921 .4451 .81387 .45042 .82511 .44737 .82046 .44174 Mtetra
.66 .78 .938 r
.82046 .44174 .82511 .44737 .83637 .44402 .83174 .4381 Mtetra
.665 .772 .93 r
.83174 .4381 .83637 .44402 .84767 .4405 .84304 .43436 Mtetra
.667 .766 .924 r
.84304 .43436 .84767 .4405 .85899 .43686 .85438 .43055 Mtetra
.666 .76 .92 r
.85438 .43055 .85899 .43686 .87035 .43318 .86577 .42676 Mtetra
.665 .757 .918 r
.86577 .42676 .87035 .43318 .88176 .42946 .8772 .42298 Mtetra
.665 .755 .918 r
.8772 .42298 .88176 .42946 .8932 .42572 .88868 .4192 Mtetra
.664 .754 .918 r
.88868 .4192 .8932 .42572 .90469 .42197 .90021 .41544 Mtetra
.65 .75 .923 r
.28248 .59781 .28853 .60308 .29782 .60044 .29179 .59507 Mtetra
.648 .747 .922 r
.29179 .59507 .29782 .60044 .30714 .59781 .30114 .59236 Mtetra
.646 .744 .921 r
.30114 .59236 .30714 .59781 .3165 .59519 .31052 .58969 Mtetra
.644 .742 .921 r
.31052 .58969 .3165 .59519 .32588 .59258 .31993 .58708 Mtetra
.639 .742 .923 r
.31993 .58708 .32588 .59258 .33531 .58999 .32936 .58456 Mtetra
.637 .744 .926 r
.32936 .58456 .33531 .58999 .34477 .58735 .33883 .58207 Mtetra
.634 .75 .932 r
.33883 .58207 .34477 .58735 .35427 .5846 .34834 .57961 Mtetra
.639 .763 .938 r
.34834 .57961 .35427 .5846 .36382 .5816 .35789 .577 Mtetra
.649 .782 .945 r
.35789 .577 .36382 .5816 .37342 .57819 .36749 .57411 Mtetra
.669 .809 .95 r
.36749 .57411 .37342 .57819 .38306 .57432 .37714 .57072 Mtetra
.699 .835 .948 r
.37714 .57072 .38306 .57432 .39277 .56987 .38686 .56659 Mtetra
.729 .852 .94 r
.38686 .56659 .39277 .56987 .4025 .56508 .39663 .56171 Mtetra
.759 .851 .92 r
.39663 .56171 .4025 .56508 .41228 .56007 .40646 .55596 Mtetra
.757 .823 .903 r
.40646 .55596 .41228 .56007 .42205 .55555 .41631 .55015 Mtetra
.735 .774 .885 r
.41631 .55015 .42205 .55555 .43183 .55205 .42616 .54484 Mtetra
.662 .699 .874 r
.42616 .54484 .43183 .55205 .44159 .55042 .43598 .54161 Mtetra
.546 .608 .867 r
.43598 .54161 .44159 .55042 .45135 .55115 .44576 .54151 Mtetra
.462 .546 .857 r
.44576 .54151 .45135 .55115 .46115 .55232 .45555 .54341 Mtetra
.382 .523 .874 r
.45555 .54341 .46115 .55232 .47103 .55264 .46539 .54643 Mtetra
.44 .644 .944 r
.46539 .54643 .47103 .55264 .48101 .54989 .47533 .54735 Mtetra
.633 .876 .987 r
.47533 .54735 .48101 .54989 .49106 .54275 .48539 .54391 Mtetra
.864 .991 .83 r
.48539 .54391 .49106 .54275 .50116 .53128 .49554 .53317 Mtetra
.954 .942 .727 r
.49554 .53317 .50116 .53128 .51126 .51718 .50572 .51579 Mtetra
.899 .911 .823 r
.50572 .51579 .51126 .51718 .52132 .5102 .51584 .50373 Mtetra
.595 .703 .919 r
.51584 .50373 .52132 .5102 .53141 .51347 .52594 .50209 Mtetra
.098 .286 .766 r
.52594 .50209 .53141 .51347 .54161 .52154 .53613 .51119 Mtetra
0 0 .411 r
.53613 .51119 .54161 .52154 .55192 .53115 .54648 .52893 Mtetra
.805 .314 0 r
.54648 .52893 .55192 .53115 .5623 .53615 .55698 .54376 Mtetra
.645 .222 .226 r
.55698 .54376 .5623 .53615 .57268 .53482 .56752 .5504 Mtetra
.432 .09 .283 r
.56752 .5504 .57268 .53482 .58307 .53167 .57801 .54725 Mtetra
.09 0 .143 r
.57801 .54725 .58307 .53167 .59347 .52668 .58835 .53427 Mtetra
.831 .899 .483 r
.58835 .53427 .59347 .52668 .60374 .51534 .59849 .51302 Mtetra
.958 .833 .678 r
.59849 .51302 .60374 .51534 .61388 .49932 .60848 .48879 Mtetra
.825 .697 .722 r
.60848 .48879 .61388 .49932 .62402 .48481 .61862 .47318 Mtetra
.675 .621 .787 r
.61862 .47318 .62402 .48481 .63429 .4751 .62906 .46839 Mtetra
.087 .417 .865 r
.62906 .46839 .63429 .4751 .64493 .47574 .6399 .47412 Mtetra
.701 .162 0 r
.6399 .47412 .64493 .47574 .65593 .48361 .65104 .48528 Mtetra
.519 0 0 r
.65104 .48528 .65593 .48361 .66692 .48886 .66205 .48976 Mtetra
.24 .753 .745 r
.66205 .48976 .66692 .48886 .67781 .48973 .67281 .48683 Mtetra
.795 .909 .919 r
.67281 .48683 .67781 .48973 .68855 .48614 .68341 .47946 Mtetra
.808 .776 .822 r
.68341 .47946 .68855 .48614 .69916 .47941 .69391 .46992 Mtetra
.758 .697 .794 r
.69391 .46992 .69916 .47941 .70974 .47179 .70447 .46151 Mtetra
.714 .666 .801 r
.70447 .46151 .70974 .47179 .72036 .46461 .71516 .45513 Mtetra
.646 .652 .842 r
.71516 .45513 .72036 .46461 .73114 .45984 .72606 .45195 Mtetra
.572 .659 .896 r
.72606 .45195 .73114 .45984 .74209 .45698 .73715 .45091 Mtetra
.522 .699 .95 r
.73715 .45091 .74209 .45698 .75316 .45518 .74834 .45039 Mtetra
.488 .738 .982 r
.74834 .45039 .75316 .45518 .76431 .45389 .75958 .44981 Mtetra
.519 .786 .993 r
.75958 .44981 .76431 .45389 .77551 .45237 .77082 .44835 Mtetra
.567 .81 .99 r
.77082 .44835 .77551 .45237 .78674 .45051 .78205 .44611 Mtetra
.618 .815 .976 r
.78205 .44611 .78674 .45051 .79797 .44805 .79328 .44312 Mtetra
.651 .805 .957 r
.79328 .44312 .79797 .44805 .80921 .4451 .80451 .43959 Mtetra
.666 .788 .939 r
.80451 .43959 .80921 .4451 .82046 .44174 .81576 .43578 Mtetra
.673 .774 .926 r
.81576 .43578 .82046 .44174 .83174 .4381 .82703 .4318 Mtetra
.672 .762 .918 r
.82703 .4318 .83174 .4381 .84304 .43436 .83835 .42784 Mtetra
.67 .755 .914 r
.83835 .42784 .84304 .43436 .85438 .43055 .84972 .42392 Mtetra
.667 .75 .913 r
.84972 .42392 .85438 .43055 .86577 .42676 .86113 .42009 Mtetra
.664 .749 .913 r
.86113 .42009 .86577 .42676 .8772 .42298 .8726 .41632 Mtetra
.662 .749 .915 r
.8726 .41632 .8772 .42298 .88868 .4192 .88412 .41258 Mtetra
.661 .751 .917 r
.88412 .41258 .88868 .4192 .90021 .41544 .89569 .40886 Mtetra
.655 .751 .921 r
.27639 .59249 .28248 .59781 .29179 .59507 .28573 .58963 Mtetra
.654 .747 .918 r
.28573 .58963 .29179 .59507 .30114 .59236 .29511 .58677 Mtetra
.652 .741 .915 r
.29511 .58677 .30114 .59236 .31052 .58969 .30451 .58396 Mtetra
.648 .736 .913 r
.30451 .58396 .31052 .58969 .31993 .58708 .31395 .58123 Mtetra
.642 .731 .913 r
.31395 .58123 .31993 .58708 .32936 .58456 .32341 .57864 Mtetra
.636 .728 .914 r
.32341 .57864 .32936 .58456 .33883 .58207 .33289 .57617 Mtetra
.628 .727 .918 r
.33289 .57617 .33883 .58207 .34834 .57961 .34241 .57387 Mtetra
.626 .732 .924 r
.34241 .57387 .34834 .57961 .35789 .577 .35196 .57161 Mtetra
.624 .745 .934 r
.35196 .57161 .35789 .577 .36749 .57411 .36155 .56932 Mtetra
.637 .773 .945 r
.36155 .56932 .36749 .57411 .37714 .57072 .37119 .56666 Mtetra
.662 .81 .954 r
.37119 .56666 .37714 .57072 .38686 .56659 .3809 .56337 Mtetra
.703 .853 .954 r
.3809 .56337 .38686 .56659 .39663 .56171 .39068 .55906 Mtetra
.755 .882 .936 r
.39068 .55906 .39663 .56171 .40646 .55596 .40054 .55339 Mtetra
.784 .885 .919 r
.40054 .55339 .40646 .55596 .41631 .55015 .41045 .54686 Mtetra
.795 .857 .897 r
.41045 .54686 .41631 .55015 .42616 .54484 .42039 .53983 Mtetra
.743 .791 .891 r
.42039 .53983 .42616 .54484 .43598 .54161 .4303 .53428 Mtetra
.643 .691 .879 r
.4303 .53428 .43598 .54161 .44576 .54151 .44016 .53156 Mtetra
.525 .572 .846 r
.44016 .53156 .44576 .54151 .45555 .54341 .44998 .53214 Mtetra
.385 .468 .823 r
.44998 .53214 .45555 .54341 .46539 .54643 .4598 .53613 Mtetra
.344 .467 .841 r
.4598 .53613 .46539 .54643 .47533 .54735 .46968 .54042 Mtetra
.378 .588 .926 r
.46968 .54042 .47533 .54735 .48539 .54391 .47968 .54249 Mtetra
.754 .94 .944 r
.47968 .54249 .48539 .54391 .49554 .53317 .48984 .53631 Mtetra
.921 .976 .721 r
.48984 .53631 .49554 .53317 .50572 .51579 .50008 .52066 Mtetra
.845 .968 .647 r
.50008 .52066 .50572 .51579 .51584 .50373 .51028 .50558 Mtetra
.766 .996 .816 r
.51028 .50558 .51584 .50373 .52594 .50209 .52044 .4965 Mtetra
.156 .511 .913 r
.52044 .4965 .52594 .50209 .53613 .51119 .53062 .50019 Mtetra
0 0 .495 r
.53062 .50019 .53613 .51119 .54648 .52893 .54095 .51669 Mtetra
0 0 .547 r
.54095 .51669 .54648 .52893 .55698 .54376 .55143 .53332 Mtetra
0 .232 .746 r
.55143 .53332 .55698 .54376 .56752 .5504 .56201 .54341 Mtetra
.654 .716 .894 r
.56201 .54341 .56752 .5504 .57801 .54725 .57252 .54023 Mtetra
.871 .761 .739 r
.57252 .54023 .57801 .54725 .58835 .53427 .58284 .52374 Mtetra
.869 .708 .68 r
.58284 .52374 .58835 .53427 .59849 .51302 .59298 .50064 Mtetra
.852 .685 .674 r
.59298 .50064 .59849 .51302 .60848 .48879 .60304 .4776 Mtetra
.765 .667 .755 r
.60304 .4776 .60848 .48879 .61862 .47318 .61335 .4674 Mtetra
.284 .581 .942 r
.61335 .4674 .61862 .47318 .62906 .46839 .62405 .47007 Mtetra
.688 .169 0 r
.62405 .47007 .62906 .46839 .6399 .47412 .63503 .47883 Mtetra
.702 .238 .148 r
.63503 .47883 .6399 .47412 .65104 .48528 .64615 .48821 Mtetra
.262 0 0 r
.64615 .48821 .65104 .48528 .66205 .48976 .65702 .48803 Mtetra
.825 .951 .901 r
.65702 .48803 .66205 .48976 .67281 .48683 .66758 .47946 Mtetra
.818 .76 .797 r
.66758 .47946 .67281 .48683 .68341 .47946 .67804 .4686 Mtetra
.774 .681 .76 r
.67804 .4686 .68341 .47946 .69391 .46992 .68852 .45802 Mtetra
.714 .64 .773 r
.68852 .45802 .69391 .46992 .70447 .46151 .69916 .45091 Mtetra
.656 .634 .817 r
.69916 .45091 .70447 .46151 .71516 .45513 .71002 .44716 Mtetra
.563 .654 .896 r
.71002 .44716 .71516 .45513 .72606 .45195 .72109 .44631 Mtetra
.433 .673 .964 r
.72109 .44631 .72606 .45195 .73715 .45091 .73232 .447 Mtetra
.385 .725 .99 r
.73232 .447 .73715 .45091 .74834 .45039 .74358 .44718 Mtetra
.414 .773 .995 r
.74358 .44718 .74834 .45039 .75958 .44981 .75486 .44649 Mtetra
.53 .826 .999 r
.75486 .44649 .75958 .44981 .77082 .44835 .76609 .44439 Mtetra
.617 .834 .983 r
.76609 .44439 .77082 .44835 .78205 .44611 .77729 .44124 Mtetra
.662 .812 .956 r
.77729 .44124 .78205 .44611 .79328 .44312 .78849 .43744 Mtetra
.681 .787 .931 r
.78849 .43744 .79328 .44312 .80451 .43959 .7997 .43325 Mtetra
.682 .764 .914 r
.7997 .43325 .80451 .43959 .81576 .43578 .81095 .42903 Mtetra
.68 .75 .905 r
.81095 .42903 .81576 .43578 .82703 .4318 .82223 .42483 Mtetra
.673 .742 .902 r
.82223 .42483 .82703 .4318 .83835 .42784 .83358 .42081 Mtetra
.668 .738 .903 r
.83358 .42081 .83835 .42784 .84972 .42392 .84498 .41692 Mtetra
.663 .738 .906 r
.84498 .41692 .84972 .42392 .86113 .42009 .85644 .41316 Mtetra
.66 .74 .909 r
.85644 .41316 .86113 .42009 .8726 .41632 .86796 .40949 Mtetra
.658 .743 .913 r
.86796 .40949 .8726 .41632 .88412 .41258 .87952 .40586 Mtetra
.657 .748 .917 r
.87952 .40586 .88412 .41258 .89569 .40886 .89113 .40224 Mtetra
.661 .753 .918 r
.27027 .58715 .27639 .59249 .28573 .58963 .27964 .58411 Mtetra
.662 .747 .914 r
.27964 .58411 .28573 .58963 .29511 .58677 .28904 .58106 Mtetra
.66 .741 .91 r
.28904 .58106 .29511 .58677 .30451 .58396 .29848 .57803 Mtetra
.657 .733 .906 r
.29848 .57803 .30451 .58396 .31395 .58123 .30795 .57507 Mtetra
.652 .725 .902 r
.30795 .57507 .31395 .58123 .32341 .57864 .31744 .57224 Mtetra
.644 .715 .899 r
.31744 .57224 .32341 .57864 .33289 .57617 .32695 .56959 Mtetra
.632 .706 .899 r
.32695 .56959 .33289 .57617 .34241 .57387 .33649 .56723 Mtetra
.621 .701 .902 r
.33649 .56723 .34241 .57387 .35196 .57161 .34604 .56513 Mtetra
.606 .702 .912 r
.34604 .56513 .35196 .57161 .36155 .56932 .35562 .56335 Mtetra
.603 .719 .926 r
.35562 .56335 .36155 .56932 .37119 .56666 .36525 .56154 Mtetra
.606 .753 .948 r
.36525 .56154 .37119 .56666 .3809 .56337 .37492 .55951 Mtetra
.641 .816 .967 r
.37492 .55951 .3809 .56337 .39068 .55906 .38468 .55654 Mtetra
.702 .884 .965 r
.38468 .55654 .39068 .55906 .40054 .55339 .39452 .55204 Mtetra
.762 .934 .941 r
.39452 .55204 .40054 .55339 .41045 .54686 .40446 .54587 Mtetra
.823 .942 .903 r
.40446 .54587 .41045 .54686 .42039 .53983 .41447 .53788 Mtetra
.825 .907 .896 r
.41447 .53788 .42039 .53983 .4303 .53428 .42449 .52981 Mtetra
.78 .816 .881 r
.42449 .52981 .4303 .53428 .44016 .53156 .43449 .52297 Mtetra
.651 .662 .848 r
.43449 .52297 .44016 .53156 .44998 .53214 .44441 .51989 Mtetra
.478 .504 .806 r
.44441 .51989 .44998 .53214 .4598 .53613 .45425 .5221 Mtetra
.35 .4 .773 r
.45425 .5221 .4598 .53613 .46968 .54042 .4641 .52803 Mtetra
.199 .334 .777 r
.4641 .52803 .46968 .54042 .47968 .54249 .47401 .53589 Mtetra
.385 .606 .936 r
.47401 .53589 .47968 .54249 .48984 .53631 .48409 .53766 Mtetra
.73 .99 .854 r
.48409 .53766 .48984 .53631 .50008 .52066 .49433 .52981 Mtetra
0 0 0 r
.49433 .52981 .50008 .52066 .51028 .50558 .50462 .51551 Mtetra
.50462 .51551 .51028 .50558 .52044 .4965 .51488 .49831 Mtetra
.694 .98 .817 r
.51488 .49831 .52044 .4965 .53062 .50019 .5251 .49039 Mtetra
.339 .478 .853 r
.5251 .49039 .53062 .50019 .54095 .51669 .53537 .49459 Mtetra
.4 .356 .694 r
.53537 .49459 .54095 .51669 .55143 .53332 .54574 .50258 Mtetra
.471 .366 .654 r
.54574 .50258 .55143 .53332 .56201 .54341 .55621 .50941 Mtetra
.594 .442 .645 r
.55621 .50941 .56201 .54341 .57252 .54023 .56666 .50619 Mtetra
.673 .496 .638 r
.56666 .50619 .57252 .54023 .58284 .52374 .57699 .49287 Mtetra
.691 .514 .643 r
.57699 .49287 .58284 .52374 .59298 .50064 .58727 .47836 Mtetra
.695 .544 .678 r
.58727 .47836 .59298 .50064 .60304 .4776 .59761 .46762 Mtetra
.487 .559 .854 r
.59761 .46762 .60304 .4776 .61335 .4674 .60824 .46907 Mtetra
.737 .239 .047 r
.60824 .46907 .61335 .4674 .62405 .47007 .61922 .47991 Mtetra
.656 .254 .271 r
.61922 .47991 .62405 .47007 .63503 .47883 .63023 .48787 Mtetra
.506 .085 .176 r
.63023 .48787 .63503 .47883 .64615 .48821 .64113 .48933 Mtetra
.712 .986 .829 r
.64113 .48933 .64615 .48821 .65702 .48803 .65173 .48104 Mtetra
.863 .773 .761 r
.65173 .48104 .65702 .48803 .66758 .47946 .66208 .46652 Mtetra
.776 .655 .728 r
.66208 .46652 .66758 .47946 .67804 .4686 .67249 .45394 Mtetra
.718 .609 .735 r
.67249 .45394 .67804 .4686 .68852 .45802 .68306 .44513 Mtetra
.639 .59 .783 r
.68306 .44513 .68852 .45802 .69916 .45091 .69391 .44169 Mtetra
.521 .599 .872 r
.69391 .44169 .69916 .45091 .71002 .44716 .70502 .44212 Mtetra
.326 .641 .966 r
.70502 .44212 .71002 .44716 .72109 .44631 .71627 .44381 Mtetra
.112 .613 .901 r
.71627 .44381 .72109 .44631 .73232 .447 .72759 .44545 Mtetra
.213 .715 .908 r
.72759 .44545 .73232 .447 .74358 .44718 .73887 .44522 Mtetra
.429 .833 .977 r
.73887 .44522 .74358 .44718 .75486 .44649 .7501 .44327 Mtetra
.617 .867 .99 r
.7501 .44327 .75486 .44649 .76609 .44439 .76127 .43976 Mtetra
.689 .831 .952 r
.76127 .43976 .76609 .44439 .77729 .44124 .77241 .43527 Mtetra
.7 .783 .916 r
.77241 .43527 .77729 .44124 .78849 .43744 .78357 .43053 Mtetra
.697 .752 .894 r
.78357 .43053 .78849 .43744 .7997 .43325 .79477 .42576 Mtetra
.685 .73 .884 r
.79477 .42576 .7997 .43325 .81095 .42903 .80602 .42132 Mtetra
.676 .72 .883 r
.80602 .42132 .81095 .42903 .82223 .42483 .81735 .41715 Mtetra
.667 .718 .887 r
.81735 .41715 .82223 .42483 .83358 .42081 .82874 .41326 Mtetra
.66 .72 .893 r
.82874 .41326 .83358 .42081 .84498 .41692 .84019 .40958 Mtetra
.656 .726 .9 r
.84019 .40958 .84498 .41692 .85644 .41316 .8517 .40601 Mtetra
.653 .731 .907 r
.8517 .40601 .85644 .41316 .86796 .40949 .86327 .40252 Mtetra
.651 .738 .913 r
.86327 .40252 .86796 .40949 .87952 .40586 .87488 .39906 Mtetra
.651 .744 .918 r
.87488 .39906 .87952 .40586 .89113 .40224 .88655 .39556 Mtetra
.665 .754 .916 r
.2641 .58177 .27027 .58715 .27964 .58411 .2735 .57861 Mtetra
.667 .751 .913 r
.2735 .57861 .27964 .58411 .28904 .58106 .28294 .57541 Mtetra
.667 .746 .909 r
.28294 .57541 .28904 .58106 .29848 .57803 .2924 .57218 Mtetra
.666 .739 .905 r
.2924 .57218 .29848 .57803 .30795 .57507 .3019 .56897 Mtetra
.664 .731 .9 r
.3019 .56897 .30795 .57507 .31744 .57224 .31143 .56579 Mtetra
.657 .719 .894 r
.31143 .56579 .31744 .57224 .32695 .56959 .32099 .56278 Mtetra
.647 .705 .889 r
.32099 .56278 .32695 .56959 .33649 .56723 .33056 .56003 Mtetra
.631 .689 .885 r
.33056 .56003 .33649 .56723 .34604 .56513 .34014 .55768 Mtetra
.609 .674 .886 r
.34014 .55768 .34604 .56513 .35562 .56335 .34974 .55587 Mtetra
.592 .667 .891 r
.34974 .55587 .35562 .56335 .36525 .56154 .35935 .55447 Mtetra
.572 .672 .907 r
.35935 .55447 .36525 .56154 .37492 .55951 .369 .55343 Mtetra
.583 .711 .931 r
.369 .55343 .37492 .55951 .38468 .55654 .3787 .55199 Mtetra
.617 .783 .961 r
.3787 .55199 .38468 .55654 .39452 .55204 .3885 .54958 Mtetra
.688 .887 .971 r
.3885 .54958 .39452 .55204 .40446 .54587 .3984 .54529 Mtetra
.777 .96 .927 r
.3984 .54529 .40446 .54587 .41447 .53788 .40842 .5384 Mtetra
.825 .984 .88 r
.40842 .5384 .41447 .53788 .42449 .52981 .41851 .52964 Mtetra
.868 .957 .863 r
.41851 .52964 .42449 .52981 .43449 .52297 .42864 .51963 Mtetra
.806 .86 .889 r
.42864 .51963 .43449 .52297 .44441 .51989 .43871 .51206 Mtetra
.643 .68 .87 r
.43871 .51206 .44441 .51989 .45425 .5221 .44867 .50928 Mtetra
.451 .48 .798 r
.44867 .50928 .45425 .5221 .4641 .52803 .45856 .51231 Mtetra
.258 .319 .736 r
.45856 .51231 .4641 .52803 .47401 .53589 .46843 .52106 Mtetra
.283 .348 .754 r
.46843 .52106 .47401 .53589 .48409 .53766 .47842 .52883 Mtetra
.401 .542 .882 r
.47842 .52883 .48409 .53766 .49433 .52981 .48857 .53142 Mtetra
.673 .976 .836 r
.48857 .53142 .49433 .52981 .50462 .51551 .49887 .52408 Mtetra
.692 .854 .439 r
.49887 .52408 .50462 .51551 .51488 .49831 .50923 .50669 Mtetra
.636 .827 .417 r
.50923 .50669 .51488 .49831 .5251 .49039 .51953 .49055 Mtetra
.872 .976 .846 r
.51953 .49055 .5251 .49039 .53537 .49459 .52981 .47987 Mtetra
.67 .58 .745 r
.52981 .47987 .53537 .49459 .54574 .50258 .5401 .47435 Mtetra
.578 .446 .664 r
.5401 .47435 .54574 .50258 .55621 .50941 .55045 .473 Mtetra
.591 .434 .638 r
.55045 .473 .55621 .50941 .56666 .50619 .56083 .46972 Mtetra
.607 .445 .637 r
.56083 .46972 .56666 .50619 .57699 .49287 .57122 .46451 Mtetra
.574 .443 .665 r
.57122 .46451 .57699 .49287 .58727 .47836 .58171 .46349 Mtetra
.439 .447 .771 r
.58171 .46349 .58727 .47836 .59761 .46762 .59236 .46765 Mtetra
.7 .166 0 r
.59236 .46765 .59761 .46762 .60824 .46907 .60323 .47736 Mtetra
.71 .299 .265 r
.60323 .47736 .60824 .46907 .61922 .47991 .61426 .48838 Mtetra
.481 .05 .143 r
.61426 .48838 .61922 .47991 .63023 .48787 .62512 .48928 Mtetra
.744 .992 .811 r
.62512 .48928 .63023 .48787 .64113 .48933 .63571 .48012 Mtetra
.834 .725 .745 r
.63571 .48012 .64113 .48933 .65173 .48104 .64611 .46568 Mtetra
.782 .635 .698 r
.64611 .46568 .65173 .48104 .66208 .46652 .65644 .4502 Mtetra
.717 .594 .718 r
.65644 .4502 .66208 .46652 .67249 .45394 .66698 .44052 Mtetra
.644 .585 .774 r
.66698 .44052 .67249 .45394 .68306 .44513 .67779 .43673 Mtetra
.478 .6 .896 r
.67779 .43673 .68306 .44513 .69391 .44169 .6889 .43784 Mtetra
.036 .505 .884 r
.6889 .43784 .69391 .44169 .70502 .44212 .70021 .44147 Mtetra
.183 0 0 r
.70021 .44147 .70502 .44212 .71627 .44381 .71154 .44384 Mtetra
.056 0 0 r
.71154 .44384 .71627 .44381 .72759 .44545 .72284 .44431 Mtetra
.378 .828 .934 r
.72284 .44431 .72759 .44545 .73887 .44522 .73404 .44211 Mtetra
.649 .883 .983 r
.73404 .44211 .73887 .44522 .7501 .44327 .74517 .43797 Mtetra
.715 .813 .926 r
.74517 .43797 .7501 .44327 .76127 .43976 .75626 .43283 Mtetra
.721 .759 .883 r
.75626 .43283 .76127 .43976 .77241 .43527 .76735 .42725 Mtetra
.703 .722 .864 r
.76735 .42725 .77241 .43527 .78357 .43053 .7785 .42206 Mtetra
.69 .705 .859 r
.7785 .42206 .78357 .43053 .79477 .42576 .78972 .41726 Mtetra
.674 .698 .865 r
.78972 .41726 .79477 .42576 .80602 .42132 .80102 .41304 Mtetra
.663 .7 .874 r
.80102 .41304 .80602 .42132 .81735 .41715 .81241 .40922 Mtetra
.655 .707 .886 r
.81241 .40922 .81735 .41715 .82874 .41326 .82386 .40567 Mtetra
.649 .715 .897 r
.82386 .40567 .82874 .41326 .84019 .40958 .83537 .40229 Mtetra
.647 .725 .905 r
.83537 .40229 .84019 .40958 .8517 .40601 .84694 .39894 Mtetra
.646 .733 .912 r
.84694 .39894 .8517 .40601 .86327 .40252 .85856 .39561 Mtetra
.646 .739 .917 r
.85856 .39561 .86327 .40252 .87488 .39906 .87022 .39226 Mtetra
.648 .744 .92 r
.87022 .39226 .87488 .39906 .88655 .39556 .88193 .38884 Mtetra
.665 .754 .916 r
.25789 .57635 .2641 .58177 .2735 .57861 .26731 .57318 Mtetra
.668 .754 .915 r
.26731 .57318 .2735 .57861 .28294 .57541 .27677 .56992 Mtetra
.671 .754 .913 r
.27677 .56992 .28294 .57541 .2924 .57218 .28627 .56658 Mtetra
.673 .751 .909 r
.28627 .56658 .2924 .57218 .3019 .56897 .2958 .56317 Mtetra
.677 .746 .903 r
.2958 .56317 .3019 .56897 .31143 .56579 .30537 .55965 Mtetra
.675 .734 .895 r
.30537 .55965 .31143 .56579 .32099 .56278 .31497 .55614 Mtetra
.67 .718 .885 r
.31497 .55614 .32099 .56278 .33056 .56003 .3246 .55273 Mtetra
.656 .695 .874 r
.3246 .55273 .33056 .56003 .34014 .55768 .33424 .54967 Mtetra
.635 .669 .865 r
.33424 .54967 .34014 .55768 .34974 .55587 .34388 .54717 Mtetra
.607 .641 .858 r
.34388 .54717 .34974 .55587 .35935 .55447 .35352 .54544 Mtetra
.57 .617 .86 r
.35352 .54544 .35935 .55447 .369 .55343 .36316 .5447 Mtetra
.545 .614 .872 r
.36316 .5447 .369 .55343 .3787 .55199 .37282 .5445 Mtetra
.517 .638 .908 r
.37282 .5445 .3787 .55199 .3885 .54958 .38252 .54457 Mtetra
.545 .742 .967 r
.38252 .54457 .3885 .54958 .3984 .54529 .39233 .54343 Mtetra
.617 .896 .988 r
.39233 .54343 .3984 .54529 .40842 .5384 .40226 .53992 Mtetra
.676 .977 .86 r
.40226 .53992 .40842 .5384 .41851 .52964 .41234 .53308 Mtetra
.786 .99 .754 r
.41234 .53308 .41851 .52964 .42864 .51963 .42256 .52232 Mtetra
.847 .998 .784 r
.42256 .52232 .42864 .51963 .43871 .51206 .43279 .51085 Mtetra
.866 .928 .864 r
.43279 .51085 .43871 .51206 .44867 .50928 .44297 .5009 Mtetra
.689 .685 .841 r
.44297 .5009 .44867 .50928 .45856 .51231 .45302 .49645 Mtetra
.472 .452 .755 r
.45302 .49645 .45856 .51231 .46843 .52106 .46297 .49965 Mtetra
.356 .33 .692 r
.46297 .49965 .46843 .52106 .47842 .52883 .47289 .50856 Mtetra
.235 .259 .682 r
.47289 .50856 .47842 .52883 .48857 .53142 .4829 .52057 Mtetra
.341 .458 .834 r
.4829 .52057 .48857 .53142 .49887 .52408 .4931 .52511 Mtetra
.714 .987 .87 r
.4931 .52511 .49887 .52408 .50923 .50669 .50347 .51768 Mtetra
0 0 0 r
.50347 .51768 .50923 .50669 .51953 .49055 .51387 .50114 Mtetra
.745 .839 .389 r
.51387 .50114 .51953 .49055 .52981 .47987 .52424 .47874 Mtetra
.95 .876 .727 r
.52424 .47874 .52981 .47987 .5401 .47435 .53454 .45966 Mtetra
.75 .621 .716 r
.53454 .45966 .5401 .47435 .55045 .473 .54482 .44795 Mtetra
.605 .475 .677 r
.54482 .44795 .55045 .473 .56083 .46972 .55516 .44463 Mtetra
.478 .391 .68 r
.55516 .44463 .56083 .46972 .57122 .46451 .56565 .44974 Mtetra
.069 .21 .703 r
.56565 .44974 .57122 .46451 .58171 .46349 .57635 .46227 Mtetra
.815 .333 .031 r
.57635 .46227 .58171 .46349 .59236 .46765 .58725 .47819 Mtetra
.685 .292 .297 r
.58725 .47819 .59236 .46765 .60323 .47736 .59819 .48828 Mtetra
.5 .102 .217 r
.59819 .48828 .60323 .47736 .61426 .48838 .60902 .48923 Mtetra
.852 .997 .818 r
.60902 .48923 .61426 .48838 .62512 .48928 .61958 .47807 Mtetra
.844 .699 .703 r
.61958 .47807 .62512 .48928 .63571 .48012 .62989 .45931 Mtetra
.745 .581 .673 r
.62989 .45931 .63571 .48012 .64611 .46568 .64024 .44364 Mtetra
.687 .542 .683 r
.64024 .44364 .64611 .46568 .65644 .4502 .65078 .43374 Mtetra
.602 .529 .745 r
.65078 .43374 .65644 .4502 .66698 .44052 .66164 .43161 Mtetra
.362 .521 .881 r
.66164 .43161 .66698 .44052 .67779 .43673 .67281 .43509 Mtetra
.345 0 0 r
.67281 .43509 .67779 .43673 .6889 .43784 .68415 .44015 Mtetra
.515 0 0 r
.68415 .44015 .6889 .43784 .70021 .44147 .69555 .44452 Mtetra
.302 0 0 r
.69555 .44452 .70021 .44147 .71154 .44384 .70682 .44489 Mtetra
.216 .734 .716 r
.70682 .44489 .71154 .44384 .72284 .44431 .71797 .44184 Mtetra
.703 .924 .966 r
.71797 .44184 .72284 .44431 .73404 .44211 .729 .43637 Mtetra
.761 .809 .891 r
.729 .43637 .73404 .44211 .74517 .43797 .73999 .42962 Mtetra
.732 .723 .843 r
.73999 .42962 .74517 .43797 .75626 .43283 .75102 .42314 Mtetra
.709 .684 .825 r
.75102 .42314 .75626 .43283 .76735 .42725 .76211 .41721 Mtetra
.683 .666 .827 r
.76211 .41721 .76735 .42725 .7785 .42206 .7733 .4123 Mtetra
.665 .665 .84 r
.7733 .4123 .7785 .42206 .78972 .41726 .7846 .40817 Mtetra
.652 .675 .859 r
.7846 .40817 .78972 .41726 .80102 .41304 .79599 .40463 Mtetra
.642 .689 .879 r
.79599 .40463 .80102 .41304 .81241 .40922 .80745 .40145 Mtetra
.639 .707 .896 r
.80745 .40145 .81241 .40922 .82386 .40567 .81898 .39837 Mtetra
.637 .721 .909 r
.81898 .39837 .82386 .40567 .83537 .40229 .83055 .3953 Mtetra
.64 .734 .916 r
.83055 .3953 .83537 .40229 .84694 .39894 .84217 .39212 Mtetra
.642 .741 .921 r
.84217 .39212 .84694 .39894 .85856 .39561 .85383 .38886 Mtetra
.644 .745 .923 r
.85383 .38886 .85856 .39561 .87022 .39226 .86553 .38551 Mtetra
.647 .748 .923 r
.86553 .38551 .87022 .39226 .88193 .38884 .87727 .38207 Mtetra
.659 .752 .919 r
.25164 .57089 .25789 .57635 .26731 .57318 .26107 .56784 Mtetra
.662 .758 .921 r
.26107 .56784 .26731 .57318 .27677 .56992 .27054 .56471 Mtetra
.666 .764 .923 r
.27054 .56471 .27677 .56992 .28627 .56658 .28005 .56146 Mtetra
.673 .769 .923 r
.28005 .56146 .28627 .56658 .2958 .56317 .28961 .55804 Mtetra
.681 .772 .92 r
.28961 .55804 .2958 .56317 .30537 .55965 .29921 .5544 Mtetra
.687 .77 .914 r
.29921 .5544 .30537 .55965 .31497 .55614 .30885 .55059 Mtetra
.693 .76 .904 r
.30885 .55059 .31497 .55614 .3246 .55273 .31853 .54659 Mtetra
.687 .74 .891 r
.31853 .54659 .3246 .55273 .33424 .54967 .32824 .54268 Mtetra
.675 .712 .876 r
.32824 .54268 .33424 .54967 .34388 .54717 .33796 .53905 Mtetra
.647 .672 .86 r
.33796 .53905 .34388 .54717 .35352 .54544 .34768 .53616 Mtetra
.606 .628 .847 r
.34768 .53616 .35352 .54544 .36316 .5447 .35737 .53442 Mtetra
.563 .587 .836 r
.35737 .53442 .36316 .5447 .37282 .5445 .36705 .53394 Mtetra
.506 .553 .838 r
.36705 .53394 .37282 .5445 .38252 .54457 .37671 .53493 Mtetra
.488 .565 .86 r
.37671 .53493 .38252 .54457 .39233 .54343 .38642 .53608 Mtetra
.493 .635 .916 r
.38642 .53608 .39233 .54343 .40226 .53992 .39623 .53647 Mtetra
.598 .828 .987 r
.39623 .53647 .40226 .53992 .41234 .53308 .4062 .53392 Mtetra
.724 .985 .894 r
.4062 .53392 .41234 .53308 .42256 .52232 .41635 .52692 Mtetra
.687 .945 .667 r
.41635 .52692 .42256 .52232 .43279 .51085 .42662 .51633 Mtetra
.772 .955 .637 r
.42662 .51633 .43279 .51085 .44297 .5009 .43696 .50297 Mtetra
.855 .997 .805 r
.43696 .50297 .44297 .5009 .45302 .49645 .44722 .49177 Mtetra
.754 .814 .9 r
.44722 .49177 .45302 .49645 .46297 .49965 .45736 .4858 Mtetra
.497 .493 .783 r
.45736 .4858 .46297 .49965 .47289 .50856 .46739 .48771 Mtetra
.312 .305 .691 r
.46739 .48771 .47289 .50856 .4829 .52057 .47737 .49771 Mtetra
.35 .318 .682 r
.47737 .49771 .4829 .52057 .4931 .52511 .48748 .50743 Mtetra
.444 .42 .737 r
.48748 .50743 .4931 .52511 .50347 .51768 .49774 .51199 Mtetra
.744 .785 .886 r
.49774 .51199 .50347 .51768 .51387 .50114 .50815 .50606 Mtetra
.869 .967 .643 r
.50815 .50606 .51387 .50114 .52424 .47874 .5186 .48964 Mtetra
0 0 0 r
.5186 .48964 .52424 .47874 .53454 .45966 .529 .47246 Mtetra
.529 .47246 .53454 .45966 .54482 .44795 .53937 .45949 Mtetra
.364 0 .169 r
.53937 .45949 .54482 .44795 .55516 .44463 .5498 .45617 Mtetra
.624 .237 .29 r
.5498 .45617 .55516 .44463 .56565 .44974 .56037 .46251 Mtetra
.681 .308 .333 r
.56037 .46251 .56565 .44974 .57635 .46227 .5711 .47313 Mtetra
.68 .29 .301 r
.5711 .47313 .57635 .46227 .58725 .47819 .58195 .48302 Mtetra
.319 0 0 r
.58195 .48302 .58725 .47819 .59819 .48828 .59271 .48239 Mtetra
.841 .799 .811 r
.59271 .48239 .59819 .48828 .60902 .48923 .60328 .47117 Mtetra
.769 .61 .682 r
.60328 .47117 .60902 .48923 .61958 .47807 .6137 .45471 Mtetra
.739 .567 .661 r
.6137 .45471 .61958 .47807 .62989 .45931 .62406 .43791 Mtetra
.677 .539 .689 r
.62406 .43791 .62989 .45931 .64024 .44364 .63465 .42927 Mtetra
.571 .534 .775 r
.63465 .42927 .64024 .44364 .65078 .43374 .64554 .42864 Mtetra
.034 .454 .876 r
.64554 .42864 .65078 .43374 .66164 .43161 .65671 .43335 Mtetra
.614 .067 0 r
.65671 .43335 .66164 .43161 .67281 .43509 .66808 .44027 Mtetra
.554 .061 .041 r
.66808 .44027 .67281 .43509 .68415 .44015 .67943 .44442 Mtetra
.364 0 0 r
.67943 .44442 .68415 .44015 .69555 .44452 .69069 .4449 Mtetra
.408 .86 .839 r
.69069 .4449 .69555 .44452 .70682 .44489 .70177 .44083 Mtetra
.779 .874 .917 r
.70177 .44083 .70682 .44489 .71797 .44184 .71272 .43374 Mtetra
.764 .74 .831 r
.71272 .43374 .71797 .44184 .729 .43637 .72364 .42584 Mtetra
.736 .679 .795 r
.72364 .42584 .729 .43637 .73999 .42962 .73458 .41809 Mtetra
.701 .647 .793 r
.73458 .41809 .73999 .42962 .75102 .42314 .74564 .41185 Mtetra
.676 .64 .806 r
.74564 .41185 .75102 .42314 .76211 .41721 .75682 .40689 Mtetra
.653 .648 .832 r
.75682 .40689 .76211 .41721 .7733 .4123 .76813 .40313 Mtetra
.635 .666 .863 r
.76813 .40313 .7733 .4123 .7846 .40817 .77954 .40014 Mtetra
.626 .693 .892 r
.77954 .40014 .7846 .40817 .79599 .40463 .79102 .39742 Mtetra
.62 .717 .915 r
.79102 .39742 .79599 .40463 .80745 .40145 .80257 .39481 Mtetra
.624 .739 .929 r
.80257 .39481 .80745 .40145 .81898 .39837 .81415 .392 Mtetra
.629 .752 .935 r
.81415 .392 .81898 .39837 .83055 .3953 .82577 .38901 Mtetra
.638 .759 .936 r
.82577 .38901 .83055 .3953 .84217 .39212 .83742 .38578 Mtetra
.644 .761 .934 r
.83742 .38578 .84217 .39212 .85383 .38886 .84911 .38238 Mtetra
.649 .759 .93 r
.84911 .38238 .85383 .38886 .86553 .38551 .86082 .37886 Mtetra
.652 .755 .925 r
.86082 .37886 .86553 .38551 .87727 .38207 .87259 .37524 Mtetra
.648 .75 .923 r
.24535 .5654 .25164 .57089 .26107 .56784 .25478 .56258 Mtetra
.649 .759 .93 r
.25478 .56258 .26107 .56784 .27054 .56471 .26425 .55973 Mtetra
.652 .771 .936 r
.26425 .55973 .27054 .56471 .28005 .56146 .27376 .55676 Mtetra
.66 .784 .941 r
.27376 .55676 .28005 .56146 .28961 .55804 .28332 .5536 Mtetra
.671 .797 .942 r
.28332 .5536 .28961 .55804 .29921 .5544 .29293 .55015 Mtetra
.685 .808 .941 r
.29293 .55015 .29921 .5544 .30885 .55059 .3026 .54634 Mtetra
.704 .812 .932 r
.3026 .54634 .30885 .55059 .31853 .54659 .31232 .54207 Mtetra
.715 .804 .92 r
.31232 .54207 .31853 .54659 .32824 .54268 .3221 .53748 Mtetra
.722 .781 .899 r
.3221 .53748 .32824 .54268 .33796 .53905 .33191 .53259 Mtetra
.706 .738 .876 r
.33191 .53259 .33796 .53905 .34768 .53616 .34174 .52798 Mtetra
.676 .683 .848 r
.34174 .52798 .34768 .53616 .35737 .53442 .35156 .52407 Mtetra
.626 .616 .82 r
.35156 .52407 .35737 .53442 .36705 .53394 .36133 .52161 Mtetra
.561 .55 .799 r
.36133 .52161 .36705 .53394 .37671 .53493 .37105 .52129 Mtetra
.505 .5 .785 r
.37105 .52129 .37671 .53493 .38642 .53608 .38074 .52284 Mtetra
.435 .466 .793 r
.38074 .52284 .38642 .53608 .39623 .53647 .39042 .52615 Mtetra
.413 .511 .849 r
.39042 .52615 .39623 .53647 .4062 .53392 .4002 .52893 Mtetra
.405 .687 .976 r
.4002 .52893 .4062 .53392 .41635 .52692 .41012 .52947 Mtetra
.302 .776 .671 r
.41012 .52947 .41635 .52692 .42662 .51633 .42026 .52506 Mtetra
0 0 0 r
.42026 .52506 .42662 .51633 .43696 .50297 .43061 .5142 Mtetra
.43061 .5142 .43696 .50297 .44722 .49177 .44105 .49987 Mtetra
.678 .869 .479 r
.44105 .49987 .44722 .49177 .45736 .4858 .45147 .48434 Mtetra
.884 .916 .843 r
.45147 .48434 .45736 .4858 .46739 .48771 .46178 .47318 Mtetra
.637 .564 .756 r
.46178 .47318 .46739 .48771 .47737 .49771 .47196 .46957 Mtetra
.482 .381 .663 r
.47196 .46957 .47737 .49771 .48748 .50743 .48205 .47463 Mtetra
.37 .288 .632 r
.48205 .47463 .48748 .50743 .49774 .51199 .49217 .48739 Mtetra
.322 .29 .667 r
.49217 .48739 .49774 .51199 .50815 .50606 .50242 .4989 Mtetra
0 .355 .829 r
.50242 .4989 .50815 .50606 .5186 .48964 .51283 .50525 Mtetra
.522 .166 .305 r
.51283 .50525 .5186 .48964 .529 .47246 .52335 .50642 Mtetra
.489 .207 .412 r
.52335 .50642 .529 .47246 .53937 .45949 .53392 .50296 Mtetra
.505 .236 .441 r
.53392 .50296 .53937 .45949 .5498 .45617 .54453 .49966 Mtetra
.506 .237 .441 r
.54453 .49966 .5498 .45617 .56037 .46251 .55518 .49651 Mtetra
.437 .162 .398 r
.55518 .49651 .56037 .46251 .5711 .47313 .56582 .48872 Mtetra
.065 0 .116 r
.56582 .48872 .5711 .47313 .58195 .48302 .57639 .47569 Mtetra
.882 .762 .725 r
.57639 .47569 .58195 .48302 .59271 .48239 .58683 .45743 Mtetra
.748 .568 .65 r
.58683 .45743 .59271 .48239 .60328 .47117 .5972 .43785 Mtetra
.663 .49 .64 r
.5972 .43785 .60328 .47117 .6137 .45471 .60769 .426 Mtetra
.595 .457 .663 r
.60769 .426 .6137 .45471 .62406 .43791 .61842 .42291 Mtetra
.423 .44 .773 r
.61842 .42291 .62406 .43791 .63465 .42927 .62945 .42749 Mtetra
.604 .037 0 r
.62945 .42749 .63465 .42927 .64554 .42864 .64072 .43653 Mtetra
.654 .22 .205 r
.64072 .43653 .64554 .42864 .65671 .43335 .65208 .44441 Mtetra
.578 .176 .244 r
.65208 .44441 .65671 .43335 .66808 .44027 .66341 .44878 Mtetra
.35 0 .068 r
.66341 .44878 .66808 .44027 .67943 .44442 .67454 .44657 Mtetra
.513 .894 .715 r
.67454 .44657 .67943 .44442 .69069 .4449 .68547 .4393 Mtetra
.823 .823 .848 r
.68547 .4393 .69069 .4449 .70177 .44083 .6963 .42971 Mtetra
.768 .682 .768 r
.6963 .42971 .70177 .44083 .71272 .43374 .7071 .41956 Mtetra
.715 .618 .748 r
.7071 .41956 .71272 .43374 .72364 .42584 .718 .41119 Mtetra
.683 .597 .753 r
.718 .41119 .72364 .42584 .73458 .41809 .72904 .40474 Mtetra
.651 .596 .78 r
.72904 .40474 .73458 .41809 .74564 .41185 .74024 .40048 Mtetra
.624 .614 .82 r
.74024 .40048 .74564 .41185 .75682 .40689 .7516 .39772 Mtetra
.604 .652 .87 r
.7516 .39772 .75682 .40689 .76813 .40313 .76305 .39568 Mtetra
.586 .693 .916 r
.76305 .39568 .76813 .40313 .77954 .40014 .77459 .39395 Mtetra
.587 .739 .948 r
.77459 .39395 .77954 .40014 .79102 .39742 .78617 .3919 Mtetra
.593 .769 .963 r
.78617 .3919 .79102 .39742 .80257 .39481 .79777 .38952 Mtetra
.613 .788 .965 r
.79777 .38952 .80257 .39481 .81415 .392 .80939 .38666 Mtetra
.63 .794 .961 r
.80939 .38666 .81415 .392 .82577 .38901 .82102 .38342 Mtetra
.645 .791 .952 r
.82102 .38342 .82577 .38901 .83742 .38578 .83268 .37989 Mtetra
.655 .784 .943 r
.83268 .37989 .83742 .38578 .84911 .38238 .84437 .37615 Mtetra
.66 .774 .934 r
.84437 .37615 .84911 .38238 .86082 .37886 .85609 .37228 Mtetra
.662 .763 .925 r
.85609 .37228 .86082 .37886 .87259 .37524 .86786 .36837 Mtetra
.638 .747 .927 r
.23902 .55988 .24535 .5654 .25478 .56258 .24845 .55727 Mtetra
.635 .755 .934 r
.24845 .55727 .25478 .56258 .26425 .55973 .25792 .55469 Mtetra
.635 .766 .942 r
.25792 .55469 .26425 .55973 .27376 .55676 .26742 .55206 Mtetra
.639 .781 .949 r
.26742 .55206 .27376 .55676 .28332 .5536 .27697 .54929 Mtetra
.645 .799 .957 r
.27697 .54929 .28332 .5536 .29293 .55015 .28657 .54633 Mtetra
.659 .822 .962 r
.28657 .54633 .29293 .55015 .3026 .54634 .29623 .543 Mtetra
.681 .846 .962 r
.29623 .543 .3026 .54634 .31232 .54207 .30596 .53913 Mtetra
.706 .867 .958 r
.30596 .53913 .31232 .54207 .3221 .53748 .31576 .53464 Mtetra
.738 .874 .944 r
.31576 .53464 .3221 .53748 .33191 .53259 .32563 .52939 Mtetra
.753 .861 .929 r
.32563 .52939 .33191 .53259 .34174 .52798 .33555 .52373 Mtetra
.756 .822 .904 r
.33555 .52373 .34174 .52798 .35156 .52407 .34549 .51786 Mtetra
.721 .751 .877 r
.34549 .51786 .35156 .52407 .36133 .52161 .35542 .51277 Mtetra
.662 .664 .842 r
.35542 .51277 .36133 .52161 .37105 .52129 .3653 .50924 Mtetra
.585 .568 .801 r
.3653 .50924 .37105 .52129 .38074 .52284 .37511 .50809 Mtetra
.496 .481 .77 r
.37511 .50809 .38074 .52284 .39042 .52615 .38483 .51005 Mtetra
.441 .432 .753 r
.38483 .51005 .39042 .52615 .4002 .52893 .39454 .51399 Mtetra
.385 .413 .767 r
.39454 .51399 .4002 .52893 .41012 .52947 .40429 .51904 Mtetra
.433 .522 .85 r
.40429 .51904 .41012 .52947 .42026 .52506 .41422 .52145 Mtetra
.606 .829 .985 r
.41422 .52145 .42026 .52506 .43061 .5142 .42437 .51872 Mtetra
.518 .867 .616 r
.42437 .51872 .43061 .5142 .44105 .49987 .43472 .5102 Mtetra
0 0 0 r
.43472 .5102 .44105 .49987 .45147 .48434 .44521 .49592 Mtetra
.44521 .49592 .45147 .48434 .46178 .47318 .4557 .48031 Mtetra
.634 .864 .498 r
.4557 .48031 .46178 .47318 .47196 .46957 .46612 .46671 Mtetra
.743 .89 .946 r
.46612 .46671 .47196 .46957 .48205 .47463 .4764 .46106 Mtetra
.401 .444 .789 r
.4764 .46106 .48205 .47463 .49217 .48739 .48658 .46537 Mtetra
.337 .315 .687 r
.48658 .46537 .49217 .48739 .50242 .4989 .49681 .47503 Mtetra
.3 .28 .668 r
.49681 .47503 .50242 .4989 .51283 .50525 .50714 .48691 Mtetra
.324 .339 .722 r
.50714 .48691 .51283 .50525 .52335 .50642 .51762 .49537 Mtetra
.449 .522 .841 r
.51762 .49537 .52335 .50642 .53392 .50296 .5282 .49774 Mtetra
.65 .786 .947 r
.5282 .49774 .53392 .50296 .54453 .49966 .53884 .49442 Mtetra
.814 .816 .852 r
.53884 .49442 .54453 .49966 .55518 .49651 .54948 .48537 Mtetra
.817 .692 .726 r
.54948 .48537 .55518 .49651 .56582 .48872 .56006 .4702 Mtetra
.78 .614 .673 r
.56006 .4702 .56582 .48872 .57639 .47569 .57055 .45155 Mtetra
.732 .56 .659 r
.57055 .45155 .57639 .47569 .58683 .45743 .58103 .43507 Mtetra
.698 .546 .678 r
.58103 .43507 .58683 .45743 .5972 .43785 .59156 .42395 Mtetra
.58 .546 .781 r
.59156 .42395 .5972 .43785 .60769 .426 .60233 .42287 Mtetra
.402 0 0 r
.60233 .42287 .60769 .426 .61842 .42291 .61338 .42987 Mtetra
.681 .24 .197 r
.61338 .42987 .61842 .42291 .62945 .42749 .6246 .43894 Mtetra
.641 .245 .278 r
.6246 .43894 .62945 .42749 .64072 .43653 .6359 .4467 Mtetra
.516 .102 .193 r
.6359 .4467 .64072 .43653 .65208 .44441 .64711 .44863 Mtetra
.017 0 0 r
.64711 .44863 .65208 .44441 .66341 .44878 .65815 .44467 Mtetra
.83 .873 .876 r
.65815 .44467 .66341 .44878 .67454 .44657 .66901 .43545 Mtetra
.79 .69 .754 r
.66901 .43545 .67454 .44657 .68547 .4393 .67974 .4235 Mtetra
.735 .612 .721 r
.67974 .4235 .68547 .4393 .6963 .42971 .69051 .41266 Mtetra
.702 .584 .72 r
.69051 .41266 .6963 .42971 .7071 .41956 .70138 .40382 Mtetra
.664 .575 .745 r
.70138 .40382 .7071 .41956 .718 .41119 .71245 .39818 Mtetra
.63 .59 .791 r
.71245 .39818 .718 .41119 .72904 .40474 .7237 .39498 Mtetra
.59 .631 .86 r
.7237 .39498 .72904 .40474 .74024 .40048 .7351 .39338 Mtetra
.539 .683 .932 r
.7351 .39338 .74024 .40048 .7516 .39772 .74662 .3926 Mtetra
.508 .746 .981 r
.74662 .3926 .7516 .39772 .76305 .39568 .75819 .39161 Mtetra
.496 .786 .997 r
.75819 .39161 .76305 .39568 .77459 .39395 .7698 .39021 Mtetra
.536 .82 .998 r
.7698 .39021 .77459 .39395 .78617 .3919 .7814 .388 Mtetra
.58 .834 .993 r
.7814 .388 .78617 .3919 .79777 .38952 .79301 .38516 Mtetra
.622 .832 .981 r
.79301 .38516 .79777 .38952 .80939 .38666 .80463 .38176 Mtetra
.648 .821 .966 r
.80463 .38176 .80939 .38666 .82102 .38342 .81625 .37797 Mtetra
.662 .804 .951 r
.81625 .37797 .82102 .38342 .83268 .37989 .82791 .37397 Mtetra
.669 .79 .939 r
.82791 .37397 .83268 .37989 .84437 .37615 .8396 .36983 Mtetra
.672 .777 .929 r
.8396 .36983 .84437 .37615 .85609 .37228 .85133 .36562 Mtetra
.671 .766 .922 r
.85133 .36562 .85609 .37228 .86786 .36837 .8631 .36144 Mtetra
.633 .745 .929 r
.23264 .55431 .23902 .55988 .24845 .55727 .24208 .5518 Mtetra
.627 .748 .934 r
.24208 .5518 .24845 .55727 .25792 .55469 .25156 .54938 Mtetra
.623 .754 .94 r
.25156 .54938 .25792 .55469 .26742 .55206 .26106 .54701 Mtetra
.619 .763 .948 r
.26106 .54701 .26742 .55206 .27697 .54929 .2706 .54466 Mtetra
.612 .779 .961 r
.2706 .54466 .27697 .54929 .28657 .54633 .28018 .54233 Mtetra
.613 .805 .974 r
.28018 .54233 .28657 .54633 .29623 .543 .2898 .53981 Mtetra
.617 .841 .985 r
.2898 .53981 .29623 .543 .30596 .53913 .29949 .53696 Mtetra
.633 .886 .987 r
.29949 .53696 .30596 .53913 .31576 .53464 .30926 .53345 Mtetra
.665 .927 .973 r
.30926 .53345 .31576 .53464 .32563 .52939 .31912 .52899 Mtetra
.704 .957 .949 r
.31912 .52899 .32563 .52939 .33555 .52373 .32907 .52345 Mtetra
.768 .965 .927 r
.32907 .52345 .33555 .52373 .34549 .51786 .33911 .51664 Mtetra
.804 .935 .917 r
.33911 .51664 .34549 .51786 .35542 .51277 .3492 .50923 Mtetra
.802 .85 .886 r
.3492 .50923 .35542 .51277 .3653 .50924 .35931 .50168 Mtetra
.734 .719 .837 r
.35931 .50168 .3653 .50924 .37511 .50809 .36936 .49557 Mtetra
.642 .591 .781 r
.36936 .49557 .37511 .50809 .38483 .51005 .37931 .49213 Mtetra
.554 .483 .73 r
.37931 .49213 .38483 .51005 .39454 .51399 .38916 .49221 Mtetra
.468 .401 .699 r
.38916 .49221 .39454 .51399 .40429 .51904 .3989 .4965 Mtetra
.414 .361 .69 r
.3989 .4965 .40429 .51904 .41422 .52145 .40864 .50317 Mtetra
.338 .346 .721 r
.40864 .50317 .41422 .52145 .42437 .51872 .41844 .51075 Mtetra
.225 .477 .887 r
.41844 .51075 .42437 .51872 .43472 .5102 .42845 .51496 Mtetra
.199 0 0 r
.42845 .51496 .43472 .5102 .44521 .49592 .4387 .51303 Mtetra
.25 0 .2 r
.4387 .51303 .44521 .49592 .4557 .48031 .44915 .50443 Mtetra
.178 0 .243 r
.44915 .50443 .4557 .48031 .46612 .46671 .45974 .48936 Mtetra
.063 0 .183 r
.45974 .48936 .46612 .46671 .4764 .46106 .47033 .47177 Mtetra
0 0 0 r
.47033 .47177 .4764 .46106 .48658 .46537 .48086 .45476 Mtetra
.779 .681 .756 r
.48086 .45476 .48658 .46537 .49681 .47503 .49129 .44383 Mtetra
.595 .448 .652 r
.49129 .44383 .49681 .47503 .50714 .48691 .50165 .44038 Mtetra
.554 .391 .615 r
.50165 .44038 .50714 .48691 .51762 .49537 .51204 .44028 Mtetra
.548 .377 .602 r
.51204 .44028 .51762 .49537 .5282 .49774 .52248 .44096 Mtetra
.574 .395 .601 r
.52248 .44096 .5282 .49774 .53884 .49442 .53299 .43757 Mtetra
.598 .412 .602 r
.53299 .43757 .53884 .49442 .54948 .48537 .54351 .43008 Mtetra
.594 .411 .603 r
.54351 .43008 .54948 .48537 .56006 .4702 .55405 .42338 Mtetra
.579 .409 .615 r
.55405 .42338 .56006 .4702 .57055 .45155 .56465 .42002 Mtetra
.502 .385 .652 r
.56465 .42002 .57055 .45155 .58103 .43507 .57541 .4242 Mtetra
0 .23 .744 r
.57541 .4242 .58103 .43507 .59156 .42395 .58638 .43456 Mtetra
.693 .295 .29 r
.58638 .43456 .59156 .42395 .60233 .42287 .5975 .44554 Mtetra
.619 .289 .389 r
.5975 .44554 .60233 .42287 .61338 .42987 .60869 .45404 Mtetra
.541 .222 .376 r
.60869 .45404 .61338 .42987 .6246 .43894 .61982 .456 Mtetra
.388 .049 .264 r
.61982 .456 .6246 .43894 .6359 .4467 .6308 .45119 Mtetra
.577 .871 .563 r
.6308 .45119 .6359 .4467 .64711 .44863 .6416 .44012 Mtetra
.847 .749 .755 r
.6416 .44012 .64711 .44863 .65815 .44467 .65226 .42558 Mtetra
.74 .59 .689 r
.65226 .42558 .65815 .44467 .66901 .43545 .66292 .41193 Mtetra
.693 .54 .675 r
.66292 .41193 .66901 .43545 .67974 .4235 .67367 .40069 Mtetra
.651 .518 .688 r
.67367 .40069 .67974 .4235 .69051 .41266 .68462 .39374 Mtetra
.615 .52 .723 r
.68462 .39374 .69051 .41266 .70138 .40382 .69578 .39039 Mtetra
.566 .55 .796 r
.69578 .39039 .70138 .40382 .71245 .39818 .70715 .38978 Mtetra
.478 .61 .904 r
.70715 .38978 .71245 .39818 .7237 .39498 .71867 .39067 Mtetra
.34 .693 .981 r
.71867 .39067 .7237 .39498 .7351 .39338 .73026 .39143 Mtetra
.2 .697 .916 r
.73026 .39143 .7351 .39338 .74662 .3926 .74189 .39159 Mtetra
.239 .746 .883 r
.74189 .39159 .74662 .3926 .75819 .39161 .7535 .39043 Mtetra
.367 .823 .928 r
.7535 .39043 .75819 .39161 .7698 .39021 .76509 .38816 Mtetra
.522 .882 .981 r
.76509 .38816 .7698 .39021 .7814 .388 .77666 .3849 Mtetra
.618 .884 .989 r
.77666 .3849 .7814 .388 .79301 .38516 .78823 .38096 Mtetra
.662 .855 .974 r
.78823 .38096 .79301 .38516 .80463 .38176 .79981 .37666 Mtetra
.679 .826 .953 r
.79981 .37666 .80463 .38176 .81625 .37797 .81141 .37216 Mtetra
.681 .8 .938 r
.81141 .37216 .81625 .37797 .82791 .37397 .82307 .36768 Mtetra
.681 .783 .927 r
.82307 .36768 .82791 .37397 .8396 .36983 .83476 .36321 Mtetra
.679 .771 .921 r
.83476 .36321 .8396 .36983 .85133 .36562 .84651 .35879 Mtetra
.675 .763 .917 r
.84651 .35879 .85133 .36562 .8631 .36144 .85831 .35446 Mtetra
.64 .747 .927 r
.22623 .54871 .23264 .55431 .24208 .5518 .2357 .54603 Mtetra
.635 .741 .925 r
.2357 .54603 .24208 .5518 .25156 .54938 .2452 .54345 Mtetra
.629 .734 .923 r
.2452 .54345 .25156 .54938 .26106 .54701 .25473 .54101 Mtetra
.62 .73 .925 r
.25473 .54101 .26106 .54701 .2706 .54466 .26428 .53874 Mtetra
.607 .729 .931 r
.26428 .53874 .2706 .54466 .28018 .54233 .27385 .53671 Mtetra
.599 .738 .942 r
.27385 .53671 .28018 .54233 .2898 .53981 .28345 .53479 Mtetra
.587 .758 .96 r
.28345 .53479 .2898 .53981 .29949 .53696 .29309 .53293 Mtetra
.588 .8 .98 r
.29309 .53293 .29949 .53696 .30926 .53345 .3028 .53075 Mtetra
.593 .857 .994 r
.3028 .53075 .30926 .53345 .31912 .52899 .31258 .52797 Mtetra
.608 .919 .975 r
.31258 .52797 .31912 .52899 .32907 .52345 .32247 .5241 Mtetra
.639 .961 .915 r
.32247 .5241 .32907 .52345 .33911 .51664 .33249 .51865 Mtetra
.664 .973 .843 r
.33249 .51865 .33911 .51664 .3492 .50923 .3426 .51168 Mtetra
.745 .993 .824 r
.3426 .51168 .3492 .50923 .35931 .50168 .35282 .50306 Mtetra
.808 .995 .863 r
.35282 .50306 .35931 .50168 .36936 .49557 .36306 .49409 Mtetra
.831 .925 .896 r
.36306 .49409 .36936 .49557 .37931 .49213 .37327 .48568 Mtetra
.739 .753 .863 r
.37327 .48568 .37931 .49213 .38916 .49221 .38339 .47973 Mtetra
.607 .575 .792 r
.38339 .47973 .38916 .49221 .3989 .4965 .39337 .47769 Mtetra
.502 .444 .725 r
.39337 .47769 .3989 .4965 .40864 .50317 .40324 .48 Mtetra
.413 .357 .686 r
.40324 .48 .40864 .50317 .41844 .51075 .41302 .48681 Mtetra
.394 .34 .679 r
.41302 .48681 .41844 .51075 .42845 .51496 .42287 .49466 Mtetra
.401 .37 .71 r
.42287 .49466 .42845 .51496 .4387 .51303 .43287 .50106 Mtetra
.487 .524 .821 r
.43287 .50106 .4387 .51303 .44915 .50443 .44309 .50265 Mtetra
.701 .927 .966 r
.44309 .50265 .44915 .50443 .45974 .48936 .45352 .49742 Mtetra
0 0 0 r
.45352 .49742 .45974 .48936 .47033 .47177 .4641 .48572 Mtetra
.4641 .48572 .47033 .47177 .48086 .45476 .47474 .46901 Mtetra
.47474 .46901 .48086 .45476 .49129 .44383 .48532 .45379 Mtetra
.48532 .45379 .49129 .44383 .50165 .44038 .49582 .44276 Mtetra
.567 .927 .761 r
.49582 .44276 .50165 .44038 .51204 .44028 .5063 .43567 Mtetra
.661 .812 .956 r
.5063 .43567 .51204 .44028 .52248 .44096 .51678 .43203 Mtetra
.653 .67 .854 r
.51678 .43203 .52248 .44096 .53299 .43757 .5273 .42861 Mtetra
.646 .667 .856 r
.5273 .42861 .53299 .43757 .54351 .43008 .53786 .4254 Mtetra
.404 .707 .984 r
.53786 .4254 .54351 .43008 .55405 .42338 .54849 .42567 Mtetra
.521 0 0 r
.54849 .42567 .55405 .42338 .56465 .42002 .55923 .42991 Mtetra
.66 .253 .262 r
.55923 .42991 .56465 .42002 .57541 .4242 .57012 .43841 Mtetra
.663 .291 .33 r
.57012 .43841 .57541 .4242 .58638 .43456 .58116 .44844 Mtetra
.588 .211 .294 r
.58116 .44844 .58638 .43456 .5975 .44554 .59222 .45347 Mtetra
.357 0 .038 r
.59222 .45347 .5975 .44554 .60869 .45404 .60323 .45196 Mtetra
.815 .943 .909 r
.60323 .45196 .60869 .45404 .61982 .456 .61411 .44353 Mtetra
.79 .671 .733 r
.61411 .44353 .61982 .456 .6308 .45119 .62485 .43019 Mtetra
.738 .579 .677 r
.62485 .43019 .6308 .45119 .6416 .44012 .63551 .41534 Mtetra
.71 .545 .664 r
.63551 .41534 .6416 .44012 .65226 .42558 .64618 .4015 Mtetra
.671 .524 .676 r
.64618 .4015 .65226 .42558 .66292 .41193 .65701 .39223 Mtetra
.635 .526 .713 r
.65701 .39223 .66292 .41193 .67367 .40069 .66804 .3874 Mtetra
.571 .554 .797 r
.66804 .3874 .67367 .40069 .68462 .39374 .6793 .38657 Mtetra
.4 .609 .933 r
.6793 .38657 .68462 .39374 .69578 .39039 .69075 .38828 Mtetra
0 .531 .821 r
.69075 .38828 .69578 .39039 .70715 .38978 .70232 .39058 Mtetra
.264 0 0 r
.70232 .39058 .70715 .38978 .71867 .39067 .71396 .39253 Mtetra
.202 0 0 r
.71396 .39253 .71867 .39067 .73026 .39143 .72558 .39281 Mtetra
.014 0 0 r
.72558 .39281 .73026 .39143 .74189 .39159 .73717 .39152 Mtetra
.316 .806 .842 r
.73717 .39152 .74189 .39159 .7535 .39043 .74871 .3886 Mtetra
.568 .909 .973 r
.74871 .3886 .7535 .39043 .76509 .38816 .76022 .38454 Mtetra
.671 .882 .976 r
.76022 .38454 .76509 .38816 .77666 .3849 .77172 .37986 Mtetra
.7 .834 .947 r
.77172 .37986 .77666 .3849 .78823 .38096 .78324 .37483 Mtetra
.699 .794 .924 r
.78324 .37483 .78823 .38096 .79981 .37666 .79481 .36986 Mtetra
.694 .769 .91 r
.79481 .36986 .79981 .37666 .81141 .37216 .80642 .365 Mtetra
.684 .755 .905 r
.80642 .365 .81141 .37216 .82307 .36768 .8181 .36038 Mtetra
.678 .749 .904 r
.8181 .36038 .82307 .36768 .83476 .36321 .82983 .35594 Mtetra
.673 .749 .907 r
.82983 .35594 .83476 .36321 .84651 .35879 .84163 .35163 Mtetra
.669 .752 .912 r
.84163 .35163 .84651 .35879 .85831 .35446 .85348 .34743 Mtetra
.657 .752 .92 r
.21976 .54307 .22623 .54871 .2357 .54603 .22929 .53997 Mtetra
.654 .737 .911 r
.22929 .53997 .2357 .54603 .2452 .54345 .23885 .53693 Mtetra
.647 .721 .902 r
.23885 .53693 .2452 .54345 .25473 .54101 .24842 .53406 Mtetra
.636 .705 .896 r
.24842 .53406 .25473 .54101 .26428 .53874 .25802 .53146 Mtetra
.62 .69 .894 r
.25802 .53146 .26428 .53874 .27385 .53671 .26761 .52924 Mtetra
.603 .679 .895 r
.26761 .52924 .27385 .53671 .28345 .53479 .27722 .52744 Mtetra
.578 .674 .905 r
.27722 .52744 .28345 .53479 .29309 .53293 .28684 .52616 Mtetra
.558 .686 .925 r
.28684 .52616 .29309 .53293 .3028 .53075 .29648 .52515 Mtetra
.528 .717 .959 r
.29648 .52515 .3028 .53075 .31258 .52797 .30616 .52433 Mtetra
.5 .788 .997 r
.30616 .52433 .31258 .52797 .32247 .5241 .31591 .52306 Mtetra
.429 .849 .958 r
.31591 .52306 .32247 .5241 .33249 .51865 .32577 .52089 Mtetra
.293 .779 .706 r
.32577 .52089 .33249 .51865 .3426 .51168 .33576 .51706 Mtetra
0 0 0 r
.33576 .51706 .3426 .51168 .35282 .50306 .34591 .51091 Mtetra
.34591 .51091 .35282 .50306 .36306 .49409 .3562 .50245 Mtetra
.3562 .50245 .36306 .49409 .37327 .48568 .3666 .49161 Mtetra
.663 .917 .607 r
.3666 .49161 .37327 .48568 .38339 .47973 .37703 .48004 Mtetra
.882 .963 .845 r
.37703 .48004 .38339 .47973 .39337 .47769 .38743 .46896 Mtetra
.765 .706 .796 r
.38743 .46896 .39337 .47769 .40324 .48 .39772 .46045 Mtetra
.63 .519 .708 r
.39772 .46045 .40324 .48 .41302 .48681 .40786 .45611 Mtetra
.543 .413 .653 r
.40786 .45611 .41302 .48681 .42287 .49466 .41787 .45689 Mtetra
.479 .35 .627 r
.41787 .45689 .42287 .49466 .43287 .50106 .42778 .46318 Mtetra
.441 .323 .623 r
.42778 .46318 .43287 .50106 .44309 .50265 .43772 .47234 Mtetra
.389 .309 .644 r
.43772 .47234 .44309 .50265 .45352 .49742 .44774 .48252 Mtetra
.21 .309 .747 r
.44774 .48252 .45352 .49742 .4641 .48572 .45792 .49127 Mtetra
.602 .132 .11 r
.45792 .49127 .4641 .48572 .47474 .46901 .46827 .49651 Mtetra
.505 .199 .382 r
.46827 .49651 .47474 .46901 .48532 .45379 .4788 .49569 Mtetra
.459 .189 .417 r
.4788 .49569 .48532 .45379 .49582 .44276 .48946 .48876 Mtetra
.448 .186 .423 r
.48946 .48876 .49582 .44276 .5063 .43567 .50015 .47981 Mtetra
.45 .186 .42 r
.50015 .47981 .5063 .43567 .51678 .43203 .51084 .47152 Mtetra
.492 .214 .421 r
.51084 .47152 .51678 .43203 .5273 .42861 .52154 .46812 Mtetra
.538 .254 .432 r
.52154 .46812 .5273 .42861 .53786 .4254 .53228 .46961 Mtetra
.544 .266 .443 r
.53228 .46961 .53786 .4254 .54849 .42567 .54311 .47178 Mtetra
.529 .255 .443 r
.54311 .47178 .54849 .42567 .55923 .42991 .554 .47195 Mtetra
.471 .2 .421 r
.554 .47195 .55923 .42991 .57012 .43841 .56488 .46596 Mtetra
.317 .038 .323 r
.56488 .46596 .57012 .43841 .58116 .44844 .57569 .45384 Mtetra
.775 .934 .579 r
.57569 .45384 .58116 .44844 .59222 .45347 .58642 .43814 Mtetra
.797 .646 .694 r
.58642 .43814 .59222 .45347 .60323 .45196 .59708 .42095 Mtetra
.701 .52 .641 r
.59708 .42095 .60323 .45196 .61411 .44353 .60771 .40474 Mtetra
.658 .476 .626 r
.60771 .40474 .61411 .44353 .62485 .43019 .61839 .39142 Mtetra
.619 .448 .63 r
.61839 .39142 .62485 .43019 .63551 .41534 .62922 .38367 Mtetra
.582 .44 .653 r
.62922 .38367 .63551 .41534 .64618 .4015 .64025 .38112 Mtetra
.521 .452 .719 r
.64025 .38112 .64618 .4015 .65701 .39223 .65151 .38284 Mtetra
.309 .486 .871 r
.65151 .38284 .65701 .39223 .66804 .3874 .66296 .38721 Mtetra
.428 0 0 r
.66296 .38721 .66804 .3874 .6793 .38657 .67453 .39211 Mtetra
.545 .051 .033 r
.67453 .39211 .6793 .38657 .69075 .38828 .68617 .39628 Mtetra
.485 .032 .099 r
.68617 .39628 .69075 .38828 .70232 .39058 .69779 .39803 Mtetra
.386 0 .028 r
.69779 .39803 .70232 .39058 .71396 .39253 .70936 .39743 Mtetra
.15 0 0 r
.70936 .39743 .71396 .39253 .72558 .39281 .72084 .39442 Mtetra
.308 .786 .697 r
.72084 .39442 .72558 .39281 .73717 .39152 .73227 .3897 Mtetra
.672 .946 .96 r
.73227 .3897 .73717 .39152 .74871 .3886 .74368 .38403 Mtetra
.74 .863 .938 r
.74368 .38403 .74871 .3886 .76022 .38454 .75508 .3779 Mtetra
.728 .785 .898 r
.75508 .3779 .76022 .38454 .77172 .37986 .76653 .37195 Mtetra
.712 .742 .875 r
.76653 .37195 .77172 .37986 .78324 .37483 .77803 .36627 Mtetra
.694 .718 .867 r
.77803 .36627 .78324 .37483 .79481 .36986 .78961 .36112 Mtetra
.681 .708 .868 r
.78961 .36112 .79481 .36986 .80642 .365 .80127 .3564 Mtetra
.67 .708 .876 r
.80127 .3564 .80642 .365 .8181 .36038 .813 .35208 Mtetra
.662 .714 .886 r
.813 .35208 .8181 .36038 .82983 .35594 .82481 .34803 Mtetra
.657 .724 .898 r
.82481 .34803 .82983 .35594 .84163 .35163 .83668 .34416 Mtetra
.655 .737 .91 r
.83668 .34416 .84163 .35163 .85348 .34743 .84861 .34035 Mtetra
.676 .756 .911 r
.21326 .53739 .21976 .54307 .22929 .53997 .22285 .5338 Mtetra
.675 .74 .9 r
.22285 .5338 .22929 .53997 .23885 .53693 .23247 .53019 Mtetra
.67 .721 .888 r
.23247 .53019 .23885 .53693 .24842 .53406 .24212 .52669 Mtetra
.66 .701 .877 r
.24212 .52669 .24842 .53406 .25802 .53146 .25178 .5234 Mtetra
.647 .678 .866 r
.25178 .5234 .25802 .53146 .26761 .52924 .26145 .52043 Mtetra
.628 .653 .856 r
.26145 .52043 .26761 .52924 .27722 .52744 .27112 .51796 Mtetra
.604 .628 .848 r
.27112 .51796 .27722 .52744 .28684 .52616 .28077 .51616 Mtetra
.579 .606 .844 r
.28077 .51616 .28684 .52616 .29648 .52515 .29043 .51506 Mtetra
.547 .59 .848 r
.29043 .51506 .29648 .52515 .30616 .52433 .30007 .51476 Mtetra
.526 .592 .864 r
.30007 .51476 .30616 .52433 .31591 .52306 .30974 .51488 Mtetra
.5 .619 .901 r
.30974 .51488 .31591 .52306 .32577 .52089 .31946 .51519 Mtetra
.497 .705 .963 r
.31946 .51519 .32577 .52089 .33576 .51706 .32927 .51479 Mtetra
.479 .836 .995 r
.32927 .51479 .33576 .51706 .34591 .51091 .33922 .51293 Mtetra
.359 .824 .751 r
.33922 .51293 .34591 .51091 .3562 .50245 .34934 .50874 Mtetra
0 0 0 r
.34934 .50874 .3562 .50245 .3666 .49161 .35964 .50144 Mtetra
.35964 .50144 .3666 .49161 .37703 .48004 .37009 .49148 Mtetra
.37009 .49148 .37703 .48004 .38743 .46896 .38063 .47914 Mtetra
.38063 .47914 .38743 .46896 .39772 .46045 .39117 .4664 Mtetra
.646 .906 .591 r
.39117 .4664 .39772 .46045 .40786 .45611 .40165 .4548 Mtetra
.814 .942 .91 r
.40165 .4548 .40786 .45611 .41787 .45689 .41199 .44683 Mtetra
.63 .632 .834 r
.41199 .44683 .41787 .45689 .42778 .46318 .42218 .44408 Mtetra
.505 .446 .724 r
.42218 .44408 .42778 .46318 .43772 .47234 .43227 .44618 Mtetra
.437 .358 .67 r
.43227 .44618 .43772 .47234 .44774 .48252 .44233 .45267 Mtetra
.417 .33 .65 r
.44233 .45267 .44774 .48252 .45792 .49127 .45244 .46117 Mtetra
.423 .334 .651 r
.45244 .46117 .45792 .49127 .46827 .49651 .46267 .46945 Mtetra
.498 .398 .671 r
.46267 .46945 .46827 .49651 .4788 .49569 .47309 .47291 Mtetra
.596 .482 .694 r
.47309 .47291 .4788 .49569 .48946 .48876 .48367 .47024 Mtetra
.652 .543 .718 r
.48367 .47024 .48946 .48876 .50015 .47981 .49433 .4646 Mtetra
.682 .588 .744 r
.49433 .4646 .50015 .47981 .51084 .47152 .50501 .45805 Mtetra
.634 .584 .78 r
.50501 .45805 .51084 .47152 .52154 .46812 .51571 .45461 Mtetra
.555 .542 .795 r
.51571 .45461 .52154 .46812 .53228 .46961 .52646 .4543 Mtetra
.579 .532 .767 r
.52646 .4543 .53228 .46961 .54311 .47178 .53726 .45308 Mtetra
.628 .529 .723 r
.53726 .45308 .54311 .47178 .554 .47195 .5481 .44889 Mtetra
.687 .539 .679 r
.5481 .44889 .554 .47195 .56488 .46596 .55891 .43851 Mtetra
.709 .535 .652 r
.55891 .43851 .56488 .46596 .57569 .45384 .56965 .42324 Mtetra
.698 .519 .643 r
.56965 .42324 .57569 .45384 .58642 .43814 .58035 .40769 Mtetra
.684 .51 .646 r
.58035 .40769 .58642 .43814 .59708 .42095 .59106 .39415 Mtetra
.659 .506 .664 r
.59106 .39415 .59708 .42095 .60771 .40474 .60184 .38504 Mtetra
.625 .519 .714 r
.60184 .38504 .60771 .40474 .61839 .39142 .61277 .38082 Mtetra
.492 .561 .854 r
.61277 .38082 .61839 .39142 .62922 .38367 .6239 .38192 Mtetra
.324 0 0 r
.6239 .38192 .62922 .38367 .64025 .38112 .63523 .38675 Mtetra
.605 .121 .08 r
.63523 .38675 .64025 .38112 .65151 .38284 .64671 .39277 Mtetra
.597 .174 .21 r
.64671 .39277 .65151 .38284 .66296 .38721 .65829 .3984 Mtetra
.544 .133 .213 r
.65829 .3984 .66296 .38721 .67453 .39211 .66987 .40163 Mtetra
.458 .027 .133 r
.66987 .40163 .67453 .39211 .68617 .39628 .68141 .40215 Mtetra
.22 0 0 r
.68141 .40215 .68617 .39628 .69779 .39803 .69287 .39948 Mtetra
.371 .829 .737 r
.69287 .39948 .69779 .39803 .70936 .39743 .70424 .3944 Mtetra
.748 .921 .949 r
.70424 .3944 .70936 .39743 .72084 .39442 .71556 .38782 Mtetra
.765 .795 .877 r
.71556 .38782 .72084 .39442 .73227 .3897 .72687 .38048 Mtetra
.737 .716 .832 r
.72687 .38048 .73227 .3897 .74368 .38403 .7382 .37332 Mtetra
.715 .677 .812 r
.7382 .37332 .74368 .38403 .75508 .3779 .74959 .36658 Mtetra
.694 .657 .809 r
.74959 .36658 .75508 .3779 .76653 .37195 .76106 .36067 Mtetra
.679 .651 .816 r
.76106 .36067 .76653 .37195 .77803 .36627 .77262 .35547 Mtetra
.665 .655 .83 r
.77262 .35547 .77803 .36627 .78961 .36112 .78428 .35097 Mtetra
.655 .664 .847 r
.78428 .35097 .78961 .36112 .80127 .3564 .79602 .34697 Mtetra
.647 .678 .865 r
.79602 .34697 .80127 .3564 .813 .35208 .80784 .34331 Mtetra
.642 .693 .883 r
.80784 .34331 .813 .35208 .82481 .34803 .81974 .33988 Mtetra
.638 .71 .899 r
.81974 .33988 .82481 .34803 .83668 .34416 .83169 .33655 Mtetra
.638 .727 .913 r
.83169 .33655 .83668 .34416 .84861 .34035 .8437 .33321 Mtetra
.69 .759 .904 r
.20671 .53168 .21326 .53739 .22285 .5338 .21636 .52769 Mtetra
.692 .747 .894 r
.21636 .52769 .22285 .5338 .23247 .53019 .22604 .52359 Mtetra
.69 .732 .883 r
.22604 .52359 .23247 .53019 .24212 .52669 .23576 .51945 Mtetra
.686 .713 .87 r
.23576 .51945 .24212 .52669 .25178 .5234 .2455 .51536 Mtetra
.679 .691 .854 r
.2455 .51536 .25178 .5234 .26145 .52043 .25527 .51134 Mtetra
.664 .661 .837 r
.25527 .51134 .26145 .52043 .27112 .51796 .26504 .50763 Mtetra
.645 .629 .819 r
.26504 .50763 .27112 .51796 .28077 .51616 .27481 .50442 Mtetra
.619 .592 .801 r
.27481 .50442 .28077 .51616 .29043 .51506 .28456 .50197 Mtetra
.587 .556 .787 r
.28456 .50197 .29043 .51506 .30007 .51476 .29428 .50057 Mtetra
.556 .525 .776 r
.29428 .50057 .30007 .51476 .30974 .51488 .30396 .50029 Mtetra
.518 .498 .774 r
.30396 .50029 .30974 .51488 .31946 .51519 .31363 .50129 Mtetra
.486 .49 .787 r
.31363 .50129 .31946 .51519 .32927 .51479 .3233 .50312 Mtetra
.441 .504 .828 r
.3233 .50312 .32927 .51479 .33922 .51293 .33301 .50548 Mtetra
.378 .586 .924 r
.33301 .50548 .33922 .51293 .34934 .50874 .34281 .50731 Mtetra
.098 .639 .848 r
.34281 .50731 .34934 .50874 .35964 .50144 .35276 .50775 Mtetra
.248 0 0 r
.35276 .50775 .35964 .50144 .37009 .49148 .36289 .50566 Mtetra
.288 0 .155 r
.36289 .50566 .37009 .49148 .38063 .47914 .37323 .50013 Mtetra
.289 0 .247 r
.37323 .50013 .38063 .47914 .39117 .4664 .38373 .49135 Mtetra
.255 0 .266 r
.38373 .49135 .39117 .4664 .40165 .4548 .39435 .47939 Mtetra
.184 0 .235 r
.39435 .47939 .40165 .4548 .41199 .44683 .40505 .46515 Mtetra
0 0 .068 r
.40505 .46515 .41199 .44683 .42218 .44408 .41577 .44956 Mtetra
.814 .967 .65 r
.41577 .44956 .42218 .44408 .43227 .44618 .42641 .43501 Mtetra
.787 .678 .744 r
.42641 .43501 .43227 .44618 .44233 .45267 .43696 .42285 Mtetra
.658 .494 .65 r
.43696 .42285 .44233 .45267 .45244 .46117 .44744 .41295 Mtetra
.603 .422 .61 r
.44744 .41295 .45244 .46117 .46267 .46945 .45787 .40563 Mtetra
.57 .385 .591 r
.45787 .40563 .46267 .46945 .47309 .47291 .46825 .40165 Mtetra
.551 .366 .584 r
.46825 .40165 .47309 .47291 .48367 .47024 .47862 .40072 Mtetra
.545 .362 .585 r
.47862 .40072 .48367 .47024 .49433 .4646 .48903 .40102 Mtetra
.547 .368 .59 r
.48903 .40102 .49433 .4646 .50501 .45805 .49952 .40098 Mtetra
.57 .39 .598 r
.49952 .40098 .50501 .45805 .51571 .45461 .51008 .39747 Mtetra
.591 .406 .599 r
.51008 .39747 .51571 .45461 .52646 .4543 .52068 .3905 Mtetra
.588 .398 .592 r
.52068 .3905 .52646 .4543 .53726 .45308 .53131 .38317 Mtetra
.578 .387 .586 r
.53131 .38317 .53726 .45308 .5481 .44889 .54195 .37706 Mtetra
.562 .374 .584 r
.54195 .37706 .5481 .44889 .55891 .43851 .55265 .37401 Mtetra
.545 .366 .59 r
.55265 .37401 .55891 .43851 .56965 .42324 .56344 .37434 Mtetra
.525 .366 .609 r
.56344 .37434 .56965 .42324 .58035 .40769 .57433 .3773 Mtetra
.479 .373 .657 r
.57433 .3773 .58035 .40769 .59106 .39415 .58535 .38255 Mtetra
.178 .351 .8 r
.58535 .38255 .59106 .39415 .60184 .38504 .59653 .39027 Mtetra
.675 .202 .12 r
.59653 .39027 .60184 .38504 .61277 .38082 .60786 .39908 Mtetra
.613 .256 .342 r
.60786 .39908 .61277 .38082 .6239 .38192 .61929 .40657 Mtetra
.574 .247 .377 r
.61929 .40657 .6239 .38192 .63523 .38675 .63076 .41176 Mtetra
.535 .212 .368 r
.63076 .41176 .63523 .38675 .64671 .39277 .64222 .41374 Mtetra
.478 .145 .323 r
.64222 .41374 .64671 .39277 .65829 .3984 .65364 .41241 Mtetra
.339 0 .187 r
.65364 .41241 .65829 .3984 .66987 .40163 .66496 .40755 Mtetra
0 0 0 r
.66496 .40755 .66987 .40163 .68141 .40215 .6762 .40008 Mtetra
.818 .957 .904 r
.6762 .40008 .68141 .40215 .69287 .39948 .68739 .39116 Mtetra
.789 .753 .82 r
.68739 .39116 .69287 .39948 .70424 .3944 .69855 .38168 Mtetra
.736 .653 .767 r
.69855 .38168 .70424 .3944 .71556 .38782 .70976 .37273 Mtetra
.705 .609 .747 r
.70976 .37273 .71556 .38782 .72687 .38048 .72102 .36461 Mtetra
.68 .588 .746 r
.72102 .36461 .72687 .38048 .7382 .37332 .73238 .3578 Mtetra
.663 .583 .755 r
.73238 .3578 .7382 .37332 .74959 .36658 .74385 .35214 Mtetra
.649 .588 .773 r
.74385 .35214 .74959 .36658 .76106 .36067 .75543 .34756 Mtetra
.638 .601 .796 r
.75543 .34756 .76106 .36067 .77262 .35547 .76711 .34378 Mtetra
.63 .622 .823 r
.76711 .34378 .77262 .35547 .78428 .35097 .77889 .3405 Mtetra
.624 .644 .849 r
.77889 .3405 .78428 .35097 .79602 .34697 .79074 .33756 Mtetra
.623 .668 .873 r
.79074 .33756 .79602 .34697 .80784 .34331 .80266 .33469 Mtetra
.621 .689 .892 r
.80266 .33469 .80784 .34331 .81974 .33988 .81464 .33186 Mtetra
.621 .707 .908 r
.81464 .33186 .81974 .33988 .83169 .33655 .82668 .329 Mtetra
.623 .724 .919 r
.82668 .329 .83169 .33655 .8437 .33321 .83876 .32602 Mtetra
.688 .758 .905 r
.20012 .52592 .20671 .53168 .21636 .52769 .20978 .52195 Mtetra
.694 .761 .903 r
.20978 .52195 .21636 .52769 .22604 .52359 .21949 .51782 Mtetra
.699 .762 .901 r
.21949 .51782 .22604 .52359 .23576 .51945 .22924 .51352 Mtetra
.703 .758 .895 r
.22924 .51352 .23576 .51945 .2455 .51536 .23904 .50906 Mtetra
.707 .748 .883 r
.23904 .50906 .2455 .51536 .25527 .51134 .24888 .50438 Mtetra
.704 .728 .869 r
.24888 .50438 .25527 .51134 .26504 .50763 .25875 .49967 Mtetra
.696 .7 .85 r
.25875 .49967 .26504 .50763 .27481 .50442 .26865 .49503 Mtetra
.676 .661 .828 r
.26865 .49503 .27481 .50442 .28456 .50197 .27854 .49079 Mtetra
.649 .617 .804 r
.27854 .49079 .28456 .50197 .29428 .50057 .28841 .48724 Mtetra
.615 .568 .779 r
.28841 .48724 .29428 .50057 .30396 .50029 .29824 .48475 Mtetra
.576 .52 .756 r
.29824 .48475 .30396 .50029 .31363 .50129 .30802 .48369 Mtetra
.539 .479 .737 r
.30802 .48369 .31363 .50129 .3233 .50312 .31776 .48413 Mtetra
.5 .443 .724 r
.31776 .48413 .3233 .50312 .33301 .50548 .32745 .48622 Mtetra
.473 .424 .722 r
.32745 .48622 .33301 .50548 .34281 .50731 .33716 .48939 Mtetra
.446 .42 .736 r
.33716 .48939 .34281 .50731 .35276 .50775 .3469 .49321 Mtetra
.441 .458 .781 r
.3469 .49321 .35276 .50775 .36289 .50566 .35676 .49632 Mtetra
.457 .571 .882 r
.35676 .49632 .36289 .50566 .37323 .50013 .36679 .49765 Mtetra
.43 .81 .991 r
.36679 .49765 .37323 .50013 .38373 .49135 .377 .49627 Mtetra
0 0 0 r
.377 .49627 .38373 .49135 .39435 .47939 .38742 .49133 Mtetra
.043 0 0 r
.38742 .49133 .39435 .47939 .40505 .46515 .398 .48255 Mtetra
.063 0 .098 r
.398 .48255 .40505 .46515 .41577 .44956 .40873 .46999 Mtetra
.092 0 .153 r
.40873 .46999 .41577 .44956 .42641 .43501 .4195 .45581 Mtetra
.099 0 .163 r
.4195 .45581 .42641 .43501 .43696 .42285 .43024 .44145 Mtetra
.079 0 .13 r
.43024 .44145 .43696 .42285 .44744 .41295 .44092 .4281 Mtetra
.076 0 .077 r
.44092 .4281 .44744 .41295 .45787 .40563 .45153 .41715 Mtetra
.22 0 .069 r
.45153 .41715 .45787 .40563 .46825 .40165 .46202 .4114 Mtetra
.431 .007 .132 r
.46202 .4114 .46825 .40165 .47862 .40072 .47246 .41107 Mtetra
.503 .088 .186 r
.47246 .41107 .47862 .40072 .48903 .40102 .48293 .41268 Mtetra
.496 .096 .211 r
.48293 .41268 .48903 .40102 .49952 .40098 .49348 .41386 Mtetra
.354 0 .167 r
.49348 .41386 .49952 .40098 .51008 .39747 .50413 .41034 Mtetra
.151 0 .072 r
.50413 .41034 .51008 .39747 .52068 .3905 .51484 .40213 Mtetra
.081 0 .01 r
.51484 .40213 .52068 .3905 .53131 .38317 .52556 .39346 Mtetra
.138 0 0 r
.52556 .39346 .53131 .38317 .54195 .37706 .53629 .38673 Mtetra
.392 0 .107 r
.53629 .38673 .54195 .37706 .55265 .37401 .54708 .38545 Mtetra
.564 .16 .234 r
.54708 .38545 .55265 .37401 .56344 .37434 .55798 .38942 Mtetra
.606 .232 .308 r
.55798 .38942 .56344 .37434 .57433 .3773 .56901 .39585 Mtetra
.612 .258 .346 r
.56901 .39585 .57433 .3773 .58535 .38255 .58018 .40333 Mtetra
.605 .261 .36 r
.58018 .40333 .58535 .38255 .59653 .39027 .59145 .41067 Mtetra
.585 .239 .35 r
.59145 .41067 .59653 .39027 .60786 .39908 .60281 .41641 Mtetra
.526 .166 .3 r
.60281 .41641 .60786 .39908 .61929 .40657 .61418 .41833 Mtetra
.396 0 .158 r
.61418 .41833 .61929 .40657 .63076 .41176 .62551 .41633 Mtetra
0 0 0 r
.62551 .41633 .63076 .41176 .64222 .41374 .63677 .41072 Mtetra
.81 .921 .911 r
.63677 .41072 .64222 .41374 .65364 .41241 .64796 .40231 Mtetra
.781 .712 .787 r
.64796 .40231 .65364 .41241 .66496 .40755 .65908 .39205 Mtetra
.74 .622 .728 r
.65908 .39205 .66496 .40755 .6762 .40008 .67017 .38104 Mtetra
.708 .576 .705 r
.67017 .38104 .6762 .40008 .68739 .39116 .68128 .37068 Mtetra
.687 .555 .699 r
.68128 .37068 .68739 .39116 .69855 .38168 .69245 .3614 Mtetra
.668 .545 .706 r
.69245 .3614 .69855 .38168 .70976 .37273 .70372 .35381 Mtetra
.653 .546 .721 r
.70372 .35381 .70976 .37273 .72102 .36461 .7151 .34775 Mtetra
.638 .556 .745 r
.7151 .34775 .72102 .36461 .73238 .3578 .72661 .34317 Mtetra
.626 .574 .776 r
.72661 .34317 .73238 .3578 .74385 .35214 .73823 .33968 Mtetra
.616 .6 .812 r
.73823 .33968 .74385 .35214 .75543 .34756 .74996 .3369 Mtetra
.606 .63 .849 r
.74996 .3369 .75543 .34756 .76711 .34378 .76177 .33455 Mtetra
.603 .663 .881 r
.76177 .33455 .76711 .34378 .77889 .3405 .77365 .33226 Mtetra
.601 .691 .906 r
.77365 .33226 .77889 .3405 .79074 .33756 .78559 .32995 Mtetra
.607 .714 .921 r
.78559 .32995 .79074 .33756 .80266 .33469 .79757 .32741 Mtetra
.611 .728 .928 r
.79757 .32741 .80266 .33469 .81464 .33186 .8096 .3247 Mtetra
.617 .735 .931 r
.8096 .3247 .81464 .33186 .82668 .329 .82167 .32182 Mtetra
.623 .738 .93 r
.82167 .32182 .82668 .329 .83876 .32602 .83378 .31877 Mtetra
.671 .755 .913 r
.19348 .52013 .20012 .52592 .20978 .52195 .20312 .51659 Mtetra
.677 .772 .922 r
.20312 .51659 .20978 .52195 .21949 .51782 .21281 .5129 Mtetra
.686 .79 .929 r
.21281 .5129 .21949 .51782 .22924 .51352 .22255 .50896 Mtetra
.699 .806 .932 r
.22255 .50896 .22924 .51352 .23904 .50906 .23236 .5047 Mtetra
.715 .817 .928 r
.23236 .5047 .23904 .50906 .24888 .50438 .24223 .49999 Mtetra
.729 .818 .92 r
.24223 .49999 .24888 .50438 .25875 .49967 .25216 .49486 Mtetra
.742 .805 .902 r
.25216 .49486 .25875 .49967 .26865 .49503 .26216 .48928 Mtetra
.741 .774 .88 r
.26216 .48928 .26865 .49503 .27854 .49079 .27219 .48348 Mtetra
.73 .728 .849 r
.27219 .48348 .27854 .49079 .28841 .48724 .28225 .47759 Mtetra
.703 .668 .813 r
.28225 .47759 .28841 .48724 .29824 .48475 .29231 .47207 Mtetra
.668 .604 .775 r
.29231 .47207 .29824 .48475 .30802 .48369 .30234 .46726 Mtetra
.628 .542 .738 r
.30234 .46726 .30802 .48369 .31776 .48413 .31232 .46363 Mtetra
.588 .487 .707 r
.31232 .46363 .31776 .48413 .32745 .48622 .32223 .46162 Mtetra
.553 .441 .681 r
.32223 .46162 .32745 .48622 .33716 .48939 .33209 .46144 Mtetra
.52 .405 .663 r
.33209 .46144 .33716 .48939 .3469 .49321 .34188 .46333 Mtetra
.495 .381 .654 r
.34188 .46333 .3469 .49321 .35676 .49632 .35166 .4669 Mtetra
.47 .366 .655 r
.35166 .4669 .35676 .49632 .36679 .49765 .36145 .47186 Mtetra
.449 .368 .673 r
.36145 .47186 .36679 .49765 .377 .49627 .37131 .47723 Mtetra
.415 .392 .725 r
.37131 .47723 .377 .49627 .38742 .49133 .38127 .48229 Mtetra
.245 .465 .874 r
.38127 .48229 .38742 .49133 .398 .48255 .39136 .48659 Mtetra
.501 0 0 r
.39136 .48659 .398 .48255 .40873 .46999 .40158 .48963 Mtetra
.516 .174 .326 r
.40158 .48963 .40873 .46999 .4195 .45581 .41195 .4907 Mtetra
.503 .211 .402 r
.41195 .4907 .4195 .45581 .43024 .44145 .42246 .48962 Mtetra
.505 .232 .434 r
.42246 .48962 .43024 .44145 .44092 .4281 .43305 .48746 Mtetra
.509 .245 .451 r
.43305 .48746 .44092 .4281 .45153 .41715 .4437 .48492 Mtetra
.516 .257 .461 r
.4437 .48492 .45153 .41715 .46202 .4114 .45438 .48297 Mtetra
.521 .263 .465 r
.45438 .48297 .46202 .4114 .47246 .41107 .4651 .48177 Mtetra
.517 .259 .463 r
.4651 .48177 .47246 .41107 .48293 .41268 .4759 .47987 Mtetra
.51 .251 .459 r
.4759 .47987 .48293 .41268 .49348 .41386 .48675 .4769 Mtetra
.505 .244 .453 r
.48675 .4769 .49348 .41386 .50413 .41034 .49766 .47343 Mtetra
.501 .242 .453 r
.49766 .47343 .50413 .41034 .51484 .40213 .50861 .46944 Mtetra
.498 .241 .456 r
.50861 .46944 .51484 .40213 .52556 .39346 .51961 .46438 Mtetra
.496 .242 .459 r
.51961 .46438 .52556 .39346 .53629 .38673 .53063 .45861 Mtetra
.501 .246 .461 r
.53063 .45861 .53629 .38673 .54708 .38545 .54169 .45358 Mtetra
.502 .245 .458 r
.54169 .45358 .54708 .38545 .55798 .38942 .5528 .44915 Mtetra
.494 .233 .447 r
.5528 .44915 .55798 .38942 .56901 .39585 .56393 .44432 Mtetra
.474 .206 .426 r
.56393 .44432 .56901 .39585 .58018 .40333 .57508 .4384 Mtetra
.42 .139 .379 r
.57508 .4384 .58018 .40333 .59145 .41067 .58623 .43028 Mtetra
.254 0 .226 r
.58623 .43028 .59145 .41067 .60281 .41641 .59734 .42014 Mtetra
.675 .937 .654 r
.59734 .42014 .60281 .41641 .61418 .41833 .60842 .40869 Mtetra
.811 .727 .772 r
.60842 .40869 .61418 .41833 .62551 .41633 .61946 .39644 Mtetra
.726 .58 .692 r
.61946 .39644 .62551 .41633 .63677 .41072 .63048 .38384 Mtetra
.686 .524 .661 r
.63048 .38384 .63677 .41072 .64796 .40231 .6415 .37163 Mtetra
.66 .495 .649 r
.6415 .37163 .64796 .40231 .65908 .39205 .65256 .36082 Mtetra
.644 .483 .65 r
.65256 .36082 .65908 .39205 .67017 .38104 .66368 .3517 Mtetra
.629 .479 .659 r
.66368 .3517 .67017 .38104 .68128 .37068 .67492 .3447 Mtetra
.617 .484 .677 r
.67492 .3447 .68128 .37068 .69245 .3614 .68627 .33957 Mtetra
.605 .497 .705 r
.68627 .33957 .69245 .3614 .70372 .35381 .69775 .3361 Mtetra
.593 .522 .744 r
.69775 .3361 .70372 .35381 .7151 .34775 .70935 .33385 Mtetra
.582 .559 .795 r
.70935 .33385 .7151 .34775 .72661 .34317 .72106 .33235 Mtetra
.568 .607 .852 r
.72106 .33235 .72661 .34317 .73823 .33968 .73286 .33122 Mtetra
.559 .663 .907 r
.73286 .33122 .73823 .33968 .74996 .3369 .74473 .33001 Mtetra
.552 .712 .946 r
.74473 .33001 .74996 .3369 .76177 .33455 .75664 .32859 Mtetra
.561 .752 .967 r
.75664 .32859 .76177 .33455 .77365 .33226 .76859 .32668 Mtetra
.575 .774 .973 r
.76859 .32668 .77365 .33226 .78559 .32995 .78057 .32436 Mtetra
.598 .785 .97 r
.78057 .32436 .78559 .32995 .79757 .32741 .79257 .32156 Mtetra
.617 .784 .961 r
.79257 .32156 .79757 .32741 .8096 .3247 .8046 .31842 Mtetra
.631 .774 .949 r
.8046 .31842 .8096 .3247 .82167 .32182 .81666 .31503 Mtetra
.64 .761 .936 r
.81666 .31503 .82167 .32182 .83378 .31877 .82876 .31146 Mtetra
.64 .747 .927 r
.18679 .51429 .19348 .52013 .20312 .51659 .19638 .51148 Mtetra
.64 .774 .945 r
.19638 .51148 .20312 .51659 .21281 .5129 .20602 .50859 Mtetra
.644 .807 .961 r
.20602 .50859 .21281 .5129 .22255 .50896 .21571 .50548 Mtetra
.652 .841 .973 r
.21571 .50548 .22255 .50896 .23236 .5047 .22547 .50204 Mtetra
.664 .876 .978 r
.22547 .50204 .23236 .5047 .24223 .49999 .2353 .49814 Mtetra
.68 .909 .975 r
.2353 .49814 .24223 .49999 .25216 .49486 .24522 .49366 Mtetra
.704 .934 .963 r
.24522 .49366 .25216 .49486 .26216 .48928 .25521 .48849 Mtetra
.729 .949 .951 r
.25521 .48849 .26216 .48928 .27219 .48348 .26529 .48265 Mtetra
.762 .95 .938 r
.26529 .48265 .27219 .48348 .28225 .47759 .27544 .47612 Mtetra
.784 .93 .929 r
.27544 .47612 .28225 .47759 .29231 .47207 .28564 .46921 Mtetra
.792 .88 .911 r
.28564 .46921 .29231 .47207 .30234 .46726 .29586 .46209 Mtetra
.77 .8 .878 r
.29586 .46209 .30234 .46726 .31232 .46363 .30608 .45528 Mtetra
.725 .705 .831 r
.30608 .45528 .31232 .46363 .32223 .46162 .31627 .44921 Mtetra
.669 .61 .78 r
.31627 .44921 .32223 .46162 .33209 .46144 .3264 .4444 Mtetra
.614 .529 .735 r
.3264 .4444 .33209 .46144 .34188 .46333 .33646 .44135 Mtetra
.566 .465 .698 r
.33646 .44135 .34188 .46333 .35166 .4669 .34644 .44038 Mtetra
.526 .415 .671 r
.34644 .44038 .35166 .4669 .36145 .47186 .35636 .44174 Mtetra
.501 .385 .653 r
.35636 .44174 .36145 .47186 .37131 .47723 .36626 .44488 Mtetra
.482 .365 .644 r
.36626 .44488 .37131 .47723 .38127 .48229 .37617 .44945 Mtetra
.465 .352 .641 r
.37617 .44945 .38127 .48229 .39136 .48659 .38612 .45524 Mtetra
.449 .346 .646 r
.38612 .45524 .39136 .48659 .40158 .48963 .39614 .46174 Mtetra
.457 .365 .664 r
.39614 .46174 .40158 .48963 .41195 .4907 .4063 .46715 Mtetra
.484 .406 .693 r
.4063 .46715 .41195 .4907 .42246 .48962 .41663 .4705 Mtetra
.506 .452 .73 r
.41663 .4705 .42246 .48962 .43305 .48746 .42709 .47231 Mtetra
.542 .515 .775 r
.42709 .47231 .43305 .48746 .4437 .48492 .43766 .47237 Mtetra
.624 .596 .801 r
.43766 .47237 .4437 .48492 .45438 .48297 .44837 .4694 Mtetra
.681 .61 .769 r
.44837 .4694 .45438 .48297 .4651 .48177 .45919 .46346 Mtetra
.676 .561 .717 r
.45919 .46346 .4651 .48177 .4759 .47987 .47006 .45605 Mtetra
.651 .513 .683 r
.47006 .45605 .4759 .47987 .48675 .4769 .48094 .44877 Mtetra
.594 .459 .667 r
.48094 .44877 .48675 .4769 .49766 .47343 .49181 .44524 Mtetra
.544 .426 .669 r
.49181 .44524 .49766 .47343 .50861 .46944 .50269 .44549 Mtetra
.542 .444 .693 r
.50269 .44549 .50861 .46944 .51961 .46438 .51364 .44588 Mtetra
.57 .499 .736 r
.51364 .44588 .51961 .46438 .53063 .45861 .52466 .44481 Mtetra
.643 .591 .781 r
.52466 .44481 .53063 .45861 .54169 .45358 .53573 .44075 Mtetra
.706 .635 .775 r
.53573 .44075 .54169 .45358 .5528 .44915 .54682 .43362 Mtetra
.713 .607 .737 r
.54682 .43362 .5528 .44915 .56393 .44432 .55791 .42472 Mtetra
.706 .571 .701 r
.55791 .42472 .56393 .44432 .57508 .4384 .569 .41423 Mtetra
.702 .545 .671 r
.569 .41423 .57508 .4384 .58623 .43028 .58004 .40162 Mtetra
.692 .522 .652 r
.58004 .40162 .58623 .43028 .59734 .42014 .59104 .38788 Mtetra
.673 .499 .642 r
.59104 .38788 .59734 .42014 .60842 .40869 .60204 .37482 Mtetra
.659 .486 .638 r
.60204 .37482 .60842 .40869 .61946 .39644 .61304 .36297 Mtetra
.649 .479 .641 r
.61304 .36297 .61946 .39644 .63048 .38384 .62408 .35256 Mtetra
.639 .479 .65 r
.62408 .35256 .63048 .38384 .6415 .37163 .63518 .34394 Mtetra
.625 .481 .667 r
.63518 .34394 .6415 .37163 .65256 .36082 .64638 .3377 Mtetra
.611 .493 .694 r
.64638 .3377 .65256 .36082 .66368 .3517 .6577 .33358 Mtetra
.593 .517 .738 r
.6577 .33358 .66368 .3517 .67492 .3447 .66915 .33126 Mtetra
.568 .558 .803 r
.66915 .33126 .67492 .3447 .68627 .33957 .68072 .33025 Mtetra
.527 .621 .889 r
.68072 .33025 .68627 .33957 .69775 .3361 .6924 .33001 Mtetra
.451 .69 .968 r
.6924 .33001 .69775 .3361 .70935 .33385 .70417 .33009 Mtetra
.356 .736 .987 r
.70417 .33009 .70935 .33385 .72106 .33235 .716 .32999 Mtetra
.287 .746 .952 r
.716 .32999 .72106 .33235 .73286 .33122 .72789 .32948 Mtetra
.299 .772 .933 r
.72789 .32948 .73286 .33122 .74473 .33001 .73981 .32827 Mtetra
.363 .811 .948 r
.73981 .32827 .74473 .33001 .75664 .32859 .75174 .32637 Mtetra
.46 .852 .978 r
.75174 .32637 .75664 .32859 .76859 .32668 .76369 .32375 Mtetra
.545 .869 .994 r
.76369 .32375 .76859 .32668 .78057 .32436 .77564 .32053 Mtetra
.607 .862 .991 r
.77564 .32053 .78057 .32436 .79257 .32156 .78762 .31683 Mtetra
.643 .841 .976 r
.78762 .31683 .79257 .32156 .8046 .31842 .79961 .31277 Mtetra
.662 .813 .956 r
.79961 .31277 .8046 .31842 .81666 .31503 .81164 .30848 Mtetra
.669 .784 .935 r
.81164 .30848 .81666 .31503 .82876 .31146 .82371 .3041 Mtetra
.601 .736 .94 r
.18006 .50842 .18679 .51429 .19638 .51148 .18959 .50637 Mtetra
.591 .762 .961 r
.18959 .50637 .19638 .51148 .20602 .50859 .19916 .50434 Mtetra
.581 .794 .98 r
.19916 .50434 .20602 .50859 .21571 .50548 .20879 .50223 Mtetra
.569 .83 .995 r
.20879 .50223 .21571 .50548 .22547 .50204 .21847 .49991 Mtetra
.547 .866 .995 r
.21847 .49991 .22547 .50204 .2353 .49814 .22822 .49732 Mtetra
.516 .892 .966 r
.22822 .49732 .2353 .49814 .24522 .49366 .23804 .49425 Mtetra
.473 .893 .896 r
.23804 .49425 .24522 .49366 .25521 .48849 .24796 .49055 Mtetra
.423 .864 .79 r
.24796 .49055 .25521 .48849 .26529 .48265 .25798 .48606 Mtetra
.395 .831 .688 r
.25798 .48606 .26529 .48265 .27544 .47612 .2681 .4806 Mtetra
.389 .807 .613 r
.2681 .4806 .27544 .47612 .28564 .46921 .27832 .4742 Mtetra
.439 .828 .603 r
.27832 .4742 .28564 .46921 .29586 .46209 .28862 .46681 Mtetra
.533 .886 .656 r
.28862 .46681 .29586 .46209 .30608 .45528 .29899 .4587 Mtetra
.684 .971 .775 r
.29899 .4587 .30608 .45528 .31627 .44921 .30941 .45004 Mtetra
.81 .988 .882 r
.30941 .45004 .31627 .44921 .3264 .4444 .31983 .44127 Mtetra
.823 .872 .882 r
.31983 .44127 .3264 .4444 .33646 .44135 .33025 .43274 Mtetra
.754 .71 .811 r
.33025 .43274 .33646 .44135 .34644 .44038 .34063 .42503 Mtetra
.679 .582 .74 r
.34063 .42503 .34644 .44038 .35636 .44174 .35095 .4186 Mtetra
.627 .498 .685 r
.35095 .4186 .35636 .44174 .36626 .44488 .36123 .41346 Mtetra
.592 .444 .649 r
.36123 .41346 .36626 .44488 .37617 .44945 .37146 .40971 Mtetra
.568 .408 .624 r
.37146 .40971 .37617 .44945 .38612 .45524 .38167 .40736 Mtetra
.553 .385 .607 r
.38167 .40736 .38612 .45524 .39614 .46174 .39188 .40624 Mtetra
.549 .374 .596 r
.39188 .40624 .39614 .46174 .4063 .46715 .40214 .4053 Mtetra
.551 .37 .589 r
.40214 .4053 .4063 .46715 .41663 .4705 .41246 .40388 Mtetra
.554 .369 .585 r
.41246 .40388 .41663 .4705 .42709 .47231 .42286 .40187 Mtetra
.56 .371 .582 r
.42286 .40187 .42709 .47231 .43766 .47237 .43335 .39859 Mtetra
.578 .383 .581 r
.43335 .39859 .43766 .47237 .44837 .4694 .44397 .39146 Mtetra
.593 .392 .579 r
.44397 .39146 .44837 .4694 .45919 .46346 .45469 .3805 Mtetra
.591 .389 .576 r
.45469 .3805 .45919 .46346 .47006 .45605 .46542 .36931 Mtetra
.58 .379 .573 r
.46542 .36931 .47006 .45605 .48094 .44877 .4761 .36015 Mtetra
.556 .36 .57 r
.4761 .36015 .48094 .44877 .49181 .44524 .48672 .35653 Mtetra
.531 .341 .568 r
.48672 .35653 .49181 .44524 .50269 .44549 .49733 .35847 Mtetra
.521 .334 .568 r
.49733 .35847 .50269 .44549 .51364 .44588 .50801 .36246 Mtetra
.522 .336 .571 r
.50801 .36246 .51364 .44588 .52466 .44481 .51879 .36624 Mtetra
.541 .353 .576 r
.51879 .36624 .52466 .44481 .53573 .44075 .52965 .3662 Mtetra
.561 .37 .58 r
.52965 .3662 .53573 .44075 .54682 .43362 .54056 .36228 Mtetra
.569 .378 .583 r
.54056 .36228 .54682 .43362 .55791 .42472 .5515 .35707 Mtetra
.574 .384 .586 r
.5515 .35707 .55791 .42472 .569 .41423 .56247 .35126 Mtetra
.579 .391 .59 r
.56247 .35126 .569 .41423 .58004 .40162 .57346 .34495 Mtetra
.582 .398 .597 r
.57346 .34495 .58004 .40162 .59104 .38788 .58448 .33882 Mtetra
.58 .405 .608 r
.58448 .33882 .59104 .38788 .60204 .37482 .59555 .33393 Mtetra
.576 .414 .625 r
.59555 .33393 .60204 .37482 .61304 .36297 .6067 .33046 Mtetra
.57 .429 .65 r
.6067 .33046 .61304 .36297 .62408 .35256 .61794 .32841 Mtetra
.559 .454 .692 r
.61794 .32841 .62408 .35256 .63518 .34394 .62928 .32768 Mtetra
.529 .498 .766 r
.62928 .32768 .63518 .34394 .64638 .3377 .64073 .32828 Mtetra
.45 .577 .89 r
.64073 .32828 .64638 .3377 .6577 .33358 .6523 .32973 Mtetra
.191 .63 .945 r
.6523 .32973 .6577 .33358 .66915 .33126 .66397 .33144 Mtetra
.177 0 0 r
.66397 .33144 .66915 .33126 .68072 .33025 .67572 .33305 Mtetra
.306 0 0 r
.67572 .33305 .68072 .33025 .6924 .33001 .68753 .33412 Mtetra
.317 0 0 r
.68753 .33412 .6924 .33001 .70417 .33009 .69938 .33445 Mtetra
.264 0 0 r
.69938 .33445 .70417 .33009 .716 .32999 .71125 .33378 Mtetra
.166 0 0 r
.71125 .33378 .716 .32999 .72789 .32948 .72314 .33213 Mtetra
0 0 0 r
.72314 .33213 .72789 .32948 .73981 .32827 .73503 .32948 Mtetra
.217 .732 .701 r
.73503 .32948 .73981 .32827 .75174 .32637 .74692 .32601 Mtetra
.437 .875 .883 r
.74692 .32601 .75174 .32637 .76369 .32375 .75881 .32188 Mtetra
.584 .92 .967 r
.75881 .32188 .76369 .32375 .77564 .32053 .77072 .31725 Mtetra
.656 .903 .981 r
.77072 .31725 .77564 .32053 .78762 .31683 .78264 .31231 Mtetra
.688 .867 .966 r
.78264 .31231 .78762 .31683 .79961 .31277 .7946 .30717 Mtetra
.698 .83 .946 r
.7946 .30717 .79961 .31277 .81164 .30848 .80658 .30192 Mtetra
.698 .796 .926 r
.80658 .30192 .81164 .30848 .82371 .3041 .81861 .29669 Mtetra
.583 .731 .945 r
.17328 .5025 .18006 .50842 .18959 .50637 .1828 .50076 Mtetra
.573 .739 .955 r
.1828 .50076 .18959 .50637 .19916 .50434 .19235 .49911 Mtetra
.563 .751 .966 r
.19235 .49911 .19916 .50434 .20879 .50223 .20194 .49752 Mtetra
.551 .768 .979 r
.20194 .49752 .20879 .50223 .21847 .49991 .21157 .49593 Mtetra
.531 .791 .993 r
.21157 .49593 .21847 .49991 .22822 .49732 .22125 .49433 Mtetra
.508 .822 1 r
.22125 .49433 .22822 .49732 .23804 .49425 .231 .49254 Mtetra
.465 .848 .983 r
.231 .49254 .23804 .49425 .24796 .49055 .24081 .49045 Mtetra
.396 .848 .908 r
.24081 .49045 .24796 .49055 .25798 .48606 .25071 .48783 Mtetra
.299 .79 .755 r
.25071 .48783 .25798 .48606 .2681 .4806 .26072 .48448 Mtetra
0 0 0 r
.26072 .48448 .2681 .4806 .27832 .4742 .27083 .48021 Mtetra
.27083 .48021 .27832 .4742 .28862 .46681 .28105 .47484 Mtetra
.28105 .47484 .28862 .46681 .29899 .4587 .29138 .46838 Mtetra
.29138 .46838 .29899 .4587 .30941 .45004 .3018 .46079 Mtetra
.3018 .46079 .30941 .45004 .31983 .44127 .31229 .45226 Mtetra
.31229 .45226 .31983 .44127 .33025 .43274 .32285 .44293 Mtetra
.32285 .44293 .33025 .43274 .34063 .42503 .33342 .43326 Mtetra
.33342 .43326 .34063 .42503 .35095 .4186 .34399 .42364 Mtetra
.564 .892 .634 r
.34399 .42364 .35095 .4186 .36123 .41346 .35454 .41447 Mtetra
.778 .993 .879 r
.35454 .41447 .36123 .41346 .37146 .40971 .36505 .40609 Mtetra
.798 .866 .899 r
.36505 .40609 .37146 .40971 .38167 .40736 .37554 .39852 Mtetra
.732 .704 .824 r
.37554 .39852 .38167 .40736 .39188 .40624 .38599 .39187 Mtetra
.67 .59 .757 r
.38599 .39187 .39188 .40624 .40214 .4053 .39643 .38632 Mtetra
.63 .526 .717 r
.39643 .38632 .40214 .4053 .41246 .40388 .40685 .38185 Mtetra
.61 .494 .696 r
.40685 .38185 .41246 .40388 .42286 .40187 .41728 .37802 Mtetra
.605 .481 .685 r
.41728 .37802 .42286 .40187 .43335 .39859 .42774 .37429 Mtetra
.626 .493 .68 r
.42774 .37429 .43335 .39859 .44397 .39146 .4383 .36886 Mtetra
.655 .519 .686 r
.4383 .36886 .44397 .39146 .45469 .3805 .44892 .36158 Mtetra
.666 .548 .711 r
.44892 .36158 .45469 .3805 .46542 .36931 .45955 .35466 Mtetra
.668 .588 .756 r
.45955 .35466 .46542 .36931 .4761 .36015 .47018 .34907 Mtetra
.646 .63 .82 r
.47018 .34907 .4761 .36015 .48672 .35653 .48082 .34542 Mtetra
.589 .603 .834 r
.48082 .34542 .48672 .35653 .49733 .35847 .49147 .34372 Mtetra
.551 .524 .779 r
.49147 .34372 .49733 .35847 .50801 .36246 .50217 .34335 Mtetra
.545 .476 .729 r
.50217 .34335 .50801 .36246 .51879 .36624 .51293 .34337 Mtetra
.577 .47 .696 r
.51293 .34337 .51879 .36624 .52965 .3662 .52376 .34153 Mtetra
.599 .475 .683 r
.52376 .34153 .52965 .3662 .54056 .36228 .53464 .33798 Mtetra
.598 .477 .685 r
.53464 .33798 .54056 .36228 .5515 .35707 .54556 .33453 Mtetra
.592 .483 .698 r
.54556 .33453 .5515 .35707 .56247 .35126 .55654 .33173 Mtetra
.579 .495 .724 r
.55654 .33173 .56247 .35126 .57346 .34495 .56758 .33003 Mtetra
.556 .528 .779 r
.56758 .33003 .57346 .34495 .58448 .33882 .5787 .32944 Mtetra
.499 .603 .888 r
.5787 .32944 .58448 .33882 .59555 .33393 .5899 .32981 Mtetra
.256 .661 .965 r
.5899 .32981 .59555 .33393 .6067 .33046 .60121 .33101 Mtetra
.252 0 0 r
.60121 .33101 .6067 .33046 .61794 .32841 .61261 .33303 Mtetra
.454 0 0 r
.61261 .33303 .61794 .32841 .62928 .32768 .62412 .33554 Mtetra
.498 .033 .081 r
.62412 .33554 .62928 .32768 .64073 .32828 .63572 .33811 Mtetra
.501 .065 .142 r
.63572 .33811 .64073 .32828 .6523 .32973 .64741 .34036 Mtetra
.482 .056 .153 r
.64741 .34036 .6523 .32973 .66397 .33144 .65915 .34181 Mtetra
.451 .021 .131 r
.65915 .34181 .66397 .33144 .67572 .33305 .67094 .34229 Mtetra
.397 0 .073 r
.67094 .34229 .67572 .33305 .68753 .33412 .68275 .34163 Mtetra
.313 0 0 r
.68275 .34163 .68753 .33412 .69938 .33445 .69457 .33986 Mtetra
.165 0 0 r
.69457 .33986 .69938 .33445 .71125 .33378 .7064 .33694 Mtetra
0 0 0 r
.7064 .33694 .71125 .33378 .72314 .33213 .71822 .33307 Mtetra
.359 .827 .771 r
.71822 .33307 .72314 .33213 .73503 .32948 .73004 .32844 Mtetra
.575 .933 .934 r
.73004 .32844 .73503 .32948 .74692 .32601 .74187 .32325 Mtetra
.674 .925 .972 r
.74187 .32325 .74692 .32601 .75881 .32188 .75372 .31773 Mtetra
.708 .886 .962 r
.75372 .31773 .75881 .32188 .77072 .31725 .76559 .31201 Mtetra
.716 .848 .945 r
.76559 .31201 .77072 .31725 .78264 .31231 .7775 .30627 Mtetra
.716 .82 .93 r
.7775 .30627 .78264 .31231 .7946 .30717 .78945 .30052 Mtetra
.713 .799 .918 r
.78945 .30052 .7946 .30717 .80658 .30192 .80144 .29482 Mtetra
.708 .783 .91 r
.80144 .29482 .80658 .30192 .81861 .29669 .81347 .28921 Mtetra
.596 .735 .941 r
.16646 .49655 .17328 .5025 .1828 .50076 .17601 .49456 Mtetra
.589 .725 .938 r
.17601 .49456 .1828 .50076 .19235 .49911 .1856 .49271 Mtetra
.58 .716 .936 r
.1856 .49271 .19235 .49911 .20194 .49752 .19521 .49105 Mtetra
.569 .71 .937 r
.19521 .49105 .20194 .49752 .21157 .49593 .20485 .48959 Mtetra
.552 .709 .944 r
.20485 .48959 .21157 .49593 .22125 .49433 .21451 .48839 Mtetra
.533 .717 .957 r
.21451 .48839 .22125 .49433 .231 .49254 .2242 .48737 Mtetra
.503 .736 .978 r
.2242 .48737 .231 .49254 .24081 .49045 .23392 .48651 Mtetra
.461 .769 .996 r
.23392 .48651 .24081 .49045 .25071 .48783 .2437 .48561 Mtetra
.374 .791 .977 r
.2437 .48561 .25071 .48783 .26072 .48448 .25355 .48456 Mtetra
.212 .736 .823 r
.25355 .48456 .26072 .48448 .27083 .48021 .26348 .48308 Mtetra
0 0 0 r
.26348 .48308 .27083 .48021 .28105 .47484 .27351 .48097 Mtetra
.143 0 0 r
.27351 .48097 .28105 .47484 .29138 .46838 .28364 .47805 Mtetra
.223 0 0 r
.28364 .47805 .29138 .46838 .3018 .46079 .29388 .47414 Mtetra
.268 0 .106 r
.29388 .47414 .3018 .46079 .31229 .45226 .30423 .46916 Mtetra
.289 0 .178 r
.30423 .46916 .31229 .45226 .32285 .44293 .31469 .46303 Mtetra
.301 0 .224 r
.31469 .46303 .32285 .44293 .33342 .43326 .32523 .45584 Mtetra
.305 0 .25 r
.32523 .45584 .33342 .43326 .34399 .42364 .33584 .44767 Mtetra
.311 0 .266 r
.33584 .44767 .34399 .42364 .35454 .41447 .34648 .43911 Mtetra
.318 .009 .274 r
.34648 .43911 .35454 .41447 .36505 .40609 .35714 .43049 Mtetra
.312 .003 .27 r
.35714 .43049 .36505 .40609 .37554 .39852 .36781 .42169 Mtetra
.301 0 .257 r
.36781 .42169 .37554 .39852 .38599 .39187 .37849 .41295 Mtetra
.317 0 .246 r
.37849 .41295 .38599 .39187 .39643 .38632 .38911 .40563 Mtetra
.358 .019 .246 r
.38911 .40563 .39643 .38632 .40685 .38185 .39967 .40038 Mtetra
.396 .049 .255 r
.39967 .40038 .40685 .38185 .41728 .37802 .4102 .39672 Mtetra
.437 .089 .275 r
.4102 .39672 .41728 .37802 .42774 .37429 .42072 .39462 Mtetra
.488 .145 .311 r
.42072 .39462 .42774 .37429 .4383 .36886 .43123 .39453 Mtetra
.523 .2 .361 r
.43123 .39453 .4383 .36886 .44892 .36158 .44177 .39611 Mtetra
.532 .23 .401 r
.44177 .39611 .44892 .36158 .45955 .35466 .45237 .39818 Mtetra
.523 .237 .422 r
.45237 .39818 .45955 .35466 .47018 .34907 .46307 .39921 Mtetra
.487 .214 .425 r
.46307 .39921 .47018 .34907 .48082 .34542 .47392 .39558 Mtetra
.445 .179 .414 r
.47392 .39558 .48082 .34542 .49147 .34372 .48487 .38728 Mtetra
.419 .149 .394 r
.48487 .38728 .49147 .34372 .50217 .34335 .49584 .37793 Mtetra
.394 .11 .36 r
.49584 .37793 .50217 .34335 .51293 .34337 .50681 .36904 Mtetra
.373 .066 .309 r
.50681 .36904 .51293 .34337 .52376 .34153 .51779 .36182 Mtetra
.377 .043 .267 r
.51779 .36182 .52376 .34153 .53464 .33798 .52879 .35662 Mtetra
.403 .056 .259 r
.52879 .35662 .53464 .33798 .54556 .33453 .53983 .35299 Mtetra
.44 .088 .271 r
.53983 .35299 .54556 .33453 .55654 .33173 .55093 .35096 Mtetra
.487 .136 .296 r
.55093 .35096 .55654 .33173 .56758 .33003 .56211 .35104 Mtetra
.516 .171 .321 r
.56211 .35104 .56758 .33003 .5787 .32944 .57338 .35259 Mtetra
.519 .183 .338 r
.57338 .35259 .5787 .32944 .5899 .32981 .58474 .3542 Mtetra
.517 .186 .345 r
.58474 .3542 .5899 .32981 .60121 .33101 .59618 .35565 Mtetra
.517 .187 .346 r
.59618 .35565 .60121 .33101 .61261 .33303 .60771 .35706 Mtetra
.51 .178 .34 r
.60771 .35706 .61261 .33303 .62412 .33554 .61931 .35808 Mtetra
.493 .156 .323 r
.61931 .35808 .62412 .33554 .63572 .33811 .63096 .35811 Mtetra
.467 .12 .293 r
.63096 .35811 .63572 .33811 .64741 .34036 .64264 .35708 Mtetra
.425 .06 .24 r
.64264 .35708 .64741 .34036 .65915 .34181 .65435 .35485 Mtetra
.357 0 .153 r
.65435 .35485 .65915 .34181 .67094 .34229 .66607 .35153 Mtetra
.235 0 0 r
.66607 .35153 .67094 .34229 .68275 .34163 .67779 .34719 Mtetra
.009 0 0 r
.67779 .34719 .68275 .34163 .69457 .33986 .68952 .34201 Mtetra
.354 .806 .675 r
.68952 .34201 .69457 .33986 .7064 .33694 .70125 .33615 Mtetra
.637 .959 .92 r
.70125 .33615 .7064 .33694 .71822 .33307 .71299 .32986 Mtetra
.73 .923 .957 r
.71299 .32986 .71822 .33307 .73004 .32844 .72474 .32338 Mtetra
.743 .86 .934 r
.72474 .32338 .73004 .32844 .74187 .32325 .73653 .31686 Mtetra
.735 .812 .912 r
.73653 .31686 .74187 .32325 .75372 .31773 .74836 .31048 Mtetra
.725 .782 .898 r
.74836 .31048 .75372 .31773 .76559 .31201 .76024 .30429 Mtetra
.715 .765 .892 r
.76024 .30429 .76559 .31201 .7775 .30627 .77217 .29836 Mtetra
.708 .758 .891 r
.77217 .29836 .7775 .30627 .78945 .30052 .78416 .29263 Mtetra
.703 .758 .895 r
.78416 .29263 .78945 .30052 .80144 .29482 .7962 .28708 Mtetra
.698 .762 .901 r
.7962 .28708 .80144 .29482 .81347 .28921 .8083 .28168 Mtetra
.638 .747 .928 r
.15958 .49055 .16646 .49655 .17601 .49456 .16925 .4877 Mtetra
.632 .718 .909 r
.16925 .4877 .17601 .49456 .1856 .49271 .17894 .48499 Mtetra
.623 .689 .891 r
.17894 .48499 .1856 .49271 .19521 .49105 .18864 .48251 Mtetra
.61 .663 .877 r
.18864 .48251 .19521 .49105 .20485 .48959 .19836 .48035 Mtetra
.593 .639 .866 r
.19836 .48035 .20485 .48959 .21451 .48839 .20807 .47862 Mtetra
.576 .62 .859 r
.20807 .47862 .21451 .48839 .2242 .48737 .21779 .47734 Mtetra
.556 .605 .858 r
.21779 .47734 .2242 .48737 .23392 .48651 .22751 .47656 Mtetra
.537 .599 .863 r
.22751 .47656 .23392 .48651 .2437 .48561 .23725 .47619 Mtetra
.515 .603 .879 r
.23725 .47619 .2437 .48561 .25355 .48456 .24701 .4762 Mtetra
.494 .624 .907 r
.24701 .4762 .25355 .48456 .26348 .48308 .25682 .47636 Mtetra
.464 .665 .949 r
.25682 .47636 .26348 .48308 .27351 .48097 .26669 .47649 Mtetra
.405 .726 .99 r
.26669 .47649 .27351 .48097 .28364 .47805 .27664 .47637 Mtetra
.261 .744 .927 r
.27664 .47637 .28364 .47805 .29388 .47414 .28668 .47575 Mtetra
0 0 0 r
.28668 .47575 .29388 .47414 .30423 .46916 .29683 .47446 Mtetra
.165 0 0 r
.29683 .47446 .30423 .46916 .31469 .46303 .30708 .4723 Mtetra
.252 0 0 r
.30708 .4723 .31469 .46303 .32523 .45584 .31745 .46906 Mtetra
.289 0 .112 r
.31745 .46906 .32523 .45584 .33584 .44767 .32794 .4646 Mtetra
.322 0 .193 r
.32794 .4646 .33584 .44767 .34648 .43911 .3385 .45939 Mtetra
.347 .011 .244 r
.3385 .45939 .34648 .43911 .35714 .43049 .34912 .45365 Mtetra
.353 .031 .273 r
.34912 .45365 .35714 .43049 .36781 .42169 .3598 .44706 Mtetra
.355 .043 .291 r
.3598 .44706 .36781 .42169 .37849 .41295 .37055 .43976 Mtetra
.383 .074 .312 r
.37055 .43976 .37849 .41295 .38911 .40563 .38128 .43323 Mtetra
.417 .107 .33 r
.38128 .43323 .38911 .40563 .39967 .40038 .39196 .4282 Mtetra
.436 .125 .339 r
.39196 .4282 .39967 .40038 .4102 .39672 .40265 .42414 Mtetra
.457 .143 .344 r
.40265 .42414 .4102 .39672 .42072 .39462 .41332 .42143 Mtetra
.513 .192 .36 r
.41332 .42143 .42072 .39462 .43123 .39453 .42393 .42235 Mtetra
.559 .238 .381 r
.42393 .42235 .43123 .39453 .44177 .39611 .43451 .42689 Mtetra
.564 .25 .394 r
.43451 .42689 .44177 .39611 .45237 .39818 .44518 .43213 Mtetra
.544 .237 .399 r
.44518 .43213 .45237 .39818 .46307 .39921 .45598 .43555 Mtetra
.466 .173 .383 r
.45598 .43555 .46307 .39921 .47392 .39558 .467 .43193 Mtetra
.37 .091 .353 r
.467 .43193 .47392 .39558 .48487 .38728 .47816 .42126 Mtetra
.327 .05 .331 r
.47816 .42126 .48487 .38728 .49584 .37793 .48935 .40874 Mtetra
.317 .032 .314 r
.48935 .40874 .49584 .37793 .50681 .36904 .50051 .39689 Mtetra
.365 .064 .315 r
.50051 .39689 .50681 .36904 .51779 .36182 .51165 .38865 Mtetra
.426 .114 .33 r
.51165 .38865 .51779 .36182 .52879 .35662 .52279 .38407 Mtetra
.451 .137 .342 r
.52279 .38407 .52879 .35662 .53983 .35299 .53398 .38085 Mtetra
.468 .153 .349 r
.53398 .38085 .53983 .35299 .55093 .35096 .54523 .37861 Mtetra
.489 .171 .354 r
.54523 .37861 .55093 .35096 .56211 .35104 .55655 .37789 Mtetra
.499 .177 .352 r
.55655 .37789 .56211 .35104 .57338 .35259 .56794 .37797 Mtetra
.486 .16 .339 r
.56794 .37797 .57338 .35259 .58474 .3542 .5794 .37734 Mtetra
.467 .134 .317 r
.5794 .37734 .58474 .3542 .59618 .35565 .59092 .37586 Mtetra
.446 .1 .285 r
.59092 .37586 .59618 .35565 .60771 .35706 .60248 .37384 Mtetra
.408 .043 .231 r
.60248 .37384 .60771 .35706 .61931 .35808 .61408 .37105 Mtetra
.326 0 .133 r
.61408 .37105 .61931 .35808 .63096 .35811 .6257 .36701 Mtetra
.173 0 0 r
.6257 .36701 .63096 .35811 .64264 .35708 .63733 .36187 Mtetra
0 0 0 r
.63733 .36187 .64264 .35708 .65435 .35485 .64896 .35581 Mtetra
.558 .932 .821 r
.64896 .35581 .65435 .35485 .66607 .35153 .6606 .34905 Mtetra
.754 .947 .943 r
.6606 .34905 .66607 .35153 .67779 .34719 .67224 .34177 Mtetra
.774 .85 .908 r
.67224 .34177 .67779 .34719 .68952 .34201 .68389 .33421 Mtetra
.757 .772 .865 r
.68389 .33421 .68952 .34201 .70125 .33615 .69556 .32661 Mtetra
.739 .723 .837 r
.69556 .32661 .70125 .33615 .71299 .32986 .70726 .31915 Mtetra
.721 .692 .822 r
.70726 .31915 .71299 .32986 .72474 .32338 .71901 .31207 Mtetra
.707 .675 .816 r
.71901 .31207 .72474 .32338 .73653 .31686 .73082 .3054 Mtetra
.695 .667 .819 r
.73082 .3054 .73653 .31686 .74836 .31048 .74269 .29924 Mtetra
.686 .668 .826 r
.74269 .29924 .74836 .31048 .76024 .30429 .75463 .29354 Mtetra
.679 .675 .839 r
.75463 .29354 .76024 .30429 .77217 .29836 .76664 .28828 Mtetra
.674 .688 .856 r
.76664 .28828 .77217 .29836 .78416 .29263 .77872 .28334 Mtetra
.671 .707 .875 r
.77872 .28334 .78416 .29263 .7962 .28708 .79087 .27864 Mtetra
.669 .73 .896 r
.79087 .27864 .7962 .28708 .8083 .28168 .80308 .27409 Mtetra
.683 .758 .908 r
.15266 .48451 .15958 .49055 .16925 .4877 .16247 .48051 Mtetra
.676 .721 .883 r
.16247 .48051 .16925 .4877 .17894 .48499 .1723 .47659 Mtetra
.664 .686 .861 r
.1723 .47659 .17894 .48499 .18864 .48251 .18215 .4729 Mtetra
.648 .653 .841 r
.18215 .4729 .18864 .48251 .19836 .48035 .19199 .46953 Mtetra
.629 .621 .823 r
.19199 .46953 .19836 .48035 .20807 .47862 .20182 .46664 Mtetra
.61 .592 .808 r
.20182 .46664 .20807 .47862 .21779 .47734 .21164 .46429 Mtetra
.588 .564 .795 r
.21164 .46429 .21779 .47734 .22751 .47656 .22144 .4626 Mtetra
.568 .541 .785 r
.22144 .4626 .22751 .47656 .23725 .47619 .23123 .46157 Mtetra
.547 .521 .778 r
.23123 .46157 .23725 .47619 .24701 .4762 .24101 .46125 Mtetra
.53 .507 .776 r
.24101 .46125 .24701 .4762 .25682 .47636 .25079 .4615 Mtetra
.513 .5 .779 r
.25079 .4615 .25682 .47636 .26669 .47649 .2606 .46226 Mtetra
.5 .502 .79 r
.2606 .46226 .26669 .47649 .27664 .47637 .27045 .46331 Mtetra
.489 .515 .811 r
.27045 .46331 .27664 .47637 .28668 .47575 .28035 .46447 Mtetra
.477 .544 .846 r
.28035 .46447 .28668 .47575 .29683 .47446 .29033 .46559 Mtetra
.455 .595 .902 r
.29033 .46559 .29683 .47446 .30708 .4723 .30039 .46649 Mtetra
.413 .681 .972 r
.30039 .46649 .30708 .4723 .31745 .46906 .31055 .46684 Mtetra
.28 .744 .949 r
.31055 .46684 .31745 .46906 .32794 .4646 .32082 .46639 Mtetra
.033 0 0 r
.32082 .46639 .32794 .4646 .3385 .45939 .33119 .46535 Mtetra
.242 0 0 r
.33119 .46535 .3385 .45939 .34912 .45365 .34165 .46372 Mtetra
.308 0 .041 r
.34165 .46372 .34912 .45365 .3598 .44706 .35221 .46109 Mtetra
.334 0 .148 r
.35221 .46109 .3598 .44706 .37055 .43976 .36288 .45736 Mtetra
.366 .008 .219 r
.36288 .45736 .37055 .43976 .38128 .43323 .3736 .45323 Mtetra
.385 .042 .255 r
.3736 .45323 .38128 .43323 .39196 .4282 .38437 .449 Mtetra
.374 .037 .259 r
.38437 .449 .39196 .4282 .40265 .42414 .3952 .44407 Mtetra
.362 .021 .245 r
.3952 .44407 .40265 .42414 .41332 .42143 .40608 .43895 Mtetra
.427 .066 .247 r
.40608 .43895 .41332 .42143 .42393 .42235 .41688 .43698 Mtetra
.505 .12 .243 r
.41688 .43698 .42393 .42235 .43451 .42689 .42763 .43865 Mtetra
.519 .107 .199 r
.42763 .43865 .43451 .42689 .44518 .43213 .43843 .4412 Mtetra
.47 .022 .104 r
.43843 .4412 .44518 .43213 .45598 .43555 .44935 .44264 Mtetra
.156 0 0 r
.44935 .44264 .45598 .43555 .467 .43193 .46044 .43901 Mtetra
0 0 0 r
.46044 .43901 .467 .43193 .47816 .42126 .47166 .4303 Mtetra
.47166 .4303 .47816 .42126 .48935 .40874 .48291 .42044 Mtetra
.034 0 0 r
.48291 .42044 .48935 .40874 .50051 .39689 .49415 .41146 Mtetra
.293 0 .143 r
.49415 .41146 .50051 .39689 .51165 .38865 .50539 .40613 Mtetra
.424 .061 .243 r
.50539 .40613 .51165 .38865 .52279 .38407 .51664 .40396 Mtetra
.434 .086 .274 r
.51664 .40396 .52279 .38407 .53398 .38085 .52796 .40161 Mtetra
.424 .082 .279 r
.52796 .40161 .53398 .38085 .54523 .37861 .53932 .39856 Mtetra
.417 .071 .268 r
.53932 .39856 .54523 .37861 .55655 .37789 .55074 .39541 Mtetra
.39 .03 .23 r
.55074 .39541 .55655 .37789 .56794 .37797 .56221 .39185 Mtetra
.311 0 .14 r
.56221 .39185 .56794 .37797 .5794 .37734 .57371 .38716 Mtetra
.164 0 0 r
.57371 .38716 .5794 .37734 .59092 .37586 .58523 .38145 Mtetra
0 0 0 r
.58523 .38145 .59092 .37586 .60248 .37384 .59677 .37514 Mtetra
.562 .933 .811 r
.59677 .37514 .60248 .37384 .61408 .37105 .60833 .3682 Mtetra
.78 .934 .932 r
.60833 .3682 .61408 .37105 .6257 .36701 .61989 .36043 Mtetra
.785 .81 .873 r
.61989 .36043 .6257 .36701 .63733 .36187 .63145 .35208 Mtetra
.758 .722 .819 r
.63145 .35208 .63733 .36187 .64896 .35581 .64301 .34349 Mtetra
.735 .667 .784 r
.64301 .34349 .64896 .35581 .6606 .34905 .65459 .33483 Mtetra
.718 .633 .762 r
.65459 .33483 .6606 .34905 .67224 .34177 .66619 .32627 Mtetra
.704 .611 .751 r
.66619 .32627 .67224 .34177 .68389 .33421 .67781 .318 Mtetra
.691 .597 .746 r
.67781 .318 .68389 .33421 .69556 .32661 .68948 .31022 Mtetra
.681 .59 .748 r
.68948 .31022 .69556 .32661 .70726 .31915 .70121 .30303 Mtetra
.671 .588 .754 r
.70121 .30303 .70726 .31915 .71901 .31207 .713 .29657 Mtetra
.662 .591 .765 r
.713 .29657 .71901 .31207 .73082 .3054 .72487 .29078 Mtetra
.654 .598 .78 r
.72487 .29078 .73082 .3054 .74269 .29924 .73683 .28567 Mtetra
.647 .61 .798 r
.73683 .28567 .74269 .29924 .75463 .29354 .74887 .28112 Mtetra
.641 .626 .82 r
.74887 .28112 .75463 .29354 .76664 .28828 .76099 .27705 Mtetra
.636 .647 .844 r
.76099 .27705 .76664 .28828 .77872 .28334 .7732 .27334 Mtetra
.633 .673 .871 r
.7732 .27334 .77872 .28334 .79087 .27864 .78548 .26984 Mtetra
.63 .704 .899 r
.78548 .26984 .79087 .27864 .80308 .27409 .79782 .26643 Mtetra
.712 .763 .892 r
.14569 .47843 .15266 .48451 .16247 .48051 .15562 .47353 Mtetra
.705 .736 .875 r
.15562 .47353 .16247 .48051 .1723 .47659 .16558 .46868 Mtetra
.695 .709 .858 r
.16558 .46868 .1723 .47659 .18215 .4729 .17554 .46396 Mtetra
.682 .681 .842 r
.17554 .46396 .18215 .4729 .19199 .46953 .18551 .45947 Mtetra
.667 .652 .826 r
.18551 .45947 .19199 .46953 .20182 .46664 .19548 .45531 Mtetra
.649 .622 .809 r
.19548 .45531 .20182 .46664 .21164 .46429 .20543 .45157 Mtetra
.631 .591 .791 r
.20543 .45157 .21164 .46429 .22144 .4626 .21538 .44831 Mtetra
.612 .561 .772 r
.21538 .44831 .22144 .4626 .23123 .46157 .22532 .44558 Mtetra
.594 .531 .754 r
.22532 .44558 .23123 .46157 .24101 .46125 .23524 .44341 Mtetra
.578 .504 .735 r
.23524 .44341 .24101 .46125 .25079 .4615 .24517 .44178 Mtetra
.564 .48 .719 r
.24517 .44178 .25079 .4615 .2606 .46226 .2551 .44067 Mtetra
.554 .461 .704 r
.2551 .44067 .2606 .46226 .27045 .46331 .26505 .43999 Mtetra
.547 .447 .692 r
.26505 .43999 .27045 .46331 .28035 .46447 .27503 .43964 Mtetra
.541 .435 .682 r
.27503 .43964 .28035 .46447 .29033 .46559 .28505 .43962 Mtetra
.536 .426 .676 r
.28505 .43962 .29033 .46559 .30039 .46649 .2951 .4399 Mtetra
.535 .423 .673 r
.2951 .4399 .30039 .46649 .31055 .46684 .30522 .44021 Mtetra
.538 .425 .673 r
.30522 .44021 .31055 .46684 .32082 .46639 .31541 .44035 Mtetra
.54 .43 .677 r
.31541 .44035 .32082 .46639 .33119 .46535 .32567 .44037 Mtetra
.544 .438 .684 r
.32567 .44037 .33119 .46535 .34165 .46372 .33601 .44018 Mtetra
.554 .453 .693 r
.33601 .44018 .34165 .46372 .35221 .46109 .34643 .43944 Mtetra
.57 .475 .707 r
.34643 .43944 .35221 .46109 .36288 .45736 .35696 .43789 Mtetra
.592 .504 .724 r
.35696 .43789 .36288 .45736 .3736 .45323 .3676 .43534 Mtetra
.619 .534 .736 r
.3676 .43534 .3736 .45323 .38437 .449 .37833 .43159 Mtetra
.655 .558 .734 r
.37833 .43159 .38437 .449 .3952 .44407 .38919 .42585 Mtetra
.675 .563 .721 r
.38919 .42585 .3952 .44407 .40608 .43895 .40014 .41848 Mtetra
.645 .53 .708 r
.40014 .41848 .40608 .43895 .41688 .43698 .41107 .41246 Mtetra
.601 .479 .686 r
.41107 .41246 .41688 .43698 .42763 .43865 .42195 .40864 Mtetra
.579 .442 .659 r
.42195 .40864 .42763 .43865 .43843 .4412 .43284 .40571 Mtetra
.57 .42 .639 r
.43284 .40571 .43843 .4412 .44935 .44264 .44378 .403 Mtetra
.576 .415 .627 r
.44378 .403 .44935 .44264 .46044 .43901 .4548 .39931 Mtetra
.584 .421 .627 r
.4548 .39931 .46044 .43901 .47166 .4303 .46587 .39464 Mtetra
.588 .432 .638 r
.46587 .39464 .47166 .4303 .48291 .42044 .47698 .3902 Mtetra
.586 .447 .659 r
.47698 .3902 .48291 .42044 .49415 .41146 .48812 .38663 Mtetra
.562 .454 .689 r
.48812 .38663 .49415 .41146 .50539 .40613 .49929 .38529 Mtetra
.539 .465 .721 r
.49929 .38529 .50539 .40613 .51664 .40396 .51052 .38533 Mtetra
.574 .505 .74 r
.51052 .38533 .51664 .40396 .52796 .40161 .52182 .38371 Mtetra
.614 .535 .742 r
.52182 .38371 .52796 .40161 .53932 .39856 .53317 .3801 Mtetra
.634 .542 .733 r
.53317 .3801 .53932 .39856 .55074 .39541 .54457 .37526 Mtetra
.643 .534 .716 r
.54457 .37526 .55074 .39541 .56221 .39185 .556 .36941 Mtetra
.645 .521 .697 r
.556 .36941 .56221 .39185 .57371 .38716 .56745 .36272 Mtetra
.644 .51 .684 r
.56745 .36272 .57371 .38716 .58523 .38145 .57892 .35545 Mtetra
.641 .501 .676 r
.57892 .35545 .58523 .38145 .59677 .37514 .5904 .34797 Mtetra
.639 .494 .67 r
.5904 .34797 .59677 .37514 .60833 .3682 .60191 .34033 Mtetra
.638 .491 .666 r
.60191 .34033 .60833 .3682 .61989 .36043 .61343 .33252 Mtetra
.61343 .33252 .61989 .36043 .63145 .35208 .62497 .32471 Mtetra
.636 .492 .669 r
.62497 .32471 .63145 .35208 .64301 .34349 .63654 .3172 Mtetra
.636 .496 .675 r
.63654 .3172 .64301 .34349 .65459 .33483 .64815 .31002 Mtetra
.637 .504 .684 r
.64815 .31002 .65459 .33483 .66619 .32627 .65979 .30317 Mtetra
.638 .513 .695 r
.65979 .30317 .66619 .32627 .67781 .318 .67149 .29674 Mtetra
.637 .525 .709 r
.67149 .29674 .67781 .318 .68948 .31022 .68324 .29085 Mtetra
.636 .538 .726 r
.68324 .29085 .68948 .31022 .70121 .30303 .69506 .2855 Mtetra
.634 .553 .746 r
.69506 .2855 .70121 .30303 .713 .29657 .70696 .28073 Mtetra
.631 .57 .768 r
.70696 .28073 .713 .29657 .72487 .29078 .71893 .2765 Mtetra
.626 .588 .792 r
.71893 .2765 .72487 .29078 .73683 .28567 .73099 .27278 Mtetra
.62 .607 .816 r
.73099 .27278 .73683 .28567 .74887 .28112 .74314 .26947 Mtetra
.613 .628 .841 r
.74314 .26947 .74887 .28112 .76099 .27705 .75537 .26652 Mtetra
.607 .649 .866 r
.75537 .26652 .76099 .27705 .7732 .27334 .76768 .26382 Mtetra
.602 .672 .89 r
.76768 .26382 .7732 .27334 .78548 .26984 .78007 .26125 Mtetra
.597 .697 .913 r
.78007 .26125 .78548 .26984 .79782 .26643 .79252 .25872 Mtetra
.724 .764 .885 r
.13868 .4723 .14569 .47843 .15562 .47353 .14868 .46696 Mtetra
.722 .752 .876 r
.14868 .46696 .15562 .47353 .16558 .46868 .15871 .46159 Mtetra
.718 .737 .866 r
.15871 .46159 .16558 .46868 .17554 .46396 .16876 .45622 Mtetra
.712 .719 .855 r
.16876 .45622 .17554 .46396 .18551 .45947 .17884 .4509 Mtetra
.703 .698 .842 r
.17884 .4509 .18551 .45947 .19548 .45531 .18893 .44567 Mtetra
.693 .671 .825 r
.18893 .44567 .19548 .45531 .20543 .45157 .19904 .44054 Mtetra
.681 .641 .804 r
.19904 .44054 .20543 .45157 .21538 .44831 .20916 .43552 Mtetra
.666 .608 .78 r
.20916 .43552 .21538 .44831 .22532 .44558 .21929 .43065 Mtetra
.651 .574 .755 r
.21929 .43065 .22532 .44558 .23524 .44341 .22944 .42596 Mtetra
.635 .541 .731 r
.22944 .42596 .23524 .44341 .24517 .44178 .2396 .4215 Mtetra
.619 .51 .708 r
.2396 .4215 .24517 .44178 .2551 .44067 .24977 .41733 Mtetra
.605 .484 .687 r
.24977 .41733 .2551 .44067 .26505 .43999 .25994 .41347 Mtetra
.593 .461 .67 r
.25994 .41347 .26505 .43999 .27503 .43964 .27013 .40994 Mtetra
.581 .441 .655 r
.27013 .40994 .27503 .43964 .28505 .43962 .28031 .40692 Mtetra
.569 .424 .644 r
.28031 .40692 .28505 .43962 .2951 .4399 .29049 .40451 Mtetra
.561 .411 .635 r
.29049 .40451 .2951 .4399 .30522 .44021 .30069 .40258 Mtetra
.554 .401 .628 r
.30069 .40258 .30522 .44021 .31541 .44035 .31091 .40108 Mtetra
.549 .394 .623 r
.31091 .40108 .31541 .44035 .32567 .44037 .32115 .39994 Mtetra
.546 .39 .621 r
.32115 .39994 .32567 .44037 .33601 .44018 .33144 .39909 Mtetra
.544 .388 .619 r
.33144 .39909 .33601 .44018 .34643 .43944 .34177 .39838 Mtetra
.546 .389 .62 r
.34177 .39838 .34643 .43944 .35696 .43789 .35217 .39753 Mtetra
.556 .398 .622 r
.35217 .39753 .35696 .43789 .3676 .43534 .36268 .39572 Mtetra
.572 .411 .624 r
.36268 .39572 .3676 .43534 .37833 .43159 .37332 .39233 Mtetra
.596 .429 .626 r
.37332 .39233 .37833 .43159 .38919 .42585 .38411 .38644 Mtetra
.618 .444 .625 r
.38411 .38644 .38919 .42585 .40014 .41848 .39503 .37799 Mtetra
.622 .445 .622 r
.39503 .37799 .40014 .41848 .41107 .41246 .406 .36873 Mtetra
.615 .435 .615 r
.406 .36873 .41107 .41246 .42195 .40864 .41696 .35959 Mtetra
.602 .418 .605 r
.41696 .35959 .42195 .40864 .43284 .40571 .42791 .35106 Mtetra
.586 .4 .596 r
.42791 .35106 .43284 .40571 .44378 .403 .43883 .344 Mtetra
.56 .377 .59 r
.43883 .344 .44378 .403 .4548 .39931 .4497 .34024 Mtetra
.537 .36 .589 r
.4497 .34024 .4548 .39931 .46587 .39464 .46054 .33979 Mtetra
.527 .357 .594 r
.46054 .33979 .46587 .39464 .47698 .3902 .47142 .34082 Mtetra
.521 .359 .603 r
.47142 .34082 .47698 .3902 .48812 .38663 .48237 .34248 Mtetra
.519 .366 .613 r
.48237 .34248 .48812 .38663 .49929 .38529 .4934 .34429 Mtetra
.526 .377 .622 r
.4934 .34429 .49929 .38529 .51052 .38533 .50452 .3453 Mtetra
.553 .398 .625 r
.50452 .3453 .51052 .38533 .52182 .38371 .51573 .34373 Mtetra
.577 .415 .626 r
.51573 .34373 .52182 .38371 .53317 .3801 .527 .33963 Mtetra
.591 .424 .624 r
.527 .33963 .53317 .3801 .54457 .37526 .53831 .33393 Mtetra
.598 .427 .622 r
.53831 .33393 .54457 .37526 .556 .36941 .54964 .32724 Mtetra
.598 .426 .62 r
.54964 .32724 .556 .36941 .56745 .36272 .561 .32042 Mtetra
.596 .425 .62 r
.561 .32042 .56745 .36272 .57892 .35545 .57239 .31371 Mtetra
.595 .424 .621 r
.57239 .31371 .57892 .35545 .5904 .34797 .58381 .30729 Mtetra
.593 .425 .624 r
.58381 .30729 .5904 .34797 .60191 .34033 .59526 .30123 Mtetra
.592 .427 .628 r
.59526 .30123 .60191 .34033 .61343 .33252 .60676 .2956 Mtetra
.59 .431 .634 r
.60676 .2956 .61343 .33252 .62497 .32471 .61831 .29045 Mtetra
.588 .437 .643 r
.61831 .29045 .62497 .32471 .63654 .3172 .62992 .28593 Mtetra
.587 .445 .655 r
.62992 .28593 .63654 .3172 .64815 .31002 .6416 .28192 Mtetra
.588 .458 .67 r
.6416 .28192 .64815 .31002 .65979 .30317 .65334 .27826 Mtetra
.59 .474 .689 r
.65334 .27826 .65979 .30317 .67149 .29674 .66514 .27492 Mtetra
.592 .493 .711 r
.66514 .27492 .67149 .29674 .68324 .29085 .67702 .27187 Mtetra
.593 .517 .737 r
.67702 .27187 .68324 .29085 .69506 .2855 .68897 .26906 Mtetra
.595 .544 .767 r
.68897 .26906 .69506 .2855 .70696 .28073 .70099 .26644 Mtetra
.596 .572 .798 r
.70099 .26644 .70696 .28073 .71893 .2765 .71308 .26397 Mtetra
.595 .601 .828 r
.71308 .26397 .71893 .2765 .73099 .27278 .72525 .26162 Mtetra
.592 .628 .856 r
.72525 .26162 .73099 .27278 .74314 .26947 .73749 .25938 Mtetra
.588 .651 .879 r
.73749 .25938 .74314 .26947 .75537 .26652 .7498 .25724 Mtetra
.583 .67 .899 r
.7498 .25724 .75537 .26652 .76768 .26382 .76219 .25515 Mtetra
.58 .687 .914 r
.76219 .25515 .76768 .26382 .78007 .26125 .77465 .25306 Mtetra
.577 .701 .927 r
.77465 .25306 .78007 .26125 .79252 .25872 .78718 .25095 Mtetra
.717 .763 .889 r
.13161 .46613 .13868 .4723 .14868 .46696 .14161 .46103 Mtetra
.722 .772 .893 r
.14161 .46103 .14868 .46696 .15871 .46159 .15165 .45579 Mtetra
.727 .778 .893 r
.15165 .45579 .15871 .46159 .16876 .45622 .16173 .45039 Mtetra
.732 .779 .89 r
.16173 .45039 .16876 .45622 .17884 .4509 .17186 .44479 Mtetra
.737 .771 .88 r
.17186 .44479 .17884 .4509 .18893 .44567 .18204 .43892 Mtetra
.739 .754 .864 r
.18204 .43892 .18893 .44567 .19904 .44054 .19227 .43278 Mtetra
.737 .728 .843 r
.19227 .43278 .19904 .44054 .20916 .43552 .20255 .42634 Mtetra
.728 .694 .818 r
.20255 .42634 .20916 .43552 .21929 .43065 .21287 .41972 Mtetra
.715 .658 .792 r
.21287 .41972 .21929 .43065 .22944 .42596 .22322 .41298 Mtetra
.697 .621 .767 r
.22322 .41298 .22944 .42596 .2396 .4215 .23358 .40636 Mtetra
.678 .587 .746 r
.23358 .40636 .2396 .4215 .24977 .41733 .24393 .40005 Mtetra
.659 .556 .728 r
.24393 .40005 .24977 .41733 .25994 .41347 .25426 .39416 Mtetra
.641 .53 .713 r
.25426 .39416 .25994 .41347 .27013 .40994 .26458 .38883 Mtetra
.623 .507 .701 r
.26458 .38883 .27013 .40994 .28031 .40692 .27486 .38421 Mtetra
.605 .487 .692 r
.27486 .38421 .28031 .40692 .29049 .40451 .28512 .38043 Mtetra
.591 .471 .684 r
.28512 .38043 .29049 .40451 .30069 .40258 .29536 .37733 Mtetra
.579 .458 .678 r
.29536 .37733 .30069 .40258 .31091 .40108 .3056 .37483 Mtetra
.57 .447 .673 r
.3056 .37483 .31091 .40108 .32115 .39994 .31586 .37281 Mtetra
.563 .439 .669 r
.31586 .37281 .32115 .39994 .33144 .39909 .32615 .3712 Mtetra
.555 .43 .665 r
.32615 .3712 .33144 .39909 .34177 .39838 .33646 .37009 Mtetra
.549 .425 .664 r
.33646 .37009 .34177 .39838 .35217 .39753 .3468 .36936 Mtetra
.555 .43 .665 r
.3468 .36936 .35217 .39753 .36268 .39572 .35722 .36821 Mtetra
.571 .444 .668 r
.35722 .36821 .36268 .39572 .37332 .39233 .36776 .36599 Mtetra
.601 .469 .673 r
.36776 .36599 .37332 .39233 .38411 .38644 .37844 .36178 Mtetra
.637 .5 .679 r
.37844 .36178 .38411 .38644 .39503 .37799 .38926 .35514 Mtetra
.67 .53 .684 r
.38926 .35514 .39503 .37799 .406 .36873 .40019 .34628 Mtetra
.69 .544 .683 r
.40019 .34628 .406 .36873 .41696 .35959 .41119 .33582 Mtetra
.685 .534 .675 r
.41119 .33582 .41696 .35959 .42791 .35106 .42219 .32516 Mtetra
.661 .509 .668 r
.42219 .32516 .42791 .35106 .43883 .344 .43314 .31601 Mtetra
.591 .456 .665 r
.43314 .31601 .43883 .344 .4497 .34024 .44396 .3122 Mtetra
.513 .403 .667 r
.44396 .3122 .4497 .34024 .46054 .33979 .4547 .31376 Mtetra
.483 .393 .678 r
.4547 .31376 .46054 .33979 .47142 .34082 .4655 .31684 Mtetra
.481 .404 .693 r
.4655 .31684 .47142 .34082 .48237 .34248 .47639 .31975 Mtetra
.512 .433 .703 r
.47639 .31975 .48237 .34248 .4934 .34429 .48739 .32106 Mtetra
.554 .457 .699 r
.48739 .32106 .4934 .34429 .50452 .3453 .49849 .32016 Mtetra
.59 .47 .684 r
.49849 .32016 .50452 .3453 .51573 .34373 .50967 .31681 Mtetra
.613 .476 .672 r
.50967 .31681 .51573 .34373 .527 .33963 .5209 .31144 Mtetra
.622 .477 .664 r
.5209 .31144 .527 .33963 .53831 .33393 .53216 .30498 Mtetra
.625 .477 .66 r
.53216 .30498 .53831 .33393 .54964 .32724 .54345 .29808 Mtetra
.62 .473 .66 r
.54345 .29808 .54964 .32724 .561 .32042 .55477 .29156 Mtetra
.615 .47 .662 r
.55477 .29156 .561 .32042 .57239 .31371 .56612 .28554 Mtetra
.612 .471 .666 r
.56612 .28554 .57239 .31371 .58381 .30729 .57752 .27993 Mtetra
.608 .472 .671 r
.57752 .27993 .58381 .30729 .59526 .30123 .58895 .27481 Mtetra
.602 .473 .676 r
.58895 .27481 .59526 .30123 .60676 .2956 .60044 .27029 Mtetra
.595 .474 .684 r
.60044 .27029 .60676 .2956 .61831 .29045 .612 .26646 Mtetra
.586 .475 .694 r
.612 .26646 .61831 .29045 .62992 .28593 .62363 .2635 Mtetra
.577 .479 .707 r
.62363 .2635 .62992 .28593 .6416 .28192 .63535 .26127 Mtetra
.569 .487 .723 r
.63535 .26127 .6416 .28192 .65334 .27826 .64715 .25962 Mtetra
.562 .5 .744 r
.64715 .25962 .65334 .27826 .66514 .27492 .65904 .2584 Mtetra
.555 .519 .77 r
.65904 .2584 .66514 .27492 .67702 .27187 .67102 .25751 Mtetra
.551 .546 .802 r
.67102 .25751 .67702 .27187 .68897 .26906 .68308 .25675 Mtetra
.55 .581 .838 r
.68308 .25675 .68897 .26906 .70099 .26644 .69521 .25588 Mtetra
.55 .619 .874 r
.69521 .25588 .70099 .26644 .71308 .26397 .70741 .25483 Mtetra
.554 .659 .906 r
.70741 .25483 .71308 .26397 .72525 .26162 .71967 .25347 Mtetra
.557 .691 .929 r
.71967 .25347 .72525 .26162 .73749 .25938 .73198 .25184 Mtetra
.563 .714 .943 r
.73198 .25184 .73749 .25938 .7498 .25724 .74435 .24994 Mtetra
.569 .726 .948 r
.74435 .24994 .7498 .25724 .76219 .25515 .75677 .24782 Mtetra
.576 .73 .947 r
.75677 .24782 .76219 .25515 .77465 .25306 .76926 .24553 Mtetra
.583 .727 .942 r
.76926 .24553 .77465 .25306 .78718 .25095 .7818 .24311 Mtetra
.693 .759 .903 r
.12449 .45992 .13161 .46613 .14161 .46103 .13442 .45556 Mtetra
.702 .786 .916 r
.13442 .45556 .14161 .46103 .15165 .45579 .14441 .45098 Mtetra
.715 .811 .924 r
.14441 .45098 .15165 .45579 .16173 .45039 .15447 .44607 Mtetra
.731 .83 .926 r
.15447 .44607 .16173 .45039 .17186 .44479 .1646 .44072 Mtetra
.75 .841 .92 r
.1646 .44072 .17186 .44479 .18204 .43892 .17482 .43479 Mtetra
.766 .84 .908 r
.17482 .43479 .18204 .43892 .19227 .43278 .18512 .4283 Mtetra
.779 .828 .89 r
.18512 .4283 .19227 .43278 .20255 .42634 .1955 .42119 Mtetra
.782 .807 .873 r
.1955 .42119 .20255 .42634 .21287 .41972 .20594 .4137 Mtetra
.779 .782 .856 r
.20594 .4137 .21287 .41972 .22322 .41298 .21641 .40599 Mtetra
.767 .755 .843 r
.21641 .40599 .22322 .41298 .23358 .40636 .22688 .39841 Mtetra
.749 .729 .834 r
.22688 .39841 .23358 .40636 .24393 .40005 .23733 .39127 Mtetra
.73 .707 .828 r
.23733 .39127 .24393 .40005 .25426 .39416 .24774 .3847 Mtetra
.709 .686 .826 r
.24774 .3847 .25426 .39416 .26458 .38883 .25811 .37884 Mtetra
.688 .669 .826 r
.25811 .37884 .26458 .38883 .27486 .38421 .26845 .37376 Mtetra
.664 .651 .827 r
.26845 .37376 .27486 .38421 .28512 .38043 .27875 .36949 Mtetra
.646 .634 .824 r
.27875 .36949 .28512 .38043 .29536 .37733 .28904 .36581 Mtetra
.631 .617 .818 r
.28904 .36581 .29536 .37733 .3056 .37483 .29935 .36257 Mtetra
.62 .6 .808 r
.29935 .36257 .3056 .37483 .31586 .37281 .30967 .35963 Mtetra
.61 .581 .796 r
.30967 .35963 .31586 .37281 .32615 .3712 .32002 .35693 Mtetra
.591 .556 .783 r
.32002 .35693 .32615 .3712 .33646 .37009 .33038 .35484 Mtetra
.571 .532 .773 r
.33038 .35484 .33646 .37009 .3468 .36936 .34075 .35347 Mtetra
.56 .518 .766 r
.34075 .35347 .3468 .36936 .35722 .36821 .35116 .35248 Mtetra
.559 .52 .769 r
.35116 .35248 .35722 .36821 .36776 .36599 .36162 .35154 Mtetra
.581 .549 .785 r
.36162 .35154 .36776 .36599 .37844 .36178 .37218 .34981 Mtetra
.627 .612 .816 r
.37218 .34981 .37844 .36178 .38926 .35514 .38286 .34659 Mtetra
.719 .721 .851 r
.38286 .34659 .38926 .35514 .40019 .34628 .39371 .34054 Mtetra
.805 .814 .859 r
.39371 .34054 .40019 .34628 .41119 .33582 .40469 .33165 Mtetra
.842 .862 .859 r
.40469 .33165 .41119 .33582 .42219 .32516 .41572 .32151 Mtetra
.834 .882 .878 r
.41572 .32151 .42219 .32516 .43314 .31601 .42673 .31205 Mtetra
.641 .852 .981 r
.42673 .31205 .43314 .31601 .44396 .3122 .43759 .30822 Mtetra
.148 .605 .929 r
.43759 .30822 .44396 .3122 .4547 .31376 .44836 .31003 Mtetra
.045 .543 .882 r
.44836 .31003 .4547 .31376 .4655 .31684 .45919 .31254 Mtetra
.232 .648 .958 r
.45919 .31254 .4655 .31684 .47639 .31975 .47013 .31382 Mtetra
.538 .744 .971 r
.47013 .31382 .47639 .31975 .48739 .32106 .48119 .31225 Mtetra
.671 .706 .874 r
.48119 .31225 .48739 .32106 .49849 .32016 .49235 .30783 Mtetra
.686 .64 .798 r
.49235 .30783 .49849 .32016 .50967 .31681 .50356 .3019 Mtetra
.683 .603 .76 r
.50356 .3019 .50967 .31681 .5209 .31144 .5148 .29518 Mtetra
.674 .584 .746 r
.5148 .29518 .5209 .31144 .53216 .30498 .52606 .28848 Mtetra
.666 .577 .746 r
.52606 .28848 .53216 .30498 .54345 .29808 .53736 .28217 Mtetra
.657 .579 .756 r
.53736 .28217 .54345 .29808 .55477 .29156 .54869 .27657 Mtetra
.65 .587 .77 r
.54869 .27657 .55477 .29156 .56612 .28554 .56006 .27159 Mtetra
.65 .601 .786 r
.56006 .27159 .56612 .28554 .57752 .27993 .57147 .26685 Mtetra
.648 .613 .801 r
.57147 .26685 .57752 .27993 .58895 .27481 .58293 .26242 Mtetra
.64 .621 .815 r
.58293 .26242 .58895 .27481 .60044 .27029 .59445 .25843 Mtetra
.626 .625 .829 r
.59445 .25843 .60044 .27029 .612 .26646 .60603 .25504 Mtetra
.603 .622 .844 r
.60603 .25504 .612 .26646 .62363 .2635 .6177 .25249 Mtetra
.577 .619 .857 r
.6177 .25249 .62363 .2635 .63535 .26127 .62944 .25073 Mtetra
.549 .616 .872 r
.62944 .25073 .63535 .26127 .64715 .25962 .64129 .24972 Mtetra
.522 .619 .89 r
.64129 .24972 .64715 .25962 .65904 .2584 .65323 .2493 Mtetra
.493 .626 .91 r
.65323 .2493 .65904 .2584 .67102 .25751 .66528 .24934 Mtetra
.47 .644 .933 r
.66528 .24934 .67102 .25751 .68308 .25675 .67741 .24953 Mtetra
.463 .673 .955 r
.67741 .24953 .68308 .25675 .69521 .25588 .68962 .2495 Mtetra
.463 .705 .973 r
.68962 .2495 .69521 .25588 .70741 .25483 .7019 .24909 Mtetra
.484 .741 .984 r
.7019 .24909 .70741 .25483 .71967 .25347 .71421 .24804 Mtetra
.509 .767 .989 r
.71421 .24804 .71967 .25347 .73198 .25184 .72657 .24641 Mtetra
.543 .784 .988 r
.72657 .24641 .73198 .25184 .74435 .24994 .73896 .24419 Mtetra
.573 .787 .98 r
.73896 .24419 .74435 .24994 .75677 .24782 .75139 .2415 Mtetra
.597 .778 .966 r
.75139 .2415 .75677 .24782 .76926 .24553 .76386 .23847 Mtetra
.614 .76 .949 r
.76386 .23847 .76926 .24553 .7818 .24311 .77637 .23521 Mtetra
.652 .75 .922 r
.11732 .45366 .12449 .45992 .13442 .45556 .12715 .45035 Mtetra
.662 .789 .942 r
.12715 .45035 .13442 .45556 .14441 .45098 .13704 .44675 Mtetra
.675 .828 .957 r
.13704 .44675 .14441 .45098 .15447 .44607 .14702 .44277 Mtetra
.69 .865 .965 r
.14702 .44277 .15447 .44607 .1646 .44072 .15708 .43831 Mtetra
.712 .898 .963 r
.15708 .43831 .1646 .44072 .17482 .43479 .16725 .4332 Mtetra
.725 .927 .958 r
.16725 .4332 .17482 .43479 .18512 .4283 .1775 .42756 Mtetra
.733 .951 .948 r
.1775 .42756 .18512 .4283 .1955 .42119 .18783 .42139 Mtetra
.718 .97 .932 r
.18783 .42139 .1955 .42119 .20594 .4137 .19821 .41499 Mtetra
.67 .973 .897 r
.19821 .41499 .20594 .4137 .21641 .40599 .20861 .40856 Mtetra
.564 .934 .815 r
.20861 .40856 .21641 .40599 .22688 .39841 .21901 .40233 Mtetra
.392 .825 .67 r
.21901 .40233 .22688 .39841 .23733 .39127 .22939 .39654 Mtetra
0 0 0 r
.22939 .39654 .23733 .39127 .24774 .3847 .23977 .39103 Mtetra
.23977 .39103 .24774 .3847 .25811 .37884 .25016 .38577 Mtetra
.25016 .38577 .25811 .37884 .26845 .37376 .26057 .38067 Mtetra
.26057 .38067 .26845 .37376 .27875 .36949 .27099 .37565 Mtetra
.27099 .37565 .27875 .36949 .28904 .36581 .28145 .37061 Mtetra
.28145 .37061 .28904 .36581 .29935 .36257 .29195 .36549 Mtetra
.386 .832 .715 r
.29195 .36549 .29935 .36257 .30967 .35963 .30248 .36029 Mtetra
.574 .94 .901 r
.30248 .36029 .30967 .35963 .32002 .35693 .31305 .3551 Mtetra
.651 .919 .977 r
.31305 .3551 .32002 .35693 .33038 .35484 .32361 .35047 Mtetra
.646 .831 .972 r
.32361 .35047 .33038 .35484 .34075 .35347 .33414 .3468 Mtetra
.597 .734 .94 r
.33414 .3468 .34075 .35347 .35116 .35248 .34464 .34445 Mtetra
.537 .666 .92 r
.34464 .34445 .35116 .35248 .36162 .35154 .35512 .3435 Mtetra
.492 .646 .926 r
.35512 .3435 .36162 .35154 .37218 .34981 .36562 .34335 Mtetra
.461 .687 .964 r
.36562 .34335 .37218 .34981 .38286 .34659 .37618 .34317 Mtetra
.56 .845 .997 r
.37618 .34317 .38286 .34659 .39371 .34054 .38693 .34042 Mtetra
.655 .962 .927 r
.38693 .34042 .39371 .34054 .40469 .33165 .39785 .33442 Mtetra
.617 .949 .773 r
.39785 .33442 .40469 .33165 .41572 .32151 .40888 .32633 Mtetra
.469 .841 .601 r
.40888 .32633 .41572 .32151 .42673 .31205 .41994 .31786 Mtetra
.049 0 0 r
.41994 .31786 .42673 .31205 .43759 .30822 .43087 .31401 Mtetra
.382 0 0 r
.43087 .31401 .43759 .30822 .44836 .31003 .44172 .31479 Mtetra
.33 0 0 r
.44172 .31479 .44836 .31003 .45919 .31254 .45266 .31521 Mtetra
.042 0 0 r
.45266 .31521 .45919 .31254 .47013 .31382 .46371 .31354 Mtetra
.56 .93 .923 r
.46371 .31354 .47013 .31382 .48119 .31225 .47487 .3086 Mtetra
.783 .897 .923 r
.47487 .3086 .48119 .31225 .49235 .30783 .48611 .30107 Mtetra
.768 .793 .874 r
.48611 .30107 .49235 .30783 .50356 .3019 .49737 .29348 Mtetra
.735 .741 .856 r
.49737 .29348 .50356 .3019 .5148 .29518 .50864 .2867 Mtetra
.698 .728 .873 r
.50864 .2867 .5148 .29518 .52606 .28848 .51993 .28133 Mtetra
.66 .754 .92 r
.51993 .28133 .52606 .28848 .53736 .28217 .53127 .27729 Mtetra
.599 .815 .983 r
.53127 .27729 .53736 .28217 .54869 .27657 .54266 .27422 Mtetra
.463 .847 .983 r
.54266 .27422 .54869 .27657 .56006 .27159 .5541 .27173 Mtetra
.259 .769 .818 r
.5541 .27173 .56006 .27159 .57147 .26685 .56561 .26925 Mtetra
0 0 0 r
.56561 .26925 .57147 .26685 .58293 .26242 .57717 .26669 Mtetra
.084 0 0 r
.57717 .26669 .58293 .26242 .59445 .25843 .58879 .26405 Mtetra
.161 0 0 r
.58879 .26405 .59445 .25843 .60603 .25504 .60048 .2614 Mtetra
.201 0 0 r
.60048 .2614 .60603 .25504 .6177 .25249 .61222 .25883 Mtetra
.211 0 0 r
.61222 .25883 .6177 .25249 .62944 .25073 .62403 .25643 Mtetra
.201 0 0 r
.62403 .25643 .62944 .25073 .64129 .24972 .63592 .25428 Mtetra
.167 0 0 r
.63592 .25428 .64129 .24972 .65323 .2493 .64788 .25243 Mtetra
.118 0 0 r
.64788 .25243 .65323 .2493 .66528 .24934 .65993 .25104 Mtetra
.033 0 0 r
.65993 .25104 .66528 .24934 .67741 .24953 .67207 .24986 Mtetra
.087 .646 .726 r
.67207 .24986 .67741 .24953 .68962 .2495 .68428 .24866 Mtetra
.217 .736 .855 r
.68428 .24866 .68962 .2495 .7019 .24909 .69655 .24722 Mtetra
.353 .807 .943 r
.69655 .24722 .7019 .24909 .71421 .24804 .70887 .24524 Mtetra
.46 .841 .986 r
.70887 .24524 .71421 .24804 .72657 .24641 .72122 .2427 Mtetra
.548 .854 .998 r
.72122 .2427 .72657 .24641 .73896 .24419 .7336 .2395 Mtetra
.605 .843 .989 r
.7336 .2395 .73896 .24419 .75139 .2415 .746 .23578 Mtetra
.639 .819 .969 r
.746 .23578 .75139 .2415 .76386 .23847 .75844 .23167 Mtetra
.657 .789 .944 r
.75844 .23167 .76386 .23847 .77637 .23521 .7709 .22725 Mtetra
.599 .736 .94 r
.1101 .44736 .11732 .45366 .12715 .45035 .11981 .44513 Mtetra
.605 .777 .963 r
.11981 .44513 .12715 .45035 .13704 .44675 .1296 .44261 Mtetra
.61 .819 .98 r
.1296 .44261 .13704 .44675 .14702 .44277 .13947 .43976 Mtetra
.612 .861 .99 r
.13947 .43976 .14702 .44277 .15708 .43831 .14942 .43653 Mtetra
.61 .901 .986 r
.14942 .43653 .15708 .43831 .16725 .4332 .15947 .4328 Mtetra
.569 .921 .957 r
.15947 .4328 .16725 .4332 .1775 .42756 .16959 .42877 Mtetra
.472 .894 .867 r
.16959 .42877 .1775 .42756 .18783 .42139 .17976 .42456 Mtetra
.28 .764 .67 r
.17976 .42456 .18783 .42139 .19821 .41499 .18996 .42039 Mtetra
0 0 0 r
.18996 .42039 .19821 .41499 .20861 .40856 .20017 .41652 Mtetra
.135 0 0 r
.20017 .41652 .20861 .40856 .21901 .40233 .21039 .41287 Mtetra
.247 0 0 r
.21039 .41287 .21901 .40233 .22939 .39654 .22062 .40947 Mtetra
.292 0 .084 r
.22062 .40947 .22939 .39654 .23977 .39103 .23092 .40586 Mtetra
.302 0 .126 r
.23092 .40586 .23977 .39103 .25016 .38577 .2413 .40172 Mtetra
.292 0 .139 r
.2413 .40172 .25016 .38577 .26057 .38067 .25178 .3969 Mtetra
.263 0 .128 r
.25178 .3969 .26057 .38067 .27099 .37565 .26236 .39122 Mtetra
.221 0 .096 r
.26236 .39122 .27099 .37565 .28145 .37061 .27302 .38486 Mtetra
.159 0 .04 r
.27302 .38486 .28145 .37061 .29195 .36549 .28375 .37789 Mtetra
.069 0 0 r
.28375 .37789 .29195 .36549 .30248 .36029 .29453 .37042 Mtetra
0 0 0 r
.29453 .37042 .30248 .36029 .31305 .3551 .30535 .36263 Mtetra
.30535 .36263 .31305 .3551 .32361 .35047 .31617 .35519 Mtetra
.31617 .35519 .32361 .35047 .33414 .3468 .32694 .34869 Mtetra
.377 .837 .773 r
.32694 .34869 .33414 .3468 .34464 .34445 .33762 .34428 Mtetra
.249 .76 .847 r
.33762 .34428 .34464 .34445 .35512 .3435 .34818 .34251 Mtetra
.019 .588 .776 r
.34818 .34251 .35512 .3435 .36562 .34335 .35868 .34307 Mtetra
.223 0 0 r
.35868 .34307 .36562 .34335 .37618 .34317 .36917 .34514 Mtetra
.188 0 0 r
.36917 .34514 .37618 .34317 .38693 .34042 .37983 .34542 Mtetra
.085 0 0 r
.37983 .34542 .38693 .34042 .39785 .33442 .39069 .34265 Mtetra
.056 0 0 r
.39069 .34265 .39785 .33442 .40888 .32633 .4017 .33729 Mtetra
.087 0 0 r
.4017 .33729 .40888 .32633 .41994 .31786 .4128 .33049 Mtetra
.29 0 .082 r
.4128 .33049 .41994 .31786 .43087 .31401 .42382 .32662 Mtetra
.405 0 .14 r
.42382 .32662 .43087 .31401 .44172 .31479 .43481 .32571 Mtetra
.326 0 .058 r
.43481 .32571 .44172 .31479 .45266 .31521 .4459 .32336 Mtetra
.095 0 0 r
.4459 .32336 .45266 .31521 .46371 .31354 .4571 .31841 Mtetra
0 0 0 r
.4571 .31841 .46371 .31354 .47487 .3086 .46839 .31038 Mtetra
.751 .993 .816 r
.46839 .31038 .47487 .3086 .48611 .30107 .47973 .30052 Mtetra
.771 .983 .906 r
.47973 .30052 .48611 .30107 .49737 .29348 .49106 .29217 Mtetra
.677 .953 .952 r
.49106 .29217 .49737 .29348 .50864 .2867 .50238 .28618 Mtetra
.417 .86 .908 r
.50238 .28618 .50864 .2867 .51993 .28133 .51373 .28284 Mtetra
.002 0 0 r
.51373 .28284 .51993 .28133 .53127 .27729 .52513 .28163 Mtetra
.263 0 0 r
.52513 .28163 .53127 .27729 .54266 .27422 .5366 .28139 Mtetra
.369 0 0 r
.5366 .28139 .54266 .27422 .5541 .27173 .54814 .28151 Mtetra
.398 0 .061 r
.54814 .28151 .5541 .27173 .56561 .26925 .55977 .28132 Mtetra
.407 0 .124 r
.55977 .28132 .56561 .26925 .57717 .26669 .57146 .28063 Mtetra
.405 .004 .161 r
.57146 .28063 .57717 .26669 .58879 .26405 .58322 .27932 Mtetra
.397 .009 .181 r
.58322 .27932 .58879 .26405 .60048 .2614 .59504 .27731 Mtetra
.379 0 .184 r
.59504 .27731 .60048 .2614 .61222 .25883 .6069 .27444 Mtetra
.357 0 .171 r
.6069 .27444 .61222 .25883 .62403 .25643 .61879 .27087 Mtetra
.326 0 .139 r
.61879 .27087 .62403 .25643 .63592 .25428 .63073 .26674 Mtetra
.286 0 .082 r
.63073 .26674 .63592 .25428 .64788 .25243 .64271 .26239 Mtetra
.241 0 0 r
.64271 .26239 .64788 .25243 .65993 .25104 .65475 .2583 Mtetra
.163 0 0 r
.65475 .2583 .65993 .25104 .67207 .24986 .66685 .25444 Mtetra
.044 0 0 r
.66685 .25444 .67207 .24986 .68428 .24866 .67902 .25088 Mtetra
0 0 0 r
.67902 .25088 .68428 .24866 .69655 .24722 .69126 .24737 Mtetra
.338 .819 .827 r
.69126 .24737 .69655 .24722 .70887 .24524 .70354 .24366 Mtetra
.497 .892 .95 r
.70354 .24366 .70887 .24524 .72122 .2427 .71586 .23964 Mtetra
.605 .901 .986 r
.71586 .23964 .72122 .2427 .7336 .2395 .72821 .2351 Mtetra
.659 .876 .98 r
.72821 .2351 .7336 .2395 .746 .23578 .74058 .23015 Mtetra
.687 .842 .958 r
.74058 .23015 .746 .23578 .75844 .23167 .75297 .22484 Mtetra
.7 .806 .931 r
.75297 .22484 .75844 .23167 .7709 .22725 .76539 .21923 Mtetra
.551 .72 .952 r
.10283 .44102 .1101 .44736 .11981 .44513 .11245 .43959 Mtetra
.552 .75 .969 r
.11245 .43959 .11981 .44513 .1296 .44261 .12215 .43795 Mtetra
.547 .782 .986 r
.12215 .43795 .1296 .44261 .13947 .43976 .13192 .43613 Mtetra
.531 .815 .998 r
.13192 .43613 .13947 .43976 .14942 .43653 .14175 .43413 Mtetra
.496 .845 .995 r
.14175 .43413 .14942 .43653 .15947 .4328 .15166 .43194 Mtetra
.394 .836 .94 r
.15166 .43194 .15947 .4328 .16959 .42877 .16161 .42976 Mtetra
.202 .729 .767 r
.16161 .42976 .16959 .42877 .17976 .42456 .17158 .42774 Mtetra
.028 0 0 r
.17158 .42774 .17976 .42456 .18996 .42039 .18158 .42595 Mtetra
.21 0 0 r
.18158 .42595 .18996 .42039 .20017 .41652 .1916 .4245 Mtetra
.296 0 0 r
.1916 .4245 .20017 .41652 .21039 .41287 .20167 .42306 Mtetra
.334 0 .039 r
.20167 .42306 .21039 .41287 .22062 .40947 .2118 .42142 Mtetra
.332 0 .081 r
.2118 .42142 .22062 .40947 .23092 .40586 .22206 .4191 Mtetra
.303 0 .091 r
.22206 .4191 .23092 .40586 .2413 .40172 .23246 .41568 Mtetra
.272 0 .088 r
.23246 .41568 .2413 .40172 .25178 .3969 .24299 .41131 Mtetra
.237 0 .078 r
.24299 .41131 .25178 .3969 .26236 .39122 .25363 .40598 Mtetra
.214 0 .072 r
.25363 .40598 .26236 .39122 .27302 .38486 .26436 .39997 Mtetra
.199 0 .071 r
.26436 .39997 .27302 .38486 .28375 .37789 .27515 .39344 Mtetra
.175 0 .068 r
.27515 .39344 .28375 .37789 .29453 .37042 .28603 .38615 Mtetra
.145 0 .056 r
.28603 .38615 .29453 .37042 .30535 .36263 .29698 .37809 Mtetra
.127 0 .043 r
.29698 .37809 .30535 .36263 .31617 .35519 .30796 .36978 Mtetra
.12 0 .025 r
.30796 .36978 .31617 .35519 .32694 .34869 .31893 .36179 Mtetra
.192 0 .032 r
.31893 .36179 .32694 .34869 .33762 .34428 .32978 .35595 Mtetra
.313 0 .066 r
.32978 .35595 .33762 .34428 .34818 .34251 .34048 .3532 Mtetra
.433 0 .111 r
.34048 .3532 .34818 .34251 .35868 .34307 .35106 .35361 Mtetra
.516 .083 .156 r
.35106 .35361 .35868 .34307 .36917 .34514 .36159 .35654 Mtetra
.488 .062 .157 r
.36159 .35654 .36917 .34514 .37983 .34542 .37224 .35847 Mtetra
.417 .007 .15 r
.37224 .35847 .37983 .34542 .39069 .34265 .3831 .35788 Mtetra
.348 0 .155 r
.3831 .35788 .39069 .34265 .4017 .33729 .39413 .35463 Mtetra
.306 0 .167 r
.39413 .35463 .4017 .33729 .4128 .33049 .40529 .34933 Mtetra
.367 .007 .214 r
.40529 .34933 .4128 .33049 .42382 .32662 .41643 .34546 Mtetra
.406 .042 .231 r
.41643 .34546 .42382 .32662 .43481 .32571 .42758 .34302 Mtetra
.335 0 .181 r
.42758 .34302 .43481 .32571 .4459 .32336 .43883 .33854 Mtetra
.203 0 .087 r
.43883 .33854 .4459 .32336 .4571 .31841 .4502 .33136 Mtetra
.012 0 0 r
.4502 .33136 .4571 .31841 .46839 .31038 .46164 .32164 Mtetra
0 0 0 r
.46164 .32164 .46839 .31038 .47973 .30052 .4731 .3109 Mtetra
.4731 .3109 .47973 .30052 .49106 .29217 .48452 .30268 Mtetra
.186 0 0 r
.48452 .30268 .49106 .29217 .50238 .28618 .49594 .29764 Mtetra
.352 0 .081 r
.49594 .29764 .50238 .28618 .51373 .28284 .50737 .29573 Mtetra
.441 .026 .155 r
.50737 .29573 .51373 .28284 .52513 .28163 .51887 .296 Mtetra
.46 .057 .189 r
.51887 .296 .52513 .28163 .5366 .28139 .53044 .29663 Mtetra
.457 .062 .201 r
.53044 .29663 .5366 .28139 .54814 .28151 .5421 .297 Mtetra
.439 .047 .197 r
.5421 .297 .54814 .28151 .55977 .28132 .55384 .2966 Mtetra
.417 .024 .184 r
.55384 .2966 .55977 .28132 .57146 .28063 .56564 .29544 Mtetra
.398 .003 .169 r
.56564 .29544 .57146 .28063 .58322 .27932 .57751 .29375 Mtetra
.375 0 .152 r
.57751 .29375 .58322 .27932 .59504 .27731 .58943 .29137 Mtetra
.34 0 .131 r
.58943 .29137 .59504 .27731 .6069 .27444 .60139 .28801 Mtetra
.3 0 .105 r
.60139 .28801 .6069 .27444 .61879 .27087 .61338 .28367 Mtetra
.244 0 .066 r
.61338 .28367 .61879 .27087 .63073 .26674 .62539 .27819 Mtetra
.182 0 .007 r
.62539 .27819 .63073 .26674 .64271 .26239 .63741 .272 Mtetra
.111 0 0 r
.63741 .272 .64271 .26239 .65475 .2583 .64946 .26559 Mtetra
.003 0 0 r
.64946 .26559 .65475 .2583 .66685 .25444 .66155 .25917 Mtetra
0 0 0 r
.66155 .25917 .66685 .25444 .67902 .25088 .67369 .25311 Mtetra
.335 .795 .671 r
.67369 .25311 .67902 .25088 .69126 .24737 .68588 .24727 Mtetra
.519 .917 .873 r
.68588 .24727 .69126 .24737 .70354 .24366 .69812 .24159 Mtetra
.632 .939 .961 r
.69812 .24159 .70354 .24366 .71586 .23964 .7104 .23591 Mtetra
.69 .91 .972 r
.7104 .23591 .71586 .23964 .72821 .2351 .72272 .23002 Mtetra
.713 .871 .956 r
.72272 .23002 .72821 .2351 .74058 .23015 .73506 .22394 Mtetra
.722 .836 .935 r
.73506 .22394 .74058 .23015 .75297 .22484 .74743 .21765 Mtetra
.727 .806 .914 r
.74743 .21765 .75297 .22484 .76539 .21923 .75983 .21113 Mtetra
.522 .709 .957 r
.09551 .43462 .10283 .44102 .11245 .43959 .10509 .43362 Mtetra
.52 .724 .966 r
.10509 .43362 .11245 .43959 .12215 .43795 .11473 .43252 Mtetra
.507 .74 .979 r
.11473 .43252 .12215 .43795 .13192 .43613 .12443 .43143 Mtetra
.478 .757 .992 r
.12443 .43143 .13192 .43613 .14175 .43413 .13416 .43043 Mtetra
.418 .769 .996 r
.13416 .43043 .14175 .43413 .15166 .43194 .14393 .42959 Mtetra
.294 .749 .954 r
.14393 .42959 .15166 .43194 .16161 .42976 .15372 .42905 Mtetra
.08 .637 .796 r
.15372 .42905 .16161 .42976 .17158 .42774 .16352 .42896 Mtetra
.125 0 0 r
.16352 .42896 .17158 .42774 .18158 .42595 .17335 .42912 Mtetra
.265 0 0 r
.17335 .42912 .18158 .42595 .1916 .4245 .18322 .42948 Mtetra
.306 0 0 r
.18322 .42948 .1916 .4245 .20167 .42306 .19319 .42949 Mtetra
.294 0 0 r
.19319 .42949 .20167 .42306 .2118 .42142 .2033 .42872 Mtetra
.245 0 0 r
.2033 .42872 .2118 .42142 .22206 .4191 .21357 .4269 Mtetra
.16 0 0 r
.21357 .4269 .22206 .4191 .23246 .41568 .22402 .4237 Mtetra
.108 0 0 r
.22402 .4237 .23246 .41568 .24299 .41131 .23458 .41971 Mtetra
.09 0 0 r
.23458 .41971 .24299 .41131 .25363 .40598 .24522 .41525 Mtetra
.116 0 0 r
.24522 .41525 .25363 .40598 .26436 .39997 .25592 .41058 Mtetra
.168 0 0 r
.25592 .41058 .26436 .39997 .27515 .39344 .26665 .4059 Mtetra
.177 0 0 r
.26665 .4059 .27515 .39344 .28603 .38615 .27748 .40036 Mtetra
.162 0 .031 r
.27748 .40036 .28603 .38615 .29698 .37809 .28844 .39358 Mtetra
.147 0 .048 r
.28844 .39358 .29698 .37809 .30796 .36978 .29949 .38577 Mtetra
.134 0 .052 r
.29949 .38577 .30796 .36978 .31893 .36179 .3106 .37736 Mtetra
.206 0 .083 r
.3106 .37736 .31893 .36179 .32978 .35595 .32161 .37066 Mtetra
.316 0 .125 r
.32161 .37066 .32978 .35595 .34048 .3532 .33247 .3669 Mtetra
.426 .021 .165 r
.33247 .3669 .34048 .3532 .35106 .35361 .34318 .36652 Mtetra
.511 .099 .196 r
.34318 .36652 .35106 .35361 .36159 .35654 .3538 .36914 Mtetra
.502 .086 .184 r
.3538 .36914 .36159 .35654 .37224 .35847 .36452 .3715 Mtetra
.45 .037 .163 r
.36452 .3715 .37224 .35847 .3831 .35788 .37541 .37204 Mtetra
.381 0 .147 r
.37541 .37204 .3831 .35788 .39413 .35463 .38648 .37018 Mtetra
.319 0 .14 r
.38648 .37018 .39413 .35463 .40529 .34933 .39769 .36608 Mtetra
.342 0 .17 r
.39769 .36608 .40529 .34933 .41643 .34546 .40895 .3622 Mtetra
.35 0 .173 r
.40895 .3622 .41643 .34546 .42758 .34302 .42024 .35854 Mtetra
.254 0 .11 r
.42024 .35854 .42758 .34302 .43883 .33854 .43165 .35264 Mtetra
.116 0 .019 r
.43165 .35264 .43883 .33854 .4502 .33136 .44316 .34431 Mtetra
0 0 0 r
.44316 .34431 .4502 .33136 .46164 .32164 .45472 .33413 Mtetra
.45472 .33413 .46164 .32164 .4731 .3109 .46629 .32366 Mtetra
.126 0 0 r
.46629 .32366 .4731 .3109 .48452 .30268 .47782 .31621 Mtetra
.298 0 .096 r
.47782 .31621 .48452 .30268 .49594 .29764 .48933 .31217 Mtetra
.411 .011 .167 r
.48933 .31217 .49594 .29764 .50737 .29573 .50087 .31111 Mtetra
.463 .067 .203 r
.50087 .31111 .50737 .29573 .51887 .296 .51247 .3118 Mtetra
.45 .058 .203 r
.51247 .3118 .51887 .296 .53044 .29663 .52415 .31189 Mtetra
.419 .024 .181 r
.52415 .31189 .53044 .29663 .5421 .297 .53592 .31095 Mtetra
.37 0 .136 r
.53592 .31095 .5421 .297 .55384 .2966 .54775 .30874 Mtetra
.315 0 .073 r
.54775 .30874 .55384 .2966 .56564 .29544 .55963 .30566 Mtetra
.277 0 .003 r
.55963 .30566 .56564 .29544 .57751 .29375 .57157 .30256 Mtetra
.231 0 0 r
.57157 .30256 .57751 .29375 .58943 .29137 .58357 .29926 Mtetra
.175 0 0 r
.58357 .29926 .58943 .29137 .60139 .28801 .59562 .29547 Mtetra
.11 0 0 r
.59562 .29547 .60139 .28801 .61338 .28367 .6077 .29086 Mtetra
.008 0 0 r
.6077 .29086 .61338 .28367 .62539 .27819 .61978 .28483 Mtetra
0 0 0 r
.61978 .28483 .62539 .27819 .63741 .272 .63187 .2777 Mtetra
.63187 .2777 .63741 .272 .64946 .26559 .64396 .26975 Mtetra
.64396 .26975 .64946 .26559 .66155 .25917 .65605 .26142 Mtetra
.516 .895 .715 r
.65605 .26142 .66155 .25917 .67369 .25311 .66818 .25328 Mtetra
.649 .969 .859 r
.66818 .25328 .67369 .25311 .68588 .24727 .68034 .24539 Mtetra
.717 .967 .936 r
.68034 .24539 .68588 .24727 .69812 .24159 .69255 .23795 Mtetra
.741 .926 .952 r
.69255 .23795 .69812 .24159 .7104 .23591 .70481 .2308 Mtetra
.745 .879 .941 r
.70481 .2308 .7104 .23591 .72272 .23002 .71711 .22382 Mtetra
.741 .842 .926 r
.71711 .22382 .72272 .23002 .73506 .22394 .72945 .21691 Mtetra
.739 .815 .912 r
.72945 .21691 .73506 .22394 .74743 .21765 .74182 .21 Mtetra
.738 .797 .899 r
.74182 .21 .74743 .21765 .75983 .21113 .75422 .20298 Mtetra
.531 .713 .955 r
.08813 .42819 .09551 .43462 .10509 .43362 .09774 .42702 Mtetra
.529 .707 .953 r
.09774 .42702 .10509 .43362 .11473 .43252 .1074 .42593 Mtetra
.516 .703 .955 r
.1074 .42593 .11473 .43252 .12443 .43143 .11709 .42501 Mtetra
.49 .7 .962 r
.11709 .42501 .12443 .43143 .13416 .43043 .12679 .42439 Mtetra
.443 .694 .972 r
.12679 .42439 .13416 .43043 .14393 .42959 .13649 .42423 Mtetra
.377 .69 .981 r
.13649 .42423 .14393 .42959 .15372 .42905 .1462 .4245 Mtetra
.273 .668 .969 r
.1462 .4245 .15372 .42905 .16352 .42896 .15592 .42529 Mtetra
.2 .656 .944 r
.15592 .42529 .16352 .42896 .17335 .42912 .16569 .42616 Mtetra
.169 .658 .921 r
.16569 .42616 .17335 .42912 .18322 .42948 .17554 .42684 Mtetra
.249 .717 .945 r
.17554 .42684 .18322 .42948 .19319 .42949 .18555 .42675 Mtetra
.416 .804 .989 r
.18555 .42675 .19319 .42949 .2033 .42872 .19575 .42534 Mtetra
.556 .841 .998 r
.19575 .42534 .2033 .42872 .21357 .4269 .20613 .42271 Mtetra
.653 .841 .972 r
.20613 .42271 .21357 .4269 .22402 .4237 .21667 .4188 Mtetra
.673 .821 .954 r
.21667 .4188 .22402 .4237 .23458 .41971 .22728 .41458 Mtetra
.658 .81 .957 r
.22728 .41458 .23458 .41971 .24522 .41525 .23791 .41069 Mtetra
.627 .824 .976 r
.23791 .41069 .24522 .41525 .25592 .41058 .24853 .40729 Mtetra
.557 .848 .998 r
.24853 .40729 .25592 .41058 .26665 .4059 .25914 .40451 Mtetra
.535 .895 .974 r
.25914 .40451 .26665 .4059 .27748 .40036 .26986 .401 Mtetra
.544 .927 .9 r
.26986 .401 .27748 .40036 .28844 .39358 .28074 .39601 Mtetra
.553 .929 .807 r
.28074 .39601 .28844 .39358 .29949 .38577 .29176 .38944 Mtetra
.568 .923 .74 r
.29176 .38944 .29949 .38577 .3106 .37736 .30291 .38152 Mtetra
.426 .839 .66 r
.30291 .38152 .3106 .37736 .32161 .37066 .314 .37466 Mtetra
0 0 0 r
.314 .37466 .32161 .37066 .33247 .3669 .32496 .37018 Mtetra
.092 0 0 r
.32496 .37018 .33247 .3669 .34318 .36652 .33579 .36876 Mtetra
.308 0 0 r
.33579 .36876 .34318 .36652 .3538 .36914 .34651 .37028 Mtetra
.265 0 0 r
.34651 .37028 .3538 .36914 .36452 .3715 .3573 .37195 Mtetra
.094 0 0 r
.3573 .37195 .36452 .3715 .37541 .37204 .36824 .37244 Mtetra
.142 .687 .762 r
.36824 .37244 .37541 .37204 .38648 .37018 .37934 .37097 Mtetra
.341 .821 .823 r
.37934 .37097 .38648 .37018 .39769 .36608 .39059 .36747 Mtetra
.328 .81 .78 r
.39059 .36747 .39769 .36608 .40895 .3622 .4019 .36357 Mtetra
.369 .835 .795 r
.4019 .36357 .40895 .3622 .42024 .35854 .41328 .35927 Mtetra
.599 .951 .881 r
.41328 .35927 .42024 .35854 .43165 .35264 .42476 .35292 Mtetra
.739 .988 .892 r
.42476 .35292 .43165 .35264 .44316 .34431 .43633 .3446 Mtetra
.789 .993 .876 r
.43633 .3446 .44316 .34431 .45472 .33413 .44795 .33506 Mtetra
.758 .995 .857 r
.44795 .33506 .45472 .33413 .46629 .32366 .45958 .32567 Mtetra
.496 .899 .781 r
.45958 .32567 .46629 .32366 .47782 .31621 .47116 .31922 Mtetra
0 0 0 r
.47116 .31922 .47782 .31621 .48933 .31217 .48273 .31587 Mtetra
.169 0 0 r
.48273 .31587 .48933 .31217 .50087 .31111 .49433 .31492 Mtetra
.257 0 0 r
.49433 .31492 .50087 .31111 .51247 .3118 .506 .31507 Mtetra
.122 0 0 r
.506 .31507 .51247 .3118 .52415 .31189 .51775 .31385 Mtetra
0 0 0 r
.51775 .31385 .52415 .31189 .53592 .31095 .52957 .31104 Mtetra
.435 .875 .873 r
.52957 .31104 .53592 .31095 .54775 .30874 .54145 .30671 Mtetra
.618 .926 .971 r
.54145 .30671 .54775 .30874 .55963 .30566 .55337 .30163 Mtetra
.638 .873 .985 r
.55337 .30163 .55963 .30566 .57157 .30256 .56534 .29719 Mtetra
.632 .824 .974 r
.56534 .29719 .57157 .30256 .58357 .29926 .57737 .29323 Mtetra
.621 .798 .967 r
.57737 .29323 .58357 .29926 .59562 .29547 .58946 .28963 Mtetra
.634 .81 .968 r
.58946 .28963 .59562 .29547 .6077 .29086 .6016 .2857 Mtetra
.685 .853 .963 r
.6016 .2857 .6077 .29086 .61978 .28483 .61376 .28044 Mtetra
.729 .892 .954 r
.61376 .28044 .61978 .28483 .63187 .2777 .62592 .27392 Mtetra
.772 .921 .936 r
.62592 .27392 .63187 .2777 .64396 .26975 .63807 .26602 Mtetra
.797 .927 .921 r
.63807 .26602 .64396 .26975 .65605 .26142 .65021 .2573 Mtetra
.803 .917 .915 r
.65021 .2573 .65605 .26142 .66818 .25328 .66236 .24837 Mtetra
.801 .892 .909 r
.66236 .24837 .66818 .25328 .68034 .24539 .67453 .2395 Mtetra
.783 .86 .907 r
.67453 .2395 .68034 .24539 .69255 .23795 .68675 .23116 Mtetra
.767 .829 .9 r
.68675 .23116 .69255 .23795 .70481 .2308 .69901 .22325 Mtetra
.75 .802 .894 r
.69901 .22325 .70481 .2308 .71711 .22382 .71133 .2158 Mtetra
.739 .786 .891 r
.71133 .2158 .71711 .22382 .72945 .21691 .7237 .20865 Mtetra
.733 .778 .889 r
.7237 .20865 .72945 .21691 .74182 .21 .73612 .20167 Mtetra
.73 .777 .89 r
.73612 .20167 .74182 .21 .75422 .20298 .74857 .19475 Mtetra
.57 .726 .948 r
.0807 .4217 .08813 .42819 .09774 .42702 .09041 .41991 Mtetra
.563 .704 .935 r
.09041 .41991 .09774 .42702 .1074 .42593 .10014 .41831 Mtetra
.549 .683 .927 r
.10014 .41831 .1074 .42593 .11709 .42501 .10988 .41704 Mtetra
.526 .664 .924 r
.10988 .41704 .11709 .42501 .12679 .42439 .11962 .41621 Mtetra
.489 .642 .924 r
.11962 .41621 .12679 .42439 .13649 .42423 .12933 .41602 Mtetra
.459 .629 .926 r
.12933 .41602 .13649 .42423 .1462 .4245 .13905 .41628 Mtetra
.428 .614 .928 r
.13905 .41628 .1462 .4245 .15592 .42529 .14878 .41697 Mtetra
.442 .619 .926 r
.14878 .41697 .15592 .42529 .16569 .42616 .15859 .4175 Mtetra
.489 .631 .915 r
.15859 .4175 .16569 .42616 .17554 .42684 .16854 .41738 Mtetra
.554 .638 .888 r
.16854 .41738 .17554 .42684 .18555 .42675 .17867 .41616 Mtetra
.618 .639 .849 r
.17867 .41616 .18555 .42675 .19575 .42534 .18903 .4133 Mtetra
.645 .623 .814 r
.18903 .4133 .19575 .42534 .20613 .42271 .19954 .40931 Mtetra
.658 .608 .787 r
.19954 .40931 .20613 .42271 .21667 .4188 .21018 .40445 Mtetra
.645 .589 .777 r
.21018 .40445 .21667 .4188 .22728 .41458 .22082 .39995 Mtetra
.614 .571 .782 r
.22082 .39995 .22728 .41458 .23791 .41069 .23138 .39672 Mtetra
.584 .565 .798 r
.23138 .39672 .23791 .41069 .24853 .40729 .24188 .39467 Mtetra
.545 .568 .829 r
.24188 .39467 .24853 .40729 .25914 .40451 .25233 .39384 Mtetra
.563 .617 .865 r
.25233 .39384 .25914 .40451 .26986 .401 .26289 .39244 Mtetra
.624 .697 .897 r
.26289 .39244 .26986 .401 .28074 .39601 .27364 .3894 Mtetra
.699 .777 .912 r
.27364 .3894 .28074 .39601 .29176 .38944 .28458 .38437 Mtetra
.765 .837 .907 r
.28458 .38437 .29176 .38944 .30291 .38152 .2957 .37732 Mtetra
.76 .866 .927 r
.2957 .37732 .30291 .38152 .314 .37466 .30683 .37055 Mtetra
.703 .864 .958 r
.30683 .37055 .314 .37466 .32496 .37018 .31788 .36532 Mtetra
.588 .809 .984 r
.31788 .36532 .32496 .37018 .33579 .36876 .32882 .36248 Mtetra
.451 .702 .974 r
.32882 .36248 .33579 .36876 .34651 .37028 .33966 .36214 Mtetra
.465 .645 .936 r
.33966 .36214 .34651 .37028 .3573 .37195 .35056 .3622 Mtetra
.519 .625 .896 r
.35056 .3622 .3573 .37195 .36824 .37244 .36156 .36163 Mtetra
.579 .628 .865 r
.36156 .36163 .36824 .37244 .37934 .37097 .37269 .35973 Mtetra
.628 .642 .845 r
.37269 .35973 .37934 .37097 .39059 .36747 .38395 .3563 Mtetra
.642 .65 .843 r
.38395 .3563 .39059 .36747 .4019 .36357 .39528 .35237 Mtetra
.656 .656 .839 r
.39528 .35237 .4019 .36357 .41328 .35927 .40667 .34792 Mtetra
.692 .669 .823 r
.40667 .34792 .41328 .35927 .42476 .35292 .41817 .34195 Mtetra
.723 .689 .817 r
.41817 .34195 .42476 .35292 .43633 .3446 .42973 .33461 Mtetra
.744 .716 .826 r
.42973 .33461 .43633 .3446 .44795 .33506 .44134 .32664 Mtetra
.75 .755 .856 r
.44134 .32664 .44795 .33506 .45958 .32567 .45296 .31906 Mtetra
.691 .792 .927 r
.45296 .31906 .45958 .32567 .47116 .31922 .46456 .31398 Mtetra
.569 .799 .986 r
.46456 .31398 .47116 .31922 .48273 .31587 .47615 .31133 Mtetra
.438 .767 .997 r
.47615 .31133 .48273 .31587 .49433 .31492 .48779 .31024 Mtetra
.419 .753 .995 r
.48779 .31024 .49433 .31492 .506 .31507 .4995 .30945 Mtetra
.582 .793 .98 r
.4995 .30945 .506 .31507 .51775 .31385 .5113 .30661 Mtetra
.679 .774 .922 r
.5113 .30661 .51775 .31385 .52957 .31104 .52315 .30174 Mtetra
.718 .731 .861 r
.52315 .30174 .52957 .31104 .54145 .30671 .53505 .29519 Mtetra
.713 .683 .819 r
.53505 .29519 .54145 .30671 .55337 .30163 .54698 .28805 Mtetra
.673 .63 .799 r
.54698 .28805 .55337 .30163 .56534 .29719 .55894 .28215 Mtetra
.639 .593 .786 r
.55894 .28215 .56534 .29719 .57737 .29323 .57097 .27745 Mtetra
.607 .567 .783 r
.57097 .27745 .57737 .29323 .58946 .28963 .58307 .27405 Mtetra
.599 .565 .788 r
.58307 .27405 .58946 .28963 .6016 .2857 .59523 .27102 Mtetra
.623 .591 .797 r
.59523 .27102 .6016 .2857 .61376 .28044 .60744 .26709 Mtetra
.655 .629 .811 r
.60744 .26709 .61376 .28044 .62592 .27392 .61966 .26201 Mtetra
.702 .676 .822 r
.61966 .26201 .62592 .27392 .63807 .26602 .63188 .25521 Mtetra
.735 .712 .829 r
.63188 .25521 .63807 .26602 .65021 .2573 .64408 .24724 Mtetra
.755 .736 .835 r
.64408 .24724 .65021 .2573 .66236 .24837 .65629 .23861 Mtetra
.762 .746 .838 r
.65629 .23861 .66236 .24837 .67453 .2395 .6685 .22978 Mtetra
.754 .745 .844 r
.6685 .22978 .67453 .2395 .68675 .23116 .68075 .22138 Mtetra
.744 .741 .849 r
.68075 .22138 .68675 .23116 .69901 .22325 .69305 .21344 Mtetra
.729 .736 .857 r
.69305 .21344 .69901 .22325 .71133 .2158 .70542 .20614 Mtetra
.719 .737 .865 r
.70542 .20614 .71133 .2158 .7237 .20865 .71785 .1993 Mtetra
.713 .743 .875 r
.71785 .1993 .7237 .20865 .73612 .20167 .73033 .19278 Mtetra
.71 .755 .887 r
.73033 .19278 .73612 .20167 .74857 .19475 .74288 .18646 Mtetra
.626 .744 .932 r
.07322 .41517 .0807 .4217 .09041 .41991 .08309 .41229 Mtetra
.615 .707 .911 r
.08309 .41229 .09041 .41991 .10014 .41831 .09297 .40968 Mtetra
.6 .674 .892 r
.09297 .40968 .10014 .41831 .10988 .41704 .10284 .40743 Mtetra
.581 .642 .876 r
.10284 .40743 .10988 .41704 .11962 .41621 .1127 .40564 Mtetra
.555 .608 .861 r
.1127 .40564 .11962 .41621 .12933 .41602 .12253 .4045 Mtetra
.542 .582 .844 r
.12253 .4045 .12933 .41602 .13905 .41628 .13237 .40371 Mtetra
.534 .558 .826 r
.13237 .40371 .13905 .41628 .14878 .41697 .14224 .40317 Mtetra
.549 .545 .803 r
.14224 .40317 .14878 .41697 .15859 .4175 .1522 .40229 Mtetra
.574 .539 .778 r
.1522 .40229 .15859 .4175 .16854 .41738 .16232 .40055 Mtetra
.598 .533 .753 r
.16232 .40055 .16854 .41738 .17867 .41616 .17261 .39773 Mtetra
.622 .532 .732 r
.17261 .39773 .17867 .41616 .18903 .4133 .1831 .39347 Mtetra
.627 .524 .718 r
.1831 .39347 .18903 .4133 .19954 .40931 .19368 .38861 Mtetra
.625 .516 .711 r
.19368 .38861 .19954 .40931 .21018 .40445 .20431 .38368 Mtetra
.605 .504 .713 r
.20431 .38368 .21018 .40445 .22082 .39995 .21486 .37988 Mtetra
.565 .485 .724 r
.21486 .37988 .22082 .39995 .23138 .39672 .22526 .37818 Mtetra
.526 .476 .743 r
.22526 .37818 .23138 .39672 .24188 .39467 .23556 .37811 Mtetra
.478 .47 .771 r
.23556 .37811 .24188 .39467 .25233 .39384 .2458 .37948 Mtetra
.492 .511 .805 r
.2458 .37948 .25233 .39384 .26289 .39244 .25618 .38018 Mtetra
.56 .585 .836 r
.25618 .38018 .26289 .39244 .27364 .3894 .26679 .37888 Mtetra
.645 .659 .849 r
.26679 .37888 .27364 .3894 .28458 .38437 .27766 .37504 Mtetra
.722 .713 .841 r
.27766 .37504 .28458 .38437 .2957 .37732 .28877 .36845 Mtetra
.74 .729 .841 r
.28877 .36845 .2957 .37732 .30683 .37055 .29996 .3612 Mtetra
.724 .715 .841 r
.29996 .3612 .30683 .37055 .31788 .36532 .31113 .3545 Mtetra
.677 .668 .834 r
.31113 .3545 .31788 .36532 .32882 .36248 .32223 .34939 Mtetra
.615 .599 .812 r
.32223 .34939 .32882 .36248 .33966 .36214 .33324 .34622 Mtetra
.591 .547 .774 r
.33324 .34622 .33966 .36214 .35056 .3622 .34427 .34364 Mtetra
.586 .516 .743 r
.34427 .34364 .35056 .3622 .36156 .36163 .35536 .34101 Mtetra
.592 .502 .722 r
.35536 .34101 .36156 .36163 .37269 .35973 .36653 .33782 Mtetra
.601 .498 .71 r
.36653 .33782 .37269 .35973 .38395 .3563 .37779 .33393 Mtetra
.6 .495 .706 r
.37779 .33393 .38395 .3563 .39528 .35237 .3891 .32995 Mtetra
.602 .496 .706 r
.3891 .32995 .39528 .35237 .40667 .34792 .40045 .32588 Mtetra
.614 .507 .708 r
.40045 .32588 .40667 .34792 .41817 .34195 .41189 .32111 Mtetra
.628 .523 .717 r
.41189 .32111 .41817 .34195 .42973 .33461 .42338 .31577 Mtetra
.637 .545 .734 r
.42338 .31577 .42973 .33461 .44134 .32664 .43491 .31038 Mtetra
.637 .572 .765 r
.43491 .31038 .44134 .32664 .45296 .31906 .44647 .30557 Mtetra
.602 .593 .815 r
.44647 .30557 .45296 .31906 .46456 .31398 .45802 .30273 Mtetra
.55 .61 .866 r
.45802 .30273 .46456 .31398 .47615 .31133 .46961 .30149 Mtetra
.519 .63 .901 r
.46961 .30149 .47615 .31133 .48779 .31024 .48126 .30082 Mtetra
.545 .655 .908 r
.48126 .30082 .48779 .31024 .4995 .30945 .49299 .2995 Mtetra
.648 .688 .874 r
.49299 .2995 .4995 .30945 .5113 .30661 .50482 .29538 Mtetra
.706 .685 .827 r
.50482 .29538 .5113 .30661 .52315 .30174 .5167 .28867 Mtetra
.73 .664 .785 r
.5167 .28867 .52315 .30174 .53505 .29519 .52861 .2799 Mtetra
.723 .631 .755 r
.52861 .2799 .53505 .29519 .54698 .28805 .54054 .27044 Mtetra
.684 .587 .74 r
.54054 .27044 .54698 .28805 .55894 .28215 .55248 .26242 Mtetra
.646 .547 .728 r
.55248 .26242 .55894 .28215 .57097 .27745 .56448 .25608 Mtetra
.605 .51 .72 r
.56448 .25608 .57097 .27745 .58307 .27405 .57654 .25187 Mtetra
.582 .49 .716 r
.57654 .25187 .58307 .27405 .59523 .27102 .58868 .24883 Mtetra
.584 .491 .716 r
.58868 .24883 .59523 .27102 .60744 .26709 .60089 .24571 Mtetra
.596 .505 .722 r
.60089 .24571 .60744 .26709 .61966 .26201 .61314 .24198 Mtetra
.626 .534 .731 r
.61314 .24198 .61966 .26201 .63188 .25521 .6254 .23675 Mtetra
.652 .564 .743 r
.6254 .23675 .63188 .25521 .64408 .24724 .63767 .2304 Mtetra
.676 .594 .756 r
.63767 .2304 .64408 .24724 .65629 .23861 .64993 .22315 Mtetra
.691 .619 .77 r
.64993 .22315 .65629 .23861 .6685 .22978 .66222 .21552 Mtetra
.696 .637 .787 r
.66222 .21552 .6685 .22978 .68075 .22138 .67454 .20814 Mtetra
.696 .654 .804 r
.67454 .20814 .68075 .22138 .69305 .21344 .68692 .20112 Mtetra
.688 .667 .824 r
.68692 .20112 .69305 .21344 .70542 .20614 .69937 .19476 Mtetra
.683 .684 .844 r
.69937 .19476 .70542 .20614 .71785 .1993 .71189 .18887 Mtetra
.679 .704 .866 r
.71189 .18887 .71785 .1993 .73033 .19278 .72447 .18335 Mtetra
.676 .729 .89 r
.72447 .18335 .73033 .19278 .74288 .18646 .73713 .1781 Mtetra
.679 .757 .91 r
.06568 .40859 .07322 .41517 .08309 .41229 .07575 .4044 Mtetra
.664 .716 .887 r
.07575 .4044 .08309 .41229 .09297 .40968 .08581 .40051 Mtetra
.647 .678 .866 r
.08581 .40051 .09297 .40968 .10284 .40743 .09586 .39696 Mtetra
.629 .642 .845 r
.09586 .39696 .10284 .40743 .1127 .40564 .1059 .39382 Mtetra
.606 .607 .826 r
.1059 .39382 .1127 .40564 .12253 .4045 .11591 .39125 Mtetra
.596 .577 .803 r
.11591 .39125 .12253 .4045 .13237 .40371 .12594 .38888 Mtetra
.59 .552 .78 r
.12594 .38888 .13237 .40371 .14224 .40317 .13601 .38656 Mtetra
.597 .534 .755 r
.13601 .38656 .14224 .40317 .1522 .40229 .14618 .38379 Mtetra
.61 .524 .732 r
.14618 .38379 .1522 .40229 .16232 .40055 .15651 .38008 Mtetra
.619 .514 .712 r
.15651 .38008 .16232 .40055 .17261 .39773 .16697 .3755 Mtetra
.629 .508 .697 r
.16697 .3755 .17261 .39773 .1831 .39347 .17758 .36991 Mtetra
.623 .497 .688 r
.17758 .36991 .1831 .39347 .19368 .38861 .18821 .36435 Mtetra
.61 .485 .685 r
.18821 .36435 .19368 .38861 .20431 .38368 .19879 .35955 Mtetra
.581 .467 .688 r
.19879 .35955 .20431 .38368 .21486 .37988 .20923 .35655 Mtetra
.531 .44 .697 r
.20923 .35655 .21486 .37988 .22526 .37818 .21946 .35623 Mtetra
.485 .421 .709 r
.21946 .35623 .22526 .37818 .23556 .37811 .22957 .35781 Mtetra
.439 .405 .724 r
.22957 .35781 .23556 .37811 .2458 .37948 .23964 .36083 Mtetra
.456 .434 .745 r
.23964 .36083 .2458 .37948 .25618 .38018 .24986 .36306 Mtetra
.523 .492 .763 r
.24986 .36306 .25618 .38018 .26679 .37888 .26035 .36298 Mtetra
.602 .552 .77 r
.26035 .36298 .26679 .37888 .27766 .37504 .27115 .35997 Mtetra
.674 .6 .764 r
.27115 .35997 .27766 .37504 .28877 .36845 .28224 .35367 Mtetra
.701 .616 .759 r
.28224 .35367 .28877 .36845 .29996 .3612 .29348 .34591 Mtetra
.703 .612 .752 r
.29348 .34591 .29996 .3612 .31113 .3545 .30475 .3378 Mtetra
.681 .586 .742 r
.30475 .3378 .31113 .3545 .32223 .34939 .31599 .33049 Mtetra
.646 .547 .728 r
.31599 .33049 .32223 .34939 .33324 .34622 .32716 .32455 Mtetra
.623 .513 .707 r
.32716 .32455 .33324 .34622 .34427 .34364 .33832 .3193 Mtetra
.608 .487 .689 r
.33832 .3193 .34427 .34364 .35536 .34101 .3495 .31448 Mtetra
.599 .47 .676 r
.3495 .31448 .35536 .34101 .36653 .33782 .36071 .30982 Mtetra
.593 .46 .669 r
.36071 .30982 .36653 .33782 .37779 .33393 .37195 .30528 Mtetra
.585 .452 .666 r
.37195 .30528 .37779 .33393 .3891 .32995 .38321 .30125 Mtetra
.578 .447 .666 r
.38321 .30125 .3891 .32995 .40045 .32588 .3945 .29774 Mtetra
.577 .449 .67 r
.3945 .29774 .40045 .32588 .41189 .32111 .40584 .29434 Mtetra
.577 .456 .678 r
.40584 .29434 .41189 .32111 .42338 .31577 .41722 .29111 Mtetra
.574 .465 .692 r
.41722 .29111 .42338 .31577 .43491 .31038 .42864 .28832 Mtetra
.566 .478 .714 r
.42864 .28832 .43491 .31038 .44647 .30557 .4401 .28622 Mtetra
.539 .484 .743 r
.4401 .28622 .44647 .30557 .45802 .30273 .45159 .28552 Mtetra
.517 .494 .77 r
.45159 .28552 .45802 .30273 .46961 .30149 .46314 .28563 Mtetra
.525 .517 .79 r
.46314 .28563 .46961 .30149 .48126 .30082 .47478 .2854 Mtetra
.566 .547 .793 r
.47478 .2854 .48126 .30082 .49299 .2995 .48651 .2837 Mtetra
.643 .584 .774 r
.48651 .2837 .49299 .2995 .50482 .29538 .49835 .27867 Mtetra
.691 .599 .749 r
.49835 .27867 .50482 .29538 .5167 .28867 .51024 .27063 Mtetra
.715 .599 .725 r
.51024 .27063 .5167 .28867 .52861 .2799 .52216 .26023 Mtetra
.714 .585 .709 r
.52216 .26023 .52861 .2799 .54054 .27044 .53407 .249 Mtetra
.685 .556 .702 r
.53407 .249 .54054 .27044 .55248 .26242 .546 .23921 Mtetra
.652 .525 .696 r
.546 .23921 .55248 .26242 .56448 .25608 .55795 .23135 Mtetra
.608 .489 .692 r
.55795 .23135 .56448 .25608 .57654 .25187 .56997 .22623 Mtetra
.578 .465 .689 r
.56997 .22623 .57654 .25187 .58868 .24883 .58208 .22296 Mtetra
.565 .456 .689 r
.58208 .22296 .58868 .24883 .60089 .24571 .59426 .22048 Mtetra
.566 .461 .694 r
.59426 .22048 .60089 .24571 .61314 .24198 .60651 .21803 Mtetra
.585 .481 .702 r
.60651 .21803 .61314 .24198 .6254 .23675 .6188 .21453 Mtetra
.604 .504 .714 r
.6188 .21453 .6254 .23675 .63767 .2304 .63111 .21013 Mtetra
.626 .533 .729 r
.63111 .21013 .63767 .2304 .64993 .22315 .64345 .20476 Mtetra
.643 .56 .746 r
.64345 .20476 .64993 .22315 .66222 .21552 .65581 .19891 Mtetra
.651 .584 .767 r
.65581 .19891 .66222 .21552 .67454 .20814 .66822 .19309 Mtetra
.655 .607 .789 r
.66822 .19309 .67454 .20814 .68692 .20112 .68069 .18749 Mtetra
.65 .627 .813 r
.68069 .18749 .68692 .20112 .69937 .19476 .69323 .18247 Mtetra
.645 .649 .839 r
.69323 .18247 .69937 .19476 .71189 .18887 .70585 .17787 Mtetra
.64 .675 .867 r
.70585 .17787 .71189 .18887 .72447 .18335 .71856 .17362 Mtetra
.633 .704 .897 r
.71856 .17362 .72447 .18335 .73713 .1781 .73134 .16968 Mtetra
.72 .764 .887 r
.05808 .40196 .06568 .40859 .07575 .4044 .06836 .39647 Mtetra
.703 .726 .868 r
.06836 .39647 .07575 .4044 .08581 .40051 .07862 .39126 Mtetra
.686 .69 .848 r
.07862 .39126 .08581 .40051 .09586 .39696 .08887 .38637 Mtetra
.668 .656 .829 r
.08887 .38637 .09586 .39696 .1059 .39382 .0991 .38182 Mtetra
.648 .622 .811 r
.0991 .38182 .1059 .39382 .11591 .39125 .1093 .37774 Mtetra
.637 .594 .789 r
.1093 .37774 .11591 .39125 .12594 .38888 .11953 .37377 Mtetra
.631 .57 .768 r
.11953 .37377 .12594 .38888 .13601 .38656 .12981 .36972 Mtetra
.633 .552 .746 r
.12981 .36972 .13601 .38656 .14618 .38379 .14018 .36517 Mtetra
.642 .541 .725 r
.14018 .36517 .14618 .38379 .15651 .38008 .15069 .35971 Mtetra
.645 .53 .709 r
.15069 .35971 .15651 .38008 .16697 .3755 .16131 .35356 Mtetra
.648 .522 .696 r
.16131 .35356 .16697 .3755 .17758 .36991 .17204 .3467 Mtetra
.637 .508 .688 r
.17204 .3467 .17758 .36991 .18821 .36435 .18275 .34023 Mtetra
.617 .49 .685 r
.18275 .34023 .18821 .36435 .19879 .35955 .19335 .33493 Mtetra
.583 .465 .684 r
.19335 .33493 .19879 .35955 .20923 .35655 .20378 .33169 Mtetra
.531 .43 .685 r
.20378 .33169 .20923 .35655 .21946 .35623 .21397 .33126 Mtetra
.49 .403 .684 r
.21397 .33126 .21946 .35623 .22957 .35781 .22405 .33277 Mtetra
.458 .382 .682 r
.22405 .33277 .22957 .35781 .23964 .36083 .23407 .33567 Mtetra
.475 .393 .683 r
.23407 .33567 .23964 .36083 .24986 .36306 .24424 .33787 Mtetra
.522 .424 .685 r
.24424 .33787 .24986 .36306 .26035 .36298 .25468 .33789 Mtetra
.574 .459 .685 r
.25468 .33789 .26035 .36298 .27115 .35997 .26542 .33511 Mtetra
.623 .493 .683 r
.26542 .33511 .27115 .35997 .28224 .35367 .27646 .32911 Mtetra
.647 .509 .682 r
.27646 .32911 .28224 .35367 .29348 .34591 .28767 .32138 Mtetra
.657 .516 .68 r
.28767 .32138 .29348 .34591 .30475 .3378 .29895 .31283 Mtetra
.651 .51 .678 r
.29895 .31283 .30475 .3378 .31599 .33049 .31023 .30457 Mtetra
.636 .496 .675 r
.31023 .30457 .31599 .33049 .32716 .32455 .32146 .29724 Mtetra
.623 .481 .668 r
.32146 .29724 .32716 .32455 .33832 .3193 .33267 .29056 Mtetra
.61 .467 .662 r
.33267 .29056 .33832 .3193 .3495 .31448 .34387 .28455 Mtetra
.6 .456 .657 r
.34387 .28455 .3495 .31448 .36071 .30982 .35507 .27909 Mtetra
.591 .447 .654 r
.35507 .27909 .36071 .30982 .37195 .30528 .36628 .27419 Mtetra
.58 .438 .653 r
.36628 .27419 .37195 .30528 .38321 .30125 .37749 .27011 Mtetra
.569 .431 .653 r
.37749 .27011 .38321 .30125 .3945 .29774 .38871 .26685 Mtetra
.561 .427 .655 r
.38871 .26685 .3945 .29774 .40584 .29434 .39996 .26417 Mtetra
.554 .425 .659 r
.39996 .26417 .40584 .29434 .41722 .29111 .41124 .26204 Mtetra
.545 .424 .665 r
.41124 .26204 .41722 .29111 .42864 .28832 .42257 .26058 Mtetra
.536 .424 .673 r
.42257 .26058 .42864 .28832 .4401 .28622 .43394 .25979 Mtetra
.52 .421 .682 r
.43394 .25979 .4401 .28622 .45159 .28552 .44536 .25995 Mtetra
.514 .422 .689 r
.44536 .25995 .45159 .28552 .46314 .28563 .45686 .26041 Mtetra
.529 .435 .692 r
.45686 .26041 .46314 .28563 .47478 .2854 .46846 .26006 Mtetra
.559 .454 .69 r
.46846 .26006 .47478 .2854 .48651 .2837 .48016 .25797 Mtetra
.608 .483 .684 r
.48016 .25797 .48651 .2837 .49835 .27867 .49196 .2526 Mtetra
.644 .504 .677 r
.49196 .2526 .49835 .27867 .51024 .27063 .50383 .24437 Mtetra
.669 .519 .672 r
.50383 .24437 .51024 .27063 .52216 .26023 .51572 .23391 Mtetra
.676 .523 .67 r
.51572 .23391 .52216 .26023 .53407 .249 .52761 .22271 Mtetra
.661 .514 .673 r
.52761 .22271 .53407 .249 .546 .23921 .53951 .21291 Mtetra
.638 .499 .677 r
.53951 .21291 .546 .23921 .55795 .23135 .55144 .20507 Mtetra
.6 .475 .682 r
.55144 .20507 .55795 .23135 .56997 .22623 .56342 .20012 Mtetra
.569 .457 .686 r
.56342 .20012 .56997 .22623 .58208 .22296 .57549 .19726 Mtetra
.551 .448 .69 r
.57549 .19726 .58208 .22296 .59426 .22048 .58765 .19562 Mtetra
.545 .449 .697 r
.58765 .19562 .59426 .22048 .60651 .21803 .5999 .19438 Mtetra
.558 .466 .706 r
.5999 .19438 .60651 .21803 .6188 .21453 .6122 .19242 Mtetra
.573 .487 .719 r
.6122 .19242 .6188 .21453 .63111 .21013 .62456 .18974 Mtetra
.594 .514 .733 r
.62456 .18974 .63111 .21013 .64345 .20476 .63695 .18612 Mtetra
.609 .539 .75 r
.63695 .18612 .64345 .20476 .65581 .19891 .64938 .18199 Mtetra
.617 .563 .771 r
.64938 .18199 .65581 .19891 .66822 .19309 .66187 .17776 Mtetra
.621 .586 .793 r
.66187 .17776 .66822 .19309 .68069 .18749 .67442 .17366 Mtetra
.614 .606 .819 r
.67442 .17366 .68069 .18749 .69323 .18247 .68706 .17003 Mtetra
.607 .629 .846 r
.68706 .17003 .69323 .18247 .70585 .17787 .69978 .16676 Mtetra
.599 .654 .875 r
.69978 .16676 .70585 .17787 .71856 .17362 .71259 .16382 Mtetra
.586 .681 .906 r
.71259 .16382 .71856 .17362 .73134 .16968 .7255 .16118 Mtetra
.747 .767 .869 r
.05043 .39529 .05808 .40196 .06836 .39647 .06089 .38868 Mtetra
.732 .737 .855 r
.06089 .38868 .06836 .39647 .07862 .39126 .07133 .38234 Mtetra
.717 .707 .84 r
.07133 .38234 .07862 .39126 .08887 .38637 .08176 .37626 Mtetra
.701 .678 .825 r
.08176 .37626 .08887 .38637 .0991 .38182 .09217 .37046 Mtetra
.684 .649 .809 r
.09217 .37046 .0991 .38182 .1093 .37774 .10256 .36502 Mtetra
.674 .623 .791 r
.10256 .36502 .1093 .37774 .11953 .37377 .11298 .35962 Mtetra
.668 .601 .771 r
.11298 .35962 .11953 .37377 .12981 .36972 .12344 .35405 Mtetra
.667 .583 .751 r
.12344 .35405 .12981 .36972 .14018 .36517 .13399 .34802 Mtetra
.672 .571 .733 r
.13399 .34802 .14018 .36517 .15069 .35971 .14467 .34117 Mtetra
.672 .559 .719 r
.14467 .34117 .15069 .35971 .16131 .35356 .15542 .33379 Mtetra
.672 .55 .708 r
.15542 .33379 .16131 .35356 .17204 .3467 .16625 .32596 Mtetra
.659 .536 .703 r
.16625 .32596 .17204 .3467 .18275 .34023 .17702 .3187 Mtetra
.635 .516 .701 r
.17702 .3187 .18275 .34023 .19335 .33493 .18768 .31276 Mtetra
.6 .49 .701 r
.18768 .31276 .19335 .33493 .20378 .33169 .19815 .30885 Mtetra
.547 .453 .699 r
.19815 .30885 .20378 .33169 .21397 .33126 .20838 .30763 Mtetra
.507 .422 .694 r
.20838 .30763 .21397 .33126 .22405 .33277 .2185 .30824 Mtetra
.478 .398 .687 r
.2185 .30824 .22405 .33277 .23407 .33567 .22856 .31015 Mtetra
.491 .401 .681 r
.22856 .31015 .23407 .33567 .24424 .33787 .23875 .31156 Mtetra
.528 .421 .677 r
.23875 .31156 .24424 .33787 .25468 .33789 .24918 .31119 Mtetra
.569 .447 .674 r
.24918 .31119 .25468 .33789 .26542 .33511 .25987 .30843 Mtetra
.61 .475 .672 r
.25987 .30843 .26542 .33511 .27646 .32911 .27085 .30287 Mtetra
.634 .493 .672 r
.27085 .30287 .27646 .32911 .28767 .32138 .28199 .29561 Mtetra
.648 .504 .673 r
.28199 .29561 .28767 .32138 .29895 .31283 .29322 .28734 Mtetra
.65 .506 .675 r
.29322 .28734 .29895 .31283 .31023 .30457 .30447 .27902 Mtetra
.643 .502 .675 r
.30447 .27902 .31023 .30457 .32146 .29724 .31571 .27123 Mtetra
.634 .494 .674 r
.31571 .27123 .32146 .29724 .33267 .29056 .32692 .26399 Mtetra
.623 .484 .672 r
.32692 .26399 .33267 .29056 .34387 .28455 .33812 .25744 Mtetra
.612 .475 .67 r
.33812 .25744 .34387 .28455 .35507 .27909 .3493 .25159 Mtetra
.6 .465 .669 r
.3493 .25159 .35507 .27909 .36628 .27419 .36048 .24651 Mtetra
.586 .455 .669 r
.36048 .24651 .36628 .27419 .37749 .27011 .37165 .24239 Mtetra
.572 .446 .67 r
.37165 .24239 .37749 .27011 .38871 .26685 .38281 .23922 Mtetra
.56 .439 .671 r
.38281 .23922 .38871 .26685 .39996 .26417 .394 .23682 Mtetra
.549 .434 .674 r
.394 .23682 .39996 .26417 .41124 .26204 .40522 .23514 Mtetra
.538 .429 .677 r
.40522 .23514 .41124 .26204 .42257 .26058 .41649 .23415 Mtetra
.528 .425 .681 r
.41649 .23415 .42257 .26058 .43394 .25979 .4278 .23373 Mtetra
.518 .421 .684 r
.4278 .23373 .43394 .25979 .44536 .25995 .43918 .23386 Mtetra
.519 .422 .685 r
.43918 .23386 .44536 .25995 .45686 .26041 .45063 .23395 Mtetra
.537 .432 .682 r
.45063 .23395 .45686 .26041 .46846 .26006 .46219 .23302 Mtetra
.564 .447 .678 r
.46219 .23302 .46846 .26006 .48016 .25797 .47386 .23039 Mtetra
.604 .471 .672 r
.47386 .23039 .48016 .25797 .49196 .2526 .48562 .2249 Mtetra
.634 .489 .668 r
.48562 .2249 .49196 .2526 .50383 .24437 .49745 .21698 Mtetra
.656 .505 .667 r
.49745 .21698 .50383 .24437 .51572 .23391 .50931 .20723 Mtetra
.665 .513 .669 r
.50931 .20723 .51572 .23391 .52761 .22271 .52118 .19695 Mtetra
.654 .511 .677 r
.52118 .19695 .52761 .22271 .53951 .21291 .53305 .18798 Mtetra
.633 .503 .686 r
.53305 .18798 .53951 .21291 .55144 .20507 .54496 .18088 Mtetra
.596 .484 .696 r
.54496 .18088 .55144 .20507 .56342 .20012 .55692 .17651 Mtetra
.563 .467 .704 r
.55692 .17651 .56342 .20012 .57549 .19726 .56897 .17423 Mtetra
.539 .457 .711 r
.56897 .17423 .57549 .19726 .58765 .19562 .58111 .17331 Mtetra
.527 .455 .718 r
.58111 .17331 .58765 .19562 .5999 .19438 .59335 .17298 Mtetra
.537 .469 .727 r
.59335 .17298 .5999 .19438 .6122 .19242 .60566 .17219 Mtetra
.548 .487 .739 r
.60566 .17219 .6122 .19242 .62456 .18974 .61805 .17087 Mtetra
.568 .512 .753 r
.61805 .17087 .62456 .18974 .63695 .18612 .63048 .16871 Mtetra
.581 .536 .77 r
.63048 .16871 .63695 .18612 .64938 .18199 .64297 .16607 Mtetra
.588 .56 .79 r
.64297 .16607 .64938 .18199 .66187 .17776 .65553 .16325 Mtetra
.589 .582 .813 r
.65553 .16325 .66187 .17776 .67442 .17366 .66815 .16048 Mtetra
.58 .601 .838 r
.66815 .16048 .67442 .17366 .68706 .17003 .68088 .15809 Mtetra
.571 .621 .864 r
.68088 .15809 .68706 .17003 .69978 .16676 .69369 .15598 Mtetra
.558 .643 .89 r
.69369 .15598 .69978 .16676 .71259 .16382 .7066 .15416 Mtetra
.541 .664 .917 r
.7066 .15416 .71259 .16382 .7255 .16118 .71961 .15261 Mtetra
.76 .768 .859 r
.04273 .38856 .05043 .39529 .06089 .38868 .0533 .38133 Mtetra
.75 .752 .853 r
.0533 .38133 .06089 .38868 .07133 .38234 .06386 .37432 Mtetra
.74 .734 .846 r
.06386 .37432 .07133 .38234 .08176 .37626 .07441 .36751 Mtetra
.73 .716 .838 r
.07441 .36751 .08176 .37626 .09217 .37046 .08496 .3609 Mtetra
.717 .696 .829 r
.08496 .3609 .09217 .37046 .10256 .36502 .09549 .35454 Mtetra
.71 .676 .815 r
.09549 .35454 .10256 .36502 .11298 .35962 .10605 .34816 Mtetra
.707 .658 .799 r
.10605 .34816 .11298 .35962 .12344 .35405 .11665 .34157 Mtetra
.706 .642 .783 r
.11665 .34157 .12344 .35405 .13399 .34802 .12733 .33457 Mtetra
.71 .631 .767 r
.12733 .33457 .13399 .34802 .14467 .34117 .13811 .32689 Mtetra
.71 .621 .756 r
.13811 .32689 .14467 .34117 .15542 .33379 .14896 .31885 Mtetra
.709 .613 .747 r
.14896 .31885 .15542 .33379 .16625 .32596 .15984 .31055 Mtetra
.696 .601 .747 r
.15984 .31055 .16625 .32596 .17702 .3187 .17067 .30289 Mtetra
.671 .585 .75 r
.17067 .30289 .17702 .3187 .18768 .31276 .18136 .29654 Mtetra
.632 .56 .756 r
.18136 .29654 .18768 .31276 .19815 .30885 .19188 .29208 Mtetra
.574 .522 .759 r
.19188 .29208 .19815 .30885 .20838 .30763 .20219 .29006 Mtetra
.525 .485 .754 r
.20219 .29006 .20838 .30763 .2185 .30824 .21237 .28975 Mtetra
.488 .454 .745 r
.21237 .28975 .2185 .30824 .22856 .31015 .2225 .29074 Mtetra
.496 .449 .735 r
.2225 .29074 .22856 .31015 .23875 .31156 .23272 .29155 Mtetra
.529 .465 .728 r
.23272 .29155 .23875 .31156 .24918 .31119 .24312 .29111 Mtetra
.572 .491 .725 r
.24312 .29111 .24918 .31119 .25987 .30843 .25375 .28884 Mtetra
.618 .524 .725 r
.25375 .28884 .25987 .30843 .27085 .30287 .26462 .2843 Mtetra
.65 .551 .729 r
.26462 .2843 .27085 .30287 .28199 .29561 .27566 .27821 Mtetra
.675 .575 .736 r
.27566 .27821 .28199 .29561 .29322 .28734 .28682 .27099 Mtetra
.687 .593 .745 r
.28682 .27099 .29322 .28734 .30447 .27902 .29802 .2634 Mtetra
.69 .602 .753 r
.29802 .2634 .30447 .27902 .31571 .27123 .30924 .25595 Mtetra
.687 .605 .759 r
.30924 .25595 .31571 .27123 .32692 .26399 .32045 .24881 Mtetra
.678 .602 .764 r
.32045 .24881 .32692 .26399 .33812 .25744 .33166 .24222 Mtetra
.665 .595 .768 r
.33166 .24222 .33812 .25744 .3493 .25159 .34285 .2363 Mtetra
.648 .586 .772 r
.34285 .2363 .3493 .25159 .36048 .24651 .35403 .23118 Mtetra
.627 .575 .777 r
.35403 .23118 .36048 .24651 .37165 .24239 .3652 .22702 Mtetra
.604 .563 .782 r
.3652 .22702 .37165 .24239 .38281 .23922 .37636 .22381 Mtetra
.583 .552 .785 r
.37636 .22381 .38281 .23922 .394 .23682 .38755 .22141 Mtetra
.564 .542 .789 r
.38755 .22141 .394 .23682 .40522 .23514 .39877 .21969 Mtetra
.548 .533 .791 r
.39877 .21969 .40522 .23514 .41649 .23415 .41003 .21853 Mtetra
.538 .526 .79 r
.41003 .21853 .41649 .23415 .4278 .23373 .42135 .2177 Mtetra
.534 .519 .785 r
.42135 .2177 .4278 .23373 .43918 .23386 .43274 .217 Mtetra
.544 .515 .773 r
.43274 .217 .43918 .23386 .45063 .23395 .44421 .21594 Mtetra
.571 .517 .756 r
.44421 .21594 .45063 .23395 .46219 .23302 .45579 .21376 Mtetra
.601 .523 .738 r
.45579 .21376 .46219 .23302 .47386 .23039 .46746 .21001 Mtetra
.638 .535 .721 r
.46746 .21001 .47386 .23039 .48562 .2249 .47922 .20394 Mtetra
.663 .546 .711 r
.47922 .20394 .48562 .2249 .49745 .21698 .49103 .19601 Mtetra
.681 .556 .707 r
.49103 .19601 .49745 .21698 .50931 .20723 .50288 .18679 Mtetra
.686 .563 .71 r
.50288 .18679 .50931 .20723 .52118 .19695 .51474 .17737 Mtetra
.673 .562 .722 r
.51474 .17737 .52118 .19695 .53305 .18798 .52662 .16926 Mtetra
.65 .557 .737 r
.52662 .16926 .53305 .18798 .54496 .18088 .53853 .16289 Mtetra
.607 .54 .754 r
.53853 .16289 .54496 .18088 .55692 .17651 .55049 .15901 Mtetra
.565 .522 .767 r
.55049 .15901 .55692 .17651 .56897 .17423 .56253 .15707 Mtetra
.531 .507 .775 r
.56253 .15707 .56897 .17423 .58111 .17331 .57467 .15647 Mtetra
.512 .501 .781 r
.57467 .15647 .58111 .17331 .59335 .17298 .58691 .15655 Mtetra
.518 .511 .787 r
.58691 .15655 .59335 .17298 .60566 .17219 .59924 .15637 Mtetra
.527 .526 .797 r
.59924 .15637 .60566 .17219 .61805 .17087 .61164 .15582 Mtetra
.546 .549 .808 r
.61164 .15582 .61805 .17087 .63048 .16871 .62411 .15458 Mtetra
.558 .571 .823 r
.62411 .15458 .63048 .16871 .64297 .16607 .63665 .15292 Mtetra
.564 .592 .84 r
.63665 .15292 .64297 .16607 .65553 .16325 .64926 .15105 Mtetra
.563 .612 .859 r
.64926 .15105 .65553 .16325 .66815 .16048 .66195 .14916 Mtetra
.552 .626 .879 r
.66195 .14916 .66815 .16048 .68088 .15809 .67473 .14754 Mtetra
.54 .64 .897 r
.67473 .14754 .68088 .15809 .69369 .15598 .68761 .14613 Mtetra
.526 .652 .914 r
.68761 .14613 .69369 .15598 .7066 .15416 .70059 .14493 Mtetra
.51 .662 .93 r
.70059 .14493 .7066 .15416 .71961 .15261 .71368 .14397 Mtetra
.763 .768 .857 r
.03496 .38178 .04273 .38856 .0533 .38133 .04559 .3744 Mtetra
.758 .765 .858 r
.04559 .3744 .0533 .38133 .06386 .37432 .05621 .36717 Mtetra
.753 .759 .858 r
.05621 .36717 .06386 .37432 .07441 .36751 .06682 .36009 Mtetra
.748 .753 .856 r
.06682 .36009 .07441 .36751 .08496 .3609 .07744 .35313 Mtetra
.742 .744 .853 r
.07744 .35313 .08496 .3609 .09549 .35454 .08806 .34633 Mtetra
.739 .733 .846 r
.08806 .34633 .09549 .35454 .10605 .34816 .0987 .33948 Mtetra
.739 .723 .837 r
.0987 .33948 .10605 .34816 .11665 .34157 .10938 .33245 Mtetra
.741 .714 .827 r
.10938 .33245 .11665 .34157 .12733 .33457 .12013 .3251 Mtetra
.747 .709 .816 r
.12013 .3251 .12733 .33457 .13811 .32689 .13096 .31725 Mtetra
.749 .707 .812 r
.13096 .31725 .13811 .32689 .14896 .31885 .14183 .30919 Mtetra
.751 .708 .811 r
.14183 .30919 .14896 .31885 .15984 .31055 .15272 .30104 Mtetra
.742 .709 .821 r
.15272 .30104 .15984 .31055 .17067 .30289 .16356 .29347 Mtetra
.72 .706 .836 r
.16356 .29347 .17067 .30289 .18136 .29654 .17429 .287 Mtetra
.681 .692 .853 r
.17429 .287 .18136 .29654 .19188 .29208 .18487 .28208 Mtetra
.617 .658 .867 r
.18487 .28208 .19188 .29208 .20219 .29006 .19528 .27912 Mtetra
.56 .612 .862 r
.19528 .27912 .20219 .29006 .21237 .28975 .20559 .27762 Mtetra
.514 .565 .844 r
.20559 .27762 .21237 .28975 .2225 .29074 .21584 .2773 Mtetra
.515 .54 .82 r
.21584 .2773 .2225 .29074 .23272 .29155 .22615 .27707 Mtetra
.541 .538 .8 r
.22615 .27707 .23272 .29155 .24312 .29111 .23658 .27616 Mtetra
.577 .551 .789 r
.23658 .27616 .24312 .29111 .25375 .28884 .24719 .27405 Mtetra
.62 .576 .784 r
.24719 .27405 .25375 .28884 .26462 .2843 .258 .27033 Mtetra
.652 .605 .788 r
.258 .27033 .26462 .2843 .27566 .27821 .26895 .26538 Mtetra
.682 .636 .798 r
.26895 .26538 .27566 .27821 .28682 .27099 .28002 .25941 Mtetra
.702 .666 .812 r
.28002 .25941 .28682 .27099 .29802 .2634 .29116 .25293 Mtetra
.714 .692 .828 r
.29116 .25293 .29802 .2634 .30924 .25595 .30234 .24628 Mtetra
.718 .711 .843 r
.30234 .24628 .30924 .25595 .32045 .24881 .31354 .23973 Mtetra
.714 .725 .858 r
.31354 .23973 .32045 .24881 .33166 .24222 .32474 .23352 Mtetra
.703 .732 .873 r
.32474 .23352 .33166 .24222 .34285 .2363 .33595 .22783 Mtetra
.684 .733 .887 r
.33595 .22783 .34285 .2363 .35403 .23118 .34715 .22283 Mtetra
.658 .728 .901 r
.34715 .22283 .35403 .23118 .3652 .22702 .35834 .21863 Mtetra
.627 .717 .911 r
.35834 .21863 .3652 .22702 .37636 .22381 .36954 .21525 Mtetra
.599 .701 .915 r
.36954 .21525 .37636 .22381 .38755 .22141 .38076 .21255 Mtetra
.576 .684 .914 r
.38076 .21255 .38755 .22141 .39877 .21969 .39202 .21038 Mtetra
.562 .666 .908 r
.39202 .21038 .39877 .21969 .41003 .21853 .40332 .20856 Mtetra
.559 .648 .894 r
.40332 .20856 .41003 .21853 .42135 .2177 .41469 .20684 Mtetra
.567 .631 .874 r
.41469 .20684 .42135 .2177 .43274 .217 .42613 .20496 Mtetra
.585 .615 .848 r
.42613 .20496 .43274 .217 .44421 .21594 .43765 .20257 Mtetra
.613 .604 .818 r
.43765 .20257 .44421 .21594 .45579 .21376 .44926 .19916 Mtetra
.639 .598 .792 r
.44926 .19916 .45579 .21376 .46746 .21001 .46095 .19449 Mtetra
.668 .601 .771 r
.46095 .19449 .46746 .21001 .47922 .20394 .47272 .18818 Mtetra
.688 .609 .762 r
.47272 .18818 .47922 .20394 .49103 .19601 .48454 .18065 Mtetra
.703 .622 .763 r
.48454 .18065 .49103 .19601 .50288 .18679 .4964 .17242 Mtetra
.709 .638 .775 r
.4964 .17242 .50288 .18679 .51474 .17737 .50827 .16427 Mtetra
.697 .652 .801 r
.50827 .16427 .51474 .17737 .52662 .16926 .52017 .1573 Mtetra
.672 .661 .832 r
.52017 .1573 .52662 .16926 .53853 .16289 .5321 .15182 Mtetra
.619 .657 .865 r
.5321 .15182 .53853 .16289 .55049 .15901 .54409 .14835 Mtetra
.563 .64 .885 r
.54409 .14835 .55049 .15901 .56253 .15707 .55615 .14645 Mtetra
.516 .618 .892 r
.55615 .14645 .56253 .15707 .57467 .15647 .56831 .1457 Mtetra
.491 .602 .891 r
.56831 .1457 .57467 .15647 .58691 .15655 .58056 .14555 Mtetra
.496 .6 .887 r
.58056 .14555 .58691 .15655 .59924 .15637 .5929 .14532 Mtetra
.505 .605 .886 r
.5929 .14532 .59924 .15637 .61164 .15582 .60533 .14487 Mtetra
.525 .618 .888 r
.60533 .14487 .61164 .15582 .62411 .15458 .61783 .14392 Mtetra
.535 .632 .894 r
.61783 .14392 .62411 .15458 .63665 .15292 .6304 .14265 Mtetra
.54 .646 .903 r
.6304 .14265 .63665 .15292 .64926 .15105 .64305 .14119 Mtetra
.539 .657 .913 r
.64305 .14119 .64926 .15105 .66195 .14916 .65579 .13969 Mtetra
.528 .664 .923 r
.65579 .13969 .66195 .14916 .67473 .14754 .66862 .13836 Mtetra
.519 .668 .93 r
.66862 .13836 .67473 .14754 .68761 .14613 .68154 .13716 Mtetra
.508 .671 .936 r
.68154 .13716 .68761 .14613 .70059 .14493 .69456 .13612 Mtetra
.498 .671 .941 r
.69456 .13612 .70059 .14493 .71368 .14397 .70769 .13525 Mtetra
.755 .768 .863 r
.02714 .37496 .03496 .38178 .04559 .3744 .03774 .36791 Mtetra
.755 .778 .872 r
.03774 .36791 .04559 .3744 .05621 .36717 .04835 .36098 Mtetra
.755 .787 .879 r
.04835 .36098 .05621 .36717 .06682 .36009 .05896 .35414 Mtetra
.755 .795 .885 r
.05896 .35414 .06682 .36009 .07744 .35313 .06958 .34737 Mtetra
.754 .802 .891 r
.06958 .34737 .07744 .35313 .08806 .34633 .08021 .34069 Mtetra
.756 .807 .893 r
.08021 .34069 .08806 .34633 .0987 .33948 .09086 .33399 Mtetra
.759 .812 .895 r
.09086 .33399 .0987 .33948 .10938 .33245 .10155 .32719 Mtetra
.764 .82 .896 r
.10155 .32719 .10938 .33245 .12013 .3251 .11228 .32023 Mtetra
.773 .834 .899 r
.11228 .32023 .12013 .3251 .13096 .31725 .12306 .31302 Mtetra
.778 .855 .908 r
.12306 .31302 .13096 .31725 .14183 .30919 .13387 .30574 Mtetra
.78 .88 .919 r
.13387 .30574 .14183 .30919 .15272 .30104 .1447 .29847 Mtetra
.766 .91 .938 r
.1447 .29847 .15272 .30104 .16356 .29347 .1555 .29159 Mtetra
.732 .93 .955 r
.1555 .29159 .16356 .29347 .17429 .287 .16624 .28541 Mtetra
.674 .931 .97 r
.16624 .28541 .17429 .287 .18487 .28208 .1769 .28018 Mtetra
.6 .905 .984 r
.1769 .28018 .18487 .28208 .19528 .27912 .18747 .27615 Mtetra
.561 .863 .996 r
.18747 .27615 .19528 .27912 .20559 .27762 .19797 .27307 Mtetra
.543 .805 .994 r
.19797 .27307 .20559 .27762 .21584 .2773 .20844 .27079 Mtetra
.561 .744 .962 r
.20844 .27079 .21584 .2773 .22615 .27707 .21895 .26874 Mtetra
.585 .695 .918 r
.21895 .26874 .22615 .27707 .23658 .27616 .22953 .26647 Mtetra
.609 .668 .882 r
.22953 .26647 .23658 .27616 .24719 .27405 .24021 .26365 Mtetra
.635 .663 .86 r
.24021 .26365 .24719 .27405 .258 .27033 .25102 .26002 Mtetra
.657 .674 .855 r
.25102 .26002 .258 .27033 .26895 .26538 .26193 .25568 Mtetra
.678 .696 .86 r
.26193 .25568 .26895 .26538 .28002 .25941 .27295 .25069 Mtetra
.695 .727 .875 r
.27295 .25069 .28002 .25941 .29116 .25293 .28403 .2453 Mtetra
.707 .761 .894 r
.28403 .2453 .29116 .25293 .30234 .24628 .29516 .2397 Mtetra
.713 .794 .915 r
.29516 .2397 .30234 .24628 .31354 .23973 .30633 .23408 Mtetra
.709 .824 .936 r
.30633 .23408 .31354 .23973 .32474 .23352 .31752 .2286 Mtetra
.696 .847 .955 r
.31752 .2286 .32474 .23352 .33595 .22783 .32874 .22343 Mtetra
.672 .86 .971 r
.32874 .22343 .33595 .22783 .34715 .22283 .33996 .21868 Mtetra
.641 .862 .983 r
.33996 .21868 .34715 .22283 .35834 .21863 .3512 .21446 Mtetra
.61 .852 .99 r
.3512 .21446 .35834 .21863 .36954 .21525 .36245 .21075 Mtetra
.589 .835 .991 r
.36245 .21075 .36954 .21525 .38076 .21255 .37374 .20747 Mtetra
.579 .812 .988 r
.37374 .20747 .38076 .21255 .39202 .21038 .38506 .20451 Mtetra
.582 .786 .976 r
.38506 .20451 .39202 .21038 .40332 .20856 .39644 .20169 Mtetra
.593 .757 .957 r
.39644 .20169 .40332 .20856 .41469 .20684 .40788 .19885 Mtetra
.608 .728 .93 r
.40788 .19885 .41469 .20684 .42613 .20496 .41938 .1958 Mtetra
.624 .702 .901 r
.41938 .1958 .42613 .20496 .43765 .20257 .43096 .19235 Mtetra
.644 .684 .873 r
.43096 .19235 .43765 .20257 .44926 .19916 .44261 .18825 Mtetra
.661 .676 .853 r
.44261 .18825 .44926 .19916 .46095 .19449 .45432 .18342 Mtetra
.682 .682 .844 r
.45432 .18342 .46095 .19449 .47272 .18818 .46611 .17777 Mtetra
.7 .704 .85 r
.46611 .17777 .47272 .18818 .48454 .18065 .47794 .17155 Mtetra
.715 .742 .872 r
.47794 .17155 .48454 .18065 .4964 .17242 .48981 .16511 Mtetra
.719 .794 .91 r
.48981 .16511 .4964 .17242 .50827 .16427 .50171 .15889 Mtetra
.691 .85 .959 r
.50171 .15889 .50827 .16427 .52017 .1573 .51365 .15348 Mtetra
.622 .882 .989 r
.51365 .15348 .52017 .1573 .5321 .15182 .52564 .14903 Mtetra
.503 .865 .986 r
.52564 .14903 .5321 .15182 .54409 .14835 .53768 .14581 Mtetra
.407 .824 .971 r
.53768 .14581 .54409 .14835 .55615 .14645 .5498 .14356 Mtetra
.362 .79 .97 r
.5498 .14356 .55615 .14645 .56831 .1457 .56199 .14203 Mtetra
.368 .772 .984 r
.56199 .14203 .56831 .1457 .58056 .14555 .57427 .14092 Mtetra
.412 .764 .995 r
.57427 .14092 .58056 .14555 .5929 .14532 .58664 .13982 Mtetra
.448 .753 .994 r
.58664 .13982 .5929 .14532 .60533 .14487 .59909 .13865 Mtetra
.484 .746 .987 r
.59909 .13865 .60533 .14487 .61783 .14392 .61162 .13724 Mtetra
.503 .74 .98 r
.61162 .13724 .61783 .14392 .6304 .14265 .62422 .13566 Mtetra
.513 .736 .975 r
.62422 .13566 .6304 .14265 .64305 .14119 .6369 .13398 Mtetra
.517 .731 .971 r
.6369 .13398 .64305 .14119 .65579 .13969 .64967 .13229 Mtetra
.514 .724 .968 r
.64967 .13229 .65579 .13969 .66862 .13836 .66253 .13069 Mtetra
.513 .715 .964 r
.66253 .13069 .66862 .13836 .68154 .13716 .67548 .12918 Mtetra
.511 .705 .958 r
.67548 .12918 .68154 .13716 .69456 .13612 .68852 .12776 Mtetra
.51 .693 .951 r
.68852 .12776 .69456 .13612 .70769 .13525 .70165 .12647 Mtetra
.733 .766 .879 r
.01926 .36808 .02714 .37496 .03774 .36791 .02975 .36192 Mtetra
.737 .792 .897 r
.02975 .36192 .03774 .36791 .04835 .36098 .04026 .35584 Mtetra
.74 .819 .914 r
.04026 .35584 .04835 .36098 .05896 .35414 .05078 .34981 Mtetra
.74 .847 .93 r
.05078 .34981 .05896 .35414 .06958 .34737 .06131 .34386 Mtetra
.737 .874 .944 r
.06131 .34386 .06958 .34737 .08021 .34069 .07186 .33797 Mtetra
.73 .9 .955 r
.07186 .33797 .08021 .34069 .09086 .33399 .08243 .33215 Mtetra
.716 .925 .962 r
.08243 .33215 .09086 .33399 .10155 .32719 .09302 .3264 Mtetra
.689 .948 .958 r
.09302 .3264 .10155 .32719 .11228 .32023 .10363 .32071 Mtetra
.635 .956 .929 r
.10363 .32071 .11228 .32023 .12306 .31302 .11426 .31508 Mtetra
.536 .925 .848 r
.11426 .31508 .12306 .31302 .13387 .30574 .12491 .30953 Mtetra
.395 .835 .708 r
.12491 .30953 .13387 .30574 .1447 .29847 .13558 .30404 Mtetra
0 0 0 r
.13558 .30404 .1447 .29847 .1555 .29159 .14627 .29861 Mtetra
.14627 .29861 .1555 .29159 .16624 .28541 .15699 .29325 Mtetra
.15699 .29325 .16624 .28541 .1769 .28018 .16773 .28796 Mtetra
.16773 .28796 .1769 .28018 .18747 .27615 .1785 .28273 Mtetra
.1785 .28273 .18747 .27615 .19797 .27307 .1893 .27756 Mtetra
.1893 .27756 .19797 .27307 .20844 .27079 .20012 .27246 Mtetra
.48 .898 .839 r
.20012 .27246 .20844 .27079 .21895 .26874 .21097 .26743 Mtetra
.635 .932 .968 r
.21097 .26743 .21895 .26874 .22953 .26647 .22186 .26246 Mtetra
.685 .868 .968 r
.22186 .26246 .22953 .26647 .24021 .26365 .23277 .25756 Mtetra
.688 .8 .934 r
.23277 .25756 .24021 .26365 .25102 .26002 .24372 .25272 Mtetra
.683 .763 .912 r
.24372 .25272 .25102 .26002 .26193 .25568 .2547 .24794 Mtetra
.679 .75 .905 r
.2547 .24794 .26193 .25568 .27295 .25069 .26571 .24323 Mtetra
.677 .758 .912 r
.26571 .24323 .27295 .25069 .28403 .2453 .27676 .23859 Mtetra
.675 .781 .93 r
.27676 .23859 .28403 .2453 .29516 .2397 .28785 .23401 Mtetra
.671 .815 .952 r
.28785 .23401 .29516 .2397 .30633 .23408 .29897 .22949 Mtetra
.66 .85 .973 r
.29897 .22949 .30633 .23408 .31752 .2286 .31014 .22504 Mtetra
.64 .88 .985 r
.31014 .22504 .31752 .2286 .32874 .22343 .32134 .22066 Mtetra
.616 .898 .987 r
.32134 .22066 .32874 .22343 .33996 .21868 .33258 .21634 Mtetra
.596 .904 .984 r
.33258 .21634 .33996 .21868 .3512 .21446 .34387 .21208 Mtetra
.59 .902 .984 r
.34387 .21208 .3512 .21446 .36245 .21075 .3552 .20789 Mtetra
.599 .893 .989 r
.3552 .20789 .36245 .21075 .37374 .20747 .36657 .20376 Mtetra
.616 .873 .99 r
.36657 .20376 .37374 .20747 .38506 .20451 .37799 .1997 Mtetra
.63 .842 .981 r
.37799 .1997 .38506 .20451 .39644 .20169 .38946 .19571 Mtetra
.637 .805 .963 r
.38946 .19571 .39644 .20169 .40788 .19885 .40097 .19178 Mtetra
.638 .77 .943 r
.40097 .19178 .40788 .19885 .41938 .1958 .41254 .18792 Mtetra
.636 .745 .927 r
.41254 .18792 .41938 .1958 .43096 .19235 .42415 .18412 Mtetra
.633 .734 .921 r
.42415 .18412 .43096 .19235 .44261 .18825 .43582 .18038 Mtetra
.629 .745 .931 r
.43582 .18038 .44261 .18825 .45432 .18342 .44754 .17672 Mtetra
.621 .78 .957 r
.44754 .17672 .45432 .18342 .46611 .17777 .45932 .17312 Mtetra
.591 .841 .992 r
.45932 .17312 .46611 .17777 .47794 .17155 .47115 .16958 Mtetra
.487 .876 .967 r
.47115 .16958 .47794 .17155 .48981 .16511 .48304 .16612 Mtetra
.268 .773 .769 r
.48304 .16612 .48981 .16511 .50171 .15889 .49499 .16271 Mtetra
0 0 0 r
.49499 .16271 .50171 .15889 .51365 .15348 .50701 .15938 Mtetra
.083 0 0 r
.50701 .15938 .51365 .15348 .52564 .14903 .51908 .15611 Mtetra
.14 0 0 r
.51908 .15611 .52564 .14903 .53768 .14581 .53122 .15292 Mtetra
.147 0 0 r
.53122 .15292 .53768 .14581 .5498 .14356 .54342 .14978 Mtetra
.116 0 0 r
.54342 .14978 .5498 .14356 .56199 .14203 .55569 .14672 Mtetra
.047 0 0 r
.55569 .14672 .56199 .14203 .57427 .14092 .56803 .14373 Mtetra
0 0 0 r
.56803 .14373 .57427 .14092 .58664 .13982 .58044 .1408 Mtetra
.192 .72 .732 r
.58044 .1408 .58664 .13982 .59909 .13865 .59292 .13794 Mtetra
.315 .802 .873 r
.59292 .13794 .59909 .13865 .61162 .13724 .60547 .13515 Mtetra
.4 .834 .951 r
.60547 .13515 .61162 .13724 .62422 .13566 .6181 .13243 Mtetra
.455 .837 .987 r
.6181 .13243 .62422 .13566 .6369 .13398 .63081 .12979 Mtetra
.49 .825 .999 r
.63081 .12979 .6369 .13398 .64967 .13229 .64359 .12721 Mtetra
.512 .807 .999 r
.64359 .12721 .64967 .13229 .66253 .13069 .65646 .1247 Mtetra
.529 .784 .991 r
.65646 .1247 .66253 .13069 .67548 .12918 .66941 .12226 Mtetra
.541 .759 .977 r
.66941 .12226 .67548 .12918 .68852 .12776 .68244 .1199 Mtetra
.549 .732 .96 r
.68244 .1199 .68852 .12776 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Nooooo`;oR/;j1?n<^oD00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo057ooooo001Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool07Oooool3o`0000;ooooo00?o0000ooooooooool0F?oo
ool2ohO8o@GoR/;j0on<^oD00ol0003oS;_eooooo`0Eooooo`03o`000?oooooooooo053ooooo001P
ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0001cooooo0_l0001Kooooo`?oPlko1On7
b?d5oh[2nP;oS;_e00?o0000oh:aloooool05?ooool00ol0003oooooo`00001Aooooo`00H?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00006_ooool3o`0005Gooooo
0omde_`5oggCo`CoPlko0_n7b?d2oh>gmPKoP[Ce00CoP[7co`000?n2/O?oP[7c5_ooool00ol0003o
ooooooooo`1?ooooo`00H?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoo
oooo00006?ooool2o`0005Cooooo1?mVeO<4ogCFo0;oOM?o0_n4^oP5oh>im`CoPkOf1_n2]?D01?l0
003oP[7coh:alon2/O<Fooooo`03o`000?oooooooooo04kooooo001Pooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`00000Eooooo`?o00000_ooool00ol0003oooooooooo`1=
ooooo`CoD<gO0_mVeO<2oh2mnPGoPkci1?n4^oP5oh>im`CoPkOf0on2]?D2oh:[k`04o`000?moZo3o
Oj_`ogn[l1Kooooo00?o0000ooooooooool0C_ooool0063ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03onk^k_m4A4Co000001?ooooo0_l0001Aooooo`;o<KRk0omb`?h4og^no0CoP;gj1On3
_?T4ohBkn0;oPkWg0_n7ZN`4ohB[kPGoPZ__00?o0000ogn[l?moZo000_moZo0Fooooo`03o`000?oo
oooooooo04gooooo001Pooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0?ooooo`?o0000B_ooool01OlM003o3000o``00?l<003o000000;oG/Gk1?mY`oh4og;0oPCoNkkl
1?n0_OX2oh>ln@;oRZGW1?n9Z>T5ohNYk0CoQ:_^1?n2Znl00ol0003oOj_`ogn[l003ogn[l1Kooooo
00?o0000ooooooooool0C?ooool008;ooooo0_l00019ooooo`;o9@000_lM00000ol<003oG<[hoec:
n002oek5n`;oOI[T1?mnVN<4oh6JhPCoQYkS1?n8XN@5ohZUi`CoRJSY1On7ZN`4ohB[kP;oPZ__00?o
QZKYo`000?n2ZNh01?n2ZNhFooooo`03o`000?oooooooooo04cooooo001oooooo`?o00000_ooool0
0ol0003oooooooooo`12ooooo`;o8`000olU00000olM003oT:?Roi2ShP04ohBNi0CoOI[T1?mnVN<4
oh6JhPCoQYkS1?n8XN@5ohZUi`CoRJSY0_n7ZN`2ohfPh@CoRZ?U0on6Y^T00ol0003oQZKYoh:YkP04
oh:YkQCooooo0ol0001=ooooo`00O?ooool3o`0004Kooooo0_lE0003ob<00004obD00?nNZ=goWZSM
oijXg@CoT:?R1?n4W^@3ogfJi0CoOYWS1?n1V^85ohJNh`CoR:7T0_n:YNL2oi2Ge`CoT9cK1On=X>44
ohZSi@;oQZKY00?o0000ohJVjOn6Y^T01?n2ZNhGooooo`03o`000?oooooooooo04[ooooo001joooo
o`;o0000A_ooool01Ol0003o5@00oaD00?lE003o8`0000?o[:WD1?nNZ=d5oi2ShPCoQ9kT0ommV^@4
ogjIh`CoPI[R0_n6W^<2oh^<cPCoSY;B1On@UmL4oi2Lf`GoSJ3Q1?n:XnD2ohJVj@03o`000?n>Y>?o
RZWZ00CoRZWZ5_ooool00ol0003oooooooooo`1:ooooo`00Moooool3o`0004Kooooo0_l000000olE
003o/=Weok:Vc@05ojbYe0GoWZSM0_n@Xn82oi25a0CoQh760on3P<L4ohB2b@CoQXK<1On;S<h4ohjB
dPCoT9OG1On@W=/2ohfPh@;oU9WF1?nBW]d2ohjTh`03o`000?n>Y>?oSZCS00GoRZWZ5_ooool00ol0
003oooooooooo`19ooooo`00MOooool2o`0000;ooooo00?o0000ooooooooool0@_ooool01?l0003o
^<_XokS;j?n`fOD4ok:Vc@Go[:WD0_nNZ=d2oi^:`@GoT8G41?n7PLH3oh>0a`CoQ8;91?n6Q/`4oh^<
cPCoSY;B1On@UmL2oi2Lf`;oUYC@1OnDVMH4oi:Ng@03ohjThol0003oSZCS00;oSZCS0_n:ZNX2oiJ^
iaOooooo00?o0000ooooooooool0B?ooool007;ooooo0ol00005ooooo`03o`000?oooooooooo03ko
oooo0_m4aL@4okS;j0Go/ZK=1?n/ZM@00onVS[coVh[1oi^:`@03oi^:`@CoT8G41?n7PLH3oh>0a`Co
Q8;91?n6Q/`4oh^<cPGoSY;B0_n@UmL2oiJ?bPGoUYC@1?nDVMH5oi:Ng@04o`000?n>Y>?oVJOOoiVW
g`GoUZkW5_ooool00ol0003oooooooooo`18ooooo`00L?ooool2o`0004Kooooo0omlh?L2okNmg`?o
^<_X0_neXlH5ok:Vc@03ojbYe?nVS[coYXjl00;oYXjl1?nKR/44oi25a0CoQh760on3P<L4ohB2b@Go
QXK<1?n;S<h2ohjBdP;oU8W51OnFSlX4oiJDd0GoU9WF0_nBW]d2oi^Qf003o`000?nIYmooVJOO00;o
VJOO1OnF[^LFooooo`03o`000?oooooooooo04Oooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol0000Pooooo`?o0000A?ooool4oiOGo@03ogcPmong_Moo]kgO00?o
]kgO00Co^<_XokFSa_neXlKo]J?61?nbY/d00on/SkSoYXjlojJ>_003ojJ>_0CoVh[11On@QL@4ohN1
aP?oPh371?n4P/T2ohJ6c0;oS7bm1?nAPl05oiB9a@CoUXo:1OnFU=02oiBIeP;oWI_A1?nKXMP00ol0
003oVJOOoiVWg`03oiVWg`;oUZkW0_nR]>DEooooo`?o0000B?ooool003Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A401kooooo0_l00003
ooooo`03o`000?oooooooooo03gooooo0onNao@4oiOGo@03ok>dfOng_Moo]kgO00?o]kgO00?o/io3
okFSa_neXlH00_neXlH3ok:Vc@?o[8nh1?nVS[`5oi^:`@CoT8G40_n7PLH2ohUd]P?oQWBg1?n9N;X5
ohal_@CoTH?01?nDRLD4oiJ?bPCoUYC@00?oWYK;oifKdOnMVm400onMVm43oi^Qf003o`000?nIYmoo
VJOO00;oVJOO00?oXjcMoj:diOnR]>D00onR]>DFooooo`03o`000?oooooooooo00Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo02Wooooo000h
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Looooo`?o0000@Ooo
ool3oj6nkPGoW/Od00?oUmOmok>dfOnc]=T00_nc]=T3okNmg`?o/io31?neXlH00onbY/go[8nhojb?
^002ojb?^0GoYXjl0onKR/400onHNk;oT7Ndoi1g]002oi1g]0CoRGBf1?n6M;L4ohUh^PCoS7bm1?nA
Pl04oiB9a@GoUXo:00?oUYC@oijFbonNU//00_nNU//4oifKd@?oVj7H00?o0000oi^Qf?nIYml01?nS
[=d5oj:diAKooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B47ooooo`03o`000?oooooooooo02[ooooo000hooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP0Hooooo`?o0000@Oooool2oj:kj`GoXKk^0_nNao@2ojj^f0Ko/kCI
00?o]kgOok>O`oncWl<00_ncWl<4okFSaPGo[8nh1OnVS[`01?nKR/7oV7^boiQk/_nHNk84oi1g]0Go
RGBf0on6M;L4ohUh^PCoS7bm1?nAPl05oiB9a@;oUXo:0_nMT<D5oijFb`GoWI_A0_nKXMP00ol0003o
YJKFoj>/g@05oj>/g@;oX[CU0on]^^<Fooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000:oooool003Sooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Gooooo0ol00012ooooo`CoX[_[0onQ_^h00onY[M[o[ZkHojj^f003ojj^
f0Co/kCI00?o/9_3ok>O`oncWl<00oncWl<3okFSaP;o[i2e1On/SkP3ojJ>_003oj:0[onHNk;oV7^b
00?oV7^b1?n@Mk@4ohUd]PCoQWBg0on9N;X5ohal_@CoTH?00_nDRLD2oi^9_`GoWI351?nNU//4oifK
d@04ojJPd?nUY]KoYJKFo`0000;oYJKF1?nS[=d00on]]=go[K[Sojfjh`04ojfjhaGooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
;?ooool003Sooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo017ooooo
0ol00003ooooo`03o`000?oooooooooo03cooooo0onR_^d5oj:kj`04oj6nk_nY[M[oZJgJojV]fPGo
[ZkH00?o/kCIok2K`on`Vl<00_n`Vl<5ok>O``04okFSa_n_T;Go[i2eojn@]@Go[8nh00CoYXjloj:0
[onRP:ooXX2_1OnHNk84oi1g]0CoRGBf1?n6M;L4ohUh^PCoS7bm0_nAPl02oiR3^`GoVhVo1?nMT<D5
oijFb`03oifKdOnVX=3oYZ3@00;oYZ3@00?oYJKFo`000?nUY]H00_nUY]H00onS[=go[KCMojfdg@02
ojfdg@Co[K[S00?o]L7Sooooooooool05?ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000002oooool01?oMgMgoEEEEooooool0000/ooooo`00>?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Aooooo`;o0000@Oooool3oj?5l@Go
X[k]0_nR^n/2ojB_g`CoZJgJ1?n^[]P00on[VLGo/9_3ok2K``03ok2K``Co/io300?o[Xjdojn@]On_
T;D00on_T;D4ojb?^0GoXX2_1?nHNk84oi1g]0GoRGBf0on6M;L4ohUh^P;oS7bm0_nBO;P5oiR3^`Co
VhVo1?nMT<D4oijFb`03ojNKbOnVX=3oYZ3@00?oYZ3@00GoYJKFo`000?nUY]KoYJKFojj_f006ojfd
g@03ojfjhone`N?o]L7S00;o]L7S5_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`00000/ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00>ooooo`?o0000@?ooool3oj?>mPCoXlGa0_nR
_^d2oinciPGoY:oO1?nY[MX00on^[]SoZiW5oj^Ia@02oj^Ia@Go/9_300?o/io3ojj>]?n^S[@00_n^
S[@4ojn@]@?o[8nh00?oYh:]oj:0[onRP:l00onRP:l4oiQk/PGoT7Nd1?n9M;H4ohId]`;oRGRj00?o
SWNdoi9l^?nBO;P00_nBO;P5oiR3^`CoVhVo1OnMT<D00onNU/_oYi_9ojNKb@02ojNKb@GoYZ3@00?o
0000ojj_f?n^[mP00_n^[mP4ojfdg@03okJngone`N?o]L7S00Co]L7S5?ooool2o`0000Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002cooooo001Iooooo`?o0000?ooo
ool2oj7Gn`GoXlkf0_nSaO400onK^^koWk?VoinciP03oinciPGoY:oO0_nY[MX00onSVL[oZiW5oj^I
a@03oj^Ia@Co/9_300?oZH^fojj>]?n^S[@00on^S[@5ojn@]@04ojb?^?nWPZgoYh:]ojN2[@CoXX2_
1OnHNk84oi1g]0;oRGBf0_n=L[04oh]b/P?oSWNd1OnBO;P4oiR3^`GoVhVo0_nMT<D2ojJEa0GoYi_9
1?nVX=000on`Z];o0000ojj_f004ojj_f003ojfdgOnf_]oo][kO00;o][kO1?ne`N<00onja^?ooooo
ooooo`0Aooooo`04o`000?ooooooooooo`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=oooo
o`03ogMgMol0003ooooo02_ooooo001Fooooo`?o00000oooool00ol0003oooooooooo`0jooooo`Go
XMOk0_nSc_H2oiO1m0CoVk[^1?nO/nH4ojB_g`03oibJdOnSVL[oXiW:00;oXiW:1?n[VLD3ok2K``;o
ZH^f1On^S[@4ojn@]@03ojZ3ZonWPZgoYh:]00;oYh:]1OnRP:l4oiQk/P;oT7Nd0_nAM:l4oheb/0Co
Rg:b1?n>Mk@4oi9l^0GoV8>k0onKRKl00onTSkkoYYG4ojJEa003ojJEa0GoYi_900GoYZ3@ok2Zd_n`
Z];o/:[Bo`000004ojj_f003okRlgOnf_]oo][kO00Co][kO00?o]L7Sok[6honja^<00_nja^<Foooo
o`03o`000?oooooooooo043ooooo001Dooooo`;o0000@Oooool3oigOo@;oXMOk0onDbOT4oiO1m0Co
Vk[^1?nO/nH00onT[mooW9[AoibJd@02oibJd@CoXiW:1?n[VLD00on`Vl?oZH^fojV;]P02ojV;]PGo
[Xjd0_n_T;D2ojZ3Z`CoYh:]1OnRP:l2oiQk/P;oVGV^1?nAM:l5oheb/0CoRg:b0on>Mk@4oi9l^0Go
V8>k00?oVhVoojB?__nTSkh00_nTSkh4ojJEa0CoYi_900?o/ZO=ok2Zd_n`Z]800_n`Z]801?l0003o
[ZoHojj_f?n^[mP3okRlg@Co][kO00?o^lOSok[6honja^<00onja^<Fooooo`03o`000?oooooooooo
043ooooo001Aooooo`?o0000?oooool4oiWTo@;oWMom0onDco`4oiC9n@CoUl7d0_nK^^h00onAXMoo
UIgIoiFMf@02oiFMf@GoW9[A1?nSVLX3oj^Ia@03oj>8^?nYRkKoZH^f00?oZH^f1On^S[@00on_T;Go
ZX>[ojZ3Z`02ojZ3Z`?oYh:]1?nRP:l00onSOjgoVGV^oiUi[P02oiUi[PGoTGB_1?n=L[04oh]b/P?o
SWNd1OnBO;P3oiR3^`03oj28^_nTSkkoY8nn00?oY8nn1OnVUL@00onWVlWo/ZO=ok:Wc@02ok:Wc@?o
/:[B00?o0000ok2Zd_n^[mP01Onh_=d00onf_]oo^lOSok_7h`02ok_7h`?o^/KS0_nlc>HFooooo`03
o`000?oooooooooo03oooooo001>ooooo`Go0000?Oooool3oiOVn`;oVNCm0onFeOd5oiC?o0;oU<Wi
00?oSj[XohnUi?n?YN@00_n?YN@4oi6Qg`CoUIgI1?nLV]45oj>IbP03oj^IaOnSR;SoXhRh00GoZH^f
1?n^S[@00onWPJ[oZX>[ojZ3Z`03ojZ3Z`CoYh:]0_nRP:l2oj=o[@GoVGV^1?nAM:l4oheb/0CoRg:b
1?n>Mk@4oi9l^003oiR3^onPR;[oX8Rj00;oX8Rj1?nTSkh4ojJEa003ok:SbOnbYlgo/ZO=00?o/ZO=
0on`Z]800ol0003o^[cKokRlg@04okRlg@03okg9i?nkan?o^lOS00Co^lOS00?o^/KSokc<i_nlc>H0
0_nlc>HFooooo`03o`000?oooooooooo03kooooo001<ooooo`;o00001Oooool00ol0003ooooooooo
o`0hooooo`CoUnKk0_nLf_d5oiKEo@;oU<ol0_nC[nT4ohnZj0CoSjGT0onAXMl4oiFMf@GoW9[A0_nS
VLX2oiV5_0CoXhRh1OnYRkH2ojj>]0;oYh6Z1OnZPj/4ojN2[@03oj:0[onSOjgoXgn]00;oXgn]1?nI
NJh4oi5d[`CoSG:`1On;L[83ohig]0;oTWbh0_nJPKH5oj28^PGoY8nn0_nVUL@3ok:Sb@Go/ZO=00?o
/:[BokZlfol000000_nj_=/3okRlg@?o_LWT1?nkan<00onmd>Wo_<cVokc<iP02okc<iP03ok[>jOoo
oooooooo01Cooooo00?o0000ooooooooool0?_ooool004Wooooo0ol00010ooooo`?oV>Ok0_nTg?/4
oicJo@;oU]Gm0_nI/nX5oi>_j@?oSj[X1On?YN@3oi6Qg`CoUIgI0_nLV]42oi:4`@GoVHFl0onSR;P5
ojV;]P03ojj>]?nWPJ[oYh6Z00;oYh6Z1?nZPj/4ojN2[@GoXgn]1?nINJh4oi5d[`GoSG:`1?n;L[82
ohig]003oiEk/onJPKKoVX6f00?oVX6f1?nPR;X5ojB?_P03ojJEa?nbXlWo/Z?900;o/Z?91?nbYld0
1Onn_MWo^[cKokZlfonj_=_o000000;o^[cK00?o^;cMokg9i?nmbN@00onmbN@00onkan?o_M3Yokg@
j@02okg@j@03okc<i_njc^Wo^/kY00;o^/kY5?ooool3o`0003oooooo000Rooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h08?ooool2o`0003oooooo1?nMiO`00onHio_oY=ckojCLn`03ojCLn`;oW=[m0onP
]nT3oiVcjPGoTjoY0on?Z^P2ohnUi0;oRHK:0on8Q<P4oh^3a@GoTXC11?nIQK`3oj>8^0CoZH^f00?o
XWf[ojN1Z_nWPJX00onWPJX5ojZ3Z`;oYh:]00?oZH>/oj=o[OnSOjd00onSOjd4oiUi[PGoTGB_1?n=
L[02oh]b/P;oT7Ja1?nENk<4oiZ1]PGoX8Rj0onTSkh00on`W/Go/Z?9ok:Sb@03ok:Sb@?o/ZO=0onn
_MT2okZlf`04o`000?nj_=_o_lgToko=i0Co_LWT00?o_MO]okg@jOnmd>T00_nmd>T00onhe^oo^/kY
ok[>j@04ok[>jAGooooo00?o0000ooooooooool0?Oooool002;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Mooooo`?o00000_ooool00ol0003oooooooooo`0iooooo`CoXn7l0_nMiO`3ojcLn0;oY=ck
0onX^^H5oj2gj@?oVK?Z0_nC[nT2oi2:b@?oS8S:1On9Q/X3ohR4b0CoRh?51?nBQ<44oiV5_0CoXhRh
0_nYRkH2oj9mZ`GoYh6Z1OnZPj/01?nWPZgoZH>/ojV3[?nYPj`4oj=o[@GoVGV^1?nAM:l2oheb/0;o
T7B`1?n@M[44oiEk/`CoVX6f1OnPR;X00onTSkko/9k5ok2Na@02ok2Na@Go/Z?900?o/ZO=okjmfOnn
_MT00onn_MT00onj_=_o0000oko=i003oko=i003okg9i?nmengo_MO]00;o_MO]00?o_M3YokSFkonh
e^l00_nhe^l4ok[>j@;o/lk^5Oooool00ol0003oooooooooo`0looooo`008_ooool01Ol@413ooooo
oooooooooooo410@01_ooooo0_l00010ooooo`CoXn7l0_nbf?@3ojcLn0;o[k_S1OnX^^H2oj2gj@;o
VY380onESLP5oi2:b@?oS8S:1?n9Q/X4ohR4b0?oRh?51?nBQ<45oiV5_0?oXhRh00?oZH^foj9mZonR
OJ/00_nROJ/4ojN1ZPCoZX>[00?o[HF[ojV3[?nYPj`00_nYPj`4oj=o[@GoVGV^0_nAM:l2oi=g/0Co
T7B`1On@M[44oiEk/`CoVX6f0onPR;X00on]V<7o/9k5ok2Na@03ok2Na@Co/Z?900?o`KkHokjmfOnn
_MT00onn_MT2olCDiP05o`000?nocNCo_lgToko=i?nnhO001?nmend2okKNm0Go^=K_00?o^/kYok?>
k_ncc^h00oncc^hEooooo`03o`000?oooooooooo03_ooooo000Rooooo`05o`000?oooooooooooooo
ool000006?ooool3o`0003oooooo1?nXfOT00onShOco/]Sdok;Hm003ok;Hm003ojcLn?n_^n?o[k_S
00;o[k_S0onX^^H00onPTlKoVY38oiZ@b003oiZ@b0?oUHg81?n@R/T3ohb8bPCoRHK:1?n8Q<P3oh^3
a@GoTXC11?nIQK`2oj>8^003oiYh[?nROJ_oXWf[00?oXWf[1OnWPJX2ojZ3Z`;o[HF[1?nYPj`5oj=o
[@?oVGV^00?oVgfaoi=g/?nCMk000_nCMk05oi1d/0CoT7Ja1?nENk<4oiZ1]P03oj28^_n]V<7o[IS1
00;o[IS11On`W/D00onbXlWo`KkHol6nf002ol6nf0?o_[gI0oo4e>H00ol0003o_lgTokkQl003okkQ
l003okgGkOnfg_Co]]kd00?o]]kd0_nhe^l3ojoGm@Co/lk^00?oZ<Waooooooooool04oooool00ol0
003oooooooooo`0kooooo`008_ooool01Ol0003ooooooooooooooooo000001Kooooo0ol0000noooo
o`;oZm3c1?nXfOT3okGBk`;o/]Sd0onc^ml5ojnkh`04ojRji_nPTlKoX9?6oj2CaPCoVY380onESLP4
oi2:b@?oS8S:1On9Q/X4ohR4b0?oRh?51?nBQ<42oiV5_0;oT7:]0onJN:`5oj9mZ`GoYh6Z00?oZX>[
ojf5Zon]QJ/00_n]QJ/3ojV3[0GoXgn]00CoVGV^oi]m/OnKOK7oVgfa1OnCMk04oi1d/0CoT7Ja1?nE
Nk<3oiZ1]P03ojJ@__n]V<7o[IS100?o[IS11?n`W/D00oo3_]Ko`KkHol6nf004ol6nf003okjmfOo4
e>Koa=CV00;oa=CV00?o0000okg]lonnhO000_nnhO02ok3Xn0Co]]kd0_nXh?X5ojoGm@03ok?>k_nX
bO7oZ<Wa00;oZ<Wa5Oooool00ol0003oooooooooo`0jooooo`008_ooool01Ol@413ooooooooooooo
oooo410@01?ooooo0ol00002ooooo`03o`000?oooooooooo03_ooooo1?n[d?<00onXfOWo]M;_okGB
k`02okGBk`03okJifonc^moo/k_O00Co/k_O0_n_^n<2ojFFa@CoX9?61?nJT<P4oiF=b0CoT8[90on<
R<X2ohV6bP;oQfb^1?n4Jjl3ohA/[`CoRFj^1?n@LZd4oiYh[0CoXWf[1OnWPJX5ojf5Z`CoZH>/0onS
Ojd00onVQ[;oVgfaoi]m/@03oi]m/@CoTgN`1?n@M;04oi1f/@GoUG^c00CoVX6fojJ@__nVT;koYY2n
1?n]V<43ok2Na@?o`kkF1?o1_]P2olSLj0?oa=CV00Go_Ngco`000?nmkO?o_NgcokkQl004ok3Xn003
okKNm?nXh?[oZ>3j00?oZ>3j0_n_eoD3oj?An0CoZ<Wa5_ooool00ol0003oooooooooo`0iooooo`00
8_ooool01OmgMgOoV9RHoooooonHV9SoMgMg013ooooo0ol00010ooooo`Co[<O^0_n[d?<4okK;jP04
okGBkonf^M_o][WKokJif`Co/k_O00?oZYS4ojFFaOnUU/D00onUU/D3oj2CaPGoVY380_nESLP00on?
L:_oS6n/oha_[002oha_[0?oRFf]1?n7K:h4ohA[[`?oQ6b_1?n9KZh5oi1b[@?oVWR/1?nROJ/4ojN1
ZP03oj^4[?n]QJ_o[HF[00?o[HF[1?nYPj`01?nSOjgoYXJbojJ6/_nVQ[85oi]m/@CoTgN`1?n@M;05
oi1f/@?oUG^c00?oX8RkojJ@__nVT;h00_nVT;h5ojfH`@03ok2NaOo3_]Ko`kkF00?o`kkF00?o`KkH
olSLj?o8g>P00oo8g>P01Oo4e>Ko_Ngcokg]lol0003o_Ngc00;oXO3f0_n`j?P4oi[Vo0;oZ>3j0onJ
eod5oj?An0;oZ<Wa0_nM`_8Dooooo`;o0000>oooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0>ooooo`;o0000@?ooool2ojg2j@Co[<O^0_nd`^@4okK;jP03okNfeonf^M_o][WK00?o][WK00?o
/k_OojZHa?nZV<@00_nZV<@4ojFFa@CoX9?60_nJT<P2oi9bZ`?oSg2[1?n<Kj`3ohU][@GoQfb^0on4
Jjl4ohA/[`CoRFj^1?n@LZd3oiYh[0GoXWf[0_nWPJX3oj^4[0Co[HF[1?nYPj`5ojJ6/PCoVgfa1?nC
Mk05oi1d/0CoT7Ja00?oUG^coj28^onPR;/00_nPR;/4ojJ@_PCo[IS11Oo3_]H2olgTj0Cob=cX0ong
mnl01?nmkO?o0000oj7`m_nQl?H3ogoTl`;oV^Kl0on<f_l5oi[Go@;oXm7h0_nHaoL5oig2lQGooooo
00?o0000ooooooooool0>?ooool003;ooooo1Ol0000mooooo`03ojfoion]`^Wo[L;Y00?o[L;Y00?o
[<O^okC2i?nd`^@00ond`^@00onfbn[o]kKGokNfe`02okNfe`?o][WK00?o[I[3ojZHa?nZV<@00onZ
V<@5ojFFa@;oX9?600?oUWB[oi9bZonBLZ/00_nBLZ/4ohm`Z`CoS6n/0on9KJd4ohM/[P?oQ6^_1?n4
K:l4ohU^[PCoT7:]0onJN:`5oj9mZ`03ojN1Z_n[Q:coZhB/00;oZhB/1On]QJ/2ojV3[003ojn>/onV
Q[;oYXJb00?oYXJb1?nKOK45oi=g/0CoT7B`0_n@M[42oiR1^0GoX8Rk1?nVT;h3ojfH`@;o`KcE0oo3
_]H4olgTj003olSLj?ngmnoo]oO_00;o]oO_00?oQ>[Oo`000?l000000omoi?<4ogGGo0CoS=[o0_nJ
eod2oi;9nPGoV<Og0_nM`_82oiFjlAKooooo00?o0000ooooooooool0=oooool0033ooooo0_l00010
ooooo`Co[KoW0on]`^T2ok6jg`Go]<;T1_ng]]L01?nf^M_o[I[3ojfJ`on]V/<4ojZHa0CoYIK500Co
VGN[oiIdZonFM:_oUWB[1OnBLZ/3ohm`Z`CoS6n/0on9KJd4ohM/[PCoQ6^_0on4K:l4ohU^[PCoT7:]
1?nJN:`3oj9mZ`03ojB1[On[Q:coZhB/00?oZhB/1On]QJ/01?nYPjco[hjcojn>/on_S[<4ojJ6/PGo
Vgfa1?nCMk02oi1d/0;oUGfg1OnHPKP4oj28^`GoYY2n00?o[IS1ol6leOo1_=D00_o1_=D00oo3_]Ko
cNCXolgTj002olgTj0?oY_SK00Ko]oO_o`000?l0003o0000oeKAdol00003oe[>l@;oMMOl0_n2a?d4
oh_8o0GoT/Wj0_nHaoL2oi>jlPGoUK[a5Oooool00ol0003oooooooooo`0gooooo`00;Oooool3o`00
043ooooo0_n^`nT5ojfoi`03ojg2jOna^]oo/K[O00;o/K[O0ond`^@2okJad`Co]kKG00?o[i[2ojfJ
`on]V/<00_n]V/<5ojZHa004ojFFaOnIMj_oVGN[oiUgZ`CoUWB[1?nBLZ/3ohm`Z`CoS6n/0on9KJd4
ohM/[PCoQ6^_0on4K:l4ohU^[PCoT7:]1?nJN:`01?nROJ_oY86]ojB1[OnTPJd5oj^4[0Go[HF[1?n_
S[<4ojJ6/PGoVgfa0_nCMk02oiAm]`CoUGfg1OnHPKP5oj28^`?oYY2n00?o_;KDol6leOo1_=D00_o1
_=D2olgZjP?ocNCX0_nVn=/3o`000003ogJ/m?mf]?WoM[Ci00;oM[Ci00?o0000og^mnomk_O/01On2
a?d4oh_8o0;oT/Wj0onA^O84oi>jlPGoUK[a5Oooool00ol0003oooooooooo`0fooooo`00;?ooool2
o`0003oooooo00?o/<c_ojk3jOn^`nT00on^`nT2ojfoi`;o[K;L1_na^]l00ond`^Co][7CokJad`02
okJad`03okNfeon_V/;o[i[200;o[i[20on]V/<4ojZHa003oiaiZonIMj_oVGN[00;oVGN[1?nFM:/4
oi9bZ`?oSg2[1?n<Kj`3ohU][@CoQfb^1?n4Jjl3ohA/[`CoRFj^1On@LZd2oiYh[003oi]k[onTPJgo
Y86]00?oY86]1?n[Q:`4ojf5Z`03okJE]On_S[?o[hjc00;o[hjc1OnVQ[83oi]m/@03oiZ2^?nDOKOo
U7fg00;oU7fg1OnEOKL4oiR1^0GoX8Rk00?oYY2nokbfe?nl]]@00_nl]]@2ol6le@CocN[Z00CocNCX
o`000?l0003o00001Omf[?@4ogJdn@03o`000?mk_O_oNkgk00;oP/Cm0_n>/>d5oi2fl@GoTKWb1?nC
^_82oiFjl@?oTk?]5Oooool00ol0003oooooooooo`0eooooo`00;?ooool3o`0003cooooo1?n`c>l3
ojk3j@;oZ:cJ1?n]/]`4ok6jg`03ok>Zconf/M?o][7C00?o][7C1On_V/84ojfJ``04ojZHa?nLNJ_o
W7V[oiaiZ`CoVGN[1?nFM:/4oi9bZ`?oSg2[1On<Kj`3ohU][@CoQfb^0on4Jjl4ohA/[`CoRFj^1?n@
LZd00onJN:coVg^_oi]k[`05ojB1[@GoZhB/0_n]QJ/3okJE]@?o[hjc1OnVQ[801?nKOK7oVX:hoiZ2
^?nJP[P5oiAm]`CoUGfg1OnHPKP3oj28^`03ok>]d_nl]]Co_;KD00?o_;KD00Co`KcEolgZj_o=j^[o
cN[Z0ol00004ogRTkP;oMZcd0_n<U=H4ohbNg`04ohfXiol0003oSJSWohfXi`CoS[3]1On@]_42oi6i
lP;oUJ_V1OnD[nT5oi>ckACooooo00?o0000ooooooooool0=Oooool002cooooo00Co0000ooooool0
003o0000>Oooool2ojoNm`Go/<c_00?o[/?YojR/f_nX[=X00_nX[=X4ojfbg003ok6jgoncZ/oo/j[?
00;o/j[?0onf/M<2ok2J`0Co[i[20on]V/<00onONjcoW7V[oiaiZ`03oiaiZ`CoVGN[0onFM:/4oi9b
Z`CoSg2[1?n<Kj`3ohU][@CoQfb^0on4Jjl4ohA/[`CoRFj^0_n@LZd2ohmd/0CoVg^_1?nTPJd5oj^4
[003ojf5ZonfUKGo]YFe00;o]YFe1?n_S[<3ojJ6/P03ojF<^_nJP[SoVX:h00?oVX:h1?nDOKL4oiEm
]`GoV86h00?oX8Rkok>]d_nc[M800_nc[M84okbfe004olc]jol0003o0000o`0000?oSXC51?n=Rld5
ohbDePCoS9kO00Co0000ohfXion=Z>OoSJSW1?n>/>d2oi2fl@;oUZKQ1OnEZnH5oiB_j@;oTk?]0_nH
/^TCooooo`03o`000?oooooo000000Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<01Wooooo000/ooooo`;o00000_ooool00ol0003ooooo
ooooo`0eooooo`Co[mkg0_n`c>l2oj:Yg0KoZ:cJ0_n]/]`00on^X/co/j[?ok>Zc`04ok>Zc`04okJa
don`V/3o/9[0ok2J`0Go[i[200?o[I[3oimk[?nONj`01OnLNJ/4oiUgZ`?oUWB[1OnBLZ/3ohm`Z`;o
S6n/0_n=K:P3oh]/ZPCoRFb/0on5Jjh4oh=//0CoQfna1?n?M;04oi]k[`CoY86]1?n[Q:`00ongVKWo
]YFeokJE]@03okJE]@Co[hjc00?oYXJbojF<^_nUS;X00_nUS;X4oiZ2^0CoU7fg1OnEOKL3oiR1^003
ojNQconc[M;o/jgB00?o/jgB0_nl]]@4o`0000;oSgnn1?n>Q<D4ohf;c@CoS9CF1?n<W]l01?n=Z>Oo
0000oiRIdonHVM<4oiNPf`GoUZKQ1OnEZnH2oiB_j@;oVZcS1OnH/^TEooooo`03o`000?oooooooooo
00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonH
V9So8B4Q01Wooooo000[ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<Oooool4
oj;^m`;o[mkg0_nKZn44oj:Yg0CoZ:cJ00?oYY[9ojjRc?n^X/`00_n^X/`4ok>Zc`03ojnG__n`V/3o
/9[000;o/9[01?n_V/800onROZcoWg^/oimk[002oimk[0CoW7V[1?nIMj/4oiIdZ`CoTW:[0_n?L:/0
0on?KJOoSFbXohe/Z002ohe/Z0?oRfbZ1?n9K:`3ohE[[PCoPfb`1?n7Kk45ohmd/0?oVg^_1OnTPJd2
oj^4[0?o]iVi1OnfUKD2ojn>/`03ojnF_OnUS;[oYHbj00?oYHbj1?nJP[P5oiAm]`CoUGfg00?oV86h
ojNQconWXLl00_nWXLl4ok>]dP;o00000_o<kN/01?l0003oSgnnohmo__n?Okh4ohj4a@CoSH_=1On<
U=H2ohbNg`04oiRBc?nHVM?oV9WCo`0000;oV9WC1?nGX=/5oiJVh@;oUJ_V0_nKY]d5oiZ/h`CoV;;Y
5Oooool00ol0003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003o
oooooooooooooooo000001Wooooo000[ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0;Oooool4og[UeP;oX^kg00?oUK7[oi^[hOnKZn400onKZn44oj:Yg003ojR/f_nVV/WoYY[900;o
YY[91?n^X/`00oncZ/oo[iNnojnG_P02ojnG_PCo/9[000Co[i[2oj9n[?nROZcoXWj/1?nONj`4oiai
Z`CoVGN[1?nFM:/2oi9bZ`;oTFjW0on?KJL5ohe/Z0?oRfbZ1?n9K:`3ohE[[PCoPfb`1?n7Kk44ohmd
/0?oVg^_1OnTPJd00on[Q:co]iViokNI^@02okNI^@Go]YFe00Co[hjcojnF_On_U[go[iJm1?nUS;X5
oiZ2^0CoU7fg0_nEOKL2oinGc0GoYj7?00Co/jgBo`000?l0003o00000_o5jnl00oo<kN_oTGbiohmo
_P03ohmo_PCoSXC51On=Rld2ohbDeP;oV8_41?nHT/`01?nHVM?o0000oiRIdonHVM<5oiNPf`;oUZKQ
0_nLX=L5oi^Vg@CoVZcS0_nH/^T3oj6diQGooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Iooooo`00:oooool3o`0000Go
oooo00?o0000ooooooooool0:oooool3oh_>oP?oSkkf0onE/N/5oi^[h@;oXZWL00?oWY?8ojJJbOnV
V/T00onVV/T4ojjRc0Go[iNn1?n`V/05oj9n[0?oWg^/1?nLNJ/4oiUgZ`;oUWB[0_nDL:L4oi5^Y`Co
SffW1?n=K:P3oh]/ZPCoRFb/0on5Jjh4oh=//0CoQfna1?n?M;03oi]k[`CoY86]00?o/9VookNI^Ong
VKT00ongVKT4okJE]@03okVQ`On_U[go[iJm00;o[iJm1OnUS;X4oiZ2^0;oU7fg0_nIT<T5oinGc0;o
Yj7?0ol000001?nc[M;oaN__olG[koo5jnl3oi5l^@GoSgnn1?n>Q<D2ohf;c@;oUhBl1?nHRl@4oiRB
c0;oV9WC00?o0000oiRIdonHVM<00_nGX=/2oijKd0GoW:3G1?nKY]d2oiZ/h`;oXZcN1_nQ]>HEoooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo
0000oa0@4?o<c<`06Oooool002_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0W
ooooo`?oSmcn1?n;c_h3ohnnmP?oUK7[0_nKZn42oi>=b@CoWY?81?nVV/T3ojjRc0;o[9>l1?n_Ukh3
ok2J`003ojB0[?nROZcoXWj/00?oXWj/0onONj`5oiaiZ`;oVGN[00?oUg:WoiA`YonDL:L00_nDL:L4
oi5^Y`CoSffW1?n=K:P3oh]/ZPCoRFb/0on5Jjh4oh=//0CoQfna1?n?M;04oi]k[`;oY86]0on`VKl5
okNI^@;o]YFe0oniXL44ojnF_@CoYHbj0_nJP[P2oi^Ab0GoVI390onOUl`3o`0000;oYj7?0onji?@0
0oo5jnooTgZdoi5l^@03oi5l^@?oSgnn00?oUgV`oiMn]_nGO[H00_nGO[H5oiN4_0CoV8_41?nHT/`2
oiRId`03o`000?nPU/[oWY_@00CoWY_@1OnLX=L2oi^Vg@03oj:Uf?nR[=koXZcN00?oXZcN1?nQ]>H0
0on[^^Goooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo01_ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool08_ooool01?l0003oVNOkoiWWnonIio/2ohoLoP03ohnLg?n3T=SoPi3H00;oPi3H0on3
R]43ohZ9c0GoThg90onNTlP5ojJJb@04ojjRc?n/Tkco[9>lojbC_0Go[iNn00Co/9[0ojB0[?nTP:co
Y82/1?nROZ`3oimk[0GoW7V[00?oVGN[oiMbYonGLZL01OnDL:L3oi5^Y`CoSffW1?n=K:P3oh]/ZPCo
RFb/0on5Jjh4oh=//0CoQfna1On?M;03oi]k[`03ojB1[On`VKoo/9Vo00;o/9Vo1OngVKT00onfUKGo
^J71okVQ`@02okVQ`@Co[iJm0onUS;X00onSUlWoVi78oi^Ab003oi^Ab0CoVI390ol00002oinGc003
ojNQconji?Co^^Cd00;o^^Cd1?nCN[@3oi5l^@04ohmo__nGNK3oUgV`oiMi/0GoUgjf1?nGQ;`4oiR;
a0;oV9;<0_nQTL@3oj2FbP03o`000?nPU/[oWY_@00CoWY_@0_nLX=L2ojBPd@CoXZGH1OnR[=h00onQ
]>KoZk[Uoj^ji@02oj^jiA?ooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
0ooMgMgo410@oiRHV00Kooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01kooooo0ol000001?n/k_SoVNOkoiWWnonMZ=d4ohnLg0CoPi3H0on3R]43ohZ9c0CoThg91?nN
TlP2ojJJb@;oYXfj1?n/Tk`4ojnG_P03ojJ1[?nTP:coY82/00;oY82/1?nROZ`4oimk[0?oW7V[00?o
VGBXoiMbYonGLZL00_nGLZL4oiA`Y`?oTFjW1?n?KJL4ohe/Z0?oRfbZ1On9K:`3ohE[[PCoPfb`1?n7
Kk44ohmd/0;oVg^_00?oY9G6ok2I_on`VKl00on`VKl4okNI^@03okZYb?niXL7o^J7100?o^J711On_
U[d01?nUS;[oXiO9oj>GbOnSUlT4oi^Ab004oiV@bOl0003o0000o`0000CoWiO<0_n_f_H3ok[Tm003
oiIi/OnCN[CoTgZd00;oTgZd0_nAO;T00onFMJ_oUgV`oiMi/003oiMi/0CoUgjf1?nGQ;`3oiR;a003
oj:=__nQTLCoXI7400?oXI740_nPU/X00ol0003oX9K:oijKd003oijKd003ojFLc?nTX=7oY:3A00;o
Y:3A1OnRYMP2oj:/gP?oZkCO1On[^^DEooooo`09o`000?ooooooooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@6Oooool0013ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`?o00002_ooool00ol0003ooooo
ooooo`0Looooo`;o00000_n/k_P00on^/M[oWJSMoifXg@02oifXg@CoSicL0on3T=P3oh>:d@?oRXW<
1?nCSLT3oijCb003oij6^OnVSK[oYXfj00?oYXfj1?n/Tk`01?n_UkkoYX6/ojJ1[?nVPJ`4ojB0[0Go
XWj/0onONj`01?nLNJ_oVGBXoiUdZ?nIM:P4oiMbY`CoU72W1?nAKZL3ohm]Y`GoSFbX0on;K:X4ohU/
[0?oQF^^1?n3K;04ohM_/@;oSgB`0_n@S</4ojBEaPGo/9Vo0_ngVKT3okZYb0Go^J710on_U[d00on/
XLcoXiO9oj>Gb@02oj>Gb@;oVi780ol00004oiV@b@03oinGc?n_f_Ko[m[f00?o[m[f00?o^^CdoiIi
/OnFNK400_nCN[@2oiIaY`?oUWF[1OnGNK04oiMn]PGoUhBl00CoV8_4oj:=__nRSKkoXXfn1?nQTL@3
oj2FbP03o`000?nPU/[oWY_@00CoYIc<1?nTX=43oj:Uf003ojb`fon[]=ooZkCO00CoZkCO0_n[^^D2
ok;3iQGooooo00?o0000ooooooooool0;oooool000Sooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41002oooool5o`0000Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0I
ooooo`;o000000?o^nkdokRde_n^/MX00on^/MX4oifXg@CoSicL0on3T=P2oh>:d@?oRXW<1OnCSLT0
1?nNTlSoWXJioij6^OnNQ[T4ojJ=^PCo[9>l1OnVPJ`3ojB0[0GoXWj/0_nONj`00onLMjWoVGBXoiUd
Z003oiUdZ0?oUg:W1?nDL:L4oi5^Y`CoSffW1?n=K:P3oh]/ZP;oRFb/0_n@N[H3ohUk_PCoQ7k51?n6
Q<X5oi2<b`?oY9G61On`VKl00ongVKWo^ZW8okZYb002okZYb0Go^J7100?o[iJmojbQc?n/XL`00_n/
XL`3oj>Gb@;o00000onKTLP2oiV@b@?oX/og1?n_f_H2oiIi/@;oUVnT1?nFLJL4oiIeZ`CoUgV`1OnG
O[H3oiN4_003oj:9^OnRSKkoXXfn00;oXXfn1?nQTL@4oj2FbP03o`000?nUW<coYIc<00?oYIc<1?nT
X=400onRYMSo[;3Kojb`f`02ojb`f`CoZkCO00?o/l;Uok;3i_nb`nH00onb`nHEooooo`03o`000?oo
oooooooo02kooooo000@ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMoooo
ool00006ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05oooool00ol0003o^nkd
okRdeP03okRdePCo[[7J0_nMZ=d00onBQL;oQWc1ohIl`@02ohIl`@?oO7Bn0omnL[`3ohZ9c0;oThg9
0_nBOKT4oij6^@CoYXfj0on/Tk`00onUPJcoYX6/ojJ1[003ojJ1[0?oY82/1?nROZ`01?nONj_oW7NY
oiagZOnLMjT5oiUdZ0?oUg:W1?nDL:L4oi5^Y`CoSffW1?n=K:P2oh]/ZP03oi9g/On@N[KoT7Zf00?o
T7Zf0on9Nkh4ohAna@CoQXC:1?n@S</3ojBEaPCo/9Vo00?o]:oCokZYb?njZLP00onjZLP4okVQ`@03
okJ^dOn/XLco[:7<00?o[:7<0ol000000onSUlWoVi78oi^Ab003oik<m`GoX/og00?o[m[foiQi[onG
KZ801?nFKj@5oiIaY`?oUWF[1OnGNK04oiMn]P03oiN4_?nRRKWoXXVi00;oXXVi0onRSKh5oj6Aa005
oj2Fb_nWVLOoYiW7o`000?nWVLL01OnUW<`2ojBPd@03ojf/e_n//=_o[;3K00Co[;3K00?oZkCOok?2
iOnc`^D00_nc`^D3ok;3iP;o]LSX5Oooool00ol0003oooooooooo`0]ooooo`004?ooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo01Cooooo0oo4j?06okRdeP;o[[7J00?oXHo1oi:5`_nBQL800_nBQL84
ohIl`@;oO7Bn0omnL[`3ohMg^PGoTWfi0onNQ[T5ojJ=^P04ojbC_?nUPJcoYH6/ojF1[0CoYX6/1?nT
P:`2oj9n[0;oWg^[1?nLMjT4oiUdZ0?oUg:W1OnDL:L3oi5^Y`CoSffW0_n=K:P2oi=d[@?oTWNa1On@
N[H4ohUk_P?oQ7k51?n6Q<X4oi2<b`CoY9G600?o/9VookB_dond[m<00_nd[m<5okZYb003okVQ`Onf
[]7o]ZkA00;o]ZkA00Co[:7<o`000?l0003o00000onSUlT2oj7Bn@GoW/cg0_nRcoL2oiYi[@03oiQi
[onGKZ;oUfjR00GoUVnT1?nFLJL3oiIeZ`GoUgV`0_nGO[H2oj>6]@GoXXVi1?nRSKh2oj6Aa0;oZIO3
1?nWVLL00ol0003oYIc<ojFLc002ojFLc003ojn[don][=Ko[JcF00;o[JcF1?n//=/00one`^Co/l;U
ok?2i@03ok?2i@03ok;3i_neb>So]LSX00?o]LSX5?ooool00ol0003oooooooooo`0]ooooo`004?oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool2o`0000oooooo
0_l0000Booooo`04o`000?o4j?3oa>S`olCXl0;o_KGB1?nh]=H00on[UKooXHo1oj6?`@02oj6?`@?o
TXG21?n6O<43ogad_P?oOW:l0on7MkX4oi9m^@CoWXJi0onVSKX00onROZcoYH6/ojF1[002ojF1[0Co
YX6/1?nTP:`00onROZcoWg^[oimkZ`02oimkZ`?oW7NY1?nIM:P4oiMbY`CoU72W0onAKZL2ohm]Y`;o
Tg:[1?nCM:d4oi9g/@CoT7Zf1?n9Nkh3ohAna@CoQXC:1On@S</2ojBEaP03ojF`gond[m?o]:oC00?o
]:oC1?njZLP01?ng^mco]ZkAokJ^dOnf[]43o`0000Co[:7<00?oXiO9oj7BnOnQd_T00_nQd_T2oik<
m`;oVgR[0onJNJd01?nGKJ3oUfjRoiM^X_nGKZ85oiI_Y0CoUW6W1?nFMJ/3oiMi/003oj>3/OnSQ[Go
XhJe00?oXhJe1?nRRKT3oj:=_P03oj^F`OnYUl?oZIO300?oZIO31?nWVLL00ol0003oYIc<ojn[d`02
ojn[d`Go[JcF00?o[;3KokG2i?ne`^@00_ne`^@3ok?2i@;o]/c[1?neb>P00onbbngoooooooooo`0C
ooooo`03o`000?oooooooooo02cooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0oo^k^koA4A4o`000006ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03Oooool0
1Ol0003oan7[olOQjoo7hN_oa>S`00Co_KGB00?o^;CFoj^E_on[UKl00_n[UKl3oj6?`@?oTXG21?n6
O<43ogad_P?oOW:l0on7MkX4oi9m^@CoWXJi00CoYXfjoj9n[?nROZcoXWj/1?nUPJ`5ojJ1[0;oY82/
00?oXWj/oimkZonONj/00onONj/3oiagZ@CoVGBX1?nGLZL4oiA`Y`;oTFjW00?oTg:Zoi=bZonCLZ/0
0_nCLZ/5oi=d[@?oTWNa1On@N[H4ohUk_P?oQ7k51?n6Q<X2oi2<b`;oRjOX1?nU/=l5okB_d`04okZY
b?ng^mco]k_LokNkg0?o00000onf[]42ojbQc0CoXmol0_nQd_T5oi]hZ`04oiYi[OnGKJ3oUffPoiM]
X0CoUfjR1?nFKj@4oiIaY`CoUWF[00CoUgV`oj>3/OnSPk7oXh>a1OnSQ[D5oj:9^@04oj:=__n[U/7o
ZiK1oj^F`@CoZIO31?nWVLL00onaZ]7o0000ojn[d`03ojn[d`?o[JcF0_ng`n@5okG2i003ok?2iOnf
c>_o]/c[00;o]/c[00?o]LSXok;;kOnbbnd00_nbbndCooooo`;o0000;_ooool0013ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0;ooooo`Coan7[00?o`;G?okfed_nm]M800onm]M85oj^E_`?oXHo11?nB
QL84ohIl`@;oO7Bn0omnL[`3ohMg^PGoTWfi0_nNQ[T00onLNJcoXWj/oj9n[002oj9n[0CoYH6/1OnV
PJ`00onTP:coXWj/oj9n[005oimkZ`?oW7NY1OnIM:P3oiMbY`;oU72W0_nELjX3oi=bZPGoTg:[1?nC
M:d3oi9g/@GoT7Zf0_n9Nkh2oiZGd0?oS9cM1?n4XNH5oh^Wj0?oYK3O1?nd[m<00on]a^co]k_Lo`00
0002o`000003okNkg?nf[]7o]ZkA00;o]ZkA0onNkOP2oj?Oo003oiehZOnLN:[oW7RZ00;oW7RZ0onK
N:/00onGK9ooUffPoiM]X002oiM]X0CoUfjR1?nFKj@4oiIaY`CoUWF[1OnSPk44oj>6]@CoXXVi00?o
[YNooj^F`On[U/400_n[U/45ojVG``05ojNIaonaZ]7o/J[Aok6ZdOl000001?n_Zm<00on][=Ko]l?T
okO3i003okO3i0;o]L;T0_ngdNh4okK<j`;o/]Cb1?nbbndEooooo`03o`000?oooooooooo02_ooooo
000Yooooo`;o00005?ooool00ol0003oooooooooo`08ooooo`?oam[X00?oan7[ol2ecoo0]Ll00_o0
]Ll3okfedP;o/YVo1?n[UKl4oj6?`@?oTXG21?n6O<43ogad_P?oOW:l0on7MkX4oi9m^@03oij6^OnL
NJcoW7V/00CoXWj/1?nUPJ`4ojJ1[003ojJ2[OnROZcoXWj/00;oXWj/1?nONj/3oiagZ@GoVGBX0_nG
LZL00onGMJ_oUG>ZoiEcZP02oiEcZPCoTg:Z1?nCLZ/4oi=d[@CoTWNa0on@N[H00onST/?oVYO@oiZG
d003oiZGd0?oS9cM1?n4XNH5oh^Wj0?oYK3O00?o]:oCojg6k?l000000_l00005okNkg005okJ^dOnN
kOSoW^ghoik]n?nNNJP01?nMN:T4oiahZP04oi]hZonGK9ooUfbOoiM/W`GoUffP0onGKZ84oiI_Y0Go
UW6W0_nFMJ/2oj>1[`CoXh>a1OnSQ[D2oj:9^@?o[YNo0on[U/44ojVG``03okB/d?naZ]7o/J[A00?o
/J[A00?o0000ojn[don_Zm<00_nib>D4okO3i003okOIlOngdNko]m7^00?o]m7^00?o]/c[ok;Dl_nb
e?800onbe?82ok;;k@;oZlS_5Oooool00ol0003oooooooooo`0Zooooo`00:Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00Cooooo0_n9k=T4olOJj0Ko`;G?00Co_KGBok:I_onbVKoo
/YVo1On[UKl2oj6?`@04oiUm/on<Lk;oS7>bohac/PCoPFba0omjIJl3ogib_0?oQgNj0_nBOKT2oi5b
[0CoW7V/1?nROZ`4ojF1[0;oYX6/0_nVPZd4oj9n[0CoWg^[1?nLMjT4oiUdZ003oiMbYonGMJ_oUgF[
00GoUG>Z0onCLZX4oi=bZ`GoTgB]0onBMk400on@N[KoXi;3oj>B``02oj>B``CoVYO@1?n<W=d4ohBQ
iP;oRjOX0om[`?h2oiC;nP;o00001?n]a^`2okNkg0;oKmoO0_nONZP3oiiiZ0GoWGRY0_nLN:X00onH
K9koUfbOoiM/W`02oiM/W`GoUffP0onGKZ85oiI_Y0CoUW6W00CoUWF[oj>1[onSPJooXh6_1?nSPk45
oj>6]@03oj:9^On^Ukoo[YNo00;o[YNo1?n[U/400onYUl?o]:c@okB/d002okB/d0Go/J[A00?o0000
okW8iOnib>D00_nib>D00ong`nCo]mWaokOIl@02okOIl@;o]m7^1?n`gOL2ok;DlP;oZM3d1On[b>lD
ooooo`03o`000?oooooooooo02[ooooo000Yooooo`03o`000?oooooooooo01Gooooo00Co0000oooo
oooooooooooo0on9k=T4olOJj0;o_kC?1?o0]Ll00oneW;oo/YVook:I_`02ok:I_`CoZiFo00CoXXBc
oiUm/onIOK?oVGfc0on<Lk84oh5//@?oNVF_0ommIZh3ohM[[@CoTG:/1?nLNJ`4oj9n[0CoYH6/00Co
YX6/ojJ2[OnVPZgoYX:]1?nROZ`5oimkZ`?oW7NY0_nIM:P2oiUh[@CoUgF[1?nELjX3oi=bZPCoTg:[
1OnCM:d2oi9g/@03oj>;^onST/?oXi;300?oXi;31OnJUm02ohbLg@?oTLcl1?m`a?l2of_0oP?o0000
0_nDboX2ojg6k0CoWgZY1?nONZP3oiiiZ0GoWGRY00?oW7RZoiQ/W_nHK9h01OnGK9l4oiM]X0?oUfjR
1OnFKj@3oiIaY`03oj9n[?nSPJooXh6_00;oXh6_1OnSPk43oj>6]@03ok2H__n^Ukoo[YNo00?o[YNo
1?n[U/45okB/d0Co/J[A00?o_<oYokW8iOl000000_nib>D2okGRmP?o]mWa0_nWio/4ok3Mm`03ojCG
nOnYd?CoZM3d00?oZM3d0_n[b>l3oj?2kaCooooo00?o0000ooooooooool0:Oooool002Wooooo00?o
0000ooooooooool05_ooool01?l0003oX_C]oj;dkOnRm>d4olGEiP03olOJj?no]<oo_kC?00;o_kC?
00?o`;G?okFL_oneW;l00_neW;l4ok:I_`04oj^E_onRQ;?oXXBcoj:4/`CoVGfc0on<Lk83oh5//@?o
NVF_0ommIZh3ohM[[@CoTG:/1?nLNJ`4oj9n[0?oYH6/00?oZ8B^ojJ2[OnVPZd00_nVPZd4oj9n[0Go
Wg^[0_nLMjT00onKO;3oVGR]oiUh[@02oiUh[@CoUgF[1?nELjX3oi=bZPGoTg:[0onCM:d00onPQKOo
Xh^koj>;^`02oj>;^`GoXi;30_nJUm03ok3:k@?oTLcl00Co0000ohVnn?n[]=ooZkCO0ol00003ojnS
c003ojjJ`_nLNJcoW7V/00GoWgZY1?nONZP4oiiiZ0?oWGRY1?nHK9h5oiM/W`CoUffP1?nGKZ84oiI_
Y004oiIaYonROZcoXWj/oj9n[0GoXh6_1?nSPk400onSQ[Go/9Rnok2H_P02ok2H_PGo[YNo0_n[U/42
okRadPGo]:c@00?o/J[Aokc?jOnlcnT00_nlcnT00ol0003o]N;fokGRmP03okGRmP03okOIlOnWio_o
YnOk00;oYnOk00?o/=ggojCGnOnTeoT00_nTeoT2ojW@m0?oXLKb1OnS`^lDooooo`03o`000?oooooo
oooo02Sooooo000Yooooo`?o00005_ooool3oj;dk@CoaMGV00?o_kG@okndcono]<l00ono]<l5okFL
_`Co/YVo1OnRQ;<3oiUm/`?oS7>b0on1K;43ogYU[`CoOFJ^0on7Jjd3oi5b[0CoW7V/1?nROZ`01?nU
PJcoZ8B^ojR4[_nXQ:h5ojJ2[@CoXWj/1?nONj/00onLMjWoVgb`oi]l/004oiUh[@CoUgF[1?nELjX3
oi=bZPGoTg:[00?oTgB]oj25]onPQKL00_nPQKL3oj>;^`CoXi;300?o_l7Kok3:kOn`b^d01?n`b^d0
0onAc?coRKkhohVnn003o`0000;oZkCO0_n_Xl`2oiMh[`CoW7V/1?nONZT4oimjZ0CoWWVX00?oWGRY
oiQ/W_nHK9h01OnHK9h4oiM/W`CoUffP1?nGKZ83oiI_Y003oj9mZonROZcoXWj/00?oXWj/1?nSPJl4
oj>3/@Go/9Rn1On^Ukl01?n[U/7o^;7BokRad_nh/M84okB/d0;o_]c_0onlcnT2ojc/n003o`000?ne
h_Ko]N;f00?oUN_g0_nWio/4oi_Lo@;oY=Oi0_nMb?H5oj76lP;oXl;_0_nO_>hCooooo`;o0000:_oo
ool002Wooooo00?o0000ooooooooool05?ooool3ok3bm@?o`m7U00?oaMGVokned?no]M000_no]M03
okndc`;o]Ik11?neW;l3ok:I_`03ojR9/onRQ;?oXXBc00?oXXBc0onIOK<3ohac/PCoPFba0_mjIJl4
ogeV[P?oQf^]1?nALZ`3oiai[0CoXWj/1OnXQ:h4ojJ2[@CoXWj/0_nONj/2oin3]0CoVgb`0onIN:d4
oiMeZ`CoUG>Z1?nCLZX3oi=bZ`03oif1]OnPQKOoX8Fg00?oX8Fg0onSRk/3oj>B``?o_l7K1?n`b^d0
1?mkIk7o0000o`000?l00002oh=^/`?oSGBb1?nGN:l4oiai[0CoWgZY1OnONZP2oiiiZ003oiU]W_nH
K9koV6bN00KoV6bN1?nGK9l4oiM]X0CoUfjR00CoUVnToj9mZonROJ_oXWf[1OnROZ`4oj>1[`?oXh>a
0_ndW<04ok2H_PCo[YNo00?o_KWFokRad_nh/M800onh/M800ond[=3o_]c_okkLk`03okkLk`06okc?
jOn/k?So[>chojc/n?m_gn;o00000_nEjoL4oh_NoP;oVmcm0_nIb?P5oig8mP;oXLKb0_nM_>h5oinl
kQCooooo00?o0000ooooooooool09oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool05?ooool2ok3bm@Go`m7U00?o_KKCokne
d?no]M000ono]M000ono]<oo]Ik1okFN`@02okFN`@Co]Ibo00Co/YVoojR9/onXRK?oZ8Vc1?nRQ;<4
oiUm/`?oS7>b0on1K;43ogYU[`?oOFJ^0on7Jjd4oi5b[0CoW7V/0_nROZ`00onUPZkoZ8B^ojR4[P03
ojR4[PCoYX:]0onROZ`00onUS;[oWh>doin3]002oin3]0CoVgb`1?nIN:d3oiMeZ`GoUG>Z0onCLZX0
1?nCLZ_oWH6eoif1]OnMPKD5oj25]`CoXh^k00?oXi;3oko1fono`M/00ono`M/01On`b^go0000o`00
0?l0003oNfNa00CoPfjc0on=M;85oiMh[`?oW7V/1?nONZT5oimjZ003oiiiZ?nIKIkoVFfN00SoV6bN
1?nGK9l5oiM]X0?oUfjR1OnROJ/4oj9n[0GoXh6_00CoXh>aokBL`?ndW<3o]9c01On`V;h00on^Ukoo
_KWFokfieP02okfieP?o^;7B0onjk?@2okkLk`?oTnk_00Go[>chofoOh_m_gn;oKmoRo`000002ogGJ
nP;oRmkn0_nCa_T5oiW8n0;oWLSf0_nL^^d5oiflkPCoWkc^5Oooool00ol0003oooooooooo`0Voooo
o`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01Oooool00ol0003oooooooooo`0Booooo`;o]ncf0oo2cnD3ol?Ai@?o_KKC0ono]M00
0oneXLCo]Ik1okFN`@03okFN`@?o]Ibo00?o[8beojR9/onXRK<00_nXRK<4oj:4/`CoVGfc0on<Lk83
oh5//@?oNVF_0ommIZh3ohM[[@CoTG:/1?nLNJ`01?nROZcoYH:^ojF2[_nUPZh4ojR4[PCoYX:]00Co
XWj/ojF<^_nUS;[oYHbj1?nOPk@4oi]l/0CoVGR]1?nGMJ/4oiEcZP;oTg:Z00?oVWjdoif1]OnMPKD0
0onMPKD5oj25]`;oXh^k00?o_[OCoko1fono`M/00_no`M/3o`0000;oNfB]0omkIk44oh=^/`?oSGBb
1?nGN:l3oiai[0GoWgZY0onONZP01?nIKIooVFfNoiU]W_nIKIh8oiQ/WPCoUfbO1OnGKJ02oiM^XP;o
XgfZ1?nROJ/5oj9n[0?oXh6_00?o]j;3okBL`?ndW<000_ndW<04ok2H_P03ol75gOnm^MKo_KWF00?o
_KWF00?o^;7Bok[/m?njk?@00_njk?@2oe_Ca@;oTnk_00?oC<G^oec?l_mLco800_mLco82ogGJnP03
o`000?n?`?OoSl3g00CoTlKi0_nIb?P3oi^fj`CoW;[]1?nM_>h2oinlkP?oWkW[5?ooool00ol0003o
ooooooooo`0Vooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03
oiRHV?lQ8B7ok^k^00Kooooo0_l0000Aooooo`?o]ncf1Oo2cnD00oo3dNGo_KKCokffd`03okffd`04
okned?neXLCo]J74okFQa0Go]Ik100Co]Iboojb<]On/S;Go[8be0onXRK<5oj:4/`;oVGfc00CoUGN_
ohM^[on7KZooQfj_0ommIjl3ogYU[`CoOFJ^0on7Jjd3oi5b[0?oW7V/00?oWgj^ojF2[_nUPZh00_nU
PZh5ojR4[P;oYX:]00?o[YJmojF<^_nUS;X00onUS;X4oin3]0?oVgb`1?nIN:d4oiMeZ`;oUG>Z0_nI
O[@3oiYn]0GoWH6e1OnPQKL01OnSRk_o_[OCokjgdonn]m?o_l7K00;o000000?o`_kKog]T[OmkI:d0
0_mkI:d3og]W/@CoPfjc0on=M;84oiMh[`?oW7V/1OnONZT01?nONZSoVFfOoiU]WonIKIl4oiU]WPOo
V6bN1OnGK9l4oiM]X004oiM^X_nSOJ[oXgfZoj=mZPCoXWf[1OnROZ`01?nSPJoo]j;3okNR`ongX/<5
okBL`003ok2H__o1aMgo`LGM00;o`LGM0onm^MH3oj?ej`05ok[/m?mKdlGoFm?5oe_CaOnAVmX01?n?
ZNP5ohfflP04oho0mol0003oSl3goho0m`;oTlKi0_nI/>L5oi^fj`CoW;[]0_nM_>h2oijdj0GoWkW[
5?ooool00ol0003oooooooooo`0Uooooo`003_ooool01Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`0>ooooo`?o^^Kd0oo1c^@3ol;?i@03okfi
e_nm]]?o_KKC00?o_KKC00?o]:C8okFQa?neXL@00_neXL@4okFN`@03ojb?^?n/S;Go[8be00;o[8be
1?nXRK<4oj:4/`03oiUm/onEMjooUGN_00?oQfj_0ommIjl3ogEQ[PCoOFJ^0on7Jjd3oi5b[004oiai
[?nOOZkoWgj^oimn[PCoYH:^1OnXQ:h01?nVPZgo[YJmojjF_On^U[d4ojF<^PCoWh>d1?nKO;03oiUh
[@;oUgF[0_nIOkD4oiUn]0CoVWjd1?nMPKD4oj25]`03okV`dOnn]m?o_[OC00?o000000Co_l7KolWn
h?n3Ij[oPfNZ1?mkI:d2og]W/@CoPfjc0on=M;84oiMh[`CoW7V/0onONZT00onGK9ooVFfOoiU]W`02
oiU]W`CoVFfN1onHK9h5oiM/W`?oUffP1OnSOJX4oj9mZ`CoXWj/00?o_:[8okNR`ongX/<00ongX/<3
okBL`003olKIj?o1aMgo`LGM00Co`LGM00?o_KWFoj?ejonSmN/00onDSl/5oi6KfPCoSjWX0_n=]_82
oi^Qf@;oVZWQ00?o0000oiZYhOnI/>L01?nI/>L2oi^fj`;oWj_O1?nN/>@5oijdj0;oWkW[0_nS^^TE
ooooo`03o`000?oooooooooo02Cooooo000>ooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo00_ooooo1?nlgo400onji_Co`LkTol7>i003
ol7>i004ol;?iOnm^MKo_KWFokfieP?o_KKC0ondY<P4okFQa004okFN`On/SkSo[8nhojb?^0Co[8be
1?nXRK<2oj:4/`;oWGf_1?nEMjl3ohM^[`;oOFN_0omeHJh4ogUT[P?oQFb_0onBMJl5oimn[P?oYH:^
1?nXQ:h00oncW<3o[YJmojjF_@02ojjF_@CoYHbj1?nOPk@4oi]l/0;oVGR]00?oUh2hoiUo]OnIOkD0
0_nIOkD5oiUn]0?oVWjd1OnMPKD2oj25]`04okV`dOl0003o0000o`0000?o_[OC00CobOkPoh=WZ_n3
Ij[oPfNZ1?mkI:d3og]W/@CoPfjc0_n=M;85oiMh[`?oW7V/00CoWgZYoiM/WonGK9ooUfbO1OnIKIl3
oiU]WPOoV6bN1OnGK9l00onGKJ3oXgfZoj=mZP06oj=mZPCoXWf[0_nROZ`3okbZb0Co]j;30_ndW<03
olKIj0Co`LGM00CoF/j/oiN5__nGQKkoUhFn1?nDSl/4oi6KfP;oSjWX0_nMVLl5oi^Qf@04oiZYhOl0
003oVZWQoiZYh@;oVK3W0_nOY=T5oin[g`CoW[3T0_nN]>P3oj>eiPCoXk[Y4oooool2o`0000Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
00Wooooo000>ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`03oooo
o`;o00002oooool4okcOl@;o`LgT1?o1c^@00onm^mSo_KWFokfieP03okfieP03okffdondY<So]:C8
00;o]:C81?neXL@4ojb?^0Go[8be0_nXRK<00onSP[3oWGf_oiem[`02oiem[`CoUGN_0on7KZl3ogeW
[`;oMF6^1?miI:h3ohE/[`?oTWF_1OnOOZh4ojF2[P;oZ8B^0oncW<03ojjF_@GoYHbj0onOPk@2oi]l
/0;oUXBn0onGP;P5oiUo]@CoVGjd0onJO[@5oif1]@?o00000_ni/=43okjgd`03olWnh?n?H9OoREbF
00;oREbF1?n6FiP3ohEKVPCoPfjc0on=M;84oiMh[`;oW7V/00?oTfZPoiM/WonGK9l00_nGK9l5oiU]
W`?oVFfN2?nHK9h3oiM/W`03oj=nZonSOJ[oXgfZ00OoXgfZ1?nROJ/00onROZco_:[8okbZb002okbZ
b0Co]j;300?o]9c0olKIj?o6fNP00oo6fNP00oo1aMgoVWndoiYo]004oiN5_PGoU8o;0_nAVmX00onP
T/KoWIW?oifIc`03oifIc`GoVj7I00?oVZWQo`000?nQWm801OnOY=T4oin[g`;oW[3T0_nT/N86oj>e
iP;oXk[Y0_nW_>PDooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Wooooo000>ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo0_l0000:ooooo`?o_MS^
00?o_=oaol7=i?o1cN@00oo1cN@00oo1c^Co_K_Hokfkf002okfkf0?o_KWF00?o]:S<okBTb?ndY<P0
0ondY<P3okFQa0;o[9:k1?n/SkP4ojb<]@03ojR9/onSP[3oXh:`00CoWGf_1?nEMjl3ohM^[`?oOFN_
0omeHJh3ogUT[PCoQFb_0onBMJl4oimn[PCoYH:^00?oZ8B^ok>L`?ncW<000_ncW<04ojjF_@CoYHbj
0_nOPk@00onGS<KoUXBnoiJ4_P02oiJ4_PCoUh2h1?nIOkD4oiUn]0CoVWjd00CoWH6eo`000?l0003o
00001_ni/=401?nn]m?oSf2GohmPUon?H9L3ohULUPCoQU^H0on5FiX4ohAMW0?oQV2O0_nGN:l2oheU
W`?oTfZP1OnGK9l4oiU]W`?oVFfN2?nHK9h2oiM/W`;oXgj[2OnSOJX4oj9mZ`Go_:[80ongX/<3ol7b
l@;oa]WX00?oWG^]oiYo]?nJOk@00onJOk@3oiN5_PCoU8o;00?oXhjnoj2Ba_nPT/H00_nPT/H4oifI
c`CoVj7I00GoXiW;oj6Od_nQWm;o0000oj6OdP05oinTf@;oWj_O00?oYJgMojBah_nT/N800onT/N84
oj>eiP03ojRiiOnW_>SoYkcX00?oYkcX5?ooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Wooooo000>ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo00?o0000oooooooo
ool01oooool5okgHkP;o`L_R0oo1cN@2okfnfPGo_K_H00Co_KWFokBXc?ndZ<co]:S<1OndY<P01?ne
XLCo[9:kojbB^on/T[/4ojb?^0?o[8be00?oYHFboj>2/?nSP[000_nSP[04oiem[`?oUGN_0on7KZl3
ogeW[`?oMF6^0omiI:h4ohE/[`?oTWF_1OnOOZh2ojF2[P03ok>M`_ncW<3o/ic000?o/ic01?n^U[d2
ojF<^P;oWIW?1?nGS<H4oiJ4_P?oUh2h1?nIOkD5oiUn]004oiYn]?l0003o0000o`0000Co/J_B1?ni
/=400onmo>CoSf2GohmPU`02ohmPU`?oREbF1?n6FiP3ohEKVPCoQ5fL0on6H9l4oheUW`?oTfZP1OnG
K9l4oiU]W`?oVFfN2?nHK9h00onGK9ooXgj[oj=nZ`02oj=nZ`WoXgfZ0_nROJ/2ol:hd@Go_:[800Co
]j;3ol7blOo1l_7o`O;a1OnMNjd4oiYo]0CoUhFn00?oU8o;oj>>__nSS[h00_nSS[h3oj2BaPGoWIW?
00CoVj7Ioj>IbonSVL_oXiW;0onQWm800ol0003oWjCIoinTf@02oinTf@03ojNYf?nU[MgoYJgM00;o
YJgM1OnT/N800onS]NKoZ;WUojRii@02ojRii@?oYkcX00?oZl3Yooooooooool04_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b00Wooooo000Wooooo`03o`000?oooooooooo00Gooooo0onmdNT3okgHkPCo`L_R00?o`LgTokfn
f_nm_]X00_nm_]X3okfkf003okF]d?ndZ<co]:S<00;o]:S<1?ndY<P00onZUL3o[9:kojbB^`02ojbB
^`Co[8nh00Co[8beojF5/_nUQK;oYHFb1?nSP[04oiem[`CoUGN_0on7KZl2ogeW[`?oMF6^1?miI:h3
ohE/[`?oTWF_1OnOOZh01?nUPZko/ig2ok>M`_ncWL85ok>L`0;o[YJm00?o[J_EoifIconMVLl00onM
VLl3oiN<aPCoUXBn0onGP;P5oiUo]@;oVGjd0ol000000onJO[CoYjOFok6[dP05ok6[dP04okV`dOnm
o>Co_OcToiIVV0CoSf2G0on9G9H4ohIKV0?oQE^J1?n4GI`3ohIPW`CoSFFO1?nCJZ04oiM/W`CoVFfO
0onIKIh7oiQ/WP03ojB0[OnSOZ_oXgj[00?oXgj[2OnSOJX01?nROJ_o`[SAol:hdOo2^=44okbZb0;o
S^kB00?o`O;aoj5jZ?nQNZP01OnMNjd4oiYo]0;oUhFn0_nWRkP5oj>>_PCoX9;60_nMVLl2ojJFa@Go
XiW;0_nQWm800ol0003oXIoBoinTf@04ojNYf0CoYJgM0_nT/N82ojVfhPGoZ;WU00?oYkcXoj_0jOn[
`>T00_n[`>TDooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`05olc<c?l0003o0000o`000?o<c<`02Oooool002Oooooo0_l00005ooooo`Go_M7Y00?o_MS^ol7;
h_o1bn800_o1bn800ono`=_o_KkJokfnfP04okfnfP04okfkf?ne[M3o]Jg@okF]d0Co]:S<00?o]:C8
ojZE`?nZUL000_nZUL04ojbB^`;o[8nh00?oYHNeojF5/_nUQK800onUQK83oj>2/0CoWGf_1?nEMjl3
ohM^[`?oOFN_0_meHJh4ogUT[P?oQFb_1?nBMJl3oimn[P03ojbI`oncWL;o/ig200;o/ig21OncW<00
1?n^U[go[J_Eojf[eOn]ZmD4oifIc`?oUhc61?nFQ;h4oiN0^0CoVGne0_l00002ojBVe`CoYjOF1?na
Zm82oiWch@?oUVJH1?n?H9L4ohULUPCoQU^H0on5FiX4ohAMW0;oQV2O1On=IIl3oi=ZX0CoUfbO1?nI
KIl4oiU]WPGoV6bN0onTP:d4oj=nZ`SoXgfZ00?ob<oOol:hdOo2^=400oo2^=401OnlZ/SoS^kBohk^
d_n>k];oY7^V00CoXGZX1?nMNjd4oiYo]0GoYh^h1?nSS[h3oj2BaP03ojVE`OnVU/GoYYK500?oYYK5
1?nSVL/2oj6OdP03ojZWe?l0003oYjWH00CoYjWH0_nU[Md2oj^eh0GoZKKR0_nX^ND3ojboj0CoZl3Y
5Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o
^[Zjoooooonj^[[o410@00Wooooo000Wooooo`03o`000?oooooooooo00;ooooo0onlb^D3okgAj@?o
`LWQ00?o`L_Roko0fono`=/00_no`=/4okfnfP03okNbe?ne[M3o]Jg@00?o]Jg@0_ndZ<`00on[VLGo
ZYG0ojZE`003ojZE`0Co[9:k00?o[8nhojF7]OnUQkD01OnUQK83oj>2/0CoWGf_0_nEMjl2oiAg/0?o
Qg2b0omlJkD3ogEQ[P?oNFB^1?n5K:l3oi9e[`03oimn[_n/VL?o[9W300;o[9W30oncWL84ok>L`003
okVgeon]ZmGo[J_E00?o[J_E0onMVLl4oiN<aPCoUXBn0onGP;P01?nIOkGo0000o`000?l00005ojBV
e`CoYjOF00Go/J_BoiWchOnIln7oVO?QoiY[VP03oiIVV0CoSf2G1?n9G9H4ohIKV0?oQE^J1?n4GI`3
ohIPW`CoSFFO0onCJZ04oiM/W`CoVFfO1?nIKIh3oiQ/WP03ojB2[onTP:goY82]00;oY82]1?nSOZ/7
oj=mZP?ob<oO0oo2^=401?l0003oWg^Zoian/OnLO[42ojAkYPCoXGZX1OnMNjd2oiYo]0;oZh^d1?nW
RkP5oj>>_P04oj2Ba_nYUL7oZIG1ojVE`@CoYYK50onSVL/00on]Y]3oZZODojZWe002ojZWe005o`00
0?nWZMSoYjWHojNYf?n^]Mh01On[]N03ojVfhP;o[KoW1On/_nP2oj_0j@;o[<?Z4_ooool3o`0000Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000002Oooool0
02Oooooo00Co0000oooooooooooooooo1Onlb^D00onmdNWo`LWQol79h@02ol79h@03ol32fono`=_o
_l3K00?o_l3K00?o_KkJokNbe?ng/]@00_ng/]@3okF]d003ojbOb_n[VLGoZiW500;oZiW51?nZUL03
ojbB^`03ojB:^OnUQkGoYHNe00;oYHNe1?nUQK84oj>2/0;oWGf_00?oW7b_oiAg/?nDMk000_nDMk03
ohM`/P?oO6^e0om`IkT3ogUT[PCoQFb_0_nBMJl00onJSLGo[9W3ojbI``03ojbI``Co/ig200?o/ic0
okVgeoni]mL00_ni]mL5ojf[e@?oWIW?0onGS<H4oiJ4_P04oiN0^?l0003o0000o`0000CoX:CH1?nT
Y]L3ojNWeP;oG]G;1?nJJiX4oiIVV0?oSf2G1?n9G9H4ohIKV0?oQE^J1?n4GI`3ohIPW`CoSFFO0onC
JZ04oiM/W`GoVFfO0onIKIh01?nHK9koY8:_ojB2[onTPZl4ojB0[@CoXgj[1_nSOJX4olS?g`03ol:h
dOnONj[oWg^Z00;oWg^Z00?oW7jaojAkY_nTNjH00_nTNjH3oj5jZ0GoWG^]00CoVWndoj^;]?n[RkCo
Zh^d1?nWRkP4oj>>_P03ojjF__nYUL7oZIG100;oZIG11OnVU/D01?nSVL_o[JK@ojfVd?n]Y]03ojZW
e003o`000?nZYmCoYjWH00?o[[GN1On[]N000onY]^;o[KoWojfoi`02ojfoi`;o[;oX0_n]aN/5ojc3
jQCooooo00Wo0000ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@
o`000?l@413oZJVY00Wooooo000Vooooo`?o00000_nka>44okc:i@;o`LOO0oo1bN43ol32f`?o_l3K
00?o^[OFokNbe?ng/]@01?ng/]@01?ne[M3o[9o:ojbOb_n/WlX3oj^Ia@GoZYG000?o[9:kojB:^OnT
R[T01?nUQkD4ojF5/PCoXh:`00?oWGf_oial[onLO:l01?nDMk04ohM`/P?oO6^e0_m`IkT3ogA__PCo
QGg31?nJSLD4ojbI``?o/ig20_nm^]L5okVge`;o[J_E0onFco/2og>cn@CoMjG_00CoQ9oUo`000?l0
003o00000onDX=d4oj2Tf0GoY:KG00CoYjOFok2;[_n`RjkoWFnM1?nJJiX4oiIVV0?oSf2G1?n9G9H4
ohIKV0?oQE^J1?n4GI`3ohIPW`CoSFFO0onCJZ04oiM/W`GoVFfO0_nIKIh00onUQK;oY8:_ojB2[`03
ojB2[`CoY82]1?nSOZ/3oj=mZP;oano^0oo8cml2oj=jYPCoWg^Z1OnTNjH3oj5jZ0CoWG^]00?o[hjb
oj^;]?n[Rk@00_n[Rk@5ojN;^004oj>>__n^U[ko[YJnojjF_PCoZIG11?nVU/D00onaZ<oo[JK@ojfV
d003ojfVd0;oZZOD00?o/KOMo`000?n^]Mh01?n^]Mh2oj^eh0;o[l7W1?n]_nL00on^b>go[LG[ojg5
j`03ojg5j`;o[<?Z0_n[a>`Eooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?nka>7o
^lCQ00?o^lCQ00?o_<[Uol77goo1aml00oo1aml00oo1bN7o`<;Kol32f`03ol32f`04oko0fonj]mKo
^[OFokZgePCo]k;D00?o[jK?ojbOb_n/WlX00_n/WlX3oj^Ia@CoZYG000?oXXfnojB:^OnTR[T00_nT
R[T3ojF7]@GoYHFb0_nSP[000onOOk3oW7b_oial[`02oial[`?oU7N`1?n7L;83oga[]@?oL6Ni0omd
Kkh4ohEm``?oVXg51On/VL<00oncWL;o_K[Gokfje`02okfje`?o^KOG0_ncgOD5oiK?n`;oLk?i00Co
MjG_o`000?l0003o00000on4WnD4oiBPg@CoX:CH0_nTY]L3oj^7[`03ok2;[_nMKigoWFnM00GoVV^J
0onFIYP3ohmPU`CoREbF1?n6FiP3ohEKVPCoQ5fL0on6H9l4oheUW`?oTfZP1OnGK9l4oiU]W`03oiU]
W_nUQK;oYHFb00GoY8:_1?nTP:d4oj=nZ`03oj=mZ_o7knkoano^00?oano^00?ob<oOoj=jY_nSNZH0
0_nSNZH2oimkZP03ojQnY_nTNjKoY7^V00?oY7^V1?nQNZP2oiek[@?o[hjb1?n[Rk@3ojN;^003okBK
_on^U[ko[YJn00?o[YJn1?nYUL400onVU/Go/JS?ok6Xc`02ok6Xc`?o[JK@00?o][gOok6ggOna]md0
0_na]md01?l0003o[[GNojjeg_n^]Mh2ok74j0Co[l7W00?o[KoWojk8kOn^b>d00_n^b>d3ojg5j`;o
[<K]1?n[a>`Dooooo`03o`000?oooooooooo01kooooo000Kooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003ooooook_4h@02ok_4h@?o`LCL0oo1aml3ol;3f`?o`<;K00?o_K_HokZge_nj
]mH00onj]mH00ong/]Co[jK?ojnVc`02ojnVc`?o[9o:1?n[VLD00onZUL3oXXfnoj:=_P02oj:=_P?o
Y8Zi1?nUQkD4ojF5/P03oj>2/?nOOk3oWgn`00CoW7b_1?nDMk03ohM`/P?oO6^e0om`IkT3ogA__PCo
QGg30onJSLD4ojbI``03okRfeonm^]Oo_K[G00Co_K[G00?o^KOGok?MmOncgOD00_ncgOD2oiK?n`;o
Uhk80ol00004ogNUk`?oQ9oU1?nDX=d2oj2Tf003oeOBd_nSOjgoZhN_00?oZhN_0onMKid5oiY[VP?o
UVJH1?n?H9L3ohULUPCoQU^H0on5FiX4ohAMW0?oQV2O1?n=IIl3oi=ZX0GoUfbO0onIKIl00onTR;Oo
YHFbojF5/P02ojF5/PCoY8:_1?nTP:d3oj=nZ`?oSnk?0_o7knh2ojIjY0GoXgZV00CoWg^ZojQnY_nX
OZKoZ7jV1?nTNjH4oj5jZ003oiek[On_S[;o[hjb00;o[hjb1?n[Rk@00onWRkSo]9^ookBK_`02okBK
_`Co[YJn0onYUL400ong[Loo/JS?ok6Xc`03ok6Xc`03ojfVd?nf_Moo][gO00;o][gO1?na]md00ol0
003o/LCXok74j003ok74j0;o[l7W0_n^c?05ojk8k@03ojg5jon/a^go[<K]00;o[<K]0_n[a>`2ojW3
k1Cooooo00?o0000ooooooooool07Oooool001_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06oooo
o`04o`000?oooooooooook_4h@Go`LCL00?o`LOOol;3foo2`m/00oo2`m/01?o0`]_o_K_Hokfkf?nm
^mP3okZgeP;o/jgC1?n_Y/l4ojbObP;oZiW500?oXI74oj:=__nRSKh00onRSKh3ojB:^@CoYHNe0_nU
QK82oj62/PCoWgn`0onLO:l4oiAg/0CoQg2b0omlJkD2og1W^@CoM6nn0on5OL<4oiZ=a@03ojbI`onh
]]Oo^;KG00;o^;KG1?nm^]L3ol;Mk@;o/mge0_n@L:/3o`0000?oS6bY1?n>KZX4oi9aZ`?oVGR/1OnS
Ojd2oj^7[`03oimaWonMKigoWFnM00;oWFnM1?nJJiX3oiIVV0CoSf2G0on9G9H4ohIKV0?oQE^J1?n4
GI`3ohIPW`CoSFFO1?nCJZ04oiM/W`04oiU]WonTR;OoY8RgojB8]`CoYHFb1?nTPZl5ojB0[@03oj=n
Zon?k/ooSnk?00?oZ7bS0onVNZ@5oj=jYPCoZ7jV1?nTNjH4oj5jZ0Go[hjb1?n[Rk@5okBK_`Co[YJn
00?oZIG1okN]cong[Ll00_ng[Ll3ok6Xc`03ok[8iOnf_Moo][gO00Co][gO0_na]md00onbbnco0000
ok74j003ok74j003ojgClon^c?3o[/c`00?o[/c`0_n^b>d2oj_:l0Co[<K]00?oZ<K_ojW3k?nY`n`0
0onY`n`Cooooo`;o00007_ooool001_ooooo00Go410@oooooooooooooooooa0@4006ooooo`;o0000
0_ooool4ol74g0;o`lCK1?o2`m/00ono`=[o_K_Hokfkf003okfkf003okZge_nc[M?o/jgC00;o/jgC
1?n_Y/l2ojbObP03oj>HbOnQTLCoXI7400;oXI741?nRSKh4ojB:^@;oYHNe00?oWX>foj62/_nQP[80
0_nQP[84oimo/0?oW7b_1?nDMk04ohM`/P?oO6^e0om`IkT3ogA__PCoQGg30_nJSLD2ojFXf@Go^;KG
00?o_K[Gol;MkOo2gNd00_o2gNd00om]eZSoT72[o`000002o`0000?oSVjZ1?n<K:T3ohi^ZPCoTW6[
0onIN:`5oj=o[@03oj^7[onOLIooWg6O00CoWFnM1?nJJiX3oiIVV0CoSf2G0on9G9H4ohIKV0CoQE^J
1?n4GI`3ohIPW`CoSFFO0onCJZ03oiM/W`03oj::^onTR;OoY8Rg00?oY8Rg0onUQK85ojB2[`?oY82]
0_nDIi/5ojQlX`CoYWZT0onSNZH00on_QZWoZ7jVojQnYP02ojQnYPGoY7^V0_nQNZP2okFC]0Go[hjb
0_n[Rk@2okbWa0Co]9^o0on^U[h00onl]mCo]jg?okN]c`04okN]c`04ok6Xconjb>Go^/SUok[8i@Co
][gO00?o/mGbok;;k?nbbn`00_nbbn`00ol0003o/LCXojgCl`03ojgCl`;o[/c`0_nYcO<5oj_:l003
ojc6kOnXa^ooZ<K_00;oZ<K_0_nY`n`2ojK1k1;ooooo00?o0000ooooool000007_ooool001_ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o`LCLol?4foo3
a=/00oo3a=/00oo2`m_o_l3Joko0fP02oko0fP?o_K_H00?o]kCGok>]donc[M<01?nc[M<2ojnVc`03
ojFOconSV<WoXiS900;oXiS90onQTL@5oj:=_P?oY8Zi00?oYHNeoij3]_nNPkH01?nQP[84oimo/0Co
W7b_0onDMk02ohM`/P;oT7bi0on6NKh3ogYha@CoM6nn0_n5OL<00on?UMKoYJSIojFXf@03ojFXf@?o
^;KG0oo3e^P00oo2gNgoKMJXoi5b[002o`0000?oT72[1?n>KZX3oha/Z@?oSVjZ1?nBLJ/3oiUh[0Co
Xgn]00?oWW6OoimaWonOLIl00_nOLIl3oie_W@CoVV^J0onFIYP4ohmPU`?oREbF1On6FiP3ohEKVPCo
Q5fL0on6H9l4oheUW`?oTfZP00CoUfbOoj::^onRR[_oXXZk1OnTR;L3ojF5/PGoY8:_00?oY82]oiAU
V?nDIi/00_nDIi/5ojQlX`CoYWZT0_nSNZH3ojn6Z@?oZ7jV1OnTNjH01?nQNZSo]I>dokFC]?neTk@5
ojn>/P04oj^;]?nlYlCo_:O4okbWa0Go]9^o00Co[YJnokbge?nl]mCo_;OD1?ng[Ll00onmg?3o^/SU
ok[8i@03ok[8i@03okJmgonceO;o/mGb00;o/mGb0_nbbn`2ojWJn@03o`000?n]do?o[M?c00?oYM;g
1?nYcO<2oj_:l0?oYlSa0onXa^l00onV`^koY/7/ojK1k003ojK1k1Cooooo00?o0000ooooooooool0
6oooool001_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo
1Oo3a=/00oo2a=_o_l3Joko0fP03oko0fP04okfkf?ng]=Oo]kCGokNde`Co/jgC00?oZjODojFOconU
Wll00_nUWll3oj>Hb@?oXI741OnRSKh2ojB:^@03oib6^onNPkKoWX>f00;oWX>f1?nQP[83oimo/0Co
W7b_0_nDMk000onJPKKoT7bioi1l^@03oi1l^@?oQWVn0_mjN<D4ogf2cPCoSiGF1OnUZ=T00onh]]Oo
`mKXol?Fj002ol?Fj0?o00000_nALZ`3oi1`Z`CoSVjZ0on<K:T4ohi^ZP?oTW6[1?nIN:`2oj=o[@;o
WW6O1?nOLIl3oie_W@CoVV^J0onFIYP4ohmPU`CoREbF1?n6FiP3ohEKVPCoQ5fL0on6H9l4oheUW`;o
TfZP00?oWHRmoj::^onRR[/00onRR[/4ojB8]`CoYHFb0onTPZl3oiAUV0;oU6NK00?o[7nTojQlXonX
O:<00onXO:<4ojIjY003oj=jY_n_QZWo[hJY00;o[hJY0onXOZH5ojAkYPCo]I>d1?n_S[800oo9`=7o
_:O4okbWa002okbWa0Co]9^o00?o`l_Pokbge?nl]m@00onl]m@00ong[Loo_Mc`okgLl002okgLl0;o
^/SU1?n[hOT2ok?ElP?oW^;m0_nYf_T00ol0003oWmCkojGBm`04ojGBm`;oZLgc0_nUb_<5ojO8l@04
ojS6konV`^koY/;^ojK2kP?oY/7/00?oYKo/ooooooooool04oooool00ol0003oooooooooo`0Joooo
o`006oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool01Oooool3ol?4
f`?o`/CK0ono`=X2ok^lfPCo]kCG00?o/jgCoj^We?n[Ym@00_n[Ym@3ojFOc`?oXiS91?nQTL@2oj:=
_P;oV8S11?nLQ[/3oij3]PCoXH:b1?nOOk02oial[`03oin4]_nJPKKoVX6f00;oVX6f1?n@O;T3ohIi
_P?oNWS51?mmP/h3ohnEePCoYJSI0_nba^T01?o3e^So0000o`000?l00002oiAe[@?oTG:/1?n@L:/3
ohi^ZP?oS6bY1?n>KZX3oi9aZ`CoVGR/00CoXgn]oiiaWonNLIooWW6O1?nOLIl3oie_W@CoVV^J0onF
IYP4ohmPU`CoREbF1?n6FiP3ohEKVP;oQ5fL0_n?M;03ohUg^0CoTX6m1?nMR;d4oj::^`CoY8Rg1?nU
QK800onTPZooU6FHoiAUV003oiAUV004oiAWVon/OjCo[7nTojaoY0CoZ7bS1?nVNZ@5ojn6Z@CoZ7jV
0onTNjH2okfO^PCo]I>d0_n_S[83olW0d@Co_:O400?o]9^ool?;h?o3bn000_o3bn03okbge0;o[?;e
0onmg?03oi7Xn@;oZn7i0on5hO/2oikRo@;oU=Gn0onOe?/01?l0003oWmCkojGBmonUd_L2oj7;mPGo
YL[c0_nWb?42ojC2k`GoY/;^00CoY/7/ojFok?nU_ncoYKo/5?ooool00ol0003oooooooooo`0Joooo
o`006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00007ooooo`03ol?4foo2a=_o`/CK
00?o`/CK00?o_l3Jok^lf_nk_=X00_nk_=X2okNde`;o[k3I1?n[Ym@4ojFOc`?oXiS90_nQTL@00onG
SLOoV8S1oiR8`@03oiR8`@?oW8Jk0onNPkH4oj62/PCoWgn`00?oW7b_oin4]_nOQ;H01?nJPKH4oi1l
^@?oQWVn0omjN<D4ogf2cPCoSiGF00?oYJSIok;6jOnba^T00ol000000oo3e^SoUgR_oiAe[@02oiAe
[@?oTG:/1?n@L:/3ohi^ZP?oS6bY1?n>KZX4oi9aZ`;oVGR/00?oV6fPoiiaWonNLIl00_nNLIl4oima
W`?oWFnM1?nJJiX4oiIVV0?oSf2G1?n9G9H4ohIKV0;oQE^J00?oUW:Xohmd/?n?M;000_n?M;04ohUg
^0CoTX6m0onMR;d4oj::^`GoY8Rg0_nUQK83oiATU`CoU6FH1?n/Oj@5ojQlX`?oYWZT1On_QZT4ojQn
YP;oY7^V0onmWkX4okFC]003ojn>/_o9`=7obL3A00;obL3A0onlYl@2oko[lPCo`l_P00?o_;ODojcb
mOn/l_D00on/l_D00onmg?3oTNSioi7Xn@03oegBk@;oQN7k0on9dOl4oiCEoP;oWmCk00?oW<Wgo`00
0?nQboH01?nQboH2ojG:l`;oXl;_1OnT`^l2ojK2kP;oY;k/1OnU_n`Dooooo`03o`000?oooooooooo
01Wooooo000Kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`07oooo
o`Co`/CK0_noa=h3ok^lfP03ok>ig_n_/=Wo[k3I00?o[k3I1?n[Ym@2ojFOc`04oi^KdonHTlgoV9?=
oiRCc@CoUhg71?nHR<43oib6^`CoWX>f0onQP[82oimo/0;oX8Jg1?nOQ;H3oiZ1]PGoT7bi0on6NKh3
ogYha@CoOH;>0_n?UMH01?nO/^Go0000o`000?l00002ok;6j@03ohg]c_nGN:ooUgR_00?oU7F]0onA
LZ`4oi1`Z`?oSVjZ1?n<K:T3ohi^ZPCoTW6[00?oVGR/oiQ]X?nHKJ001?nNLIl4oimaW`?oWFnM1?nJ
JiX4oiIVV0?oSf2G1?n9G9H2ohIKV0;oUVjS0onFLZP5ohmd/0?oRGNh1?nBPKd3oif8_@GoXXZk1?nT
R;L00onUQK;oU6BGoiATU`02oiATU`CoU6FH1?n/Oj@5ojQlX`;oYWZT0_niU;44ojn6Z@CoZ7jV00?o
Y7^VokfO^_nmWkX00_nmWkX4okFC]0KobL3A00?o_:O4oko[l_nojo800_nojo82ol?;h003odk9/_mG
/O_o<k;Z00?o<k;Z0_lm_^82oh:nn`GoO/Wo1?n9dOl2oiCEoP;oUlCf0onLbOL00ol0003oXL_foj7;
mP03oj70k`CoXl;_0_nT`^l3ojBmj`CoY;k/0_nU_n`2ojFnjaCooooo00?o0000ooooooooool06Ooo
ool002Gooooo00?o0000ooooooooool02?ooool00oo2a=_o_lCNoko4gP03oko4gP04ok^lf_nc^Mko
/kWNok>igPGo[k3I0_n[Ym@00onQY=SoVi_Coi^Kd`02oi^Kd`?oV9?=0onGSLL4oiR8`@CoW8Jk0onN
PkH2oj62/P03oin8^onPQ[OoX8Jg00?oX8Jg0onOQ;H4oiZ1]PCoT7bi0_n6NKh01?nET<coRi7Doh^A
e?n;TM@4oi2Mg@?o00000_nO/^D00onba^WoSNg>oiYl/@03oiMh[`CoU7F]0onALZ`3oi1`Z`CoSVjZ
0on<K:T3ohi^ZP;oTW6[0_nBJIl3oiQ]X0CoWW6O1?nOLIl3oie_W@GoVV^J0onFIYP3ohmPU`?oREbF
00?oUF^PoiI^XonFKZ<00_nFKZ<4oiIbZ0CoSgB`0on9MkP4oi:1_@CoWHRm1?nRR[/2ojB8]`?oTV:F
1?nDI9L3oiAUV003ok65Y_n/OjCo[7nT00;o[7nT1OnXO:<01?nVNZCo^IBaokVD/OniU;45ojn6Z@?o
Z7jV1_nmWkX2okFC]0;odOCW1?o9`=42oekD_0;o_n_b0omjW>L2oeNan`;oUj7L1On9[^h3oh:nn`;o
O/Wo0_nF/NX5oiJmlPCoUlCf0_nLbOL00ol0003oWkg]oj70k`04oj70k`;oXl;_0_nS^nX5ojBmj`;o
Y;k/0_nU_NX4ojFnja;ooooo00?o0000ooooool000006_ooool002Gooooo00?o0000ooooooooool0
2_ooool3oko4gP03okS3honc^Mko/kWN00?o/kWN0_n_/=T2ojF]g@CoXJCH0onKVm<3oiRCc@?oUhg7
1OnHR<43oib6^`;oWX>f00?oVHS0oin8^onOR;/00_nOR;/4oj26]`?oWhBf1?nJPKH2oi1l^@;oWI;8
1?nET<`3oh^Ae0?o00000_n@WMd2oinbi@04oh_]i_nJO;7oVWbaoiYl/@CoUgR_0onDMJd3oi5b[0?o
T72[1?n>KZX2oha/Z@04oh]SW_n>IIooSVFOohiUW`CoTVVO1?nHKJ04oiiaW`?oWg6O1?nMKid4oiY[
VP?oUVJH0on?H9L01?n9G9KoUF^PoiE[X?nEJj04oiI^X`CoUW:X1?n?M;04ohUg^0CoTX6m0onMR;d2
oj::^`?oTF2E1?nBHYH4oiATU`;oU6FH0onaQJH3ojaoY0GoZ7bS1?niU;45ojn6Z@;oZ7jV0_o7]/T5
okfO^P03okFC]?oAm>OodOCW00;odOCW00CobL3AoekD_?mNe;coG]Bl0_n@S</2ogZLi`;oXIO:1OnG
XM`2ohV^kP;oWigA1?nJY]h4oiJajP;oU[gb0_nP/N@4oijgjP?oWkg]00Co0000oinmkOnQ`>ooXL3_
0_nS^>P5oj>kjP;oY;g[0_nU^nT5ojFmjP;oYKk[0_nV_^/Dooooo`03o`000?oooooooooo01Oooooo
000Uooooo`;o00003?ooool01?noa=ko^<?SokS3honh`n<3ok>igP;oZKOS1?nU[Md3oj6Tf0?oVi_C
1?nHTld3oiN=a`CoV8S10_nLQ[/00onBRLOoVHS0oiV8`002oiV8`0?oWhRk1?nPQ[L4oin4]P;oVX6f
00?oYIK6oifBb?nMT/P00onMT/P3oiF@c003oh^Ae?l0003o000000CoT9gM0_n8iOT2oin1/`?oVWba
1?nGN:l2oiAe[@04oheVX?n<I9ooS6BOohaTW`[oRf>N0on>IIl4oi9YW`CoV6fP1?nNLIl4oimaW`?o
WFnM1?nJJiX3oiIVV0;oSf2G00?oTfZPoiE[X?nEJj000_nEJj04oiI^X`CoUW:X1On?M;03ohUg^0Co
TX6m0_nMR;d3ohmNU0?oTF2E1OnBHYH3oiATU`03oiAUV?naQJKo/HFV00;o/HFV1?n/Oj@3ojQlX`;o
ck[50oniU;45ojn6Z@04ojQnY_o7]/WoakK9olNfb@Co_Inj0_l00002om7di`GoWHFi0_n@S</00onY
TkkoXIO:oj6GbP03oj6GbP?oUj7L00?oYYS7oinMdOnOWM400onOWM44oiZVgP;oU[7Z00?oXZ[Loj2a
i?nP/N@00onP/N@4oijgjP;oWkg]00?oXkCUo`000?nS]>D01?nS^>P2oj>kjP;oYKWW1OnU^nT2ojFm
jP;oY[cY1OnV_^/Cooooo`03o`000?oooooooooo01Oooooo000Tooooo`03o`000?oooooooooo00go
oooo1?nh`n<00onc^MkoZKOSojVgh`02ojVgh`?oYJgM1?nQY=P3oi^Kd`;oV9?=00CoRYCHohR>don8
S]?oR8kC1?n<Rld4oi:9a`?oVHS00onOR;/5oj26]`?oWhBf00CoVX6fojFFa_nUU/KoYIK61?nMT/P0
1?nET<co0000o`000?l00003oh^Ae004oi2MgOn8iOWoR>GiohSUn@?oWh6c0onJO;42oiMh[`;oSfVR
0on=IZ03ohaTW`[oRf>N0on>IIl4oi9YW`CoV6fP1?nNLIl4oimaW`?oWFnM1?nJJiX2oiIVV004oi5[
XonCJZ3oTfZPoi=ZX0GoUF^P0onFKZ<4oiIbZ0GoSgB`0_n9MkP3ohEFTP?oRUZC1?n?GY@3oi5PU@Go
TV:F0onDI9L5ok65YPCo[7nT0_nXO:<3olnja@?o^IBa1?n_QZT00oo?jnWoakK9olNfb@02olNfb@?o
_Inj00?o/HZ/ojJ4/?nVQ;000_nVQ;04oif5^@03ok>E^?nYTkkoZI>n00;oZI>n1?nQUlX00onGXMco
YYS7ojJHa`02ojJHa`CoWigA0_nJY]h2ojNUe0CoXZ[L1OnP/N@2oijgjP;oY;3Q0onS]>D01?l0003o
XkCUoj>hj?nS^>P2ojJgi@CoYKWW0_nU^nT3ojNkj0CoY[cY0_nV_^/2ojRojQCooooo00?o0000oooo
ooooool05_ooool002Cooooo00?o0000ooooooooool03_ooool2okS3h`?o[L7X1?nY]n<3ojF]g@;o
XJCH00CoU:CPohjKg?n>VmcoSY_L1?n:U=P3ohR>d`CoS8_=0onBRLL3oiV8`0CoWhRk1?nPQ[L2oin4
]P03ojRKbOnUU/KoYIK600;oYIK60_nMT/P3o`0000;oUI3<0_nPd_T4ohkIo`;oY8Nf0_nOPK<01?nD
L:OoTFbToi5/Y?nAK:@4ohmYXP?oSFJP0on<I9l:oh]SWPCoSVFO0onBJIl4oiQ]X0CoWW6O1?nOLIl3
oie_W@;oVV^J0_nDLJP3oi5[X`?oTfZP1OnEJj04oiI^X`CoUW:X0on?M;02ohEET@CoQEJB0on:FY<4
ohmNU0?oTF2E1OnBHYH3oiATU`Go/HFV1?n/Oj@00onXO:?ock[5olnja@02olnja@Co^IBa0_n_QZT3
olo[j@CoakK900Co_Injok6:[?naRZco/HZ/1?nVQ;02oif5^@?o/iFh0onYTkh3oj6GbP03ojjH`?nV
V<OoYYS700?oYYS70onOWM400on]XlkoYjGDojNUe003ojNUe0CoXZ[L0_nP/N@2ojJ/f`GoY;3Q0_nS
]>D00ol0003oYkCRojJgi@04ojJgi@;oYKWW0_nW^NH5ojNkj0;oY[cY0_nX_^T4ojRojQCooooo00?o
0000ooooooooool05Oooool002Cooooo0ol0000?ooooo`Go[L7X0_nY]n<01?nM]>WoVJcToiV/i?nI
[>@4oiBTh0?oSY_L0on:U=P3ohR>d`CoS8_=0onBRLL4oiV8`0?oWhRk0_nPQ[L2ojFOd0CoZ9_90_nU
U/H3o`0000?oWI;800?oUI3<oj3BnOnPd_T00_nPd_T01On>fOooZ8jjojB7]_nTQkKoUgJ[00?oU72W
0onAK:@4ohmYXP?oSFJP1?n<I9l9oh]SWPCoSVFO0onBJIl4oiQ]X0CoWW6O1?nOLIl2oie_W@03oiUj
[onDLJSoU76X00;oU76X0onAJj<4oi=ZX0CoUF^P1?nFKZ<4oiIbZ003ohmd/?n7Ei7oQEFA00;oQEFA
1?n5EY83ohYJT`CoSejD1?nAH9D4oi9RUP;oU6BG0_ncRj/4ok65YPCo[7nT1_o?^/D3okVD/@03ojn6
ZOo?jnWocn_Y00?ocn_Y0_o7]/T00onRQ[Ko/HZ/ok6:[002ok6:[0CoYXB`00?oWHFiok>E^?ncUKP0
0_ncUKP4ojVC_P04oj6Gb_n^V<3o[YS0ojjH`0GoYYS700CoWigAojfSc_n]Xlko[J?>1?nWYM@2oj:Z
g0;oZZ[G1OnV[=/2ojB`h@;oZK?O0onW]>801?l0003oYkCRojJgiOnV]nD2ojRhi0GoYkWV0_nW^nP2
ojRmj0GoZ;kY0_nX_nX2ojW0jQ;ooooo0_l00009ooooo`Co000000?o410@ooooooooool01oooool0
02Cooooo00?o0000ooooooooool04?ooool2ojg1j0?oX;k^0onM]>T3oiV/i0CoU:CP0on>Vm`3ohZD
f0;oR8kC1?n<Rld4oi:9a`?oVHS00_nOR;/00onNXmWoYIo@ojFOd003ojFOd0;oZ9_90ol00002ojFF
aP;oWI;81?nXco@2oj3Bn@;oZ8jj00CoVW^_oiMfZonGMZ_oUgJ[0onDL:L3oi5/Y0CoSfVR0on=IZ04
ohaTW`WoRf>N1?n>IIl4oi9YW`?oV6fP1?nNLIl3oimaW`04ojF7]OnINZooVGZ_oiUj[`CoU76X1?nA
Jj<3oi=ZX0CoUF^P1?nFKZ<3oiIbZ0?oQeNA0on5EI44ohEFTP?oRUZC1?n?GY@4oi5PU@CoTV:F00Co
U6BGok>;ZoncRj_o/h^[1OnaQJH3ojaoY003ojc_Yoo?^/Gock[500?ock[50_niU;400onNLZ7oU72W
o`000002olo[j@CoZhJ]1OnaRZ`4ojJ4/0Go/iFh0onYTkh00ongW[oo[YS0ojjH`002ojjH`0CoYYS7
00?o/jG;ojfSc_n]Xlh00_n]Xlh3ojNUe003ojjZdonZZ]OoZZ[G00?oZZ[G0onV[=/00on//]goZK?O
ojVcg`03ojVcg`?oYkCR00?o0000ojRhi?nX^>@00onX^>@3ojNiiP03ojVlionX_NSoZ;gX00?oZ;gX
0_nX_^T2ojVojPGoZL3Z4oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo
0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`00
0?oooooooooo01;ooooo1?nP_^h3oifdj@?oVJcT0_nDY>000on6ZNcoOJC/ogfTk002ogfTk0?oMJ7]
0_m]WNd4ohb;c@?oTXW70_nIR<000on=Xn?oWZ?IoijSf@02oijSf@?oYIo@0ol00002ojRKb@;oYIK6
1?n/d_@2ojS?m0;o[IJn00CoZ8jjoiYk[onJNjooVW^_0onGMZ/4oiA`Y`?oTFbT0on?JJ83oheVX0Co
S6BO2_n;Hih3ohiUW`CoTVVO1?nHKJ03oiiaW`04oimaWonUQkGoYHNeojF7]@CoVGZ_0onDLJP4oi5[
X`?oTfZP1?nEJj04oiI^X`;oUW:X00CoSUbAohMGTOn7Ei7oQeNA0on5EI44ohEFTP?oRUZC1On?GY@3
oi5PU@?oTV:F00?o]9:cok>;ZoncRj/00_ncRj/5ok65YP;o[7nT0_ncQJ@00on/kjOock[5olnja@05
oiibX@Co]H^Y1?n[QZd5ok6:[0CoYXB`00?o_9bhok>E^?ncUKP00oncUKP01?nYTkko]ijookNN_ong
W[l4ojjH`003ojJHaoncYL_o/jG;00;o/jG;1?n]Xlh01?nWYMCo[Z[CojjZdon^Z]<5ojZZe`04ojJ/
fon//]go[;;Mojbbg@CoZK?O00GoYkCRojZghonZ]n?o0000ojZgh`04ojRhi003ojNii_nY_>OoZKcW
00;oZKcW0onX_NP00onY_nWoZKoZojVojP03ojVojP;oZL3Z0_nY`N/Dooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02Oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool04oooool2
oj2nkP03oi6il_n@]>ooT;C_00;oT;C_0on<[^d3ohJYk0CoOJC/0omeXNd3offMk@?oLIk]0_mmXNX4
ohfSh`?oWZ?I0ol00002ojFOd0;oZ9_90_nWeoP4ojcBm0;o/Yk40_n]U[h00onNP[GoVW^_oiYk[`02
oiYk[`?oUgJ[1?nDL:L3oi5/Y0?oSfVR1?n=IZ03ohaTW`[oRf>N0on>IIl4oi9YW`CoV6fP0_nNLIl0
0on/T;SoYHNeojF7]@02ojF7]@CoVGZ_0onDLJP4oi5[X`?oTfZP1?nEJj04oiI^X`03oiIbZ?n>G97o
SUbA00?oQeNA0on5EI44ohEFTP?oRUZC1On?GY@3oi5PU@;oTV:F0_ndT[<4ok>;Z`Go/HFV00Co[7nT
ok>5Y?ncQJCo/hFT0onXNJ05oiibX@Go]H^Y0_n[QZd2okfG/0Go/HZ/0_nVQ;02okbL^0Go/iFh1?ng
W[l3ojjH`003okb]boncYL_o/jG;00?o/jG;0_n]Xlh2okF_d`Go[Z[C0_nZZ]L2ok2df`Go[;;M0_nY
/ml2ojfhhP?oZ[OS00Co0000ojZghonX^>CoZ;ST0_n[_>L4ojVli`03ojRmj?nY_nWoZKoY00;oZKoY
0_nY_nX3oj[1j`CoZL7[4oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo
0009ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP06ooooo`03o`00
0?oooooooooo01Gooooo0onA^O84oi2dk`?oS:k]0on6ZN`4ogfTk0?oMJ7]0om]WNd3og6Nk@;oOJ7Z
0on=Xn<01?nNXmWo0000o`000?nNXmT2ojFOd0?oS]Oo1?nWeoP01On/d_Co]jS:ok:Na?nbW/CoXXZk
00?oWX:e1?nJNjl3oiMfZ`CoU72W0onAK:@4ohmYXP?oSFJP0on<I9l:oh]SWP?oSVFO1?nBJIl4oiQ]
X004oiiaWon/T;So[92hojb@^0?oYHNe1?nINZl4oiAaZ0?oTF^S0onCJZ05oiE[X0?oUVjS0on>G943
ohMGT@?oQEFA1?n5EY84ohYJT`CoSejD0onAH9D00onBHYKo]9:cokBB/`02okBB/`?o/h^[1?naQJH0
0on_PZGo/hFTok>5Y002ok>5Y0CoZ7VP0onNLZ42okbD[@Co]H^Y00CoZhJ]okfG/?nmUk3o_IN`1Ona
RZ`01?nVQ;3o_9bhokbL^?nlW;P4ok>E^003olB^a?ngW[oo]ijo00?o]ijo00Co[YS0okb]bonl[L_o
_:g;1?ncYL/5okF_d`?o[Z[C00?o/kSMok2dfon`]=/00on`]=/2ojbbg@;o[k[R1On]^>82ojZgh`03
ojbmi_l0003oZkcW00CoZkcW0_nY_>L2ojZoj@?oZKoY1onZ`N/4ojW1ja?ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`09ooooo`002Oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01Oooool3o`0001Kooooo0onA^O82oi2dk`?oQkCc0on4/o@3ogfcmP?o
LK7h1?mP/?/3odF[n0?o<jOa00Co:jS[o`000?l0003o00000_nNXmT4of[=o@?oS]Oo0_nWeoP2okNX
bP03ojJB`OnRR[_oXXZk00;oXXZk0onNP[D4oiYk[`?oUgJ[0onDL:L3oi5/Y0CoSfVR0on=IZ03ohaT
W`[oRf>N1?n>IIl3oi9YW`?oV6fP00?oYhjkojb@^?n/T;P00_n/T;P4ojF7]@?oVGZ_1?nDLJP3oi5[
X`?oTfZP1OnEJj02oiI^X`CoSUbA1?n7Ei43ohEET@CoQEJB0on:FY<4ohmNU0?oTF2E1OndT[<4ok>;
Z`;o/HFV0_n_PZD4ok>5Y0CoZ7VP0_nNLZ43okbD[@Co]H^Y1?nmUk04ok6:[003olZ``OnlW;So_9bh
00?o_9bh0_ncUKP3olB^a0?o]ijo00?o`kgDokb]bonl[L/00_nl[L/3ok>Ub`;o^kWG1One[m<01?n^
Z]?o/kSMok>hgOnc^=d3ok2df`03ok;0i?n_^^;o[k[R00?o[k[R0_n]^>83ojjoi`?o[;gV00?o0000
oj^lion[_>L00_n[`NT5ojZoj@03ojVojOnZ`N_oZ/7[00CoZ/7[0_nY`^/5ojW1ja7ooooo0ol00007
ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo01Sooooo0on7]_@4ohNdl`?oQ;?d0omm/oH3
og6an0;oH;3k1?m;_o@01?lDXl_o0000o`000?l00002okW]m@;oa=OX0oo7dn<3okbje`Co^[7A00Co
]jS:ojJB`OnVT/7oYY;10onRR[/3oij2]@CoVW^_0onGMZ/3oiA`Y`?oTFbT1?n?JJ83oheVX0?oS6BO
2_n;Hih4ohiUW`?oTVVO00?oV6fPojN>^onWS[/00_nWS[/3ojb@^0CoYHNe0onINZl4oiAaZ0?oTF^S
0onCJZ05oiE[X003oiI^XonDHI;oU66B00?oSUbA1?n7Ei43ohEET@CoQEJB0on:FY<4ohmNU0;oTF2E
0_nfVk`4okBB/`Co/h^[00?o/HFVojn2YOn_PZD00_o<YK43ok>5Y0CoZ7VP00?oWW:QokbD[OnlU:d0
0_nlU:d4okF;Z@03omRo`OnmUk3o_IN`00;o_IN`0_naRZ`3olZ``@Co_9bh00?o/iFholB^a?o4[/@0
0_o4[/@2okNN_`;o`kgD1Onl[L/01?ncYL_o^kWGok^ieonk^ML4okF_d`03okS2h_nc^=go/kSM00?o
/kSM00Co/;CKok;0i?nb`>Co//3T0on_^^82ojk3j@Go[[oW0_n/_NH00ol0003o[<?[oj_1j@03oj_1
j@;oZ[oY0_nZ`^/4oj[1j`03ojW2k?nY`^_oZL;[00?oZL;[1?nY`N/>ooooo`Co000000?oooooo`00
0?ooool01_ooool00ol0003oooooooooo`09ooooo`002Oooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`?oQkKd0_n7]?<2ohFi
m`?oPKgj1?mj`Od2of_4oP?oO]Sn0ol000001?nAjoCo^NgeokW]mOnikOD4olCGj003olOChonl^]Oo
_;[G00?o_;[G0_nj/M400onZVlOoYY;1ojJB`@02ojJB`@?oXXZk0onNP[D4oiYk[`?oUgJ[1?nDL:L3
oi5/Y0?oSfVR0on=IZ04ohaTW`WoRf>N1?n>IIl2oi9YW`03oij8_?nWS[_oYhjk00?oYhjk1?n/T;P3
ojF7]@CoVGZ_0onDLJP3oi5[X`CoTfZP0onEJj04oiAQTP?oSUbA1?n7Ei43ohEET@CoQEJB0on:FY<4
ohmNU004oi5PUOnfVkco]Y^lokJK_0Go]9:c0_ncRj/00onbQ:Co[h:Uojn2Y@03olbU/@?o/hFT1?nX
NJ05okbD[@?o]H^Y0_oH_l44okfG/003ok6:[?o:/<7ob[3100;ob[311?nlW;P5olB^a003okNN_oo3
_MCo`kgD00;o`kgD0onl[L/2ol;?i0Co^kWG00?o]JoCokS2h_nh`^800_nh`^82ok>hg@;o/lSZ1Onb
`>@00on_^^;o[/?Yojk3j@02ojk3j@;o[[oW0_n/a^d3ojc3j`04o`000?n/`n_oZl7Yoj_1j@;oZ/C/
1?nZ`^/00onZ`N_oZL;/ojW2k002ojW2k0CoZL;[1OnY`N/:ooooo`?o00001Oooool00ol0003ooooo
ooooo`03ooooo`03oeEEEOmVIVKo000000_ooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo0_l0000Kooooo`?oQKGd1?n5^OL3oh6mnP;o
N/7m0on7d?l3o`0000;oW>Kl0onfiOH3okoGj`;oa=OX0_nm`Md4okbje`03ojjTcOnZVlOoZY_700;o
ZY_70onVT/44oj::^`?oWX:e0onJNjl3oiMfZ`CoU72W0onAK:@3ohmYXP?oSFJP1?n<I9l9oh]SWP;o
SVFO0_nGPKT4oij8_0CoYhjk1?n/T;P3ojF7]@CoVGZ_0onDLJP4oi5[X`?oTfZP0_nEJj000onGHi?o
U66BoiAQTP02oiAQTP?oSUbA1?n7Ei43ohEET@CoQEJB0on:FY<3ohmNU003okBRa_nfVkco]Y^l00;o
]Y^l1OndT[<01?ncRj_o/XBTok:4Y?n_PZD4olbU/@Co/hFT0onXNJ000oo:Zk_o_9B]okbD[@03okbD
[@04okF;ZOoH_l7of;o1omRo`@Co_IN`1Oo:/<43okbL^0;od];I0oo4[/@2olOOjPCo`kgD00?o_:g;
ol;?i?o2cn@00oo2cn@2ok^ie`;o]m3]0onh`^82ok3Dl`Co/lSZ0_nb`>@2ojk9kPCo[/?Y00?oZ/W`
ojc6kOn/a^d00on/a^d2ojc3j`03oj[5k_l0003oZ/C/00CoZ/C/0_nZ`^/2ojW3k@CoZL;/1OnY`^/4
ojW1j`Kooooo1?l00008ooooo`03o`000?oooooooooo017ooooo0009ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool06ooo
ool3ohFem0;oQKWg0_n=_oP4ohc8o0?o00000_nLg?d3ok3Mm`03okKUm_noen_o_mO[00;o_mO[00?o
_<GQokg1gOnm`Md00onm`Md00onl^]Oo[ZC=ojjTc@02ojjTc@?oZY_71?nVT/43oj::^`?oWX:e0onJ
Njl3oiMfZ`CoU72W0onAK:@3ohmYXP?oSFJP1?n<I9l8oh]SWP03oi5i]?nGPKWoUh6i00?oUh6i0onN
R;`5ojN>^`;o[92h00CoS5nHoheNU_n=GYKoSEjF0on=GYD4ohmNU0CoTF^S0onCJZ000onEJj3oUf>C
oiMST`04oiAQTP?oSUbA1?n7Ei43ohEET@CoQEJB0on:FY<00on?GYCo]:;6okBRaP02okBRaPCo]Y^l
0ondT[<4ok:4Y0Goc:Fa1?ncQJ@2ojQiX0;obZ^k1OnlU:d00oneRjWof;o1omRo`@02omRo`@;o_IN`
0_oDgn05olZ``@03okbL^?oBd]Wod];I00;od];I00?oa:k4olOOj_o7gnX00_o7gnX2ol>me0;o/ncg
1?o2cn@00onVh__o]m3]okO@k@03okO@k@03okS2h_n`e??o/=Cc00;o/=Cc0_ncb>X2ojW?m0Co[/W^
00?o[/?Yoj[9l?nZbO000_nZbO02ojc6k@;oZ<O`0onZaNh01?l0003oZ/G^oj[4k?nZa>`2ojW4kPGo
ZL?]1OnY`^`2ojW2j`;oZ<7[1?nY`N/2ooooo`?o00003?ooool00ol0003oooooooooo`0Aooooo`00
8_ooool00ol0003oooooooooo`0Mooooo`CoSKSc0on=_oP3o`0000?oW=7j00CoW=cmok3Mmon`gOOo
/=gg1?nke>d01?noen_o_<GQokc5hOnlaN43okg1g@03ok6[don^Y<go[ZC=00?o[ZC=0onZVlL4ojJB
`@;oXXZk00CoTh6loi1j^?n@N[SoT7Zh0on=M[@3ohab/@CoRVn^0on9KJd3ohQ/[0?oRFb/1?n:KZd3
oh]`[`?oSG>a1?nANK@4oiN1^@?oWXRl1OnWS[/00on/T;SoS5nHohaOV003oheNUP?oSEjE1?n?GY@3
oi=RU004oi5[XonCJZ3oTfZPoiMTU0?oUf>C1?nDHI83ohiLT@CoQeNA0on5EI44ohEFTP;oRUZC00?o
Y9O7okBRa_ndX/H00ondX/H4okJK_003okBB/oneR:Ko]HRV00Co/XBT00?oa^nDolbU/Oo<YK400_o<
YK44ok>5Y004ojQiX?o:Zk_obZ^kolZ[^`Co_9B]00?oTmj@omRo`OoH_l400ooH_l401?nmUk3oe=oP
omCOh?oDgn04olZ``@;oPnBg0_oBd]T3ofSLeP;oamoZ0olg^kL4ok?/m`03ol;?i?nVh__oY^;k00;o
Y^;k0_ngd>d3oigMo@;o/=Cc0_nMeO/5ojW?m0;o[/W^0onVc_@2oj[9l0;oYLWb1?nXao02oj[5kP03
ojO6kol0003oYlK_00CoZLC^0_nY`nd2ojS3k@CoZL;/00?oZ<7/ojS1jonX`N/00onX`N/2ojW1j`;o
Z<3[00?o0000ooooooooool03_ooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0003ooooo
ooooo`0Nooooo`;oSKSc0_nI_?02o`0000?oV/Kf0_nLdOX3ojcCm003ok3Mmonke>go^mC]00;o^mC]
0_nkan<4okc5h@04okg1gOnaZm?o/J_Cok6[d`Go[ZC=0onZVlL2ojJB`@04oiR7`OnCPKcoTh6loi>1
_0?oT7Zh0on=M[@3ohab/@CoRVn^0on9KJd3ohQ/[0?oRFb/1?n:KZd3oh]`[`?oSG>a1?nANK@4oiN1
^@CoWXRl0onWS[/01?n=HY_oS5nHohaOV?n<GiP3oheNUP?oSEjE1?n?GY@3oi=RU0CoUfBD0onGHi<4
oiAQTP;oSUbA00GoV7FZoh]]Zon;KJ_oRff[ohMGT@03ohEET@;oQEJB0_nAOk`4ojBGa`Co]:;60onf
Vk`4okF8YP?o/XBT0_o6ki@5olbU/@?o/hFT1Oo:Zk/2okbD[@?oTmj@0ooH_l400onJQkko1000omCO
h003omCOh003olZ``OnTULKoY9G600CoXiO81?n5VMl4oe>Tm`04oabLi_l>003oH=?_of3Ck`?o=[OX
1?m]eOX2oigMo@?oQm?o0onMeO/2ojW?m0?oW]3i0_nVc_@2oj3:mPGoYLWb0_nXao02ojK7l@?oYlK_
00Co0000ojO6konYa>koZLC^0_nW`nd4ojS3k@03ojW2k?nX`NcoZ<7/00;oZ<7/1?nX`N/5ojS0ja3o
oooo00?o0000ooooooooool04?ooool002;ooooo0_l0000Pooooo`?o00000_nI_?02oi[6mP?oZLWa
0_n/do@4okO?k003ok_DkOnkan?o^lOS00;o^lOS0_nlaN400onc/]Oo/J_Cok6[d`02ok6[d`Co[ZC=
00CoXIO:oib?aOnLSlGoW8o51?nHQl43oi>1_0?oT7Zh0on=M[@3ohab/@?oRVn^1?n9KJd3ohQ/[0?o
RFb/0on:KZd4oh]`[`?oSG>a0onANK@5oiN1^@?oWXRl00CoYhjkoheRVon=HY_oSF:K0on<GiP3oheN
UP?oSEjE1?n?GY@3oi=RU0CoUfBD0onGHi<4oiAQTP03ohiLTOnHMJ[oV7FZ00CoRff[0on:LK45oi5o
_0?oY9O71OndX/H00onfVkco[hV]okF8YP04okF8YP04ok:4Y?o6kiCoa^nDolK_U0Goc:Fa0_ncQJ@2
om3aj0CobZ^k00?o_9B]ojf9/?n]RK000_n_RZh01?oH_l7o[hZ^ojn:[_nJQkh2okNH]`;oe=oP0onT
ULH2okNK_0CoXiO80_n5VMl00onWX]7oT:OUoi2Wi@03oi2Wi@CoKZcf1?mR^Od3ofW5oP;oQm?o0_n4
bOh5oi7?o@;oW]3i0_nIbOP4oj3:mP;oYLWb0_nRao85ojK7l@;oYlK_00?oY/?^o`000?nW`nd01?nW
`nd2ojS3k@;oYl;/0onX`N`2ojS0j`CoZ<7[1?nX`>/@ooooo`03o`000?oooooooooo013ooooo000R
ooooo`03o`000?oooooooooo01cooooo0ol000000oooooooVKc`oiVll003ojJok0?oZLWa0_ncbNX4
okO?k0;o^/OT0onkan<00onf^=[o/k;Gok>be`02ok>be`Co/J_C00Co[ZC=oj6Gb_nQUl[oXIO:1?nL
SlD3oiR7`@?oTh6l0on@N[P3ohef]0?oS7:a0on:Kjh4ohU][@?oR6b/0on9K:`3ohY^[@CoRg2_0on=
Lk44oi5i]0CoUh6i0_nNR;`00omgFZCoTFROoheRV`02oheRV`?oS5nH0on=GYH3oheNU@CoSejD0onC
HY@4oiMTU0?oUf>C0onDHI800onVPjkoV7FZoiQeZP02oiQeZP?oRff[1?n:LK44oi5o_0CoY9O70_nd
X/H5ojn9[@Co]HRV00?o/XBTok^?Z?nkSjP00_nbRjd4olbU/@04ok>5Y?o@lNSod?7Xom3aj0?obZ^k
0on]RK02okjD[0Co[hZ^1_ngV;L01?nTULKo]i^lokNK_?ngVk`4oj>Gb0CoYj;A1On@YnD2ofj/mP;o
TZSU0on5/_<5ogbln`?oQ<Wn0_nAcod2oi;5n0GoVLWh0_nPb_H2oik5m0CoX/Ob0_nVao42ojC3k`?o
Y/?^00Co0000ojK3k_nW`ngoYl?]0_nW`^d5ojO2k003ojS1k?nX`>_oZ<3[00;oZ<3[0_nX`N/6ojS0
j`oooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool06Oooool3o`0000Ko
oooo1?nV_n`00onYbO7o/lWZok?9jP02ok?9jP03okO?k?njanCo^/OT00?o^/OT00Co^lOSokJhf_nf
^=[o][SJ1?nc/]L2ok6[d`03ojJOconQUl[oXIO:00?oXIO:0onLSlD3oiR7`@?oTh6l0on@N[P3ohef
]0?oS7:a1?n:Kjh3ohU][@?oR6b/0on9K:`4ohY^[@?oRg2_0on=Lk44oi5i]0;oUh6i0omkGJ@3ogMJ
Y0?oSF:K0on<GiP3oheNUPCoSEjE0on?GY@3oi=RU0CoUfBD0onGHi<01?nDHI;oYX>^ojJ3[_nVPjh4
oiQeZPCoRff[0on:LK44oi5o_0?oY9O70onPQkT5ojn9[@Co]HRV0onkSjP00onbRjgo_i6VoknAYP02
oknAYPCoZGfS00?o_I6Yom3aj?o:Zk/00_nmTJT01?n]RK3o_YB/okjD[?nnU:`4ojn:[P03olRR/_ng
V;Oo]iRg00?o]iRg1?ngVk`3oj>Gb0;o]Z?51?nWX]42oi2Wi@;oYJKG1OnBZ>D3ohFbl`;oO;ck0_n@
]o45ohnomP?oT/Gh0_nIbOP2oi[2m0GoW/Gd0_nRao82oj;2l0CoY<?_0_nV`nh00onV`Ngo0000ojO2
k@04ojO2k@;oYl;/0_nW`>/4ojS0j`03ojRojonX`>_oZ<3[00KoZ<3[3oooool00ol0003ooooooooo
o`0@ooooo`008_ooool00ol0003oooooooooo`0Fooooo`?o00002_ooool2ojJok0;o/L;W0oncbNX3
okS5i0?o^/OT0_ng_=d4okJhfP;o/k;G00?oZZKCojJOconVWll00_nVWll4oj6GbP?oW8o51?nHQl43
oi>1_0?oT7Zh0on=M[@2ohab/@CoRVn^0on9KJd3ohQ/[0?oRFb/1?n:KZd4oh]`[`?oSG>a0_nANK@3
oh1RY`?oNefT0omgFZ@2og9HY@04oheRVon<GiSoS5nHohaOV0?oSEjF1?n=GYD3ohmNU0?oTf:D1?nG
I9@2oiMST`03ojf?]onVPjkoYX>^00?oYX>^0onHMJX4oh]]Z`?oRW6a1OnAOk`00onTUlOoU8S4oj27
^@03oj27^@Co[hV]0oneR:H4ok^?Z0Go_i6V1?nYOJ<5okfAZ@04ojf9/?nnU:co_YB/okjD[0?o[hZ^
0_o8X[84okNH]`03olJW^_ngVkco]i^l00?o]i^l00CoXiO8okJSaOnfXlGo]Z?50onWX]400onfZ/go
YJKGojFVe`03ojFVe`;oTZSU0_nS[]l4oiVaj0CoT;Oa0_n?_oH2oiRikPGoUkgb0onJ`_@2oik5m0;o
Wko`1OnR`_02ojC3k`;oY<3]0onV`Nd00ol0003oYl;]ojO2k@02ojNoj`GoYl3[00?oZ<3[ojRojonX
_n/00_nX_n/8ojS0j`kooooo00?o0000ooooooooool04?ooool002;ooooo0_l0000Dooooo`?o0000
3_ooool4ok72i`03ok?9j_nhaNCo^<GT00?o^<GT00?o^/OTokNlgOng_=d00_ng_=d2okJhfP03ojj^
eonZY]?oZZKC00;oZZKC0onVWll4oj6GbPCoW8o50onHQl43oi>1_0?oT7Zh0on=M[@3ohab/@?oRVn^
1?n9KJd3ohQ/[0?oRFb/0on:KZd4oh]`[`?oSG>a00?oTGVdohIZZon0HZL00_n0HZL3og]MY0?oMeZT
0ombF:D3ohaOV0?oSEjF1?n=GYD3ohmNU0?oTf:D1?nGI9@00onGHi?o[Hngojf?]`05ojJ3[P?oV7FZ
1?n;KJ/4ohYa/@?oTGnl0onDR<@4oj27^@Co[hV]0_neR:H00oo7WJco^hnXok^?Z002ok^?Z0Go_i6V
0onYOJ<2olBL[PCo_I6Y1OnnU:`01?n_RZkob::bolRR/_o8X[83okNH]`?oaZNj0ongVk`00oo6[/;o
]Z?5okJSa@03okJSa@04ojNRdOnfZ/go]Z[=okJZc@?oYJKG00?o/K7Hoj>^gonS[]l00onS[]l4oiVa
j0;oT;Oa0_nL]>T4oiRikP;oUkgb0_nL^Nd4oifmk`CoWko`0_nR`_02oj>nk@GoY<3]0_nV`Nd00onV
_n_o0000ojNoj`03ojNoj`;oYl3[0_nW_n/4ojRoj`03ojRoj_nX`>_oZ<3[00OoZ<3[3Oooool00ol0
003oooooooooo`0@ooooo`008Oooool2o`0001;ooooo0ol0000Booooo`;o/L;W0ong`n<2okS5i0?o
^<3P0ong_=d00ona]M_o[ZkGojj^e`02ojj^e`CoZZKC0onVWll2oj6GbP03oiJ@bonAR/SoTH[800;o
TH[80on<QLL3ohN1aP?oPgo70omoP<X3ogf3c`?oRVn^1?n9KJd3ohQ/[0?oRFb/0on:KZd2oh]`[`;o
QFNY0omnHJL3ohIZZ`;oP6:W0omkGJ@3ogMJY0?oLURU0omdGJT3oheNUPCoSEjE0on?GY@3oi=RU0?o
UfBD00?o[Yc4ojf?]on]SkL00_n]SkL4ojJ3[P?oV7FZ1On;KJ/3ohYa/@03oi5o_?n>R/_oSX[;00Co
U8S40onPQkT4ojn9[@03okF8Y_o7WJcoaif/00?o^hnX0_oQ`kT5oknAYP;oZGfS0_o4W:h4okfAZ@Go
_YB/00?o[hZ^olRR/_o8X[800_o8X[800ongV;OoaZNjolJW^P02olJW^P;o]i^l0oo6[/83okJSa@03
ol:bbonfZ/go]Z[=00?o]Z[=00CoYJKGok6af?na/MSo/K7H0onS[]l00on/]=ooXk;Soj>bh`02oj>b
h`GoW;CY0_nH^Nh2oijhjPCoW;W]1?nM_Nl2oinol0;oXKc/1?nS_^d2ojC0k@;oYKk[0onV_n/01?l0
003oY[o[ojNojonW_n/2ojNnjPCoYko[00?oZ;o[ojRoj_nX_nX00_nX_nX2ojS0j`;oZ<3Z1OnX`>/<
ooooo`03o`000?oooooooooo013ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00oooooo0_l0000F
ooooo`?o]l?S0oni`n84okS0h004okNlgOna]M_o/KGKok6ef`Co[ZkG0_nZY]<01?nQW];oW9O>oibG
c_nLUlh4oiJ@b`?oTH[81?n<QLL3ohN1aP?oPgo70omoP<X2ogf3c`?oNX_H1OmdV>H4ofV^n0;oAkkb
0on=L:h3ohEWZ@?oOV6W0_mhGJL00on6JZ_oP6:Woh1RY`04og]MY0;oMeZT0ombF:D3ogAMZ@;oNfNa
00?oSEjFoheNUOn=GYD00_n=GYD3ohmNU0?oTf:D00?oUfBDojjLa?n^W<@00_n^W<@3ojf?]`CoYX>^
1?nHMJX4oh]]Z`;oRW6a0_nRULL3ohj:b`?oU8S41?nPQkT2ojn9[@04oiAXWOo7WJcoaif/olNM[0?o
^hnX0_oQ`kT5oknAYP04ojUmXoo4W:koa9b^olBL[P?o_I6Y0_oH/[<4okjD[0Gob::b1Oo6YkX00ong
VkcoaZk2olJ^`P02olJ^`P03okJSaOo2//_o`[;;00;o`[;;0onfZ/d00oo0^]Co/K7Hok6af003ok6a
f004oj>^gon/]=oo[;COojbdg`CoXk;S0_nL]>T2oj>gi`GoW[SZ0_nL^Nd2oj2hj@?oX;[[1OnQ_>`2
oj>nk@;oY;c[1?nU_^/2ojJoj`03ojJmj_l0003oYkkZ00CoYkkZ0_nW_n/7ojRojPCoZ<3Z0_nX`>/2
ojW0j`gooooo00?o0000ooooooooool03oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo0ol0000I
ooooo`03okO3honi`n;o^L?R00?o^L?R0_nh`>02okBlg`Co/KGK0_n^[]L00onUYmOoXIkBoj6NdP02
oj6NdP?oW9O>0onFT</4oi6:b0?oS8G70on7PLH3oh=oa`?oOh3:0ommPll3ogZ;f0GoM9SV0_mY[_P3
oiIl]0?oSG2^0on5IjT3ogiQY`?oN5fW0on0HZL3og]MY0;oMeZT1?mbF:D2ogAMZ@?oNfNa1?n=GYD3
ohmNU0;oTf:D00?oWiS=ojjLa?n^W<@00on^W<@3ojf?]`CoYX>^1?nHMJX2oh]]Z`;o[YJn0_nRULL3
ohaPVP?oTVFI0_nIJIX4oj27^@03ojn9[OnHJI[oaif/00Coaif/00Co^hnXon73^OoQ`kWohL>i1Ono
TJH01?nYOJ?oa9b^olBL[_o4W:h3okfAZ@;of;:c1?nnU:`00ooE^Kkob::bolRR/P02olRR/P03omc5
`_o6Yk[oaZNj00;oaZNj1Oo6[/85ol:bb`03okJZcOo0^]Co`;[D00;o`;[D0_na/MP2okJlgPGo[;CO
0_nS/^<2ojRiiPCoXkOW0_nN^>X2oj:hj0GoX;SY0onP^^/2oj6lk0;oXk_Z1OnT_>/2ojFnj`;oY[cY
0onV_NX00ol0003oYkkZojNnjP02ojNnjP[oZ;oZ0_nX`>X2ojW0jPCoZL3[3?ooool00ol0003ooooo
ooooo`0?ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00005ooooo`;o0000
2_ooool3o`0001gooooo1?ni`n800onf`nCo];cOokBlg`03okBlg`;o/KGK00?oZJoLojFWeonUYmL0
0_nUYmL3oj6NdP?oW9O>1?nFT</3oi6:b0CoS8G70on7PLH3oh=oa`?oOh3:0ommPll3ogZ;f0;oM9SV
00CoZi[6oj2:_?nPR[coX8Zl0onFO;@3ohe`[P?oQFNY0omnHJL3ogQMY`;oLUj/00CoP6:Wog]MY?mk
GJCoNefT0omgFZ@3og9HY@?oM5fY0_mkIk44oh5c^P?oRX?61?nOV<d4ojjLa0Co[Hng1?nVPjh2oiQe
ZP04ojJ;]on^U[ko[YJnojjF_P?oSFBM0on<H9X3oi9UV@GoVFVJ0onHJIX00ooA/KWoaif/olNM[002
olNM[004ok^?Z?oQ`kWohL>ion73^@Co_i6V00?oelc?olBL[_o4W:h00oo4W:h01?nmTJWof;:comRb
/ooH/[<3okjD[0;oeKVn0oo8X[82omc5`P?oaZNj0_oA`/`3olJ^`P;oc/KB0oo2///2olO7fP?o`;[D
00?o`/gRokJlg_nf_=h00onf_=h2ojbdg`;o[/3W1OnX^NH2oj>gi`;oYK[X1?nR^>P2oj2hj@KoX[[Y
1?nS^nX2ojBlj`;oYKcY1OnV_>T2ojJmjP03o`000?nW_NWoYkkZ00?oYkkZ2?nX_nX6ojW0jP;oZL3[
0_nY`N/;ooooo`03o`000?oooooooooo00oooooo0007ooooo`05o`000?ooooooooooooooool00000
2oooool01?m4A4CogMgMooooool00006ooooo`03o`000?oooooooooo00Kooooo0ol0000Qooooo`03
okW3h_nf`nCo]/?T00;o]/?T0ond_=l00on]^>;oZJoLojV_g002ojV_g0?oYJOG1?nQW]83oibGcP;o
UY3;00?oSY[KohVIg?n9VM`00_n9VM`3oh>Jh@CoOYoX0omfZ_84ofNio@;o@[k]0_ncZm03oj^JaP?o
X8Zl0onFO;@4ohe`[P;oQFNY0omnHJL3ogQMY`?oLUj/0omkGJ@3ogMJY0?oLURU0omdGJT3og]W/@Co
PG>j0on:PlH3oinHc@Go[Yc40on]SkL4ojJ3[P06oiQeZ_nVRkOoYX^gojJ;]on^U[koV7:V0on=I9d3
ohaPVP?oTVFI1OnIJIX2oiQYVP;odK6i1?o7WJ`00onBLJ[ohL>ion73^@02on73^@;o_i6V0_oGc<l5
olBL[P03okfAZOoH/[?of;:c00;of;:c00Co_YB/omFi__oE^KkoeKVn0_o8X[84omc5`P03olJW^_oA
`/codL;<00;odL;<00?oaZk2olk6d_o>a]800_o>a]800oo2//_oalOJolO7fP02olO7fP04ol2je?o2
cN;o`/gRol;=hP?o][cN0_ndbn/4ojk0i`;oZ;WV0_nW`>/5ojFjj0;oX[SX0_nR^n/8oj:jj@;oXk_Z
0_nT^nT4ojFlj@;oY[cY0_nV_NT3ojNmj@04o`000?nW_NWoYkkZojNnjP;oZ;kY1OnX_nX8ojW0jPGo
ZL7[2_ooool00ol0003oooooooooo`0?ooooo`001oooool01Ol0003ooooooooooooooooo000000_o
oooo00CogMgMoeEEEOoooooo00001_ooool00ol0003oooooooooo`03ooooo`?o00009_ooool4okK3
i004okBlgon]^>;o[KSRojfhhPCoZJoL0onUYmL2oj6NdP04oiNSgOnCW]_oTikKoi>Nf`CoSY[K1?n9
VM`3oh>Jh@CoOYoX0omfZ_82ofNio@03okZjfOncZm3o/j_@00;o/j_@1?n[V/H3oj2:_0?oUWbd0on=
L:h3ohEWZ@;oOV6W1?mhGJL2og9N[0?oJVBi0omgFZ@3og9HY@?oM5fY0omkIk44oh5c^P?oRX?61?nO
V<d4ojjLa0;o[Hng00?oOfF[oiQk/OnHNk400_nHNk43ojJ;]`03oda7ZonHLZKoV7:V00?oSFBM0on<
H9X4oi9UV@CoVFVJ00CoV6VJom6a^OoA/KWodK6i1?o7WJ`2oi9aZP?ohL>i00?o_i6VomO<cooGc<l0
0_oGc<l3olBL[P03om[odOoH/[?of;:c00?of;:c00?o_YB/omFi__oE^Kh00_oE^Kh00oo8X[;og<G2
omc5`P02omc5`PGodL;<00CobnS[olk6d_o>a];oc/KB0_o6gn/3olO7fP;o`=o_1?o2cN800onf_=ko
]<_[okC;j`02okC;j`;o[/3W0_nYbO04ojO0j`;oYK[X0_nS_nd5oj:kj`;oX[[Y00?oX[_[oj>kj_nS
^nX00_nS^nX5ojBkj@;oYKcY0_nV_>T4ojJmj@;oYkgY00?oYkkYo`000?nX_^T01?nX_^T5ojRojPSo
ZL3Z1?nY`N/:ooooo`03o`000?oooooooooo00oooooo0007ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00omgMgOoc<c<o`000005ooooo`04o`000?ooooooooooooooo`?o0000:_ooool2okK3
i0;o[/;X1?n]^>82ojV_g004oin`i?nLZN3oW:WPoibYh0CoUj?M0onCW]/3ohjJf`GoRIWL0on3V^42
ogjOj0;o=[cB0_njl_<01?o3lo3o^[[IokZjfOnj^]T4ok>[d0?oZi[60onPR[`3oiIl]0?oSG2^0on5
IjT3ogiQY`?oN5fW0ombGZ`2ofYT^@;o?WOO00CoMeZTog9HYOmbF:GoLURU0omdGJT3og]W/@CoPG>j
1?n:PlH2oinHc@;oJUBV0om/EJH3ogmUZ`CoV7^a0_nVRkL2oeI@[`03oda7ZonHLZKoSFBM00;oSFBM
1?n<H9X3oi9UV@CoVFVJ00?oV6VJom6a^OoA/KT00_oA/KT2olNM[0GoTW6Z0_naRjd4omO<c`;oa9b^
0ooJom43omRb/`;o__g?0ooE^Kh2okKle0?og<G20_oClnH3om72c0?obnS[00?oc/KBolKOjoo6gn/0
0_o6gn/00oo7am[o`=o_ol3Ok`02ol3Ok`;o`/gR0_ngg?<2okC;j`;oYmGh1OnYbO02ojO0j`;oXLGb
1?nS_nd2oj:kj`;oX;k^1?nR^n/4oj>kjP;oY;_Y0_nT_>X5ojJlj@;oY[gY0_nW_^X3ojNnj@03o`00
0?nX_^WoZ;kY00KoZ;oZ00?oZL3[ojW0j_nY`>X01?nY`>X7ojW1j`Wooooo00?o0000ooooooooool0
3oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Gooooo
1?l0000^ooooo`Co[/;X0_n]^>800onQ]nSoWk3Toin`i002oin`i0?oW:WP1?nGXmd3oi>Nf`?oSY[K
0_n9VM`4ogK4oP;oGl[j0onjl_<3okg6h@Co^[[I0_ncZm001?nMTLOoThG1oi>5`OnCQL43ohUj_0?o
Og6i0omiK;P3ohEWZ@?oOV6W0omhGJL3og9N[0?oJVBi0_lnMml4og9HY@?oM5fY0omkIk44oh5c^P;o
RX?60omSCj@00oleCkooJUBVofaEYP02ofaEYP?oOfF[1?nHNk401?nVRkOoEU2_oeI@[omFD:l2oda7
Z`?oSFBM1?n<H9X3oi9UV@?oVFVJ00?od=3Jom6a^OoA/KT00ooA/KT00oo7WJcoVg6Soi9aZP03oi9a
ZP04ok23Y?naRjgo/H^]ok6;[@?oelc?00?oa9b^om[odOoJom400ooJom400ooH/[?o__g?okkmc`02
okkmc`03omFi__nfo=Co]_cD00;o]_cD00?og<G2om?ci_oClnH00_oClnH01OoA`/cobnS[ol_Xjoo;
j>_oTNOj00Coa]o[0_nRjOX2ol3Ok`?oYNKk0_ngg?<2oicQo@CoYmGh0_nYbO02oic>n@GoXLGb0_nS
_nd2oig2lPCoX;k^1?nR^n/2oj>kjP;oXkg/1?nT_>X2ojJlj@;oY[g[1OnW_^X2ojNnj@03o`000?nX
_n[oZ;oZ00CoZ;oZ1?nY`>/2ojW0jP[oZL7[2Oooool00ol0003oooooooooo`0?ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01?ooool2o`00037ooooo0_n^
`^P2oj>ok@?oXKOX1?nO/>@3oibYh0;oUj?M0_n=]O45ohRgm0?oP;cj0_mfa?h00omUfNSo]>ofokC_
mP02okg>iPGo_LKQ0_nj^]T00onVWLgoWI77oifAa`02oifAa`?oThG10on9N[`2ogma^@?oNFbh0_mb
Jk`01?n5IjWoOV6WogiQYomnHJL3ogQMY`?oLUj/1?mZI;T01OlnMmooVi?:oi^Cb_n0LKWoLURU00?o
M5fY0omkIk42oh5c^P04ogYIX?m`DYooL5:Oog1BW`?oHdnT0_leCkl3ofaEYPCoOfF[0_nHNk42oei9
X@03oe9:Z_mFD:ooEU2_00;oC4N[0_mBE[P00on=I9goS62JohaPVP02ohaPVP?oTVFI0_nIJIX2om3@
fPCodK6i1?nKLJ<2oi9aZP?o/8>T0onaRjd2omZ_[0Godk:h00?oe[ZnokbO_?nlWk`00_nlWk`4oj:<
_@?oNGo<0_oClnH01?mESN[o09;5o`2BaOo;j>/4oi7WnP04olKOjonRjO[oX^Wjoj;YnP?oOMck0_nU
i_/3ohGOo0?oW>7m0_nWeOP3oi7EoP?oW<ki0_nQaO82oiO7n0GoWL;b0_nP_^h2oi_0lPCoX;k^1?nS
_N`2ojBljP;oY;k/1?nV_N/2ojNnjP;oYko[0onX_nX00ol0003oZ;oZojRojP03ojS0j`;oZL3[3onY
`N/8ooooo`03o`000?oooooooooo00oooooo000Rooooo`03o`000?oooooooooo02oooooo1?nS_nd3
oj6gj0;oWk3T0_nD]nl3oi6ek`CoSKGa0_n8]o@4oh;Bo`;oMmWk00?oNNCUokC_m_ndkoH01?nmc^H2
okg6h@;o[JWC1?nVWLd3oifAa`?oThG10on9N[`3ogma^@?oNFbh0_mbJk`3ogiQY`CoN5fW0ombGZ`2
ofYT^@;oSG^j0_mgI[800onKTl[oP76ioh1a^@02ofUK[`?oI5N]1?mjFJ02og1BW`?oHdnT0oleCkl0
0omoO/SoK5FVofaEYP03ogmUZ`04oiQk/OmkHJWoGTVQoei9X@;oDTZZ00CoEU2_oda7Zom<Aj_oC4N[
0_mBE[P4ohaPVP?oTVFI00?oVFVJom3@f_o@d=X00_o@d=X2om6a^@03oiM_XonKLJ?oVg6S00;oVg6S
00?oTW6Zok23Y?n`Pj@00_n`Pj@2ok6;[@?ofZn/00ComMF]om>b^?oC/[Sodk:h0_oF^[h3okbO_0;o
_Yni0onRS;d4ogUoc0CoEHgZ0ol_X_42oeg>m0?oKL_n0_mmg?/3ogKEo@;oQMol0omjeoh3oh7Ho`;o
TMGn0omlc_l4oh[<oP?oUlOh0_nM`_82oiC3m`GoVl3b0_nP_^h2oibol@?oXKk^1OnT_^`2ojJmj`03
ojFok?nW_n_oYko[00?oYko[0_nX_nX00onW`>_o0000ojS0j`02ojS0j`;oZ<7/4?nY`N/9ooooo`03
o`000?oooooooooo00kooooo000Sooooo`03o`000?oooooooooo02oooooo0_nS_nd2oiRll0?oU[W`
1?nD]nl3oi6ek`;oSKGa1?n7b_h2oh;Bo`;oQ>Cg0_n^j?T2ok[Aj`?o_LkV00?o/[?IojfYdon]ZM<0
0on]ZM<3ojJMc@?oWI770onCQL43ohUj_0?oOg6i0omiK;P2og9[_0?oL7G71?mhGJL3og9N[004ofYT
^On=Nk[oSG^johek^P?oMfJb0_n0LKT3ofUK[`;oI5N]0_mVG[D2ogYIX0?oL5:O0omSCj@00oleCkoo
`M3Vogmnb002ogmnb0;oOfF[00?oCdj`og]QZOmkHJT00omNBJ42oe9:ZP03oeI@[om<Aj_oC4N[00;o
DUJh0ombQML00on<H9[oTVFIoi9UV@02ojK9lPCod=3J00?odK6ioiM_XonGKj<01?nKLJ<5ok23Y004
ok6;[OoJ[jcofZn/omZ_[0;omMF]0_oC/[P4omJj_P04okbO_?nnWkWo_YniokjO^@CoXXbm0_miOl`0
0onPT<?oTigJoi>MfP03oi>MfP;oN[;g0_nS]^H5ohk>o@;oM]Gm0on9eOl2og[GoP;oOm?o1?mac_h2
ogc>o`;oL/Ko1?mkaOh4oh[5n`?oU<?g0_nK`?82oiK1m@GoW;oa0onQ_^h2ojBnk0;oX[o^1?nU_n`2
ojNoj`;oY/3/0onW`>/00ol0003oYl3[ojS0j`04ojS1k0;oZL7[0_nX`N`<ojW1j`Sooooo00?o0000
ooooooooool03_ooool002Cooooo00?o0000ooooooooool0;oooool4oiRll0?oU[W`0_nD]nl2oi30
m`GoSLCj0_n7b_h2ohcMoP?oZN3j00?o[^Siok[AjonjdN/00_njdN/01?nmc^Ko/[?Iok:cfOnb/mT5
ojfYd`?oYYg=0onMTLL3oi>5`@?oRGZl0_moLKT3ogU/^0?oLV^l0_m`MLL6ogBBh@03ofk?oOnTUlOo
SG^j00;oSG^j0omgI[82ofUL/003oh1a^OmYFjooJE^_00;oI5N]1?mVG[D3og1BW`;oHdnT00Co/ngg
ogQc`OmhLl7oN7?10_moO/P3odm>/003oeUA[_mkHJWoNf6Y00;oGTVQ0omBBZX2oda7Z`?oDUJh1?mb
QML4ojK9lP;od=3J00?oTg:YoiM_XonGKj<00_nGKj<3oi]aX`Go/8>T00Co/H^]omZ_[?oJ[jcofZn/
0ooeeJd00ooC/[Soe[ZnomJj_P02omJj_PCo_Yni0onRS;d00on^Tk[oX933oj2@``02oj2@``?oTigJ
0_n_YLh4oj>fiP;oS/km0_nYc_<2ok[=j@?oW=Ck0_n[dO@4ohg?oP?oLlOo1?mba_l2og_5oP;oLkkm
0on0`O`5ohc1n@?oU/7e0_nL_o42oiS0l`GoW/3`0onR_nh2ojFok0;oY<3]1?nV`>`2ojO0j`03ojO1
k?l0003oYl7/00WoZ<7/3?nY`N/7ooooo`03o`000?oooooooooo00kooooo000Uooooo`;o0000<?oo
ool2oiRll0;oUK_a1?nB_O@3oi30m`;oSLCj1?nAe?h01?n<gOkoZN3jojWPn_nYh?X3okOAk@;o^]7[
0_nd^]h4ok:cf@;o[JWC0_nNUld3oiJ>b@?oSXK60on4OlH3ogamb@?oOg6i0omiK;P2og9[_0?oL7G7
1?mdT^44ojBGa`?oSG^j0_mgI[83ofUL/0;oJE^_0omTEjd3ofIN]@?oO8KB00CoHdnTok?]monckOOo
/:oG0_mhLl400omKE;7oOgk8odm>/002odm>/0;oFE6^00?oNf6Yoei9XOmNBJ400omBBZX2o`1Je003
oda7ZomBE[SoDUJh00GoLXGG0_nVbO800omVFk7oTg:Yoi=bZ@02oi=bZ@?oUfnS0_nKLJ<2ojanX`Co
/8>T1?oJ[j`3ooGE[@04onci]OoF^[koe[ZnomJj_P;oc;k=1?nnWkT01?nRS;go[Y>jojjC^_n^TkX4
oj2@``03oi>Mf_n_YLko[jG>00;o[jG>0_nS]^H3okZlf`03ojW>lonjcNWo^/gY00;o^/gY00?oW=Ck
oj_Am?n[dO@00_n[dO@2ohg?oP;oV<[i1?ml`_d3og6ooPCoLkkm0on0`O`2ohc1n@;oQKgi1?n@_oH4
oiS0l`;oW/3`0_nL`?84oj70k`CoY<3]0_nV`>`3ojG1k@;oYl7/00?o0000ojK2kOnX`N`01OnX`N`2
ojS2k0goZL7[1_ooool00ol0003oooooooooo`0>ooooo`009oooool00ol0003oooooooooo`0^oooo
o`CoUK_a0_nB_O@3oiO3mPCoU<_j0_nAe?h2ojKGn@;o//k^0ongdNd2okBohPCo];[N0_nb/mT00onU
XM7oWYO=oijGc@02oijGc@?oUXk90on>Q/H4ohAoaP;oO7g90om`PM<3ogU/^0?oLV^l0om`MLL01?md
T^7o^kSFok^he_nk^=H3ojBGa`?oSG^j0_mgI[83ofUL/0;oEURh00?oJE^_ofAG[OmTEjd00omVG[D4
ogb6dP?o/:oG0_mhLl42oe]D/@03ogmnb?m?C[3oCdj`00?oFE6^0_mNBJ44oe9:ZP03o`1Je?nnb>;o
DUJh00;oDUJh0_mbQML00olIBLCo9h;YoeIjfP02ofIK/@;oN5fW0_nCLZT3oiM_X`04oi]aXon/OZ?o
[7jSojanX`Co/8>T00?og[F^omZ_[?oJ[j`01?oeeJd2onci]@04omJj__o<_/goc;k=olbnc@Co_Yni
1?n^TkX3oj2@``03okBL_on_YLko[jG>00?o[jG>1Onj_=/4ok[=j@;oa<gR0_n[dO@3okC=k@;oV<[i
0_nPaO84ohJnn@CoN;[k0omc^?/4og^kn`?oQKgi1?n@_oH2oiS0l`03oiFom?nL`?;oW<3b00?oW<3b
0_nQ`>l2oio1l0CoXl7_0_nU`Nd2ojC1kP?oY/;]00Go0000ojK2kOnX`NcoZ<7/ojO2k@05ojS2k0;o
ZL7[0_nX`N`6ojW1j`;oZ<7[1_ooool00ol0003oooooooooo`0>ooooo`00:?ooool00ol0003ooooo
ooooo`0^ooooo`;oUK_a0onI_?04oiO3mP;oU<_j0onTc_H00onVeoWo//k^ok;>kP02ok;>kP03okOA
kOnd_n;o];oR00;o];oR0_nd^]h00onYZMKoYJ7AojFQd@02ojFQd@CoWYO=0onFS/T3ohj6aP?oQ7o6
0omlOLT3og21d`CoH9K/00?o6J?IolgIh_o=fN800_o=fN82ok^heP04oiFAcOmnNlGoOW_5ogika@?o
SG^j0omgI[83ofUL/0;oEURh0_mTEjd4ofIN]@;oO8KB0_oMkMd2ok2_e`?oN7?10_mKE;43odm>/0;o
FE6^0_maJk`00omNBJ7oDTZZoe9:ZP02okk8hP;of?NU0_oVjM82oiRcj`;o6DW400?o001nofIK/OmV
Fk401?mhGJL2oiM_X`03oiQaYOn/OZ?o[7jS00;o[7jS0on`Pj@2omje[P;ofZn/0ooeeJd2onci]@03
o`000?o<_/goc;k=00;oc;k=0onnWkT2ok^O_0Co[Y>j00CoX933okBL_ondW;oo]9bo0on_YLh2ol6`
b@?o^[cK0_o8`M@01?njcNWoa<gRolC=h_o4cN82olW=g@?o]<g]0_nibNL4oj35lP;oQ[ki0_n?^O<3
oh2fm`CoN;Ch0omk]oT4oh:jn0CoS;gg0onE_o@2oic0lP;oV[ob1OnO`O02oj?1k`;oX/7_1?nT`Nh2
ojK2k@03o`000?nV`^goYl;]00?oYl;]0_nX`^`7ojS1k0;oZL7[1_nX`N/5ooooo`03o`000?oooooo
oooo00kooooo000Yooooo`03o`000?oooooooooo02oooooo1?nI_?02oiO3mP?oXlKa0_nTc_H3ojo:
k@;o//k^0_nc`^D3okBohP03ojf`f_nYZMKoZJWF00;oZJWF0onUXM44oijGc@?oUXk90on>Q/H3ohAo
aP?oO7g91?m`PM<2of2Fk0?ocNoZ0_o=fN800onYZMOoUI7=oiFAc@02oiFAc@;oOW_50om`K/03ogMV
/P?oJEb`0_mFF;P2ocUjh`06ofAG[OmVG[GoIUjeofIN]OmlQ];ogNgM0_nT[]h3og=jc0;oN7?10_mK
E;400oll@ZkoCdj`odm>/003oeUA[P;oLF^l00GoDTZZokk8h_nnb>;o0000omSgY@02onKYdP07oknf
dOmaNlkoLG_>og5kc_lIBLCo001noeIjfP02ofIK/@?oN5fW0onHLJD4ojanX`?o/8>T0ooN]Jh01?oJ
[jcomMF]ooGE[Oo/nKD2oci<^003o`00Pol0003oc;k=00?oc;k=00Co_Yniok^O_?nkWkco^inl1?n^
TkX5okBL_`03ojnUc_o1/<Wo`K3900;o`K3900Co^[cKolS1e?o8`MCob<7D0_oAb=000oo4cN;obLgM
olW=g@02olW=g@03okC=kOnibNOo^LWW00;o^LWW0_nPaO82ojG0k0CoSkWc0on0]_L4ogRdn0?oNkOi
1?n2^_P2ohbmm`03oh^km_nB_OCoT[gd00;oT[gd1?nJ_o82oio1l0;oWL3a1OnR`Nl3ojC1kP?oY/;]
00?o0000ojK2kOnW`^d00onW`^d8ojS1k0WoZ<7[1?ooool00ol0003oooooooooo`0>ooooo`00:_oo
ool2o`00037ooooo1?nS_nd2oj?6l@;o[LG/0on_b^d2ok;3iPCo/l;U00Co];oRojf`f_n]/=[o[K3J
0onYZMH4ojFQd@?oWYO=0onFS/T3ohj6aPCoQ7o60omlOLT2og21d`03og[Fo_nYnMOocNoZ00;ocNoZ
00?o^<3PojVYeonYZML00_nYZML3oiFAc@?oOW_50_m`K/02of9Ya004ogMV/_mYG;3oJEb`ofUL/0?o
EURh0_liN^<2ofIN]@;oc]cS0onT[]h3og=jc003od9A_?mhLl7oFeBa00;oFeBa00?o?4:^odm>/?mI
DJh00_mIDJh4og5[_003okk8h_oHmjGoi^WB00?o_kKA0omaNlh00oloF<Co6DW4o`00OP02ofIK/@?o
N5fW0onHLJD4ojanX`;o/8>T1?oN]Jh2omCVN`03ooGE[OnPRK_oX8Vk00;o?Tbh00?o0023olbncOo<
_/d00_nTZm/4ok^O_0?o[Y>j0_ngV[/4okBL_`Co`K3900Coc[[7olS1e?o8`MCob<7D0ooAb=001?oG
c<oobLgMolW=gOo9cMd2olc=f`;o^LWW0onja^<2ojG0k0;oZ;_W0onF]^d5ohRbl@?oOk7d0omo/oH4
oh>gmP?oRk_f1?nB_O@2oiZolP;oV;kb1?nM`?42oj;1k`;oXL3_1?nT`Nh2ojK2k@03ojG1kOl0003o
Yl;]00CoYl;]0_nX`N`2ojO1k0CoZ<7/1onX`N/2ojS0j`?ooooo00?o0000ooooooooool03_ooool0
02cooooo00?o0000ooooooooool0;oooool2oj>ok@;oZl7Y1?n]aN`00on_b^go//?Vok;3iP02ok;3
iP;o/l;U0_n_]]h4ojf`fP?oZJWF0_nUXM401?nJX=WoU9_HoiBKf?nDVmP3ohbGf@CoQYOM1OmoW^H2
ogndmP05od_7]?o4mngoa?O]olCgkOo=knX00onh`>03ojVYe`?oUI7=0omnNlD3og1^`0;oHVW41?mY
G;03oeIH^003ocUjhonKe?coc]cS00?oc]cS0onT[]h2og=jc0;o@U6l00?oN7?1oe]D/OmKE;400_ll
@Zh3oeUA[PCoLF^l00?ojoVhooCa^_no]]401?no]]43og5kcP04ocmHa?l006WoIU^aofIK/@?oN5fW
1?nHLJD4ojanX`03ok23Y?oN]Jkog[F^00;og[F^00Woe>IkolbT/?nPRK_oX8Vkoj28^_mEF[_o?Tbh
o`0HXol007H00onTZm/5ok^O_004ojjC^_ngV[_o]iZkokNJ^`?o]9bo0_o4ZKl2ol6`b@?oc[[700?o
b<7Dom78d?oAb=000_oAb=02omO<c`05olW=gOo<cM_oc<gKolc=foo<c=X00onja^<2ok[3h0CoZ;_W
0onF]^d2ohRbl@;oSZo]0on6[_04ohBalP?oQ[Cc1?n<^?@4oi:ll`CoV;kb0_nM`?42oifol0CoXL3_
0_nT`Nh2oj?1kP?oYL7]00?o0000ojO2kOnW`^d00_nV`Nd5ojO1k0?oZ<7/1OnX`N/5ojS0j`?ooooo
00?o0000ooooooooool03Oooool002gooooo00?o0000ooooooooool0;oooool4oj_1j@;o[LG/0ona
`^L2ok;3iP;o/;_R1?n_]]h2ojf`fP04ojF]gOnPYm_oX:OKoj2Wf`CoVZ3I0onDVmP3ohbGf@CoQYOM
0_moW^H3ofgIm@04oj?fj_o4mngoa?O]olCgk@?o`M;W0onh`>03ojVYe`?oUI7=0_mnNlD3og1^`0;o
HVW40om^QMT00omYG;3oEURhoeIH^002oi_Do0;og_CL0_o>g><01?nVZMWoNX7>ogZ1c_mjPLh3og=j
c0;o@U6l0_mKE;42oca2[P;oEgGE0_mIDJh2og5[_004ojcie_o[nKSom?6jonOJb0Co_kKA0omaNlh2
ocmHa003o`00O_mVFk7oN5fW00;oN5fW1?nHLJD4ojanX`05ok23Y?oN]Jkog[F^omje[_oDiW/00_o<
Y;03oj28^P;oEEZk0_l06:<01?l007KoY:_KojB[fonTZm/3ok^O_003okJP`_ngV[_o]iZk00?o]iZk
00Go]9boolBY_oo4ZKooa:Vool6`b@04oljja`04omO4aooAb=3odLS@om78d0?oelc?0oo<cM/3olc<
fP03ok[6honj`n3o^/?P00;o^/?P0_nX^nL00onY^>CoV[;XoiZbj002oiZbj0CoSZo]0on6[_04ohBa
lP?oQ[Cc1?n<^?@2oi:ll`;oTk[b1?nH_O44oifol0;oXL3_00?oXKo_oj?1k_nS`Nh00onS`Nh2ojG1
k@03o`000?nU`NgoY/7]00?oY/7]1?nW`N`4ojS1k0GoZ<7[1?nX`>/3ooooo`03o`000?oooooooooo
00gooooo000^ooooo`03o`000?oooooooooo02oooooo0_n[`NT2ok32i`?o/L;W0_na_n@4ok2khP;o
[kKN00?oZ;?PojF]gOnU[Md00_nU[Md3oj2Wf`CoVZ3I0onDVmP3ohbGf@;oQYOM1?mobOl00om]fOGo
]?CbokCdlP02ol3Lk@?o`M;W00Co[JkIoj2MdOnPWM7oX9gA0on?S<`3oh5ob0?oKgO;0_m`K/03of9Y
a0GoKXGI00CoVmClomkdg?oNm=coam3Q1?nVZMT2ogZ1cP;oFFK500?oLg[<od9A_?m2DK`00_m8FL40
0omKE;7o?4:^oca2[P03oeMee@04og5[_?n/nMKojoVhooCa^P?oim[80_no]]401OnQU<OoL6o2og1_
`_m`Kl;oLG_>00;o?eS400Co002<ogQMYomhGJOoN5fW1?nHLJD4ojanX`Cog[F^0oo<Y;04oj28^P;o
EEZk0_l06:<3og:<g@04ok^O_?nfX<;o]Z32okJP`PCo]iZk00?o_jK0olBY_oo4ZKl00_o4ZKl5oljj
a`;oelC700CodLS@omO<cooGc<ooelc?0_oJd=001Oo<cM_oc<cJolc<f_o<c=[ob/[J00Co^/?P00?o
^KoNojVhi?nY^>@00_nY^>@4oiZbj0;oSZo]0_nC[NP3ohb]j`?oRZo^1?n:/_04ohjfl@CoTk[b0_nH
_O400onI^o3oWKk_oifnk`03oifnk`?oXKo_0_nS`Nh2oj>ok@?oYL7]00Co0000ojG1kOnV`NgoY/7]
0_nV`N`4ojO1k0;oZ<7/0onW`N`2ojS1j`KoZ<3[0_ooool00ol0003oooooooooo`0=ooooo`00;ooo
ool00ol0003oooooooooo`0_ooooo`Co/<;W00?o/L;Wok6oi?na_n@00_na_n@2ok2khP03oj^hhonX
/n3oZ;?P00;oZ;?P1?nU[Md3oj2Wf`;oVZ3I0_nC[>L3ohj_k0CoQkOe0_mobOl01?nKjoWo]?CbokCd
l_ndm?84ol3Lk@04ol7Bion][]Wo[JkIojf^f@?oX9gA0on?S<`3oh5ob0;oKgO;0omYP]T3of9Ya0;o
KXGI00Co^OcTolWm`OoNm=cog_CL0oo7d>43ojJYf@?oNX7>0_mII/D3od9A_0;oB5W10_ll@Zh3oeMe
e@03ojcie_o[nKSom?6j00Coim[81?nQU<L3og1_`P?oN7W700CoIU^aogQMYomhGJOoN5fW0onHLJD4
ojanX`03omk2_OoN]Jkog[F^00?oc:B`0_o7X[83oj28^P;oEEZk00?o336ao`0HXol008P00_mbS=d5
okJP`P;o]iZk0_noY/04olBY_`04om2f`Oo>^/Ooc[[7oljja`?oelC70ooGc<l3om[@d0;ofM;B00Go
c<cJol[:f_o:b][ob/[Jok[3h004okVogP;oZKST0_nZ]>43oif`i0GoTjgX0on<[N/3ohZ_kPCoR[;`
0_n>]_42oi6dk`?oUKS_1?nI^o02oifnk`;oW[c^1OnQ_^h3oj>ok@;oYL7]00?oYL3]o`000?nU`>d0
0_nV`N`2ojK0k0CoYl3/0_nW`N`2ojO0j`KoZ<3[0_nW`>/2ooooo`03o`000?oooooooooo00gooooo
000`ooooo`;o0000<?ooool4ok32i`?o/KoT00?o[;gVoj^hhon[^><00_n[^><4ojRch0;oYJgM00?o
W[3ToiZ]iOnJ[ND00_nJ[ND4oi>/i`?oSZo/0_n7]oD2oiOKoP?oZ^gi0onlgo42ol3Lk@;o];cP0on]
[]T3oj2Md@?oShc<0on1OlP3ofmgb`?oJH;I0omW[oT01Onio>Co[O[Lom?khOoCnn7odnSU00Coam3Q
0onVZMT2ogZ1cP;oFFK50_lbELH00om2DKcoB5W1odQI`@03ofJ:h@03oeMeeOmVR^7ojoVh00;om?6j
0ooWf/P2ol^oc`?oXIC70om`Kl83ogQia`04o`00S?mhGJOoN5fWogQMY`?oV76U0on/OZ<2omk2_@;o
g[F^0_o<Y;03olNR/P?oX8Rj0omEF[/00ol<<K7o01RSo`00R002og:<g@Co]Z3200?o]iZkoknV`?no
Y/000_noY/02olBY_`?od;K100?oc[[7omO4aooGa<L00_oGa<L00ooMcLWoelc?om[@d002om[@d0?o
fM;B0oo:b]X2olO7fP?o^KoN00?o]kcMojZdhOnZ]>400onZ]>43oif`i0;oTjgX0_nHZn@3oi:[i`Co
SjgZ0on?/>d5oi6dk`?oUKS_0_nI^o02oi^jkPCoW[c^0_nQ_^h2oj6mk@GoXko]00?oYL3]o`000?nU
_n`01OnV`>`3ojO0k0GoYl3[0_nX`>/6ojO0j`03ooooool0003ooooo00kooooo000booooo`03o`00
0?oooooooooo02kooooo1?n``^L01?na_nCo[;gVojbmi_n/_NH4oj^hh`;oZ;?P0_nR]>D3oij`i0Co
VZgU0_nC[>L2oiK2m@?oU/cj0onRh_`00onZkOWo_=oaokcOl@02okcOl@03okS7i_nd_>3o];cP00?o
];cP0on][]T3oj2Md@?oShc<0on1OlP3ofmgb`?oJH;I00?oIjoioiWCo?n]n]`00_oCnn43om?Xi@;o
am3Q00CoY;3QohJBf?n6T]SoQY;H0omRMm82oeUVa@?o<UG60_m8FL43ofJ:h@03ok[mf_oMoMCogOgD
00;oiO3E00Coim[8ol^ocoo;_loobko?0onQU<L4og1_`P?oN7W70omhGJL4oiQaY@;o[7jS0ooN`[d0
0ooN]Jkoc:B`olNR/P03olNR/P;oX8Rj00CoXH^mofEW`?mUIl3oEEZk0_l<<K400ol02Y_oC7;Godab
e`03okJP`P03ok2SbonoY/3o_jK000?o_jK000?oa:Voom2f`Oo@]/400_o@]/401?oJa<CoelC7omO4
aooGa<L2omg=b@;ohMG<00Cof]3@omWBd_oId];ofM;B0_oGdm@00oo:b][oalOJolO7fP02olO7fP04
okVog_ng_=go]kcMokNlg@?oZ[CQ00?oZ[;Noj2^hOnP[^400_nP[^44oiR[i0?oTZ_W1?n?[NX3ohn`
k@;oTKC_0_nE/^`3oiNfk@GoVk[^0_nN_>h2oinkk0CoXKg]0_nS_nd2ojBnk0;oYKo/00Co0000ojFo
k?nV`>coY/3/0_nV_n/4ojO0k0coYl3[00?oooooo`000?ooool03_ooool003?ooooo00?o0000oooo
ooooool0;_ooool2ok32i`;o[L7Y1?n/_NH2oj^hh`;oYKSV1?nR]>D3oij`i0;oVZgU0onI_?43oiK2
m@04oiK<n_nRh_coX^;loj;Ro0?o]=ge00?o_=oaokS7i_nhanH00_nhanH2okBlh0;oYJcL0onKX=P3
oi2FeP?oPHgF0omlT=`4ogjRjP?oVM?l00?o[O[Lom?khOoCnn400ooCj>D2okk:i0?oY;3Q0on6T]P2
of9gdP;oF7OG0olbELH3of:Kk`04ofJ:hOo1l?7o`O3aomgme0?oiO3E00?of=oLol^ocoo;_ll00_o;
_ll3oj6Da`?oL6o20omhNLL00onE[>KoN5fWogQMY`04oiQaY@03ojanXooN`[gog/:m00;og/:m00?o
fJn]olNR/_o7X[800oo7X[84oj6;_@?oIFO00_l<<K401?l008SoC7;GodabeonfX<83ok2Sb`Co_jK0
1Oo@]/42om[4a004omO4aooMcLWogLg9omg=b@;ohMG<0ooId]83omOCe005om?Aeoo7am[oalOJolO7
f_o3a=/01Ong_=d01?nZ]>7oZ[;NojZbg_nZ/]h4oj2^h@?oV:_T0_nBZnL2oiJZi0?oU:cW1?nC[nT4
oiFbk0?oUkK]0_nK^^h2oifhk0GoWk_/0_nQ_Nd00onR_>_oY;k/ojBnk003ojBnk0;oYKo/00?o0000
ojJnjonV_n/00onV_n/2ojO0k0koYl3[00?o0000ooooooooool03Oooool003Cooooo00?o0000oooo
ooooool0;_ooool4ojg1j@;o[;gV0_nW_>T4ojFhiP;oX[CU0_nN^^`4oi^jkP;oVKca0onLc_T2oigG
o0?o[]Sf0_ndgOD3okO=j`;o^<OV00?o[;KPojF/g?nU[=`00onU[=`3oi^Pf0?oT9KF0on1SMH3ogb@
g0CoOZ;Z00?oVM?lolKekOo6mNd00_oBlNL00oo;fnGo_/[Tokk:i003okk:i0?oY;3Q0_n6T]P3of9g
dP;oF7OG0olbELH01OmRVnoo`O3aol7`lOo1l?7ogOgD00?oiO3E0ooHgm`2ol^oc`04ojRWeOn>Q/Ko
SXK6ohj6aP?oOGO20_mhNLL2ojBCa003o`0k__mhGJOoV76U00?oV76U00?o[7jSomk2_OoN`[d00_oN
`[d00ooI[jgoejn`olNR/P03olNR/P04olBS]onQRkgoXH^moj6;_@?oIFO00_l<<K400ol02Y_oC7;G
odabe`04ok2Sb`?o_jK00_o7/lH3om2f`@?of/C40ooMcLT3on7Ec003on7JcooId];oem?D00;oem?D
0ooCdML01?o7am[o`lCKol?4foo3a=/2okNlg@;o];SL1?nZ/]h2oj2^h@;oXZcN0onKZ^45oiJZi0?o
U:cW1?nC[nT2oiFbk003oiVajOnJ]N_oV[G[00?oV[G[0onM^>`2oinkk0;oXK[[1?nR_>/2ojBnk0;o
YKg[0onV_^/01Ol0003oY[k[ojJojonV_n_oYko[00ooYl3[00?oooooo`000?ooool03_ooool003Go
oooo0_l0000_ooooo`;o[L7Y0onX`>/3ojNlj@;oYKSV0_nQ^n`4oijjk0;oVk[^0_nLaoH3oic>n@;o
Z=;f0on^f?H2okC?kP?o]lg[00?o[kgTojbfh?n/]^000_n/]^04ojF/g0?oVj3H0on@U]H4oh6=eP?o
O93L0_mnX^X00onMiOcoa_G]olKek@02om;ai`?obm_U0_nnb^@2ojVbg`?oRi_M0omfRm/2of9gdP?o
F7OG1?mPU^d01Oo1l?7oX^3lol_ak?o;lNcoiO3E00?of=oL00?o_L[UojRWeOnXYmD00_nXYmD3ohj6
aP;oOGO21OnTTl@00ol0>kkoV76UoiQaY@03ojNgi0?og/:m00?ofJn]omN_/?oG[k000oo7X[82olBS
]`?oXH^m0omUIl000olYBKko336ao`0OZ`02oceZeP03odabeon`Xl_o/:?;00;o/:?;00?o_jK0olNc
a_o7/lH00_o7/lH01?o@]/7of/C4om[4a?oJa<@2on7Ab004omg=bOoQeLcohMG<on7Ec0;ohM[?0_oN
g=@01OoGdmCodm7Gom?AeooCdMOocLkJ00?o`lCK0_nn`=/4okBhg0;oZ[;N0_nY[m`4oj:/gP?oVj[Q
0_nFZ^@2oiZYh@CoV:_T0onH[^H4oiVaj@;oV[G[0_nM]>P4oingjPCoXK[[0_nR_>/2ojBljPCoYKg[
0_nV_^/00ol0003oY[k[ojNoj`03ojNoj`;oYl3[0_nW_n/6ojO0j`Kooooo00?o0000ooooooooool0
3?ooool003Oooooo00?o0000ooooooooool0;_ooool2ojS0j`;oXko]0onR_N`4oj6kk0;oW[[/0onN
`o83oic7mP03oic>nOnXd_KoZ=;f00;oZ=;f00?o[]SfokC?k_ndcnh00_ndcnh01?ngcN_o[kgTojnm
i?n__N@4ojbfh0;oYJcL00CoVjCKoi6Mg?nAWMcoTIgL1?n;WMl3ohBSj0CoRkgg0_n`hoP2ol?_l004
om;aioo;fnGobm_Uol_Ki@;o_<KR1?nY/]l3oh^Kg@?oMX_K0_mQQMl3oeQge`;oH9K]0_nRh?`2ol_a
k0;odO7W00?oaNK^okg:iOnmb^D00_nmb^D3ojRWe@?oSXK60ommMl84ojBCa0;ofkNd1OnW]n@00ooN
`[gofJn]omV_[@03omN_/004olNR/_o4XkOoa:>golBS]`CoXH^m0omUIl000olYBKko336ao`0OZ`03
oceZeP;o/:?;00?o[:_FolNca_o7/lH00oo7/lH3om[4a0?ohM780_oTg<d00ooQeLcohM[?on7Jc`03
omkLe0?odm7G0oo=c]X00oo3a=_o_/3Kokk0f`02okk0f`;o];SL00?o/[GKojV_g?nY[m`00onY[m`2
oj:/gP03oj>[g?nNZMkoWZWN00;oWZWN1?nJZN44oiR[i0?oV:kV0_nI/NT2oibaiPCoWKCX1?nO]nX2
oj6jj`03oj:ijOnT_>[oY;cZ00?oY;cZ0_nU_N/01_nU_N[oY[k[ojJnjonV_^_o0000ojJnj`SoYko[
0_nW`>/9ooooo`03o`000?oooooooooo00cooooo000hooooo`03o`000?oooooooooo02kooooo1?nS
_nd3oj:mk0;oXK_/0onO`O02oik3lP;oXlOb1?nUc?@2ojSBmP?o[lk`0_ndcnh2ok72i`Co[kgT0_n/
]^000onRZmgoVjCKoi^Tf`02oi^Tf`?oTIgL1?n;WMl3ohBSj003oh^mmon`hoSo/>?h00?o`no`0oo8
h^/00oo;fnGo_<KRokc6hP02okc6hP?oZK;O0on;Vmd4ogJ;f`;oHHGO1?m`Y?401?nRh?cobo7/ol_a
k?oAlNL4olGVkP?o_L[U1?nXYmD2ohj6aP?oOGO20onTTl@2ok^R_`;ofkNd0_nW]n@01?oM]JoogKJ_
omff[ooI[jd4omN_/0Goa:>g0_nQRkd01?nSU<KoKWO;ofigbom^Ml/2obU9_P;o01n[0_lmJ]H4ojb[
eP?oak?60_o?a<l00ooJa<CohM78on7Ab002on7Ab0;oi=c=00?oi>CBon7JcooNg=@00_oNg=@2om[L
f@04om?Aeoo=c][ocLkJolg>fP;oalWK0onn`=/00onj_=_o/[GKok:ef`02ok:ef`;oZJoL0_nY[]/4
oj>[g0CoWZWN0onJZN42oiR[i0;oW:_Q0onK[^@5oibaiP;oWKCX0_nP]>H3oj6gj0CoX[WY0_nT_>X2
ojFkj@CoYKgZ0_nV_^/00onW_^[o0000ojNoj`06ojNoj`cooooo00?o0000ooooooooool03?ooool0
03Wooooo00?o0000ooooooooool0;_ooool2oj>ok@;oX[k]1?nP_nl2oio1l0;oX/Ca1?nSao82ojG<
m0?oZlca0_n_c_02ojo5j@Co/L;W0_n__N@2ojNag`?oXZ_M1?nKY=/3oi6Mg0;oRigO0_nE]^h3oig8
mP?o/n;g00Co`no`olSRjoo8h^_ob>;[0oo1d^L2okc6hP03ojbihonJZn;oVZ_R00;oVZ_R0omnVn@3
ogFKj@?oN:cc0_m`Y?42oigEn`04ok7/monfk_Ko]^kfokK^mP;oaNK^0_nZeoL2oiNbjPCoPXoH0omo
OlT3ogeg`P03ojBCa?nkX[oo^j:o00;o^j:o00CofkNdomfe[ooM]JoogKF_0_oM]Zl00ooI[jgoejn`
omN_/002omN_/003omFb]_o4XkOoa:>g00;oa:>g1?nSU<H2ofigb`;o>V3>0_l0>[h2ocYag003oceZ
e_n/ZmKo[:_F00;o[:_F00Goak?6olo4coo?a<ooclC?omKDe`03on7Ab0?oi=c=00Coi>CBon7WeooQ
imOog]cD0_oJg=T3om?Hg003olg>f_o7bM_oalWK00;oalWK00Co_/3KokZlfonj_=_o^[cK0_nb]M/0
0on`/][oZJkKojV^f`03ojV^f`CoXj_L0_nNZMh00onPZMgoWJWOoifYg`02oifYg`CoW:_Q0onK[^@2
oibaiP;oWk7T1OnP]>H3oj6gj0;oX[WY0_nT^NP4ojFkj@;oYKgZ0_nV_NT3ojNnjP03o`000?nW_n_o
Yko[013ooooo00?o0000ooooooooool03?ooool003[ooooo0_l0000_ooooo`CoX[k]0_nP_nl2oj;1
k`CoX/Ca0_nSao83ojS8l0;oZlca0_n^aN/4ojo5j@;o/L;W0_n[]n84ojNag`?oXZ_M0_nKY=/2oiNZ
i0?oTZcX1?nE]^h01?nMb?Ko/n;gok?Rmonch_L3ol7Qk`05olSRjoo1d^Oo`M;Wol7Bionfa>D01?n/
^N<4oiZ[hP?oOY_T0omeVnT3ogR/l`03oigEnonak?Oo/Ncg00?o]^kf0on/jOT3oj[Gm`;oUk;Z0on2
SmP3ogmob@?oRX?51OnkX[l3omfe[`?ogKJ_1?oG[k02omFb]P?oa:>g0_o4Z/03oj>DaP?oKWO;0_lj
H<h2o`0j_P;o>W7L0_n/ZmH2ojbih`?oclC?0ooFe=L01OoQdLSoi=c=onCLcOoTg<goi>CB00?ohNOG
00?ofnSMom[LfOoCf=`00ooCf=`4olO9f`03ol74g?nj_=_o^[cK00;o^[cK00Co/[GKok2bf_n`/][o
/;;J1?nY[]/2oj>[g0;oY:[K1?nPZMd4oifYg`;oW:_Q00?oWj_Ooin^h_nO[^800_nO[^84oinai0;o
X;CV0_nS]>D3oj>giPGoY;WX0_nU^nT00onV^nSoY[gYojJmj@03ojJmj@;oYkkZ00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0<ooooo`00??ooool00ol0003oooooooooo`0]ooooo`;oX[k]
0_nS_nd4oj;1k`;oX/Ca0onVaNl2ojS8l0;o[<C/1?n^aN/2ojo5j@;o[;_U1?n[]n82ojNag`03oj6`
h_nK[>;oVjcR00;oVjcR1?nGZ^@3oi:/j0;oUKK^0onTd?L01?nch_Oo`N7_ol7Qkoo1hNl3ol;Ij`04
ol7Bionfa>Go]/CUokK4i@Co[;WS0_nJZn82oiF/iP?oPJS]1?n0]oL2oi;BoP?oYNGk00Co]^kfojcY
nOn/jOWo[>Wi0_nGfoh3ogfno0;oHIO]0on2SmP2ogmob@CoRX?51?nkX[l00oo8[KkogKF_omfe[`03
omff[`03omjj/ooG[k3oejn`00CoeK:f00Coa:>golBZ`?o4Z/3oa:[01?nSU<H2ofigb`?o>V3>0_l0
>[h2ocYag0Co[;WS00?oclC?omKDeooFe=L00_oFe=L2omWSg@03onCLcOoTi=;ohNOG00;ohNOG0_oK
j=d01?oDhn;odmSLom?Hg?oCf=`2olcCg`03olO9foo1a=co`LCL00;o`LCL0_nj_=/2okJhf`Co/;;J
0_nY[]/2ojR/fPCoY:[K0onPZMd2oifYg`;oX:WM1?nOZml4oin^hP;oWk7T0_nR/N84oj>di@?oXkOV
0_nT^NP2ojJii`CoY[_X0_nV_NT5ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
3?ooool003gooooo00?o0000ooooooooool0;Oooool4oj>ok@;oX/7_0onV`^h2ojK5k`;oZ/?/1?n/
a>`2ojk5j`;o[KkW1?n/^nD2oj^ghP;oYKCS0onQ/>84oi^/hP;oUj[T0_nJ^>d4oi_0lP;oY=3g0_nc
f_@3ok[Jl0;o`]W[0_nkc>L4okK4i@;o[;WS0_nS/n@4oiF/iP?oPJS]0_n0]oL3oiCBo@;oYNGk0_n[
joT2ojWXnPCoUm_n0omm__`01?mQUngoDg[Koe=jfomCN]/3ogmob@?oRX?50onkX[l3olR]_P03omfe
[ooM]ZoogKJ_00?og[Zc00?oejn`omFb]_oE/[H00_oE/[H5olBZ`0;oXiC600CoYJ3@ogR9f?mhRMSo
N8WH0_ljH<h2oa1IdP?o@hCW0_n/^N<2ojk:kP?oe]CG0_oIhmd2omS]h@;oe?7U00?ohNOGom_XgOoK
j=d00ooDhn800ooCf=coc=?OolcCg`02olG<h0?o`LCL0_nk_m`4okJhf`;o/;;J00?o[K3IojR/f_nX
[=X00onX[=X2ojBZf`03ojFYf_nRZM_oXZWK00;oXZWK1?nPZMd3oin[g`;oWjkR0_nR[^05oj:ahP;o
XkCU00?oYKCSojJgiOnV]nD00onV]nD3ojJii`;oY[_X2Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00cooooo000nooooo`03o`000?oooooooooo02gooooo0_nS_nd3ojFok0;oY/;^
0_nY`^/4oj[3k0;o[<C/0_n/`>P4ojfni`;o[;_U0_nX^>@4ojFdh`?oXK3R0_nK[>82oi^cj@CoV[S]
0_nK`?83ojW?m004ok?Jm?njf_3o^][`ok[Jl0;o^M3[1?nkc>L2okK4i@;o[K[T1?nS/n@2oiF/iP;o
VKW^1?n?_oL2oiCBo@;oX^;l0_n]i_T2ojWXnP?oX^3l0ommbOl2odZOm@;o9gOS0_mCN]/3og60d`Co
RX?500?o^j:oolR]__o8[Kh00_o8[Kh3omff[`?og[Zc1OoE/[H4olBZ`003olBdbonUX=3oYJ3@00;o
YJ3@0omhRMP2odakgP;o45WB0om3Q>L4ojk:kP03omKDeooIhmgof>gQ00;of>gQ0_oDlND2om3aj@04
om_XgOoDhn;oe>?RomCShP;ocMgU00?oc=?OolG<h?o5c>000_o5c>000oo1a=co^koLok^og002ok^o
g0;o][SK00?o/[CJojf`fOn]/=T00_n]/=T2ojR/fP;oZ:_I1?nUZMX4oj:Yf`;oX:WM00?oXj[Loj:/
g_nR[=h00_nR[=h4oj:^h0;oX[7R0_nU/^44ojFdh`;oY[OU4?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00cooooo000oooooo`;o0000;oooool2ojFok0;oZ<3[1?nY`^/2oj[3k0;o
Zl7Y1?n/`>P2ojfni`;oZK_V1?nX^>@2ojFdh`;oXKCV0onN/nH4oi^cj@;oV[S]0onSaO42ojW?m0?o
/]Gb00?o^][`okW@jonid>/00_nid>/2ok_<i`;o/l;U1?n]^^@2oj>ci0;oX;OX1?nI^Nh2ohnom`?o
X=?j00?oX^;lojgVnOn]i_T00onaiOP2oj;Po0?oVMCl0_mU]_`2oa^0i`;o9gOS0_mCN]/2og60d`Co
Ui?=1?o8[Kh2om2f`@03omff[ooN^[?og[Zc00;og[Zc00Cog/6komFb]_oE/[KoeK:f0_oE^l02olBZ
`0?oa;C;0onUX=04ogR9f0;oC7_N00Go:W_Voa1Id_m@W_CoD9kdod>4i`02ojk:kP05ok3Lm_n`j?So
/>Shok3Xn?oHkN400_oDlND2om3aj@?obn_/00?oe>?RolgMiOo=gND00_o5e>D3olG<h003okk6h?nk
_mco^koL00;o^koL00?o][[Lok:df_nb]=X00_nb]=X2ojf`f@03ojb^fOnXZmWoZ:_I00?oZ:_I1?nU
ZMX2oj:Yf`03ojBYf_nSZ]coXj[L00;oXj[L1?nR[=h2oj:^h0;oYJoO1?nU/^42ojFdhaCooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`00@Oooool00ol0003oooooooooo`0]
ooooo`CoZ<3[0_nY`^/2oj_1jPCoZl7Y0_n/`>P2ojZmi`CoZK_V0_nX^>@2ojBgiPCoXKCV0onN/nH2
oi^cj@?oWkk_0_nSaO43oj_?l`;o/]Gb0onfdNd2okW@j`;o]LOW1?nc`^D2ojfji003ojNii_nP]nSo
X;OX00?oX;OX0_nI^Nh2oj?7lP;oX=?j0_n`g_L3okWRl`;o/NGh0onbg_H2oiWDo0;oTLWj0_mGZ?P2
oa^0i`03o`1Gd?lWMn?o7F?G00?oLH3C1?nGTld2olR]_P?od;K100CogKJ_omjj/ooN^[?og[Zc0_oN
`K/2omFb]P?oeK_000?oa:[0olBdboo4]</00_o4]</2ojFPd003ojN`g_n0W^KoP9kV00;oP9kV0omL
Unh2obYkiP?oD9kd00Co/=cfok3Xn?n`j?So/>Sh0_n`kOP00ooDlNGod?7Yom3aj@03ol_[k0;oaNC^
00?ocMgUolGDiOo5e>D00_o5e>D01Oo5c>3o_/KPokk6h?nna^3o^koL00Co][[L0_nb]=X00on_/M[o
[:kIojb^f@02ojb^f@CoZ:_I0_nUZMX2ojJYf@CoY:WJ1?nSZ]`2oj:/gP03ojF]gOnU[mooYJoO00?o
YJoO0_nU/^4Hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool004;ooooo
00?o0000ooooooooool0;Oooool2ojS0j`;oZ/7Z1?n[`NX2oj_1j@;oZ[kX1?nZ_NL2ojVkiP;oY[WV
1?nT]nH2oj6diP;oX;[[1?nP^n`2oinnk`;oY/Sa0on[co<2ok7>k`?o]]7]00?o]L[ZokG7ioneanL0
0oneanL2ok?2i@03ojfmiOnW^NKoYkWV00;oYkWV0_nP]nP3ojFok0;oXlOb0on_do<01?n`g_Oo^N;c
okWRlonih_<3okkNl0;o/]kf0_n`e_<4oi79nP?oEjSh00Co0VkLo`1Gd?l0Em3o7F?G0_maP=<4oiNC
c@03olR]__o@]/7od;K100;od;K11?oN^[<3omk1^`05omFb]_oE^l3oeK_0omFk`?oCaL`00oo4]</2
ol?1f@?oYk3N1?n0W^H3oebGkP;oA9gd1?mP]o`00on`j?So/>ghok3]n002ok3^m`;o/^_h00Cobn_/
olGTk_o5i>koaNC^0_nof^d2olGDi@?o_/cU0_nna^02okRog`Co][[L00Co/[CJojnaf_n_/M[o[k7J
1?n/[]T2ojR[f@;oZ:[I1?nVZMT3ojBYfP;oXj[L0_nUZm/4ojF]g@;oYJoO7Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00_ooooo0013ooooo`03o`000?oooooooooo02gooooo1?nZ
`NX2oj_1jP;oZ/3Y1?nZ_^P2ojZmi`;oZ;_W1?nV^NH2ojBgiP;oX[[Y1?nP^^/2oj2kk0;oXl?`1?nV
b?400on[co?o/Lk_ok7>k`02ok7>k`04okKAkOneb^[o]L[ZokG:jP;o]LOW0_n``>H4ojfmi@;oYkWV
0onX_>P2ojFok0?o[LW^0_n_do<3okWJl@04okWRlonng_3o_]k`okkNl0;o_mW]0_n`e_<3ojg<l0?o
SKkg0_mBX?D2o`1YfP03o`14_ol0BLSo04W800;oGH?N0_nGTld00onOXmSod;K1om2f`@03om2f`@03
omC1b?oN^[?og[Zc00Cog/6k0ooE^l03om?5c003olBdboo3`MWo`l7I00;o`l7I0onW/=h2oh2NiP;o
Qk;b0_m][oP01?mLUnkoA9gdodBMm?m4WO@2og;;o`?oPMOo00?o/>kgok;[n?nbjoP00onciOL00oo5
i>ko_m[]okoJk@02ok[Aj`?o_/cU0_nhaN@4okRog`;o][[L00?o/[KLojnaf_n_/MX00on_/MX2ojb^
f@03ojZ/fOnXZ]WoZ:[I00?oZ:[I0_nVZMT00onVZMSoYZWIojJYf@02ojJYf@CoYJ_K0_nU[MdPoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool004Cooooo00?o0000oooooooo
ool0;Oooool4oj[1jPCoZ/3Y0_nZ_^P3ojRmj0?oZ;_W0_nV^NH2ojBkj@CoX[[Y0_nP^^/2oj:okPCo
Xl?`0_nVb?43ojc;l0;o/Lk_0_nbbn`2okG:jP;o//?W1?n``>H2ojfmi@?oZ[_V0_nX_>P2ojc2jP?o
[LW^0onfdNd2okWJl@?o_m[]00?o_]k`okoIkOnofNd00onmd^T2ojg<l0;oZ/C/0on<]o<2oeRNl`;o
06WJ00Co04Boo`19b?l0BLSoGH?N1?nOXmP3om2f`@?oe<7800?og[Zcomk1^ooN`K/00_oN`K/00ooN
c<KoeK_0om?5c003om?5c005om3Af_o3`MWo`l7Iol?1fOnncND01OnW_nX3ohNblP?oKJoh0omN]o`2
oh7Go`;oTMcn0onLg?d2ok?Um`;o/m_d00?o_m[]ok[AjonjdN/00_njdN/00onnc>Go^<GTokS5i002
okS5i0;o^;oO00?o/k_Ook:fg?nb]]`00_nb]]`2ojnafP;o[:oJ1?nZ[=T2ojRZf@;oYj[H1?nVZMP4
ojJYf@;oYJ_K9?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0015oooo
o`;o0000;oooool3oj[1jP;oZ/3Y0onY_nT2ojRmj0;oY[gZ1?nU_>T3ojBkj@;oX[[Y0_nS_^d4oj:o
kP;oXl?`0onXao02ojc;l0;o[l[^0_nbbn`2ok75j@Co//?W0_n``>H3ojfmi@;oZ[_V0_n/_^L4ojc2
jP04ojg9k_nfdNgo]]7]okKAk@?o_]C[0_nof^d2ol;HjP04okoIkOnmd^Wo_M;YokgBj@;o^/_V1?nZ
a>`3ohbgl`?oF9kc00?o273Oo`11^Ol0>;<00_lmQNT4oinSf003om2f`OoD`LSoe<7800;oe<7800Co
eLkBomk1^ooN`K_og/6k0_oNc<H01?oKf=CodlG<om?5c?oCaL`3om3AfP04ol?1fOnncNGo_/gUokk=
i@;oYkoZ0_nVb?44ohnom`CoOKol0_mgaol2ohW?oP;oW=cm0onTe_T2ok?Km0?o/M;a0_njdN/00one
b>So^<GTokS5i002okS5i003ok>ohonc^moo/k_O00;o/k_O0_nb]]`2ojjcg0Co[:oJ0_nZ[=T00onX
ZmWoYj[HojNZf003ojNZf0?oYZWH0_nVZMTYooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02oooool004Oooooo00?o0000ooooooooool0;Oooool4ojW0j`;oZKoY0_nW_n/4ojJmjP;o
YKcY0_nT_N/4oj>mk0?oXkk]0_nR_nh2ojG4k`;oZ<O`0_n[b>l3ojo:kP;o[lK[1?naaNT2ok;3i`;o
[koV0on]_ND2ojfmiPCo[;kW0_n/`^X3ok;9j`05okKAkOnne>_o_]C[okkDjoo2e>P00oo2f>X3ol?C
iP03okgBjOnjbnKo^/_V00;o^/_V0_nZa>`2ojRmj0?oSK;_0omSWo800olQOnOo04c0o`0h/`02ocf5
j@;oWj?H0_nR]nL3omC1b0?oeLkB00?og/6komk<a_oNc<H00ooKf=@01OoCaLcod=7Jom3Af_o@dM[o
b=_W00?o_/gU0_nhdnh4ojK8l@;oSkog0onEaoT3oh_8o0;oRLon0onHc_/2ojCFn@?oZ<oe0_nad_40
0on_bNgo]LSXokG8j002okG8j003okS5i?nc_n?o/koS00;o/koS0_nc^ml2ojngg`Co[[?L0_n/[mX0
0onY[]_oZ:_IojR[f@02ojR[f@CoYj[H0_nVZMP/ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02oooool004Sooooo00?o0000ooooooooool0;Oooool2ojW0j`;oYl3[1?nW_n/2ojJm
jP;oYKk[1?nT_N/2oj>mk003ojC0kOnT`^koY<;^00;oY<;^0_nUa>l2ojS6k`CoZlS_00?o[l[^ojo6
jon_a^/00_n_a^/2ok75j@;o[l7W1?n__nH00on]_NGo[KgVojfmiP02ojfmiP;o[;kW0_n``nP3ok;9
j`?o^LkY00Go_]C[ol;Dj?o2e>So`]CXol;HjP03ol?CiP?o`LgT0_njbnH00onga>CoZ;gXojRmj003
ojRmj0?oSK;_0omSWo801OlQOnOo04c0o`1<`?lFPNKo?HGY00CoX[OW00Coe<78omG>d_oEc];oeLkB
0_oBgN400ooNc<KofmSDom_He002om_He0;odn?S00God=7JolSKioo8fnOob=_Wokk=i@04okSCkP;o
Y/Sa0onUcO@2oiG7n@03oic7m_nGbOWoUlWi00?oUlWi0_nHc_/2oio;mP;oZ<oe0_nYanl4ojo9k@;o
]LSX0ona`^H2ok>oh`;o[k[R1?n_]ml2ojjcg003oj^agOnY[]_oZJkK00;oZJkK1?nXZmT2ojNZf33o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`00BOooool00ol0003ooooo
ooooo`0]ooooo`CoYl3[0_nW_n/2ojFok0CoYKk[0_nT_N/00onT_ngoY<3]ojC0k@02ojC0k@;oY<;^
0_nVa>h4ojS6k`;oZlS_0on/aN`2ojo6j`;o[/;X1?n_`NL2ojnoiPGo[KgV0_n^_nL4ok33j004ok;9
jonic^Wo^LkYokW>j@;o_]3X0_o2e>P3olCBi@05ol?Ci_o1cNCo`LgTol7=i?noan401?nga>@2ojRm
j0;oYkSU1?n@[n/2og2Rl0?o?Xk^00?o06?BoaJ1i_lFPNH00_nR]nL2oi_9m`04omG>d_oBgN7od]gQ
om;Mh@;oa^W^0ooKf=@2om?Sh`;oa^W^0_o8fnL3okkMk`;o^=?^0onbe?82ojG=m0;oY/_c0onLaoH2
oiO9n@?oW/Oe0_nOboH2ojC4l0CoZLO_0_n_bNd2ojg2j@?o/L;V00?o[[gUojnjh_n_^^800on_^^82
ojngg`03oj^dgon[/MgoZk7M00;oZk7M1?nY[]/2ojR[fCCooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`00B_ooool2o`0002kooooo0_nW`>/2ojJok0CoYKo/0_nU_^/2ojBo
k0?oY;o]0_nT`>d2ojG2kPCoY/C^0_nXa^l3oj[4k@;o[<G/0_n/`^X4ojk2j0;o[l7W0on]_^H2ojfm
iP;o[KkV1?n^_nL2ok33j0;o]LSX00Co^LkYokk@j?nnd>So_]3X0_o1d>D3olCBi@?oa<kR00Co`LgT
oko7hOnoan7o_lOQ0_nga>@2okBnh@CoYkSU0_n@[n/2oiB/i`;oO:C]0olnS^h2oa9mi@03o`1heonK
bOOoVlWg00?oQ]?o00?od]gQolKYk_o6jNh00_o6jNh00ooKf=Codn?SolKYkP02olKYkP?o^NOd0_nn
gNl2okGLm0;o/]Cb0on^d?82ojK;l`;oY/Sa1?nPa_<2oik7m@;oXl;`1?nTa?02ojW7k`03ojW2jon]
`^Wo[L;Y00?o[L;Y00Co/L;VojjmiOn^_NGo[[gU0_n_^^82oj^ghPCoZkCO0on[/Md2ojV^fcWooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00C?ooool00ol0003ooooooooo
o`0/ooooo`CoY[o/1?nU_n`4ojBok004ojBokOnU`NgoYL7]ojG1k@?oYL;^0_nVa>h3ojS3k@;oZ/C]
0_n[`n/4ojc2jP;o[/;X0_n/_nL3ojfniP;o[;gV1?n]_^H2ojjoi`;o/LCW0_neb>P3okW;i`03okk@
j?o1d>Go`M3U00;o`M3U00Goa=;UolC>h_o4c^;oa<kRol;:h003oko7h@;o_<;O1?nd_^42ojNhi@;o
Y[?R1?nD[>L2ogbTk@?oFi[`0_lmU?42o`1fb`;oQ]?o0om[dO/2olKYkP05ok?]monRj_[oX^[joj;Z
n_o6jNh00oniio@2ok3Qn0;o]Mcd0on`eO<2ojk@lP;oZl_a1?nVb?42oj36l`03ojC2k_nS`_3oXl;`
00?oXl;`0_nTa?000onV`>coZL;[ojW2j`02ojW2j`;o[L;Y0on[_^L2ojjmi@;oZk[T1?n[]n83oj^d
g`;oZk7M??ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo001=ooooo`03
o`000?oooooooooo02cooooo0_nV_n`6ojFok0;oY;o/0_nU`>d2ojG1k@;oY/7]1?nW`^d2ojS3k@;o
ZL;/1?n[`n/2ojc2jP;oZl3Y1?n/_nL00on]_^Ko[;gVojbmiP02ojbmiP;o[KkV00Co[l7Wok74iona
a>Oo/LCW0_neanP3okW;i`?o_LgV0_o1d>D3ol;>h`05olC>h_o2b^3o`/[Pol;:h?noan401?nl`]l2
okBnh@;o/KWO1?nV/n82oiB/i`04oiR[i?n7Y^WoQjKYohNVj@?oFi[`0olmU?400olYU>oo07KHoa6E
h003oe_;m@04ok?]monRj_[oX^[joj;ZnP?oV^Cm00?o^NOdok3Qn?n`hOP00on/f?L2ok3El`;o[Lkb
1?n[bo42ojK8l@;oYl?]0onT`^h2oj?2l0?oYKo/0onV`>`2ojW2j`?oZKkY0_n[_^L2ojVkiPCoZk[T
0_n[]n93ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool004kooooo00?o
0000ooooooooool0;Oooool7ojFok0;oYL3]1_nV`Nd2ojO2k@;oZ<;/1?nY`^`2oj_3j`;oZ/3Y1?n[
`>T2ojboi`?oZkkW0_n/_NH00on/_nOo[l7Wojo1i`02ojo1i`03ok74ioneanSo]LOX00;o]LOX00Co
^L_Wokg=i_nmcNKo_LgV0_nocND3ol;>h`;o`/_Q0_o2b^03ol35gP;o_<;O0_ni_Md4ok6ig`;oY[?R
00?oY[3OoiR[i?nHZn@00_nHZn@4ohNVj@;oLJ;_0omOX_@2oe>Wn0?o>Z_d0omYc_`2oi[To@?oVMgn
00Go/>7hojcHmon/f?Oo[=Sgoj[@m005ojg>lP;oZl_a0_nZaNd2ojO3k@;oYkoZ1?nV_^/2ojFok0;o
Y[cY1?nW_NT2ojVnj@03ojRkionY^nKoZK_V00?oZK_V0_n[^^A7ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02_ooool004oooooo0_l0000^ooooo`GoYKo/0_nU`>`6ojK1k@;oYl7/
1?nX`^`2ojW2k0?oZL3Z0onZ`>T2oj_0j@?oZ[kX0_n[_^L00on[_^So[;oWojboi`02ojboi`;o[l7W
0ona`nP2okG7j0?o^<WW00?o_LgVoko=iOnocND00_nocND00oo2c^?o`/_Qol;;h@02ol37h0?o`<GN
0_nm`Md4okVmg@;o/KWO00?o[kGMojJ`gonV/=l00_nV/=l3oiR[i0;oQjKY0_n@YnD3oh:Vj`?oGj;d
0omCYoP3oejio0;oNloo0on;bod3oikEn`04ojcHmonZd?CoZ]3doj[@m0;o[Lkb0on[anh2oj[5k@;o
ZL3Z1?nW_nX2ojJnj`03ojNlj?nV_>WoY[cY00?oY[cY0_nW_NT00onW^nOoZ;_WojRki`02ojRki`;o
ZK_VC?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo001Aooooo`03o`00
0?oooooooooo02cooooo0onU_n`4ojG0k0;oY/7]0_nV`N`4ojO1k0;oZ<;/0onX`>/2ojW0jP;oZKoY
1?nY_^T2ojZnj003ojVnj?n[_^SoZkkX00;oZkkX0_n/_nL2ojk1j0?o/L?X0_nca^P3okS9i`;o^/[V
0onocND2oko;h`03ol;;hOo0an3o`<OP00;o`<OP00?o`<GNokg1gOnm`Md00_nm`Md2okVmg@03okJi
g?n_]Mgo[kGM00;o[kGM0_nV/=l2ojJ^g@?oVj[Q1?n@YnD3oh:Vj`?oN:Wa0omc/?L3ogZmo0;oRl_m
0_nFa_P4oj7=m`;oZ]3d0onYanl2oj_7kP;oZL7[1?nY`>X2ojNojP03ojRlj?nW_>SoYkcX00;oYkcX
0_nV_>T2ojNji`CoYk_W0_nX^nM?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2_ooool005;ooooo00?o0000ooooooooool0:oooool4ojFok0;oYL3/0onV`>`3ojK1k0;oYl7/0onW
`>/2ojS0j`;oZ;oZ1?nY_nT3ojVnj@CoZKkX0_n[_^P2oj^oj0Co[/7X00?o/L?Xok?6j?nca^P00_nc
a^P00onhbNOo^/[Vok[:iP02ok[:iP03oko=iOnobn?o_l_S00;o_lSR0oo0an02okk3gP?o_L7M00?o
^[gLokJig?nf^M`00_nf^M`2ojneg@;o[K;K1?nV[]d3oi^Zh@;oT:OU0_nFZ>83ohjXi`?oR:c]0on6
/_84oh^lmP?oU/Kh0_nQcOL3ojC5l@;oZLO_00?oZ<;/ojW1jonY`N/00onY`N/2ojW0jP03ojVmj?nX
_>SoZ;cX00;oZ;cX0_nW_>P2ojNjiPCoYk[W0_nW^nMCooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02_ooool005?ooooo00?o0000ooooooooool0:oooool2ojFok0?oY[o/1?nV`>`4
ojO0k0;oYl3[0_nW_n/4ojRojP;oZKoY00?oZ;kYojVnjOnY_^T00_nY_^T2ojVnj0;oZKkY1?n[_nP2
ojk1j0?o[l?Y0_nca^P3okK8j0;o^/[V0_nlb^D00onobn?o_lSRoko8hP02oko8hP03ol37h?nn`mko
_/?N00;o_/?N00Co_L7MokZmg?nj_Mco^[gL0_nf^M`2ok>ff`Co[K;K0_nV[]d00onV[=_oWZWNoijY
gP02oijYgPCoUZSR0on>Z>L3ohR/k@?oQ[;b0_n;_?H2oiNil0CoWL7a0_nTaO400onU`>coZ<;/ojS2
k002ojS2k0;oZL7[1_nY_NP2ojRlj0;oZ;[V1?nW^^H2ojNjieOooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`09ooooo`00E?ooool2o`0002gooooo1?nV_n`4ojK0k0;oYl3/1_nW_n/2
ojRojP03ojNnj_nX_^WoZ;kY00;oZ;kY0_nY_^T2ojRnj@CoZKkY0_n[_nP3ojc1j@;o[l?Y0_naaNT3
okK8j004okO8ionlb^Go_<[Uokc:i@?o_<WT0_nob>83okg5h0;o_/?N00Co^l3MokZmg?nj_Mco^[gL
0_ng^M/4ok>ff`;o[K;K0_n/[mX3ojJ/f`CoWZWN0_nFZ>801?nKZ=ooUZWSoiJYhonFZN<3oi>]j0Go
Tk;/0onG^O02oig1l@03oj6lk?nU`>coYL3/00;oYL3/0_nX`^`2ojRnj@KoZKgX1_nX^^H2ojNjiU[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`00E_ooool00ol0003ooooo
ooooo`0[ooooo`CoY[o/0_nV`>`:ojNoj`?oYkkZ0_nX_^T2ojNnjPCoZ;kY0_nY_^T3oj[0jP;o[<7Y
0_n^`nX4ok75j@05okK8j?ngb>Oo]lSWokO8ionlb^D00onlbN@2ok_6h`?o_LGP00?o^l;Ook_0gOnk
`=d00_nk`=d00onj_Mco]kWKokNif`02okNif`;o/kKK0_n`/]X4ojb_fP?oYZcK0_nNZMh00onQZMco
VjSOoi^Xg`02oi^Xg`?oUZWS0onC[NP2oi>bk0;oVk;X1?nM]n/3oj6lk0;oYL3/0onV_>T3ojRnj@;o
ZKgX0onX^nL5ojRjiUkooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`00
Eoooool00ol0003oooooooooo`0[ooooo`CoY[o/3?nW_n/7ojNnjP;oZ;kY0onX_nX2oj[0jP;oZl;Z
1?n^`nX2ok75j@;o/lKY0_ngb>L3okS8iP03okc9i?nka^?o^lKS00;o^lKS00Co_LGPok_2gonk`]oo
^l;O0_nk`=d2okRlg0?o]kWK00?o];KJok2bf_n`/]X00on`/]X2ojb_fP04oj^]fOnVZm[oYZ_JojJ[
fPCoXJWL0onKZ=l2oiJYh`;oW:[P0onK[N@4oi^bj0;oWKO[0_nR]^L4ojBjj0;oY[cY00?oYk[WojRk
ionX^nL01?nX^nMVooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool005So
oooo00?o0000ooooooooool0;?ooool3ojJok0;oYko[0onV_n/2ojNoj`03ojJojonW_n_oYko[00;o
Yko[0_nW_^X2ojJoj`CoYko[0_nX_nX2ojS0j`CoZl;Z0_n^`nX2ojo5jP;o/lKY0ondanP2okS8iP;o
^<KU0onka^<01?nja>;o^l;Ook_2gonk`]l2okVogPCo^;cL00Co]kWKokBff_nd]][o];KJ0on`/]X0
0on^/=WoZjgIoj^]f@02oj^]f@?oYZ_J0_nQZM`00onSZM_oWjWMoinYg@02oinYg@CoW:[P0onK[N@2
oi^bj0;oX;7T1?nR]^L2ojBjj003ojJhi_nW^^OoYk[W00;oYk[W0_nX^nMZooooo`05o`000?oooooo
ooooooooool000002oooool005Wooooo00?o0000ooooooooool0;?ooool4ojJok0OoY[o[0_nW_n/6
ojJoj`;oYko[0_nW`>/4ojS0j`;oZl;Z0_n/`n/2ojo5jP;o/<GZ0ondanP2okC6i`Co^<KU00Go^lKS
ok[4h_nja>;o^/CRok_2g`04okVogP;o^;cL0_ne^M`4okBffP04ok2bf_n^/=Wo[[3Iojj`f@?oZjgI
0_nVZmX2ojJZf@?oXjWK1?nOZMd2oibZh0;oXJ_N0onP[^44oj2ai0;oX[KW00?oYKGTojJhi_nV^>H0
0_nV^>H2ojNjifgooooo00Go0000ooooooooooooooooo`00000;ooooo`00F_ooool2o`0002gooooo
1?nV_n`?ojJoj`CoYl3[0_nX`>/2ojW2j`;o[<?[0_n]a>/4ok35jP03okC7j?nda^Oo]<KW00;o]<KW
0_nha^D2okO5i0;o^/CR0onh`N42okVogP;o][cN1?ne^M`2okBffP03ok6cf_n^/=Wo[[3I00;o[[3I
0_n[[MT2ojV/f@CoYZ[I0onSZM/2oinYg@;oXZWK1?nQZmh3oj2^h@;oX;7T00?oY;;RojFei?nU]N@0
0_nU]N@2ojJhiW7ooooo00Co0000oooooooooooo00002oooool005cooooo00?o0000ooooooooool0
:oooool4ojJok003ojJojonV_ncoY[o/00KoY[o[0_nV_n`4ojJoj`;oYl3[0_nX`N`2ojW2j`;oZ/?/
1?n]a>/2ok35jP?o/LGY0_nda^L2okC5i`;o]lGT0_nf`^<3okS1h@;o]KkQ1?nf_=h2okFig003ok:f
g?na/m[o/K?J00;o/K?J0_n^/=T2ojb^f@CoZJcI0_nVZ]T01?nWZMWoY:WJojBYf_nTZMX5oj:Yf`;o
XJ_N00CoY:cLojB^gonT[]ooY:kO1?nT/^82ojFei7Gooooo00?o0000ooooool000002oooool005go
oooo00?o0000ooooooooool0:oooool7ojJok0;oY[o[1_nV_n`2ojJoj`?oY/3/00?oZ<7/ojS2k?nX
`^`01?nZ`n`5ojg4j`;o/LGY0_naa>P3okC5i`03ok?3i_nf`^?o]/;S00;o]/;S00?o^<7QokFnhOne
_^400_ne_^42okJlgP03ok>ig_nb]]co/[KL00;o/[KL0_na/mX2ojjafPCo[:kI0_nY[=T00onYZmWo
YjWIojNYf@02ojNYf@?oY:WJ0_nRZM/2ojFZfPCoY:cL0onT[]l2ojBbhWSooooo00Co0000oooooooo
oooo00002_ooool005kooooo00?o0000ooooooooool0:oooool2ojJok0KoYKo/0_nV_n`2ojFok0Ko
Y/3/00?oYl7/ojS2k?nX`^`00_nX`^`2oj[3k0?oZl?[0_n]a>/2ojk4jPCo/LCX00Co]<GWok?3i_nc
`nKo/l?V0_nf`^<2okC0h`?o]KkQ00?o/kcPok>ig_nc^Mh00_nc^Mh2ok:fg0;o/;CL1?n^/MX2ojb^
f@03oj^]fOnYZmWoZJ_I00;oZJ_I0onWZMT2ojBYfP;oYZWI1?nUZ]X3ojB/g0;oY:kOO?ooool00ol0
003oooooo`00000:ooooo`00Goooool2o`0002cooooo3?nU_n`3ojK0k0CoYl7/0_nX`^`3ojW2k0Co
Zl?[1?n^a>X2ok74j0;o/<?X0_nc`nH2ok;1i@Co]<3S00Co]KkQok>lh?nc_>3o/kcP0_nc^Mh2ok2g
gPCo/;CL0_n^/MX2ojb`fP?oZjgI0onYZmT2ojNYf@;oYjWH1?nVZMT2ojFZfX?ooooo0_l0000:oooo
o`00HOooool00ol0003oooooooooo`0Zooooo`[oYKo/1OnV`>`5ojO1k0CoZL;/1?n[`n/2ojk4jP;o
[/?Y0_n``nP2ok32i`Co//7U0_nd`><2ok:nh`;o/kcP0_n`^^04ok2ggP;o/;CL0_n]/]`4ojb`fP03
oj^]fOnY[=[oZ:_I00?oZ:_I1?nWZMP2ojJYfHGooooo0ol0000:ooooo`00H_ooool00ol0003ooooo
ooooo`0[ooooo`SoYKo/0onV`>`4ojK1k0;oYl7/0_nX`N`4ojW2k0;oZl?[0_n/`^/2ojk3j@;o[/;Y
1?n``^L2ok;1i@;o/;oU0_nb_^<2ok2lh`Co/;[P0_n`]mh2ojjegPCo[K;L0_n//=X01?nZ[]_oZJcJ
ojV/f_nY[=X4ojR[f@;oYjWHQ?ooool4o`0000gooooo001Sooooo`03o`000?oooooooooo02_ooooo
1_nU_n`00onU`>coY/3/ojK0k002ojK0k0;oY/7/0_nW`N`4ojS1k0;oZL;/0_nZ`^/2ojc2j`;o[<;Z
1?n^`^T2ok32i`;o[l3W0on`_nD00on^_NGo/;cSok2lh`02ok2lh`;o/;[P0_n^^>44ojjegP;o[K;L
00?oZ[7MojZ^fonZ[]/00_nZ[]/3ojV/fP;oZ:_IPoooool4o`00017ooooo001Tooooo`;o0000;?oo
ool3ojFok0CoYL3/1OnV`>`3ojO1k0CoZ<7/1?nZ`^/4ojc2jP;o[/;Y0_n]`NP4ojo0i`04ok2oiOn^
_NGo[[gUojjmi@;o/;cS0_n]^^<4ojjhh@;o[[GN00?oZkCOojZagOnZ/Md00_nZ/Md3ojZ^f`;oZJcJ
Poooool3o`0001Gooooo001Vooooo`03o`000?oooooooooo02_ooooo0_nU_n`2ojG0k0GoY/3/0_nW
`>`4ojO1k003ojS1k?nX`N_oZ<7[00CoZ/;[0_n/`^X3oj_1j@?o[L7X0_n_`>L2ojfoi`;o[[gU0_n/
_>D4ojfjh`;o[[SQ00?oZkKQoj^dgon[]=l00_n[]=l2ojZagHGooooo1?l0000Hooooo`00Ioooool0
0ol0003oooooooooo`0Zooooo`CoY[o/1?nV`>`4ojO0k0;oYl7/00?oZ<7/ojS1jonX`N/00_nX`N/2
oj[2j`?oZ/7[0_n[`NT00on[`>Wo[;oXojboj002ojboj0;o[KoW0_n/_NL4ojbli@;o[K[S00?oZkWT
oj^fhOn[]^400_n[]^42oj^dghCooooo1?l0000Looooo`00J?ooool00ol0003oooooooooo`0Zoooo
o`CoY[o/1?nV`>`4ojO0k0?oZ<7/0_nX`N/3ojW1j`;oZ/7[00?oZL3Zoj_0jOn[`>T00_n[`>T2ojbo
j0;oZkoX1?n/_NL2ojbli@03ojZki_n[^NCoZkWT00;oZkWT0_n[]^63ooooo`Co00008?ooool006Wo
oooo0_l0000/ooooo`?oY[o/0_nV`>`6ojO0k0CoZ<7[0_nY`N/2ojS1j`?oZL3Z0_n[`>T2ojZoj@Co
ZkoX0_n/_NL00onZ_>OoZ[_VojZkiP02ojZkiP;oZkWTP_ooool4o`0002Cooooo001[ooooo`03o`00
0?oooooooooo02[ooooo1?nV`>`7ojO0k0;oZ<7[0_nX`>/4ojS1j`CoZL3Z0onZ_nT2oj^oj0?oZKkX
0_nZ_>L2ojZkiX;ooooo0ol0000Xooooo`00K?ooool00ol0003oooooooooo`0Zooooo`;oY/3/00?o
Yl3[ojO0k?nW`>`01?nW`>`3ojO0j`?oZ<3[0_nX`N/2ojS0j`;oZL3Z0_nX_nX4ojVoj@;oZKkXPooo
ool4o`0002_ooooo001]ooooo`03o`000?oooooooooo02_ooooo0_nW`>/2ojO0k0KoYl3[2?nX`>/4
ojRojP;oZKoYP_ooool4o`0002oooooo001^ooooo`03o`000?oooooooooo02[ooooo2onW`>/8ojS0
j`;oZ;oZPOooool4o`0003?ooooo001_ooooo`;o0000:oooool<ojO0j`GoZ<3[P?ooool4o`0003Oo
oooo001aooooo`03o`000?oooooooooo02[ooooo2OnW`>^2ooooo`Co0000>oooool007;ooooo00?o
0000ooooooooool0:_ooool5ojO0jh;ooooo0ol0000oooooo`00Loooool00ol0003oooooooooo`0Z
ooooo`03ojO0jooooooooooo07oooooo1?l00012ooooo`00M?ooool2o`0002[ooooo00?o0000oooo
ooooool0Noooool4o`0004Kooooo001fooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0N?ooool4o`0004[ooooo001gooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
M?ooool4o`0004kooooo001hooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0LOoo
ool3o`0005;ooooo001iooooo`;o00009?ooool00ol0003oooooooooo`1]ooooo`Co0000EOooool0
07_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Yooooo`Co0000FOooool007co
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Uooooo`Co0000GOooool007gooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`1Qooooo`Co0000HOooool007kooooo0_l0
000Oooooo`03o`000?oooooooooo05gooooo1?l0001Uooooo`00P?ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo05[ooooo0ol0001Yooooo`00POooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo05Kooooo1?l0001/ooooo`00P_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo05;ooooo1?l0001`ooooo`00Poooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo04kooooo1?l0001dooooo`00Q?ooool2o`0001Wooooo00?o0000ooooooooool0B_oo
ool4o`0007Sooooo0026ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0A_ooool4
o`0007cooooo0027ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@oooool3o`00
083ooooo0028ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?oooool4o`0008?o
oooo0029ooooo`;o00005?ooool00ol0003oooooooooo`0kooooo`Co0000Qoooool008_ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0gooooo`Co0000Roooool008cooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0cooooo`Co0000Soooool008gooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0`ooooo`?o0000Toooool008kooooo0_l0000?ooooo`03
o`000?oooooooooo02cooooo1?l0002Fooooo`00T?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo02Sooooo1?l0002Jooooo`00TOooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo02Cooooo1?l0002Nooooo`00T_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo027ooooo1?l0002Rooooo`00Toooool2o`0000Wooooo00?o0000ooooooooool07Oooool4o`00
0:Kooooo002Eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool3o`000:[o
oooo002Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool4o`000:gooooo
002Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool4o`000;7ooooo002H
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool4o`000;Gooooo002Ioooo
o`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000^Oooool009_ooooo00Co0000oooooooo
oooo00002Oooool3o`000;gooooo002Looooo`03o`000?oooooo000000Gooooo1?l00030ooooo`00
WOooool2o`000003ooooool0003o000000;o0000a?ooool009kooooo0_l00038ooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Z_ooool01OnHV9So0000o`000?m4A4Co^[Zj00Wooooo1Ol00005oooo
o`;o000000?o410@ooooooooool00oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c02C
ooooo`00Z_ooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo1_l000001_ooooooV9RHob4Q8Oo^
k^koooooodA4A0Kooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@2Cooooo`00Z_ooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Cooooo
1Ol0000;ooooo`05o`000?ooooooooooooooool00000Toooool00:[ooooo00?o0000ooooooooool0
1?ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h00oooool01?m4A4CogMgMooooool0000<ooooo`05
oc8b<_nHV9SooooooiRHV?lb<S80Toooool00:[ooooo00?o0000ooooooooool03_ooool00omgMgOo
IVIVooooo`02ooooo`04omgMgOmEEEGoooooo`0000cooooo00Goc<c<o`000?l0003o0000olc<c02C
ooooo`00Z?ooool00ol@413o0000o`000003o`0000kooooo00?o0000ooooooooool00_ooool00omg
MgOoc<c<o`00000<ooooo`05oa0@4?nj^[[ooooookZj^_l@4100Toooool00:[ooooo00?o0000oooo
ooooool02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?ok^k^odA4A?l000003?ooool0
1Ol0003o^[Zjoooooonj^[[o000009?ooooo002Zooooo`03o`000?oooooooooo00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c005ooooo`03ogMgMol0003ooooo00_ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@2Cooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -20 0 ]
[.5 .82364 20 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25.6) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.657 .752 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69464 Mtetra
.657 .751 .919 r
.4053 .69464 .41061 .69934 .41957 .69681 .41428 .69207 Mtetra
.658 .75 .917 r
.41428 .69207 .41957 .69681 .42855 .69428 .42328 .68947 Mtetra
.66 .748 .915 r
.42328 .68947 .42855 .69428 .43756 .69174 .43231 .68683 Mtetra
.661 .745 .912 r
.43231 .68683 .43756 .69174 .4466 .68919 .44137 .68415 Mtetra
.663 .741 .908 r
.44137 .68415 .4466 .68919 .45567 .68663 .45047 .68143 Mtetra
.665 .736 .903 r
.45047 .68143 .45567 .68663 .46478 .68407 .45959 .67864 Mtetra
.667 .729 .896 r
.45959 .67864 .46478 .68407 .47391 .68149 .46875 .67581 Mtetra
.668 .721 .888 r
.46875 .67581 .47391 .68149 .48307 .67891 .47793 .67293 Mtetra
.668 .711 .88 r
.47793 .67293 .48307 .67891 .49227 .67632 .48715 .67002 Mtetra
.667 .701 .872 r
.48715 .67002 .49227 .67632 .50149 .67371 .49639 .6671 Mtetra
.665 .692 .865 r
.49639 .6671 .50149 .67371 .51075 .6711 .50566 .66422 Mtetra
.662 .683 .859 r
.50566 .66422 .51075 .6711 .52004 .66849 .51497 .66139 Mtetra
.658 .676 .856 r
.51497 .66139 .52004 .66849 .52936 .66586 .5243 .65866 Mtetra
.653 .672 .856 r
.5243 .65866 .52936 .66586 .53871 .66322 .53367 .65608 Mtetra
.648 .672 .86 r
.53367 .65608 .53871 .66322 .54809 .66058 .54307 .65367 Mtetra
.641 .677 .868 r
.54307 .65367 .54809 .66058 .55751 .65792 .5525 .65144 Mtetra
.635 .688 .883 r
.5525 .65144 .55751 .65792 .56695 .65526 .56197 .64938 Mtetra
.627 .706 .903 r
.56197 .64938 .56695 .65526 .57643 .65259 .57148 .64746 Mtetra
.619 .733 .928 r
.57148 .64746 .57643 .65259 .58595 .6499 .58103 .64561 Mtetra
.607 .765 .955 r
.58103 .64561 .58595 .6499 .59549 .64721 .59061 .64376 Mtetra
.592 .801 .98 r
.59061 .64376 .59549 .64721 .60507 .64451 .60023 .64182 Mtetra
.574 .834 .994 r
.60023 .64182 .60507 .64451 .61468 .6418 .60989 .63974 Mtetra
.556 .859 .997 r
.60989 .63974 .61468 .6418 .62432 .63908 .61958 .63746 Mtetra
.543 .875 .991 r
.61958 .63746 .62432 .63908 .634 .63636 .62929 .63498 Mtetra
.538 .883 .985 r
.62929 .63498 .634 .63636 .64371 .63362 .63904 .63233 Mtetra
.542 .889 .982 r
.63904 .63233 .64371 .63362 .65345 .63087 .64882 .62955 Mtetra
.547 .89 .983 r
.64882 .62955 .65345 .63087 .66323 .62811 .65863 .62672 Mtetra
.551 .889 .985 r
.65863 .62672 .66323 .62811 .67304 .62535 .66847 .62388 Mtetra
.55 .887 .986 r
.66847 .62388 .67304 .62535 .68289 .62257 .67835 .62109 Mtetra
.546 .885 .986 r
.67835 .62109 .68289 .62257 .69277 .61979 .68827 .61834 Mtetra
.541 .885 .985 r
.68827 .61834 .69277 .61979 .70269 .61699 .69822 .61559 Mtetra
.539 .887 .983 r
.69822 .61559 .70269 .61699 .71264 .61418 .70821 .61279 Mtetra
.549 .892 .982 r
.70821 .61279 .71264 .61418 .72262 .61137 .71823 .60986 Mtetra
.571 .896 .985 r
.71823 .60986 .72262 .61137 .73264 .60854 .72827 .60676 Mtetra
.604 .897 .988 r
.72827 .60676 .73264 .60854 .7427 .60571 .73833 .60345 Mtetra
.639 .887 .986 r
.73833 .60345 .7427 .60571 .75279 .60286 .74841 .59994 Mtetra
.667 .863 .974 r
.74841 .59994 .75279 .60286 .76291 .60001 .75852 .59627 Mtetra
.683 .829 .953 r
.75852 .59627 .76291 .60001 .77308 .59714 .76865 .59252 Mtetra
.688 .791 .928 r
.76865 .59252 .77308 .59714 .78328 .59427 .77881 .58876 Mtetra
.685 .755 .904 r
.77881 .58876 .78328 .59427 .79351 .59138 .78901 .58507 Mtetra
.679 .725 .885 r
.78901 .58507 .79351 .59138 .80378 .58849 .79925 .58152 Mtetra
.671 .702 .87 r
.79925 .58152 .80378 .58849 .81409 .58558 .80954 .57813 Mtetra
.664 .686 .86 r
.80954 .57813 .81409 .58558 .82443 .58267 .81988 .57494 Mtetra
.658 .676 .856 r
.81988 .57494 .82443 .58267 .83482 .57974 .83028 .57192 Mtetra
.653 .672 .856 r
.83028 .57192 .83482 .57974 .84523 .5768 .84072 .56904 Mtetra
.65 .673 .859 r
.84072 .56904 .84523 .5768 .85569 .57385 .85122 .56627 Mtetra
.648 .677 .864 r
.85122 .56627 .85569 .57385 .86618 .57089 .86176 .56356 Mtetra
.647 .685 .871 r
.86176 .56356 .86618 .57089 .87672 .56792 .87234 .56088 Mtetra
.647 .694 .879 r
.87234 .56088 .87672 .56792 .88729 .56494 .88297 .55818 Mtetra
.648 .704 .888 r
.88297 .55818 .88729 .56494 .89789 .56195 .89363 .55546 Mtetra
.649 .714 .895 r
.89363 .55546 .89789 .56195 .90854 .55895 .90433 .55269 Mtetra
.65 .723 .902 r
.90433 .55269 .90854 .55895 .91923 .55594 .91507 .54987 Mtetra
.651 .731 .908 r
.91507 .54987 .91923 .55594 .92995 .55292 .92584 .54698 Mtetra
.652 .738 .912 r
.92584 .54698 .92995 .55292 .94071 .54988 .93665 .54405 Mtetra
.653 .742 .915 r
.93665 .54405 .94071 .54988 .95152 .54684 .94749 .54106 Mtetra
.654 .746 .917 r
.94749 .54106 .95152 .54684 .96236 .54378 .95836 .53804 Mtetra
.655 .748 .919 r
.95836 .53804 .96236 .54378 .97324 .54071 .96928 .53499 Mtetra
.655 .75 .92 r
.96928 .53499 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.658 .752 .919 r
.391 .69252 .39636 .6972 .4053 .69464 .39996 .68993 Mtetra
.659 .751 .918 r
.39996 .68993 .4053 .69464 .41428 .69207 .40895 .6873 Mtetra
.66 .75 .917 r
.40895 .6873 .41428 .69207 .42328 .68947 .41798 .68464 Mtetra
.663 .749 .914 r
.41798 .68464 .42328 .68947 .43231 .68683 .42703 .68191 Mtetra
.666 .747 .911 r
.42703 .68191 .43231 .68683 .44137 .68415 .43611 .67911 Mtetra
.669 .743 .906 r
.43611 .67911 .44137 .68415 .45047 .68143 .44523 .67621 Mtetra
.672 .739 .9 r
.44523 .67621 .45047 .68143 .45959 .67864 .45438 .67322 Mtetra
.675 .732 .893 r
.45438 .67322 .45959 .67864 .46875 .67581 .46356 .67014 Mtetra
.677 .725 .885 r
.46356 .67014 .46875 .67581 .47793 .67293 .47276 .66697 Mtetra
.678 .716 .877 r
.47276 .66697 .47793 .67293 .48715 .67002 .482 .66375 Mtetra
.677 .706 .87 r
.482 .66375 .48715 .67002 .49639 .6671 .49126 .66052 Mtetra
.674 .696 .863 r
.49126 .66052 .49639 .6671 .50566 .66422 .50055 .65735 Mtetra
.669 .687 .858 r
.50055 .65735 .50566 .66422 .51497 .66139 .50987 .65431 Mtetra
.661 .679 .856 r
.50987 .65431 .51497 .66139 .5243 .65866 .51922 .65149 Mtetra
.651 .673 .858 r
.51922 .65149 .5243 .65866 .53367 .65608 .5286 .64895 Mtetra
.64 .671 .864 r
.5286 .64895 .53367 .65608 .54307 .65367 .53802 .64677 Mtetra
.626 .672 .875 r
.53802 .64677 .54307 .65367 .5525 .65144 .54747 .64496 Mtetra
.61 .68 .891 r
.54747 .64496 .5525 .65144 .56197 .64938 .55696 .6435 Mtetra
.592 .695 .914 r
.55696 .6435 .56197 .64938 .57148 .64746 .5665 .64234 Mtetra
.574 .718 .94 r
.5665 .64234 .57148 .64746 .58103 .64561 .57608 .64132 Mtetra
.553 .748 .968 r
.57608 .64132 .58103 .64561 .59061 .64376 .5857 .64032 Mtetra
.535 .783 .989 r
.5857 .64032 .59061 .64376 .60023 .64182 .59537 .63915 Mtetra
.52 .816 .999 r
.59537 .63915 .60023 .64182 .60989 .63974 .60506 .63768 Mtetra
.515 .844 .998 r
.60506 .63768 .60989 .63974 .61958 .63746 .61479 .63583 Mtetra
.522 .866 .991 r
.61479 .63583 .61958 .63746 .62929 .63498 .62455 .63355 Mtetra
.536 .881 .986 r
.62455 .63355 .62929 .63498 .63904 .63233 .63433 .63094 Mtetra
.555 .89 .985 r
.63433 .63094 .63904 .63233 .64882 .62955 .64414 .62808 Mtetra
.566 .892 .987 r
.64414 .62808 .64882 .62955 .65863 .62672 .65398 .62514 Mtetra
.57 .889 .989 r
.65398 .62514 .65863 .62672 .66847 .62388 .66386 .62222 Mtetra
.564 .884 .99 r
.66386 .62222 .66847 .62388 .67835 .62109 .67377 .61941 Mtetra
.553 .88 .991 r
.67377 .61941 .67835 .62109 .68827 .61834 .68372 .61672 Mtetra
.545 .88 .989 r
.68372 .61672 .68827 .61834 .69822 .61559 .69372 .61405 Mtetra
.544 .884 .987 r
.69372 .61405 .69822 .61559 .70821 .61279 .70374 .6113 Mtetra
.561 .893 .985 r
.70374 .6113 .70821 .61279 .71823 .60986 .71379 .6083 Mtetra
.592 .902 .985 r
.71379 .6083 .71823 .60986 .72827 .60676 .72385 .60496 Mtetra
.636 .907 .983 r
.72385 .60496 .72827 .60676 .73833 .60345 .73393 .60119 Mtetra
.677 .898 .976 r
.73393 .60119 .73833 .60345 .74841 .59994 .744 .59703 Mtetra
.706 .875 .96 r
.744 .59703 .74841 .59994 .75852 .59627 .75409 .59255 Mtetra
.72 .84 .939 r
.75409 .59255 .75852 .59627 .76865 .59252 .76419 .5879 Mtetra
.719 .801 .916 r
.76419 .5879 .76865 .59252 .77881 .58876 .77432 .58326 Mtetra
.711 .765 .894 r
.77432 .58326 .77881 .58876 .78901 .58507 .78448 .57876 Mtetra
.698 .733 .878 r
.78448 .57876 .78901 .58507 .79925 .58152 .7947 .57456 Mtetra
.685 .709 .866 r
.7947 .57456 .79925 .58152 .80954 .57813 .80497 .57069 Mtetra
.671 .69 .859 r
.80497 .57069 .80954 .57813 .81988 .57494 .81531 .56723 Mtetra
.66 .679 .857 r
.81531 .56723 .81988 .57494 .83028 .57192 .82572 .56411 Mtetra
.651 .673 .858 r
.82572 .56411 .83028 .57192 .84072 .56904 .83619 .5613 Mtetra
.644 .672 .862 r
.83619 .5613 .84072 .56904 .85122 .56627 .84673 .5587 Mtetra
.64 .675 .868 r
.84673 .5587 .85122 .56627 .86176 .56356 .85732 .55624 Mtetra
.637 .682 .876 r
.85732 .55624 .86176 .56356 .87234 .56088 .86795 .55385 Mtetra
.637 .691 .884 r
.86795 .55385 .87234 .56088 .88297 .55818 .87863 .55143 Mtetra
.638 .701 .892 r
.87863 .55143 .88297 .55818 .89363 .55546 .88935 .54898 Mtetra
.64 .712 .899 r
.88935 .54898 .89363 .55546 .90433 .55269 .9001 .54643 Mtetra
.643 .721 .905 r
.9001 .54643 .90433 .55269 .91507 .54987 .91089 .54378 Mtetra
.646 .73 .91 r
.91089 .54378 .91507 .54987 .92584 .54698 .9217 .54103 Mtetra
.648 .737 .914 r
.9217 .54103 .92584 .54698 .93665 .54405 .93255 .53819 Mtetra
.65 .742 .916 r
.93255 .53819 .93665 .54405 .94749 .54106 .94343 .53526 Mtetra
.652 .746 .918 r
.94343 .53526 .94749 .54106 .95836 .53804 .95434 .53227 Mtetra
.653 .748 .919 r
.95434 .53227 .95836 .53804 .96928 .53499 .96529 .52923 Mtetra
.654 .75 .92 r
.96529 .52923 .96928 .53499 .98024 .53192 .97628 .52616 Mtetra
.659 .752 .919 r
.38561 .68781 .391 .69252 .39996 .68993 .39459 .68518 Mtetra
.66 .752 .918 r
.39459 .68518 .39996 .68993 .40895 .6873 .4036 .68252 Mtetra
.662 .751 .916 r
.4036 .68252 .40895 .6873 .41798 .68464 .41264 .67979 Mtetra
.666 .75 .913 r
.41264 .67979 .41798 .68464 .42703 .68191 .42172 .67698 Mtetra
.67 .748 .909 r
.42172 .67698 .42703 .68191 .43611 .67911 .43082 .67406 Mtetra
.674 .746 .904 r
.43082 .67406 .43611 .67911 .44523 .67621 .43996 .67101 Mtetra
.679 .742 .898 r
.43996 .67101 .44523 .67621 .45438 .67322 .44913 .66783 Mtetra
.683 .736 .891 r
.44913 .66783 .45438 .67322 .46356 .67014 .45833 .66451 Mtetra
.686 .73 .883 r
.45833 .66451 .46356 .67014 .47276 .66697 .46756 .66106 Mtetra
.687 .721 .876 r
.46756 .66106 .47276 .66697 .482 .66375 .47682 .65755 Mtetra
.686 .712 .868 r
.47682 .65755 .482 .66375 .49126 .66052 .48611 .65402 Mtetra
.682 .702 .863 r
.48611 .65402 .49126 .66052 .50055 .65735 .49542 .65058 Mtetra
.675 .693 .859 r
.49542 .65058 .50055 .65735 .50987 .65431 .50475 .64733 Mtetra
.664 .684 .859 r
.50475 .64733 .50987 .65431 .51922 .65149 .51412 .64441 Mtetra
.649 .676 .862 r
.51412 .64441 .51922 .65149 .5286 .64895 .52351 .64192 Mtetra
.631 .671 .87 r
.52351 .64192 .5286 .64895 .53802 .64677 .53294 .63995 Mtetra
.608 .669 .883 r
.53294 .63995 .53802 .64677 .54747 .64496 .54241 .63856 Mtetra
.583 .673 .901 r
.54241 .63856 .54747 .64496 .55696 .6435 .55193 .63769 Mtetra
.552 .682 .925 r
.55193 .63769 .55696 .6435 .5665 .64234 .56149 .63727 Mtetra
.521 .7 .951 r
.56149 .63727 .5665 .64234 .57608 .64132 .5711 .63706 Mtetra
.491 .725 .976 r
.5711 .63706 .57608 .64132 .5857 .64032 .58076 .63689 Mtetra
.471 .758 .993 r
.58076 .63689 .5857 .64032 .59537 .63915 .59046 .63645 Mtetra
.467 .794 .999 r
.59046 .63645 .59537 .63915 .60506 .63768 .6002 .63554 Mtetra
.483 .828 .998 r
.6002 .63554 .60506 .63768 .61479 .63583 .60996 .63404 Mtetra
.518 .859 .994 r
.60996 .63404 .61479 .63583 .62455 .63355 .61976 .6319 Mtetra
.554 .879 .991 r
.61976 .6319 .62455 .63355 .63433 .63094 .62957 .62925 Mtetra
.587 .89 .99 r
.62957 .62925 .63433 .63094 .64414 .62808 .63941 .62623 Mtetra
.602 .889 .99 r
.63941 .62623 .64414 .62808 .65398 .62514 .64928 .62312 Mtetra
.603 .882 .991 r
.64928 .62312 .65398 .62514 .66386 .62222 .65918 .62008 Mtetra
.591 .873 .994 r
.65918 .62008 .66386 .62222 .67377 .61941 .66913 .61726 Mtetra
.573 .867 .995 r
.66913 .61726 .67377 .61941 .68372 .61672 .67912 .61465 Mtetra
.56 .867 .996 r
.67912 .61465 .68372 .61672 .69372 .61405 .68915 .61213 Mtetra
.557 .873 .994 r
.68915 .61213 .69372 .61405 .70374 .6113 .69922 .60951 Mtetra
.578 .887 .99 r
.69922 .60951 .70374 .6113 .71379 .6083 .70931 .60651 Mtetra
.616 .901 .986 r
.70931 .60651 .71379 .6083 .72385 .60496 .7194 .60301 Mtetra
.666 .91 .978 r
.7194 .60301 .72385 .60496 .73393 .60119 .72948 .59885 Mtetra
.71 .903 .964 r
.72948 .59885 .73393 .60119 .744 .59703 .73956 .59409 Mtetra
.739 .88 .945 r
.73956 .59409 .744 .59703 .75409 .59255 .74963 .58883 Mtetra
.751 .848 .923 r
.74963 .58883 .75409 .59255 .76419 .5879 .7597 .58331 Mtetra
.747 .81 .903 r
.7597 .58331 .76419 .5879 .77432 .58326 .7698 .5778 Mtetra
.735 .774 .885 r
.7698 .5778 .77432 .58326 .78448 .57876 .77993 .5725 Mtetra
.716 .742 .872 r
.77993 .5725 .78448 .57876 .7947 .57456 .79013 .56766 Mtetra
.698 .717 .864 r
.79013 .56766 .7947 .57456 .80497 .57069 .80039 .56333 Mtetra
.679 .696 .86 r
.80039 .56333 .80497 .57069 .81531 .56723 .81073 .5596 Mtetra
.662 .683 .859 r
.81073 .5596 .81531 .56723 .82572 .56411 .82115 .5564 Mtetra
.648 .675 .862 r
.82115 .5564 .82572 .56411 .83619 .5613 .83165 .55365 Mtetra
.638 .673 .867 r
.83165 .55365 .83619 .5613 .84673 .5587 .84222 .55123 Mtetra
.631 .675 .874 r
.84222 .55123 .84673 .5587 .85732 .55624 .85286 .54901 Mtetra
.627 .681 .881 r
.85286 .54901 .85732 .55624 .86795 .55385 .86355 .54688 Mtetra
.627 .69 .889 r
.86355 .54688 .86795 .55385 .87863 .55143 .87428 .54474 Mtetra
.628 .7 .897 r
.87428 .54474 .87863 .55143 .88935 .54898 .88505 .54252 Mtetra
.632 .711 .903 r
.88505 .54252 .88935 .54898 .9001 .54643 .89585 .54018 Mtetra
.636 .72 .909 r
.89585 .54018 .9001 .54643 .91089 .54378 .90668 .5377 Mtetra
.64 .729 .913 r
.90668 .5377 .91089 .54378 .9217 .54103 .91754 .53507 Mtetra
.644 .736 .916 r
.91754 .53507 .9217 .54103 .93255 .53819 .92843 .53231 Mtetra
.648 .741 .918 r
.92843 .53231 .93255 .53819 .94343 .53526 .93935 .52944 Mtetra
.65 .745 .919 r
.93935 .52944 .94343 .53526 .95434 .53227 .9503 .52647 Mtetra
.652 .748 .92 r
.9503 .52647 .95434 .53227 .96529 .52923 .96128 .52344 Mtetra
.653 .749 .92 r
.96128 .52344 .96529 .52923 .97628 .52616 .9723 .52037 Mtetra
.66 .752 .919 r
.38018 .68308 .38561 .68781 .39459 .68518 .38918 .68041 Mtetra
.661 .752 .918 r
.38918 .68041 .39459 .68518 .4036 .68252 .39821 .67771 Mtetra
.664 .752 .916 r
.39821 .67771 .4036 .68252 .41264 .67979 .40727 .67492 Mtetra
.668 .751 .913 r
.40727 .67492 .41264 .67979 .42172 .67698 .41637 .67204 Mtetra
.673 .75 .909 r
.41637 .67204 .42172 .67698 .43082 .67406 .4255 .66902 Mtetra
.679 .748 .903 r
.4255 .66902 .43082 .67406 .43996 .67101 .43466 .66583 Mtetra
.685 .745 .897 r
.43466 .66583 .43996 .67101 .44913 .66783 .44385 .66247 Mtetra
.69 .741 .89 r
.44385 .66247 .44913 .66783 .45833 .66451 .45308 .65894 Mtetra
.694 .735 .882 r
.45308 .65894 .45833 .66451 .46756 .66106 .46233 .65525 Mtetra
.695 .727 .875 r
.46233 .65525 .46756 .66106 .47682 .65755 .47161 .65147 Mtetra
.695 .719 .868 r
.47161 .65147 .47682 .65755 .48611 .65402 .48092 .64766 Mtetra
.69 .71 .864 r
.48092 .64766 .48611 .65402 .49542 .65058 .49025 .64396 Mtetra
.681 .7 .861 r
.49025 .64396 .49542 .65058 .50475 .64733 .4996 .64052 Mtetra
.667 .69 .862 r
.4996 .64052 .50475 .64733 .51412 .64441 .50899 .63749 Mtetra
.648 .681 .868 r
.50899 .63749 .51412 .64441 .52351 .64192 .5184 .63504 Mtetra
.623 .674 .878 r
.5184 .63504 .52351 .64192 .53294 .63995 .52784 .63328 Mtetra
.59 .668 .893 r
.52784 .63328 .53294 .63995 .54241 .63856 .53733 .63228 Mtetra
.552 .666 .912 r
.53733 .63228 .54241 .63856 .55193 .63769 .54686 .63197 Mtetra
.505 .668 .936 r
.54686 .63197 .55193 .63769 .56149 .63727 .55645 .63227 Mtetra
.461 .679 .959 r
.55645 .63227 .56149 .63727 .5711 .63706 .56608 .63284 Mtetra
.421 .697 .978 r
.56608 .63284 .5711 .63706 .58076 .63689 .57577 .63344 Mtetra
.405 .728 .99 r
.57577 .63344 .58076 .63689 .59046 .63645 .58551 .63367 Mtetra
.422 .77 .996 r
.58551 .63367 .59046 .63645 .6002 .63554 .59529 .63324 Mtetra
.468 .815 .998 r
.59529 .63324 .6002 .63554 .60996 .63404 .60509 .63199 Mtetra
.534 .854 .997 r
.60509 .63199 .60996 .63404 .61976 .6319 .61491 .62986 Mtetra
.589 .876 .993 r
.61491 .62986 .61976 .6319 .62957 .62925 .62475 .62705 Mtetra
.63 .882 .987 r
.62475 .62705 .62957 .62925 .63941 .62623 .63462 .62376 Mtetra
.644 .873 .984 r
.63462 .62376 .63941 .62623 .64928 .62312 .64451 .6204 Mtetra
.64 .861 .983 r
.64451 .6204 .64928 .62312 .65918 .62008 .65444 .61719 Mtetra
.621 .848 .986 r
.65444 .61719 .65918 .62008 .66913 .61726 .66442 .61436 Mtetra
.596 .84 .991 r
.66442 .61436 .66913 .61726 .67912 .61465 .67445 .61189 Mtetra
.577 .841 .995 r
.67445 .61189 .67912 .61465 .68915 .61213 .68452 .60958 Mtetra
.571 .85 .996 r
.68452 .60958 .68915 .61213 .69922 .60951 .69464 .6072 Mtetra
.594 .87 .993 r
.69464 .6072 .69922 .60951 .70931 .60651 .70476 .60434 Mtetra
.635 .891 .986 r
.70476 .60434 .70931 .60651 .7194 .60301 .71489 .60079 Mtetra
.69 .904 .972 r
.71489 .60079 .7194 .60301 .72948 .59885 .72499 .59634 Mtetra
.736 .9 .952 r
.72499 .59634 .72948 .59885 .73956 .59409 .73507 .59106 Mtetra
.765 .881 .93 r
.73507 .59106 .73956 .59409 .74963 .58883 .74514 .5851 Mtetra
.776 .852 .908 r
.74514 .5851 .74963 .58883 .7597 .58331 .75519 .57875 Mtetra
.77 .817 .89 r
.75519 .57875 .7597 .58331 .7698 .5778 .76526 .57241 Mtetra
.755 .784 .876 r
.76526 .57241 .7698 .5778 .77993 .5725 .77537 .56635 Mtetra
.733 .752 .868 r
.77537 .56635 .77993 .5725 .79013 .56766 .78554 .56089 Mtetra
.71 .726 .863 r
.78554 .56089 .79013 .56766 .80039 .56333 .79579 .55612 Mtetra
.686 .705 .862 r
.79579 .55612 .80039 .56333 .81073 .5596 .80614 .55214 Mtetra
.665 .69 .863 r
.80614 .55214 .81073 .5596 .82115 .5564 .81658 .54886 Mtetra
.646 .68 .868 r
.81658 .54886 .82115 .5564 .83165 .55365 .8271 .54617 Mtetra
.632 .676 .874 r
.8271 .54617 .83165 .55365 .84222 .55123 .83771 .54391 Mtetra
.623 .677 .881 r
.83771 .54391 .84222 .55123 .85286 .54901 .84839 .54191 Mtetra
.617 .682 .889 r
.84839 .54191 .85286 .54901 .86355 .54688 .85913 .54003 Mtetra
.617 .691 .896 r
.85913 .54003 .86355 .54688 .87428 .54474 .86991 .53812 Mtetra
.619 .7 .903 r
.86991 .53812 .87428 .54474 .88505 .54252 .88073 .53613 Mtetra
.624 .711 .908 r
.88073 .53613 .88505 .54252 .89585 .54018 .89158 .53397 Mtetra
.629 .72 .913 r
.89158 .53397 .89585 .54018 .90668 .5377 .90246 .53163 Mtetra
.635 .729 .916 r
.90246 .53163 .90668 .5377 .91754 .53507 .91336 .52911 Mtetra
.64 .736 .918 r
.91336 .52911 .91754 .53507 .92843 .53231 .92429 .52642 Mtetra
.645 .741 .919 r
.92429 .52642 .92843 .53231 .93935 .52944 .93524 .52358 Mtetra
.649 .745 .92 r
.93524 .52358 .93935 .52944 .9503 .52647 .94622 .52064 Mtetra
.651 .748 .92 r
.94622 .52064 .9503 .52647 .96128 .52344 .95724 .51761 Mtetra
.652 .749 .921 r
.95724 .51761 .96128 .52344 .9723 .52037 .96829 .51454 Mtetra
.66 .752 .918 r
.37472 .67831 .38018 .68308 .38918 .68041 .38374 .67562 Mtetra
.662 .752 .917 r
.38374 .67562 .38918 .68041 .39821 .67771 .39279 .67288 Mtetra
.665 .752 .915 r
.39279 .67288 .39821 .67771 .40727 .67492 .40187 .67005 Mtetra
.67 .752 .912 r
.40187 .67005 .40727 .67492 .41637 .67204 .41099 .6671 Mtetra
.676 .752 .908 r
.41099 .6671 .41637 .67204 .4255 .66902 .42014 .66399 Mtetra
.682 .751 .903 r
.42014 .66399 .4255 .66902 .43466 .66583 .42932 .66069 Mtetra
.69 .749 .897 r
.42932 .66069 .43466 .66583 .44385 .66247 .43854 .65718 Mtetra
.696 .745 .89 r
.43854 .65718 .44385 .66247 .45308 .65894 .44779 .65347 Mtetra
.701 .741 .882 r
.44779 .65347 .45308 .65894 .46233 .65525 .45707 .64956 Mtetra
.703 .735 .876 r
.45707 .64956 .46233 .65525 .47161 .65147 .46637 .64554 Mtetra
.703 .728 .87 r
.46637 .64554 .47161 .65147 .48092 .64766 .4757 .64148 Mtetra
.697 .719 .866 r
.4757 .64148 .48092 .64766 .49025 .64396 .48505 .63757 Mtetra
.687 .71 .865 r
.48505 .63757 .49025 .64396 .4996 .64052 .49443 .63394 Mtetra
.67 .7 .868 r
.49443 .63394 .4996 .64052 .50899 .63749 .50383 .63082 Mtetra
.646 .689 .876 r
.50383 .63082 .50899 .63749 .5184 .63504 .51325 .62841 Mtetra
.614 .679 .888 r
.51325 .62841 .5184 .63504 .52784 .63328 .52271 .62683 Mtetra
.569 .668 .905 r
.52271 .62683 .52784 .63328 .53733 .63228 .53222 .62621 Mtetra
.518 .66 .925 r
.53222 .62621 .53733 .63228 .54686 .63197 .54177 .62643 Mtetra
.452 .651 .945 r
.54177 .62643 .54686 .63197 .55645 .63227 .55137 .62738 Mtetra
.393 .653 .962 r
.55137 .62738 .55645 .63227 .56608 .63284 .56104 .62868 Mtetra
.346 .664 .973 r
.56104 .62868 .56608 .63284 .57577 .63344 .57076 .62998 Mtetra
.343 .697 .982 r
.57076 .62998 .57577 .63344 .58551 .63367 .58052 .63078 Mtetra
.389 .75 .992 r
.58052 .63078 .58551 .63367 .59529 .63324 .59033 .63071 Mtetra
.471 .806 .999 r
.59033 .63071 .59529 .63324 .60509 .63199 .60017 .62958 Mtetra
.566 .85 .997 r
.60017 .62958 .60509 .63199 .61491 .62986 .61002 .62729 Mtetra
.633 .865 .986 r
.61002 .62729 .61491 .62986 .62475 .62705 .61988 .62416 Mtetra
.674 .861 .97 r
.61988 .62416 .62475 .62705 .63462 .62376 .62976 .62045 Mtetra
.681 .843 .961 r
.62976 .62045 .63462 .62376 .64451 .6204 .63967 .61671 Mtetra
.67 .824 .957 r
.63967 .61671 .64451 .6204 .65444 .61719 .64962 .61327 Mtetra
.643 .807 .961 r
.64962 .61327 .65444 .61719 .66442 .61436 .65963 .61042 Mtetra
.611 .796 .97 r
.65963 .61042 .66442 .61436 .67445 .61189 .6697 .60815 Mtetra
.587 .798 .98 r
.6697 .60815 .67445 .61189 .68452 .60958 .67982 .60618 Mtetra
.577 .811 .988 r
.67982 .60618 .68452 .60958 .69464 .6072 .68998 .60419 Mtetra
.6 .84 .99 r
.68998 .60419 .69464 .6072 .70476 .60434 .70015 .60163 Mtetra
.644 .869 .983 r
.70015 .60163 .70476 .60434 .71489 .60079 .71032 .5982 Mtetra
.704 .891 .965 r
.71032 .5982 .71489 .60079 .72499 .59634 .72045 .59361 Mtetra
.753 .893 .941 r
.72045 .59361 .72499 .59634 .73507 .59106 .73055 .58792 Mtetra
.784 .879 .916 r
.73055 .58792 .73507 .59106 .74514 .5851 .74061 .58135 Mtetra
.796 .854 .894 r
.74061 .58135 .74514 .5851 .75519 .57875 .75065 .57426 Mtetra
.789 .824 .879 r
.75065 .57426 .75519 .57875 .76526 .57241 .7607 .56714 Mtetra
.774 .793 .869 r
.7607 .56714 .76526 .57241 .77537 .56635 .77079 .56036 Mtetra
.749 .763 .865 r
.77079 .56036 .77537 .56635 .78554 .56089 .78095 .55433 Mtetra
.722 .738 .863 r
.78095 .55433 .78554 .56089 .79579 .55612 .7912 .54914 Mtetra
.693 .715 .866 r
.7912 .54914 .79579 .55612 .80614 .55214 .80155 .54492 Mtetra
.667 .699 .87 r
.80155 .54492 .80614 .55214 .81658 .54886 .812 .54156 Mtetra
.644 .687 .876 r
.812 .54156 .81658 .54886 .8271 .54617 .82256 .53892 Mtetra
.626 .682 .883 r
.82256 .53892 .8271 .54617 .83771 .54391 .8332 .53681 Mtetra
.614 .681 .89 r
.8332 .53681 .83771 .54391 .84839 .54191 .84392 .535 Mtetra
.608 .685 .897 r
.84392 .535 .84839 .54191 .85913 .54003 .8547 .53334 Mtetra
.607 .693 .904 r
.8547 .53334 .85913 .54003 .86991 .53812 .86553 .53164 Mtetra
.61 .702 .909 r
.86553 .53164 .86991 .53812 .88073 .53613 .8764 .52983 Mtetra
.616 .712 .914 r
.8764 .52983 .88073 .53613 .89158 .53397 .88729 .52782 Mtetra
.623 .721 .917 r
.88729 .52782 .89158 .53397 .90246 .53163 .89821 .5256 Mtetra
.631 .73 .919 r
.89821 .5256 .90246 .53163 .91336 .52911 .90915 .52316 Mtetra
.637 .736 .92 r
.90915 .52316 .91336 .52911 .92429 .52642 .92012 .52052 Mtetra
.643 .742 .921 r
.92012 .52052 .92429 .52642 .93524 .52358 .93111 .51771 Mtetra
.648 .745 .921 r
.93111 .51771 .93524 .52358 .94622 .52064 .94212 .51478 Mtetra
.65 .748 .921 r
.94212 .51478 .94622 .52064 .95724 .51761 .95317 .51175 Mtetra
.652 .749 .921 r
.95317 .51175 .95724 .51761 .96829 .51454 .96426 .50866 Mtetra
.66 .753 .918 r
.36922 .67351 .37472 .67831 .38374 .67562 .37826 .6708 Mtetra
.662 .753 .917 r
.37826 .6708 .38374 .67562 .39279 .67288 .38733 .66803 Mtetra
.666 .753 .915 r
.38733 .66803 .39279 .67288 .40187 .67005 .39644 .66516 Mtetra
.671 .753 .912 r
.39644 .66516 .40187 .67005 .41099 .6671 .40557 .66216 Mtetra
.678 .754 .908 r
.40557 .66216 .41099 .6671 .42014 .66399 .41475 .65898 Mtetra
.685 .753 .903 r
.41475 .65898 .42014 .66399 .42932 .66069 .42395 .65559 Mtetra
.694 .752 .897 r
.42395 .65559 .42932 .66069 .43854 .65718 .43319 .65196 Mtetra
.7 .75 .89 r
.43319 .65196 .43854 .65718 .44779 .65347 .44246 .64809 Mtetra
.707 .747 .883 r
.44246 .64809 .44779 .65347 .45707 .64956 .45177 .644 Mtetra
.709 .742 .877 r
.45177 .644 .45707 .64956 .46637 .64554 .4611 .63979 Mtetra
.709 .736 .872 r
.4611 .63979 .46637 .64554 .4757 .64148 .47045 .63552 Mtetra
.703 .728 .87 r
.47045 .63552 .4757 .64148 .48505 .63757 .47982 .63142 Mtetra
.692 .72 .871 r
.47982 .63142 .48505 .63757 .49443 .63394 .48922 .62764 Mtetra
.673 .71 .876 r
.48922 .62764 .49443 .63394 .50383 .63082 .49864 .62444 Mtetra
.644 .699 .886 r
.49864 .62444 .50383 .63082 .51325 .62841 .50808 .62206 Mtetra
.604 .686 .9 r
.50808 .62206 .51325 .62841 .52271 .62683 .51755 .62066 Mtetra
.547 .67 .918 r
.51755 .62066 .52271 .62683 .53222 .62621 .52707 .62037 Mtetra
.479 .653 .936 r
.52707 .62037 .53222 .62621 .54177 .62643 .53664 .62106 Mtetra
.394 .633 .95 r
.53664 .62106 .54177 .62643 .55137 .62738 .54626 .62262 Mtetra
.324 .623 .958 r
.54626 .62262 .55137 .62738 .56104 .62868 .55595 .62454 Mtetra
.279 .629 .962 r
.55595 .62454 .56104 .62868 .57076 .62998 .5657 .62642 Mtetra
.301 .671 .974 r
.5657 .62642 .57076 .62998 .58052 .63078 .5755 .62764 Mtetra
.386 .737 .991 r
.5755 .62764 .58052 .63078 .59033 .63071 .58533 .62777 Mtetra
.503 .801 .999 r
.58533 .62777 .59033 .63071 .60017 .62958 .59519 .62656 Mtetra
.613 .838 .985 r
.59519 .62656 .60017 .62958 .61002 .62729 .60506 .62393 Mtetra
.678 .84 .961 r
.60506 .62393 .61002 .62729 .61988 .62416 .61494 .62029 Mtetra
.709 .824 .936 r
.61494 .62029 .61988 .62416 .62976 .62045 .62484 .616 Mtetra
.707 .8 .923 r
.62484 .616 .62976 .62045 .63967 .61671 .63476 .61178 Mtetra
.688 .776 .918 r
.63476 .61178 .63967 .61671 .64962 .61327 .64473 .60805 Mtetra
.654 .755 .924 r
.64473 .60805 .64962 .61327 .65963 .61042 .65476 .60518 Mtetra
.616 .742 .936 r
.65476 .60518 .65963 .61042 .6697 .60815 .66486 .60316 Mtetra
.587 .742 .95 r
.66486 .60316 .6697 .60815 .67982 .60618 .67503 .60165 Mtetra
.573 .757 .965 r
.67503 .60165 .67982 .60618 .68998 .60419 .68524 .6002 Mtetra
.597 .792 .974 r
.68524 .6002 .68998 .60419 .70015 .60163 .69547 .59811 Mtetra
.645 .832 .972 r
.69547 .59811 .70015 .60163 .71032 .5982 .70568 .59499 Mtetra
.71 .864 .955 r
.70568 .59499 .71032 .5982 .72045 .59361 .71586 .59044 Mtetra
.762 .876 .929 r
.71586 .59044 .72045 .59361 .73055 .58792 .72597 .58453 Mtetra
.796 .87 .902 r
.72597 .58453 .73055 .58792 .74061 .58135 .73604 .57749 Mtetra
.809 .852 .881 r
.73604 .57749 .74061 .58135 .75065 .57426 .74608 .56977 Mtetra
.804 .827 .869 r
.74608 .56977 .75065 .57426 .7607 .56714 .75612 .56199 Mtetra
.789 .801 .862 r
.75612 .56199 .7607 .56714 .77079 .56036 .7662 .55456 Mtetra
.763 .774 .863 r
.7662 .55456 .77079 .56036 .78095 .55433 .77635 .548 Mtetra
.734 .75 .865 r
.77635 .548 .78095 .55433 .7912 .54914 .78659 .54243 Mtetra
.7 .728 .871 r
.78659 .54243 .7912 .54914 .80155 .54492 .79695 .538 Mtetra
.67 .71 .878 r
.79695 .538 .80155 .54492 .812 .54156 .80743 .53456 Mtetra
.642 .697 .885 r
.80743 .53456 .812 .54156 .82256 .53892 .81801 .53196 Mtetra
.62 .689 .893 r
.81801 .53196 .82256 .53892 .8332 .53681 .82869 .52996 Mtetra
.606 .687 .9 r
.82869 .52996 .8332 .53681 .84392 .535 .83945 .52831 Mtetra
.598 .689 .906 r
.83945 .52831 .84392 .535 .8547 .53334 .85027 .52682 Mtetra
.599 .696 .911 r
.85027 .52682 .8547 .53334 .86553 .53164 .86115 .52529 Mtetra
.602 .704 .916 r
.86115 .52529 .86553 .53164 .8764 .52983 .87205 .52363 Mtetra
.61 .714 .919 r
.87205 .52363 .8764 .52983 .88729 .52782 .88299 .52173 Mtetra
.618 .723 .921 r
.88299 .52173 .88729 .52782 .89821 .5256 .89395 .5196 Mtetra
.627 .731 .922 r
.89395 .5196 .89821 .5256 .90915 .52316 .90493 .51722 Mtetra
.635 .737 .922 r
.90493 .51722 .90915 .52316 .92012 .52052 .91593 .51461 Mtetra
.642 .742 .922 r
.91593 .51461 .92012 .52052 .93111 .51771 .92695 .51182 Mtetra
.647 .746 .922 r
.92695 .51182 .93111 .51771 .94212 .51478 .938 .50888 Mtetra
.65 .748 .921 r
.938 .50888 .94212 .51478 .95317 .51175 .94908 .50585 Mtetra
.652 .749 .921 r
.94908 .50585 .95317 .51175 .96426 .50866 .9602 .50275 Mtetra
.661 .753 .918 r
.36369 .66869 .36922 .67351 .37826 .6708 .37275 .66595 Mtetra
.663 .753 .917 r
.37275 .66595 .37826 .6708 .38733 .66803 .38184 .66316 Mtetra
.666 .754 .915 r
.38184 .66316 .38733 .66803 .39644 .66516 .39096 .66026 Mtetra
.672 .754 .912 r
.39096 .66026 .39644 .66516 .40557 .66216 .40012 .65722 Mtetra
.679 .755 .908 r
.40012 .65722 .40557 .66216 .41475 .65898 .40932 .65399 Mtetra
.687 .756 .904 r
.40932 .65399 .41475 .65898 .42395 .65559 .41855 .65053 Mtetra
.696 .756 .897 r
.41855 .65053 .42395 .65559 .43319 .65196 .42781 .6468 Mtetra
.704 .755 .891 r
.42781 .6468 .43319 .65196 .44246 .64809 .43711 .64283 Mtetra
.711 .753 .885 r
.43711 .64283 .44246 .64809 .45177 .644 .44643 .6386 Mtetra
.714 .749 .88 r
.44643 .6386 .45177 .644 .4611 .63979 .45578 .63424 Mtetra
.715 .745 .875 r
.45578 .63424 .4611 .63979 .47045 .63552 .46516 .62981 Mtetra
.709 .739 .875 r
.46516 .62981 .47045 .63552 .47982 .63142 .47456 .62556 Mtetra
.697 .732 .877 r
.47456 .62556 .47982 .63142 .48922 .62764 .48397 .62166 Mtetra
.675 .722 .885 r
.48397 .62166 .48922 .62764 .49864 .62444 .49341 .61841 Mtetra
.641 .711 .897 r
.49341 .61841 .49864 .62444 .50808 .62206 .50287 .61608 Mtetra
.593 .695 .914 r
.50287 .61608 .50808 .62206 .51755 .62066 .51237 .61483 Mtetra
.522 .673 .932 r
.51237 .61483 .51755 .62066 .52707 .62037 .5219 .61483 Mtetra
.437 .647 .947 r
.5219 .61483 .52707 .62037 .53664 .62106 .53148 .61592 Mtetra
.333 .613 .951 r
.53148 .61592 .53664 .62106 .54626 .62262 .54112 .61797 Mtetra
.258 .594 .95 r
.54112 .61797 .54626 .62262 .55595 .62454 .55083 .62039 Mtetra
.227 .601 .95 r
.55083 .62039 .55595 .62454 .5657 .62642 .5606 .62269 Mtetra
.285 .655 .97 r
.5606 .62269 .5657 .62642 .5755 .62764 .57042 .62415 Mtetra
.412 .734 .991 r
.57042 .62415 .5755 .62764 .58533 .62777 .58028 .62426 Mtetra
.552 .794 .989 r
.58028 .62426 .58533 .62777 .59519 .62656 .59016 .62274 Mtetra
.66 .815 .957 r
.59016 .62274 .59519 .62656 .60506 .62393 .60005 .61954 Mtetra
.712 .803 .921 r
.60005 .61954 .60506 .62393 .61494 .62029 .60994 .61518 Mtetra
.731 .779 .891 r
.60994 .61518 .61494 .62029 .62484 .616 .61984 .61014 Mtetra
.72 .751 .876 r
.61984 .61014 .62484 .616 .63476 .61178 .62977 .6053 Mtetra
.695 .724 .872 r
.62977 .6053 .63476 .61178 .64473 .60805 .63975 .60121 Mtetra
.656 .7 .879 r
.63975 .60121 .64473 .60805 .65476 .60518 .6498 .59831 Mtetra
.612 .683 .892 r
.6498 .59831 .65476 .60518 .66486 .60316 .65993 .59662 Mtetra
.578 .679 .91 r
.65993 .59662 .66486 .60316 .67503 .60165 .67014 .59568 Mtetra
.559 .693 .929 r
.67014 .59568 .67503 .60165 .68524 .6002 .68041 .59496 Mtetra
.582 .732 .946 r
.68041 .59496 .68524 .6002 .69547 .59811 .6907 .59356 Mtetra
.631 .781 .953 r
.6907 .59356 .69547 .59811 .70568 .59499 .70097 .59098 Mtetra
.702 .827 .942 r
.70097 .59098 .70568 .59499 .71586 .59044 .71119 .58671 Mtetra
.761 .851 .918 r
.71119 .58671 .71586 .59044 .72597 .58453 .72134 .58078 Mtetra
.8 .856 .891 r
.72134 .58078 .72597 .58453 .73604 .57749 .73143 .57347 Mtetra
.818 .846 .87 r
.73143 .57347 .73604 .57749 .74608 .56977 .74148 .56528 Mtetra
.815 .829 .86 r
.74148 .56528 .74608 .56977 .75612 .56199 .75152 .55695 Mtetra
.802 .809 .857 r
.75152 .55695 .75612 .56199 .7662 .55456 .7616 .54898 Mtetra
.775 .786 .862 r
.7616 .54898 .7662 .55456 .77635 .548 .77175 .54197 Mtetra
.745 .764 .869 r
.77175 .54197 .77635 .548 .78659 .54243 .78199 .53606 Mtetra
.708 .742 .879 r
.78199 .53606 .78659 .54243 .79695 .538 .79237 .53143 Mtetra
.673 .724 .888 r
.79237 .53143 .79695 .538 .80743 .53456 .80286 .52791 Mtetra
.64 .709 .897 r
.80286 .52791 .80743 .53456 .81801 .53196 .81347 .52532 Mtetra
.615 .699 .904 r
.81347 .52532 .81801 .53196 .82869 .52996 .82418 .52341 Mtetra
.599 .695 .911 r
.82418 .52341 .82869 .52996 .83945 .52831 .83498 .52187 Mtetra
.59 .696 .916 r
.83498 .52187 .83945 .52831 .85027 .52682 .84584 .52051 Mtetra
.591 .701 .92 r
.84584 .52051 .85027 .52682 .86115 .52529 .85675 .51909 Mtetra
.595 .708 .923 r
.85675 .51909 .86115 .52529 .87205 .52363 .8677 .51753 Mtetra
.604 .717 .924 r
.8677 .51753 .87205 .52363 .88299 .52173 .87867 .51571 Mtetra
.614 .725 .925 r
.87867 .51571 .88299 .52173 .89395 .5196 .88966 .51364 Mtetra
.624 .733 .925 r
.88966 .51364 .89395 .5196 .90493 .51722 .90067 .51129 Mtetra
.633 .738 .924 r
.90067 .51129 .90493 .51722 .91593 .51461 .91171 .5087 Mtetra
.641 .743 .923 r
.91171 .5087 .91593 .51461 .92695 .51182 .92276 .50591 Mtetra
.646 .746 .922 r
.92276 .50591 .92695 .51182 .938 .50888 .93384 .50296 Mtetra
.65 .748 .922 r
.93384 .50296 .938 .50888 .94908 .50585 .94496 .49991 Mtetra
.651 .749 .921 r
.94496 .49991 .94908 .50585 .9602 .50275 .9561 .4968 Mtetra
.661 .753 .918 r
.35813 .66383 .36369 .66869 .37275 .66595 .36721 .66108 Mtetra
.663 .753 .917 r
.36721 .66108 .37275 .66595 .38184 .66316 .37631 .65827 Mtetra
.667 .754 .916 r
.37631 .65827 .38184 .66316 .39096 .66026 .38546 .65535 Mtetra
.672 .755 .913 r
.38546 .65535 .39096 .66026 .40012 .65722 .39464 .65229 Mtetra
.68 .757 .909 r
.39464 .65229 .40012 .65722 .40932 .65399 .40385 .64902 Mtetra
.689 .758 .904 r
.40385 .64902 .40932 .65399 .41855 .65053 .4131 .64551 Mtetra
.698 .759 .899 r
.4131 .64551 .41855 .65053 .42781 .6468 .42239 .64172 Mtetra
.706 .759 .893 r
.42239 .64172 .42781 .6468 .43711 .64283 .43171 .63767 Mtetra
.714 .758 .887 r
.43171 .63767 .43711 .64283 .44643 .6386 .44106 .63334 Mtetra
.718 .756 .882 r
.44106 .63334 .44643 .6386 .45578 .63424 .45044 .62887 Mtetra
.719 .753 .879 r
.45044 .62887 .45578 .63424 .46516 .62981 .45984 .62432 Mtetra
.713 .748 .88 r
.45984 .62432 .46516 .62981 .47456 .62556 .46926 .61996 Mtetra
.7 .743 .884 r
.46926 .61996 .47456 .62556 .48397 .62166 .4787 .61599 Mtetra
.676 .734 .894 r
.4787 .61599 .48397 .62166 .49341 .61841 .48815 .61272 Mtetra
.638 .722 .909 r
.48815 .61272 .49341 .61841 .50287 .61608 .49763 .61043 Mtetra
.581 .705 .928 r
.49763 .61043 .50287 .61608 .51237 .61483 .50714 .60932 Mtetra
.495 .676 .946 r
.50714 .60932 .51237 .61483 .5219 .61483 .51669 .60957 Mtetra
.394 .64 .954 r
.51669 .60957 .5219 .61483 .53148 .61592 .52629 .61099 Mtetra
.278 .593 .948 r
.52629 .61099 .53148 .61592 .54112 .61797 .53595 .61341 Mtetra
.211 .572 .94 r
.53595 .61341 .54112 .61797 .55083 .62039 .54568 .61615 Mtetra
.208 .586 .944 r
.54568 .61615 .55083 .62039 .5606 .62269 .55546 .61866 Mtetra
.311 .656 .971 r
.55546 .61866 .5606 .62269 .57042 .62415 .56531 .62011 Mtetra
.469 .735 .985 r
.56531 .62011 .57042 .62415 .58028 .62426 .57518 .61992 Mtetra
.608 .776 .961 r
.57518 .61992 .58028 .62426 .59016 .62274 .58508 .61784 Mtetra
.697 .779 .914 r
.58508 .61784 .59016 .62274 .60005 .61954 .59497 .61386 Mtetra
.732 .759 .874 r
.59497 .61386 .60005 .61954 .60994 .61518 .60487 .60862 Mtetra
.74 .735 .846 r
.60487 .60862 .60994 .61518 .61984 .61014 .61477 .60272 Mtetra
.724 .707 .834 r
.61477 .60272 .61984 .61014 .62977 .6053 .6247 .59721 Mtetra
.695 .681 .833 r
.6247 .59721 .62977 .6053 .63975 .60121 .63468 .59273 Mtetra
.652 .656 .841 r
.63468 .59273 .63975 .60121 .6498 .59831 .64475 .58981 Mtetra
.604 .634 .854 r
.64475 .58981 .6498 .59831 .65993 .59662 .65491 .58846 Mtetra
.564 .625 .871 r
.65491 .58846 .65993 .59662 .67014 .59568 .66516 .58816 Mtetra
.541 .632 .891 r
.66516 .58816 .67014 .59568 .68041 .59496 .67548 .58825 Mtetra
.56 .668 .91 r
.67548 .58825 .68041 .59496 .6907 .59356 .68583 .5877 Mtetra
.608 .72 .924 r
.68583 .5877 .6907 .59356 .70097 .59098 .69617 .58588 Mtetra
.684 .777 .922 r
.69617 .58588 .70097 .59098 .71119 .58671 .70645 .58213 Mtetra
.749 .815 .904 r
.70645 .58213 .71119 .58671 .72134 .58078 .71665 .57647 Mtetra
.795 .833 .881 r
.71665 .57647 .72134 .58078 .73143 .57347 .72677 .56912 Mtetra
.819 .835 .862 r
.72677 .56912 .73143 .57347 .74148 .56528 .73684 .56069 Mtetra
.821 .827 .853 r
.73684 .56069 .74148 .56528 .75152 .55695 .7469 .552 Mtetra
.811 .814 .853 r
.7469 .552 .75152 .55695 .7616 .54898 .75698 .54361 Mtetra
.786 .797 .862 r
.75698 .54361 .7616 .54898 .77175 .54197 .76714 .53623 Mtetra
.754 .778 .872 r
.76714 .53623 .77175 .54197 .78199 .53606 .77739 .53003 Mtetra
.715 .757 .886 r
.77739 .53003 .78199 .53606 .79237 .53143 .78778 .52521 Mtetra
.676 .738 .897 r
.78778 .52521 .79237 .53143 .80286 .52791 .79829 .5216 Mtetra
.639 .721 .907 r
.79829 .5216 .80286 .52791 .81347 .52532 .80893 .519 Mtetra
.61 .709 .915 r
.80893 .519 .81347 .52532 .82418 .52341 .81967 .51712 Mtetra
.592 .703 .92 r
.81967 .51712 .82418 .52341 .83498 .52187 .8305 .51565 Mtetra
.583 .702 .925 r
.8305 .51565 .83498 .52187 .84584 .52051 .8414 .51437 Mtetra
.584 .707 .927 r
.8414 .51437 .84584 .52051 .85675 .51909 .85234 .51302 Mtetra
.589 .712 .929 r
.85234 .51302 .85675 .51909 .8677 .51753 .86332 .51153 Mtetra
.6 .721 .929 r
.86332 .51153 .8677 .51753 .87867 .51571 .87433 .50975 Mtetra
.611 .728 .928 r
.87433 .50975 .87867 .51571 .88966 .51364 .88536 .50771 Mtetra
.623 .735 .927 r
.88536 .50771 .88966 .51364 .90067 .51129 .8964 .50537 Mtetra
.632 .74 .926 r
.8964 .50537 .90067 .51129 .91171 .5087 .90746 .50278 Mtetra
.64 .744 .924 r
.90746 .50278 .91171 .5087 .92276 .50591 .91855 .49998 Mtetra
.646 .747 .923 r
.91855 .49998 .92276 .50591 .93384 .50296 .92966 .49701 Mtetra
.65 .749 .922 r
.92966 .49701 .93384 .50296 .94496 .49991 .94081 .49394 Mtetra
.651 .75 .922 r
.94081 .49394 .94496 .49991 .9561 .4968 .95198 .4908 Mtetra
.66 .752 .918 r
.35253 .65894 .35813 .66383 .36721 .66108 .36162 .65618 Mtetra
.662 .753 .918 r
.36162 .65618 .36721 .66108 .37631 .65827 .37075 .65336 Mtetra
.666 .754 .916 r
.37075 .65336 .37631 .65827 .38546 .65535 .37992 .65043 Mtetra
.672 .756 .914 r
.37992 .65043 .38546 .65535 .39464 .65229 .38912 .64735 Mtetra
.68 .758 .91 r
.38912 .64735 .39464 .65229 .40385 .64902 .39835 .64406 Mtetra
.689 .76 .906 r
.39835 .64406 .40385 .64902 .4131 .64551 .40762 .64052 Mtetra
.699 .761 .9 r
.40762 .64052 .4131 .64551 .42239 .64172 .41693 .63669 Mtetra
.708 .762 .895 r
.41693 .63669 .42239 .64172 .43171 .63767 .42628 .63259 Mtetra
.716 .763 .889 r
.42628 .63259 .43171 .63767 .44106 .63334 .43565 .6282 Mtetra
.72 .762 .886 r
.43565 .6282 .44106 .63334 .45044 .62887 .44505 .62366 Mtetra
.722 .761 .883 r
.44505 .62366 .45044 .62887 .45984 .62432 .45448 .61905 Mtetra
.715 .758 .886 r
.45448 .61905 .45984 .62432 .46926 .61996 .46392 .61463 Mtetra
.702 .753 .892 r
.46392 .61463 .46926 .61996 .4787 .61599 .47338 .61062 Mtetra
.676 .746 .904 r
.47338 .61062 .4787 .61599 .48815 .61272 .48286 .60736 Mtetra
.632 .735 .922 r
.48286 .60736 .48815 .61272 .49763 .61043 .49236 .60514 Mtetra
.567 .715 .942 r
.49236 .60514 .49763 .61043 .50714 .60932 .50188 .60417 Mtetra
.467 .68 .958 r
.50188 .60417 .50714 .60932 .51669 .60957 .51145 .60462 Mtetra
.353 .634 .96 r
.51145 .60462 .51669 .60957 .52629 .61099 .52106 .60627 Mtetra
.234 .579 .943 r
.52106 .60627 .52629 .61099 .53595 .61341 .53074 .6089 Mtetra
.189 .563 .935 r
.53074 .6089 .53595 .61341 .54568 .61615 .54048 .61175 Mtetra
.228 .592 .948 r
.54048 .61175 .54568 .61615 .55546 .61866 .55029 .61419 Mtetra
.372 .669 .973 r
.55029 .61419 .55546 .61866 .56531 .62011 .56015 .61532 Mtetra
.54 .732 .963 r
.56015 .61532 .56531 .62011 .57518 .61992 .57004 .61452 Mtetra
.657 .749 .918 r
.57004 .61452 .57518 .61992 .58508 .61784 .57994 .6116 Mtetra
.721 .739 .865 r
.57994 .6116 .58508 .61784 .59497 .61386 .58984 .60661 Mtetra
.742 .717 .828 r
.58984 .60661 .59497 .61386 .60487 .60862 .59973 .60033 Mtetra
.742 .694 .805 r
.59973 .60033 .60487 .60862 .61477 .60272 .60963 .59351 Mtetra
.722 .669 .797 r
.60963 .59351 .61477 .60272 .6247 .59721 .61956 .5873 Mtetra
.691 .644 .798 r
.61956 .5873 .6247 .59721 .63468 .59273 .62954 .58243 Mtetra
.646 .617 .806 r
.62954 .58243 .63468 .59273 .64475 .58981 .63962 .57949 Mtetra
.595 .592 .818 r
.63962 .57949 .64475 .58981 .65491 .58846 .6498 .57848 Mtetra
.551 .576 .833 r
.6498 .57848 .65491 .58846 .66516 .58816 .66009 .57883 Mtetra
.522 .576 .851 r
.66009 .57883 .66516 .58816 .67548 .58825 .67046 .57981 Mtetra
.535 .605 .87 r
.67046 .57981 .67548 .58825 .68583 .5877 .68086 .58025 Mtetra
.578 .655 .889 r
.68086 .58025 .68583 .5877 .69617 .58588 .69127 .57941 Mtetra
.654 .718 .896 r
.69127 .57941 .69617 .58588 .70645 .58213 .70161 .57648 Mtetra
.725 .77 .889 r
.70161 .57648 .70645 .58213 .71665 .57647 .71188 .57139 Mtetra
.781 .804 .872 r
.71188 .57139 .71665 .57647 .72677 .56912 .72205 .56434 Mtetra
.813 .819 .855 r
.72205 .56434 .72677 .56912 .73684 .56069 .73216 .55594 Mtetra
.822 .822 .849 r
.73216 .55594 .73684 .56069 .7469 .552 .74225 .54709 Mtetra
.816 .817 .851 r
.74225 .54709 .7469 .552 .75698 .54361 .75235 .53846 Mtetra
.794 .807 .863 r
.75235 .53846 .75698 .54361 .76714 .53623 .76252 .5308 Mtetra
.763 .792 .877 r
.76252 .5308 .76714 .53623 .77739 .53003 .77279 .52436 Mtetra
.721 .773 .894 r
.77279 .52436 .77739 .53003 .78778 .52521 .7832 .51936 Mtetra
.679 .754 .907 r
.7832 .51936 .78778 .52521 .79829 .5216 .79373 .51564 Mtetra
.639 .735 .918 r
.79373 .51564 .79829 .5216 .80893 .519 .80439 .51299 Mtetra
.607 .721 .926 r
.80439 .51299 .80893 .519 .81967 .51712 .81516 .51111 Mtetra
.587 .713 .93 r
.81516 .51111 .81967 .51712 .8305 .51565 .82602 .50965 Mtetra
.577 .709 .933 r
.82602 .50965 .8305 .51565 .8414 .51437 .83694 .5084 Mtetra
.579 .712 .934 r
.83694 .5084 .8414 .51437 .85234 .51302 .84792 .50709 Mtetra
.585 .717 .934 r
.84792 .50709 .85234 .51302 .86332 .51153 .85893 .50562 Mtetra
.598 .724 .933 r
.85893 .50562 .86332 .51153 .87433 .50975 .86997 .50385 Mtetra
.609 .731 .931 r
.86997 .50385 .87433 .50975 .88536 .50771 .88103 .50181 Mtetra
.622 .737 .929 r
.88103 .50181 .88536 .50771 .8964 .50537 .8921 .49945 Mtetra
.632 .742 .927 r
.8921 .49945 .8964 .50537 .90746 .50278 .9032 .49685 Mtetra
.64 .745 .925 r
.9032 .49685 .90746 .50278 .91855 .49998 .91431 .49403 Mtetra
.646 .748 .924 r
.91431 .49403 .91855 .49998 .92966 .49701 .92545 .49103 Mtetra
.65 .749 .922 r
.92545 .49103 .92966 .49701 .94081 .49394 .93663 .48793 Mtetra
.652 .75 .922 r
.93663 .48793 .94081 .49394 .95198 .4908 .94784 .48476 Mtetra
.66 .752 .919 r
.34689 .65403 .35253 .65894 .36162 .65618 .35601 .65126 Mtetra
.662 .753 .918 r
.35601 .65126 .36162 .65618 .37075 .65336 .36516 .64844 Mtetra
.666 .755 .917 r
.36516 .64844 .37075 .65336 .37992 .65043 .37434 .64551 Mtetra
.672 .757 .915 r
.37434 .64551 .37992 .65043 .38912 .64735 .38356 .64243 Mtetra
.68 .759 .911 r
.38356 .64243 .38912 .64735 .39835 .64406 .39281 .63913 Mtetra
.689 .762 .907 r
.39281 .63913 .39835 .64406 .40762 .64052 .40211 .63558 Mtetra
.699 .764 .902 r
.40211 .63558 .40762 .64052 .41693 .63669 .41144 .63173 Mtetra
.708 .766 .897 r
.41144 .63173 .41693 .63669 .42628 .63259 .4208 .6276 Mtetra
.717 .767 .892 r
.4208 .6276 .42628 .63259 .43565 .6282 .4302 .62318 Mtetra
.722 .767 .889 r
.4302 .62318 .43565 .6282 .44505 .62366 .43963 .61859 Mtetra
.723 .767 .887 r
.43963 .61859 .44505 .62366 .45448 .61905 .44908 .61394 Mtetra
.717 .765 .89 r
.44908 .61394 .45448 .61905 .46392 .61463 .45854 .60949 Mtetra
.702 .762 .898 r
.45854 .60949 .46392 .61463 .47338 .61062 .46803 .60548 Mtetra
.674 .755 .912 r
.46803 .60548 .47338 .61062 .48286 .60736 .47753 .60225 Mtetra
.625 .743 .932 r
.47753 .60225 .48286 .60736 .49236 .60514 .48705 .60012 Mtetra
.551 .722 .953 r
.48705 .60012 .49236 .60514 .50188 .60417 .49659 .59929 Mtetra
.439 .681 .966 r
.49659 .59929 .50188 .60417 .51145 .60462 .50617 .59991 Mtetra
.319 .629 .961 r
.50617 .59991 .51145 .60462 .52106 .60627 .5158 .6017 Mtetra
.209 .573 .94 r
.5158 .6017 .52106 .60627 .53074 .6089 .52549 .60439 Mtetra
.199 .571 .939 r
.52549 .60439 .53074 .6089 .54048 .61175 .53525 .60712 Mtetra
.286 .616 .958 r
.53525 .60712 .54048 .61175 .55029 .61419 .54507 .60918 Mtetra
.456 .686 .965 r
.54507 .60918 .55029 .61419 .56015 .61532 .55494 .60964 Mtetra
.608 .722 .926 r
.55494 .60964 .56015 .61532 .57004 .61452 .56484 .60787 Mtetra
.692 .718 .869 r
.56484 .60787 .57004 .61452 .57994 .6116 .57475 .60383 Mtetra
.734 .702 .821 r
.57475 .60383 .57994 .6116 .58984 .60661 .58465 .59769 Mtetra
.743 .682 .792 r
.58465 .59769 .58984 .60661 .59973 .60033 .59454 .59042 Mtetra
.739 .663 .776 r
.59454 .59042 .59973 .60033 .60963 .59351 .60444 .58284 Mtetra
.719 .644 .773 r
.60444 .58284 .60963 .59351 .61956 .5873 .61436 .57611 Mtetra
.688 .622 .777 r
.61436 .57611 .61956 .5873 .62954 .58243 .62435 .57097 Mtetra
.642 .597 .788 r
.62435 .57097 .62954 .58243 .63962 .57949 .63443 .56801 Mtetra
.589 .569 .799 r
.63443 .56801 .63962 .57949 .6498 .57848 .64463 .56722 Mtetra
.542 .548 .81 r
.64463 .56722 .6498 .57848 .66009 .57883 .65494 .56804 Mtetra
.509 .539 .823 r
.65494 .56804 .66009 .57883 .67046 .57981 .66534 .56974 Mtetra
.513 .556 .837 r
.66534 .56974 .67046 .57981 .68086 .58025 .6758 .57113 Mtetra
.546 .596 .855 r
.6758 .57113 .68086 .58025 .69127 .57941 .68626 .5714 Mtetra
.617 .658 .868 r
.68626 .5714 .69127 .57941 .70161 .57648 .69668 .56955 Mtetra
.69 .719 .871 r
.69668 .56955 .70161 .57648 .71188 .57139 .70703 .56541 Mtetra
.756 .769 .863 r
.70703 .56541 .71188 .57139 .72205 .56434 .71727 .55901 Mtetra
.799 .8 .852 r
.71727 .55901 .72205 .56434 .73216 .55594 .72743 .55095 Mtetra
.817 .815 .848 r
.72743 .55095 .73216 .55594 .74225 .54709 .73756 .54219 Mtetra
.818 .819 .85 r
.73756 .54219 .74225 .54709 .75235 .53846 .74769 .53345 Mtetra
.799 .815 .864 r
.74769 .53345 .75235 .53846 .76252 .5308 .75789 .52562 Mtetra
.77 .804 .88 r
.75789 .52562 .76252 .5308 .77279 .52436 .76818 .51895 Mtetra
.728 .787 .899 r
.76818 .51895 .77279 .52436 .7832 .51936 .77861 .51378 Mtetra
.683 .767 .915 r
.77861 .51378 .7832 .51936 .79373 .51564 .78916 .50992 Mtetra
.64 .746 .926 r
.78916 .50992 .79373 .51564 .80439 .51299 .79984 .50719 Mtetra
.605 .73 .933 r
.79984 .50719 .80439 .51299 .81516 .51111 .81064 .50528 Mtetra
.584 .72 .937 r
.81064 .50528 .81516 .51111 .82602 .50965 .82152 .50381 Mtetra
.573 .715 .939 r
.82152 .50381 .82602 .50965 .83694 .5084 .83248 .50257 Mtetra
.576 .717 .939 r
.83248 .50257 .83694 .5084 .84792 .50709 .84348 .50126 Mtetra
.583 .722 .939 r
.84348 .50126 .84792 .50709 .85893 .50562 .85452 .49978 Mtetra
.596 .728 .937 r
.85452 .49978 .85893 .50562 .86997 .50385 .86559 .49801 Mtetra
.608 .734 .934 r
.86559 .49801 .86997 .50385 .88103 .50181 .87668 .49594 Mtetra
.621 .74 .932 r
.87668 .49594 .88103 .50181 .8921 .49945 .88778 .49356 Mtetra
.632 .744 .929 r
.88778 .49356 .8921 .49945 .9032 .49685 .8989 .49093 Mtetra
.64 .747 .926 r
.8989 .49093 .9032 .49685 .91431 .49403 .91005 .48806 Mtetra
.646 .749 .924 r
.91005 .48806 .91431 .49403 .92545 .49103 .92122 .48503 Mtetra
.65 .75 .923 r
.92122 .48503 .92545 .49103 .93663 .48793 .93242 .48189 Mtetra
.652 .751 .922 r
.93242 .48189 .93663 .48793 .94784 .48476 .94366 .47868 Mtetra
.658 .752 .919 r
.34122 .64908 .34689 .65403 .35601 .65126 .35036 .64632 Mtetra
.66 .754 .919 r
.35036 .64632 .35601 .65126 .36516 .64844 .35952 .64351 Mtetra
.664 .756 .918 r
.35952 .64351 .36516 .64844 .37434 .64551 .36872 .6406 Mtetra
.671 .758 .916 r
.36872 .6406 .37434 .64551 .38356 .64243 .37796 .63752 Mtetra
.679 .761 .913 r
.37796 .63752 .38356 .64243 .39281 .63913 .38724 .63423 Mtetra
.688 .764 .91 r
.38724 .63423 .39281 .63913 .40211 .63558 .39655 .63069 Mtetra
.699 .767 .905 r
.39655 .63069 .40211 .63558 .41144 .63173 .40591 .62683 Mtetra
.709 .769 .9 r
.40591 .62683 .41144 .63173 .4208 .6276 .41529 .62269 Mtetra
.718 .771 .894 r
.41529 .62269 .4208 .6276 .4302 .62318 .42472 .61824 Mtetra
.723 .772 .892 r
.42472 .61824 .4302 .62318 .43963 .61859 .43416 .61362 Mtetra
.724 .772 .89 r
.43416 .61362 .43963 .61859 .44908 .61394 .44364 .60894 Mtetra
.717 .77 .894 r
.44364 .60894 .44908 .61394 .45854 .60949 .45313 .60448 Mtetra
.702 .768 .903 r
.45313 .60448 .45854 .60949 .46803 .60548 .46264 .60049 Mtetra
.67 .762 .919 r
.46264 .60049 .46803 .60548 .47753 .60225 .47216 .59732 Mtetra
.616 .749 .941 r
.47216 .59732 .47753 .60225 .48705 .60012 .4817 .59531 Mtetra
.535 .726 .962 r
.4817 .59531 .48705 .60012 .49659 .59929 .49126 .59462 Mtetra
.411 .679 .972 r
.49126 .59462 .49659 .59929 .50617 .59991 .50086 .59541 Mtetra
.293 .626 .961 r
.50086 .59541 .50617 .59991 .5158 .6017 .5105 .59726 Mtetra
.205 .579 .942 r
.5105 .59726 .5158 .6017 .52549 .60439 .52021 .59985 Mtetra
.244 .597 .95 r
.52021 .59985 .52549 .60439 .53525 .60712 .52999 .60219 Mtetra
.376 .652 .964 r
.52999 .60219 .53525 .60712 .54507 .60918 .53982 .60352 Mtetra
.547 .7 .94 r
.53982 .60352 .54507 .60918 .55494 .60964 .5497 .60288 Mtetra
.664 .706 .879 r
.5497 .60288 .55494 .60964 .56484 .60787 .5596 .59973 Mtetra
.716 .688 .823 r
.5596 .59973 .56484 .60787 .57475 .60383 .56951 .59431 Mtetra
.739 .67 .783 r
.56951 .59431 .57475 .60383 .58465 .59769 .5794 .58696 Mtetra
.739 .651 .762 r
.5794 .58696 .58465 .59769 .59454 .59042 .58929 .57885 Mtetra
.73 .636 .754 r
.58929 .57885 .59454 .59042 .60444 .58284 .59919 .57084 Mtetra
.711 .623 .756 r
.59919 .57084 .60444 .58284 .61436 .57611 .60913 .56391 Mtetra
.682 .606 .765 r
.60913 .56391 .61436 .57611 .62435 .57097 .61912 .55872 Mtetra
.64 .585 .776 r
.61912 .55872 .62435 .57097 .63443 .56801 .62921 .55573 Mtetra
.589 .558 .787 r
.62921 .55573 .63443 .56801 .64463 .56722 .6394 .55495 Mtetra
.541 .532 .794 r
.6394 .55495 .64463 .56722 .65494 .56804 .64972 .55591 Mtetra
.506 .515 .8 r
.64972 .55591 .65494 .56804 .66534 .56974 .66013 .55798 Mtetra
.499 .518 .807 r
.66013 .55798 .66534 .56974 .6758 .57113 .67063 .56018 Mtetra
.518 .543 .821 r
.67063 .56018 .6758 .57113 .68626 .5714 .68116 .56162 Mtetra
.575 .597 .837 r
.68116 .56162 .68626 .5714 .69668 .56955 .69165 .56113 Mtetra
.645 .661 .851 r
.69165 .56113 .69668 .56955 .70703 .56541 .70209 .55834 Mtetra
.721 .727 .855 r
.70209 .55834 .70703 .56541 .71727 .55901 .71242 .55299 Mtetra
.777 .775 .851 r
.71242 .55299 .71727 .55901 .72743 .55095 .72266 .54565 Mtetra
.806 .804 .849 r
.72266 .54565 .72743 .55095 .73756 .54219 .73284 .53724 Mtetra
.816 .819 .852 r
.73284 .53724 .73756 .54219 .74769 .53345 .74302 .52858 Mtetra
.803 .821 .866 r
.74302 .52858 .74769 .53345 .75789 .52562 .75325 .52063 Mtetra
.777 .814 .882 r
.75325 .52063 .75789 .52562 .76818 .51895 .76356 .51377 Mtetra
.734 .798 .903 r
.76356 .51377 .76818 .51895 .77861 .51378 .774 .5084 Mtetra
.688 .778 .919 r
.774 .5084 .77861 .51378 .78916 .50992 .78457 .50438 Mtetra
.642 .756 .931 r
.78457 .50438 .78916 .50992 .79984 .50719 .79528 .50155 Mtetra
.604 .737 .939 r
.79528 .50155 .79984 .50719 .81064 .50528 .8061 .49958 Mtetra
.582 .726 .942 r
.8061 .49958 .81064 .50528 .82152 .50381 .81701 .49809 Mtetra
.57 .72 .944 r
.81701 .49809 .82152 .50381 .83248 .50257 .82799 .49683 Mtetra
.573 .722 .943 r
.82799 .49683 .83248 .50257 .84348 .50126 .83902 .49551 Mtetra
.58 .726 .942 r
.83902 .49551 .84348 .50126 .85452 .49978 .8501 .49402 Mtetra
.595 .732 .94 r
.8501 .49402 .85452 .49978 .86559 .49801 .86119 .49222 Mtetra
.608 .738 .937 r
.86119 .49222 .86559 .49801 .87668 .49594 .87231 .49012 Mtetra
.622 .743 .934 r
.87231 .49012 .87668 .49594 .88778 .49356 .88344 .4877 Mtetra
.632 .747 .931 r
.88344 .4877 .88778 .49356 .8989 .49093 .89459 .48501 Mtetra
.641 .75 .928 r
.89459 .48501 .8989 .49093 .91005 .48806 .90576 .4821 Mtetra
.647 .751 .925 r
.90576 .4821 .91005 .48806 .92122 .48503 .91695 .47901 Mtetra
.651 .752 .923 r
.91695 .47901 .92122 .48503 .93242 .48189 .92818 .47582 Mtetra
.653 .751 .922 r
.92818 .47582 .93242 .48189 .94366 .47868 .93945 .47256 Mtetra
.657 .752 .92 r
.33552 .6441 .34122 .64908 .35036 .64632 .34467 .64136 Mtetra
.658 .754 .92 r
.34467 .64136 .35036 .64632 .35952 .64351 .35385 .63858 Mtetra
.662 .756 .92 r
.35385 .63858 .35952 .64351 .36872 .6406 .36307 .63569 Mtetra
.669 .759 .918 r
.36307 .63569 .36872 .6406 .37796 .63752 .37233 .63264 Mtetra
.677 .763 .916 r
.37233 .63264 .37796 .63752 .38724 .63423 .38162 .62938 Mtetra
.687 .767 .913 r
.38162 .62938 .38724 .63423 .39655 .63069 .39096 .62586 Mtetra
.698 .771 .908 r
.39096 .62586 .39655 .63069 .40591 .62683 .40033 .62202 Mtetra
.708 .774 .903 r
.40033 .62202 .40591 .62683 .41529 .62269 .40974 .61788 Mtetra
.719 .776 .898 r
.40974 .61788 .41529 .62269 .42472 .61824 .41919 .6134 Mtetra
.724 .777 .895 r
.41919 .6134 .42472 .61824 .43416 .61362 .42866 .60876 Mtetra
.726 .777 .894 r
.42866 .60876 .43416 .61362 .44364 .60894 .43816 .60404 Mtetra
.718 .775 .898 r
.43816 .60404 .44364 .60894 .45313 .60448 .44768 .59956 Mtetra
.702 .772 .907 r
.44768 .59956 .45313 .60448 .46264 .60049 .45721 .59556 Mtetra
.667 .765 .923 r
.45721 .59556 .46264 .60049 .47216 .59732 .46675 .59244 Mtetra
.608 .75 .945 r
.46675 .59244 .47216 .59732 .4817 .59531 .47631 .59055 Mtetra
.52 .724 .966 r
.47631 .59055 .4817 .59531 .49126 .59462 .48589 .59002 Mtetra
.39 .673 .972 r
.48589 .59002 .49126 .59462 .50086 .59541 .4955 .59097 Mtetra
.28 .623 .96 r
.4955 .59097 .50086 .59541 .5105 .59726 .50517 .59287 Mtetra
.221 .591 .947 r
.50517 .59287 .5105 .59726 .52021 .59985 .51489 .59525 Mtetra
.308 .632 .963 r
.51489 .59525 .52021 .59985 .52999 .60219 .52468 .59701 Mtetra
.473 .689 .961 r
.52468 .59701 .52999 .60219 .53982 .60352 .53453 .59729 Mtetra
.625 .71 .907 r
.53453 .59729 .53982 .60352 .5497 .60288 .54442 .59517 Mtetra
.708 .696 .836 r
.54442 .59517 .5497 .60288 .5596 .59973 .55432 .59024 Mtetra
.734 .668 .786 r
.55432 .59024 .5596 .59973 .56951 .59431 .56422 .58322 Mtetra
.74 .647 .756 r
.56422 .58322 .56951 .59431 .5794 .58696 .57412 .57475 Mtetra
.732 .63 .745 r
.57412 .57475 .5794 .58696 .58929 .57885 .58402 .56625 Mtetra
.718 .619 .746 r
.58402 .56625 .58929 .57885 .59919 .57084 .59393 .55856 Mtetra
.702 .615 .757 r
.59393 .55856 .59919 .57084 .60913 .56391 .60389 .55214 Mtetra
.677 .61 .773 r
.60389 .55214 .60913 .56391 .61912 .55872 .6139 .54736 Mtetra
.643 .599 .79 r
.6139 .54736 .61912 .55872 .62921 .55573 .62399 .54434 Mtetra
.6 .577 .8 r
.62399 .54434 .62921 .55573 .6394 .55495 .63418 .5431 Mtetra
.555 .546 .8 r
.63418 .5431 .6394 .55495 .64972 .55591 .64447 .5435 Mtetra
.519 .518 .795 r
.64447 .5435 .64972 .55591 .66013 .55798 .65488 .5452 Mtetra
.495 .5 .791 r
.65488 .5452 .66013 .55798 .67063 .56018 .66538 .54773 Mtetra
.493 .505 .797 r
.66538 .54773 .67063 .56018 .68116 .56162 .67596 .55025 Mtetra
.532 .544 .813 r
.67596 .55025 .68116 .56162 .69165 .56113 .68653 .55132 Mtetra
.591 .606 .835 r
.68653 .55132 .69165 .56113 .70209 .55834 .69707 .5503 Mtetra
.677 .686 .851 r
.69707 .5503 .70209 .55834 .71242 .55299 .70751 .54641 Mtetra
.748 .752 .855 r
.70751 .54641 .71242 .55299 .72266 .54565 .71783 .54009 Mtetra
.792 .795 .854 r
.71783 .54009 .72266 .54565 .73284 .53724 .72809 .53224 Mtetra
.812 .818 .855 r
.72809 .53224 .73284 .53724 .74302 .52858 .73831 .52374 Mtetra
.804 .824 .866 r
.73831 .52374 .74302 .52858 .75325 .52063 .74857 .51571 Mtetra
.782 .819 .881 r
.74857 .51571 .75325 .52063 .76356 .51377 .75891 .50864 Mtetra
.74 .803 .903 r
.75891 .50864 .76356 .51377 .774 .5084 .76937 .50307 Mtetra
.693 .783 .92 r
.76937 .50307 .774 .5084 .78457 .50438 .77996 .49889 Mtetra
.644 .76 .933 r
.77996 .49889 .78457 .50438 .79528 .50155 .79069 .49597 Mtetra
.604 .741 .941 r
.79069 .49597 .79528 .50155 .8061 .49958 .80153 .49397 Mtetra
.58 .73 .946 r
.80153 .49397 .8061 .49958 .81701 .49809 .81247 .49246 Mtetra
.567 .724 .948 r
.81247 .49246 .81701 .49809 .82799 .49683 .82349 .4912 Mtetra
.57 .727 .948 r
.82349 .4912 .82799 .49683 .83902 .49551 .83455 .48987 Mtetra
.578 .731 .947 r
.83455 .48987 .83902 .49551 .8501 .49402 .84565 .48836 Mtetra
.594 .737 .944 r
.84565 .48836 .8501 .49402 .86119 .49222 .85677 .48652 Mtetra
.608 .743 .941 r
.85677 .48652 .86119 .49222 .87231 .49012 .86791 .48437 Mtetra
.623 .748 .936 r
.86791 .48437 .87231 .49012 .88344 .4877 .87907 .48188 Mtetra
.634 .751 .932 r
.87907 .48188 .88344 .4877 .89459 .48501 .89024 .47912 Mtetra
.643 .753 .929 r
.89024 .47912 .89459 .48501 .90576 .4821 .90144 .47613 Mtetra
.649 .754 .926 r
.90144 .47613 .90576 .4821 .91695 .47901 .91266 .47298 Mtetra
.653 .753 .923 r
.91266 .47298 .91695 .47901 .92818 .47582 .92392 .46971 Mtetra
.655 .753 .922 r
.92392 .46971 .92818 .47582 .93945 .47256 .93521 .46639 Mtetra
.654 .751 .921 r
.32977 .63908 .33552 .6441 .34467 .64136 .33894 .63639 Mtetra
.656 .753 .922 r
.33894 .63639 .34467 .64136 .35385 .63858 .34814 .63364 Mtetra
.66 .757 .922 r
.34814 .63364 .35385 .63858 .36307 .63569 .35738 .6308 Mtetra
.666 .761 .921 r
.35738 .6308 .36307 .63569 .37233 .63264 .36665 .6278 Mtetra
.674 .765 .919 r
.36665 .6278 .37233 .63264 .38162 .62938 .37596 .6246 Mtetra
.684 .77 .916 r
.37596 .6246 .38162 .62938 .39096 .62586 .38532 .62112 Mtetra
.697 .775 .912 r
.38532 .62112 .39096 .62586 .40033 .62202 .39472 .61731 Mtetra
.708 .779 .907 r
.39472 .61731 .40033 .62202 .40974 .61788 .40415 .61318 Mtetra
.719 .782 .902 r
.40415 .61318 .40974 .61788 .41919 .6134 .41362 .60869 Mtetra
.725 .783 .898 r
.41362 .60869 .41919 .6134 .42866 .60876 .42312 .604 Mtetra
.728 .783 .896 r
.42312 .604 .42866 .60876 .43816 .60404 .43265 .59922 Mtetra
.72 .78 .899 r
.43265 .59922 .43816 .60404 .44768 .59956 .44219 .59466 Mtetra
.703 .775 .907 r
.44219 .59466 .44768 .59956 .45721 .59556 .45174 .5906 Mtetra
.666 .765 .924 r
.45174 .5906 .45721 .59556 .46675 .59244 .46131 .58749 Mtetra
.603 .747 .946 r
.46131 .58749 .46675 .59244 .47631 .59055 .47088 .58569 Mtetra
.509 .717 .966 r
.47088 .58569 .47631 .59055 .48589 .59002 .48048 .58533 Mtetra
.371 .661 .97 r
.48048 .58533 .48589 .59002 .4955 .59097 .49011 .58649 Mtetra
.273 .619 .959 r
.49011 .58649 .4955 .59097 .50517 .59287 .49979 .58845 Mtetra
.247 .607 .954 r
.49979 .58845 .50517 .59287 .51489 .59525 .50954 .59059 Mtetra
.383 .67 .972 r
.50954 .59059 .51489 .59525 .52468 .59701 .51934 .59161 Mtetra
.566 .72 .945 r
.51934 .59161 .52468 .59701 .53453 .59729 .52921 .59053 Mtetra
.69 .716 .87 r
.52921 .59053 .53453 .59729 .54442 .59517 .53911 .58654 Mtetra
.744 .688 .798 r
.53911 .58654 .54442 .59517 .55432 .59024 .54901 .5794 Mtetra
.747 .654 .757 r
.54901 .5794 .55432 .59024 .56422 .58322 .55891 .57062 Mtetra
.739 .629 .737 r
.55891 .57062 .56422 .58322 .57412 .57475 .56881 .56127 Mtetra
.718 .61 .735 r
.56881 .56127 .57412 .57475 .58402 .56625 .57872 .55308 Mtetra
.693 .601 .748 r
.57872 .55308 .58402 .56625 .59393 .55856 .58867 .5468 Mtetra
.679 .611 .773 r
.58867 .5468 .59393 .55856 .60389 .55214 .59867 .5419 Mtetra
.663 .628 .804 r
.59867 .5419 .60389 .55214 .6139 .54736 .60872 .53818 Mtetra
.651 .643 .829 r
.60872 .53818 .6139 .54736 .62399 .54434 .61883 .53514 Mtetra
.632 .635 .835 r
.61883 .53514 .62399 .54434 .63418 .5431 .62899 .53278 Mtetra
.596 .596 .821 r
.62899 .53278 .63418 .5431 .64447 .5435 .63924 .53162 Mtetra
.559 .549 .8 r
.63924 .53162 .64447 .5435 .65488 .5452 .64958 .53184 Mtetra
.51 .501 .782 r
.64958 .53184 .65488 .5452 .66538 .54773 .66007 .534 Mtetra
.477 .477 .779 r
.66007 .534 .66538 .54773 .67596 .55025 .67067 .53736 Mtetra
.487 .495 .792 r
.67067 .53736 .67596 .55025 .68653 .55132 .68133 .54016 Mtetra
.526 .546 .819 r
.68133 .54016 .68653 .55132 .69707 .5503 .69198 .54131 Mtetra
.62 .639 .848 r
.69198 .54131 .69707 .5503 .70751 .54641 .70254 .53929 Mtetra
.711 .725 .862 r
.70254 .53929 .70751 .54641 .71783 .54009 .71297 .53431 Mtetra
.774 .785 .862 r
.71297 .53431 .71783 .54009 .72809 .53224 .7233 .52717 Mtetra
.807 .816 .858 r
.7233 .52717 .72809 .53224 .73831 .52374 .73357 .51887 Mtetra
.806 .824 .865 r
.73357 .51887 .73831 .52374 .74857 .51571 .74387 .51075 Mtetra
.788 .819 .877 r
.74387 .51075 .74857 .51571 .75891 .50864 .75422 .50342 Mtetra
.745 .802 .898 r
.75422 .50342 .75891 .50864 .76937 .50307 .7647 .49764 Mtetra
.697 .782 .917 r
.7647 .49764 .76937 .50307 .77996 .49889 .77531 .49333 Mtetra
.645 .759 .932 r
.77531 .49333 .77996 .49889 .79069 .49597 .78607 .49036 Mtetra
.602 .741 .942 r
.78607 .49036 .79069 .49597 .80153 .49397 .79695 .48837 Mtetra
.576 .731 .948 r
.79695 .48837 .80153 .49397 .81247 .49246 .80792 .4869 Mtetra
.563 .727 .951 r
.80792 .4869 .81247 .49246 .82349 .4912 .81896 .48567 Mtetra
.567 .731 .952 r
.81896 .48567 .82349 .4912 .83455 .48987 .83006 .48434 Mtetra
.576 .736 .951 r
.83006 .48434 .83455 .48987 .84565 .48836 .84119 .48281 Mtetra
.593 .743 .948 r
.84119 .48281 .84565 .48836 .85677 .48652 .85234 .48092 Mtetra
.609 .749 .944 r
.85234 .48092 .85677 .48652 .86791 .48437 .8635 .47869 Mtetra
.624 .753 .939 r
.8635 .47869 .86791 .48437 .87907 .48188 .87468 .47611 Mtetra
.636 .756 .934 r
.87468 .47611 .87907 .48188 .89024 .47912 .88588 .47326 Mtetra
.645 .757 .93 r
.88588 .47326 .89024 .47912 .90144 .47613 .8971 .47018 Mtetra
.651 .756 .926 r
.8971 .47018 .90144 .47613 .91266 .47298 .90835 .46693 Mtetra
.655 .756 .924 r
.90835 .46693 .91266 .47298 .92392 .46971 .91963 .46358 Mtetra
.657 .754 .921 r
.91963 .46358 .92392 .46971 .93521 .46639 .93095 .46018 Mtetra
.652 .75 .922 r
.32399 .63404 .32977 .63908 .33894 .63639 .33318 .63138 Mtetra
.653 .753 .923 r
.33318 .63138 .33894 .63639 .34814 .63364 .34239 .62869 Mtetra
.656 .756 .924 r
.34239 .62869 .34814 .63364 .35738 .6308 .35164 .62591 Mtetra
.662 .761 .923 r
.35164 .62591 .35738 .6308 .36665 .6278 .36094 .62298 Mtetra
.67 .766 .922 r
.36094 .62298 .36665 .6278 .37596 .6246 .37027 .61986 Mtetra
.68 .772 .92 r
.37027 .61986 .37596 .6246 .38532 .62112 .37964 .61646 Mtetra
.693 .779 .917 r
.37964 .61646 .38532 .62112 .39472 .61731 .38906 .61272 Mtetra
.706 .784 .913 r
.38906 .61272 .39472 .61731 .40415 .61318 .39851 .60863 Mtetra
.719 .789 .907 r
.39851 .60863 .40415 .61318 .41362 .60869 .40801 .60415 Mtetra
.727 .791 .903 r
.40801 .60415 .41362 .60869 .42312 .604 .41753 .59942 Mtetra
.731 .791 .9 r
.41753 .59942 .42312 .604 .43265 .59922 .42709 .59454 Mtetra
.724 .787 .902 r
.42709 .59454 .43265 .59922 .44219 .59466 .43666 .58986 Mtetra
.708 .78 .908 r
.43666 .58986 .44219 .59466 .45174 .5906 .44624 .58564 Mtetra
.67 .767 .923 r
.44624 .58564 .45174 .5906 .46131 .58749 .45583 .58242 Mtetra
.603 .743 .943 r
.45583 .58242 .46131 .58749 .47088 .58569 .46543 .58062 Mtetra
.506 .707 .961 r
.46543 .58062 .47088 .58569 .48048 .58533 .47504 .58037 Mtetra
.364 .646 .964 r
.47504 .58037 .48048 .58533 .49011 .58649 .48469 .58175 Mtetra
.277 .61 .956 r
.48469 .58175 .49011 .58649 .49979 .58845 .49438 .58383 Mtetra
.275 .616 .958 r
.49438 .58383 .49979 .58845 .50954 .59059 .50414 .58584 Mtetra
.446 .698 .973 r
.50414 .58584 .50954 .59059 .51934 .59161 .51397 .58617 Mtetra
.636 .745 .927 r
.51397 .58617 .51934 .59161 .52921 .59053 .52386 .58367 Mtetra
.741 .729 .841 r
.52386 .58367 .52921 .59053 .53911 .58654 .53377 .5776 Mtetra
.777 .694 .772 r
.53377 .5776 .53911 .58654 .54901 .5794 .54368 .56795 Mtetra
.764 .653 .739 r
.54368 .56795 .54901 .5794 .55891 .57062 .55358 .55732 Mtetra
.74 .623 .728 r
.55358 .55732 .55891 .57062 .56881 .56127 .56348 .54738 Mtetra
.698 .596 .738 r
.56348 .54738 .56881 .56127 .57872 .55308 .57341 .54044 Mtetra
.645 .583 .77 r
.57341 .54044 .57872 .55308 .58867 .5468 .58342 .53706 Mtetra
.62 .618 .827 r
.58342 .53706 .58867 .5468 .59867 .5419 .5935 .53508 Mtetra
.607 .689 .9 r
.5935 .53508 .59867 .5419 .60872 .53818 .60362 .53337 Mtetra
.654 .781 .941 r
.60362 .53337 .60872 .53818 .61883 .53514 .61375 .53031 Mtetra
.707 .795 .919 r
.61375 .53031 .61883 .53514 .62899 .53278 .62388 .5259 Mtetra
.691 .72 .872 r
.62388 .5259 .62899 .53278 .63924 .53162 .63405 .52176 Mtetra
.64 .627 .821 r
.63405 .52176 .63924 .53162 .64958 .53184 .6443 .51901 Mtetra
.543 .528 .788 r
.6443 .51901 .64958 .53184 .66007 .534 .65473 .51986 Mtetra
.462 .463 .773 r
.65473 .51986 .66007 .534 .67067 .53736 .66535 .52375 Mtetra
.433 .453 .781 r
.66535 .52375 .67067 .53736 .68133 .54016 .67608 .52837 Mtetra
.443 .488 .812 r
.67608 .52837 .68133 .54016 .69198 .54131 .68686 .53202 Mtetra
.55 .599 .855 r
.68686 .53202 .69198 .54131 .70254 .53929 .69753 .53206 Mtetra
.67 .709 .877 r
.69753 .53206 .70254 .53929 .71297 .53431 .70807 .52848 Mtetra
.758 .782 .872 r
.70807 .52848 .71297 .53431 .7233 .52717 .71847 .52201 Mtetra
.804 .813 .859 r
.71847 .52201 .7233 .52717 .73357 .51887 .72879 .5138 Mtetra
.807 .818 .86 r
.72879 .5138 .73357 .51887 .74387 .51075 .73911 .50551 Mtetra
.79 .811 .869 r
.73911 .50551 .74387 .51075 .75422 .50342 .74948 .49791 Mtetra
.747 .794 .89 r
.74948 .49791 .75422 .50342 .7647 .49764 .75998 .49198 Mtetra
.697 .775 .911 r
.75998 .49198 .7647 .49764 .77531 .49333 .77063 .48763 Mtetra
.642 .754 .93 r
.77063 .48763 .77531 .49333 .78607 .49036 .78142 .48474 Mtetra
.595 .739 .944 r
.78142 .48474 .78607 .49036 .79695 .48837 .79234 .48287 Mtetra
.568 .733 .952 r
.79234 .48287 .79695 .48837 .80792 .4869 .80334 .48149 Mtetra
.555 .731 .957 r
.80334 .48149 .80792 .4869 .81896 .48567 .81443 .48031 Mtetra
.562 .737 .958 r
.81443 .48031 .81896 .48567 .83006 .48434 .82555 .47898 Mtetra
.574 .744 .957 r
.82555 .47898 .83006 .48434 .84119 .48281 .83671 .47741 Mtetra
.594 .751 .953 r
.83671 .47741 .84119 .48281 .85234 .48092 .84788 .47543 Mtetra
.611 .756 .948 r
.84788 .47543 .85234 .48092 .8635 .47869 .85907 .47309 Mtetra
.628 .76 .941 r
.85907 .47309 .8635 .47869 .87468 .47611 .87027 .47039 Mtetra
.64 .761 .936 r
.87027 .47039 .87468 .47611 .88588 .47326 .88149 .4674 Mtetra
.649 .76 .931 r
.88149 .4674 .88588 .47326 .8971 .47018 .89273 .46421 Mtetra
.654 .759 .926 r
.89273 .46421 .8971 .47018 .90835 .46693 .904 .46086 Mtetra
.658 .757 .923 r
.904 .46086 .90835 .46693 .91963 .46358 .91531 .45741 Mtetra
.659 .755 .921 r
.91531 .45741 .91963 .46358 .93095 .46018 .92665 .45393 Mtetra
.649 .75 .923 r
.31818 .62896 .32399 .63404 .33318 .63138 .32738 .62635 Mtetra
.649 .752 .925 r
.32738 .62635 .33318 .63138 .34239 .62869 .33661 .62371 Mtetra
.652 .756 .926 r
.33661 .62371 .34239 .62869 .35164 .62591 .34587 .62101 Mtetra
.657 .76 .926 r
.34587 .62101 .35164 .62591 .36094 .62298 .35518 .61817 Mtetra
.664 .766 .926 r
.35518 .61817 .36094 .62298 .37027 .61986 .36453 .61515 Mtetra
.675 .774 .925 r
.36453 .61515 .37027 .61986 .37964 .61646 .37392 .61188 Mtetra
.688 .782 .922 r
.37392 .61188 .37964 .61646 .38906 .61272 .38335 .60825 Mtetra
.702 .79 .919 r
.38335 .60825 .38906 .61272 .39851 .60863 .39283 .60425 Mtetra
.718 .797 .913 r
.39283 .60425 .39851 .60863 .40801 .60415 .40235 .59982 Mtetra
.728 .801 .909 r
.40235 .59982 .40801 .60415 .41753 .59942 .4119 .59507 Mtetra
.736 .802 .905 r
.4119 .59507 .41753 .59942 .42709 .59454 .42148 .59008 Mtetra
.731 .797 .904 r
.42148 .59008 .42709 .59454 .43666 .58986 .43109 .58518 Mtetra
.718 .788 .907 r
.43109 .58518 .43666 .58986 .44624 .58564 .4407 .58067 Mtetra
.68 .77 .919 r
.4407 .58067 .44624 .58564 .45583 .58242 .45032 .57717 Mtetra
.613 .741 .937 r
.45032 .57717 .45583 .58242 .46543 .58062 .45994 .5752 Mtetra
.514 .698 .952 r
.45994 .5752 .46543 .58062 .47504 .58037 .46957 .57494 Mtetra
.367 .629 .954 r
.46957 .57494 .47504 .58037 .48469 .58175 .47923 .57655 Mtetra
.283 .594 .948 r
.47923 .57655 .48469 .58175 .49438 .58383 .48894 .57886 Mtetra
.289 .609 .954 r
.48894 .57886 .49438 .58383 .50414 .58584 .49871 .58096 Mtetra
.487 .712 .97 r
.49871 .58096 .50414 .58584 .51397 .58617 .50856 .58082 Mtetra
.687 .764 .91 r
.50856 .58082 .51397 .58617 .52386 .58367 .51847 .57704 Mtetra
.783 .745 .818 r
.51847 .57704 .52386 .58367 .53377 .5776 .52841 .56882 Mtetra
.809 .706 .751 r
.52841 .56882 .53377 .5776 .54368 .56795 .53833 .55646 Mtetra
.783 .66 .728 r
.53833 .55646 .54368 .56795 .55358 .55732 .54824 .54395 Mtetra
.742 .623 .727 r
.54824 .54395 .55358 .55732 .56348 .54738 .55814 .5338 Mtetra
.663 .581 .753 r
.55814 .5338 .56348 .54738 .57341 .54044 .56812 .52922 Mtetra
.517 .537 .816 r
.56812 .52922 .57341 .54044 .58342 .53706 .57821 .53057 Mtetra
.338 .57 .925 r
.57821 .53057 .58342 .53706 .5935 .53508 .58839 .53327 Mtetra
.039 .581 .846 r
.58839 .53327 .5935 .53508 .60362 .53337 .59862 .53478 Mtetra
.218 .731 .693 r
.59862 .53478 .60362 .53337 .61375 .53031 .6088 .5317 Mtetra
.692 .98 .823 r
.6088 .5317 .61375 .53031 .62388 .5259 .61889 .52404 Mtetra
.846 .927 .884 r
.61889 .52404 .62388 .5259 .63405 .52176 .62895 .51516 Mtetra
.774 .753 .835 r
.62895 .51516 .63405 .52176 .6443 .51901 .63906 .50761 Mtetra
.606 .584 .802 r
.63906 .50761 .6443 .51901 .65473 .51986 .6494 .50602 Mtetra
.452 .462 .778 r
.6494 .50602 .65473 .51986 .66535 .52375 .66001 .51007 Mtetra
.365 .411 .776 r
.66001 .51007 .66535 .52375 .67608 .52837 .67082 .51653 Mtetra
.327 .419 .803 r
.67082 .51653 .67608 .52837 .68686 .53202 .68172 .52289 Mtetra
.459 .556 .867 r
.68172 .52289 .68686 .53202 .69753 .53206 .69251 .52506 Mtetra
.626 .7 .898 r
.69251 .52506 .69753 .53206 .70807 .52848 .70314 .52274 Mtetra
.747 .783 .882 r
.70314 .52274 .70807 .52848 .71847 .52201 .7136 .51671 Mtetra
.805 .81 .856 r
.7136 .51671 .71847 .52201 .72879 .5138 .72395 .50837 Mtetra
.808 .807 .85 r
.72395 .50837 .72879 .5138 .73911 .50551 .73429 .4998 Mtetra
.791 .796 .857 r
.73429 .4998 .73911 .50551 .74948 .49791 .74468 .49194 Mtetra
.744 .778 .88 r
.74468 .49194 .74948 .49791 .75998 .49198 .75521 .48596 Mtetra
.691 .761 .905 r
.75521 .48596 .75998 .49198 .77063 .48763 .7659 .48175 Mtetra
.632 .745 .929 r
.7659 .48175 .77063 .48763 .78142 .48474 .77674 .47909 Mtetra
.581 .734 .947 r
.77674 .47909 .78142 .48474 .79234 .48287 .7877 .47749 Mtetra
.555 .734 .959 r
.7877 .47749 .79234 .48287 .80334 .48149 .79876 .47628 Mtetra
.544 .737 .965 r
.79876 .47628 .80334 .48149 .81443 .48031 .80988 .47519 Mtetra
.556 .746 .966 r
.80988 .47519 .81443 .48031 .82555 .47898 .82104 .47384 Mtetra
.572 .754 .964 r
.82104 .47384 .82555 .47898 .83671 .47741 .83222 .47218 Mtetra
.596 .761 .958 r
.83222 .47218 .83671 .47741 .84788 .47543 .84341 .47006 Mtetra
.616 .765 .951 r
.84341 .47006 .84788 .47543 .85907 .47309 .85462 .46756 Mtetra
.633 .766 .943 r
.85462 .46756 .85907 .47309 .87027 .47039 .86584 .46469 Mtetra
.645 .765 .936 r
.86584 .46469 .87027 .47039 .88149 .4674 .87707 .46155 Mtetra
.653 .763 .93 r
.87707 .46155 .88149 .4674 .89273 .46421 .88833 .45822 Mtetra
.658 .761 .926 r
.88833 .45822 .89273 .46421 .904 .46086 .89963 .45475 Mtetra
.661 .759 .923 r
.89963 .45475 .904 .46086 .91531 .45741 .91095 .4512 Mtetra
.661 .756 .92 r
.91095 .4512 .91531 .45741 .92665 .45393 .92232 .44763 Mtetra
.647 .749 .924 r
.31232 .62385 .31818 .62896 .32738 .62635 .32154 .62127 Mtetra
.647 .751 .925 r
.32154 .62127 .32738 .62635 .33661 .62371 .33079 .61868 Mtetra
.648 .754 .926 r
.33079 .61868 .33661 .62371 .34587 .62101 .34007 .61603 Mtetra
.652 .758 .927 r
.34007 .61603 .34587 .62101 .35518 .61817 .34939 .61328 Mtetra
.658 .763 .928 r
.34939 .61328 .35518 .61817 .36453 .61515 .35875 .6104 Mtetra
.667 .771 .928 r
.35875 .6104 .36453 .61515 .37392 .61188 .36816 .60727 Mtetra
.68 .781 .926 r
.36816 .60727 .37392 .61188 .38335 .60825 .3776 .60382 Mtetra
.695 .791 .925 r
.3776 .60382 .38335 .60825 .39283 .60425 .3871 .59999 Mtetra
.712 .802 .921 r
.3871 .59999 .39283 .60425 .40235 .59982 .39664 .5957 Mtetra
.726 .81 .917 r
.39664 .5957 .40235 .59982 .4119 .59507 .40622 .59102 Mtetra
.738 .815 .912 r
.40622 .59102 .4119 .59507 .42148 .59008 .41583 .58596 Mtetra
.739 .814 .91 r
.41583 .58596 .42148 .59008 .43109 .58518 .42547 .58085 Mtetra
.732 .805 .909 r
.42547 .58085 .43109 .58518 .4407 .58067 .43512 .57593 Mtetra
.698 .784 .918 r
.43512 .57593 .4407 .58067 .45032 .57717 .44477 .57196 Mtetra
.634 .75 .932 r
.44477 .57196 .45032 .57717 .45994 .5752 .45442 .56953 Mtetra
.536 .698 .944 r
.45442 .56953 .45994 .5752 .46957 .57494 .46407 .569 Mtetra
.388 .619 .944 r
.46407 .569 .46957 .57494 .47923 .57655 .47374 .57062 Mtetra
.304 .576 .936 r
.47374 .57062 .47923 .57655 .48894 .57886 .48346 .57319 Mtetra
.295 .582 .941 r
.48346 .57319 .48894 .57886 .49871 .58096 .49324 .57568 Mtetra
.497 .7 .96 r
.49324 .57568 .49871 .58096 .50856 .58082 .50311 .57556 Mtetra
.709 .774 .903 r
.50311 .57556 .50856 .58082 .51847 .57704 .51305 .57111 Mtetra
.817 .769 .808 r
.51305 .57111 .51847 .57704 .52841 .56882 .52302 .56122 Mtetra
.845 .733 .74 r
.52302 .56122 .52841 .56882 .53833 .55646 .53297 .54632 Mtetra
.813 .688 .726 r
.53297 .54632 .53833 .55646 .54824 .54395 .54289 .53197 Mtetra
.756 .644 .738 r
.54289 .53197 .54824 .54395 .55814 .5338 .55281 .52165 Mtetra
.604 .569 .788 r
.55281 .52165 .55814 .5338 .56812 .52922 .56283 .52013 Mtetra
.107 .342 .811 r
.56283 .52013 .56812 .52922 .57821 .53057 .57302 .52761 Mtetra
.589 .034 0 r
.57302 .52761 .57821 .53057 .58839 .53327 .58333 .5365 Mtetra
.632 .133 .049 r
.58333 .5365 .58839 .53327 .59862 .53478 .59369 .54239 Mtetra
.305 0 .048 r
.59369 .54239 .59862 .53478 .6088 .5317 .60394 .53931 Mtetra
0 0 0 r
.60394 .53931 .6088 .5317 .61889 .52404 .61398 .52723 Mtetra
.89 .978 .684 r
.61398 .52723 .61889 .52404 .62895 .51516 .62392 .5121 Mtetra
.904 .861 .788 r
.62392 .5121 .62895 .51516 .63906 .50761 .63386 .49835 Mtetra
.69 .663 .819 r
.63386 .49835 .63906 .50761 .6494 .50602 .64411 .49364 Mtetra
.427 .469 .801 r
.64411 .49364 .6494 .50602 .66001 .51007 .65472 .4978 Mtetra
.244 .358 .782 r
.65472 .4978 .66001 .51007 .67082 .51653 .6656 .50607 Mtetra
.133 .325 .79 r
.6656 .50607 .67082 .51653 .68172 .52289 .67661 .51494 Mtetra
.331 .519 .89 r
.67661 .51494 .68172 .52289 .69251 .52506 .6875 .51877 Mtetra
.595 .712 .926 r
.6875 .51877 .69251 .52506 .70314 .52274 .69818 .51708 Mtetra
.75 .788 .884 r
.69818 .51708 .70314 .52274 .7136 .51671 .70868 .51099 Mtetra
.808 .798 .843 r
.70868 .51099 .7136 .51671 .72395 .50837 .71903 .50221 Mtetra
.804 .785 .835 r
.71903 .50221 .72395 .50837 .73429 .4998 .72939 .49334 Mtetra
.783 .773 .843 r
.72939 .49334 .73429 .4998 .74468 .49194 .73981 .48541 Mtetra
.733 .758 .873 r
.73981 .48541 .74468 .49194 .75521 .48596 .75039 .47968 Mtetra
.676 .748 .905 r
.75039 .47968 .75521 .48596 .7659 .48175 .76114 .47589 Mtetra
.611 .739 .936 r
.76114 .47589 .7659 .48175 .77674 .47909 .77204 .47369 Mtetra
.555 .733 .958 r
.77204 .47369 .77674 .47909 .7877 .47749 .78307 .47246 Mtetra
.534 .741 .97 r
.78307 .47246 .7877 .47749 .79876 .47628 .79417 .47144 Mtetra
.531 .748 .975 r
.79417 .47144 .79876 .47628 .80988 .47519 .80533 .47037 Mtetra
.552 .76 .974 r
.80533 .47037 .80988 .47519 .82104 .47384 .81651 .46892 Mtetra
.576 .767 .969 r
.81651 .46892 .82104 .47384 .83222 .47218 .82771 .46706 Mtetra
.604 .771 .96 r
.82771 .46706 .83222 .47218 .84341 .47006 .83891 .46473 Mtetra
.624 .771 .951 r
.83891 .46473 .84341 .47006 .85462 .46756 .85013 .462 Mtetra
.64 .77 .942 r
.85013 .462 .85462 .46756 .86584 .46469 .86137 .45893 Mtetra
.651 .767 .934 r
.86137 .45893 .86584 .46469 .87707 .46155 .87262 .45561 Mtetra
.657 .764 .928 r
.87262 .45561 .87707 .46155 .88833 .45822 .8839 .45215 Mtetra
.661 .761 .924 r
.8839 .45215 .88833 .45822 .89963 .45475 .89521 .44857 Mtetra
.663 .759 .921 r
.89521 .44857 .89963 .45475 .91095 .4512 .90657 .44493 Mtetra
.663 .756 .919 r
.90657 .44493 .91095 .4512 .92232 .44763 .91796 .44128 Mtetra
.646 .749 .924 r
.30643 .61871 .31232 .62385 .32154 .62127 .31566 .61612 Mtetra
.645 .749 .925 r
.31566 .61612 .32154 .62127 .33079 .61868 .32493 .61355 Mtetra
.646 .751 .926 r
.32493 .61355 .33079 .61868 .34007 .61603 .33423 .61094 Mtetra
.648 .754 .926 r
.33423 .61094 .34007 .61603 .34939 .61328 .34357 .60827 Mtetra
.652 .758 .928 r
.34357 .60827 .34939 .61328 .35875 .6104 .35294 .60551 Mtetra
.659 .766 .929 r
.35294 .60551 .35875 .6104 .36816 .60727 .36236 .60257 Mtetra
.669 .776 .929 r
.36236 .60257 .36816 .60727 .3776 .60382 .37182 .59936 Mtetra
.683 .789 .93 r
.37182 .59936 .3776 .60382 .3871 .59999 .38132 .5958 Mtetra
.701 .804 .929 r
.38132 .5958 .3871 .59999 .39664 .5957 .39088 .59179 Mtetra
.718 .819 .927 r
.39088 .59179 .39664 .5957 .40622 .59102 .40048 .58731 Mtetra
.737 .83 .922 r
.40048 .58731 .40622 .59102 .41583 .58596 .41012 .58231 Mtetra
.746 .834 .918 r
.41012 .58231 .41583 .58596 .42547 .58085 .41979 .57702 Mtetra
.749 .827 .912 r
.41979 .57702 .42547 .58085 .43512 .57593 .42948 .5716 Mtetra
.723 .806 .916 r
.42948 .5716 .43512 .57593 .44477 .57196 .43918 .56694 Mtetra
.668 .769 .925 r
.43918 .56694 .44477 .57196 .45442 .56953 .44887 .56369 Mtetra
.576 .709 .933 r
.44887 .56369 .45442 .56953 .46407 .569 .45855 .56249 Mtetra
.433 .621 .931 r
.45855 .56249 .46407 .569 .47374 .57062 .46824 .56378 Mtetra
.336 .559 .918 r
.46824 .56378 .47374 .57062 .48346 .57319 .47796 .56652 Mtetra
.285 .537 .916 r
.47796 .56652 .48346 .57319 .49324 .57568 .48775 .56974 Mtetra
.463 .66 .946 r
.48775 .56974 .49324 .57568 .50311 .57556 .49763 .57035 Mtetra
.698 .775 .911 r
.49763 .57035 .50311 .57556 .51305 .57111 .50759 .56624 Mtetra
.841 .8 .811 r
.50759 .56624 .51305 .57111 .52302 .56122 .5176 .55555 Mtetra
.882 .772 .735 r
.5176 .55555 .52302 .56122 .53297 .54632 .52759 .53866 Mtetra
.854 .734 .731 r
.52759 .53866 .53297 .54632 .54289 .53197 .53754 .5226 Mtetra
.786 .692 .76 r
.53754 .5226 .54289 .53197 .55281 .52165 .54748 .51193 Mtetra
.478 .548 .85 r
.54748 .51193 .55281 .52165 .56283 .52013 .55754 .51375 Mtetra
.661 .193 0 r
.55754 .51375 .56283 .52013 .57302 .52761 .56782 .52837 Mtetra
.831 .383 .163 r
.56782 .52837 .57302 .52761 .58333 .5365 .57828 .54471 Mtetra
.723 .326 .298 r
.57828 .54471 .58333 .5365 .59369 .54239 .5888 .55606 Mtetra
.425 .074 .264 r
.5888 .55606 .59369 .54239 .60394 .53931 .59914 .55297 Mtetra
0 0 0 r
.59914 .55297 .60394 .53931 .61398 .52723 .60914 .53541 Mtetra
.828 .88 .446 r
.60914 .53541 .61398 .52723 .62392 .5121 .61895 .51279 Mtetra
.973 .904 .686 r
.61895 .51279 .62392 .5121 .63386 .49835 .62873 .49182 Mtetra
.786 .761 .831 r
.62873 .49182 .63386 .49835 .64411 .49364 .63888 .4837 Mtetra
.357 .477 .845 r
.63888 .4837 .64411 .49364 .65472 .4978 .64952 .48817 Mtetra
0 .256 .762 r
.64952 .48817 .65472 .4978 .6656 .50607 .66046 .49811 Mtetra
0 .162 .699 r
.66046 .49811 .6656 .50607 .67661 .51494 .67156 .50895 Mtetra
.153 .484 .9 r
.67156 .50895 .67661 .51494 .6875 .51877 .6825 .51355 Mtetra
.599 .757 .954 r
.6825 .51355 .6875 .51877 .69818 .51708 .6932 .51148 Mtetra
.769 .796 .875 r
.6932 .51148 .69818 .51708 .70868 .51099 .70368 .5046 Mtetra
.812 .78 .822 r
.70368 .5046 .70868 .51099 .71903 .50221 .71403 .49503 Mtetra
.795 .755 .817 r
.71403 .49503 .71903 .50221 .72939 .49334 .72441 .48595 Mtetra
.767 .743 .831 r
.72441 .48595 .72939 .49334 .73981 .48541 .73488 .47831 Mtetra
.711 .734 .869 r
.73488 .47831 .73981 .48541 .75039 .47968 .74553 .47322 Mtetra
.646 .732 .911 r
.74553 .47322 .75039 .47968 .76114 .47589 .75636 .47023 Mtetra
.575 .733 .95 r
.75636 .47023 .76114 .47589 .77204 .47369 .76735 .46869 Mtetra
.516 .735 .973 r
.76735 .46869 .77204 .47369 .78307 .47246 .77844 .46794 Mtetra
.507 .753 .984 r
.77844 .46794 .78307 .47246 .79417 .47144 .78959 .46706 Mtetra
.52 .766 .986 r
.78959 .46706 .79417 .47144 .80533 .47037 .80077 .4659 Mtetra
.556 .779 .982 r
.80077 .4659 .80533 .47037 .81651 .46892 .81196 .46419 Mtetra
.588 .782 .972 r
.81196 .46419 .81651 .46892 .82771 .46706 .82317 .462 Mtetra
.617 .781 .96 r
.82317 .462 .82771 .46706 .83891 .46473 .83438 .45935 Mtetra
.636 .776 .948 r
.83438 .45935 .83891 .46473 .85013 .462 .84561 .45633 Mtetra
.65 .771 .937 r
.84561 .45633 .85013 .462 .86137 .45893 .85685 .45303 Mtetra
.658 .766 .929 r
.85685 .45303 .86137 .45893 .87262 .45561 .86812 .44954 Mtetra
.661 .762 .924 r
.86812 .44954 .87262 .45561 .8839 .45215 .87942 .44594 Mtetra
.664 .759 .921 r
.87942 .44594 .8839 .45215 .89521 .44857 .89076 .44228 Mtetra
.665 .757 .919 r
.89076 .44228 .89521 .44857 .90657 .44493 .90214 .43858 Mtetra
.664 .755 .918 r
.90214 .43858 .90657 .44493 .91796 .44128 .91357 .43489 Mtetra
.647 .749 .924 r
.3005 .61354 .30643 .61871 .31566 .61612 .30975 .61091 Mtetra
.646 .748 .924 r
.30975 .61091 .31566 .61612 .32493 .61355 .31904 .6083 Mtetra
.646 .748 .923 r
.31904 .6083 .32493 .61355 .33423 .61094 .32836 .60568 Mtetra
.647 .748 .923 r
.32836 .60568 .33423 .61094 .34357 .60827 .33771 .60304 Mtetra
.647 .75 .924 r
.33771 .60304 .34357 .60827 .35294 .60551 .3471 .60037 Mtetra
.652 .755 .925 r
.3471 .60037 .35294 .60551 .36236 .60257 .35653 .59759 Mtetra
.658 .764 .928 r
.35653 .59759 .36236 .60257 .37182 .59936 .366 .59464 Mtetra
.669 .777 .931 r
.366 .59464 .37182 .59936 .38132 .5958 .37552 .59141 Mtetra
.683 .794 .934 r
.37552 .59141 .38132 .5958 .39088 .59179 .38508 .58782 Mtetra
.702 .815 .935 r
.38508 .58782 .39088 .59179 .40048 .58731 .39469 .58373 Mtetra
.726 .835 .933 r
.39469 .58373 .40048 .58731 .41012 .58231 .40435 .57902 Mtetra
.745 .85 .928 r
.40435 .57902 .41012 .58231 .41979 .57702 .41405 .57377 Mtetra
.762 .853 .919 r
.41405 .57377 .41979 .57702 .42948 .5716 .42378 .568 Mtetra
.748 .839 .92 r
.42378 .568 .42948 .5716 .43918 .56694 .43353 .56261 Mtetra
.71 .806 .925 r
.43353 .56261 .43918 .56694 .44887 .56369 .44327 .55826 Mtetra
.63 .744 .93 r
.44327 .55826 .44887 .56369 .45855 .56249 .453 .55588 Mtetra
.502 .651 .925 r
.453 .55588 .45855 .56249 .46824 .56378 .46271 .55616 Mtetra
.39 .561 .902 r
.46271 .55616 .46824 .56378 .47796 .56652 .47245 .55857 Mtetra
.291 .496 .885 r
.47245 .55857 .47796 .56652 .48775 .56974 .48223 .56249 Mtetra
.409 .586 .913 r
.48223 .56249 .48775 .56974 .49763 .57035 .49211 .56445 Mtetra
.631 .732 .92 r
.49211 .56445 .49763 .57035 .50759 .56624 .50209 .56202 Mtetra
.839 .823 .833 r
.50209 .56202 .50759 .56624 .5176 .55555 .51213 .55216 Mtetra
.914 .821 .741 r
.51213 .55216 .5176 .55555 .52759 .53866 .52217 .53479 Mtetra
.908 .811 .739 r
.52217 .53479 .52759 .53866 .53754 .5226 .53217 .51747 Mtetra
.853 .795 .793 r
.53217 .51747 .53754 .5226 .54748 .51193 .54215 .50558 Mtetra
.227 .515 .912 r
.54215 .50558 .54748 .51193 .55754 .51375 .55223 .50932 Mtetra
.858 .409 .023 r
.55223 .50932 .55754 .51375 .56782 .52837 .56258 .52953 Mtetra
.871 .461 .246 r
.56258 .52953 .56782 .52837 .57828 .54471 .57315 .55226 Mtetra
.78 .391 .318 r
.57315 .55226 .57828 .54471 .5888 .55606 .5838 .56873 Mtetra
.41 .047 .235 r
.5838 .56873 .5888 .55606 .59914 .55297 .59422 .56564 Mtetra
0 0 0 r
.59422 .56564 .59914 .55297 .60914 .53541 .60421 .54293 Mtetra
.948 .896 .505 r
.60421 .54293 .60914 .53541 .61895 .51279 .61394 .51387 Mtetra
.986 .873 .637 r
.61394 .51387 .61895 .51279 .62873 .49182 .62363 .48725 Mtetra
.843 .828 .833 r
.62363 .48725 .62873 .49182 .63888 .4837 .63375 .47715 Mtetra
.09 .42 .867 r
.63375 .47715 .63888 .4837 .64952 .48817 .64444 .48281 Mtetra
0 .005 .514 r
.64444 .48281 .64952 .48817 .66046 .49811 .65544 .49399 Mtetra
.582 .058 0 r
.65544 .49399 .66046 .49811 .67156 .50895 .66658 .50528 Mtetra
.012 .49 .872 r
.66658 .50528 .67156 .50895 .6825 .51355 .6775 .50899 Mtetra
.674 .812 .95 r
.6775 .50899 .6825 .51355 .6932 .51148 .68814 .50517 Mtetra
.791 .778 .841 r
.68814 .50517 .6932 .51148 .70368 .5046 .69859 .49687 Mtetra
.806 .745 .795 r
.69859 .49687 .70368 .5046 .71403 .49503 .70892 .48654 Mtetra
.775 .72 .801 r
.70892 .48654 .71403 .49503 .72441 .48595 .71935 .47774 Mtetra
.738 .715 .829 r
.71935 .47774 .72441 .48595 .73488 .47831 .72991 .4711 Mtetra
.677 .72 .882 r
.72991 .4711 .73488 .47831 .74553 .47322 .74067 .46718 Mtetra
.597 .728 .936 r
.74067 .46718 .74553 .47322 .75636 .47023 .7516 .46528 Mtetra
.518 .738 .974 r
.7516 .46528 .75636 .47023 .76735 .46869 .76267 .46445 Mtetra
.463 .745 .99 r
.76267 .46445 .76735 .46869 .77844 .46794 .77382 .46402 Mtetra
.485 .772 .995 r
.77382 .46402 .77844 .46794 .78959 .46706 .785 .46306 Mtetra
.526 .788 .993 r
.785 .46306 .78959 .46706 .80077 .4659 .79619 .46155 Mtetra
.576 .795 .982 r
.79619 .46155 .80077 .4659 .81196 .46419 .80738 .4594 Mtetra
.612 .791 .967 r
.80738 .4594 .81196 .46419 .82317 .462 .81858 .45674 Mtetra
.636 .781 .951 r
.81858 .45674 .82317 .462 .83438 .45935 .82979 .45369 Mtetra
.65 .772 .938 r
.82979 .45369 .83438 .45935 .84561 .45633 .84102 .45036 Mtetra
.658 .764 .928 r
.84102 .45036 .84561 .45633 .85685 .45303 .85228 .44685 Mtetra
.663 .759 .922 r
.85228 .44685 .85685 .45303 .86812 .44954 .86357 .44322 Mtetra
.664 .755 .918 r
.86357 .44322 .86812 .44954 .87942 .44594 .8749 .43955 Mtetra
.664 .754 .917 r
.8749 .43955 .87942 .44594 .89076 .44228 .88627 .43585 Mtetra
.664 .753 .917 r
.88627 .43585 .89076 .44228 .90214 .43858 .89769 .43215 Mtetra
.663 .754 .918 r
.89769 .43215 .90214 .43858 .91357 .43489 .90915 .42846 Mtetra
.651 .75 .922 r
.29453 .60833 .3005 .61354 .30975 .61091 .30381 .60561 Mtetra
.65 .747 .921 r
.30381 .60561 .30975 .61091 .31904 .6083 .31312 .60291 Mtetra
.649 .744 .919 r
.31312 .60291 .31904 .6083 .32836 .60568 .32246 .60022 Mtetra
.648 .742 .918 r
.32246 .60022 .32836 .60568 .33771 .60304 .33183 .59754 Mtetra
.647 .741 .918 r
.33183 .59754 .33771 .60304 .3471 .60037 .34124 .59489 Mtetra
.647 .742 .919 r
.34124 .59489 .3471 .60037 .35653 .59759 .35068 .59221 Mtetra
.648 .747 .922 r
.35068 .59221 .35653 .59759 .366 .59464 .36016 .58949 Mtetra
.653 .758 .927 r
.36016 .58949 .366 .59464 .37552 .59141 .36968 .58664 Mtetra
.66 .775 .934 r
.36968 .58664 .37552 .59141 .38508 .58782 .37924 .58358 Mtetra
.676 .801 .942 r
.37924 .58358 .38508 .58782 .39469 .58373 .38885 .58009 Mtetra
.701 .831 .945 r
.38885 .58009 .39469 .58373 .40435 .57902 .39852 .57598 Mtetra
.73 .861 .943 r
.39852 .57598 .40435 .57902 .41405 .57377 .40824 .5711 Mtetra
.763 .879 .93 r
.40824 .5711 .41405 .57377 .42378 .568 .41801 .56529 Mtetra
.769 .878 .926 r
.41801 .56529 .42378 .568 .43353 .56261 .42781 .55931 Mtetra
.756 .854 .923 r
.42781 .55931 .43353 .56261 .44327 .55826 .43761 .55367 Mtetra
.699 .796 .925 r
.43761 .55367 .44327 .55826 .453 .55588 .4474 .54958 Mtetra
.599 .704 .917 r
.4474 .54958 .453 .55588 .46271 .55616 .45717 .54795 Mtetra
.472 .587 .887 r
.45717 .54795 .46271 .55616 .47245 .55857 .46693 .54926 Mtetra
.322 .474 .857 r
.46693 .54926 .47245 .55857 .48223 .56249 .47671 .55351 Mtetra
.343 .497 .867 r
.47671 .55351 .48223 .56249 .49211 .56445 .48657 .55728 Mtetra
.483 .627 .915 r
.48657 .55728 .49211 .56445 .50209 .56202 .49654 .55802 Mtetra
.786 .836 .89 r
.49654 .55802 .50209 .56202 .51213 .55216 .50661 .55109 Mtetra
.931 .889 .767 r
.50661 .55109 .51213 .55216 .52217 .53479 .51671 .53547 Mtetra
.956 .915 .732 r
.51671 .53547 .52217 .53479 .53217 .51747 .52677 .5177 Mtetra
.931 .939 .781 r
.52677 .5177 .53217 .51747 .54215 .50558 .53679 .50341 Mtetra
0 .432 .752 r
.53679 .50341 .54215 .50558 .55223 .50932 .5469 .50647 Mtetra
.884 .452 .131 r
.5469 .50647 .55223 .50932 .56258 .52953 .55727 .52872 Mtetra
.895 .49 .228 r
.55727 .52872 .56258 .52953 .57315 .55226 .56787 .55485 Mtetra
.844 .428 .247 r
.56787 .55485 .57315 .55226 .5838 .56873 .5786 .5748 Mtetra
.225 0 0 r
.5786 .5748 .5838 .56873 .59422 .56564 .58908 .5717 Mtetra
.958 .916 .558 r
.58908 .5717 .59422 .56564 .60421 .54293 .59909 .54548 Mtetra
.993 .859 .595 r
.59909 .54548 .60421 .54293 .61394 .51387 .60883 .51298 Mtetra
.976 .835 .64 r
.60883 .51298 .61394 .51387 .62363 .48725 .61854 .48427 Mtetra
.85 .888 .866 r
.61854 .48427 .62363 .48725 .63375 .47715 .62873 .47482 Mtetra
.543 0 0 r
.62873 .47482 .63375 .47715 .64444 .48281 .63952 .48286 Mtetra
.747 .233 0 r
.63952 .48286 .64444 .48281 .65544 .49399 .65056 .49446 Mtetra
.696 .163 0 r
.65056 .49446 .65544 .49399 .66658 .50528 .66165 .50395 Mtetra
.084 .627 .844 r
.66165 .50395 .66658 .50528 .6775 .50899 .67248 .50465 Mtetra
.784 .846 .898 r
.67248 .50465 .6775 .50899 .68814 .50517 .683 .49756 Mtetra
.806 .748 .799 r
.683 .49756 .68814 .50517 .69859 .49687 .69337 .48738 Mtetra
.79 .706 .771 r
.69337 .48738 .69859 .49687 .70892 .48654 .70372 .47666 Mtetra
.742 .682 .792 r
.70372 .47666 .70892 .48654 .71935 .47774 .71423 .46894 Mtetra
.691 .684 .839 r
.71423 .46894 .71935 .47774 .72991 .4711 .72493 .4642 Mtetra
.616 .707 .91 r
.72493 .4642 .72991 .4711 .74067 .46718 .73583 .46199 Mtetra
.51 .726 .97 r
.73583 .46199 .74067 .46718 .7516 .46528 .74688 .46137 Mtetra
.43 .745 .993 r
.74688 .46137 .7516 .46528 .76267 .46445 .75802 .46111 Mtetra
.407 .76 .995 r
.75802 .46111 .76267 .46445 .77382 .46402 .76922 .46069 Mtetra
.484 .8 1 r
.76922 .46069 .77382 .46402 .785 .46306 .7804 .45931 Mtetra
.558 .815 .994 r
.7804 .45931 .785 .46306 .79619 .46155 .79157 .45714 Mtetra
.613 .809 .975 r
.79157 .45714 .79619 .46155 .80738 .4594 .80274 .45432 Mtetra
.643 .793 .954 r
.80274 .45432 .80738 .4594 .81858 .45674 .81392 .45106 Mtetra
.656 .774 .936 r
.81392 .45106 .81858 .45674 .82979 .45369 .82513 .44759 Mtetra
.662 .761 .924 r
.82513 .44759 .82979 .45369 .84102 .45036 .83637 .44397 Mtetra
.664 .752 .916 r
.83637 .44397 .84102 .45036 .85228 .44685 .84765 .4403 Mtetra
.664 .748 .913 r
.84765 .4403 .85228 .44685 .86357 .44322 .85896 .43661 Mtetra
.663 .746 .912 r
.85896 .43661 .86357 .44322 .8749 .43955 .87033 .43293 Mtetra
.662 .747 .913 r
.87033 .43293 .8749 .43955 .88627 .43585 .88174 .42927 Mtetra
.661 .748 .915 r
.88174 .42927 .88627 .43585 .89769 .43215 .89319 .42561 Mtetra
.66 .751 .917 r
.89319 .42561 .89769 .43215 .90915 .42846 .90469 .42197 Mtetra
.655 .751 .921 r
.28853 .60308 .29453 .60833 .30381 .60561 .29783 .60025 Mtetra
.655 .748 .918 r
.29783 .60025 .30381 .60561 .31312 .60291 .30716 .59742 Mtetra
.654 .743 .916 r
.30716 .59742 .31312 .60291 .32246 .60022 .31653 .5946 Mtetra
.652 .739 .913 r
.31653 .5946 .32246 .60022 .33183 .59754 .32593 .59182 Mtetra
.65 .735 .911 r
.32593 .59182 .33183 .59754 .34124 .59489 .33536 .58907 Mtetra
.648 .732 .911 r
.33536 .58907 .34124 .59489 .35068 .59221 .34482 .58639 Mtetra
.644 .731 .912 r
.34482 .58639 .35068 .59221 .36016 .58949 .35431 .58377 Mtetra
.642 .735 .916 r
.35431 .58377 .36016 .58949 .36968 .58664 .36384 .58118 Mtetra
.64 .745 .925 r
.36384 .58118 .36968 .58664 .37924 .58358 .3734 .57862 Mtetra
.649 .767 .935 r
.3734 .57862 .37924 .58358 .38885 .58009 .383 .57579 Mtetra
.665 .798 .946 r
.383 .57579 .38885 .58009 .39852 .57598 .39266 .57252 Mtetra
.697 .84 .951 r
.39266 .57252 .39852 .57598 .40824 .5711 .40238 .56842 Mtetra
.741 .879 .944 r
.40238 .56842 .40824 .5711 .41801 .56529 .41217 .56318 Mtetra
.767 .904 .936 r
.41217 .56318 .41801 .56529 .42781 .55931 .422 .55717 Mtetra
.785 .903 .924 r
.422 .55717 .42781 .55931 .43761 .55367 .43187 .55062 Mtetra
.763 .867 .925 r
.43187 .55062 .43761 .55367 .4474 .54958 .44173 .54474 Mtetra
.704 .789 .917 r
.44173 .54474 .4474 .54958 .45717 .54795 .45158 .54048 Mtetra
.573 .657 .893 r
.45158 .54048 .45717 .54795 .46693 .54926 .46139 .53956 Mtetra
.392 .505 .854 r
.46139 .53956 .46693 .54926 .47671 .55351 .47119 .54283 Mtetra
.328 .446 .828 r
.47119 .54283 .47671 .55351 .48657 .55728 .48103 .5477 Mtetra
.327 .473 .853 r
.48103 .5477 .48657 .55728 .49654 .55802 .49097 .55202 Mtetra
.613 .725 .926 r
.49097 .55202 .49654 .55802 .50661 .55109 .50103 .54994 Mtetra
.881 .928 .848 r
.50103 .54994 .50661 .55109 .51671 .53547 .51117 .53919 Mtetra
.917 .974 .692 r
.51117 .53919 .51671 .53547 .52677 .5177 .52131 .52292 Mtetra
.88 .96 .623 r
.52131 .52292 .52677 .5177 .53679 .50341 .5314 .50583 Mtetra
.105 0 0 r
.5314 .50583 .53679 .50341 .5469 .50647 .54152 .50446 Mtetra
.846 .385 .075 r
.54152 .50446 .5469 .50647 .55727 .52872 .55185 .52192 Mtetra
.845 .415 0 r
.55185 .52192 .55727 .52872 .56787 .55485 .5624 .54479 Mtetra
0 0 .368 r
.5624 .54479 .56787 .55485 .5786 .5748 .57309 .56372 Mtetra
.642 .614 .807 r
.57309 .56372 .5786 .5748 .58908 .5717 .58357 .5606 Mtetra
.87 .701 .669 r
.58357 .5606 .58908 .5717 .59909 .54548 .59364 .53535 Mtetra
.893 .714 .652 r
.59364 .53535 .59909 .54548 .60883 .51298 .60352 .50607 Mtetra
.909 .757 .681 r
.60352 .50607 .60883 .51298 .61854 .48427 .61342 .48213 Mtetra
.702 .918 .967 r
.61342 .48213 .61854 .48427 .62873 .47482 .62379 .4771 Mtetra
.741 .255 .086 r
.62379 .4771 .62873 .47482 .63952 .48286 .63471 .48795 Mtetra
.716 .266 .181 r
.63471 .48795 .63952 .48286 .65056 .49446 .64574 .49801 Mtetra
.566 .051 0 r
.64574 .49801 .65056 .49446 .66165 .50395 .65668 .50254 Mtetra
.613 .924 .972 r
.65668 .50254 .66165 .50395 .67248 .50465 .66732 .49827 Mtetra
.83 .783 .808 r
.66732 .49827 .67248 .50465 .683 .49756 .67771 .4875 Mtetra
.792 .697 .76 r
.67771 .4875 .683 .49756 .69337 .48738 .68805 .47614 Mtetra
.759 .667 .76 r
.68805 .47614 .69337 .48738 .70372 .47666 .69847 .46637 Mtetra
.697 .656 .806 r
.69847 .46637 .70372 .47666 .71423 .46894 .70912 .46088 Mtetra
.614 .671 .881 r
.70912 .46088 .71423 .46894 .72493 .4642 .72001 .45879 Mtetra
.503 .714 .966 r
.72001 .45879 .72493 .4642 .73583 .46199 .73105 .45837 Mtetra
.363 .723 .988 r
.73105 .45837 .73583 .46199 .74688 .46137 .7422 .45865 Mtetra
.342 .752 .981 r
.7422 .45865 .74688 .46137 .75802 .46111 .75338 .45839 Mtetra
.416 .793 .992 r
.75338 .45839 .75802 .46111 .76922 .46069 .76457 .45734 Mtetra
.545 .829 .998 r
.76457 .45734 .76922 .46069 .7804 .45931 .77572 .45511 Mtetra
.622 .822 .978 r
.77572 .45511 .7804 .45931 .79157 .45714 .78686 .45203 Mtetra
.655 .797 .95 r
.78686 .45203 .79157 .45714 .80274 .45432 .79801 .44848 Mtetra
.669 .774 .928 r
.79801 .44848 .80274 .45432 .81392 .45106 .80917 .44467 Mtetra
.669 .754 .915 r
.80917 .44467 .81392 .45106 .82513 .44759 .82039 .44087 Mtetra
.667 .744 .907 r
.82039 .44087 .82513 .44759 .83637 .44397 .83164 .4371 Mtetra
.664 .738 .905 r
.83164 .4371 .83637 .44397 .84765 .4403 .84295 .4334 Mtetra
.662 .737 .905 r
.84295 .4334 .84765 .4403 .85896 .43661 .8543 .42975 Mtetra
.66 .738 .908 r
.8543 .42975 .85896 .43661 .87033 .43293 .86571 .42615 Mtetra
.658 .741 .911 r
.86571 .42615 .87033 .43293 .88174 .42927 .87716 .42257 Mtetra
.657 .744 .914 r
.87716 .42257 .88174 .42927 .89319 .42561 .88866 .41901 Mtetra
.657 .748 .917 r
.88866 .41901 .89319 .42561 .90469 .42197 .90021 .41544 Mtetra
.659 .752 .919 r
.28248 .59781 .28853 .60308 .29783 .60025 .29181 .59486 Mtetra
.66 .749 .916 r
.29181 .59486 .29783 .60025 .30716 .59742 .30117 .59188 Mtetra
.66 .744 .912 r
.30117 .59188 .30716 .59742 .31653 .5946 .31057 .5889 Mtetra
.659 .739 .909 r
.31057 .5889 .31653 .5946 .32593 .59182 .31999 .58593 Mtetra
.657 .733 .905 r
.31999 .58593 .32593 .59182 .33536 .58907 .32945 .58299 Mtetra
.653 .726 .902 r
.32945 .58299 .33536 .58907 .34482 .58639 .33894 .58015 Mtetra
.647 .719 .901 r
.33894 .58015 .34482 .58639 .35431 .58377 .34845 .57745 Mtetra
.64 .715 .902 r
.34845 .57745 .35431 .58377 .36384 .58118 .35799 .57493 Mtetra
.628 .714 .908 r
.35799 .57493 .36384 .58118 .3734 .57862 .36755 .57266 Mtetra
.625 .724 .918 r
.36755 .57266 .3734 .57862 .383 .57579 .37715 .57043 Mtetra
.625 .747 .935 r
.37715 .57043 .383 .57579 .39266 .57252 .3868 .56813 Mtetra
.647 .792 .952 r
.3868 .56813 .39266 .57252 .40238 .56842 .3965 .56521 Mtetra
.686 .851 .962 r
.3965 .56521 .40238 .56842 .41217 .56318 .40627 .56126 Mtetra
.73 .911 .957 r
.40627 .56126 .41217 .56318 .422 .55717 .41612 .55606 Mtetra
.781 .943 .93 r
.41612 .55606 .422 .55717 .43187 .55062 .42603 .54937 Mtetra
.806 .937 .916 r
.42603 .54937 .43187 .55062 .44173 .54474 .43597 .54202 Mtetra
.805 .88 .901 r
.43597 .54202 .44173 .54474 .45158 .54048 .44592 .53471 Mtetra
.701 .757 .895 r
.44592 .53471 .45158 .54048 .46139 .53956 .45582 .53043 Mtetra
.522 .589 .863 r
.45582 .53043 .46139 .53956 .47119 .54283 .46567 .53092 Mtetra
.38 .451 .809 r
.46567 .53092 .47119 .54283 .48103 .5477 .47551 .53538 Mtetra
.237 .357 .784 r
.47551 .53538 .48103 .5477 .49097 .55202 .4854 .54271 Mtetra
.33 .484 .861 r
.4854 .54271 .49097 .55202 .50103 .54994 .49542 .54679 Mtetra
.597 .841 .991 r
.49542 .54679 .50103 .54994 .51117 .53919 .50556 .54413 Mtetra
.707 .933 .615 r
.50556 .54413 .51117 .53919 .52131 .52292 .51576 .53201 Mtetra
.732 .856 .425 r
.51576 .53201 .52131 .52292 .5314 .50583 .52594 .51264 Mtetra
0 0 0 r
.52594 .51264 .5314 .50583 .54152 .50446 .5361 .50311 Mtetra
.412 0 0 r
.5361 .50311 .54152 .50446 .55185 .52192 .54635 .50788 Mtetra
.092 .234 .719 r
.54635 .50788 .55185 .52192 .5624 .54479 .55675 .51943 Mtetra
.34 .299 .665 r
.55675 .51943 .5624 .54479 .57309 .56372 .56728 .53157 Mtetra
.597 .449 .651 r
.56728 .53157 .57309 .56372 .58357 .5606 .57771 .5284 Mtetra
.711 .525 .636 r
.57771 .5284 .58357 .5606 .59364 .53535 .58789 .50986 Mtetra
.735 .557 .652 r
.58789 .50986 .59364 .53535 .60352 .50607 .59802 .49188 Mtetra
.749 .625 .722 r
.59802 .49188 .60352 .50607 .61342 .48213 .60827 .48065 Mtetra
.208 0 0 r
.60827 .48065 .61342 .48213 .62379 .4771 .61892 .48382 Mtetra
.749 .332 .258 r
.61892 .48382 .62379 .4771 .63471 .48795 .62996 .49695 Mtetra
.621 .209 .24 r
.62996 .49695 .63471 .48795 .64574 .49801 .6409 .5028 Mtetra
.1 0 0 r
.6409 .5028 .64574 .49801 .65668 .50254 .65157 .4991 Mtetra
.863 .879 .848 r
.65157 .4991 .65668 .50254 .66732 .49827 .662 .48854 Mtetra
.822 .712 .743 r
.662 .48854 .66732 .49827 .67771 .4875 .67227 .47465 Mtetra
.759 .647 .737 r
.67227 .47465 .67771 .4875 .68805 .47614 .68265 .46365 Mtetra
.708 .627 .765 r
.68265 .46365 .68805 .47614 .69847 .46637 .69323 .45667 Mtetra
.615 .631 .844 r
.69323 .45667 .69847 .46637 .70912 .46088 .70409 .45455 Mtetra
.441 .646 .945 r
.70409 .45455 .70912 .46088 .72001 .45879 .71518 .45555 Mtetra
.255 .677 .964 r
.71518 .45555 .72001 .45879 .73105 .45837 .72635 .4566 Mtetra
.174 .681 .904 r
.72635 .4566 .73105 .45837 .7422 .45865 .73755 .45698 Mtetra
.328 .784 .949 r
.73755 .45698 .7422 .45865 .75338 .45839 .74871 .45586 Mtetra
.517 .852 .996 r
.74871 .45586 .75338 .45839 .76457 .45734 .75984 .45343 Mtetra
.637 .842 .979 r
.75984 .45343 .76457 .45734 .77572 .45511 .77094 .44994 Mtetra
.679 .803 .941 r
.77094 .44994 .77572 .45511 .78686 .45203 .78203 .44582 Mtetra
.683 .766 .914 r
.78203 .44582 .78686 .45203 .79801 .44848 .79315 .44161 Mtetra
.68 .743 .898 r
.79315 .44161 .79801 .44848 .80917 .44467 .80432 .43743 Mtetra
.671 .729 .893 r
.80432 .43743 .80917 .44467 .82039 .44087 .81555 .43352 Mtetra
.664 .723 .893 r
.81555 .43352 .82039 .44087 .83164 .4371 .82684 .42979 Mtetra
.659 .723 .896 r
.82684 .42979 .83164 .4371 .84295 .4334 .83819 .42621 Mtetra
.656 .726 .901 r
.83819 .42621 .84295 .4334 .8543 .42975 .8496 .42272 Mtetra
.654 .732 .906 r
.8496 .42272 .8543 .42975 .86571 .42615 .86105 .41926 Mtetra
.653 .737 .911 r
.86105 .41926 .86571 .42615 .87716 .42257 .87255 .41581 Mtetra
.653 .742 .915 r
.87255 .41581 .87716 .42257 .88866 .41901 .8841 .41235 Mtetra
.653 .746 .918 r
.8841 .41235 .88866 .41901 .90021 .41544 .89569 .40886 Mtetra
.661 .753 .918 r
.27639 .59249 .28248 .59781 .29181 .59486 .28575 .58947 Mtetra
.663 .751 .916 r
.28575 .58947 .29181 .59486 .30117 .59188 .29513 .5864 Mtetra
.664 .749 .913 r
.29513 .5864 .30117 .59188 .31057 .5889 .30456 .5833 Mtetra
.665 .745 .91 r
.30456 .5833 .31057 .5889 .31999 .58593 .31401 .58016 Mtetra
.666 .74 .906 r
.31401 .58016 .31999 .58593 .32945 .58299 .3235 .577 Mtetra
.663 .732 .901 r
.3235 .577 .32945 .58299 .33894 .58015 .33302 .57389 Mtetra
.658 .723 .897 r
.33302 .57389 .33894 .58015 .34845 .57745 .34257 .57089 Mtetra
.648 .711 .894 r
.34257 .57089 .34845 .57745 .35799 .57493 .35213 .56814 Mtetra
.633 .7 .893 r
.35213 .56814 .35799 .57493 .36755 .57266 .36172 .56576 Mtetra
.619 .692 .896 r
.36172 .56576 .36755 .57266 .37715 .57043 .37133 .56372 Mtetra
.602 .692 .906 r
.37133 .56372 .37715 .57043 .3868 .56813 .38096 .56206 Mtetra
.603 .715 .924 r
.38096 .56206 .3868 .56813 .3965 .56521 .39063 .56027 Mtetra
.616 .763 .95 r
.39063 .56027 .3965 .56521 .40627 .56126 .40037 .55801 Mtetra
.663 .847 .97 r
.40037 .55801 .40627 .56126 .41612 .55606 .41019 .55446 Mtetra
.734 .925 .955 r
.41019 .55446 .41612 .55606 .42603 .54937 .4201 .549 Mtetra
.795 .966 .914 r
.4201 .549 .42603 .54937 .43597 .54202 .43009 .54159 Mtetra
.852 .955 .878 r
.43009 .54159 .43597 .54202 .44592 .53471 .44014 .53236 Mtetra
.815 .896 .9 r
.44014 .53236 .44592 .53471 .45582 .53043 .45015 .5247 Mtetra
.689 .757 .904 r
.45015 .5247 .45582 .53043 .46567 .53092 .46009 .52074 Mtetra
.496 .553 .844 r
.46009 .52074 .46567 .53092 .47551 .53538 .46999 .52205 Mtetra
.283 .368 .774 r
.46999 .52205 .47551 .53538 .4854 .54271 .47986 .5291 Mtetra
.227 .329 .76 r
.47986 .5291 .4854 .54271 .49542 .54679 .48983 .5374 Mtetra
.202 .406 .84 r
.48983 .5374 .49542 .54679 .50556 .54413 .49991 .54333 Mtetra
.659 .946 .958 r
.49991 .54333 .50556 .54413 .51576 .53201 .51014 .53837 Mtetra
.825 .938 .57 r
.51014 .53837 .51576 .53201 .52594 .51264 .52041 .52125 Mtetra
.614 .808 .391 r
.52041 .52125 .52594 .51264 .5361 .50311 .53063 .50501 Mtetra
.818 1 .8 r
.53063 .50501 .5361 .50311 .54635 .50788 .54084 .49456 Mtetra
.647 .582 .767 r
.54084 .49456 .54635 .50788 .55675 .51943 .5511 .49077 Mtetra
.545 .423 .664 r
.5511 .49077 .55675 .51943 .56728 .53157 .56145 .4922 Mtetra
.589 .428 .631 r
.56145 .4922 .56728 .53157 .57771 .5284 .5718 .48898 Mtetra
.625 .453 .63 r
.5718 .48898 .57771 .5284 .58789 .50986 .5821 .48108 Mtetra
.594 .455 .662 r
.5821 .48108 .58789 .50986 .59802 .49188 .59253 .47841 Mtetra
.431 .46 .789 r
.59253 .47841 .59802 .49188 .60827 .48065 .60315 .48245 Mtetra
.72 .218 .038 r
.60315 .48245 .60827 .48065 .61892 .48382 .61402 .49235 Mtetra
.707 .3 .273 r
.61402 .49235 .61892 .48382 .62996 .49695 .62505 .50319 Mtetra
.336 0 0 r
.62505 .50319 .62996 .49695 .6409 .5028 .6358 .50177 Mtetra
.904 .947 .821 r
.6358 .50177 .6409 .5028 .65157 .4991 .64619 .48932 Mtetra
.831 .713 .735 r
.64619 .48932 .65157 .4991 .662 .48854 .65647 .47443 Mtetra
.776 .641 .713 r
.65647 .47443 .662 .48854 .67227 .47465 .66677 .46077 Mtetra
.71 .612 .746 r
.66677 .46077 .67227 .47465 .68265 .46365 .67731 .45292 Mtetra
.624 .615 .821 r
.67731 .45292 .68265 .46365 .69323 .45667 .68814 .45043 Mtetra
.415 .637 .947 r
.68814 .45043 .69323 .45667 .70409 .45455 .69921 .45173 Mtetra
.005 .522 .858 r
.69921 .45173 .70409 .45455 .71518 .45555 .71044 .45465 Mtetra
0 .559 .766 r
.71044 .45465 .71518 .45555 .72635 .4566 .72166 .45573 Mtetra
.214 .73 .871 r
.72166 .45573 .72635 .4566 .73755 .45698 .73281 .45482 Mtetra
.53 .873 .99 r
.73281 .45482 .73755 .45698 .74871 .45586 .7439 .45193 Mtetra
.672 .853 .969 r
.7439 .45193 .74871 .45586 .75984 .45343 .75494 .44773 Mtetra
.701 .79 .92 r
.75494 .44773 .75984 .45343 .77094 .44994 .76599 .44303 Mtetra
.701 .749 .889 r
.76599 .44303 .77094 .44994 .78203 .44582 .77706 .4382 Mtetra
.686 .723 .878 r
.77706 .4382 .78203 .44582 .79315 .44161 .78819 .43375 Mtetra
.675 .712 .877 r
.78819 .43375 .79315 .44161 .80432 .43743 .79939 .42964 Mtetra
.663 .71 .883 r
.79939 .42964 .80432 .43743 .81555 .43352 .81067 .42592 Mtetra
.655 .713 .891 r
.81067 .42592 .81555 .43352 .82684 .42979 .82202 .42245 Mtetra
.651 .72 .899 r
.82202 .42245 .82684 .42979 .83819 .42621 .83342 .41909 Mtetra
.648 .727 .906 r
.83342 .41909 .83819 .42621 .8496 .42272 .84487 .4158 Mtetra
.649 .735 .912 r
.84487 .4158 .8496 .42272 .86105 .41926 .85637 .41247 Mtetra
.649 .74 .916 r
.85637 .41247 .86105 .41926 .87255 .41581 .86792 .4091 Mtetra
.65 .744 .919 r
.86792 .4091 .87255 .41581 .8841 .41235 .8795 .4057 Mtetra
.651 .747 .92 r
.8795 .4057 .8841 .41235 .89569 .40886 .89113 .40224 Mtetra
.66 .752 .919 r
.27027 .58715 .27639 .59249 .28575 .58947 .27964 .58414 Mtetra
.662 .754 .918 r
.27964 .58414 .28575 .58947 .29513 .5864 .28904 .58107 Mtetra
.665 .755 .918 r
.28904 .58107 .29513 .5864 .30456 .5833 .29849 .57792 Mtetra
.668 .755 .916 r
.29849 .57792 .30456 .5833 .31401 .58016 .30797 .57468 Mtetra
.673 .753 .911 r
.30797 .57468 .31401 .58016 .3235 .577 .31749 .57132 Mtetra
.674 .748 .906 r
.31749 .57132 .3235 .577 .33302 .57389 .32705 .5679 Mtetra
.675 .738 .898 r
.32705 .5679 .33302 .57389 .34257 .57089 .33664 .56444 Mtetra
.667 .721 .89 r
.33664 .56444 .34257 .57089 .35213 .56814 .34625 .56115 Mtetra
.654 .702 .881 r
.34625 .56115 .35213 .56814 .36172 .56576 .35588 .55818 Mtetra
.634 .678 .874 r
.35588 .55818 .36172 .56576 .37133 .56372 .36552 .55576 Mtetra
.605 .657 .875 r
.36552 .55576 .37133 .56372 .38096 .56206 .37516 .55411 Mtetra
.581 .648 .882 r
.37516 .55411 .38096 .56206 .39063 .56027 .38482 .55305 Mtetra
.551 .658 .907 r
.38482 .55305 .39063 .56027 .40037 .55801 .39451 .55248 Mtetra
.565 .725 .949 r
.39451 .55248 .40037 .55801 .41019 .55446 .40427 .55122 Mtetra
.616 .838 .985 r
.40427 .55122 .41019 .55446 .4201 .549 .41413 .54842 Mtetra
.709 .957 .949 r
.41413 .54842 .4201 .549 .43009 .54159 .4241 .54284 Mtetra
.815 .996 .857 r
.4241 .54284 .43009 .54159 .44014 .53236 .4342 .53377 Mtetra
.846 .994 .838 r
.4342 .53377 .44014 .53236 .45015 .5247 .44432 .52364 Mtetra
.856 .936 .875 r
.44432 .52364 .45015 .5247 .46009 .52074 .45442 .51425 Mtetra
.705 .739 .877 r
.45442 .51425 .46009 .52074 .46999 .52205 .46443 .50966 Mtetra
.471 .498 .804 r
.46443 .50966 .46999 .52205 .47986 .5291 .47437 .5121 Mtetra
.3 .331 .726 r
.47437 .5121 .47986 .5291 .48983 .5374 .48429 .52074 Mtetra
.118 .216 .69 r
.48429 .52074 .48983 .5374 .49991 .54333 .4943 .53325 Mtetra
.343 .475 .848 r
.4943 .53325 .49991 .54333 .51014 .53837 .50448 .53746 Mtetra
.84 .955 .889 r
.50448 .53746 .51014 .53837 .52041 .52125 .51479 .52851 Mtetra
.805 .916 .525 r
.51479 .52851 .52041 .52125 .53063 .50501 .5251 .51026 Mtetra
.964 .93 .608 r
.5251 .51026 .53063 .50501 .54084 .49456 .53534 .48651 Mtetra
.873 .737 .709 r
.53534 .48651 .54084 .49456 .5511 .49077 .54552 .46728 Mtetra
.69 .535 .671 r
.54552 .46728 .5511 .49077 .56145 .4922 .55571 .45647 Mtetra
.592 .436 .639 r
.55571 .45647 .56145 .4922 .5718 .48898 .566 .45319 Mtetra
.516 .383 .639 r
.566 .45319 .5718 .48898 .5821 .48108 .57643 .45748 Mtetra
.3 .281 .67 r
.57643 .45748 .5821 .48108 .59253 .47841 .58712 .47024 Mtetra
.627 .198 0 r
.58712 .47024 .59253 .47841 .60315 .48245 .59805 .48761 Mtetra
.743 .302 .205 r
.59805 .48761 .60315 .48245 .61402 .49235 .60901 .49951 Mtetra
.528 .079 .128 r
.60901 .49951 .61402 .49235 .62505 .50319 .61985 .50208 Mtetra
.875 .957 .855 r
.61985 .50208 .62505 .50319 .6358 .50177 .63034 .49135 Mtetra
.854 .71 .703 r
.63034 .49135 .6358 .50177 .64619 .48932 .64053 .47217 Mtetra
.765 .613 .689 r
.64053 .47217 .64619 .48932 .65647 .47443 .65081 .45688 Mtetra
.702 .576 .71 r
.65081 .45688 .65647 .47443 .66677 .46077 .6613 .44784 Mtetra
.605 .57 .788 r
.6613 .44784 .66677 .46077 .67731 .45292 .67213 .44594 Mtetra
.325 .56 .922 r
.67213 .44594 .67731 .45292 .68814 .45043 .68324 .44896 Mtetra
.244 0 0 r
.68324 .44896 .68814 .45043 .69921 .45173 .69448 .45274 Mtetra
.361 0 0 r
.69448 .45274 .69921 .45173 .71044 .45465 .70575 .45547 Mtetra
.002 0 0 r
.70575 .45547 .71044 .45465 .72166 .45573 .7169 .45463 Mtetra
.519 .901 .953 r
.7169 .45463 .72166 .45573 .73281 .45482 .72793 .45095 Mtetra
.719 .868 .952 r
.72793 .45095 .73281 .45482 .7439 .45193 .7389 .44567 Mtetra
.738 .782 .888 r
.7389 .44567 .7439 .45193 .75494 .44773 .74985 .43967 Mtetra
.712 .72 .857 r
.74985 .43967 .75494 .44773 .76599 .44303 .76087 .43418 Mtetra
.691 .693 .847 r
.76087 .43418 .76599 .44303 .77706 .4382 .77196 .42927 Mtetra
.67 .683 .853 r
.77196 .42927 .77706 .4382 .78819 .43375 .78315 .42517 Mtetra
.655 .686 .867 r
.78315 .42517 .78819 .43375 .79939 .42964 .79442 .42163 Mtetra
.645 .698 .884 r
.79442 .42163 .79939 .42964 .81067 .42592 .80577 .41842 Mtetra
.639 .711 .899 r
.80577 .41842 .81067 .42592 .82202 .42245 .81719 .41538 Mtetra
.64 .726 .911 r
.81719 .41538 .82202 .42245 .83342 .41909 .82865 .41231 Mtetra
.64 .736 .918 r
.82865 .41231 .83342 .41909 .84487 .4158 .84015 .40917 Mtetra
.644 .745 .922 r
.84015 .40917 .84487 .4158 .85637 .41247 .85169 .4059 Mtetra
.647 .749 .923 r
.85169 .4059 .85637 .41247 .86792 .4091 .86327 .40253 Mtetra
.65 .751 .923 r
.86327 .40253 .86792 .4091 .8795 .4057 .87489 .39908 Mtetra
.652 .751 .922 r
.87489 .39908 .8795 .4057 .89113 .40224 .88655 .39556 Mtetra
.655 .751 .921 r
.2641 .58177 .27027 .58715 .27964 .58414 .27348 .57886 Mtetra
.656 .756 .923 r
.27348 .57886 .27964 .58414 .28904 .58107 .2829 .5759 Mtetra
.66 .762 .925 r
.2829 .5759 .28904 .58107 .29849 .57792 .29236 .57285 Mtetra
.665 .767 .926 r
.29236 .57285 .29849 .57792 .30797 .57468 .30186 .56966 Mtetra
.673 .771 .924 r
.30186 .56966 .30797 .57468 .31749 .57132 .3114 .56627 Mtetra
.68 .773 .921 r
.3114 .56627 .31749 .57132 .32705 .5679 .32099 .56269 Mtetra
.688 .769 .913 r
.32099 .56269 .32705 .5679 .33664 .56444 .33062 .55887 Mtetra
.689 .758 .904 r
.33062 .55887 .33664 .56444 .34625 .56115 .34029 .55501 Mtetra
.685 .738 .891 r
.34029 .55501 .34625 .56115 .35588 .55818 .34998 .55121 Mtetra
.666 .707 .878 r
.34998 .55121 .35588 .55818 .36552 .55576 .35968 .54787 Mtetra
.636 .672 .868 r
.35968 .54787 .36552 .55576 .37516 .55411 .36937 .54536 Mtetra
.597 .635 .859 r
.36937 .54536 .37516 .55411 .38482 .55305 .37905 .54391 Mtetra
.544 .602 .862 r
.37905 .54391 .38482 .55305 .39451 .55248 .38873 .54382 Mtetra
.521 .604 .877 r
.38873 .54382 .39451 .55248 .40427 .55122 .39844 .54413 Mtetra
.512 .648 .918 r
.39844 .54413 .40427 .55122 .41413 .54842 .40822 .54419 Mtetra
.596 .792 .974 r
.40822 .54419 .41413 .54842 .4241 .54284 .41812 .54199 Mtetra
.73 .953 .948 r
.41812 .54199 .4241 .54284 .4342 .53377 .42817 .53613 Mtetra
.77 .996 .808 r
.42817 .53613 .4342 .53377 .44432 .52364 .43833 .52684 Mtetra
.85 .995 .755 r
.43833 .52684 .44432 .52364 .45442 .51425 .44855 .51462 Mtetra
.865 .975 .855 r
.44855 .51462 .45442 .51425 .46443 .50966 .45872 .50441 Mtetra
.727 .787 .9 r
.45872 .50441 .46443 .50966 .47437 .5121 .4688 .49929 Mtetra
.454 .482 .798 r
.4688 .49929 .47437 .5121 .48429 .52074 .47879 .50225 Mtetra
.233 .272 .698 r
.47879 .50225 .48429 .52074 .4943 .53325 .48876 .51336 Mtetra
.325 .322 .702 r
.48876 .51336 .4943 .53325 .50448 .53746 .49888 .52275 Mtetra
.5 .485 .772 r
.49888 .52275 .50448 .53746 .51479 .52851 .50914 .52485 Mtetra
.857 .853 .837 r
.50914 .52485 .51479 .52851 .5251 .51026 .5195 .5142 Mtetra
.971 .93 .644 r
.5195 .5142 .5251 .51026 .53534 .48651 .52983 .49154 Mtetra
.955 .938 .615 r
.52983 .49154 .53534 .48651 .54552 .46728 .54008 .46924 Mtetra
.935 .967 .735 r
.54008 .46924 .54552 .46728 .55571 .45647 .5503 .45343 Mtetra
.626 .861 .987 r
.5503 .45343 .55571 .45647 .566 .45319 .56061 .45013 Mtetra
.593 .039 0 r
.56061 .45013 .566 .45319 .57643 .45748 .57114 .45939 Mtetra
.813 .361 .165 r
.57114 .45939 .57643 .45748 .58712 .47024 .58191 .47521 Mtetra
.795 .372 .246 r
.58191 .47521 .58712 .47024 .59805 .48761 .59285 .49146 Mtetra
.555 .043 0 r
.59285 .49146 .59805 .48761 .60901 .49951 .60366 .49568 Mtetra
.822 .867 .879 r
.60366 .49568 .60901 .49951 .61985 .50208 .61422 .48704 Mtetra
.788 .639 .697 r
.61422 .48704 .61985 .50208 .63034 .49135 .62456 .471 Mtetra
.763 .594 .668 r
.62456 .471 .63034 .49135 .64053 .47217 .63481 .45318 Mtetra
.7 .565 .699 r
.63481 .45318 .64053 .47217 .65081 .45688 .6453 .44357 Mtetra
.592 .558 .786 r
.6453 .44357 .65081 .45688 .6613 .44784 .65611 .44217 Mtetra
.178 .524 .92 r
.65611 .44217 .6613 .44784 .67213 .44594 .66721 .44596 Mtetra
.517 0 0 r
.66721 .44596 .67213 .44594 .68324 .44896 .6785 .45182 Mtetra
.46 0 0 r
.6785 .45182 .68324 .44896 .69448 .45274 .68975 .45472 Mtetra
.147 0 0 r
.68975 .45472 .69448 .45274 .70575 .45547 .70089 .45413 Mtetra
.591 .924 .964 r
.70089 .45413 .70575 .45547 .7169 .45463 .71188 .44979 Mtetra
.766 .839 .908 r
.71188 .44979 .7169 .45463 .72793 .45095 .72277 .44311 Mtetra
.747 .738 .844 r
.72277 .44311 .72793 .45095 .7389 .44567 .73366 .43617 Mtetra
.723 .691 .819 r
.73366 .43617 .7389 .44567 .74985 .43967 .7446 .42963 Mtetra
.689 .667 .823 r
.7446 .42963 .74985 .43967 .76087 .43418 .75566 .42448 Mtetra
.665 .663 .838 r
.75566 .42448 .76087 .43418 .77196 .42927 .76684 .42042 Mtetra
.644 .674 .864 r
.76684 .42042 .77196 .42927 .78315 .42517 .77812 .41721 Mtetra
.629 .692 .89 r
.77812 .41721 .78315 .42517 .79442 .42163 .78949 .41449 Mtetra
.624 .717 .913 r
.78949 .41449 .79442 .42163 .80577 .41842 .80092 .41183 Mtetra
.623 .736 .928 r
.80092 .41183 .80577 .41842 .81719 .41538 .8124 .40912 Mtetra
.631 .752 .935 r
.8124 .40912 .81719 .41538 .82865 .41231 .8239 .40617 Mtetra
.637 .76 .937 r
.8239 .40617 .82865 .41231 .84015 .40917 .83544 .40301 Mtetra
.645 .763 .935 r
.83544 .40301 .84015 .40917 .85169 .4059 .84701 .39965 Mtetra
.651 .763 .932 r
.84701 .39965 .85169 .4059 .86327 .40253 .85861 .39613 Mtetra
.655 .76 .927 r
.85861 .39613 .86327 .40253 .87489 .39908 .87025 .39251 Mtetra
.656 .756 .923 r
.87025 .39251 .87489 .39908 .88655 .39556 .88193 .38884 Mtetra
.646 .749 .924 r
.25789 .57635 .2641 .58177 .27348 .57886 .26728 .57361 Mtetra
.646 .756 .929 r
.26728 .57361 .27348 .57886 .2829 .5759 .2767 .57086 Mtetra
.648 .765 .934 r
.2767 .57086 .2829 .5759 .29236 .57285 .28616 .56803 Mtetra
.653 .776 .938 r
.28616 .56803 .29236 .57285 .30186 .56966 .29567 .56506 Mtetra
.661 .787 .941 r
.29567 .56506 .30186 .56966 .3114 .56627 .30523 .56187 Mtetra
.674 .798 .941 r
.30523 .56187 .3114 .56627 .32099 .56269 .31483 .55838 Mtetra
.691 .806 .936 r
.31483 .55838 .32099 .56269 .33062 .55887 .32449 .55448 Mtetra
.705 .805 .927 r
.32449 .55448 .33062 .55887 .34029 .55501 .33421 .55022 Mtetra
.717 .793 .911 r
.33421 .55022 .34029 .55501 .34998 .55121 .34397 .54558 Mtetra
.711 .763 .893 r
.34397 .54558 .34998 .55121 .35968 .54787 .35375 .54102 Mtetra
.692 .72 .871 r
.35375 .54102 .35968 .54787 .36937 .54536 .36354 .53685 Mtetra
.651 .663 .849 r
.36354 .53685 .36937 .54536 .37905 .54391 .3733 .5338 Mtetra
.592 .604 .832 r
.3733 .5338 .37905 .54391 .38873 .54382 .38303 .5325 Mtetra
.536 .553 .819 r
.38303 .5325 .38873 .54382 .39844 .54413 .39274 .53289 Mtetra
.465 .517 .827 r
.39274 .53289 .39844 .54413 .40822 .54419 .40244 .53503 Mtetra
.448 .556 .873 r
.40244 .53503 .40822 .54419 .41812 .54199 .41222 .53685 Mtetra
.465 .705 .972 r
.41222 .53685 .41812 .54199 .42817 .53613 .42212 .53682 Mtetra
.542 .927 .889 r
.42212 .53682 .42817 .53613 .43833 .52684 .4322 .53217 Mtetra
.625 .902 .598 r
.4322 .53217 .43833 .52684 .44855 .51462 .44246 .5214 Mtetra
.667 .888 .531 r
.44246 .5214 .44855 .51462 .45872 .50441 .45277 .50796 Mtetra
.872 .989 .73 r
.45277 .50796 .45872 .50441 .4688 .49929 .46306 .49437 Mtetra
.795 .808 .863 r
.46306 .49437 .4688 .49929 .47879 .50225 .47324 .48662 Mtetra
.535 .493 .756 r
.47324 .48662 .47879 .50225 .48876 .51336 .48331 .48757 Mtetra
.421 .349 .67 r
.48331 .48757 .48876 .51336 .49888 .52275 .49338 .49553 Mtetra
.339 .287 .653 r
.49338 .49553 .49888 .52275 .50914 .52485 .50353 .50778 Mtetra
.42 .41 .742 r
.50353 .50778 .50914 .52485 .5195 .5142 .51384 .51305 Mtetra
.675 .943 .962 r
.51384 .51305 .5195 .5142 .52983 .49154 .52424 .50793 Mtetra
.212 0 .192 r
.52424 .50793 .52983 .49154 .54008 .46924 .53465 .49799 Mtetra
.362 .089 .358 r
.53465 .49799 .54008 .46924 .5503 .45343 .54506 .48706 Mtetra
.495 .215 .418 r
.54506 .48706 .5503 .45343 .56061 .45013 .55552 .48378 Mtetra
.572 .282 .437 r
.55552 .48378 .56061 .45013 .57114 .45939 .56613 .48817 Mtetra
.565 .264 .417 r
.56613 .48817 .57114 .45939 .58191 .47521 .5768 .49159 Mtetra
.473 .127 .299 r
.5768 .49159 .58191 .47521 .59285 .49146 .58747 .49018 Mtetra
.894 .94 .834 r
.58747 .49018 .59285 .49146 .60366 .49568 .59797 .47831 Mtetra
.79 .625 .676 r
.59797 .47831 .60366 .49568 .61422 .48704 .60826 .45935 Mtetra
.703 .53 .652 r
.60826 .45935 .61422 .48704 .62456 .471 .61862 .44468 Mtetra
.649 .5 .667 r
.61862 .44468 .62456 .471 .63481 .45318 .62918 .43707 Mtetra
.531 .49 .756 r
.62918 .43707 .63481 .45318 .6453 .44357 .64005 .43828 Mtetra
0 .28 .756 r
.64005 .43828 .6453 .44357 .65611 .44217 .65123 .44545 Mtetra
.638 .126 .013 r
.65123 .44545 .65611 .44217 .66721 .44596 .66252 .4525 Mtetra
.572 .109 .116 r
.66252 .4525 .66721 .44596 .6785 .45182 .6738 .45685 Mtetra
.251 0 0 r
.6738 .45685 .6785 .45182 .68975 .45472 .68487 .45499 Mtetra
.644 .967 .878 r
.68487 .45499 .68975 .45472 .70089 .45413 .69575 .44838 Mtetra
.801 .812 .86 r
.69575 .44838 .70089 .45413 .71188 .44979 .70654 .43987 Mtetra
.761 .697 .791 r
.70654 .43987 .71188 .44979 .72277 .44311 .71733 .43101 Mtetra
.712 .641 .777 r
.71733 .43101 .72277 .44311 .73366 .43617 .72823 .42393 Mtetra
.679 .624 .787 r
.72823 .42393 .73366 .43617 .7446 .42963 .73926 .41858 Mtetra
.646 .628 .817 r
.73926 .41858 .7446 .42963 .75566 .42448 .75045 .41502 Mtetra
.618 .648 .858 r
.75045 .41502 .75566 .42448 .76684 .42042 .76177 .41263 Mtetra
.601 .686 .901 r
.76177 .41263 .76684 .42042 .77812 .41721 .77318 .41064 Mtetra
.588 .721 .936 r
.77318 .41064 .77812 .41721 .78949 .41449 .78465 .40875 Mtetra
.597 .757 .955 r
.78465 .40875 .78949 .41449 .80092 .41183 .79614 .40645 Mtetra
.608 .778 .962 r
.79614 .40645 .80092 .41183 .8124 .40912 .80766 .40379 Mtetra
.627 .789 .959 r
.80766 .40379 .8124 .40912 .8239 .40617 .81919 .40069 Mtetra
.642 .79 .953 r
.81919 .40069 .8239 .40617 .83544 .40301 .83074 .39728 Mtetra
.653 .785 .945 r
.83074 .39728 .83544 .40301 .84701 .39965 .84232 .39364 Mtetra
.659 .778 .937 r
.84232 .39364 .84701 .39965 .85861 .39613 .85393 .38985 Mtetra
.663 .77 .929 r
.85393 .38985 .85861 .39613 .87025 .39251 .86558 .38597 Mtetra
.664 .762 .923 r
.86558 .38597 .87025 .39251 .88193 .38884 .87727 .38207 Mtetra
.64 .747 .927 r
.25164 .57089 .25789 .57635 .26728 .57361 .26104 .56828 Mtetra
.637 .752 .931 r
.26104 .56828 .26728 .57361 .2767 .57086 .27047 .5657 Mtetra
.637 .759 .936 r
.27047 .5657 .2767 .57086 .28616 .56803 .27993 .5631 Mtetra
.639 .769 .942 r
.27993 .5631 .28616 .56803 .29567 .56506 .28944 .56041 Mtetra
.642 .782 .948 r
.28944 .56041 .29567 .56506 .30523 .56187 .29899 .5576 Mtetra
.653 .8 .953 r
.29899 .5576 .30523 .56187 .31483 .55838 .3086 .55451 Mtetra
.67 .821 .956 r
.3086 .55451 .31483 .55838 .32449 .55448 .31826 .55099 Mtetra
.693 .841 .954 r
.31826 .55099 .32449 .55448 .33421 .55022 .32799 .54693 Mtetra
.722 .853 .944 r
.32799 .54693 .33421 .55022 .34397 .54558 .33779 .54214 Mtetra
.74 .85 .931 r
.33779 .54214 .34397 .54558 .35375 .54102 .34764 .53689 Mtetra
.75 .824 .91 r
.34764 .53689 .35375 .54102 .36354 .53685 .35753 .53127 Mtetra
.726 .77 .888 r
.35753 .53127 .36354 .53685 .3733 .5338 .36741 .52618 Mtetra
.679 .698 .861 r
.36741 .52618 .3733 .5338 .38303 .5325 .37727 .52229 Mtetra
.606 .609 .828 r
.37727 .52229 .38303 .5325 .39274 .53289 .38706 .52053 Mtetra
.513 .523 .804 r
.38706 .52053 .39274 .53289 .40244 .53503 .3968 .52167 Mtetra
.451 .473 .79 r
.3968 .52167 .40244 .53503 .41222 .53685 .40652 .5247 Mtetra
.385 .455 .81 r
.40652 .5247 .41222 .53685 .42212 .53682 .41629 .5288 Mtetra
.458 .597 .903 r
.41629 .5288 .42212 .53682 .4322 .53217 .42622 .53001 Mtetra
.666 .901 .979 r
.42622 .53001 .4322 .53217 .44246 .5214 .43635 .52581 Mtetra
.633 .924 .657 r
.43635 .52581 .44246 .5214 .45277 .50796 .44665 .51603 Mtetra
.64 .85 .461 r
.44665 .51603 .45277 .50796 .46306 .49437 .45705 .50116 Mtetra
.708 .903 .539 r
.45705 .50116 .46306 .49437 .47324 .48662 .46741 .48678 Mtetra
.864 .974 .857 r
.46741 .48678 .47324 .48662 .48331 .48757 .47768 .47655 Mtetra
.583 .586 .821 r
.47768 .47655 .48331 .48757 .49338 .49553 .48784 .4755 Mtetra
.333 .326 .702 r
.48784 .4755 .49338 .49553 .50353 .50778 .49797 .48457 Mtetra
.315 .293 .674 r
.49797 .48457 .50353 .50778 .51384 .51305 .5082 .49579 Mtetra
.275 .316 .724 r
.5082 .49579 .51384 .51305 .52424 .50793 .51857 .50516 Mtetra
0 .347 .707 r
.51857 .50516 .52424 .50793 .53465 .49799 .52905 .50946 Mtetra
.424 .034 .193 r
.52905 .50946 .53465 .49799 .54506 .48706 .53959 .50786 Mtetra
.454 .135 .334 r
.53959 .50786 .54506 .48706 .55552 .48378 .55017 .50458 Mtetra
.419 .104 .322 r
.55017 .50458 .55552 .48378 .56613 .48817 .56077 .49961 Mtetra
0 0 0 r
.56077 .49961 .56613 .48817 .5768 .49159 .57132 .48871 Mtetra
.922 .865 .766 r
.57132 .48871 .5768 .49159 .58747 .49018 .58177 .47268 Mtetra
.782 .62 .679 r
.58177 .47268 .58747 .49018 .59797 .47831 .59214 .45475 Mtetra
.73 .561 .662 r
.59214 .45475 .59797 .47831 .60826 .45935 .60251 .43892 Mtetra
.645 .524 .702 r
.60251 .43892 .60826 .45935 .61862 .44468 .61312 .4333 Mtetra
.407 .488 .83 r
.61312 .4333 .61862 .44468 .62918 .43707 .62403 .43696 Mtetra
.621 .056 0 r
.62403 .43696 .62918 .43707 .64005 .43828 .63517 .44487 Mtetra
.671 .224 .181 r
.63517 .44487 .64005 .43828 .65123 .44545 .64646 .45332 Mtetra
.547 .103 .148 r
.64646 .45332 .65123 .44545 .66252 .4525 .65765 .45661 Mtetra
.153 0 0 r
.65765 .45661 .66252 .4525 .6738 .45685 .66869 .45425 Mtetra
.804 .928 .916 r
.66869 .45425 .6738 .45685 .68487 .45499 .67952 .44634 Mtetra
.805 .736 .788 r
.67952 .44634 .68487 .45499 .69575 .44838 .69021 .43545 Mtetra
.745 .645 .75 r
.69021 .43545 .69575 .44838 .70654 .43987 .70095 .42564 Mtetra
.708 .613 .748 r
.70095 .42564 .70654 .43987 .71733 .43101 .7118 .41774 Mtetra
.665 .603 .775 r
.7118 .41774 .71733 .43101 .72823 .42393 .72284 .41282 Mtetra
.625 .617 .822 r
.72284 .41282 .72823 .42393 .73926 .41858 .73406 .41009 Mtetra
.585 .658 .887 r
.73406 .41009 .73926 .41858 .75045 .41502 .74542 .4086 Mtetra
.54 .704 .946 r
.74542 .4086 .75045 .41502 .76177 .41263 .75688 .40766 Mtetra
.528 .758 .981 r
.75688 .40766 .76177 .41263 .77318 .41064 .76837 .40634 Mtetra
.535 .792 .992 r
.76837 .40634 .77318 .41064 .78465 .40875 .77989 .40455 Mtetra
.577 .816 .989 r
.77989 .40455 .78465 .40875 .79614 .40645 .7914 .40201 Mtetra
.613 .821 .98 r
.7914 .40201 .79614 .40645 .80766 .40379 .80292 .3989 Mtetra
.642 .814 .966 r
.80292 .3989 .80766 .40379 .81919 .40069 .81445 .39535 Mtetra
.659 .803 .952 r
.81445 .39535 .81919 .40069 .83074 .39728 .82601 .39149 Mtetra
.666 .789 .94 r
.82601 .39149 .83074 .39728 .84232 .39364 .83759 .3875 Mtetra
.669 .779 .931 r
.83759 .3875 .84232 .39364 .85393 .38985 .84921 .38343 Mtetra
.67 .77 .925 r
.84921 .38343 .85393 .38985 .86558 .38597 .86087 .37932 Mtetra
.669 .762 .92 r
.86087 .37932 .86558 .38597 .87727 .38207 .87259 .37524 Mtetra
.639 .747 .927 r
.24535 .5654 .25164 .57089 .26104 .56828 .25477 .5628 Mtetra
.635 .747 .929 r
.25477 .5628 .26104 .56828 .27047 .5657 .26421 .56027 Mtetra
.631 .749 .932 r
.26421 .56027 .27047 .5657 .27993 .5631 .27368 .55779 Mtetra
.627 .753 .937 r
.27368 .55779 .27993 .5631 .28944 .56041 .28319 .55537 Mtetra
.621 .762 .946 r
.28319 .55537 .28944 .56041 .29899 .5576 .29273 .553 Mtetra
.622 .781 .957 r
.29273 .553 .29899 .5576 .3086 .55451 .30232 .55052 Mtetra
.626 .807 .97 r
.30232 .55052 .3086 .55451 .31826 .55099 .31196 .54783 Mtetra
.642 .847 .978 r
.31196 .54783 .31826 .55099 .32799 .54693 .32167 .5446 Mtetra
.673 .887 .976 r
.32167 .5446 .32799 .54693 .33779 .54214 .33145 .54057 Mtetra
.711 .922 .964 r
.33145 .54057 .33779 .54214 .34764 .53689 .34132 .53556 Mtetra
.765 .933 .94 r
.34132 .53556 .34764 .53689 .35753 .53127 .35128 .52931 Mtetra
.791 .91 .922 r
.35128 .52931 .35753 .53127 .36741 .52618 .36129 .52245 Mtetra
.791 .842 .89 r
.36129 .52245 .36741 .52618 .37727 .52229 .37132 .51535 Mtetra
.73 .732 .853 r
.37132 .51535 .37727 .52229 .38706 .52053 .38131 .50967 Mtetra
.64 .614 .808 r
.38131 .50967 .38706 .52053 .3968 .52167 .3912 .50664 Mtetra
.544 .505 .762 r
.3912 .50664 .3968 .52167 .40652 .5247 .40101 .50709 Mtetra
.438 .414 .734 r
.40101 .50709 .40652 .5247 .41629 .5288 .41073 .5116 Mtetra
.387 .386 .737 r
.41073 .5116 .41629 .5288 .42622 .53001 .4205 .51755 Mtetra
.325 .416 .801 r
.4205 .51755 .42622 .53001 .43635 .52581 .43037 .52291 Mtetra
.282 .712 .968 r
.43037 .52291 .43635 .52581 .44665 .51603 .44046 .52324 Mtetra
0 0 0 r
.44046 .52324 .44665 .51603 .45705 .50116 .45077 .51599 Mtetra
0 0 .03 r
.45077 .51599 .45705 .50116 .46741 .48678 .46122 .50249 Mtetra
0 0 0 r
.46122 .50249 .46741 .48678 .47768 .47655 .47171 .48463 Mtetra
.6 .824 .434 r
.47171 .48463 .47768 .47655 .48784 .4755 .48211 .47007 Mtetra
.776 .796 .869 r
.48211 .47007 .48784 .4755 .49797 .48457 .49241 .46294 Mtetra
.498 .423 .702 r
.49241 .46294 .49797 .48457 .5082 .49579 .50265 .46613 Mtetra
.35 .286 .643 r
.50265 .46613 .5082 .49579 .51857 .50516 .51293 .47876 Mtetra
.319 .279 .656 r
.51293 .47876 .51857 .50516 .52905 .50946 .52335 .49137 Mtetra
.363 .366 .729 r
.52335 .49137 .52905 .50946 .53959 .50786 .53391 .49872 Mtetra
.649 .663 .85 r
.53391 .49872 .53959 .50786 .55017 .50458 .5445 .49541 Mtetra
.827 .721 .748 r
.5445 .49541 .55017 .50458 .56077 .49961 .55504 .48142 Mtetra
.786 .618 .672 r
.55504 .48142 .56077 .49961 .57132 .48871 .56549 .46211 Mtetra
.739 .557 .646 r
.56549 .46211 .57132 .48871 .58177 .47268 .57587 .44272 Mtetra
.658 .495 .651 r
.57587 .44272 .58177 .47268 .59214 .45475 .58637 .43278 Mtetra
.551 .457 .701 r
.58637 .43278 .59214 .45475 .60251 .43892 .59709 .43324 Mtetra
0 .219 .712 r
.59709 .43324 .60251 .43892 .61312 .4333 .60808 .44124 Mtetra
.714 .294 .248 r
.60808 .44124 .61312 .4333 .62403 .43696 .61928 .45262 Mtetra
.619 .257 .334 r
.61928 .45262 .62403 .43696 .63517 .44487 .63048 .45963 Mtetra
.507 .143 .282 r
.63048 .45963 .63517 .44487 .64646 .45332 .64157 .46032 Mtetra
0 0 0 r
.64157 .46032 .64646 .45332 .65765 .45661 .65243 .45329 Mtetra
.886 .889 .827 r
.65243 .45329 .65765 .45661 .66869 .45425 .66309 .4411 Mtetra
.778 .658 .729 r
.66309 .4411 .66869 .45425 .67952 .44634 .67371 .4283 Mtetra
.725 .588 .702 r
.67371 .4283 .67952 .44634 .69021 .43545 .68437 .41692 Mtetra
.673 .556 .714 r
.68437 .41692 .69021 .43545 .70095 .42564 .69525 .40969 Mtetra
.63 .553 .749 r
.69525 .40969 .70095 .42564 .7118 .41774 .70634 .40602 Mtetra
.575 .58 .821 r
.70634 .40602 .7118 .41774 .72284 .41282 .71764 .40508 Mtetra
.488 .633 .917 r
.71764 .40508 .72284 .41282 .73406 .41009 .72909 .40561 Mtetra
.395 .712 .986 r
.72909 .40561 .73406 .41009 .74542 .4086 .74061 .40589 Mtetra
.326 .751 .974 r
.74061 .40589 .74542 .4086 .75688 .40766 .75215 .40556 Mtetra
.393 .812 .972 r
.75215 .40556 .75688 .40766 .76837 .40634 .76367 .40396 Mtetra
.5 .858 .99 r
.76367 .40396 .76837 .40634 .77989 .40455 .77517 .40135 Mtetra
.598 .869 .993 r
.77517 .40135 .77989 .40455 .7914 .40201 .78665 .39789 Mtetra
.651 .851 .977 r
.78665 .39789 .7914 .40201 .80292 .3989 .79814 .39388 Mtetra
.672 .822 .955 r
.79814 .39388 .80292 .3989 .81445 .39535 .80965 .38964 Mtetra
.679 .798 .938 r
.80965 .38964 .81445 .39535 .82601 .39149 .8212 .38528 Mtetra
.677 .78 .927 r
.8212 .38528 .82601 .39149 .83759 .3875 .83279 .38097 Mtetra
.676 .769 .921 r
.83279 .38097 .83759 .3875 .84921 .38343 .84443 .37671 Mtetra
.673 .762 .918 r
.84443 .37671 .84921 .38343 .86087 .37932 .85612 .3725 Mtetra
.67 .758 .917 r
.85612 .3725 .86087 .37932 .87259 .37524 .86786 .36837 Mtetra
.646 .749 .924 r
.23902 .55988 .24535 .5654 .25477 .5628 .24847 .55708 Mtetra
.643 .742 .921 r
.24847 .55708 .25477 .5628 .26421 .56027 .25794 .55436 Mtetra
.638 .735 .919 r
.25794 .55436 .26421 .56027 .27368 .55779 .26744 .55176 Mtetra
.631 .729 .918 r
.26744 .55176 .27368 .55779 .28319 .55537 .27697 .54932 Mtetra
.619 .726 .922 r
.27697 .54932 .28319 .55537 .29273 .553 .28652 .54711 Mtetra
.611 .73 .93 r
.28652 .54711 .29273 .553 .30232 .55052 .29609 .54504 Mtetra
.601 .742 .944 r
.29609 .54504 .30232 .55052 .31196 .54783 .3057 .5431 Mtetra
.603 .773 .961 r
.3057 .5431 .31196 .54783 .32167 .5446 .31537 .54093 Mtetra
.613 .82 .98 r
.31537 .54093 .32167 .5446 .33145 .54057 .3251 .5383 Mtetra
.641 .885 .985 r
.3251 .5383 .33145 .54057 .34132 .53556 .33493 .53469 Mtetra
.69 .943 .961 r
.33493 .53469 .34132 .53556 .35128 .52931 .34486 .52964 Mtetra
.731 .977 .921 r
.34486 .52964 .35128 .52931 .36129 .52245 .3549 .52312 Mtetra
.798 .986 .891 r
.3549 .52312 .36129 .52245 .37132 .51535 .36503 .515 Mtetra
.825 .961 .898 r
.36503 .515 .37132 .51535 .38131 .50967 .37517 .50666 Mtetra
.807 .872 .895 r
.37517 .50666 .38131 .50967 .3912 .50664 .38529 .49908 Mtetra
.702 .711 .855 r
.38529 .49908 .3912 .50664 .40101 .50709 .39531 .4943 Mtetra
.565 .547 .793 r
.39531 .4943 .40101 .50709 .41073 .5116 .4052 .49383 Mtetra
.463 .428 .734 r
.4052 .49383 .41073 .5116 .4205 .51755 .41501 .49753 Mtetra
.367 .348 .706 r
.41501 .49753 .4205 .51755 .43037 .52291 .42478 .50507 Mtetra
.369 .37 .729 r
.42478 .50507 .43037 .52291 .44046 .52324 .43468 .51174 Mtetra
.438 .503 .829 r
.43468 .51174 .44046 .52324 .45077 .51599 .44477 .51443 Mtetra
.629 .916 .979 r
.44477 .51443 .45077 .51599 .46122 .50249 .45508 .51032 Mtetra
0 0 0 r
.45508 .51032 .46122 .50249 .47171 .48463 .46556 .49845 Mtetra
.46556 .49845 .47171 .48463 .48211 .47007 .47607 .48313 Mtetra
.47607 .48313 .48211 .47007 .49241 .46294 .48656 .46771 Mtetra
.48656 .46771 .49241 .46294 .50265 .46613 .49694 .45932 Mtetra
.484 .655 .935 r
.49694 .45932 .50265 .46613 .51293 .47876 .50729 .4596 Mtetra
.483 .432 .724 r
.50729 .4596 .51293 .47876 .52335 .49137 .51769 .46297 Mtetra
.514 .403 .665 r
.51769 .46297 .52335 .49137 .53391 .49872 .52817 .46605 Mtetra
.592 .443 .648 r
.52817 .46605 .53391 .49872 .5445 .49541 .53871 .46269 Mtetra
.65 .482 .644 r
.53871 .46269 .5445 .49541 .55504 .48142 .54924 .45289 Mtetra
.664 .503 .656 r
.54924 .45289 .55504 .48142 .56549 .46211 .55977 .44277 Mtetra
.668 .545 .705 r
.55977 .44277 .56549 .46211 .57587 .44272 .57033 .43573 Mtetra
.396 .607 .933 r
.57033 .43573 .57587 .44272 .58637 .43278 .58107 .43743 Mtetra
.687 .216 .128 r
.58107 .43743 .58637 .43278 .59709 .43324 .59202 .44623 Mtetra
.652 .272 .312 r
.59202 .44623 .59709 .43324 .60808 .44124 .6031 .45499 Mtetra
.595 .219 .299 r
.6031 .45499 .60808 .44124 .61928 .45262 .6142 .46028 Mtetra
.304 0 .007 r
.6142 .46028 .61928 .45262 .63048 .45963 .62517 .45773 Mtetra
.843 .946 .887 r
.62517 .45773 .63048 .45963 .64157 .46032 .63595 .44827 Mtetra
.796 .678 .733 r
.63595 .44827 .64157 .46032 .65243 .45329 .64659 .43472 Mtetra
.75 .599 .688 r
.64659 .43472 .65243 .45329 .66309 .4411 .65716 .42025 Mtetra
.7 .557 .689 r
.65716 .42025 .66309 .4411 .67371 .4283 .66787 .40967 Mtetra
.661 .548 .716 r
.66787 .40967 .67371 .4283 .68437 .41692 .67877 .40333 Mtetra
.6 .564 .786 r
.67877 .40333 .68437 .41692 .69525 .40969 .68993 .4014 Mtetra
.475 .609 .905 r
.68993 .4014 .69525 .40969 .70634 .40602 .7013 .40236 Mtetra
.202 .633 .949 r
.7013 .40236 .70634 .40602 .71764 .40508 .7128 .40411 Mtetra
0 .523 .743 r
.7128 .40411 .71764 .40508 .72909 .40561 .72436 .40565 Mtetra
0 0 0 r
.72436 .40565 .72909 .40561 .74061 .40589 .7359 .40555 Mtetra
.213 .737 .83 r
.7359 .40555 .74061 .40589 .75215 .40556 .74741 .40395 Mtetra
.485 .876 .966 r
.74741 .40395 .75215 .40556 .76367 .40396 .75886 .40086 Mtetra
.634 .886 .987 r
.75886 .40086 .76367 .40396 .77517 .40135 .7703 .39674 Mtetra
.684 .842 .959 r
.7703 .39674 .77517 .40135 .78665 .39789 .78173 .39214 Mtetra
.697 .802 .93 r
.78173 .39214 .78665 .39789 .79814 .39388 .79319 .3873 Mtetra
.692 .772 .913 r
.79319 .3873 .79814 .39388 .80965 .38964 .8047 .38258 Mtetra
.686 .754 .904 r
.8047 .38258 .80965 .38964 .8212 .38528 .81626 .378 Mtetra
.677 .745 .902 r
.81626 .378 .8212 .38528 .83279 .38097 .82788 .37366 Mtetra
.671 .742 .904 r
.82788 .37366 .83279 .38097 .84443 .37671 .83956 .36948 Mtetra
.667 .744 .908 r
.83956 .36948 .84443 .37671 .85612 .3725 .85131 .36542 Mtetra
.664 .749 .913 r
.85131 .36542 .85612 .3725 .86786 .36837 .8631 .36144 Mtetra
.661 .753 .918 r
.23264 .55431 .23902 .55988 .24847 .55708 .24214 .55116 Mtetra
.659 .74 .91 r
.24214 .55116 .24847 .55708 .25794 .55436 .25166 .54803 Mtetra
.654 .726 .902 r
.25166 .54803 .25794 .55436 .26744 .55176 .26121 .54504 Mtetra
.645 .711 .896 r
.26121 .54504 .26744 .55176 .27697 .54932 .27078 .54226 Mtetra
.632 .698 .893 r
.27078 .54226 .27697 .54932 .28652 .54711 .28036 .53981 Mtetra
.616 .685 .892 r
.28036 .53981 .28652 .54711 .29609 .54504 .28995 .53773 Mtetra
.594 .678 .899 r
.28995 .53773 .29609 .54504 .3057 .5431 .29955 .53616 Mtetra
.577 .684 .914 r
.29955 .53616 .3057 .5431 .31537 .54093 .30917 .53487 Mtetra
.554 .707 .942 r
.30917 .53487 .31537 .54093 .3251 .5383 .31882 .53383 Mtetra
.547 .768 .98 r
.31882 .53383 .3251 .5383 .33493 .53469 .32855 .5324 Mtetra
.533 .853 .997 r
.32855 .5324 .33493 .53469 .34486 .52964 .33836 .53012 Mtetra
.499 .905 .901 r
.33836 .53012 .34486 .52964 .3549 .52312 .34831 .5262 Mtetra
.491 .886 .725 r
.34831 .5262 .3549 .52312 .36503 .515 .3584 .51993 Mtetra
.514 .862 .607 r
.3584 .51993 .36503 .515 .37517 .50666 .36862 .51146 Mtetra
.697 .951 .677 r
.36862 .51146 .37517 .50666 .38529 .49908 .37893 .50081 Mtetra
.854 .994 .83 r
.37893 .50081 .38529 .49908 .39531 .4943 .38924 .49014 Mtetra
.826 .83 .852 r
.38924 .49014 .39531 .4943 .4052 .49383 .39948 .48107 Mtetra
.671 .603 .77 r
.39948 .48107 .4052 .49383 .41501 .49753 .40958 .47612 Mtetra
.54 .45 .702 r
.40958 .47612 .41501 .49753 .42478 .50507 .41952 .477 Mtetra
.462 .367 .661 r
.41952 .477 .42478 .50507 .43468 .51174 .42938 .48287 Mtetra
.387 .312 .65 r
.42938 .48287 .43468 .51174 .44477 .51443 .43923 .49283 Mtetra
.329 .313 .689 r
.43923 .49283 .44477 .51443 .45508 .51032 .4492 .50227 Mtetra
.116 .406 .856 r
.4492 .50227 .45508 .51032 .46556 .49845 .45937 .50784 Mtetra
.368 0 .099 r
.45937 .50784 .46556 .49845 .47607 .48313 .46976 .5059 Mtetra
.279 0 .275 r
.46976 .5059 .47607 .48313 .48656 .46771 .48032 .49494 Mtetra
.17 0 .265 r
.48032 .49494 .48656 .46771 .49694 .45932 .49094 .47723 Mtetra
0 0 0 r
.49094 .47723 .49694 .45932 .50729 .4596 .50154 .4557 Mtetra
.919 .822 .735 r
.50154 .4557 .50729 .4596 .51769 .46297 .51205 .43723 Mtetra
.69 .527 .662 r
.51205 .43723 .51769 .46297 .52817 .46605 .52249 .42529 Mtetra
.584 .42 .626 r
.52249 .42529 .52817 .46605 .53871 .46269 .53295 .42188 Mtetra
.503 .364 .624 r
.53295 .42188 .53871 .46269 .54924 .45289 .54349 .42702 Mtetra
.334 .293 .662 r
.54349 .42702 .54924 .45289 .55977 .44277 .55419 .43876 Mtetra
.752 .25 0 r
.55419 .43876 .55977 .44277 .57033 .43573 .56506 .45363 Mtetra
.662 .312 .37 r
.56506 .45363 .57033 .43573 .58107 .43743 .57604 .46471 Mtetra
.569 .258 .402 r
.57604 .46471 .58107 .43743 .59202 .44623 .58703 .46903 Mtetra
.43 .119 .335 r
.58703 .46903 .59202 .44623 .6031 .45499 .59791 .46425 Mtetra
0 0 0 r
.59791 .46425 .6031 .45499 .6142 .46028 .60863 .45184 Mtetra
.861 .748 .738 r
.60863 .45184 .6142 .46028 .62517 .45773 .61922 .43549 Mtetra
.747 .577 .665 r
.61922 .43549 .62517 .45773 .63595 .44827 .62975 .41855 Mtetra
.681 .511 .649 r
.62975 .41855 .63595 .44827 .64659 .43472 .64037 .40573 Mtetra
.641 .486 .658 r
.64037 .40573 .64659 .43472 .65716 .42025 .65118 .39797 Mtetra
.585 .479 .7 r
.65118 .39797 .65716 .42025 .66787 .40967 .66225 .39616 Mtetra
.477 .497 .799 r
.66225 .39616 .66787 .40967 .67877 .40333 .67357 .39857 Mtetra
.066 .495 .894 r
.67357 .39857 .67877 .40333 .68993 .4014 .68506 .40263 Mtetra
.449 0 0 r
.68506 .40263 .68993 .4014 .7013 .40236 .69665 .40672 Mtetra
.433 0 0 r
.69665 .40672 .7013 .40236 .7128 .40411 .70821 .40858 Mtetra
.309 0 0 r
.70821 .40858 .7128 .40411 .72436 .40565 .71972 .40818 Mtetra
0 0 0 r
.71972 .40818 .72436 .40565 .7359 .40555 .73115 .40536 Mtetra
.486 .9 .888 r
.73115 .40536 .7359 .40555 .74741 .40395 .74251 .40085 Mtetra
.7 .907 .968 r
.74251 .40085 .74741 .40395 .75886 .40086 .75386 .39545 Mtetra
.731 .825 .923 r
.75386 .39545 .75886 .40086 .7703 .39674 .7652 .38964 Mtetra
.716 .763 .89 r
.7652 .38964 .7703 .39674 .78173 .39214 .77659 .38407 Mtetra
.702 .73 .872 r
.77659 .38407 .78173 .39214 .79319 .3873 .78805 .37879 Mtetra
.685 .712 .869 r
.78805 .37879 .79319 .3873 .8047 .38258 .79958 .37403 Mtetra
.674 .707 .873 r
.79958 .37403 .8047 .38258 .81626 .378 .81119 .36965 Mtetra
.664 .709 .881 r
.81119 .36965 .81626 .378 .82788 .37366 .82287 .36561 Mtetra
.657 .716 .891 r
.82287 .36561 .82788 .37366 .83956 .36948 .83463 .3618 Mtetra
.653 .725 .902 r
.83463 .3618 .83956 .36948 .85131 .36542 .84644 .35812 Mtetra
.651 .738 .913 r
.84644 .35812 .85131 .36542 .8631 .36144 .85831 .35446 Mtetra
.675 .756 .912 r
.22623 .54871 .23264 .55431 .24214 .55116 .23577 .54519 Mtetra
.675 .744 .903 r
.23577 .54519 .24214 .55116 .25166 .54803 .24535 .54163 Mtetra
.672 .73 .893 r
.24535 .54163 .25166 .54803 .26121 .54504 .25496 .53813 Mtetra
.665 .713 .884 r
.25496 .53813 .26121 .54504 .27078 .54226 .26458 .53478 Mtetra
.654 .694 .875 r
.26458 .53478 .27078 .54226 .28036 .53981 .27422 .53167 Mtetra
.638 .671 .865 r
.27422 .53167 .28036 .53981 .28995 .53773 .28387 .52898 Mtetra
.616 .648 .859 r
.28387 .52898 .28995 .53773 .29955 .53616 .29351 .52689 Mtetra
.592 .626 .854 r
.29351 .52689 .29955 .53616 .30917 .53487 .30315 .52546 Mtetra
.561 .609 .858 r
.30315 .52546 .30917 .53487 .31882 .53383 .31278 .52483 Mtetra
.54 .61 .872 r
.31278 .52483 .31882 .53383 .32855 .5324 .32244 .52462 Mtetra
.516 .635 .906 r
.32244 .52462 .32855 .5324 .33836 .53012 .33214 .52462 Mtetra
.524 .72 .963 r
.33214 .52462 .33836 .53012 .34831 .5262 .34194 .52383 Mtetra
.541 .855 .997 r
.34194 .52383 .34831 .5262 .3584 .51993 .35187 .52144 Mtetra
.503 .909 .837 r
.35187 .52144 .3584 .51993 .36862 .51146 .36196 .51652 Mtetra
.473 .837 .583 r
.36196 .51652 .36862 .51146 .37893 .50081 .37224 .50828 Mtetra
0 0 0 r
.37224 .50828 .37893 .50081 .38924 .49014 .38262 .49764 Mtetra
.574 .84 .488 r
.38262 .49764 .38924 .49014 .39948 .48107 .39307 .48525 Mtetra
.759 .977 .715 r
.39307 .48525 .39948 .48107 .40958 .47612 .40346 .47406 Mtetra
.817 .914 .905 r
.40346 .47406 .40958 .47612 .41952 .477 .41372 .46614 Mtetra
.626 .612 .817 r
.41372 .46614 .41952 .477 .42938 .48287 .42383 .46351 Mtetra
.468 .42 .72 r
.42383 .46351 .42938 .48287 .43923 .49283 .43381 .46724 Mtetra
.412 .344 .671 r
.43381 .46724 .43923 .49283 .4492 .50227 .44377 .47492 Mtetra
.385 .318 .658 r
.44377 .47492 .4492 .50227 .45937 .50784 .4538 .48442 Mtetra
.436 .373 .689 r
.4538 .48442 .45937 .50784 .46976 .5059 .46401 .49048 Mtetra
.564 .518 .763 r
.46401 .49048 .46976 .5059 .48032 .49494 .47442 .49003 Mtetra
.808 .822 .862 r
.47442 .49003 .48032 .49494 .49094 .47723 .48498 .48148 Mtetra
.874 .979 .683 r
.48498 .48148 .49094 .47723 .50154 .4557 .49562 .46596 Mtetra
0 0 0 r
.49562 .46596 .50154 .4557 .51205 .43723 .50621 .45067 Mtetra
.03 0 .041 r
.50621 .45067 .51205 .43723 .52249 .42529 .51676 .43943 Mtetra
.388 .023 .219 r
.51676 .43943 .52249 .42529 .53295 .42188 .52731 .43602 Mtetra
.58 .209 .301 r
.52731 .43602 .53295 .42188 .54349 .42702 .53792 .44044 Mtetra
.648 .272 .318 r
.53792 .44044 .54349 .42702 .55419 .43876 .54866 .44897 Mtetra
.664 .261 .271 r
.54866 .44897 .55419 .43876 .56506 .45363 .55953 .45778 Mtetra
.435 0 0 r
.55953 .45778 .56506 .45363 .57604 .46471 .57041 .4596 Mtetra
.754 .823 .906 r
.57041 .4596 .57604 .46471 .58703 .46903 .58124 .45326 Mtetra
.756 .622 .711 r
.58124 .45326 .58703 .46903 .59791 .46425 .59195 .44031 Mtetra
.734 .563 .661 r
.59195 .44031 .59791 .46425 .60863 .45184 .60256 .42385 Mtetra
.702 .529 .651 r
.60256 .42385 .60863 .45184 .61922 .43549 .61317 .40919 Mtetra
.676 .518 .664 r
.61317 .40919 .61922 .43549 .62975 .41855 .62388 .39851 Mtetra
.625 .517 .711 r
.62388 .39851 .62975 .41855 .64037 .40573 .63479 .39428 Mtetra
.501 .546 .834 r
.63479 .39428 .64037 .40573 .65118 .39797 .64595 .39544 Mtetra
0 .353 .707 r
.64595 .39544 .65118 .39797 .66225 .39616 .65733 .39997 Mtetra
.589 .07 0 r
.65733 .39997 .66225 .39616 .67357 .39857 .66886 .40574 Mtetra
.554 .092 .11 r
.66886 .40574 .67357 .39857 .68506 .40263 .68041 .40976 Mtetra
.471 .004 .063 r
.68041 .40976 .68506 .40263 .69665 .40672 .69194 .41134 Mtetra
.219 0 0 r
.69194 .41134 .69665 .40672 .70821 .40858 .70336 .40951 Mtetra
.368 .833 .779 r
.70336 .40951 .70821 .40858 .71972 .40818 .71469 .40507 Mtetra
.732 .913 .956 r
.71469 .40507 .71972 .40818 .73115 .40536 .72596 .39899 Mtetra
.757 .797 .885 r
.72596 .39899 .73115 .40536 .74251 .40085 .7372 .39206 Mtetra
.732 .722 .841 r
.7372 .39206 .74251 .40085 .75386 .39545 .74848 .38534 Mtetra
.712 .685 .823 r
.74848 .38534 .75386 .39545 .7652 .38964 .75981 .37904 Mtetra
.69 .666 .822 r
.75981 .37904 .7652 .38964 .77659 .38407 .77124 .37357 Mtetra
.675 .662 .83 r
.77124 .37357 .77659 .38407 .78805 .37879 .78276 .36878 Mtetra
.662 .667 .844 r
.78276 .36878 .78805 .37879 .79958 .37403 .79436 .3646 Mtetra
.652 .676 .86 r
.79436 .3646 .79958 .37403 .81119 .36965 .80606 .36086 Mtetra
.646 .69 .877 r
.80606 .36086 .81119 .36965 .82287 .36561 .81782 .35736 Mtetra
.641 .704 .892 r
.81782 .35736 .82287 .36561 .83463 .3618 .82965 .35403 Mtetra
.638 .718 .905 r
.82965 .35403 .83463 .3618 .84644 .35812 .84154 .35075 Mtetra
.639 .732 .916 r
.84154 .35075 .84644 .35812 .85831 .35446 .85348 .34743 Mtetra
.683 .757 .908 r
.21976 .54307 .22623 .54871 .23577 .54519 .22935 .53932 Mtetra
.686 .751 .901 r
.22935 .53932 .23577 .54519 .24535 .54163 .23898 .53543 Mtetra
.687 .741 .892 r
.23898 .53543 .24535 .54163 .25496 .53813 .24864 .53149 Mtetra
.686 .728 .882 r
.24864 .53149 .25496 .53813 .26458 .53478 .25833 .52752 Mtetra
.683 .71 .869 r
.25833 .52752 .26458 .53478 .27422 .53167 .26805 .52355 Mtetra
.671 .684 .854 r
.26805 .52355 .27422 .53167 .28387 .52898 .27779 .5198 Mtetra
.655 .654 .837 r
.27779 .5198 .28387 .52898 .29351 .52689 .28753 .51645 Mtetra
.63 .618 .82 r
.28753 .51645 .29351 .52689 .30315 .52546 .29725 .51381 Mtetra
.597 .582 .807 r
.29725 .51381 .30315 .52546 .31278 .52483 .30695 .51218 Mtetra
.563 .549 .797 r
.30695 .51218 .31278 .52483 .32244 .52462 .31662 .51167 Mtetra
.52 .521 .797 r
.31662 .51167 .32244 .52462 .33214 .52462 .32627 .51249 Mtetra
.486 .517 .815 r
.32627 .51249 .33214 .52462 .34194 .52383 .33593 .51405 Mtetra
.438 .543 .866 r
.33593 .51405 .34194 .52383 .35187 .52144 .34564 .51597 Mtetra
.38 .66 .968 r
.34564 .51597 .35187 .52144 .36196 .51652 .35546 .51689 Mtetra
.128 .677 .757 r
.35546 .51689 .36196 .51652 .37224 .50828 .36545 .51573 Mtetra
.121 0 0 r
.36545 .51573 .37224 .50828 .38262 .49764 .37564 .51123 Mtetra
.12 0 .064 r
.37564 .51123 .38262 .49764 .39307 .48525 .38603 .50245 Mtetra
.079 0 .11 r
.38603 .50245 .39307 .48525 .40346 .47406 .39656 .49027 Mtetra
0 0 .011 r
.39656 .49027 .40346 .47406 .41372 .46614 .40718 .47541 Mtetra
0 0 0 r
.40718 .47541 .41372 .46614 .42383 .46351 .41775 .46071 Mtetra
.886 .867 .815 r
.41775 .46071 .42383 .46351 .43381 .46724 .42823 .44826 Mtetra
.679 .552 .703 r
.42823 .44826 .43381 .46724 .44377 .47492 .43856 .44044 Mtetra
.571 .423 .641 r
.43856 .44044 .44377 .47492 .4538 .48442 .44876 .43875 Mtetra
.514 .362 .612 r
.44876 .43875 .4538 .48442 .46401 .49048 .4589 .44288 Mtetra
.463 .322 .604 r
.4589 .44288 .46401 .49048 .47442 .49003 .46902 .45241 Mtetra
.381 .283 .617 r
.46902 .45241 .47442 .49003 .48498 .48148 .47922 .46568 Mtetra
0 .108 .644 r
.47922 .46568 .48498 .48148 .49562 .46596 .48955 .48038 Mtetra
.679 .313 .346 r
.48955 .48038 .49562 .46596 .50621 .45067 .50006 .49165 Mtetra
.566 .281 .442 r
.50006 .49165 .50621 .45067 .51676 .43943 .51073 .49658 Mtetra
.508 .248 .455 r
.51073 .49658 .51676 .43943 .52731 .43602 .52151 .4932 Mtetra
.447 .197 .441 r
.52151 .4932 .52731 .43602 .53792 .44044 .53231 .48148 Mtetra
.32 .074 .375 r
.53231 .48148 .53792 .44044 .54866 .44897 .54307 .46337 Mtetra
0 0 0 r
.54307 .46337 .54866 .44897 .55953 .45778 .55373 .44174 Mtetra
.81 .645 .677 r
.55373 .44174 .55953 .45778 .57041 .4596 .56434 .4215 Mtetra
.68 .492 .625 r
.56434 .4215 .57041 .4596 .58124 .45326 .57494 .40498 Mtetra
.627 .44 .611 r
.57494 .40498 .58124 .45326 .59195 .44031 .58559 .39387 Mtetra
.591 .417 .615 r
.58559 .39387 .59195 .44031 .60256 .42385 .59636 .38863 Mtetra
.542 .403 .641 r
.59636 .38863 .60256 .42385 .61317 .40919 .60733 .38961 Mtetra
.426 .397 .723 r
.60733 .38961 .61317 .40919 .62388 .39851 .6185 .3953 Mtetra
.456 0 0 r
.6185 .3953 .62388 .39851 .63479 .39428 .62986 .40333 Mtetra
.652 .226 .222 r
.62986 .40333 .63479 .39428 .64595 .39544 .64135 .41155 Mtetra
.59 .224 .315 r
.64135 .41155 .64595 .39544 .65733 .39997 .65286 .41708 Mtetra
.532 .175 .307 r
.65286 .41708 .65733 .39997 .66886 .40574 .66433 .41915 Mtetra
.415 .037 .211 r
.66433 .41915 .66886 .40574 .68041 .40976 .67568 .41685 Mtetra
.089 0 0 r
.67568 .41685 .68041 .40976 .69194 .41134 .68692 .41113 Mtetra
.729 .987 .888 r
.68692 .41113 .69194 .41134 .70336 .40951 .69807 .40324 Mtetra
.803 .809 .856 r
.69807 .40324 .70336 .40951 .71469 .40507 .70918 .39431 Mtetra
.748 .687 .792 r
.70918 .39431 .71469 .40507 .72596 .39899 .72032 .38574 Mtetra
.714 .634 .767 r
.72032 .38574 .72596 .39899 .7372 .39206 .73151 .37791 Mtetra
.686 .609 .764 r
.73151 .37791 .7372 .39206 .74848 .38534 .74282 .37144 Mtetra
.667 .602 .774 r
.74282 .37144 .74848 .38534 .75981 .37904 .75424 .36611 Mtetra
.65 .608 .793 r
.75424 .36611 .75981 .37904 .77124 .37357 .76577 .36184 Mtetra
.638 .622 .817 r
.76577 .36184 .77124 .37357 .78276 .36878 .7774 .3583 Mtetra
.631 .643 .844 r
.7774 .3583 .78276 .36878 .79436 .3646 .78912 .35517 Mtetra
.626 .665 .868 r
.78912 .35517 .79436 .3646 .80606 .36086 .80091 .35228 Mtetra
.626 .688 .889 r
.80091 .35228 .80606 .36086 .81782 .35736 .81276 .34938 Mtetra
.625 .706 .904 r
.81276 .34938 .81782 .35736 .82965 .35403 .82466 .34646 Mtetra
.626 .721 .914 r
.82466 .34646 .82965 .35403 .84154 .35075 .83661 .34347 Mtetra
.63 .732 .921 r
.83661 .34347 .84154 .35075 .85348 .34743 .84861 .34035 Mtetra
.678 .756 .91 r
.21326 .53739 .21976 .54307 .22935 .53932 .22285 .53375 Mtetra
.683 .762 .911 r
.22285 .53375 .22935 .53932 .23898 .53543 .23249 .52996 Mtetra
.69 .767 .911 r
.23249 .52996 .23898 .53543 .24864 .53149 .24218 .52598 Mtetra
.696 .768 .907 r
.24218 .52598 .24864 .53149 .25833 .52752 .25191 .52181 Mtetra
.704 .764 .898 r
.25191 .52181 .25833 .52752 .26805 .52355 .26169 .51737 Mtetra
.705 .749 .887 r
.26169 .51737 .26805 .52355 .27779 .5198 .27151 .51283 Mtetra
.701 .725 .869 r
.27151 .51283 .27779 .5198 .28753 .51645 .28135 .50824 Mtetra
.684 .689 .848 r
.28135 .50824 .28753 .51645 .29725 .51381 .2912 .504 Mtetra
.658 .644 .825 r
.2912 .504 .29725 .51381 .30695 .51218 .30104 .5004 Mtetra
.621 .593 .8 r
.30104 .5004 .30695 .51218 .31662 .51167 .31084 .49787 Mtetra
.577 .541 .778 r
.31084 .49787 .31662 .51167 .32627 .51249 .32059 .49686 Mtetra
.535 .495 .758 r
.32059 .49686 .32627 .51249 .33593 .51405 .33029 .49742 Mtetra
.489 .457 .749 r
.33029 .49742 .33593 .51405 .34564 .51597 .33996 .4997 Mtetra
.46 .444 .754 r
.33996 .4997 .34564 .51597 .35546 .51689 .34965 .50282 Mtetra
.433 .458 .785 r
.34965 .50282 .35546 .51689 .36545 .51573 .35941 .50612 Mtetra
.447 .555 .872 r
.35941 .50612 .36545 .51573 .37564 .51123 .36932 .50779 Mtetra
.491 .798 .999 r
.36932 .50779 .37564 .51123 .38603 .50245 .37944 .50641 Mtetra
0 0 0 r
.37944 .50641 .38603 .50245 .39656 .49027 .38977 .50096 Mtetra
.38977 .50096 .39656 .49027 .40718 .47541 .4003 .49079 Mtetra
0 0 .015 r
.4003 .49079 .40718 .47541 .41775 .46071 .41094 .47747 Mtetra
0 0 .028 r
.41094 .47747 .41775 .46071 .42823 .44826 .42161 .46232 Mtetra
0 0 0 r
.42161 .46232 .42823 .44826 .43856 .44044 .43221 .44845 Mtetra
.43221 .44845 .43856 .44044 .44876 .43875 .4427 .43808 Mtetra
.619 .939 .955 r
.4427 .43808 .44876 .43875 .4589 .44288 .45305 .43343 Mtetra
.429 .55 .876 r
.45305 .43343 .4589 .44288 .46902 .45241 .46331 .43543 Mtetra
.317 .349 .737 r
.46331 .43543 .46902 .45241 .47922 .46568 .47356 .44296 Mtetra
.292 .282 .677 r
.47356 .44296 .47922 .46568 .48955 .48038 .48388 .45402 Mtetra
.389 .327 .667 r
.48388 .45402 .48955 .48038 .50006 .49165 .49434 .46296 Mtetra
.498 .392 .664 r
.49434 .46296 .50006 .49165 .51073 .49658 .50496 .46671 Mtetra
.594 .453 .659 r
.50496 .46671 .51073 .49658 .52151 .4932 .51569 .46328 Mtetra
.663 .499 .652 r
.51569 .46328 .52151 .4932 .53231 .48148 .52646 .45266 Mtetra
.707 .531 .647 r
.52646 .45266 .53231 .48148 .54307 .46337 .5372 .43679 Mtetra
.731 .552 .649 r
.5372 .43679 .54307 .46337 .55373 .44174 .54789 .41875 Mtetra
.724 .561 .668 r
.54789 .41875 .55373 .44174 .56434 .4215 .55855 .40422 Mtetra
.703 .581 .716 r
.55855 .40422 .56434 .4215 .57494 .40498 .56927 .39522 Mtetra
.612 .639 .853 r
.56927 .39522 .57494 .40498 .58559 .39387 .5801 .39295 Mtetra
.291 0 0 r
.5801 .39295 .58559 .39387 .59636 .38863 .59111 .39646 Mtetra
.635 .194 .185 r
.59111 .39646 .59636 .38863 .60733 .38961 .60229 .40355 Mtetra
.639 .258 .306 r
.60229 .40355 .60733 .38961 .6185 .3953 .61362 .41198 Mtetra
.605 .241 .326 r
.61362 .41198 .6185 .3953 .62986 .40333 .62503 .41859 Mtetra
.554 .182 .29 r
.62503 .41859 .62986 .40333 .64135 .41155 .63644 .42203 Mtetra
.405 0 .137 r
.63644 .42203 .64135 .41155 .65286 .41708 .64777 .42065 Mtetra
0 0 0 r
.64777 .42065 .65286 .41708 .66433 .41915 .65898 .41511 Mtetra
.816 .884 .893 r
.65898 .41511 .66433 .41915 .67568 .41685 .67008 .40643 Mtetra
.779 .703 .78 r
.67008 .40643 .67568 .41685 .68692 .41113 .68112 .39607 Mtetra
.733 .622 .734 r
.68112 .39607 .68692 .41113 .69807 .40324 .69216 .38586 Mtetra
.706 .587 .719 r
.69216 .38586 .69807 .40324 .70918 .39431 .70324 .37648 Mtetra
.681 .569 .723 r
.70324 .37648 .70918 .39431 .72032 .38574 .71444 .36887 Mtetra
.662 .568 .738 r
.71444 .36887 .72032 .38574 .73151 .37791 .72575 .36287 Mtetra
.644 .577 .764 r
.72575 .36287 .73151 .37791 .74282 .37144 .73721 .35842 Mtetra
.629 .596 .797 r
.73721 .35842 .74282 .37144 .75424 .36611 .74878 .3551 Mtetra
.617 .625 .836 r
.74878 .3551 .75424 .36611 .76577 .36184 .76045 .35243 Mtetra
.607 .657 .873 r
.76045 .35243 .76577 .36184 .7774 .3583 .7722 .35012 Mtetra
.606 .69 .903 r
.7722 .35012 .7774 .3583 .78912 .35517 .78402 .34777 Mtetra
.606 .716 .922 r
.78402 .34777 .78912 .35517 .80091 .35228 .79588 .34531 Mtetra
.614 .735 .932 r
.79588 .34531 .80091 .35228 .81276 .34938 .80778 .34258 Mtetra
.621 .745 .935 r
.80778 .34258 .81276 .34938 .82466 .34646 .81971 .33963 Mtetra
.628 .748 .934 r
.81971 .33963 .82466 .34646 .83661 .34347 .83169 .3365 Mtetra
.634 .747 .93 r
.83169 .3365 .83661 .34347 .84861 .34035 .8437 .33321 Mtetra
.659 .752 .919 r
.20671 .53168 .21326 .53739 .22285 .53375 .21628 .52848 Mtetra
.664 .77 .929 r
.21628 .52848 .22285 .53375 .23249 .52996 .2259 .52516 Mtetra
.672 .79 .937 r
.2259 .52516 .23249 .52996 .24218 .52598 .23557 .52161 Mtetra
.684 .809 .942 r
.23557 .52161 .24218 .52598 .25191 .52181 .2453 .51774 Mtetra
.702 .824 .94 r
.2453 .51774 .25191 .52181 .26169 .51737 .2551 .51342 Mtetra
.719 .831 .934 r
.2551 .51342 .26169 .51737 .27151 .51283 .26497 .50863 Mtetra
.738 .824 .918 r
.26497 .50863 .27151 .51283 .28135 .50824 .2749 .50331 Mtetra
.743 .799 .898 r
.2749 .50331 .28135 .50824 .2912 .504 .28487 .49769 Mtetra
.737 .755 .866 r
.28487 .49769 .2912 .504 .30104 .5004 .29488 .49187 Mtetra
.711 .692 .83 r
.29488 .49187 .30104 .5004 .31084 .49787 .30489 .48643 Mtetra
.673 .623 .791 r
.30489 .48643 .31084 .49787 .32059 .49686 .31487 .48177 Mtetra
.626 .553 .752 r
.31487 .48177 .32059 .49686 .33029 .49742 .32479 .47852 Mtetra
.577 .491 .72 r
.32479 .47852 .33029 .49742 .33996 .4997 .33463 .47728 Mtetra
.535 .441 .695 r
.33463 .47728 .33996 .4997 .34965 .50282 .34441 .47817 Mtetra
.492 .401 .68 r
.34441 .47817 .34965 .50282 .35941 .50612 .35412 .48143 Mtetra
.458 .378 .679 r
.35412 .48143 .35941 .50612 .36932 .50779 .36383 .48635 Mtetra
.412 .369 .7 r
.36383 .48635 .36932 .50779 .37944 .50641 .37358 .49233 Mtetra
.343 .406 .782 r
.37358 .49233 .37944 .50641 .38977 .50096 .38346 .49763 Mtetra
0 .454 .809 r
.38346 .49763 .38977 .50096 .4003 .49079 .3935 .50088 Mtetra
.457 .04 .158 r
.3935 .50088 .4003 .49079 .41094 .47747 .40374 .50109 Mtetra
.44 .124 .332 r
.40374 .50109 .41094 .47747 .42161 .46232 .41417 .49736 Mtetra
.417 .138 .379 r
.41417 .49736 .42161 .46232 .43221 .44845 .42477 .48926 Mtetra
.38 .118 .385 r
.42477 .48926 .43221 .44845 .4427 .43808 .4355 .47675 Mtetra
.327 .069 .362 r
.4355 .47675 .4427 .43808 .45305 .43343 .44628 .46136 Mtetra
.167 0 .256 r
.44628 .46136 .45305 .43343 .46331 .43543 .45707 .44392 Mtetra
.809 .91 .511 r
.45707 .44392 .46331 .43543 .47356 .44296 .46785 .4241 Mtetra
.791 .617 .665 r
.46785 .4241 .47356 .44296 .48388 .45402 .47858 .40334 Mtetra
.659 .46 .605 r
.47858 .40334 .48388 .45402 .49434 .46296 .4892 .38563 Mtetra
.601 .401 .582 r
.4892 .38563 .49434 .46296 .50496 .46671 .49973 .37348 Mtetra
.559 .363 .571 r
.49973 .37348 .50496 .46671 .51569 .46328 .5102 .36995 Mtetra
.523 .335 .568 r
.5102 .36995 .51569 .46328 .52646 .45266 .5207 .37507 Mtetra
.488 .316 .574 r
.5207 .37507 .52646 .45266 .5372 .43679 .53131 .3858 Mtetra
.425 .292 .595 r
.53131 .3858 .5372 .43679 .54789 .41875 .54207 .39964 Mtetra
.165 .23 .685 r
.54207 .39964 .54789 .41875 .55855 .40422 .55299 .4126 Mtetra
.697 .275 .24 r
.55299 .4126 .55855 .40422 .56927 .39522 .56402 .42322 Mtetra
.607 .289 .405 r
.56402 .42322 .56927 .39522 .5801 .39295 .57517 .43181 Mtetra
.57 .277 .432 r
.57517 .43181 .5801 .39295 .59111 .39646 .58639 .43753 Mtetra
.533 .248 .429 r
.58639 .43753 .59111 .39646 .60229 .40355 .59762 .4388 Mtetra
.485 .198 .401 r
.59762 .4388 .60229 .40355 .61362 .41198 .60881 .43564 Mtetra
.381 .075 .315 r
.60881 .43564 .61362 .41198 .62503 .41859 .61993 .42846 Mtetra
0 0 0 r
.61993 .42846 .62503 .41859 .63644 .42203 .63097 .41818 Mtetra
.883 .881 .827 r
.63097 .41818 .63644 .42203 .64777 .42065 .64193 .40577 Mtetra
.768 .64 .72 r
.64193 .40577 .64777 .42065 .65898 .41511 .65285 .39262 Mtetra
.706 .554 .679 r
.65285 .39262 .65898 .41511 .67008 .40643 .66379 .38054 Mtetra
.674 .52 .668 r
.66379 .38054 .67008 .40643 .68112 .39607 .6748 .37012 Mtetra
.65 .504 .672 r
.6748 .37012 .68112 .39607 .69216 .38586 .68592 .36213 Mtetra
.632 .503 .687 r
.68592 .36213 .69216 .38586 .70324 .37648 .69718 .35632 Mtetra
.615 .514 .716 r
.69718 .35632 .70324 .37648 .71444 .36887 .70859 .35256 Mtetra
.598 .537 .757 r
.70859 .35256 .71444 .36887 .72575 .36287 .72014 .35026 Mtetra
.583 .578 .813 r
.72014 .35026 .72575 .36287 .73721 .35842 .73179 .34879 Mtetra
.565 .63 .875 r
.73179 .34879 .73721 .35842 .74878 .3551 .74354 .34769 Mtetra
.556 .692 .93 r
.74354 .34769 .74878 .3551 .76045 .35243 .75535 .34641 Mtetra
.55 .74 .964 r
.75535 .34641 .76045 .35243 .7722 .35012 .76719 .34482 Mtetra
.565 .777 .978 r
.76719 .34482 .7722 .35012 .78402 .34777 .77906 .34267 Mtetra
.585 .795 .979 r
.77906 .34267 .78402 .34777 .79588 .34531 .79095 .34005 Mtetra
.611 .8 .972 r
.79095 .34005 .79588 .34531 .80778 .34258 .80286 .33695 Mtetra
.631 .795 .961 r
.80286 .33695 .80778 .34258 .81971 .33963 .81479 .33351 Mtetra
.644 .782 .947 r
.81479 .33351 .81971 .33963 .83169 .3365 .82676 .32983 Mtetra
.652 .766 .933 r
.82676 .32983 .83169 .3365 .8437 .33321 .83876 .32602 Mtetra
.632 .745 .93 r
.20012 .52592 .20671 .53168 .21628 .52848 .20965 .52332 Mtetra
.63 .767 .945 r
.20965 .52332 .21628 .52848 .2259 .52516 .21923 .52067 Mtetra
.632 .795 .96 r
.21923 .52067 .2259 .52516 .23557 .52161 .22886 .51786 Mtetra
.639 .826 .972 r
.22886 .51786 .23557 .52161 .2453 .51774 .23855 .51476 Mtetra
.65 .86 .979 r
.23855 .51476 .2453 .51774 .2551 .51342 .24831 .51124 Mtetra
.666 .894 .979 r
.24831 .51124 .2551 .51342 .26497 .50863 .25815 .50716 Mtetra
.693 .923 .969 r
.25815 .50716 .26497 .50863 .2749 .50331 .26808 .50234 Mtetra
.72 .943 .956 r
.26808 .50234 .2749 .50331 .28487 .49769 .27809 .49679 Mtetra
.758 .947 .941 r
.27809 .49679 .28487 .49769 .29488 .49187 .28818 .49043 Mtetra
.783 .93 .93 r
.28818 .49043 .29488 .49187 .30489 .48643 .29832 .48361 Mtetra
.793 .88 .91 r
.29832 .48361 .30489 .48643 .31487 .48177 .30849 .47653 Mtetra
.765 .795 .878 r
.30849 .47653 .31487 .48177 .32479 .47852 .31865 .46991 Mtetra
.712 .693 .83 r
.31865 .46991 .32479 .47852 .33463 .47728 .32876 .46432 Mtetra
.647 .59 .777 r
.32876 .46432 .33463 .47728 .34441 .47817 .33879 .46048 Mtetra
.582 .504 .732 r
.33879 .46048 .34441 .47817 .35412 .48143 .34874 .45903 Mtetra
.529 .438 .696 r
.34874 .45903 .35412 .48143 .36383 .48635 .3586 .46018 Mtetra
.481 .387 .672 r
.3586 .46018 .36383 .48635 .37358 .49233 .36839 .46415 Mtetra
.454 .36 .66 r
.36839 .46415 .37358 .49233 .38346 .49763 .37818 .4699 Mtetra
.433 .348 .661 r
.37818 .4699 .38346 .49763 .3935 .50088 .38803 .47661 Mtetra
.432 .366 .682 r
.38803 .47661 .3935 .50088 .40374 .50109 .398 .48255 Mtetra
.455 .423 .733 r
.398 .48255 .40374 .50109 .41417 .49736 .40816 .48628 Mtetra
.532 .571 .84 r
.40816 .48628 .41417 .49736 .42477 .48926 .41851 .48636 Mtetra
.684 .887 .973 r
.41851 .48636 .42477 .48926 .4355 .47675 .42907 .48178 Mtetra
.51 .854 .587 r
.42907 .48178 .4355 .47675 .44628 .46136 .43977 .47259 Mtetra
0 0 0 r
.43977 .47259 .44628 .46136 .45707 .44392 .45058 .45903 Mtetra
.45058 .45903 .45707 .44392 .46785 .4241 .46144 .44169 Mtetra
.46144 .44169 .46785 .4241 .47858 .40334 .47228 .42247 Mtetra
0 0 .103 r
.47228 .42247 .47858 .40334 .4892 .38563 .48302 .40617 Mtetra
.233 0 .227 r
.48302 .40617 .4892 .38563 .49973 .37348 .49366 .39532 Mtetra
.436 .113 .318 r
.49366 .39532 .49973 .37348 .5102 .36995 .50425 .39179 Mtetra
.561 .228 .361 r
.50425 .39179 .5102 .36995 .5207 .37507 .51486 .3956 Mtetra
.631 .29 .374 r
.51486 .3956 .5207 .37507 .53131 .3858 .52556 .40491 Mtetra
.667 .318 .373 r
.52556 .40491 .53131 .3858 .54207 .39964 .5364 .4172 Mtetra
.652 .295 .353 r
.5364 .4172 .54207 .39964 .55299 .4126 .54737 .42765 Mtetra
.61 .236 .309 r
.54737 .42765 .55299 .4126 .56402 .42322 .55845 .43435 Mtetra
.52 .11 .202 r
.55845 .43435 .56402 .42322 .57517 .43181 .56957 .43665 Mtetra
.17 0 0 r
.56957 .43665 .57517 .43181 .58639 .43753 .58071 .4343 Mtetra
.774 .905 .932 r
.58071 .4343 .58639 .43753 .59762 .4388 .5918 .42722 Mtetra
.772 .68 .763 r
.5918 .42722 .59762 .4388 .60881 .43564 .60281 .41641 Mtetra
.734 .589 .693 r
.60281 .41641 .60881 .43564 .61993 .42846 .61377 .40332 Mtetra
.709 .544 .664 r
.61377 .40332 .61993 .42846 .63097 .41818 .62467 .38942 Mtetra
.685 .517 .652 r
.62467 .38942 .63097 .41818 .64193 .40577 .63558 .37646 Mtetra
.668 .504 .653 r
.63558 .37646 .64193 .40577 .65285 .39262 .64654 .3653 Mtetra
.649 .498 .665 r
.64654 .3653 .65285 .39262 .66379 .38054 .65762 .35699 Mtetra
.631 .503 .688 r
.65762 .35699 .66379 .38054 .6748 .37012 .66882 .35134 Mtetra
.609 .52 .729 r
.66882 .35134 .6748 .37012 .68592 .36213 .68018 .34814 Mtetra
.581 .555 .791 r
.68018 .34814 .68592 .36213 .69718 .35632 .69168 .34674 Mtetra
.536 .616 .88 r
.69168 .34674 .69718 .35632 .70859 .35256 .7033 .34641 Mtetra
.453 .685 .965 r
.7033 .34641 .70859 .35256 .72014 .35026 .71503 .34657 Mtetra
.357 .736 .987 r
.71503 .34657 .72014 .35026 .73179 .34879 .72682 .34648 Mtetra
.294 .751 .953 r
.72682 .34648 .73179 .34879 .74354 .34769 .73865 .34591 Mtetra
.327 .787 .943 r
.73865 .34591 .74354 .34769 .75535 .34641 .7505 .34451 Mtetra
.405 .83 .963 r
.7505 .34451 .75535 .34641 .76719 .34482 .76236 .34235 Mtetra
.506 .865 .988 r
.76236 .34235 .76719 .34482 .77906 .34267 .77422 .33942 Mtetra
.582 .871 .994 r
.77422 .33942 .77906 .34267 .79095 .34005 .78608 .33591 Mtetra
.632 .856 .984 r
.78608 .33591 .79095 .34005 .80286 .33695 .79796 .33196 Mtetra
.659 .833 .967 r
.79796 .33196 .80286 .33695 .81479 .33351 .80987 .3277 Mtetra
.672 .807 .947 r
.80987 .3277 .81479 .33351 .82676 .32983 .8218 .32326 Mtetra
.675 .781 .93 r
.8218 .32326 .82676 .32983 .83876 .32602 .83378 .31877 Mtetra
.605 .738 .938 r
.19348 .52013 .20012 .52592 .20965 .52332 .20298 .51804 Mtetra
.595 .755 .954 r
.20298 .51804 .20965 .52332 .21923 .52067 .21252 .51603 Mtetra
.587 .778 .971 r
.21252 .51603 .21923 .52067 .22886 .51786 .2221 .51399 Mtetra
.578 .807 .986 r
.2221 .51399 .22886 .51786 .23855 .51476 .23173 .51184 Mtetra
.561 .84 .997 r
.23173 .51184 .23855 .51476 .24831 .51124 .24142 .50951 Mtetra
.542 .876 .99 r
.24142 .50951 .24831 .51124 .25815 .50716 .25118 .50678 Mtetra
.51 .898 .949 r
.25118 .50678 .25815 .50716 .26808 .50234 .26103 .50348 Mtetra
.469 .893 .862 r
.26103 .50348 .26808 .50234 .27809 .49679 .27098 .49936 Mtetra
.446 .872 .761 r
.27098 .49936 .27809 .49679 .28818 .49043 .28103 .4942 Mtetra
.442 .851 .678 r
.28103 .4942 .28818 .49043 .29832 .48361 .29118 .48795 Mtetra
.509 .879 .667 r
.29118 .48795 .29832 .48361 .30849 .47653 .30144 .48047 Mtetra
.62 .94 .728 r
.30144 .48047 .30849 .47653 .31865 .46991 .31177 .47214 Mtetra
.773 .997 .839 r
.31177 .47214 .31865 .46991 .32876 .46432 .32214 .46317 Mtetra
.839 .935 .89 r
.32214 .46317 .32876 .46432 .33879 .46048 .33251 .45427 Mtetra
.789 .772 .838 r
.33251 .45427 .33879 .46048 .34874 .45903 .34285 .44599 Mtetra
.704 .618 .758 r
.34285 .44599 .34874 .45903 .3586 .46018 .35313 .43901 Mtetra
.634 .512 .697 r
.35313 .43901 .3586 .46018 .36839 .46415 .36333 .43395 Mtetra
.583 .441 .654 r
.36333 .43395 .36839 .46415 .37818 .4699 .37344 .43129 Mtetra
.546 .395 .627 r
.37344 .43129 .37818 .4699 .38803 .47661 .38348 .43139 Mtetra
.527 .37 .612 r
.38348 .43139 .38803 .47661 .398 .48255 .3935 .43347 Mtetra
.513 .355 .604 r
.3935 .43347 .398 .48255 .40816 .48628 .40353 .4372 Mtetra
.495 .342 .603 r
.40353 .4372 .40816 .48628 .41851 .48636 .41358 .44286 Mtetra
.469 .332 .611 r
.41358 .44286 .41851 .48636 .42907 .48178 .42367 .45033 Mtetra
.423 .329 .644 r
.42367 .45033 .42907 .48178 .43977 .47259 .43385 .45851 Mtetra
.178 .306 .757 r
.43385 .45851 .43977 .47259 .45058 .45903 .44414 .46702 Mtetra
.695 .275 .244 r
.44414 .46702 .45058 .45903 .46144 .44169 .45451 .47713 Mtetra
.616 .313 .434 r
.45451 .47713 .46144 .44169 .47228 .42247 .46499 .4883 Mtetra
.576 .307 .471 r
.46499 .4883 .47228 .42247 .48302 .40617 .47563 .49774 Mtetra
.55 .296 .483 r
.47563 .49774 .48302 .40617 .49366 .39532 .48645 .50303 Mtetra
.519 .274 .483 r
.48645 .50303 .49366 .39532 .50425 .39179 .49744 .49958 Mtetra
.486 .247 .477 r
.49744 .49958 .50425 .39179 .51486 .3956 .50852 .48736 Mtetra
.456 .218 .464 r
.50852 .48736 .51486 .3956 .52556 .40491 .5196 .47093 Mtetra
.406 .165 .433 r
.5196 .47093 .52556 .40491 .5364 .4172 .53062 .45273 Mtetra
.28 .024 .336 r
.53062 .45273 .5364 .4172 .54737 .42765 .5416 .43553 Mtetra
.608 .826 .432 r
.5416 .43553 .54737 .42765 .55845 .43435 .55255 .4199 Mtetra
.791 .653 .71 r
.55255 .4199 .55845 .43435 .56957 .43665 .56346 .40457 Mtetra
.686 .508 .64 r
.56346 .40457 .56957 .43665 .58071 .4343 .57434 .38991 Mtetra
.642 .455 .615 r
.57434 .38991 .58071 .4343 .5918 .42722 .58522 .37705 Mtetra
.62 .433 .607 r
.58522 .37705 .5918 .42722 .60281 .41641 .59613 .36612 Mtetra
.61 .425 .607 r
.59613 .36612 .60281 .41641 .61377 .40332 .60708 .35685 Mtetra
.601 .424 .613 r
.60708 .35685 .61377 .40332 .62467 .38942 .61809 .34958 Mtetra
.588 .424 .628 r
.61809 .34958 .62467 .38942 .63558 .37646 .62921 .34511 Mtetra
.572 .434 .655 r
.62921 .34511 .63558 .37646 .64654 .3653 .64046 .34309 Mtetra
.55 .46 .705 r
.64046 .34309 .64654 .3653 .65762 .35699 .65184 .34304 Mtetra
.505 .513 .798 r
.65184 .34304 .65762 .35699 .66882 .35134 .66336 .34434 Mtetra
.363 .604 .94 r
.66336 .34434 .66882 .35134 .68018 .34814 .67499 .3463 Mtetra
0 .534 .803 r
.67499 .3463 .68018 .34814 .69168 .34674 .68672 .34834 Mtetra
.266 0 0 r
.68672 .34834 .69168 .34674 .7033 .34641 .6985 .34974 Mtetra
.3 0 0 r
.6985 .34974 .7033 .34641 .71503 .34657 .71031 .35028 Mtetra
.233 0 0 r
.71031 .35028 .71503 .34657 .72682 .34648 .72213 .34956 Mtetra
.107 0 0 r
.72213 .34956 .72682 .34648 .73865 .34591 .73395 .34771 Mtetra
0 0 0 r
.73395 .34771 .73865 .34591 .7505 .34451 .74575 .34478 Mtetra
.348 .825 .819 r
.74575 .34478 .7505 .34451 .76236 .34235 .75755 .341 Mtetra
.54 .913 .949 r
.75755 .341 .76236 .34235 .77422 .33942 .76936 .33663 Mtetra
.64 .912 .981 r
.76936 .33663 .77422 .33942 .78608 .33591 .78117 .33183 Mtetra
.68 .877 .972 r
.78117 .33183 .78608 .33591 .79796 .33196 .79302 .32683 Mtetra
.695 .842 .953 r
.79302 .32683 .79796 .33196 .80987 .3277 .80489 .32171 Mtetra
.698 .812 .936 r
.80489 .32171 .80987 .3277 .8218 .32326 .8168 .31655 Mtetra
.695 .786 .921 r
.8168 .31655 .8218 .32326 .83378 .31877 .82876 .31146 Mtetra
.603 .737 .939 r
.18679 .51429 .19348 .52013 .20298 .51804 .19631 .51223 Mtetra
.594 .736 .942 r
.19631 .51223 .20298 .51804 .21252 .51603 .20585 .5103 Mtetra
.586 .737 .947 r
.20585 .5103 .21252 .51603 .2221 .51399 .21543 .5085 Mtetra
.576 .743 .956 r
.21543 .5085 .2221 .51399 .23173 .51184 .22504 .50681 Mtetra
.559 .756 .97 r
.22504 .50681 .23173 .51184 .24142 .50951 .23468 .50525 Mtetra
.544 .783 .987 r
.23468 .50525 .24142 .50951 .25118 .50678 .24438 .50363 Mtetra
.518 .818 1 r
.24438 .50363 .25118 .50678 .26103 .50348 .25413 .50185 Mtetra
.478 .856 .983 r
.25413 .50185 .26103 .50348 .27098 .49936 .26396 .49961 Mtetra
.405 .856 .892 r
.26396 .49961 .27098 .49936 .28103 .4942 .27389 .49667 Mtetra
.299 .782 .704 r
.27389 .49667 .28103 .4942 .29118 .48795 .28393 .49271 Mtetra
0 0 0 r
.28393 .49271 .29118 .48795 .30144 .48047 .29409 .48744 Mtetra
.29409 .48744 .30144 .48047 .31177 .47214 .30438 .48081 Mtetra
.30438 .48081 .31177 .47214 .32214 .46317 .31477 .47268 Mtetra
.31477 .47268 .32214 .46317 .33251 .45427 .32524 .46346 Mtetra
.32524 .46346 .33251 .45427 .34285 .44599 .33576 .45341 Mtetra
.33576 .45341 .34285 .44599 .35313 .43901 .34629 .44312 Mtetra
.703 .966 .726 r
.34629 .44312 .35313 .43901 .36333 .43395 .35681 .43315 Mtetra
.829 .954 .898 r
.35681 .43315 .36333 .43395 .37344 .43129 .36725 .42448 Mtetra
.75 .755 .856 r
.36725 .42448 .37344 .43129 .38348 .43139 .37761 .41786 Mtetra
.657 .591 .77 r
.37761 .41786 .38348 .43139 .3935 .43347 .3879 .41331 Mtetra
.59 .492 .711 r
.3879 .41331 .3935 .43347 .40353 .4372 .39813 .41111 Mtetra
.535 .424 .674 r
.39813 .41111 .40353 .4372 .41358 .44286 .40829 .41193 Mtetra
.489 .375 .65 r
.40829 .41193 .41358 .44286 .42367 .45033 .41842 .41594 Mtetra
.464 .347 .636 r
.41842 .41594 .42367 .45033 .43385 .45851 .42857 .42214 Mtetra
.442 .327 .628 r
.42857 .42214 .43385 .45851 .44414 .46702 .43878 .43023 Mtetra
.392 .291 .621 r
.43878 .43023 .44414 .46702 .45451 .47713 .44902 .44166 Mtetra
.343 .262 .618 r
.44902 .44166 .45451 .47713 .46499 .4883 .45935 .45547 Mtetra
.367 .288 .634 r
.45935 .45547 .46499 .4883 .47563 .49774 .46987 .4671 Mtetra
.454 .356 .654 r
.46987 .4671 .47563 .49774 .48645 .50303 .48061 .47338 Mtetra
.592 .453 .661 r
.48061 .47338 .48645 .50303 .49744 .49958 .49156 .46989 Mtetra
.685 .515 .65 r
.49156 .46989 .49744 .49958 .50852 .48736 .50261 .45658 Mtetra
.718 .533 .639 r
.50261 .45658 .50852 .48736 .5196 .47093 .51366 .43786 Mtetra
.723 .531 .63 r
.51366 .43786 .5196 .47093 .53062 .45273 .52466 .41689 Mtetra
.699 .509 .627 r
.52466 .41689 .53062 .45273 .5416 .43553 .53559 .39826 Mtetra
.674 .489 .627 r
.53559 .39826 .5416 .43553 .55255 .4199 .54648 .38296 Mtetra
.662 .481 .629 r
.54648 .38296 .55255 .4199 .56346 .40457 .55735 .36953 Mtetra
.652 .477 .635 r
.55735 .36953 .56346 .40457 .57434 .38991 .56823 .35828 Mtetra
.633 .473 .648 r
.56823 .35828 .57434 .38991 .58522 .37705 .57916 .35024 Mtetra
.614 .476 .671 r
.57916 .35024 .58522 .37705 .59613 .36612 .59016 .34525 Mtetra
.594 .494 .711 r
.59016 .34525 .59613 .36612 .60708 .35685 .60126 .34265 Mtetra
.555 .537 .789 r
.60126 .34265 .60708 .35685 .61809 .34958 .61247 .34217 Mtetra
.395 .607 .933 r
.61247 .34217 .61809 .34958 .62921 .34511 .62381 .34378 Mtetra
.184 0 0 r
.62381 .34378 .62921 .34511 .64046 .34309 .63528 .34675 Mtetra
.474 0 0 r
.63528 .34675 .64046 .34309 .65184 .34304 .64686 .35006 Mtetra
.512 .036 .062 r
.64686 .35006 .65184 .34304 .66336 .34434 .65853 .35315 Mtetra
.498 .05 .116 r
.65853 .35315 .66336 .34434 .67499 .3463 .67026 .35541 Mtetra
.464 .02 .108 r
.67026 .35541 .67499 .3463 .68672 .34834 .68202 .35656 Mtetra
.397 0 .045 r
.68202 .35656 .68672 .34834 .6985 .34974 .69379 .35619 Mtetra
.286 0 0 r
.69379 .35619 .6985 .34974 .71031 .35028 .70555 .35441 Mtetra
.077 0 0 r
.70555 .35441 .71031 .35028 .72213 .34956 .71729 .35128 Mtetra
.238 .738 .667 r
.71729 .35128 .72213 .34956 .73395 .34771 .72903 .34709 Mtetra
.533 .92 .913 r
.72903 .34709 .73395 .34771 .74575 .34478 .74075 .34217 Mtetra
.669 .926 .973 r
.74075 .34217 .74575 .34478 .75755 .341 .75249 .33676 Mtetra
.708 .878 .961 r
.75249 .33676 .75755 .341 .76936 .33663 .76425 .33117 Mtetra
.716 .835 .938 r
.76425 .33117 .76936 .33663 .78117 .33183 .77604 .32552 Mtetra
.711 .804 .923 r
.77604 .32552 .78117 .33183 .79302 .32683 .78788 .31999 Mtetra
.706 .785 .914 r
.78788 .31999 .79302 .32683 .80489 .32171 .79977 .31457 Mtetra
.7 .774 .909 r
.79977 .31457 .80489 .32171 .8168 .31655 .81171 .30927 Mtetra
.695 .769 .908 r
.81171 .30927 .8168 .31655 .82876 .31146 .82371 .3041 Mtetra
.626 .744 .932 r
.18006 .50842 .18679 .51429 .19631 .51223 .18964 .50587 Mtetra
.62 .726 .922 r
.18964 .50587 .19631 .51223 .20585 .5103 .19925 .50348 Mtetra
.611 .709 .914 r
.19925 .50348 .20585 .5103 .21543 .5085 .20887 .50132 Mtetra
.598 .693 .91 r
.20887 .50132 .21543 .5085 .22504 .50681 .21851 .49947 Mtetra
.579 .682 .911 r
.21851 .49947 .22504 .50681 .23468 .50525 .22815 .49801 Mtetra
.56 .679 .919 r
.22815 .49801 .23468 .50525 .24438 .50363 .23782 .49689 Mtetra
.534 .686 .937 r
.23782 .49689 .24438 .50363 .25413 .50185 .2475 .49612 Mtetra
.504 .712 .965 r
.2475 .49612 .25413 .50185 .26396 .49961 .25722 .49549 Mtetra
.447 .754 .994 r
.25722 .49549 .26396 .49961 .27389 .49667 .26699 .49488 Mtetra
.329 .779 .955 r
.26699 .49488 .27389 .49667 .28393 .49271 .27684 .49392 Mtetra
0 0 0 r
.27684 .49392 .28393 .49271 .29409 .48744 .28679 .49232 Mtetra
.102 0 0 r
.28679 .49232 .29409 .48744 .30438 .48081 .29686 .48971 Mtetra
.2 0 0 r
.29686 .48971 .30438 .48081 .31477 .47268 .30706 .48575 Mtetra
.249 0 .097 r
.30706 .48575 .31477 .47268 .32524 .46346 .31738 .48037 Mtetra
.266 0 .174 r
.31738 .48037 .32524 .46346 .33576 .45341 .32782 .47344 Mtetra
.27 0 .215 r
.32782 .47344 .33576 .45341 .34629 .44312 .33836 .46511 Mtetra
.26 0 .231 r
.33836 .46511 .34629 .44312 .35681 .43315 .34897 .45548 Mtetra
.242 0 .227 r
.34897 .45548 .35681 .43315 .36725 .42448 .35963 .44507 Mtetra
.199 0 .192 r
.35963 .44507 .36725 .42448 .37761 .41786 .3703 .43426 Mtetra
.1 0 .091 r
.3703 .43426 .37761 .41786 .3879 .41331 .38095 .4236 Mtetra
0 0 0 r
.38095 .4236 .3879 .41331 .39813 .41111 .39159 .41343 Mtetra
.785 .998 .813 r
.39159 .41343 .39813 .41111 .40829 .41193 .4022 .40352 Mtetra
.787 .728 .797 r
.4022 .40352 .40829 .41193 .41842 .41594 .41281 .39385 Mtetra
.683 .539 .683 r
.41281 .39385 .41842 .41594 .42857 .42214 .42342 .3843 Mtetra
.631 .456 .628 r
.42342 .3843 .42857 .42214 .43878 .43023 .43402 .37504 Mtetra
.597 .41 .599 r
.43402 .37504 .43878 .43023 .44902 .44166 .44459 .36692 Mtetra
.576 .381 .58 r
.44459 .36692 .44902 .44166 .45935 .45547 .45514 .36015 Mtetra
.565 .364 .568 r
.45514 .36015 .45935 .45547 .46987 .4671 .4657 .35395 Mtetra
.558 .354 .561 r
.4657 .35395 .46987 .4671 .48061 .47338 .47628 .34843 Mtetra
.55 .346 .557 r
.47628 .34843 .48061 .47338 .49156 .46989 .48686 .3448 Mtetra
.544 .341 .556 r
.48686 .3448 .49156 .46989 .50261 .45658 .49746 .34307 Mtetra
.542 .343 .559 r
.49746 .34307 .50261 .45658 .51366 .43786 .50812 .34202 Mtetra
.541 .347 .566 r
.50812 .34202 .51366 .43786 .52466 .41689 .51883 .34156 Mtetra
.536 .351 .577 r
.51883 .34156 .52466 .41689 .53559 .39826 .52961 .34247 Mtetra
.528 .359 .596 r
.52961 .34247 .53559 .39826 .54648 .38296 .54047 .34455 Mtetra
.52 .379 .629 r
.54047 .34455 .54648 .38296 .55735 .36953 .55142 .34693 Mtetra
.499 .423 .702 r
.55142 .34693 .55735 .36953 .56823 .35828 .56245 .34946 Mtetra
.359 .541 .898 r
.56245 .34946 .56823 .35828 .57916 .35024 .57357 .35225 Mtetra
.419 0 0 r
.57357 .35225 .57916 .35024 .59016 .34525 .58479 .35532 Mtetra
.544 .116 .179 r
.58479 .35532 .59016 .34525 .60126 .34265 .59611 .35892 Mtetra
.553 .181 .29 r
.59611 .35892 .60126 .34265 .61247 .34217 .60754 .36269 Mtetra
.547 .199 .33 r
.60754 .36269 .61247 .34217 .62381 .34378 .61905 .36608 Mtetra
.536 .197 .34 r
.61905 .36608 .62381 .34378 .63528 .34675 .63064 .3687 Mtetra
.516 .177 .331 r
.63064 .3687 .63528 .34675 .64686 .35006 .64227 .37001 Mtetra
.488 .141 .305 r
.64227 .37001 .64686 .35006 .65853 .35315 .65392 .36989 Mtetra
.442 .08 .253 r
.65392 .36989 .65853 .35315 .67026 .35541 .66559 .36819 Mtetra
.365 0 .158 r
.66559 .36819 .67026 .35541 .68202 .35656 .67724 .36502 Mtetra
.205 0 0 r
.67724 .36502 .68202 .35656 .69379 .35619 .68888 .36046 Mtetra
0 0 0 r
.68888 .36046 .69379 .35619 .70555 .35441 .70051 .35486 Mtetra
.556 .933 .848 r
.70051 .35486 .70555 .35441 .71729 .35128 .71213 .34858 Mtetra
.733 .938 .953 r
.71213 .34858 .71729 .35128 .72903 .34709 .72376 .34193 Mtetra
.75 .853 .927 r
.72376 .34193 .72903 .34709 .74075 .34217 .73542 .33528 Mtetra
.738 .792 .895 r
.73542 .33528 .74075 .34217 .75249 .33676 .74711 .32876 Mtetra
.721 .754 .878 r
.74711 .32876 .75249 .33676 .76425 .33117 .75887 .3226 Mtetra
.708 .734 .871 r
.75887 .3226 .76425 .33117 .77604 .32552 .77068 .31678 Mtetra
.696 .725 .873 r
.77068 .31678 .77604 .32552 .78788 .31999 .78257 .31137 Mtetra
.688 .726 .879 r
.78257 .31137 .78788 .31999 .79977 .31457 .79452 .30627 Mtetra
.682 .734 .889 r
.79452 .30627 .79977 .31457 .81171 .30927 .80653 .3014 Mtetra
.678 .746 .902 r
.80653 .3014 .81171 .30927 .82371 .3041 .81861 .29669 Mtetra
.664 .753 .917 r
.17328 .5025 .18006 .50842 .18964 .50587 .18297 .49909 Mtetra
.658 .725 .898 r
.18297 .49909 .18964 .50587 .19925 .50348 .19268 .4958 Mtetra
.647 .695 .881 r
.19268 .4958 .19925 .50348 .20887 .50132 .2024 .49274 Mtetra
.632 .667 .866 r
.2024 .49274 .20887 .50132 .21851 .49947 .21213 .49003 Mtetra
.613 .64 .853 r
.21213 .49003 .21851 .49947 .22815 .49801 .22185 .48782 Mtetra
.593 .615 .843 r
.22185 .48782 .22815 .49801 .23782 .49689 .23156 .48615 Mtetra
.57 .593 .837 r
.23156 .48615 .23782 .49689 .2475 .49612 .24127 .48512 Mtetra
.549 .579 .836 r
.24127 .48512 .2475 .49612 .25722 .49549 .25098 .48466 Mtetra
.525 .571 .844 r
.25098 .48466 .25722 .49549 .26699 .49488 .26069 .48476 Mtetra
.505 .578 .862 r
.26069 .48476 .26699 .49488 .27684 .49392 .27044 .48518 Mtetra
.48 .603 .897 r
.27044 .48518 .27684 .49392 .28679 .49232 .28024 .48576 Mtetra
.451 .662 .952 r
.28024 .48576 .28679 .49232 .29686 .48971 .29012 .48608 Mtetra
.379 .745 .991 r
.29012 .48608 .29686 .48971 .30706 .48575 .3001 .4858 Mtetra
.168 .706 .801 r
.3001 .4858 .30706 .48575 .31738 .48037 .31019 .4846 Mtetra
.077 0 0 r
.31019 .4846 .31738 .48037 .32782 .47344 .32042 .48218 Mtetra
.206 0 0 r
.32042 .48218 .32782 .47344 .33836 .46511 .33077 .47839 Mtetra
.258 0 .104 r
.33077 .47839 .33836 .46511 .34897 .45548 .34124 .47308 Mtetra
.28 0 .188 r
.34124 .47308 .34897 .45548 .35963 .44507 .35182 .46619 Mtetra
.283 0 .231 r
.35182 .46619 .35963 .44507 .3703 .43426 .3625 .45774 Mtetra
.292 0 .256 r
.3625 .45774 .3703 .43426 .38095 .4236 .37322 .44849 Mtetra
.297 0 .27 r
.37322 .44849 .38095 .4236 .39159 .41343 .38397 .43873 Mtetra
.27 0 .263 r
.38397 .43873 .39159 .41343 .4022 .40352 .39477 .4277 Mtetra
.214 0 .232 r
.39477 .4277 .4022 .40352 .41281 .39385 .40562 .41521 Mtetra
.133 0 .173 r
.40562 .41521 .41281 .39385 .42342 .3843 .41647 .40188 Mtetra
0 0 .065 r
.41647 .40188 .42342 .3843 .43402 .37504 .42733 .38791 Mtetra
0 0 0 r
.42733 .38791 .43402 .37504 .44459 .36692 .43819 .37265 Mtetra
.83 .961 .63 r
.43819 .37265 .44459 .36692 .45514 .36015 .44904 .3567 Mtetra
.902 .855 .786 r
.44904 .3567 .45514 .36015 .4657 .35395 .45981 .34208 Mtetra
.774 .67 .748 r
.45981 .34208 .4657 .35395 .47628 .34843 .4705 .3308 Mtetra
.62 .531 .732 r
.4705 .3308 .47628 .34843 .48686 .3448 .48107 .32714 Mtetra
.437 .421 .743 r
.48107 .32714 .48686 .3448 .49746 .34307 .4916 .33111 Mtetra
.172 .343 .794 r
.4916 .33111 .49746 .34307 .50812 .34202 .5022 .33846 Mtetra
.533 0 0 r
.5022 .33846 .50812 .34202 .51883 .34156 .51291 .34718 Mtetra
.66 .19 .127 r
.51291 .34718 .51883 .34156 .52961 .34247 .52375 .35525 Mtetra
.613 .218 .27 r
.52375 .35525 .52961 .34247 .54047 .34455 .53471 .36206 Mtetra
.593 .229 .32 r
.53471 .36206 .54047 .34455 .55142 .34693 .54578 .36825 Mtetra
.575 .23 .346 r
.54578 .36825 .55142 .34693 .56245 .34946 .55696 .37363 Mtetra
.554 .221 .358 r
.55696 .37363 .56245 .34946 .57357 .35225 .56822 .37756 Mtetra
.537 .209 .36 r
.56822 .37756 .57357 .35225 .58479 .35532 .57956 .38022 Mtetra
.53 .201 .354 r
.57956 .38022 .58479 .35532 .59611 .35892 .59099 .38239 Mtetra
.517 .183 .341 r
.59099 .38239 .59611 .35892 .60754 .36269 .60248 .38376 Mtetra
.487 .146 .312 r
.60248 .38376 .60754 .36269 .61905 .36608 .61402 .38356 Mtetra
.441 .082 .259 r
.61402 .38356 .61905 .36608 .63064 .3687 .62557 .38175 Mtetra
.357 0 .155 r
.62557 .38175 .63064 .3687 .64227 .37001 .63714 .37837 Mtetra
.18 0 0 r
.63714 .37837 .64227 .37001 .65392 .36989 .6487 .3736 Mtetra
0 0 0 r
.6487 .3736 .65392 .36989 .66559 .36819 .66025 .36755 Mtetra
.686 .973 .914 r
.66025 .36755 .66559 .36819 .67724 .36502 .67178 .36055 Mtetra
.782 .88 .918 r
.67178 .36055 .67724 .36502 .68888 .36046 .68331 .35292 Mtetra
.767 .778 .861 r
.68331 .35292 .68888 .36046 .70051 .35486 .69485 .345 Mtetra
.742 .713 .824 r
.69485 .345 .70051 .35486 .71213 .34858 .70641 .33723 Mtetra
.723 .677 .805 r
.70641 .33723 .71213 .34858 .72376 .34193 .71802 .32978 Mtetra
.705 .656 .798 r
.71802 .32978 .72376 .34193 .73542 .33528 .72968 .32289 Mtetra
.692 .646 .799 r
.72968 .32289 .73542 .33528 .74711 .32876 .74141 .31659 Mtetra
.68 .645 .808 r
.74141 .31659 .74711 .32876 .75887 .3226 .75323 .31094 Mtetra
.671 .65 .82 r
.75323 .31094 .75887 .3226 .77068 .31678 .76512 .30584 Mtetra
.662 .66 .838 r
.76512 .30584 .77068 .31678 .78257 .31137 .7771 .30126 Mtetra
.656 .676 .857 r
.7771 .30126 .78257 .31137 .79452 .30627 .78915 .29705 Mtetra
.652 .697 .879 r
.78915 .29705 .79452 .30627 .80653 .3014 .80128 .29307 Mtetra
.649 .721 .901 r
.80128 .29307 .80653 .3014 .81861 .29669 .81347 .28921 Mtetra
.697 .76 .901 r
.16646 .49655 .17328 .5025 .18297 .49909 .17626 .4922 Mtetra
.692 .731 .881 r
.17626 .4922 .18297 .49909 .19268 .4958 .18609 .48788 Mtetra
.681 .701 .862 r
.18609 .48788 .19268 .4958 .2024 .49274 .19594 .48371 Mtetra
.667 .67 .843 r
.19594 .48371 .2024 .49274 .21213 .49003 .20579 .4798 Mtetra
.65 .639 .825 r
.20579 .4798 .21213 .49003 .22185 .48782 .21564 .4763 Mtetra
.63 .607 .808 r
.21564 .4763 .22185 .48782 .23156 .48615 .22547 .47331 Mtetra
.609 .576 .792 r
.22547 .47331 .23156 .48615 .24127 .48512 .23529 .47098 Mtetra
.587 .547 .777 r
.23529 .47098 .24127 .48512 .25098 .48466 .24509 .46935 Mtetra
.564 .52 .764 r
.24509 .46935 .25098 .48466 .26069 .48476 .25486 .46853 Mtetra
.544 .498 .755 r
.25486 .46853 .26069 .48476 .27044 .48518 .26463 .46847 Mtetra
.523 .481 .752 r
.26463 .46847 .27044 .48518 .28024 .48576 .2744 .46918 Mtetra
.507 .474 .755 r
.2744 .46918 .28024 .48576 .29012 .48608 .2842 .47043 Mtetra
.492 .477 .768 r
.2842 .47043 .29012 .48608 .3001 .4858 .29403 .47202 Mtetra
.48 .497 .797 r
.29403 .47202 .3001 .4858 .31019 .4846 .30393 .47366 Mtetra
.464 .542 .852 r
.30393 .47366 .31019 .4846 .32042 .48218 .31392 .47505 Mtetra
.413 .627 .942 r
.31392 .47505 .32042 .48218 .33077 .47839 .324 .47604 Mtetra
.187 .681 .919 r
.324 .47604 .33077 .47839 .34124 .47308 .33418 .47644 Mtetra
.202 0 0 r
.33418 .47644 .34124 .47308 .35182 .46619 .34448 .47579 Mtetra
.34 0 .054 r
.34448 .47579 .35182 .46619 .3625 .45774 .3549 .47387 Mtetra
.405 .039 .225 r
.3549 .47387 .3625 .45774 .37322 .44849 .36541 .47133 Mtetra
.437 .108 .309 r
.36541 .47133 .37322 .44849 .38397 .43873 .37598 .46837 Mtetra
.441 .137 .351 r
.37598 .46837 .38397 .43873 .39477 .4277 .38665 .46416 Mtetra
.441 .152 .378 r
.38665 .46416 .39477 .4277 .40562 .41521 .39741 .45846 Mtetra
.45 .173 .4 r
.39741 .45846 .40562 .41521 .41647 .40188 .40822 .45219 Mtetra
.456 .187 .416 r
.40822 .45219 .41647 .40188 .42733 .38791 .41908 .44523 Mtetra
.439 .18 .422 r
.41908 .44523 .42733 .38791 .43819 .37265 .43006 .43497 Mtetra
.422 .17 .424 r
.43006 .43497 .43819 .37265 .44904 .3567 .44111 .42154 Mtetra
.428 .177 .429 r
.44111 .42154 .44904 .3567 .45981 .34208 .45215 .40814 Mtetra
.449 .195 .436 r
.45215 .40814 .45981 .34208 .4705 .3308 .46311 .39727 Mtetra
.499 .237 .449 r
.46311 .39727 .4705 .3308 .48107 .32714 .47395 .39364 Mtetra
.541 .273 .458 r
.47395 .39364 .48107 .32714 .4916 .33111 .48474 .39727 Mtetra
.555 .284 .46 r
.48474 .39727 .4916 .33111 .5022 .33846 .49561 .40347 Mtetra
.555 .284 .459 r
.49561 .40347 .5022 .33846 .51291 .34718 .50658 .40973 Mtetra
.538 .267 .452 r
.50658 .40973 .51291 .34718 .52375 .35525 .51767 .41283 Mtetra
.517 .246 .442 r
.51767 .41283 .52375 .35525 .53471 .36206 .52886 .41263 Mtetra
.51 .233 .43 r
.52886 .41263 .53471 .36206 .54578 .36825 .5401 .41173 Mtetra
.5 .216 .414 r
.5401 .41173 .54578 .36825 .55696 .37363 .55141 .41027 Mtetra
.478 .185 .39 r
.55141 .41027 .55696 .37363 .56822 .37756 .56277 .4073 Mtetra
.446 .141 .353 r
.56277 .4073 .56822 .37756 .57956 .38022 .57415 .40307 Mtetra
.409 .083 .299 r
.57415 .40307 .57956 .38022 .59099 .38239 .58557 .39839 Mtetra
.331 0 .194 r
.58557 .39839 .59099 .38239 .60248 .38376 .59702 .39309 Mtetra
.105 0 0 r
.59702 .39309 .60248 .38376 .61402 .38356 .60847 .38647 Mtetra
.474 .864 .67 r
.60847 .38647 .61402 .38356 .62557 .38175 .61992 .37878 Mtetra
.801 .929 .918 r
.61992 .37878 .62557 .38175 .63714 .37837 .63137 .37045 Mtetra
.78 .768 .842 r
.63137 .37045 .63714 .37837 .6487 .3736 .64281 .36169 Mtetra
.745 .675 .783 r
.64281 .36169 .6487 .3736 .66025 .36755 .65426 .35267 Mtetra
.719 .623 .75 r
.65426 .35267 .66025 .36755 .67178 .36055 .66572 .34367 Mtetra
.7 .593 .733 r
.66572 .34367 .67178 .36055 .68331 .35292 .6772 .33501 Mtetra
.686 .577 .727 r
.6772 .33501 .68331 .35292 .69485 .345 .68873 .32689 Mtetra
.674 .568 .728 r
.68873 .32689 .69485 .345 .70641 .33723 .70032 .31954 Mtetra
.664 .567 .735 r
.70032 .31954 .70641 .33723 .71802 .32978 .71198 .31297 Mtetra
.656 .571 .748 r
.71198 .31297 .71802 .32978 .72968 .32289 .72372 .30723 Mtetra
.648 .579 .764 r
.72372 .30723 .72968 .32289 .74141 .31659 .73555 .30221 Mtetra
.641 .592 .784 r
.73555 .30221 .74141 .31659 .75323 .31094 .74746 .29787 Mtetra
.634 .608 .806 r
.74746 .29787 .75323 .31094 .76512 .30584 .75947 .29407 Mtetra
.628 .628 .831 r
.75947 .29407 .76512 .30584 .7771 .30126 .77156 .29067 Mtetra
.622 .651 .857 r
.77156 .29067 .7771 .30126 .78915 .29705 .78374 .28757 Mtetra
.618 .676 .883 r
.78374 .28757 .78915 .29705 .80128 .29307 .79599 .28461 Mtetra
.616 .704 .907 r
.79599 .28461 .80128 .29307 .81347 .28921 .8083 .28168 Mtetra
.71 .762 .893 r
.15958 .49055 .16646 .49655 .17626 .4922 .16946 .48577 Mtetra
.71 .75 .883 r
.16946 .48577 .17626 .4922 .18609 .48788 .17936 .48092 Mtetra
.706 .734 .873 r
.17936 .48092 .18609 .48788 .19594 .48371 .1893 .47605 Mtetra
.7 .715 .86 r
.1893 .47605 .19594 .48371 .20579 .4798 .19926 .47124 Mtetra
.691 .69 .845 r
.19926 .47124 .20579 .4798 .21564 .4763 .20923 .46655 Mtetra
.677 .66 .826 r
.20923 .46655 .21564 .4763 .22547 .47331 .21921 .46209 Mtetra
.66 .626 .805 r
.21921 .46209 .22547 .47331 .23529 .47098 .22919 .45797 Mtetra
.64 .59 .782 r
.22919 .45797 .23529 .47098 .24509 .46935 .23916 .45432 Mtetra
.619 .554 .759 r
.23916 .45432 .24509 .46935 .25486 .46853 .24912 .45125 Mtetra
.597 .519 .737 r
.24912 .45125 .25486 .46853 .26463 .46847 .25906 .44887 Mtetra
.576 .487 .717 r
.25906 .44887 .26463 .46847 .2744 .46918 .26898 .44731 Mtetra
.558 .461 .7 r
.26898 .44731 .2744 .46918 .2842 .47043 .27888 .44653 Mtetra
.543 .44 .687 r
.27888 .44653 .2842 .47043 .29403 .47202 .28879 .44656 Mtetra
.532 .425 .678 r
.28879 .44656 .29403 .47202 .30393 .47366 .29871 .44719 Mtetra
.525 .416 .672 r
.29871 .44719 .30393 .47366 .31392 .47505 .30867 .44826 Mtetra
.518 .411 .671 r
.30867 .44826 .31392 .47505 .324 .47604 .31867 .44971 Mtetra
.513 .41 .674 r
.31867 .44971 .324 .47604 .33418 .47644 .32873 .45142 Mtetra
.516 .418 .683 r
.32873 .45142 .33418 .47644 .34448 .47579 .33886 .45291 Mtetra
.524 .436 .698 r
.33886 .45291 .34448 .47579 .3549 .47387 .3491 .4539 Mtetra
.523 .456 .722 r
.3491 .4539 .3549 .47387 .36541 .47133 .35942 .45477 Mtetra
.517 .485 .76 r
.35942 .45477 .36541 .47133 .37598 .46837 .3698 .45561 Mtetra
.515 .538 .818 r
.3698 .45561 .37598 .46837 .38665 .46416 .38027 .45611 Mtetra
.488 .638 .922 r
.38027 .45611 .38665 .46416 .39741 .45846 .39082 .45624 Mtetra
.121 .641 .885 r
.39082 .45624 .39741 .45846 .40822 .45219 .40141 .45702 Mtetra
.399 0 0 r
.40141 .45702 .40822 .45219 .41908 .44523 .41206 .45822 Mtetra
.409 .011 .17 r
.41206 .45822 .41908 .44523 .43006 .43497 .42286 .45678 Mtetra
.392 .06 .278 r
.42286 .45678 .43006 .43497 .44111 .42154 .43381 .45207 Mtetra
.415 .114 .344 r
.43381 .45207 .44111 .42154 .45215 .40814 .44483 .44611 Mtetra
.441 .154 .38 r
.44483 .44611 .45215 .40814 .46311 .39727 .45588 .44015 Mtetra
.477 .194 .404 r
.45588 .44015 .46311 .39727 .47395 .39364 .46692 .43654 Mtetra
.5 .214 .411 r
.46692 .43654 .47395 .39364 .48474 .39727 .47796 .43528 Mtetra
.496 .202 .397 r
.47796 .43528 .48474 .39727 .49561 .40347 .48907 .43403 Mtetra
.469 .162 .361 r
.48907 .43403 .49561 .40347 .50658 .40973 .50025 .43154 Mtetra
.371 .042 .271 r
.50025 .43154 .50658 .40973 .51767 .41283 .51149 .42574 Mtetra
.122 0 .034 r
.51149 .42574 .51767 .41283 .52886 .41263 .52277 .41728 Mtetra
0 0 0 r
.52277 .41728 .52886 .41263 .5401 .41173 .53406 .40922 Mtetra
.774 .934 .935 r
.53406 .40922 .5401 .41173 .55141 .41027 .54538 .4018 Mtetra
.756 .742 .84 r
.54538 .4018 .55141 .41027 .56277 .4073 .55671 .39399 Mtetra
.719 .64 .769 r
.55671 .39399 .56277 .4073 .57415 .40307 .56805 .38582 Mtetra
.692 .584 .73 r
.56805 .38582 .57415 .40307 .58557 .39839 .57941 .3776 Mtetra
.674 .547 .703 r
.57941 .3776 .58557 .39839 .59702 .39309 .59078 .36924 Mtetra
.666 .525 .683 r
.59078 .36924 .59702 .39309 .60847 .38647 .60215 .36036 Mtetra
.659 .511 .671 r
.60215 .36036 .60847 .38647 .61992 .37878 .61353 .35123 Mtetra
.651 .5 .665 r
.61353 .35123 .61992 .37878 .63137 .37045 .62492 .34235 Mtetra
.646 .495 .664 r
.62492 .34235 .63137 .37045 .64281 .36169 .63634 .33383 Mtetra
.642 .493 .665 r
.63634 .33383 .64281 .36169 .65426 .35267 .64779 .32576 Mtetra
.638 .494 .671 r
.64779 .32576 .65426 .35267 .66572 .34367 .65928 .31829 Mtetra
.634 .498 .68 r
.65928 .31829 .66572 .34367 .6772 .33501 .67084 .31164 Mtetra
.63 .506 .693 r
.67084 .31164 .6772 .33501 .68873 .32689 .68246 .30578 Mtetra
.626 .518 .711 r
.68246 .30578 .68873 .32689 .70032 .31954 .69416 .30076 Mtetra
.623 .534 .733 r
.69416 .30076 .70032 .31954 .71198 .31297 .70595 .29645 Mtetra
.619 .554 .759 r
.70595 .29645 .71198 .31297 .72372 .30723 .71782 .29274 Mtetra
.616 .577 .788 r
.71782 .29274 .72372 .30723 .73555 .30221 .72977 .28952 Mtetra
.612 .603 .818 r
.72977 .28952 .73555 .30221 .74746 .29787 .74181 .28665 Mtetra
.607 .629 .847 r
.74181 .28665 .74746 .29787 .75947 .29407 .75393 .28402 Mtetra
.603 .655 .873 r
.75393 .28402 .75947 .29407 .77156 .29067 .76611 .28152 Mtetra
.6 .676 .894 r
.76611 .28152 .77156 .29067 .78374 .28757 .77837 .27907 Mtetra
.598 .695 .911 r
.77837 .27907 .78374 .28757 .79599 .28461 .7907 .27662 Mtetra
.598 .711 .924 r
.7907 .27662 .79599 .28461 .8083 .28168 .80308 .27409 Mtetra
.706 .762 .895 r
.15266 .48451 .15958 .49055 .16946 .48577 .16255 .47982 Mtetra
.712 .766 .895 r
.16255 .47982 .16946 .48577 .17936 .48092 .17248 .47497 Mtetra
.717 .768 .892 r
.17248 .47497 .17936 .48092 .1893 .47605 .18246 .46992 Mtetra
.722 .764 .886 r
.18246 .46992 .1893 .47605 .19926 .47124 .19248 .46465 Mtetra
.726 .752 .873 r
.19248 .46465 .19926 .47124 .20923 .46655 .20256 .45913 Mtetra
.724 .729 .855 r
.20256 .45913 .20923 .46655 .21921 .46209 .21267 .45344 Mtetra
.716 .698 .832 r
.21267 .45344 .21921 .46209 .22919 .45797 .22282 .44763 Mtetra
.702 .66 .805 r
.22282 .44763 .22919 .45797 .23916 .45432 .23299 .44182 Mtetra
.685 .619 .777 r
.23299 .44182 .23916 .45432 .24912 .45125 .24318 .43615 Mtetra
.663 .577 .748 r
.24318 .43615 .24912 .45125 .25906 .44887 .25336 .43078 Mtetra
.64 .538 .722 r
.25336 .43078 .25906 .44887 .26898 .44731 .26353 .4259 Mtetra
.618 .502 .698 r
.26353 .4259 .26898 .44731 .27888 .44653 .27367 .42165 Mtetra
.597 .47 .678 r
.27367 .42165 .27888 .44653 .28879 .44656 .28379 .41822 Mtetra
.58 .445 .661 r
.28379 .41822 .28879 .44656 .29871 .44719 .2939 .41553 Mtetra
.567 .425 .648 r
.2939 .41553 .29871 .44719 .30867 .44826 .304 .41357 Mtetra
.555 .409 .637 r
.304 .41357 .30867 .44826 .31867 .44971 .3141 .41238 Mtetra
.545 .395 .629 r
.3141 .41238 .31867 .44971 .32873 .45142 .3242 .41194 Mtetra
.539 .387 .623 r
.3242 .41194 .32873 .45142 .33886 .45291 .33433 .41198 Mtetra
.536 .382 .619 r
.33433 .41198 .33886 .45291 .3491 .4539 .34452 .41231 Mtetra
.533 .379 .618 r
.34452 .41231 .3491 .4539 .35942 .45477 .35475 .41291 Mtetra
.53 .377 .617 r
.35475 .41291 .35942 .45477 .3698 .45561 .36503 .4138 Mtetra
.522 .372 .617 r
.36503 .4138 .3698 .45561 .38027 .45611 .37535 .41539 Mtetra
.511 .365 .62 r
.37535 .41539 .38027 .45611 .39082 .45624 .3857 .41801 Mtetra
.485 .353 .625 r
.3857 .41801 .39082 .45624 .40141 .45702 .39606 .42256 Mtetra
.45 .338 .635 r
.39606 .42256 .40141 .45702 .41206 .45822 .40644 .42899 Mtetra
.435 .347 .658 r
.40644 .42899 .41206 .45822 .42286 .45678 .41694 .43527 Mtetra
.425 .385 .71 r
.41694 .43527 .42286 .45678 .43381 .45207 .42758 .44028 Mtetra
.381 .487 .843 r
.42758 .44028 .43381 .45207 .44483 .44611 .43837 .44357 Mtetra
.163 .662 .912 r
.43837 .44357 .44483 .44611 .45588 .44015 .44931 .44425 Mtetra
0 0 0 r
.44931 .44425 .45588 .44015 .46692 .43654 .46041 .44062 Mtetra
.46 .846 .631 r
.46041 .44062 .46692 .43654 .47796 .43528 .47162 .43267 Mtetra
.857 .917 .87 r
.47162 .43267 .47796 .43528 .48907 .43403 .48289 .42209 Mtetra
.786 .684 .752 r
.48289 .42209 .48907 .43403 .50025 .43154 .49417 .40973 Mtetra
.724 .57 .681 r
.49417 .40973 .50025 .43154 .51149 .42574 .50545 .39608 Mtetra
.688 .517 .649 r
.50545 .39608 .51149 .42574 .52277 .41728 .5167 .38224 Mtetra
.656 .481 .635 r
.5167 .38224 .52277 .41728 .53406 .40922 .52793 .37026 Mtetra
.631 .455 .627 r
.52793 .37026 .53406 .40922 .54538 .4018 .53915 .36021 Mtetra
.618 .441 .621 r
.53915 .36021 .54538 .4018 .55671 .39399 .55039 .35119 Mtetra
.61 .434 .619 r
.55039 .35119 .55671 .39399 .56805 .38582 .56164 .34284 Mtetra
.608 .432 .618 r
.56164 .34284 .56805 .38582 .57941 .3776 .57291 .33479 Mtetra
.606 .431 .619 r
.57291 .33479 .57941 .3776 .59078 .36924 .5842 .327 Mtetra
.604 .431 .62 r
.5842 .327 .59078 .36924 .60215 .36036 .59552 .31949 Mtetra
.603 .432 .623 r
.59552 .31949 .60215 .36036 .61353 .35123 .60687 .31244 Mtetra
.599 .434 .629 r
.60687 .31244 .61353 .35123 .62492 .34235 .61827 .30617 Mtetra
.596 .437 .637 r
.61827 .30617 .62492 .34235 .63634 .33383 .62972 .30067 Mtetra
.594 .444 .647 r
.62972 .30067 .63634 .33383 .64779 .32576 .64124 .29591 Mtetra
.591 .452 .661 r
.64124 .29591 .64779 .32576 .65928 .31829 .65283 .29191 Mtetra
.587 .464 .679 r
.65283 .29191 .65928 .31829 .67084 .31164 .6645 .28874 Mtetra
.583 .48 .702 r
.6645 .28874 .67084 .31164 .68246 .30578 .67627 .28624 Mtetra
.58 .502 .731 r
.67627 .28624 .68246 .30578 .69416 .30076 .68812 .28423 Mtetra
.577 .53 .766 r
.68812 .28423 .69416 .30076 .70595 .29645 .70005 .28256 Mtetra
.575 .564 .804 r
.70005 .28256 .70595 .29645 .71782 .29274 .71206 .28101 Mtetra
.574 .601 .843 r
.71206 .28101 .71782 .29274 .72977 .28952 .72415 .27949 Mtetra
.574 .64 .879 r
.72415 .27949 .72977 .28952 .74181 .28665 .73629 .27784 Mtetra
.575 .674 .907 r
.73629 .27784 .74181 .28665 .75393 .28402 .7485 .27602 Mtetra
.58 .702 .926 r
.7485 .27602 .75393 .28402 .76611 .28152 .76075 .27394 Mtetra
.586 .719 .935 r
.76075 .27394 .76611 .28152 .77837 .27907 .77306 .27163 Mtetra
.592 .728 .938 r
.77306 .27163 .77837 .27907 .7907 .27662 .78542 .26912 Mtetra
.599 .73 .936 r
.78542 .26912 .7907 .27662 .80308 .27409 .79782 .26643 Mtetra
.687 .758 .906 r
.14569 .47843 .15266 .48451 .16255 .47982 .15554 .47429 Mtetra
.697 .779 .914 r
.15554 .47429 .16255 .47982 .17248 .47497 .16544 .46991 Mtetra
.71 .798 .919 r
.16544 .46991 .17248 .47497 .18246 .46992 .17541 .46518 Mtetra
.725 .812 .918 r
.17541 .46518 .18246 .46992 .19248 .46465 .18545 .46003 Mtetra
.743 .818 .91 r
.18545 .46003 .19248 .46465 .20256 .45913 .19558 .4543 Mtetra
.755 .812 .898 r
.19558 .4543 .20256 .45913 .21267 .45344 .20577 .44811 Mtetra
.763 .797 .88 r
.20577 .44811 .21267 .45344 .22282 .44763 .21603 .44146 Mtetra
.762 .772 .862 r
.21603 .44146 .22282 .44763 .23299 .44182 .22633 .43454 Mtetra
.754 .742 .841 r
.22633 .43454 .23299 .44182 .24318 .43615 .23666 .42748 Mtetra
.74 .707 .82 r
.23666 .42748 .24318 .43615 .25336 .43078 .24699 .42049 Mtetra
.721 .67 .799 r
.24699 .42049 .25336 .43078 .26353 .4259 .25733 .41376 Mtetra
.697 .631 .779 r
.25733 .41376 .26353 .4259 .27367 .42165 .26764 .40751 Mtetra
.671 .593 .76 r
.26764 .40751 .27367 .42165 .28379 .41822 .27792 .40197 Mtetra
.648 .559 .74 r
.27792 .40197 .28379 .41822 .2939 .41553 .28818 .39707 Mtetra
.627 .528 .722 r
.28818 .39707 .2939 .41553 .304 .41357 .29842 .39283 Mtetra
.607 .5 .706 r
.29842 .39283 .304 .41357 .3141 .41238 .30865 .3893 Mtetra
.59 .475 .691 r
.30865 .3893 .3141 .41238 .3242 .41194 .31887 .38648 Mtetra
.577 .455 .677 r
.31887 .38648 .3242 .41194 .33433 .41198 .3291 .38424 Mtetra
.567 .439 .665 r
.3291 .38424 .33433 .41198 .34452 .41231 .33935 .38244 Mtetra
.565 .43 .656 r
.33935 .38244 .34452 .41231 .35475 .41291 .34965 .38067 Mtetra
.564 .422 .646 r
.34965 .38067 .35475 .41291 .36503 .4138 .36001 .37882 Mtetra
.554 .407 .637 r
.36001 .37882 .36503 .4138 .37535 .41539 .37038 .37761 Mtetra
.54 .391 .628 r
.37038 .37761 .37535 .41539 .3857 .41801 .38077 .37752 Mtetra
.52 .372 .62 r
.38077 .37752 .3857 .41801 .39606 .42256 .39114 .37919 Mtetra
.499 .352 .612 r
.39114 .37919 .39606 .42256 .40644 .42899 .40152 .38284 Mtetra
.482 .335 .605 r
.40152 .38284 .40644 .42899 .41694 .43527 .41192 .38829 Mtetra
.472 .327 .602 r
.41192 .38829 .41694 .43527 .42758 .44028 .42239 .39481 Mtetra
.477 .333 .607 r
.42239 .39481 .42758 .44028 .43837 .44357 .43299 .40075 Mtetra
.503 .357 .616 r
.43299 .40075 .43837 .44357 .44931 .44425 .44376 .40411 Mtetra
.575 .414 .625 r
.44376 .40411 .44931 .44425 .46041 .44062 .45477 .40042 Mtetra
.634 .455 .623 r
.45477 .40042 .46041 .44062 .47162 .43267 .46596 .38967 Mtetra
.646 .459 .616 r
.46596 .38967 .47162 .43267 .48289 .42209 .47719 .3763 Mtetra
.644 .453 .611 r
.47719 .3763 .48289 .42209 .49417 .40973 .4884 .36232 Mtetra
.634 .444 .608 r
.4884 .36232 .49417 .40973 .50545 .39608 .49958 .34938 Mtetra
.623 .437 .609 r
.49958 .34938 .50545 .39608 .5167 .38224 .51073 .33821 Mtetra
.614 .434 .615 r
.51073 .33821 .5167 .38224 .52793 .37026 .52187 .32904 Mtetra
.605 .432 .621 r
.52187 .32904 .52793 .37026 .53915 .36021 .53302 .32162 Mtetra
.6 .434 .628 r
.53302 .32162 .53915 .36021 .55039 .35119 .5442 .31532 Mtetra
.598 .438 .636 r
.5442 .31532 .55039 .35119 .56164 .34284 .55542 .30968 Mtetra
.604 .449 .645 r
.55542 .30968 .56164 .34284 .57291 .33479 .56666 .30394 Mtetra
.608 .459 .654 r
.56666 .30394 .57291 .33479 .5842 .327 .57794 .29822 Mtetra
.608 .466 .663 r
.57794 .29822 .5842 .327 .59552 .31949 .58926 .29295 Mtetra
.606 .474 .675 r
.58926 .29295 .59552 .31949 .60687 .31244 .60064 .28826 Mtetra
.602 .483 .69 r
.60064 .28826 .60687 .31244 .61827 .30617 .61207 .28429 Mtetra
.596 .493 .707 r
.61207 .28429 .61827 .30617 .62972 .30067 .62358 .28104 Mtetra
.589 .506 .728 r
.62358 .28104 .62972 .30067 .64124 .29591 .63516 .27848 Mtetra
.58 .52 .752 r
.63516 .27848 .64124 .29591 .65283 .29191 .64683 .27658 Mtetra
.565 .536 .782 r
.64683 .27658 .65283 .29191 .6645 .28874 .6586 .27541 Mtetra
.55 .558 .815 r
.6586 .27541 .6645 .28874 .67627 .28624 .67045 .27475 Mtetra
.535 .585 .851 r
.67045 .27475 .67627 .28624 .68812 .28423 .6824 .27436 Mtetra
.522 .616 .887 r
.6824 .27436 .68812 .28423 .70005 .28256 .69444 .27406 Mtetra
.513 .651 .92 r
.69444 .27406 .70005 .28256 .71206 .28101 .70654 .27362 Mtetra
.51 .686 .947 r
.70654 .27362 .71206 .28101 .72415 .27949 .71871 .27291 Mtetra
.519 .721 .965 r
.71871 .27291 .72415 .27949 .73629 .27784 .73092 .27172 Mtetra
.535 .747 .974 r
.73092 .27172 .73629 .27784 .7485 .27602 .74318 .27006 Mtetra
.562 .767 .974 r
.74318 .27006 .7485 .27602 .76075 .27394 .75546 .26781 Mtetra
.587 .773 .968 r
.75546 .26781 .76075 .27394 .77306 .27163 .76778 .2651 Mtetra
.607 .768 .957 r
.76778 .2651 .77306 .27163 .78542 .26912 .78013 .26204 Mtetra
.621 .756 .943 r
.78013 .26204 .78542 .26912 .79782 .26643 .79252 .25872 Mtetra
.656 .751 .92 r
.13868 .4723 .14569 .47843 .15554 .47429 .14845 .46897 Mtetra
.666 .782 .935 r
.14845 .46897 .15554 .47429 .16544 .46991 .15829 .46536 Mtetra
.681 .813 .946 r
.15829 .46536 .16544 .46991 .17541 .46518 .16821 .46135 Mtetra
.701 .843 .951 r
.16821 .46135 .17541 .46518 .18545 .46003 .17821 .45682 Mtetra
.727 .869 .948 r
.17821 .45682 .18545 .46003 .19558 .4543 .18832 .45159 Mtetra
.747 .888 .943 r
.18832 .45159 .19558 .4543 .20577 .44811 .19851 .44578 Mtetra
.766 .902 .936 r
.19851 .44578 .20577 .44811 .21603 .44146 .20878 .43939 Mtetra
.777 .911 .932 r
.20878 .43939 .21603 .44146 .22633 .43454 .21911 .43264 Mtetra
.783 .918 .929 r
.21911 .43264 .22633 .43454 .23666 .42748 .22947 .42568 Mtetra
.784 .922 .929 r
.22947 .42568 .23666 .42748 .24699 .42049 .23985 .41865 Mtetra
.78 .922 .931 r
.23985 .41865 .24699 .42049 .25733 .41376 .25024 .41172 Mtetra
.771 .917 .936 r
.25024 .41172 .25733 .41376 .26764 .40751 .26063 .40505 Mtetra
.757 .904 .942 r
.26063 .40505 .26764 .40751 .27792 .40197 .271 .39882 Mtetra
.747 .881 .941 r
.271 .39882 .27792 .40197 .28818 .39707 .28137 .39293 Mtetra
.735 .846 .932 r
.28137 .39293 .28818 .39707 .29842 .39283 .29174 .38738 Mtetra
.72 .798 .913 r
.29174 .38738 .29842 .39283 .30865 .3893 .30211 .38215 Mtetra
.702 .742 .883 r
.30211 .38215 .30865 .3893 .31887 .38648 .31249 .37725 Mtetra
.68 .682 .845 r
.31249 .37725 .31887 .38648 .3291 .38424 .32288 .37264 Mtetra
.661 .628 .806 r
.32288 .37264 .3291 .38424 .33935 .38244 .33329 .36826 Mtetra
.657 .589 .767 r
.33329 .36826 .33935 .38244 .34965 .38067 .34376 .36338 Mtetra
.654 .555 .731 r
.34376 .36338 .34965 .38067 .36001 .37882 .35431 .35773 Mtetra
.638 .518 .7 r
.35431 .35773 .36001 .37882 .37038 .37761 .36488 .35204 Mtetra
.619 .483 .674 r
.36488 .35204 .37038 .37761 .38077 .37752 .37547 .34671 Mtetra
.599 .451 .651 r
.37547 .34671 .38077 .37752 .39114 .37919 .38606 .34192 Mtetra
.578 .419 .63 r
.38606 .34192 .39114 .37919 .40152 .38284 .39665 .3382 Mtetra
.544 .382 .611 r
.39665 .3382 .40152 .38284 .41192 .38829 .40717 .33733 Mtetra
.517 .353 .598 r
.40717 .33733 .41192 .38829 .42239 .39481 .41764 .33942 Mtetra
.507 .34 .59 r
.41764 .33942 .42239 .39481 .43299 .40075 .42816 .34288 Mtetra
.514 .344 .588 r
.42816 .34288 .43299 .40075 .44376 .40411 .43879 .34557 Mtetra
.561 .378 .59 r
.43879 .34557 .44376 .40411 .45477 .40042 .44966 .34181 Mtetra
.601 .407 .592 r
.44966 .34181 .45477 .40042 .46596 .38967 .4607 .33159 Mtetra
.606 .411 .592 r
.4607 .33159 .46596 .38967 .47719 .3763 .47176 .32057 Mtetra
.6 .409 .595 r
.47176 .32057 .47719 .3763 .4884 .36232 .48279 .3109 Mtetra
.586 .403 .601 r
.48279 .3109 .4884 .36232 .49958 .34938 .4938 .30421 Mtetra
.57 .4 .612 r
.4938 .30421 .49958 .34938 .51073 .33821 .50481 .30037 Mtetra
.567 .411 .63 r
.50481 .30037 .51073 .33821 .52187 .32904 .51587 .29761 Mtetra
.567 .428 .652 r
.51587 .29761 .52187 .32904 .53302 .32162 .52697 .29541 Mtetra
.567 .449 .678 r
.52697 .29541 .53302 .32162 .5442 .31532 .53814 .29357 Mtetra
.573 .478 .709 r
.53814 .29357 .5442 .31532 .55542 .30968 .54936 .29169 Mtetra
.595 .521 .742 r
.54936 .29169 .55542 .30968 .56666 .30394 .56064 .28904 Mtetra
.613 .566 .778 r
.56064 .28904 .56666 .30394 .57794 .29822 .57197 .28589 Mtetra
.615 .606 .819 r
.57197 .28589 .57794 .29822 .58926 .29295 .58335 .28296 Mtetra
.61 .653 .867 r
.58335 .28296 .58926 .29295 .60064 .28826 .59479 .28035 Mtetra
.593 .703 .92 r
.59479 .28035 .60064 .28826 .61207 .28429 .6063 .27806 Mtetra
.56 .747 .964 r
.6063 .27806 .61207 .28429 .62358 .28104 .61788 .27611 Mtetra
.51 .775 .992 r
.61788 .27611 .62358 .28104 .63516 .27848 .62954 .2745 Mtetra
.445 .783 .998 r
.62954 .2745 .63516 .27848 .64683 .27658 .64127 .27326 Mtetra
.369 .767 .986 r
.64127 .27326 .64683 .27658 .6586 .27541 .6531 .27248 Mtetra
.315 .749 .969 r
.6531 .27248 .6586 .27541 .67045 .27475 .66501 .27197 Mtetra
.292 .741 .96 r
.66501 .27197 .67045 .27475 .6824 .27436 .67701 .27157 Mtetra
.297 .744 .961 r
.67701 .27157 .6824 .27436 .69444 .27406 .68908 .27112 Mtetra
.326 .757 .971 r
.68908 .27112 .69444 .27406 .70654 .27362 .70122 .27046 Mtetra
.373 .778 .984 r
.70122 .27046 .70654 .27362 .71871 .27291 .71341 .26942 Mtetra
.438 .803 .995 r
.71341 .26942 .71871 .27291 .73092 .27172 .72565 .26779 Mtetra
.502 .819 1 r
.72565 .26779 .73092 .27172 .74318 .27006 .73791 .26556 Mtetra
.566 .828 .995 r
.73791 .26556 .74318 .27006 .75546 .26781 .75019 .2626 Mtetra
.61 .821 .981 r
.75019 .2626 .75546 .26781 .76778 .2651 .7625 .2591 Mtetra
.638 .803 .962 r
.7625 .2591 .76778 .2651 .78013 .26204 .77482 .25517 Mtetra
.655 .78 .94 r
.77482 .25517 .78013 .26204 .79252 .25872 .78718 .25095 Mtetra
.621 .742 .934 r
.13161 .46613 .13868 .4723 .14845 .46897 .14131 .46355 Mtetra
.625 .771 .95 r
.14131 .46355 .14845 .46897 .15829 .46536 .15108 .46079 Mtetra
.631 .804 .966 r
.15108 .46079 .15829 .46536 .16821 .46135 .16091 .45776 Mtetra
.636 .842 .98 r
.16091 .45776 .16821 .46135 .17821 .45682 .17082 .45442 Mtetra
.638 .886 .986 r
.17082 .45442 .17821 .45682 .18832 .45159 .18081 .45064 Mtetra
.609 .922 .973 r
.18081 .45064 .18832 .45159 .19851 .44578 .19087 .44654 Mtetra
.527 .919 .903 r
.19087 .44654 .19851 .44578 .20878 .43939 .20098 .44217 Mtetra
.365 .824 .729 r
.20098 .44217 .20878 .43939 .21911 .43264 .21115 .43761 Mtetra
0 0 0 r
.21115 .43761 .21911 .43264 .22947 .42568 .22136 .43293 Mtetra
.22136 .43293 .22947 .42568 .23985 .41865 .23162 .42804 Mtetra
.098 0 0 r
.23162 .42804 .23985 .41865 .25024 .41172 .24194 .4229 Mtetra
.158 0 0 r
.24194 .4229 .25024 .41172 .26063 .40505 .2523 .41754 Mtetra
.19 0 .027 r
.2523 .41754 .26063 .40505 .271 .39882 .2627 .41195 Mtetra
.195 0 .046 r
.2627 .41195 .271 .39882 .28137 .39293 .27315 .40609 Mtetra
.182 0 .04 r
.27315 .40609 .28137 .39293 .29174 .38738 .28365 .39995 Mtetra
.156 0 .013 r
.28365 .39995 .29174 .38738 .30211 .38215 .29419 .39363 Mtetra
.112 0 0 r
.29419 .39363 .30211 .38215 .31249 .37725 .30475 .3872 Mtetra
.052 0 0 r
.30475 .3872 .31249 .37725 .32288 .37264 .31534 .38084 Mtetra
0 0 0 r
.31534 .38084 .32288 .37264 .33329 .36826 .32594 .37456 Mtetra
.32594 .37456 .33329 .36826 .34376 .36338 .3366 .36766 Mtetra
.509 .879 .666 r
.3366 .36766 .34376 .36338 .35431 .35773 .34733 .35981 Mtetra
.715 .987 .834 r
.34733 .35981 .35431 .35773 .36488 .35204 .35811 .35139 Mtetra
.822 .966 .898 r
.35811 .35139 .36488 .35204 .37547 .34671 .36892 .34249 Mtetra
.836 .853 .858 r
.36892 .34249 .37547 .34671 .38606 .34192 .37978 .33265 Mtetra
.787 .72 .789 r
.37978 .33265 .38606 .34192 .39665 .3382 .39066 .32243 Mtetra
.691 .591 .739 r
.39066 .32243 .39665 .3382 .40717 .33733 .40142 .31496 Mtetra
.604 .49 .696 r
.40142 .31496 .40717 .33733 .41764 .33942 .41207 .31117 Mtetra
.549 .426 .664 r
.41207 .31117 .41764 .33942 .42816 .34288 .42267 .31038 Mtetra
.529 .398 .646 r
.42267 .31038 .42816 .34288 .43879 .34557 .43329 .31095 Mtetra
.581 .427 .638 r
.43329 .31095 .43879 .34557 .44966 .34181 .44409 .30714 Mtetra
.624 .457 .636 r
.44409 .30714 .44966 .34181 .4607 .33159 .45504 .29894 Mtetra
.616 .457 .644 r
.45504 .29894 .4607 .33159 .47176 .32057 .46597 .29209 Mtetra
.591 .454 .663 r
.46597 .29209 .47176 .32057 .48279 .3109 .47688 .28825 Mtetra
.54 .45 .701 r
.47688 .28825 .48279 .3109 .4938 .30421 .48778 .28813 Mtetra
.455 .457 .772 r
.48778 .28813 .4938 .30421 .50481 .30037 .49874 .29077 Mtetra
.386 .544 .89 r
.49874 .29077 .50481 .30037 .51587 .29761 .50978 .29306 Mtetra
.248 .646 .962 r
.50978 .29306 .51587 .29761 .52697 .29541 .52092 .29441 Mtetra
0 .566 .764 r
.52092 .29441 .52697 .29541 .53814 .29357 .53214 .2953 Mtetra
.175 0 0 r
.53214 .2953 .53814 .29357 .54936 .29169 .54344 .29561 Mtetra
.225 0 0 r
.54344 .29561 .54936 .29169 .56064 .28904 .5548 .29498 Mtetra
.269 0 0 r
.5548 .29498 .56064 .28904 .57197 .28589 .56623 .29372 Mtetra
.331 0 0 r
.56623 .29372 .57197 .28589 .58335 .28296 .57773 .29256 Mtetra
.369 0 .053 r
.57773 .29256 .58335 .28296 .59479 .28035 .5893 .29147 Mtetra
.388 0 .104 r
.5893 .29147 .59479 .28035 .6063 .27806 .60093 .29027 Mtetra
.395 0 .133 r
.60093 .29027 .6063 .27806 .61788 .27611 .61263 .28891 Mtetra
.393 0 .145 r
.61263 .28891 .61788 .27611 .62954 .2745 .62439 .28725 Mtetra
.384 0 .14 r
.62439 .28725 .62954 .2745 .64127 .27326 .63621 .28532 Mtetra
.368 0 .117 r
.63621 .28532 .64127 .27326 .6531 .27248 .64808 .28317 Mtetra
.339 0 .07 r
.64808 .28317 .6531 .27248 .66501 .27197 .66001 .28079 Mtetra
.288 0 0 r
.66001 .28079 .66501 .27197 .67701 .27157 .672 .27815 Mtetra
.204 0 0 r
.672 .27815 .67701 .27157 .68908 .27112 .68403 .2753 Mtetra
.071 0 0 r
.68403 .2753 .68908 .27112 .70122 .27046 .69612 .27232 Mtetra
0 0 0 r
.69612 .27232 .70122 .27046 .71341 .26942 .70826 .26914 Mtetra
.357 .83 .86 r
.70826 .26914 .71341 .26942 .72565 .26779 .72044 .26569 Mtetra
.52 .89 .972 r
.72044 .26569 .72565 .26779 .73791 .26556 .73266 .26189 Mtetra
.615 .881 .99 r
.73266 .26189 .73791 .26556 .75019 .2626 .7449 .25764 Mtetra
.657 .85 .974 r
.7449 .25764 .75019 .2626 .7625 .2591 .75717 .25305 Mtetra
.676 .818 .951 r
.75717 .25305 .7625 .2591 .77482 .25517 .76947 .24818 Mtetra
.684 .789 .93 r
.76947 .24818 .77482 .25517 .78718 .25095 .7818 .24311 Mtetra
.59 .733 .943 r
.12449 .45992 .13161 .46613 .14131 .46355 .13414 .45791 Mtetra
.584 .752 .958 r
.13414 .45791 .14131 .46355 .15108 .46079 .14384 .4559 Mtetra
.571 .777 .976 r
.14384 .4559 .15108 .46079 .16091 .45776 .15358 .45389 Mtetra
.543 .807 .995 r
.15358 .45389 .16091 .45776 .17082 .45442 .16336 .45192 Mtetra
.481 .834 .996 r
.16336 .45192 .17082 .45442 .18081 .45064 .17318 .45001 Mtetra
.33 .804 .911 r
.17318 .45001 .18081 .45064 .19087 .44654 .18304 .44821 Mtetra
0 0 0 r
.18304 .44821 .19087 .44654 .20098 .44217 .19292 .44662 Mtetra
.153 0 0 r
.19292 .44662 .20098 .44217 .21115 .43761 .20285 .44507 Mtetra
.284 0 0 r
.20285 .44507 .21115 .43761 .22136 .43293 .21282 .44352 Mtetra
.337 0 .062 r
.21282 .44352 .22136 .43293 .23162 .42804 .22289 .44159 Mtetra
.353 0 .138 r
.22289 .44159 .23162 .42804 .24194 .4229 .23306 .43899 Mtetra
.356 0 .181 r
.23306 .43899 .24194 .4229 .2523 .41754 .24334 .43561 Mtetra
.347 0 .203 r
.24334 .43561 .2523 .41754 .2627 .41195 .25374 .43132 Mtetra
.334 0 .212 r
.25374 .43132 .2627 .41195 .27315 .40609 .26424 .42616 Mtetra
.315 0 .211 r
.26424 .42616 .27315 .40609 .28365 .39995 .27484 .42016 Mtetra
.298 0 .204 r
.27484 .42016 .28365 .39995 .29419 .39363 .28551 .41355 Mtetra
.282 0 .194 r
.28551 .41355 .29419 .39363 .30475 .3872 .29623 .40652 Mtetra
.272 0 .183 r
.29623 .40652 .30475 .3872 .31534 .38084 .30698 .39943 Mtetra
.266 0 .172 r
.30698 .39943 .31534 .38084 .32594 .37456 .31773 .39244 Mtetra
.241 0 .152 r
.31773 .39244 .32594 .37456 .3366 .36766 .32853 .38509 Mtetra
.208 0 .13 r
.32853 .38509 .3366 .36766 .34733 .35981 .33938 .37709 Mtetra
.171 0 .111 r
.33938 .37709 .34733 .35981 .35811 .35139 .3503 .36824 Mtetra
.11 0 .076 r
.3503 .36824 .35811 .35139 .36892 .34249 .36128 .35822 Mtetra
0 0 0 r
.36128 .35822 .36892 .34249 .37978 .33265 .37238 .34575 Mtetra
.37238 .34575 .37978 .33265 .39066 .32243 .38355 .33123 Mtetra
.38355 .33123 .39066 .32243 .40142 .31496 .39462 .31854 Mtetra
.647 .95 .73 r
.39462 .31854 .40142 .31496 .41207 .31117 .40554 .3093 Mtetra
.674 .93 .97 r
.40554 .3093 .41207 .31117 .42267 .31038 .41633 .30414 Mtetra
.57 .741 .957 r
.41633 .30414 .42267 .31038 .43329 .31095 .42704 .30219 Mtetra
.656 .695 .875 r
.42704 .30219 .43329 .31095 .44409 .30714 .43787 .29835 Mtetra
.709 .714 .853 r
.43787 .29835 .44409 .30714 .45504 .29894 .44878 .29262 Mtetra
.599 .751 .95 r
.44878 .29262 .45504 .29894 .46597 .29209 .45966 .29011 Mtetra
0 .554 .812 r
.45966 .29011 .46597 .29209 .47688 .28825 .47052 .2917 Mtetra
.551 .017 0 r
.47052 .2917 .47688 .28825 .48778 .28813 .48141 .29678 Mtetra
.617 .171 .169 r
.48141 .29678 .48778 .28813 .49874 .29077 .49239 .30373 Mtetra
.567 .159 .23 r
.49239 .30373 .49874 .29077 .50978 .29306 .50351 .30865 Mtetra
.516 .129 .246 r
.50351 .30865 .50978 .29306 .52092 .29441 .51474 .31113 Mtetra
.492 .114 .25 r
.51474 .31113 .52092 .29441 .53214 .2953 .52607 .31243 Mtetra
.474 .1 .248 r
.52607 .31243 .53214 .2953 .54344 .29561 .53748 .31288 Mtetra
.46 .087 .243 r
.53748 .31288 .54344 .29561 .5548 .29498 .54896 .31269 Mtetra
.454 .084 .246 r
.54896 .31269 .5548 .29498 .56623 .29372 .56052 .31215 Mtetra
.46 .093 .256 r
.56052 .31215 .56623 .29372 .57773 .29256 .57215 .31172 Mtetra
.461 .099 .264 r
.57215 .31172 .57773 .29256 .5893 .29147 .58385 .31123 Mtetra
.455 .097 .267 r
.58385 .31123 .5893 .29147 .60093 .29027 .59562 .31032 Mtetra
.443 .088 .266 r
.59562 .31032 .60093 .29027 .61263 .28891 .60745 .3088 Mtetra
.425 .071 .258 r
.60745 .3088 .61263 .28891 .62439 .28725 .61932 .30641 Mtetra
.401 .045 .242 r
.61932 .30641 .62439 .28725 .63621 .28532 .63123 .30314 Mtetra
.368 .008 .215 r
.63123 .30314 .63621 .28532 .64808 .28317 .64315 .29892 Mtetra
.324 0 .169 r
.64315 .29892 .64808 .28317 .66001 .28079 .6551 .2939 Mtetra
.257 0 .093 r
.6551 .2939 .66001 .28079 .672 .27815 .66705 .28817 Mtetra
.157 0 0 r
.66705 .28817 .672 .27815 .68403 .2753 .67903 .28205 Mtetra
.006 0 0 r
.67903 .28205 .68403 .2753 .69612 .27232 .69104 .2759 Mtetra
0 0 0 r
.69104 .2759 .69612 .27232 .70826 .26914 .70309 .2698 Mtetra
.48 .896 .817 r
.70309 .2698 .70826 .26914 .72044 .26569 .71519 .2639 Mtetra
.634 .944 .953 r
.71519 .2639 .72044 .26569 .73266 .26189 .72734 .25811 Mtetra
.691 .905 .972 r
.72734 .25811 .73266 .26189 .7449 .25764 .73953 .25237 Mtetra
.704 .856 .955 r
.73953 .25237 .7449 .25764 .75717 .25305 .75177 .24665 Mtetra
.706 .818 .935 r
.75177 .24665 .75717 .25305 .76947 .24818 .76405 .24094 Mtetra
.705 .791 .918 r
.76405 .24094 .76947 .24818 .7818 .24311 .77637 .23521 Mtetra
.574 .728 .947 r
.11732 .45366 .12449 .45992 .13414 .45791 .12696 .4519 Mtetra
.558 .732 .956 r
.12696 .4519 .13414 .45791 .14384 .4559 .13662 .45035 Mtetra
.53 .74 .971 r
.13662 .45035 .14384 .4559 .15358 .45389 .14629 .44908 Mtetra
.481 .75 .989 r
.14629 .44908 .15358 .45389 .16336 .45192 .15597 .44817 Mtetra
.385 .749 .992 r
.15597 .44817 .16336 .45192 .17318 .45001 .16565 .44774 Mtetra
.229 .712 .932 r
.16565 .44774 .17318 .45001 .18304 .44821 .17535 .44767 Mtetra
.009 .583 .744 r
.17535 .44767 .18304 .44821 .19292 .44662 .18507 .44796 Mtetra
.154 0 0 r
.18507 .44796 .19292 .44662 .20285 .44507 .19485 .44824 Mtetra
.237 0 0 r
.19485 .44824 .20285 .44507 .21282 .44352 .20472 .44823 Mtetra
.247 0 0 r
.20472 .44823 .21282 .44352 .22289 .44159 .21472 .44755 Mtetra
.209 0 0 r
.21472 .44755 .22289 .44159 .23306 .43899 .22487 .4458 Mtetra
.169 0 0 r
.22487 .4458 .23306 .43899 .24334 .43561 .23515 .44311 Mtetra
.122 0 0 r
.23515 .44311 .24334 .43561 .25374 .43132 .24556 .43946 Mtetra
.096 0 0 r
.24556 .43946 .25374 .43132 .26424 .42616 .25608 .43508 Mtetra
.09 0 0 r
.25608 .43508 .26424 .42616 .27484 .42016 .26667 .43012 Mtetra
.107 0 0 r
.26667 .43012 .27484 .42016 .28551 .41355 .27733 .42472 Mtetra
.139 0 0 r
.27733 .42472 .28551 .41355 .29623 .40652 .28804 .41905 Mtetra
.192 0 .022 r
.28804 .41905 .29623 .40652 .30698 .39943 .29877 .41349 Mtetra
.251 0 .088 r
.29877 .41349 .30698 .39943 .31773 .39244 .3095 .40831 Mtetra
.298 0 .145 r
.3095 .40831 .31773 .39244 .32853 .38509 .32025 .40342 Mtetra
.337 0 .2 r
.32025 .40342 .32853 .38509 .33938 .37709 .33102 .39868 Mtetra
.35 .011 .241 r
.33102 .39868 .33938 .37709 .3503 .36824 .34187 .39325 Mtetra
.343 .02 .266 r
.34187 .39325 .3503 .36824 .36128 .35822 .35282 .38635 Mtetra
.287 0 .265 r
.35282 .38635 .36128 .35822 .37238 .34575 .36398 .37593 Mtetra
.226 0 .253 r
.36398 .37593 .37238 .34575 .38355 .33123 .3753 .36197 Mtetra
.246 0 .265 r
.3753 .36197 .38355 .33123 .39462 .31854 .38658 .34851 Mtetra
.295 0 .281 r
.38658 .34851 .39462 .31854 .40554 .3093 .39773 .33745 Mtetra
.366 .055 .299 r
.39773 .33745 .40554 .3093 .41633 .30414 .40873 .33036 Mtetra
.429 .104 .312 r
.40873 .33036 .41633 .30414 .42704 .30219 .41963 .327 Mtetra
.413 .085 .297 r
.41963 .327 .42704 .30219 .43787 .29835 .4306 .32316 Mtetra
.404 .076 .293 r
.4306 .32316 .43787 .29835 .44878 .29262 .44161 .31883 Mtetra
.477 .147 .328 r
.44161 .31883 .44878 .29262 .45966 .29011 .45259 .31825 Mtetra
.535 .207 .358 r
.45259 .31825 .45966 .29011 .47052 .2917 .46355 .32167 Mtetra
.562 .236 .374 r
.46355 .32167 .47052 .2917 .48141 .29678 .47457 .32754 Mtetra
.567 .242 .377 r
.47457 .32754 .48141 .29678 .49239 .30373 .4857 .33393 Mtetra
.527 .204 .363 r
.4857 .33393 .49239 .30373 .50351 .30865 .49698 .3368 Mtetra
.478 .153 .337 r
.49698 .3368 .50351 .30865 .51474 .31113 .50838 .33611 Mtetra
.447 .114 .307 r
.50838 .33611 .51474 .31113 .52607 .31243 .51985 .33395 Mtetra
.419 .073 .269 r
.51985 .33395 .52607 .31243 .53748 .31288 .53138 .33108 Mtetra
.403 .038 .228 r
.53138 .33108 .53748 .31288 .54896 .31269 .54297 .32837 Mtetra
.391 .008 .187 r
.54297 .32837 .54896 .31269 .56052 .31215 .55461 .32596 Mtetra
.384 0 .152 r
.55461 .32596 .56052 .31215 .57215 .31172 .56633 .32394 Mtetra
.37 0 .112 r
.56633 .32394 .57215 .31172 .58385 .31123 .57811 .32205 Mtetra
.339 0 .062 r
.57811 .32205 .58385 .31123 .59562 .31032 .58995 .31987 Mtetra
.295 0 .003 r
.58995 .31987 .59562 .31032 .60745 .3088 .60185 .31725 Mtetra
.237 0 0 r
.60185 .31725 .60745 .3088 .61932 .30641 .61379 .31403 Mtetra
.167 0 0 r
.61379 .31403 .61932 .30641 .63123 .30314 .62576 .31006 Mtetra
.076 0 0 r
.62576 .31006 .63123 .30314 .64315 .29892 .63775 .3051 Mtetra
0 0 0 r
.63775 .3051 .64315 .29892 .6551 .2939 .64975 .29916 Mtetra
.64975 .29916 .6551 .2939 .66705 .28817 .66174 .29211 Mtetra
.66174 .29211 .66705 .28817 .67903 .28205 .67372 .28433 Mtetra
.509 .89 .706 r
.67372 .28433 .67903 .28205 .69104 .2759 .68571 .27625 Mtetra
.656 .971 .847 r
.68571 .27625 .69104 .2759 .70309 .2698 .69772 .26814 Mtetra
.731 .974 .927 r
.69772 .26814 .70309 .2698 .71519 .2639 .70978 .26039 Mtetra
.754 .93 .946 r
.70978 .26039 .71519 .2639 .72734 .25811 .72188 .253 Mtetra
.746 .874 .939 r
.72188 .253 .72734 .25811 .73953 .25237 .73405 .2461 Mtetra
.733 .832 .926 r
.73405 .2461 .73953 .25237 .75177 .24665 .74628 .23956 Mtetra
.721 .802 .914 r
.74628 .23956 .75177 .24665 .76405 .24094 .75856 .2333 Mtetra
.712 .783 .907 r
.75856 .2333 .76405 .24094 .77637 .23521 .7709 .22725 Mtetra
.579 .73 .946 r
.1101 .44736 .11732 .45366 .12696 .4519 .11977 .4455 Mtetra
.555 .718 .949 r
.11977 .4455 .12696 .4519 .13662 .45035 .12942 .44405 Mtetra
.52 .71 .958 r
.12942 .44405 .13662 .45035 .14629 .44908 .13907 .44309 Mtetra
.47 .702 .969 r
.13907 .44309 .14629 .44908 .15597 .44817 .14871 .4427 Mtetra
.384 .684 .978 r
.14871 .4427 .15597 .44817 .16565 .44774 .15832 .44306 Mtetra
.296 .671 .974 r
.15832 .44306 .16565 .44774 .17535 .44767 .16794 .44382 Mtetra
.203 .649 .947 r
.16794 .44382 .17535 .44767 .18507 .44796 .1776 .44486 Mtetra
.178 .657 .929 r
.1776 .44486 .18507 .44796 .19485 .44824 .18735 .44563 Mtetra
.236 .708 .941 r
.18735 .44563 .19485 .44824 .20472 .44823 .19724 .44568 Mtetra
.352 .775 .975 r
.19724 .44568 .20472 .44823 .21472 .44755 .20728 .4448 Mtetra
.498 .837 .997 r
.20728 .4448 .21472 .44755 .22487 .4458 .2175 .44267 Mtetra
.576 .853 .996 r
.2175 .44267 .22487 .4458 .23515 .44311 .22783 .43977 Mtetra
.614 .858 .989 r
.22783 .43977 .23515 .44311 .24556 .43946 .23825 .43638 Mtetra
.619 .869 .989 r
.23825 .43638 .24556 .43946 .25608 .43508 .24873 .4328 Mtetra
.586 .886 .991 r
.24873 .4328 .25608 .43508 .26667 .43012 .25924 .42932 Mtetra
.515 .897 .957 r
.25924 .42932 .26667 .43012 .27733 .42472 .2698 .42579 Mtetra
.367 .836 .829 r
.2698 .42579 .27733 .42472 .28804 .41905 .2804 .42224 Mtetra
0 0 0 r
.2804 .42224 .28804 .41905 .29877 .41349 .29102 .41911 Mtetra
.141 0 0 r
.29102 .41911 .29877 .41349 .3095 .40831 .30163 .41672 Mtetra
.326 0 0 r
.30163 .41672 .3095 .40831 .32025 .40342 .31221 .41551 Mtetra
.432 .014 .143 r
.31221 .41551 .32025 .40342 .33102 .39868 .32277 .41551 Mtetra
.456 .078 .233 r
.32277 .41551 .33102 .39868 .34187 .39325 .33341 .41537 Mtetra
.446 .1 .283 r
.33341 .41537 .34187 .39325 .35282 .38635 .34419 .41392 Mtetra
.388 .068 .297 r
.34419 .41392 .35282 .38635 .36398 .37593 .35525 .40842 Mtetra
.329 .032 .3 r
.35525 .40842 .36398 .37593 .3753 .36197 .36656 .39837 Mtetra
.337 .049 .321 r
.36656 .39837 .3753 .36197 .38658 .34851 .37791 .38735 Mtetra
.365 .079 .34 r
.37791 .38735 .38658 .34851 .39773 .33745 .38922 .37722 Mtetra
.412 .122 .36 r
.38922 .37722 .39773 .33745 .40873 .33036 .40042 .37012 Mtetra
.454 .158 .373 r
.40042 .37012 .40873 .33036 .41963 .327 .41153 .36626 Mtetra
.453 .157 .372 r
.41153 .36626 .41963 .327 .4306 .32316 .42267 .36242 Mtetra
.454 .158 .372 r
.42267 .36242 .4306 .32316 .44161 .31883 .43387 .35862 Mtetra
.491 .191 .384 r
.43387 .35862 .44161 .31883 .45259 .31825 .44503 .35808 Mtetra
.522 .218 .393 r
.44503 .35808 .45259 .31825 .46355 .32167 .45619 .36058 Mtetra
.531 .224 .392 r
.45619 .36058 .46355 .32167 .47457 .32754 .46743 .36401 Mtetra
.521 .211 .381 r
.46743 .36401 .47457 .32754 .4857 .33393 .47878 .36649 Mtetra
.463 .151 .349 r
.47878 .36649 .4857 .33393 .49698 .3368 .49027 .36439 Mtetra
.381 .064 .297 r
.49027 .36439 .49698 .3368 .50838 .33611 .50186 .35818 Mtetra
.31 0 .229 r
.50186 .35818 .50838 .33611 .51985 .33395 .51348 .35063 Mtetra
.23 0 .131 r
.51348 .35063 .51985 .33395 .53138 .33108 .52513 .34293 Mtetra
.165 0 .004 r
.52513 .34293 .53138 .33108 .54297 .32837 .5368 .33645 Mtetra
.09 0 0 r
.5368 .33645 .54297 .32837 .55461 .32596 .54852 .33116 Mtetra
0 0 0 r
.54852 .33116 .55461 .32596 .56633 .32394 .56028 .32662 Mtetra
.56028 .32662 .56633 .32394 .57811 .32205 .57209 .32251 Mtetra
.383 .846 .834 r
.57209 .32251 .57811 .32205 .58995 .31987 .58396 .31837 Mtetra
.531 .904 .958 r
.58396 .31837 .58995 .31987 .60185 .31725 .59587 .31419 Mtetra
.595 .889 .99 r
.59587 .31419 .60185 .31725 .61379 .31403 .60784 .31009 Mtetra
.629 .872 .987 r
.60784 .31009 .61379 .31403 .62576 .31006 .61985 .30581 Mtetra
.66 .872 .979 r
.61985 .30581 .62576 .31006 .63775 .3051 .6319 .301 Mtetra
.693 .889 .969 r
.6319 .301 .63775 .3051 .64975 .29916 .64397 .29541 Mtetra
.742 .914 .951 r
.64397 .29541 .64975 .29916 .66174 .29211 .65602 .2885 Mtetra
.774 .925 .935 r
.65602 .2885 .66174 .29211 .67372 .28433 .66806 .28062 Mtetra
.798 .926 .92 r
.66806 .28062 .67372 .28433 .68571 .27625 .68008 .27197 Mtetra
.806 .91 .911 r
.68008 .27197 .68571 .27625 .69772 .26814 .69211 .26303 Mtetra
.798 .883 .907 r
.69211 .26303 .69772 .26814 .70978 .26039 .70416 .25435 Mtetra
.783 .851 .902 r
.70416 .25435 .70978 .26039 .72188 .253 .71626 .24608 Mtetra
.758 .818 .9 r
.71626 .24608 .72188 .253 .73405 .2461 .72844 .23857 Mtetra
.738 .795 .898 r
.72844 .23857 .73405 .2461 .74628 .23956 .74068 .23165 Mtetra
.722 .779 .898 r
.74068 .23165 .74628 .23956 .75856 .2333 .753 .22522 Mtetra
.708 .77 .9 r
.753 .22522 .75856 .2333 .7709 .22725 .76539 .21923 Mtetra
.606 .738 .938 r
.10283 .44102 .1101 .44736 .11977 .4455 .11257 .43864 Mtetra
.582 .714 .933 r
.11257 .43864 .11977 .4455 .12942 .44405 .1223 .43676 Mtetra
.555 .691 .93 r
.1223 .43676 .12942 .44405 .13907 .44309 .132 .43542 Mtetra
.526 .668 .927 r
.132 .43542 .13907 .44309 .14871 .4427 .14169 .43464 Mtetra
.487 .64 .923 r
.14169 .43464 .14871 .4427 .15832 .44306 .15136 .43456 Mtetra
.478 .623 .914 r
.15136 .43456 .15832 .44306 .16794 .44382 .16105 .43473 Mtetra
.488 .611 .9 r
.16105 .43473 .16794 .44382 .1776 .44486 .17081 .43487 Mtetra
.522 .603 .876 r
.17081 .43487 .1776 .44486 .18735 .44563 .18068 .43452 Mtetra
.567 .599 .845 r
.18068 .43452 .18735 .44563 .19724 .44568 .1907 .43322 Mtetra
.594 .587 .815 r
.1907 .43322 .19724 .44568 .20728 .4448 .20087 .43108 Mtetra
.616 .579 .789 r
.20087 .43108 .20728 .4448 .2175 .44267 .21117 .42804 Mtetra
.619 .568 .776 r
.21117 .42804 .2175 .44267 .22783 .43977 .22153 .42474 Mtetra
.612 .56 .772 r
.22153 .42474 .22783 .43977 .23825 .43638 .23192 .42168 Mtetra
.606 .562 .778 r
.23192 .42168 .23825 .43638 .24873 .4328 .24233 .41887 Mtetra
.598 .568 .792 r
.24233 .41887 .24873 .4328 .25924 .42932 .25275 .41648 Mtetra
.601 .588 .81 r
.25275 .41648 .25924 .42932 .2698 .42579 .26322 .41406 Mtetra
.609 .612 .829 r
.26322 .41406 .2698 .42579 .2804 .42224 .27376 .41142 Mtetra
.594 .624 .851 r
.27376 .41142 .2804 .42224 .29102 .41911 .28431 .40928 Mtetra
.555 .63 .881 r
.28431 .40928 .29102 .41911 .30163 .41672 .29484 .40812 Mtetra
.436 .608 .92 r
.29484 .40812 .30163 .41672 .31221 .41551 .3053 .40893 Mtetra
.159 .524 .919 r
.3053 .40893 .31221 .41551 .32277 .41551 .31568 .41204 Mtetra
0 .389 .744 r
.31568 .41204 .32277 .41551 .33341 .41537 .3261 .41585 Mtetra
.373 0 0 r
.3261 .41585 .33341 .41537 .34419 .41392 .33666 .41902 Mtetra
.267 0 0 r
.33666 .41902 .34419 .41392 .35525 .40842 .34751 .41848 Mtetra
.134 0 0 r
.34751 .41848 .35525 .40842 .36656 .39837 .35867 .41327 Mtetra
.183 0 .062 r
.35867 .41327 .36656 .39837 .37791 .38735 .36996 .40615 Mtetra
.248 0 .156 r
.36996 .40615 .37791 .38735 .38922 .37722 .38128 .39863 Mtetra
.335 0 .225 r
.38128 .39863 .38922 .37722 .40042 .37012 .39256 .39282 Mtetra
.399 .056 .264 r
.39256 .39282 .40042 .37012 .41153 .36626 .40379 .38914 Mtetra
.396 .055 .264 r
.40379 .38914 .41153 .36626 .42267 .36242 .41507 .3853 Mtetra
.393 .052 .263 r
.41507 .3853 .42267 .36242 .43387 .35862 .4264 .38131 Mtetra
.438 .092 .279 r
.4264 .38131 .43387 .35862 .44503 .35808 .43772 .37946 Mtetra
.468 .113 .279 r
.43772 .37946 .44503 .35808 .45619 .36058 .44906 .37934 Mtetra
.451 .082 .245 r
.44906 .37934 .45619 .36058 .46743 .36401 .46049 .37882 Mtetra
.373 0 .155 r
.46049 .37882 .46743 .36401 .47878 .36649 .47201 .37639 Mtetra
.036 0 0 r
.47201 .37639 .47878 .36649 .49027 .36439 .48366 .36924 Mtetra
.588 .897 .622 r
.48366 .36924 .49027 .36439 .50186 .35818 .49537 .35831 Mtetra
.85 .992 .844 r
.49537 .35831 .50186 .35818 .51348 .35063 .50709 .34672 Mtetra
.853 .896 .867 r
.50709 .34672 .51348 .35063 .52513 .34293 .51879 .33579 Mtetra
.783 .798 .865 r
.51879 .33579 .52513 .34293 .5368 .33645 .5305 .32719 Mtetra
.721 .727 .855 r
.5305 .32719 .5368 .33645 .54852 .33116 .54223 .32059 Mtetra
.688 .686 .843 r
.54223 .32059 .54852 .33116 .56028 .32662 .55401 .31497 Mtetra
.669 .657 .829 r
.55401 .31497 .56028 .32662 .57209 .32251 .56583 .30986 Mtetra
.668 .639 .812 r
.56583 .30986 .57209 .32251 .58396 .31837 .57769 .30452 Mtetra
.662 .617 .794 r
.57769 .30452 .58396 .31837 .59587 .31419 .58959 .29914 Mtetra
.646 .594 .781 r
.58959 .29914 .59587 .31419 .60784 .31009 .60154 .29418 Mtetra
.637 .578 .772 r
.60154 .29418 .60784 .31009 .61985 .30581 .61355 .28948 Mtetra
.63 .57 .768 r
.61355 .28948 .61985 .30581 .6319 .301 .62561 .28501 Mtetra
.637 .578 .772 r
.62561 .28501 .6319 .301 .64397 .29541 .63771 .28029 Mtetra
.659 .601 .779 r
.63771 .28029 .64397 .29541 .65602 .2885 .64982 .27461 Mtetra
.684 .631 .79 r
.64982 .27461 .65602 .2885 .66806 .28062 .66194 .26806 Mtetra
.713 .666 .803 r
.66194 .26806 .66806 .28062 .68008 .27197 .67404 .26051 Mtetra
.732 .695 .815 r
.67404 .26051 .68008 .27197 .69211 .26303 .68615 .25244 Mtetra
.741 .716 .828 r
.68615 .25244 .69211 .26303 .70416 .25435 .69827 .24432 Mtetra
.741 .729 .841 r
.69827 .24432 .70416 .25435 .71626 .24608 .71044 .23644 Mtetra
.728 .734 .856 r
.71044 .23644 .71626 .24608 .72844 .23857 .72267 .22928 Mtetra
.717 .739 .869 r
.72267 .22928 .72844 .23857 .74068 .23165 .73498 .2227 Mtetra
.705 .745 .883 r
.73498 .2227 .74068 .23165 .753 .22522 .74736 .21665 Mtetra
.691 .751 .897 r
.74736 .21665 .753 .22522 .76539 .21923 .75983 .21113 Mtetra
.643 .748 .925 r
.09551 .43462 .10283 .44102 .11257 .43864 .10537 .43144 Mtetra
.622 .718 .915 r
.10537 .43144 .11257 .43864 .1223 .43676 .11521 .42875 Mtetra
.603 .688 .902 r
.11521 .42875 .1223 .43676 .132 .43542 .12503 .4265 Mtetra
.587 .657 .886 r
.12503 .4265 .132 .43542 .14169 .43464 .13486 .42464 Mtetra
.569 .623 .866 r
.13486 .42464 .14169 .43464 .15136 .43456 .14468 .42324 Mtetra
.571 .596 .839 r
.14468 .42324 .15136 .43456 .16105 .43473 .15455 .42183 Mtetra
.583 .573 .808 r
.15455 .42183 .16105 .43473 .17081 .43487 .16451 .42002 Mtetra
.596 .552 .775 r
.16451 .42002 .17081 .43487 .18068 .43452 .17459 .4176 Mtetra
.612 .537 .746 r
.17459 .4176 .18068 .43452 .1907 .43322 .18482 .41424 Mtetra
.614 .52 .725 r
.18482 .41424 .1907 .43322 .20087 .43108 .19514 .41042 Mtetra
.612 .507 .71 r
.19514 .41042 .20087 .43108 .21117 .42804 .20551 .40639 Mtetra
.601 .494 .704 r
.20551 .40639 .21117 .42804 .22153 .42474 .21588 .4028 Mtetra
.582 .48 .703 r
.21588 .4028 .22153 .42474 .23192 .42168 .22619 .40022 Mtetra
.572 .477 .708 r
.22619 .40022 .23192 .42168 .24233 .41887 .2365 .39821 Mtetra
.565 .479 .716 r
.2365 .39821 .24233 .41887 .25275 .41648 .24683 .39663 Mtetra
.573 .491 .724 r
.24683 .39663 .25275 .41648 .26322 .41406 .25724 .39471 Mtetra
.589 .505 .727 r
.25724 .39471 .26322 .41406 .27376 .41142 .26776 .39206 Mtetra
.583 .501 .728 r
.26776 .39206 .27376 .41142 .28431 .40928 .2783 .38972 Mtetra
.561 .487 .729 r
.2783 .38972 .28431 .40928 .29484 .40812 .28883 .38836 Mtetra
.501 .449 .731 r
.28883 .38836 .29484 .40812 .3053 .40893 .29923 .38949 Mtetra
.407 .393 .732 r
.29923 .38949 .3053 .40893 .31568 .41204 .3095 .39374 Mtetra
.339 .363 .74 r
.3095 .39374 .31568 .41204 .3261 .41585 .31978 .39952 Mtetra
.297 .364 .763 r
.31978 .39952 .3261 .41585 .33666 .41902 .33014 .40554 Mtetra
.385 .466 .821 r
.33014 .40554 .33666 .41902 .34751 .41848 .34078 .40874 Mtetra
.536 .631 .892 r
.34078 .40874 .34751 .41848 .35867 .41327 .35172 .40788 Mtetra
.611 .798 .971 r
.35172 .40788 .35867 .41327 .36996 .40615 .36285 .40475 Mtetra
.587 .919 .97 r
.36285 .40475 .36996 .40615 .38128 .39863 .37408 .40032 Mtetra
.318 .802 .76 r
.37408 .40032 .38128 .39863 .39256 .39282 .38534 .39631 Mtetra
0 0 0 r
.38534 .39631 .39256 .39282 .40379 .38914 .39661 .39313 Mtetra
.39661 .39313 .40379 .38914 .41507 .3853 .40796 .38928 Mtetra
.40796 .38928 .41507 .3853 .4264 .38131 .41938 .38474 Mtetra
.41938 .38474 .4264 .38131 .43772 .37946 .43082 .38104 Mtetra
.23 .743 .723 r
.43082 .38104 .43772 .37946 .44906 .37934 .4423 .37777 Mtetra
.588 .92 .969 r
.4423 .37777 .44906 .37934 .46049 .37882 .45385 .37318 Mtetra
.752 .834 .915 r
.45385 .37318 .46049 .37882 .47201 .37639 .4655 .36629 Mtetra
.791 .728 .794 r
.4655 .36629 .47201 .37639 .48366 .36924 .47723 .3553 Mtetra
.787 .67 .734 r
.47723 .3553 .48366 .36924 .49537 .35831 .489 .34141 Mtetra
.76 .628 .714 r
.489 .34141 .49537 .35831 .50709 .34672 .50074 .32773 Mtetra
.729 .595 .707 r
.50074 .32773 .50709 .34672 .51879 .33579 .51245 .31558 Mtetra
.683 .561 .71 r
.51245 .31558 .51879 .33579 .5305 .32719 .52416 .30658 Mtetra
.647 .537 .716 r
.52416 .30658 .5305 .32719 .54223 .32059 .53588 .30009 Mtetra
.632 .529 .72 r
.53588 .30009 .54223 .32059 .55401 .31497 .54764 .2946 Mtetra
.627 .528 .722 r
.54764 .2946 .55401 .31497 .56583 .30986 .55945 .28942 Mtetra
.639 .534 .72 r
.55945 .28942 .56583 .30986 .57769 .30452 .57129 .28347 Mtetra
.641 .531 .714 r
.57129 .28347 .57769 .30452 .58959 .29914 .58315 .27718 Mtetra
.631 .519 .708 r
.58315 .27718 .58959 .29914 .60154 .29418 .59507 .27132 Mtetra
.619 .506 .703 r
.59507 .27132 .60154 .29418 .61355 .28948 .60704 .26604 Mtetra
.602 .492 .702 r
.60704 .26604 .61355 .28948 .62561 .28501 .61908 .26178 Mtetra
.595 .49 .704 r
.61908 .26178 .62561 .28501 .63771 .28029 .63119 .25798 Mtetra
.601 .5 .711 r
.63119 .25798 .63771 .28029 .64982 .27461 .64335 .25397 Mtetra
.613 .52 .725 r
.64335 .25397 .64982 .27461 .66194 .26806 .65554 .24948 Mtetra
.638 .552 .741 r
.65554 .24948 .66194 .26806 .67404 .26051 .66774 .24399 Mtetra
.659 .586 .762 r
.66774 .24399 .67404 .26051 .68615 .25244 .67996 .23787 Mtetra
.678 .621 .784 r
.67996 .23787 .68615 .25244 .69827 .24432 .69219 .23134 Mtetra
.69 .651 .806 r
.69219 .23134 .69827 .24432 .71044 .23644 .70445 .22477 Mtetra
.688 .675 .831 r
.70445 .22477 .71044 .23644 .72267 .22928 .71678 .21866 Mtetra
.685 .696 .854 r
.71678 .21866 .72267 .22928 .73498 .2227 .72918 .21296 Mtetra
.678 .715 .877 r
.72918 .21296 .73498 .2227 .74736 .21665 .74166 .20772 Mtetra
.665 .731 .899 r
.74166 .20772 .74736 .21665 .75983 .21113 .75422 .20298 Mtetra
.683 .757 .908 r
.08813 .42819 .09551 .43462 .10537 .43144 .09814 .42398 Mtetra
.666 .724 .892 r
.09814 .42398 .10537 .43144 .11521 .42875 .10815 .42013 Mtetra
.653 .689 .871 r
.10815 .42013 .11521 .42875 .12503 .4265 .11815 .41653 Mtetra
.643 .655 .847 r
.11815 .41653 .12503 .4265 .13486 .42464 .12817 .41308 Mtetra
.633 .619 .819 r
.12817 .41308 .13486 .42464 .14468 .42324 .13822 .40973 Mtetra
.631 .587 .787 r
.13822 .40973 .14468 .42324 .15455 .42183 .14834 .40613 Mtetra
.634 .562 .756 r
.14834 .40613 .15455 .42183 .16451 .42002 .15857 .40193 Mtetra
.633 .538 .729 r
.15857 .40193 .16451 .42002 .17459 .4176 .16888 .39726 Mtetra
.633 .521 .709 r
.16888 .39726 .17459 .4176 .18482 .41424 .17929 .392 Mtetra
.623 .503 .696 r
.17929 .392 .18482 .41424 .19514 .41042 .18971 .38693 Mtetra
.608 .486 .689 r
.18971 .38693 .19514 .41042 .20551 .40639 .20008 .38258 Mtetra
.588 .472 .688 r
.20008 .38258 .20551 .40639 .21588 .4028 .21038 .37938 Mtetra
.56 .456 .693 r
.21038 .37938 .21588 .4028 .22619 .40022 .22057 .37783 Mtetra
.547 .455 .702 r
.22057 .37783 .22619 .40022 .2365 .39821 .23074 .37696 Mtetra
.545 .462 .712 r
.23074 .37696 .2365 .39821 .24683 .39663 .24097 .37621 Mtetra
.565 .481 .719 r
.24097 .37621 .24683 .39663 .25724 .39471 .25132 .3746 Mtetra
.596 .503 .719 r
.25132 .3746 .25724 .39471 .26776 .39206 .26186 .37146 Mtetra
.599 .502 .715 r
.26186 .37146 .26776 .39206 .2783 .38972 .27247 .36803 Mtetra
.587 .487 .707 r
.27247 .36803 .2783 .38972 .28883 .38836 .28308 .36512 Mtetra
.541 .447 .698 r
.28308 .36512 .28883 .38836 .29923 .38949 .29357 .36454 Mtetra
.474 .393 .685 r
.29357 .36454 .29923 .38949 .3095 .39374 .3039 .3672 Mtetra
.435 .359 .673 r
.3039 .3672 .3095 .39374 .31978 .39952 .31419 .37181 Mtetra
.419 .343 .664 r
.31419 .37181 .31978 .39952 .33014 .40554 .32451 .37737 Mtetra
.459 .369 .666 r
.32451 .37737 .33014 .40554 .34078 .40874 .33505 .38114 Mtetra
.515 .41 .673 r
.33505 .38114 .34078 .40874 .35172 .40788 .34586 .38193 Mtetra
.55 .441 .683 r
.34586 .38193 .35172 .40788 .36285 .40475 .35684 .38073 Mtetra
.577 .47 .695 r
.35684 .38073 .36285 .40475 .37408 .40032 .36796 .37804 Mtetra
.585 .486 .708 r
.36796 .37804 .37408 .40032 .38534 .39631 .37915 .37508 Mtetra
.587 .495 .717 r
.37915 .37508 .38534 .39631 .39661 .39313 .39039 .37214 Mtetra
.605 .508 .718 r
.39039 .37214 .39661 .39313 .40796 .38928 .40172 .36824 Mtetra
.62 .517 .715 r
.40172 .36824 .40796 .38928 .41938 .38474 .41313 .36339 Mtetra
.619 .514 .713 r
.41313 .36339 .41938 .38474 .43082 .38104 .42459 .35854 Mtetra
.619 .507 .704 r
.42459 .35854 .43082 .38104 .4423 .37777 .43609 .35342 Mtetra
.634 .505 .689 r
.43609 .35342 .4423 .37777 .45385 .37318 .44767 .3468 Mtetra
.65 .506 .674 r
.44767 .3468 .45385 .37318 .4655 .36629 .45932 .33816 Mtetra
.675 .514 .66 r
.45932 .33816 .4655 .36629 .47723 .3553 .47103 .32648 Mtetra
.688 .52 .654 r
.47103 .32648 .47723 .3553 .489 .34141 .48277 .31298 Mtetra
.682 .517 .657 r
.48277 .31298 .489 .34141 .50074 .32773 .49447 .3004 Mtetra
.667 .512 .665 r
.49447 .3004 .50074 .32773 .51245 .31558 .50615 .28976 Mtetra
.637 .5 .679 r
.50615 .28976 .51245 .31558 .52416 .30658 .51782 .28241 Mtetra
.611 .492 .693 r
.51782 .28241 .52416 .30658 .53588 .30009 .52952 .27742 Mtetra
.607 .499 .705 r
.52952 .27742 .53588 .30009 .54764 .2946 .54127 .27295 Mtetra
.615 .511 .713 r
.54127 .27295 .54764 .2946 .55945 .28942 .55306 .26819 Mtetra
.641 .53 .712 r
.55306 .26819 .55945 .28942 .57129 .28347 .56488 .26185 Mtetra
.652 .534 .707 r
.56488 .26185 .57129 .28347 .58315 .27718 .57672 .25462 Mtetra
.646 .524 .701 r
.57672 .25462 .58315 .27718 .59507 .27132 .58859 .2475 Mtetra
.631 .508 .694 r
.58859 .2475 .59507 .27132 .60704 .26604 .6005 .24108 Mtetra
.604 .484 .69 r
.6005 .24108 .60704 .26604 .61908 .26178 .6125 .23633 Mtetra
.585 .47 .689 r
.6125 .23633 .61908 .26178 .63119 .25798 .62458 .23278 Mtetra
.575 .465 .692 r
.62458 .23278 .63119 .25798 .64335 .25397 .63675 .22996 Mtetra
.574 .472 .701 r
.63675 .22996 .64335 .25397 .65554 .24948 .64899 .22734 Mtetra
.587 .493 .715 r
.64899 .22734 .65554 .24948 .66774 .24399 .66128 .22412 Mtetra
.601 .52 .735 r
.66128 .22412 .66774 .24399 .67996 .23787 .6736 .2204 Mtetra
.621 .555 .759 r
.6736 .2204 .67996 .23787 .69219 .23134 .68595 .21606 Mtetra
.635 .59 .786 r
.68595 .21606 .69219 .23134 .70445 .22477 .69834 .21145 Mtetra
.641 .623 .816 r
.69834 .21145 .70445 .22477 .71678 .21866 .71079 .20694 Mtetra
.644 .655 .846 r
.71079 .20694 .71678 .21866 .72918 .21296 .7233 .20258 Mtetra
.641 .684 .875 r
.7233 .20258 .72918 .21296 .74166 .20772 .73589 .19848 Mtetra
.63 .71 .904 r
.73589 .19848 .74166 .20772 .75422 .20298 .74857 .19475 Mtetra
.714 .763 .891 r
.0807 .4217 .08813 .42819 .09814 .42398 .09087 .4165 Mtetra
.703 .734 .875 r
.09087 .4165 .09814 .42398 .10815 .42013 .10104 .41147 Mtetra
.694 .702 .853 r
.10104 .41147 .10815 .42013 .11815 .41653 .11124 .40647 Mtetra
.687 .67 .828 r
.11124 .40647 .11815 .41653 .12817 .41308 .12148 .40135 Mtetra
.681 .638 .799 r
.12148 .40135 .12817 .41308 .13822 .40973 .13178 .39597 Mtetra
.676 .606 .77 r
.13178 .39597 .13822 .40973 .14834 .40613 .14216 .39017 Mtetra
.674 .581 .742 r
.14216 .39017 .14834 .40613 .15857 .40193 .15264 .38369 Mtetra
.665 .555 .721 r
.15264 .38369 .15857 .40193 .16888 .39726 .16317 .37696 Mtetra
.656 .535 .705 r
.16317 .37696 .16888 .39726 .17929 .392 .17373 .37018 Mtetra
.637 .514 .696 r
.17373 .37018 .17929 .392 .18971 .38693 .18422 .36423 Mtetra
.609 .491 .694 r
.18422 .36423 .18971 .38693 .20008 .38258 .19457 .35986 Mtetra
.58 .473 .696 r
.19457 .35986 .20008 .38258 .21038 .37938 .20479 .35719 Mtetra
.541 .452 .703 r
.20479 .35719 .21038 .37938 .22057 .37783 .21485 .35656 Mtetra
.528 .45 .712 r
.21485 .35656 .22057 .37783 .23074 .37696 .22492 .35653 Mtetra
.535 .462 .72 r
.22492 .35653 .23074 .37696 .24097 .37621 .23508 .35617 Mtetra
.569 .486 .722 r
.23508 .35617 .24097 .37621 .25132 .3746 .24543 .35432 Mtetra
.613 .512 .715 r
.24543 .35432 .25132 .3746 .26186 .37146 .25603 .35014 Mtetra
.626 .512 .705 r
.25603 .35014 .26186 .37146 .27247 .36803 .26676 .34498 Mtetra
.621 .499 .693 r
.26676 .34498 .27247 .36803 .28308 .36512 .27752 .3397 Mtetra
.586 .464 .68 r
.27752 .3397 .28308 .36512 .29357 .36454 .28818 .33628 Mtetra
.535 .417 .665 r
.28818 .33628 .29357 .36454 .3039 .3672 .29867 .33583 Mtetra
.501 .381 .649 r
.29867 .33583 .3039 .3672 .31419 .37181 .30909 .33748 Mtetra
.48 .357 .635 r
.30909 .33748 .31419 .37181 .32451 .37737 .31949 .34058 Mtetra
.494 .36 .628 r
.31949 .34058 .32451 .37737 .33505 .38114 .33002 .34295 Mtetra
.518 .374 .625 r
.33002 .34295 .33505 .38114 .34586 .38193 .34075 .34354 Mtetra
.535 .386 .626 r
.34075 .34354 .34586 .38193 .35684 .38073 .35162 .34277 Mtetra
.549 .398 .628 r
.35162 .34277 .35684 .38073 .36796 .37804 .36263 .34078 Mtetra
.556 .404 .631 r
.36263 .34078 .36796 .37804 .37915 .37508 .37371 .33827 Mtetra
.561 .409 .632 r
.37371 .33827 .37915 .37508 .39039 .37214 .38488 .33534 Mtetra
.572 .417 .633 r
.38488 .33534 .39039 .37214 .40172 .36824 .39613 .33139 Mtetra
.583 .425 .633 r
.39613 .33139 .40172 .36824 .41313 .36339 .40748 .3264 Mtetra
.587 .427 .632 r
.40748 .3264 .41313 .36339 .42459 .35854 .41887 .321 Mtetra
.591 .429 .63 r
.41887 .321 .42459 .35854 .43609 .35342 .43032 .31507 Mtetra
.602 .434 .628 r
.43032 .31507 .43609 .35342 .44767 .3468 .44184 .3079 Mtetra
.613 .441 .625 r
.44184 .3079 .44767 .3468 .45932 .33816 .45341 .29934 Mtetra
.628 .452 .625 r
.45341 .29934 .45932 .33816 .47103 .32648 .46504 .28897 Mtetra
.638 .461 .628 r
.46504 .28897 .47103 .32648 .48277 .31298 .47668 .27784 Mtetra
.632 .462 .636 r
.47668 .27784 .48277 .31298 .49447 .3004 .48829 .26816 Mtetra
.619 .462 .648 r
.48829 .26816 .49447 .3004 .50615 .28976 .4999 .2606 Mtetra
.591 .455 .664 r
.4999 .2606 .50615 .28976 .51782 .28241 .51152 .25603 Mtetra
.57 .454 .681 r
.51152 .25603 .51782 .28241 .52952 .27742 .52318 .25336 Mtetra
.576 .471 .697 r
.52318 .25336 .52952 .27742 .54127 .27295 .5349 .25058 Mtetra
.596 .494 .709 r
.5349 .25058 .54127 .27295 .55306 .26819 .54668 .24679 Mtetra
.637 .526 .711 r
.54668 .24679 .55306 .26819 .56488 .26185 .55849 .24061 Mtetra
.66 .541 .708 r
.55849 .24061 .56488 .26185 .57672 .25462 .57031 .2329 Mtetra
.662 .539 .704 r
.57031 .2329 .57672 .25462 .58859 .2475 .58214 .22484 Mtetra
.649 .525 .699 r
.58214 .22484 .58859 .2475 .6005 .24108 .59401 .21739 Mtetra
.616 .499 .697 r
.59401 .21739 .6005 .24108 .6125 .23633 .60597 .21201 Mtetra
.588 .478 .696 r
.60597 .21201 .6125 .23633 .62458 .23278 .61802 .20838 Mtetra
.562 .462 .698 r
.61802 .20838 .62458 .23278 .63675 .22996 .63018 .20638 Mtetra
.548 .458 .706 r
.63018 .20638 .63675 .22996 .64899 .22734 .64245 .20526 Mtetra
.55 .47 .719 r
.64245 .20526 .64899 .22734 .66128 .22412 .6548 .20407 Mtetra
.556 .491 .738 r
.6548 .20407 .66128 .22412 .6736 .2204 .66722 .20265 Mtetra
.573 .525 .763 r
.66722 .20265 .6736 .2204 .68595 .21606 .67968 .20051 Mtetra
.587 .56 .792 r
.67968 .20051 .68595 .21606 .69834 .21145 .69219 .19795 Mtetra
.597 .598 .823 r
.69219 .19795 .69834 .21145 .71079 .20694 .70476 .19511 Mtetra
.603 .634 .854 r
.70476 .19511 .71079 .20694 .7233 .20258 .71739 .19215 Mtetra
.603 .666 .884 r
.71739 .19215 .7233 .20258 .73589 .19848 .73009 .18922 Mtetra
.594 .693 .912 r
.73009 .18922 .73589 .19848 .74857 .19475 .74288 .18646 Mtetra
.731 .765 .88 r
.07322 .41517 .0807 .4217 .09087 .4165 .08349 .40932 Mtetra
.726 .747 .869 r
.08349 .40932 .09087 .4165 .10104 .41147 .09379 .40349 Mtetra
.723 .727 .853 r
.09379 .40349 .10104 .41147 .11124 .40647 .10414 .3975 Mtetra
.722 .704 .833 r
.10414 .3975 .11124 .40647 .12148 .40135 .11454 .39121 Mtetra
.722 .681 .81 r
.11454 .39121 .12148 .40135 .13178 .39597 .12503 .38443 Mtetra
.719 .657 .787 r
.12503 .38443 .13178 .39597 .14216 .39017 .1356 .37715 Mtetra
.718 .635 .764 r
.1356 .37715 .14216 .39017 .15264 .38369 .14627 .36919 Mtetra
.708 .613 .749 r
.14627 .36919 .15264 .38369 .16317 .37696 .15695 .36117 Mtetra
.695 .593 .738 r
.15695 .36117 .16317 .37696 .17373 .37018 .16762 .35345 Mtetra
.671 .572 .735 r
.16762 .35345 .17373 .37018 .18422 .36423 .17817 .34688 Mtetra
.633 .546 .738 r
.17817 .34688 .18422 .36423 .19457 .35986 .18854 .34225 Mtetra
.596 .522 .742 r
.18854 .34225 .19457 .35986 .20479 .35719 .19876 .33941 Mtetra
.549 .494 .746 r
.19876 .33941 .20479 .35719 .21485 .35656 .20883 .33848 Mtetra
.541 .486 .744 r
.20883 .33848 .21485 .35656 .22492 .35653 .21893 .33785 Mtetra
.562 .493 .736 r
.21893 .33785 .22492 .35653 .23508 .35617 .22917 .33638 Mtetra
.6 .507 .721 r
.22917 .33638 .23508 .35617 .24543 .35432 .23964 .33297 Mtetra
.641 .521 .702 r
.23964 .33297 .24543 .35432 .25603 .35014 .2504 .32678 Mtetra
.651 .516 .685 r
.2504 .32678 .25603 .35014 .26676 .34498 .2613 .31921 Mtetra
.647 .502 .671 r
.2613 .31921 .26676 .34498 .27752 .3397 .27225 .31116 Mtetra
.62 .472 .66 r
.27225 .31116 .27752 .3397 .28818 .33628 .2831 .3046 Mtetra
.579 .434 .648 r
.2831 .3046 .28818 .33628 .29867 .33583 .29378 .30071 Mtetra
.547 .401 .634 r
.29378 .30071 .29867 .33583 .30909 .33748 .30435 .29899 Mtetra
.523 .375 .622 r
.30435 .29899 .30909 .33748 .31949 .34058 .31486 .29907 Mtetra
.521 .367 .613 r
.31486 .29907 .31949 .34058 .33002 .34295 .32543 .29927 Mtetra
.529 .369 .609 r
.32543 .29927 .33002 .34295 .34075 .34354 .33611 .29874 Mtetra
.536 .373 .607 r
.33611 .29874 .34075 .34354 .35162 .34277 .3469 .29748 Mtetra
.544 .378 .606 r
.3469 .29748 .35162 .34277 .36263 .34078 .3578 .29541 Mtetra
.548 .381 .607 r
.3578 .29541 .36263 .34078 .37371 .33827 .36879 .29284 Mtetra
.553 .385 .607 r
.36879 .29284 .37371 .33827 .38488 .33534 .37985 .28975 Mtetra
.561 .391 .607 r
.37985 .28975 .38488 .33534 .39613 .33139 .391 .28573 Mtetra
.57 .396 .607 r
.391 .28573 .39613 .33139 .40748 .3264 .40224 .28079 Mtetra
.574 .4 .608 r
.40224 .28079 .40748 .3264 .41887 .321 .41353 .27532 Mtetra
.578 .403 .608 r
.41353 .27532 .41887 .321 .43032 .31507 .42488 .26934 Mtetra
.585 .408 .608 r
.42488 .26934 .43032 .31507 .44184 .3079 .43628 .26254 Mtetra
.592 .413 .608 r
.43628 .26254 .44184 .3079 .45341 .29934 .44773 .25501 Mtetra
.599 .42 .61 r
.44773 .25501 .45341 .29934 .46504 .28897 .45922 .24671 Mtetra
.602 .425 .615 r
.45922 .24671 .46504 .28897 .47668 .27784 .47072 .23852 Mtetra
.591 .423 .623 r
.47072 .23852 .47668 .27784 .48829 .26816 .48222 .23215 Mtetra
.574 .42 .635 r
.48222 .23215 .48829 .26816 .4999 .2606 .49373 .22797 Mtetra
.545 .411 .648 r
.49373 .22797 .4999 .2606 .51152 .25603 .50526 .2265 Mtetra
.525 .409 .664 r
.50526 .2265 .51152 .25603 .52318 .25336 .51686 .22655 Mtetra
.533 .427 .68 r
.51686 .22655 .52318 .25336 .5349 .25058 .52855 .22612 Mtetra
.558 .457 .696 r
.52855 .22612 .5349 .25058 .54668 .24679 .5403 .2243 Mtetra
.609 .501 .706 r
.5403 .2243 .54668 .24679 .55849 .24061 .5521 .21963 Mtetra
.645 .534 .713 r
.5521 .21963 .55849 .24061 .57031 .2329 .56392 .21298 Mtetra
.663 .553 .719 r
.56392 .21298 .57031 .2329 .58214 .22484 .57576 .20546 Mtetra
.662 .557 .725 r
.57576 .20546 .58214 .22484 .59401 .21739 .58763 .19823 Mtetra
.631 .541 .735 r
.58763 .19823 .59401 .21739 .60597 .21201 .59958 .19296 Mtetra
.597 .523 .742 r
.59958 .19296 .60597 .21201 .61802 .20838 .61163 .18952 Mtetra
.556 .501 .749 r
.61163 .18952 .61802 .20838 .63018 .20638 .6238 .18807 Mtetra
.529 .491 .758 r
.6238 .18807 .63018 .20638 .64245 .20526 .63609 .18783 Mtetra
.52 .496 .771 r
.63609 .18783 .64245 .20526 .6548 .20407 .64849 .18791 Mtetra
.519 .513 .789 r
.64849 .18791 .6548 .20407 .66722 .20265 .66097 .18793 Mtetra
.536 .544 .81 r
.66097 .18793 .66722 .20265 .67968 .20051 .67351 .18727 Mtetra
.548 .577 .835 r
.67351 .18727 .67968 .20051 .69219 .19795 .68611 .18609 Mtetra
.562 .613 .861 r
.68611 .18609 .69219 .19795 .70476 .19511 .69877 .1844 Mtetra
.57 .644 .884 r
.69877 .1844 .70476 .19511 .71739 .19215 .71148 .1824 Mtetra
.572 .67 .905 r
.71148 .1824 .71739 .19215 .73009 .18922 .72427 .18025 Mtetra
.567 .691 .924 r
.72427 .18025 .73009 .18922 .74288 .18646 .73713 .1781 Mtetra
.737 .766 .877 r
.06568 .40859 .07322 .41517 .08349 .40932 .07601 .4025 Mtetra
.738 .76 .871 r
.07601 .4025 .08349 .40932 .09379 .40349 .08639 .39627 Mtetra
.741 .751 .86 r
.08639 .39627 .09379 .40349 .10414 .3975 .09682 .38977 Mtetra
.746 .739 .846 r
.09682 .38977 .10414 .3975 .11454 .39121 .10733 .38285 Mtetra
.752 .726 .828 r
.10733 .38285 .11454 .39121 .12503 .38443 .11795 .37529 Mtetra
.754 .711 .811 r
.11795 .37529 .12503 .38443 .1356 .37715 .12863 .36721 Mtetra
.756 .697 .795 r
.12863 .36721 .1356 .37715 .14627 .36919 .13941 .35855 Mtetra
.748 .683 .788 r
.13941 .35855 .14627 .36919 .15695 .36117 .15018 .34999 Mtetra
.734 .67 .787 r
.15018 .34999 .15695 .36117 .16762 .35345 .16089 .34198 Mtetra
.709 .657 .795 r
.16089 .34198 .16762 .35345 .17817 .34688 .17147 .33527 Mtetra
.665 .637 .812 r
.17147 .33527 .17817 .34688 .18854 .34225 .18185 .33058 Mtetra
.62 .617 .826 r
.18185 .33058 .18854 .34225 .19876 .33941 .1921 .3275 Mtetra
.568 .589 .834 r
.1921 .3275 .19876 .33941 .20883 .33848 .20223 .32599 Mtetra
.571 .58 .823 r
.20223 .32599 .20883 .33848 .21893 .33785 .21243 .32437 Mtetra
.609 .583 .799 r
.21243 .32437 .21893 .33785 .22917 .33638 .2228 .32146 Mtetra
.655 .586 .766 r
.2228 .32146 .22917 .33638 .23964 .33297 .23343 .31631 Mtetra
.695 .588 .732 r
.23343 .31631 .23964 .33297 .2504 .32678 .24436 .30815 Mtetra
.703 .577 .71 r
.24436 .30815 .2504 .32678 .2613 .31921 .25544 .29836 Mtetra
.699 .559 .693 r
.25544 .29836 .2613 .31921 .27225 .31116 .26659 .28782 Mtetra
.673 .529 .681 r
.26659 .28782 .27225 .31116 .2831 .3046 .27765 .27841 Mtetra
.634 .491 .67 r
.27765 .27841 .2831 .3046 .29378 .30071 .28854 .27127 Mtetra
.598 .453 .656 r
.28854 .27127 .29378 .30071 .30435 .29899 .2993 .26621 Mtetra
.566 .42 .642 r
.2993 .26621 .30435 .29899 .31486 .29907 .30995 .26315 Mtetra
.553 .402 .631 r
.30995 .26315 .31486 .29907 .32543 .29927 .3206 .26082 Mtetra
.549 .394 .623 r
.3206 .26082 .32543 .29927 .33611 .29874 .33131 .25857 Mtetra
.549 .39 .618 r
.33131 .25857 .33611 .29874 .3469 .29748 .34207 .25621 Mtetra
.552 .39 .615 r
.34207 .25621 .3469 .29748 .3578 .29541 .35291 .25351 Mtetra
.554 .39 .614 r
.35291 .25351 .3578 .29541 .36879 .29284 .36382 .25051 Mtetra
.557 .392 .613 r
.36382 .25051 .36879 .29284 .37985 .28975 .37479 .24713 Mtetra
.564 .396 .613 r
.37479 .24713 .37985 .28975 .391 .28573 .38585 .24305 Mtetra
.57 .401 .613 r
.38585 .24305 .391 .28573 .40224 .28079 .39699 .23829 Mtetra
.574 .404 .613 r
.39699 .23829 .40224 .28079 .41353 .27532 .40817 .23313 Mtetra
.577 .407 .614 r
.40817 .23313 .41353 .27532 .42488 .26934 .41941 .22768 Mtetra
.581 .411 .616 r
.41941 .22768 .42488 .26934 .43628 .26254 .43069 .22187 Mtetra
.584 .415 .618 r
.43069 .22187 .43628 .26254 .44773 .25501 .44202 .21595 Mtetra
.585 .419 .623 r
.44202 .21595 .44773 .25501 .45922 .24671 .45337 .2101 Mtetra
.582 .423 .631 r
.45337 .2101 .45922 .24671 .47072 .23852 .46474 .205 Mtetra
.564 .419 .643 r
.46474 .205 .47072 .23852 .48222 .23215 .47612 .2019 Mtetra
.538 .414 .658 r
.47612 .2019 .48222 .23215 .49373 .22797 .48754 .20091 Mtetra
.501 .403 .677 r
.48754 .20091 .49373 .22797 .50526 .2265 .499 .20225 Mtetra
.474 .403 .697 r
.499 .20225 .50526 .2265 .51686 .22655 .51055 .20475 Mtetra
.485 .428 .718 r
.51055 .20475 .51686 .22655 .52855 .22612 .5222 .2065 Mtetra
.52 .47 .74 r
.5222 .2065 .52855 .22612 .5403 .2243 .53395 .2066 Mtetra
.591 .532 .757 r
.53395 .2066 .5403 .2243 .5521 .21963 .54575 .20364 Mtetra
.645 .582 .769 r
.54575 .20364 .5521 .21963 .56392 .21298 .5576 .19839 Mtetra
.68 .618 .78 r
.5576 .19839 .56392 .21298 .57576 .20546 .56947 .1918 Mtetra
.688 .636 .792 r
.56947 .1918 .57576 .20546 .58763 .19823 .58136 .1851 Mtetra
.657 .63 .811 r
.58136 .1851 .58763 .19823 .59958 .19296 .59333 .17999 Mtetra
.616 .613 .825 r
.59333 .17999 .59958 .19296 .61163 .18952 .60539 .17655 Mtetra
.554 .582 .836 r
.60539 .17655 .61163 .18952 .6238 .18807 .61758 .17519 Mtetra
.508 .559 .843 r
.61758 .17519 .6238 .18807 .63609 .18783 .62989 .17517 Mtetra
.485 .551 .849 r
.62989 .17517 .63609 .18783 .64849 .18791 .64231 .17573 Mtetra
.477 .558 .859 r
.64231 .17573 .64849 .18791 .66097 .18793 .65484 .17642 Mtetra
.495 .584 .873 r
.65484 .17642 .66097 .18793 .67351 .18727 .66743 .1765 Mtetra
.51 .611 .889 r
.66743 .1765 .67351 .18727 .68611 .18609 .68009 .17606 Mtetra
.531 .642 .904 r
.68009 .17606 .68611 .18609 .69877 .1844 .69281 .17497 Mtetra
.544 .666 .916 r
.69281 .17497 .69877 .1844 .71148 .1824 .70559 .17344 Mtetra
.552 .685 .927 r
.70559 .17344 .71148 .1824 .72427 .18025 .71843 .17162 Mtetra
.554 .697 .935 r
.71843 .17162 .72427 .18025 .73713 .1781 .73134 .16968 Mtetra
.728 .765 .882 r
.05808 .40196 .06568 .40859 .07601 .4025 .0684 .39616 Mtetra
.736 .775 .884 r
.0684 .39616 .07601 .4025 .08639 .39627 .07878 .39013 Mtetra
.746 .783 .883 r
.07878 .39013 .08639 .39627 .09682 .38977 .08922 .38375 Mtetra
.759 .788 .877 r
.08922 .38375 .09682 .38977 .10733 .38285 .09976 .37688 Mtetra
.774 .791 .867 r
.09976 .37688 .10733 .38285 .11795 .37529 .1104 .36931 Mtetra
.783 .792 .86 r
.1104 .36931 .11795 .37529 .12863 .36721 .12111 .36129 Mtetra
.792 .794 .854 r
.12111 .36129 .12863 .36721 .13941 .35855 .1319 .35282 Mtetra
.789 .801 .862 r
.1319 .35282 .13941 .35855 .15018 .34999 .14266 .34463 Mtetra
.775 .813 .883 r
.14266 .34463 .15018 .34999 .16089 .34198 .15333 .33726 Mtetra
.742 .833 .921 r
.15333 .33726 .16089 .34198 .17147 .33527 .16386 .33128 Mtetra
.654 .847 .974 r
.16386 .33128 .17147 .33527 .18185 .33058 .1742 .32735 Mtetra
.534 .84 .999 r
.1742 .32735 .18185 .33058 .1921 .3275 .1844 .32489 Mtetra
.375 .79 .979 r
.1844 .32489 .1921 .3275 .20223 .32599 .19453 .3237 Mtetra
.396 .81 .977 r
.19453 .3237 .20223 .32599 .21243 .32437 .20475 .32213 Mtetra
.55 .878 .991 r
.20475 .32213 .21243 .32437 .2228 .32146 .21519 .31897 Mtetra
.714 .912 .963 r
.21519 .31897 .2228 .32146 .23343 .31631 .2259 .31336 Mtetra
.82 .896 .896 r
.2259 .31336 .23343 .31631 .24436 .30815 .23693 .30457 Mtetra
.851 .87 .854 r
.23693 .30457 .24436 .30815 .25544 .29836 .24815 .29385 Mtetra
.858 .841 .827 r
.24815 .29385 .25544 .29836 .26659 .28782 .25946 .28198 Mtetra
.838 .809 .822 r
.25946 .28198 .26659 .28782 .27765 .27841 .27071 .27067 Mtetra
.796 .762 .822 r
.27071 .27067 .27765 .27841 .28854 .27127 .28183 .26102 Mtetra
.741 .697 .809 r
.28183 .26102 .28854 .27127 .2993 .26621 .29282 .25312 Mtetra
.682 .627 .787 r
.29282 .25312 .2993 .26621 .30995 .26315 .30369 .24709 Mtetra
.643 .569 .756 r
.30369 .24709 .30995 .26315 .3206 .26082 .31452 .2421 Mtetra
.619 .529 .731 r
.31452 .2421 .3206 .26082 .33131 .25857 .32534 .23773 Mtetra
.605 .504 .713 r
.32534 .23773 .33131 .25857 .34207 .25621 .33618 .23374 Mtetra
.597 .488 .7 r
.33618 .23374 .34207 .25621 .35291 .25351 .34705 .22989 Mtetra
.592 .478 .692 r
.34705 .22989 .35291 .25351 .36382 .25051 .35797 .2261 Mtetra
.591 .473 .687 r
.35797 .2261 .36382 .25051 .37479 .24713 .36894 .22226 Mtetra
.594 .473 .684 r
.36894 .22226 .37479 .24713 .38585 .24305 .37996 .21814 Mtetra
.598 .475 .684 r
.37996 .21814 .38585 .24305 .39699 .23829 .39105 .21375 Mtetra
.6 .479 .686 r
.39105 .21375 .39699 .23829 .40817 .23313 .40218 .2093 Mtetra
.601 .483 .691 r
.40218 .2093 .40817 .23313 .41941 .22768 .41335 .20491 Mtetra
.601 .491 .7 r
.41335 .20491 .41941 .22768 .43069 .22187 .42456 .20067 Mtetra
.6 .501 .713 r
.42456 .20067 .43069 .22187 .44202 .21595 .4358 .1968 Mtetra
.594 .514 .735 r
.4358 .1968 .44202 .21595 .45337 .2101 .44708 .19356 Mtetra
.577 .532 .769 r
.44708 .19356 .45337 .2101 .46474 .205 .45838 .19137 Mtetra
.521 .544 .82 r
.45838 .19137 .46474 .205 .47612 .2019 .46972 .19108 Mtetra
.423 .55 .88 r
.46972 .19108 .47612 .2019 .48754 .20091 .48111 .19258 Mtetra
.249 .523 .914 r
.48111 .19258 .48754 .20091 .499 .20225 .49257 .19578 Mtetra
.105 .496 .903 r
.49257 .19578 .499 .20225 .51055 .20475 .50413 .19956 Mtetra
.13 .562 .923 r
.50413 .19956 .51055 .20475 .5222 .2065 .51581 .2022 Mtetra
.261 .679 .966 r
.51581 .2022 .5222 .2065 .53395 .2066 .52759 .20289 Mtetra
.506 .833 .999 r
.52759 .20289 .53395 .2066 .54575 .20364 .53945 .20034 Mtetra
.651 .904 .982 r
.53945 .20034 .54575 .20364 .5576 .19839 .55135 .19529 Mtetra
.725 .93 .958 r
.55135 .19529 .5576 .19839 .56947 .1918 .56328 .1886 Mtetra
.742 .932 .951 r
.56328 .1886 .56947 .1918 .58136 .1851 .57523 .18151 Mtetra
.69 .91 .972 r
.57523 .18151 .58136 .1851 .59333 .17999 .58724 .17571 Mtetra
.625 .867 .988 r
.58724 .17571 .59333 .17999 .60539 .17655 .59933 .17143 Mtetra
.519 .793 .995 r
.59933 .17143 .60539 .17655 .61758 .17519 .61153 .16925 Mtetra
.446 .728 .986 r
.61153 .16925 .61758 .17519 .62989 .17517 .62385 .16851 Mtetra
.411 .683 .974 r
.62385 .16851 .62989 .17517 .64231 .17573 .6363 .16863 Mtetra
.405 .664 .965 r
.6363 .16863 .64231 .17573 .65484 .17642 .64884 .16904 Mtetra
.439 .675 .963 r
.64884 .16904 .65484 .17642 .66743 .1765 .66147 .16901 Mtetra
.468 .687 .962 r
.66147 .16901 .66743 .1765 .68009 .17606 .67416 .16851 Mtetra
.507 .707 .961 r
.67416 .16851 .68009 .17606 .69281 .17497 .68691 .1673 Mtetra
.533 .717 .957 r
.68691 .1673 .69281 .17497 .70559 .17344 .69971 .16558 Mtetra
.552 .721 .952 r
.69971 .16558 .70559 .17344 .71843 .17162 .71257 .1635 Mtetra
.564 .72 .946 r
.71257 .1635 .71843 .17162 .73134 .16968 .7255 .16118 Mtetra
.707 .762 .895 r
.05043 .39529 .05808 .40196 .0684 .39616 .06067 .3902 Mtetra
.719 .786 .905 r
.06067 .3902 .0684 .39616 .07878 .39013 .07098 .38482 Mtetra
.734 .809 .911 r
.07098 .38482 .07878 .39013 .08922 .38375 .08137 .37906 Mtetra
.751 .831 .913 r
.08137 .37906 .08922 .38375 .09976 .37688 .09185 .37282 Mtetra
.772 .851 .91 r
.09185 .37282 .09976 .37688 .1104 .36931 .10245 .3659 Mtetra
.784 .872 .913 r
.10245 .3659 .1104 .36931 .12111 .36129 .11311 .35861 Mtetra
.793 .896 .916 r
.11311 .35861 .12111 .36129 .1319 .35282 .12382 .35104 Mtetra
.778 .926 .933 r
.12382 .35104 .1319 .35282 .14266 .34463 .1345 .34389 Mtetra
.721 .953 .95 r
.1345 .34389 .14266 .34463 .15333 .33726 .14508 .3377 Mtetra
.572 .934 .924 r
.14508 .3377 .15333 .33726 .16386 .33128 .15553 .3329 Mtetra
.255 .763 .758 r
.15553 .3329 .16386 .33128 .1742 .32735 .16578 .33004 Mtetra
.005 0 0 r
.16578 .33004 .1742 .32735 .1844 .32489 .17594 .32845 Mtetra
.169 0 0 r
.17594 .32845 .1844 .32489 .19453 .3237 .18606 .32781 Mtetra
.141 0 0 r
.18606 .32781 .19453 .3237 .20475 .32213 .19629 .3266 Mtetra
0 0 0 r
.19629 .3266 .20475 .32213 .21519 .31897 .20676 .32364 Mtetra
.20676 .32364 .21519 .31897 .2259 .31336 .21753 .31818 Mtetra
.574 .916 .701 r
.21753 .31818 .2259 .31336 .23693 .30457 .22862 .30955 Mtetra
.706 .967 .726 r
.22862 .30955 .23693 .30457 .24815 .29385 .23992 .29878 Mtetra
.778 .985 .735 r
.23992 .29878 .24815 .29385 .25946 .28198 .25135 .28654 Mtetra
.791 .99 .747 r
.25135 .28654 .25946 .28198 .27071 .27067 .26276 .2743 Mtetra
.784 .995 .781 r
.26276 .2743 .27071 .27067 .28183 .26102 .27408 .26308 Mtetra
.785 .998 .84 r
.27408 .26308 .28183 .26102 .29282 .25312 .28529 .25319 Mtetra
.775 .983 .905 r
.28529 .25319 .29282 .25312 .30369 .24709 .29638 .24491 Mtetra
.766 .934 .939 r
.29638 .24491 .30369 .24709 .31452 .2421 .30741 .23778 Mtetra
.742 .865 .937 r
.30741 .23778 .31452 .2421 .32534 .23773 .31839 .23157 Mtetra
.714 .801 .918 r
.31839 .23157 .32534 .23773 .33618 .23374 .32935 .22607 Mtetra
.69 .75 .897 r
.32935 .22607 .33618 .23374 .34705 .22989 .34032 .22111 Mtetra
.672 .714 .88 r
.34032 .22111 .34705 .22989 .35797 .2261 .3513 .21656 Mtetra
.659 .691 .868 r
.3513 .21656 .35797 .2261 .36894 .22226 .36231 .21229 Mtetra
.653 .679 .862 r
.36231 .21229 .36894 .22226 .37996 .21814 .37336 .20814 Mtetra
.649 .677 .863 r
.37336 .20814 .37996 .21814 .39105 .21375 .38444 .20411 Mtetra
.641 .683 .875 r
.38444 .20411 .39105 .21375 .40218 .2093 .39556 .20036 Mtetra
.627 .697 .895 r
.39556 .20036 .40218 .2093 .41335 .20491 .40672 .19703 Mtetra
.604 .72 .926 r
.40672 .19703 .41335 .20491 .42456 .20067 .4179 .19423 Mtetra
.555 .749 .967 r
.4179 .19423 .42456 .20067 .4358 .1968 .42912 .19215 Mtetra
.444 .766 .997 r
.42912 .19215 .4358 .1968 .44708 .19356 .44038 .19102 Mtetra
.205 .697 .922 r
.44038 .19102 .44708 .19356 .45838 .19137 .45168 .19105 Mtetra
.152 0 0 r
.45168 .19105 .45838 .19137 .46972 .19108 .46302 .19272 Mtetra
.369 0 0 r
.46302 .19272 .46972 .19108 .48111 .19258 .47444 .19576 Mtetra
.469 0 0 r
.47444 .19576 .48111 .19258 .49257 .19578 .48595 .19985 Mtetra
.483 0 0 r
.48595 .19985 .49257 .19578 .50413 .19956 .49757 .20398 Mtetra
.415 0 0 r
.49757 .20398 .50413 .19956 .51581 .2022 .50931 .20662 Mtetra
.29 0 0 r
.50931 .20662 .51581 .2022 .52759 .20289 .52116 .2071 Mtetra
.043 0 0 r
.52116 .2071 .52759 .20289 .53945 .20034 .5331 .20436 Mtetra
0 0 0 r
.5331 .20436 .53945 .20034 .55135 .19529 .54508 .19905 Mtetra
.54508 .19905 .55135 .19529 .56328 .1886 .55709 .19195 Mtetra
.432 .839 .65 r
.55709 .19195 .56328 .1886 .57523 .18151 .56912 .18424 Mtetra
.402 .832 .68 r
.56912 .18424 .57523 .18151 .58724 .17571 .58119 .1775 Mtetra
.367 .825 .733 r
.58119 .1775 .58724 .17571 .59933 .17143 .59333 .17206 Mtetra
.281 .782 .785 r
.59333 .17206 .59933 .17143 .61153 .16925 .60557 .16861 Mtetra
.246 .758 .851 r
.60557 .16861 .61153 .16925 .62385 .16851 .61791 .1666 Mtetra
.249 .743 .912 r
.61791 .1666 .62385 .16851 .6363 .16863 .63037 .16559 Mtetra
.287 .741 .956 r
.63037 .16559 .6363 .16863 .64884 .16904 .64293 .16502 Mtetra
.368 .759 .987 r
.64293 .16502 .64884 .16904 .66147 .16901 .65557 .16417 Mtetra
.433 .767 .997 r
.65557 .16417 .66147 .16901 .67416 .16851 .66827 .16294 Mtetra
.502 .777 .994 r
.66827 .16294 .67416 .16851 .68691 .1673 .68103 .16101 Mtetra
.546 .774 .983 r
.68103 .16101 .68691 .1673 .69971 .16558 .69384 .15857 Mtetra
.575 .763 .968 r
.69384 .15857 .69971 .16558 .71257 .1635 .7067 .15574 Mtetra
.595 .748 .95 r
.7067 .15574 .71257 .1635 .7255 .16118 .71961 .15261 Mtetra
.669 .754 .915 r
.04273 .38856 .05043 .39529 .06067 .3902 .05283 .38456 Mtetra
.681 .792 .934 r
.05283 .38456 .06067 .3902 .07098 .38482 .063 .38028 Mtetra
.693 .831 .949 r
.063 .38028 .07098 .38482 .08137 .37906 .07326 .37566 Mtetra
.705 .872 .96 r
.07326 .37566 .08137 .37906 .09185 .37282 .08361 .37063 Mtetra
.719 .912 .961 r
.08361 .37063 .09185 .37282 .10245 .3659 .09407 .36503 Mtetra
.708 .947 .956 r
.09407 .36503 .10245 .3659 .11311 .35861 .10459 .35916 Mtetra
.67 .965 .929 r
.10459 .35916 .11311 .35861 .12382 .35104 .11516 .35314 Mtetra
.544 .928 .849 r
.11516 .35314 .12382 .35104 .1345 .34389 .1257 .34755 Mtetra
.314 .784 .674 r
.1257 .34755 .1345 .34389 .14508 .3377 .13615 .34287 Mtetra
0 0 0 r
.13615 .34287 .14508 .3377 .15553 .3329 .1465 .33936 Mtetra
.179 0 0 r
.1465 .33936 .15553 .3329 .16578 .33004 .15671 .33744 Mtetra
.282 0 0 r
.15671 .33744 .16578 .33004 .17594 .32845 .16687 .33643 Mtetra
.332 0 0 r
.16687 .33643 .17594 .32845 .18606 .32781 .17702 .33598 Mtetra
.29 0 0 r
.17702 .33598 .18606 .32781 .19629 .3266 .18732 .33479 Mtetra
.168 0 0 r
.18732 .33479 .19629 .3266 .20676 .32364 .19786 .33184 Mtetra
0 0 0 r
.19786 .33184 .20676 .32364 .21753 .31818 .20868 .32654 Mtetra
.20868 .32654 .21753 .31818 .22862 .30955 .21982 .31833 Mtetra
.21982 .31833 .22862 .30955 .23992 .29878 .23116 .30809 Mtetra
.23116 .30809 .23992 .29878 .25135 .28654 .24264 .29634 Mtetra
.24264 .29634 .25135 .28654 .26276 .2743 .25414 .28436 Mtetra
.25414 .28436 .26276 .2743 .27408 .26308 .26557 .27301 Mtetra
.26557 .27301 .27408 .26308 .28529 .25319 .27691 .26271 Mtetra
.27691 .26271 .28529 .25319 .29638 .24491 .28814 .25378 Mtetra
.28814 .25378 .29638 .24491 .30741 .23778 .2993 .24599 Mtetra
.2993 .24599 .30741 .23778 .31839 .23157 .31041 .23923 Mtetra
.31041 .23923 .31839 .23157 .32935 .22607 .32148 .2333 Mtetra
.32148 .2333 .32935 .22607 .34032 .22111 .33255 .22804 Mtetra
.33255 .22804 .34032 .22111 .3513 .21656 .34362 .22326 Mtetra
.011 0 0 r
.34362 .22326 .3513 .21656 .36231 .21229 .35472 .21886 Mtetra
.026 0 0 r
.35472 .21886 .36231 .21229 .37336 .20814 .36584 .21469 Mtetra
.046 0 0 r
.36584 .21469 .37336 .20814 .38444 .20411 .377 .21075 Mtetra
.083 0 0 r
.377 .21075 .38444 .20411 .39556 .20036 .38819 .20718 Mtetra
.131 0 0 r
.38819 .20718 .39556 .20036 .40672 .19703 .39941 .20411 Mtetra
.19 0 0 r
.39941 .20411 .40672 .19703 .4179 .19423 .41066 .20171 Mtetra
.257 0 0 r
.41066 .20171 .4179 .19423 .42912 .19215 .42195 .20014 Mtetra
.328 0 0 r
.42195 .20014 .42912 .19215 .44038 .19102 .43326 .19963 Mtetra
.392 0 0 r
.43326 .19963 .44038 .19102 .45168 .19105 .44463 .20027 Mtetra
.454 0 .046 r
.44463 .20027 .45168 .19105 .46302 .19272 .45605 .20233 Mtetra
.491 .026 .077 r
.45605 .20233 .46302 .19272 .47444 .19576 .46754 .20546 Mtetra
.511 .047 .088 r
.46754 .20546 .47444 .19576 .48595 .19985 .47914 .20926 Mtetra
.502 .033 .073 r
.47914 .20926 .48595 .19985 .49757 .20398 .49084 .21283 Mtetra
.447 0 .024 r
.49084 .21283 .49757 .20398 .50931 .20662 .50268 .21491 Mtetra
.355 0 0 r
.50268 .21491 .50931 .20662 .52116 .2071 .51462 .21492 Mtetra
.191 0 0 r
.51462 .21492 .52116 .2071 .5331 .20436 .52664 .21197 Mtetra
.035 0 0 r
.52664 .21197 .5331 .20436 .54508 .19905 .53873 .20662 Mtetra
0 0 0 r
.53873 .20662 .54508 .19905 .55709 .19195 .55084 .19945 Mtetra
.55084 .19945 .55709 .19195 .56912 .18424 .56297 .19151 Mtetra
.56297 .19151 .56912 .18424 .58119 .1775 .57513 .18412 Mtetra
.57513 .18412 .58119 .1775 .59333 .17206 .58735 .17767 Mtetra
.58735 .17767 .59333 .17206 .60557 .16861 .59965 .17285 Mtetra
.59965 .17285 .60557 .16861 .61791 .1666 .61203 .16924 Mtetra
.61203 .16924 .61791 .1666 .63037 .16559 .62451 .16656 Mtetra
.13 .675 .704 r
.62451 .16656 .63037 .16559 .64293 .16502 .63708 .16433 Mtetra
.276 .778 .86 r
.63708 .16433 .64293 .16502 .65557 .16417 .64972 .16194 Mtetra
.407 .835 .958 r
.64972 .16194 .65557 .16417 .66827 .16294 .66242 .15928 Mtetra
.521 .855 .996 r
.66242 .15928 .66827 .16294 .68103 .16101 .67516 .15603 Mtetra
.585 .84 .993 r
.67516 .15603 .68103 .16101 .69384 .15857 .68795 .15235 Mtetra
.621 .813 .974 r
.68795 .15235 .69384 .15857 .7067 .15574 .70079 .14831 Mtetra
.641 .782 .948 r
.70079 .14831 .7067 .15574 .71961 .15261 .71368 .14397 Mtetra
.614 .74 .936 r
.03496 .38178 .04273 .38856 .05283 .38456 .0449 .37903 Mtetra
.619 .784 .96 r
.0449 .37903 .05283 .38456 .063 .38028 .05491 .37603 Mtetra
.62 .829 .981 r
.05491 .37603 .063 .38028 .07326 .37566 .065 .37277 Mtetra
.613 .873 .991 r
.065 .37277 .07326 .37566 .08361 .37063 .07518 .3692 Mtetra
.597 .91 .98 r
.07518 .3692 .08361 .37063 .09407 .36503 .08545 .36523 Mtetra
.53 .915 .93 r
.08545 .36523 .09407 .36503 .10459 .35916 .09579 .36108 Mtetra
.411 .861 .817 r
.09579 .36108 .10459 .35916 .11516 .35314 .10617 .35687 Mtetra
0 0 0 r
.10617 .35687 .11516 .35314 .1257 .34755 .11654 .35299 Mtetra
.11654 .35299 .1257 .34755 .13615 .34287 .12687 .34981 Mtetra
.156 0 0 r
.12687 .34981 .13615 .34287 .1465 .33936 .13715 .34745 Mtetra
.277 0 0 r
.13715 .34745 .1465 .33936 .15671 .33744 .14734 .34617 Mtetra
.324 0 0 r
.14734 .34617 .15671 .33744 .16687 .33643 .15753 .3454 Mtetra
.339 0 0 r
.15753 .3454 .16687 .33643 .17702 .33598 .16777 .34483 Mtetra
.291 0 0 r
.16777 .34483 .17702 .33598 .18732 .33479 .17815 .34347 Mtetra
.184 0 0 r
.17815 .34347 .18732 .33479 .19786 .33184 .18875 .34057 Mtetra
.038 0 0 r
.18875 .34057 .19786 .33184 .20868 .32654 .19961 .33573 Mtetra
0 0 0 r
.19961 .33573 .20868 .32654 .21982 .31833 .21073 .32856 Mtetra
.21073 .32856 .21982 .31833 .23116 .30809 .22204 .3197 Mtetra
.22204 .3197 .23116 .30809 .24264 .29634 .23348 .30958 Mtetra
.23348 .30958 .24264 .29634 .25414 .28436 .24494 .29913 Mtetra
.24494 .29913 .25414 .28436 .26557 .27301 .25638 .28905 Mtetra
.045 0 0 r
.25638 .28905 .26557 .27301 .27691 .26271 .26776 .27971 Mtetra
.129 0 .039 r
.26776 .27971 .27691 .26271 .28814 .25378 .27906 .27143 Mtetra
.188 0 .08 r
.27906 .27143 .28814 .25378 .2993 .24599 .29031 .26411 Mtetra
.235 0 .111 r
.29031 .26411 .2993 .24599 .31041 .23923 .30151 .25769 Mtetra
.268 0 .132 r
.30151 .25769 .31041 .23923 .32148 .2333 .31269 .25201 Mtetra
.293 0 .148 r
.31269 .25201 .32148 .2333 .33255 .22804 .32387 .24691 Mtetra
.31 0 .158 r
.32387 .24691 .33255 .22804 .34362 .22326 .33506 .24223 Mtetra
.321 0 .165 r
.33506 .24223 .34362 .22326 .35472 .21886 .34627 .23785 Mtetra
.328 0 .169 r
.34627 .23785 .35472 .21886 .36584 .21469 .35752 .23367 Mtetra
.335 0 .172 r
.35752 .23367 .36584 .21469 .377 .21075 .36881 .22967 Mtetra
.344 0 .175 r
.36881 .22967 .377 .21075 .38819 .20718 .38013 .22598 Mtetra
.356 0 .179 r
.38013 .22598 .38819 .20718 .39941 .20411 .39148 .22272 Mtetra
.371 0 .183 r
.39148 .22272 .39941 .20411 .41066 .20171 .40286 .22004 Mtetra
.39 .008 .188 r
.40286 .22004 .41066 .20171 .42195 .20014 .41428 .21811 Mtetra
.412 .026 .193 r
.41428 .21811 .42195 .20014 .43326 .19963 .42573 .2171 Mtetra
.434 .043 .195 r
.42573 .2171 .43326 .19963 .44463 .20027 .43723 .21706 Mtetra
.458 .06 .196 r
.43723 .21706 .44463 .20027 .45605 .20233 .44878 .21811 Mtetra
.473 .066 .187 r
.44878 .21811 .45605 .20233 .46754 .20546 .46041 .21993 Mtetra
.478 .06 .167 r
.46041 .21993 .46754 .20546 .47914 .20926 .47213 .22214 Mtetra
.464 .03 .13 r
.47213 .22214 .47914 .20926 .49084 .21283 .48396 .22404 Mtetra
.413 0 .066 r
.48396 .22404 .49084 .21283 .50268 .21491 .4959 .22467 Mtetra
.328 0 0 r
.4959 .22467 .50268 .21491 .51462 .21492 .50794 .22359 Mtetra
.185 0 0 r
.50794 .22359 .51462 .21492 .52664 .21197 .52007 .22013 Mtetra
.049 0 0 r
.52007 .22013 .52664 .21197 .53873 .20662 .53225 .21468 Mtetra
0 0 0 r
.53225 .21468 .53873 .20662 .55084 .19945 .54447 .20764 Mtetra
.54447 .20764 .55084 .19945 .56297 .19151 .55671 .19978 Mtetra
.55671 .19978 .56297 .19151 .57513 .18412 .56899 .19211 Mtetra
.56899 .19211 .57513 .18412 .58735 .17767 .5813 .18496 Mtetra
.5813 .18496 .58735 .17767 .59965 .17285 .59367 .1789 Mtetra
.59367 .1789 .59965 .17285 .61203 .16924 .60611 .17369 Mtetra
.60611 .17369 .61203 .16924 .62451 .16656 .61862 .16919 Mtetra
.61862 .16919 .62451 .16656 .63708 .16433 .6312 .16504 Mtetra
.325 .809 .787 r
.6312 .16504 .63708 .16433 .64972 .16194 .64384 .16082 Mtetra
.472 .888 .921 r
.64384 .16082 .64972 .16194 .66242 .15928 .65653 .15641 Mtetra
.589 .909 .98 r
.65653 .15641 .66242 .15928 .67516 .15603 .66926 .15157 Mtetra
.649 .885 .983 r
.66926 .15157 .67516 .15603 .68795 .15235 .68203 .14641 Mtetra
.678 .846 .964 r
.68203 .14641 .68795 .15235 .70079 .14831 .69484 .14096 Mtetra
.69 .806 .936 r
.69484 .14096 .70079 .14831 .71368 .14397 .70769 .13525 Mtetra
.545 .718 .953 r
.02714 .37496 .03496 .38178 .0449 .37903 .03691 .3734 Mtetra
.539 .758 .977 r
.03691 .3734 .0449 .37903 .05491 .37603 .04675 .37166 Mtetra
.524 .797 .996 r
.04675 .37166 .05491 .37603 .065 .37277 .05667 .36975 Mtetra
.494 .832 .998 r
.05667 .36975 .065 .37277 .07518 .3692 .06667 .36763 Mtetra
.446 .849 .971 r
.06667 .36763 .07518 .3692 .08545 .36523 .07675 .36527 Mtetra
.345 .82 .885 r
.07675 .36527 .08545 .36523 .09579 .36108 .0869 .3628 Mtetra
.21 .732 .736 r
.0869 .3628 .09579 .36108 .10617 .35687 .0971 .36029 Mtetra
0 0 0 r
.0971 .36029 .10617 .35687 .11654 .35299 .10733 .35793 Mtetra
.087 0 0 r
.10733 .35793 .11654 .35299 .12687 .34981 .11756 .35591 Mtetra
.18 0 0 r
.11756 .35591 .12687 .34981 .13715 .34745 .1278 .35427 Mtetra
.246 0 0 r
.1278 .35427 .13715 .34745 .14734 .34617 .13804 .35312 Mtetra
.261 0 0 r
.13804 .35312 .14734 .34617 .15753 .3454 .14832 .35211 Mtetra
.248 0 0 r
.14832 .35211 .15753 .3454 .16777 .34483 .15867 .35104 Mtetra
.184 0 0 r
.15867 .35104 .16777 .34483 .17815 .34347 .16914 .34937 Mtetra
.079 0 0 r
.16914 .34937 .17815 .34347 .18875 .34057 .17979 .34667 Mtetra
0 0 0 r
.17979 .34667 .18875 .34057 .19961 .33573 .19061 .34275 Mtetra
.19061 .34275 .19961 .33573 .21073 .32856 .20163 .33742 Mtetra
.20163 .33742 .21073 .32856 .22204 .3197 .21278 .33103 Mtetra
.21278 .33103 .22204 .3197 .23348 .30958 .22404 .32384 Mtetra
.08 0 0 r
.22404 .32384 .23348 .30958 .24494 .29913 .23535 .31638 Mtetra
.167 0 .053 r
.23535 .31638 .24494 .29913 .25638 .28905 .24666 .30903 Mtetra
.233 0 .125 r
.24666 .30903 .25638 .28905 .26776 .27971 .25797 .30207 Mtetra
.285 0 .176 r
.25797 .30207 .26776 .27971 .27906 .27143 .26926 .29568 Mtetra
.319 0 .21 r
.26926 .29568 .27906 .27143 .29031 .26411 .28053 .28983 Mtetra
.344 .002 .233 r
.28053 .28983 .29031 .26411 .30151 .25769 .2918 .28452 Mtetra
.361 .022 .249 r
.2918 .28452 .30151 .25769 .31269 .25201 .30307 .27963 Mtetra
.373 .036 .259 r
.30307 .27963 .31269 .25201 .32387 .24691 .31437 .27505 Mtetra
.38 .045 .265 r
.31437 .27505 .32387 .24691 .33506 .24223 .32569 .27068 Mtetra
.385 .05 .269 r
.32569 .27068 .33506 .24223 .34627 .23785 .33706 .26644 Mtetra
.387 .052 .271 r
.33706 .26644 .34627 .23785 .35752 .23367 .34846 .26225 Mtetra
.388 .053 .271 r
.34846 .26225 .35752 .23367 .36881 .22967 .35992 .25811 Mtetra
.39 .055 .271 r
.35992 .25811 .36881 .22967 .38013 .22598 .37141 .2541 Mtetra
.393 .056 .27 r
.37141 .2541 .38013 .22598 .39148 .22272 .38295 .2503 Mtetra
.398 .058 .269 r
.38295 .2503 .39148 .22272 .40286 .22004 .39452 .24682 Mtetra
.403 .059 .265 r
.39452 .24682 .40286 .22004 .41428 .21811 .40614 .24376 Mtetra
.409 .061 .26 r
.40614 .24376 .41428 .21811 .42573 .2171 .41779 .24124 Mtetra
.415 .059 .25 r
.41779 .24124 .42573 .2171 .43723 .21706 .42949 .23928 Mtetra
.42 .054 .235 r
.42949 .23928 .43723 .21706 .44878 .21811 .44125 .2379 Mtetra
.418 .039 .209 r
.44125 .2379 .44878 .21811 .46041 .21993 .45307 .23692 Mtetra
.407 .009 .168 r
.45307 .23692 .46041 .21993 .47213 .22214 .46496 .23608 Mtetra
.376 0 .103 r
.46496 .23608 .47213 .22214 .48396 .22404 .47694 .23496 Mtetra
.307 0 0 r
.47694 .23496 .48396 .22404 .4959 .22467 .48901 .23303 Mtetra
.195 0 0 r
.48901 .23303 .4959 .22467 .50794 .22359 .50116 .23003 Mtetra
.026 0 0 r
.50116 .23003 .50794 .22359 .52007 .22013 .51338 .22558 Mtetra
0 0 0 r
.51338 .22558 .52007 .22013 .53225 .21468 .52566 .21988 Mtetra
.52566 .21988 .53225 .21468 .54447 .20764 .53797 .21312 Mtetra
.53797 .21312 .54447 .20764 .55671 .19978 .55032 .20573 Mtetra
.55032 .20573 .55671 .19978 .56899 .19211 .5627 .19826 Mtetra
.5627 .19826 .56899 .19211 .5813 .18496 .57511 .19092 Mtetra
.57511 .19092 .5813 .18496 .59367 .1789 .58756 .18408 Mtetra
.58756 .18408 .59367 .1789 .60611 .17369 .60006 .17762 Mtetra
.60006 .17762 .60611 .17369 .61862 .16919 .61262 .1715 Mtetra
.345 .804 .688 r
.61262 .1715 .61862 .16919 .6312 .16504 .62522 .16553 Mtetra
.485 .9 .834 r
.62522 .16553 .6312 .16504 .64384 .16082 .63787 .15951 Mtetra
.6 .944 .931 r
.63787 .15951 .64384 .16082 .65653 .15641 .65056 .15336 Mtetra
.678 .937 .966 r
.65056 .15336 .65653 .15641 .66926 .15157 .66329 .14695 Mtetra
.713 .902 .963 r
.66329 .14695 .66926 .15157 .68203 .14641 .67604 .14032 Mtetra
.728 .86 .943 r
.67604 .14032 .68203 .14641 .69484 .14096 .68883 .13349 Mtetra
.731 .818 .919 r
.68883 .13349 .69484 .14096 .70769 .13525 .70165 .12647 Mtetra
.476 .691 .962 r
.01926 .36808 .02714 .37496 .03691 .3734 .02889 .36748 Mtetra
.462 .72 .98 r
.02889 .36748 .03691 .3734 .04675 .37166 .03859 .36676 Mtetra
.44 .748 .993 r
.03859 .36676 .04675 .37166 .05667 .36975 .04837 .36593 Mtetra
.405 .77 .994 r
.04837 .36593 .05667 .36975 .06667 .36763 .05822 .36499 Mtetra
.353 .78 .973 r
.05822 .36499 .06667 .36763 .07675 .36527 .06814 .36393 Mtetra
.277 .764 .914 r
.06814 .36393 .07675 .36527 .0869 .3628 .07814 .36276 Mtetra
.187 .719 .819 r
.07814 .36276 .0869 .3628 .0971 .36029 .08821 .36147 Mtetra
.102 .655 .706 r
.08821 .36147 .0971 .36029 .10733 .35793 .09835 .36006 Mtetra
0 0 0 r
.09835 .36006 .10733 .35793 .11756 .35591 .10857 .35853 Mtetra
.10857 .35853 .11756 .35591 .1278 .35427 .11886 .35688 Mtetra
.11886 .35688 .1278 .35427 .13804 .35312 .12922 .35512 Mtetra
.12922 .35512 .13804 .35312 .14832 .35211 .13964 .35323 Mtetra
.179 .713 .751 r
.13964 .35323 .14832 .35211 .15867 .35104 .15014 .35122 Mtetra
.268 .774 .843 r
.15014 .35122 .15867 .35104 .16914 .34937 .16071 .34908 Mtetra
.317 .802 .884 r
.16071 .34908 .16914 .34937 .17979 .34667 .17135 .34682 Mtetra
.296 .792 .854 r
.17135 .34682 .17979 .34667 .19061 .34275 .18206 .34444 Mtetra
.185 .714 .72 r
.18206 .34444 .19061 .34275 .20163 .33742 .19283 .34194 Mtetra
.009 0 0 r
.19283 .34194 .20163 .33742 .21278 .33103 .20367 .3393 Mtetra
.176 0 0 r
.20367 .3393 .21278 .33103 .22404 .32384 .21458 .33654 Mtetra
.279 0 .023 r
.21458 .33654 .22404 .32384 .23535 .31638 .22556 .33366 Mtetra
.335 0 .136 r
.22556 .33366 .23535 .31638 .24666 .30903 .23659 .33064 Mtetra
.367 0 .203 r
.23659 .33064 .24666 .30903 .25797 .30207 .2477 .3275 Mtetra
.386 .036 .244 r
.2477 .3275 .25797 .30207 .26926 .29568 .25887 .32423 Mtetra
.396 .057 .269 r
.25887 .32423 .26926 .29568 .28053 .28983 .2701 .32083 Mtetra
.403 .071 .285 r
.2701 .32083 .28053 .28983 .2918 .28452 .28139 .3173 Mtetra
.407 .08 .295 r
.28139 .3173 .2918 .28452 .30307 .27963 .29274 .31364 Mtetra
.408 .084 .302 r
.29274 .31364 .30307 .27963 .31437 .27505 .30416 .30985 Mtetra
.409 .087 .305 r
.30416 .30985 .31437 .27505 .32569 .27068 .31563 .30592 Mtetra
.408 .087 .307 r
.31563 .30592 .32569 .27068 .33706 .26644 .32717 .30187 Mtetra
.407 .086 .307 r
.32717 .30187 .33706 .26644 .34846 .26225 .33876 .29768 Mtetra
.405 .085 .306 r
.33876 .29768 .34846 .26225 .35992 .25811 .35041 .29335 Mtetra
.403 .082 .305 r
.35041 .29335 .35992 .25811 .37141 .2541 .36212 .2889 Mtetra
.399 .079 .302 r
.36212 .2889 .37141 .2541 .38295 .2503 .37388 .28431 Mtetra
.395 .073 .297 r
.37388 .28431 .38295 .2503 .39452 .24682 .38569 .27959 Mtetra
.389 .064 .289 r
.38569 .27959 .39452 .24682 .40614 .24376 .39756 .27473 Mtetra
.38 .051 .277 r
.39756 .27473 .40614 .24376 .41779 .24124 .40948 .26974 Mtetra
.367 .031 .257 r
.40948 .26974 .41779 .24124 .42949 .23928 .42145 .26461 Mtetra
.347 .001 .228 r
.42145 .26461 .42949 .23928 .44125 .2379 .43348 .25935 Mtetra
.315 0 .179 r
.43348 .25935 .44125 .2379 .45307 .23692 .44555 .25396 Mtetra
.26 0 .1 r
.44555 .25396 .45307 .23692 .46496 .23608 .45767 .24843 Mtetra
.164 0 0 r
.45767 .24843 .46496 .23608 .47694 .23496 .46984 .24276 Mtetra
0 0 0 r
.46984 .24276 .47694 .23496 .48901 .23303 .48205 .23696 Mtetra
.48205 .23696 .48901 .23303 .50116 .23003 .49431 .23102 Mtetra
.497 .906 .832 r
.49431 .23102 .50116 .23003 .51338 .22558 .50661 .22494 Mtetra
.602 .947 .92 r
.50661 .22494 .51338 .22558 .52566 .21988 .51896 .21873 Mtetra
.631 .952 .936 r
.51896 .21873 .52566 .21988 .53797 .21312 .53134 .21239 Mtetra
.617 .952 .92 r
.53134 .21239 .53797 .21312 .55032 .20573 .54377 .20591 Mtetra
.572 .94 .875 r
.54377 .20591 .55032 .20573 .5627 .19826 .55624 .19929 Mtetra
.521 .916 .82 r
.55624 .19929 .5627 .19826 .57511 .19092 .56874 .19254 Mtetra
.485 .893 .776 r
.56874 .19254 .57511 .19092 .58756 .18408 .58128 .18565 Mtetra
.493 .897 .777 r
.58128 .18565 .58756 .18408 .60006 .17762 .59385 .17863 Mtetra
.537 .922 .814 r
.59385 .17863 .60006 .17762 .61262 .1715 .60646 .17147 Mtetra
.607 .954 .874 r
.60646 .17147 .61262 .1715 .62522 .16553 .6191 .16417 Mtetra
.675 .968 .924 r
.6191 .16417 .62522 .16553 .63787 .15951 .63178 .15675 Mtetra
.723 .955 .948 r
.63178 .15675 .63787 .15951 .65056 .15336 .64448 .14919 Mtetra
.749 .924 .948 r
.64448 .14919 .65056 .15336 .66329 .14695 .65721 .14149 Mtetra
.759 .888 .936 r
.65721 .14149 .66329 .14695 .67604 .14032 .66997 .13366 Mtetra
.761 .852 .919 r
.66997 .13366 .67604 .14032 .68883 .13349 .68275 .1257 Mtetra
.759 .819 .9 r
.68275 .1257 .68883 .13349 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Sooooo`03ol;Ai_l0003ooooo01Gooooo00?o
0000ooooooooool0DOooool0063ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`0Mooooo`?o00000_ooool00ol0003oooooooooo`1Oooooo`?o`]7V00?o
0000ol;Ai_ooool05Oooool00ol0003oooooooooo`1@ooooo`00H?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol0000Looooo`;o0000IOooool00oo2f^_o`]7Vol;AiP02ol;AiP03o`000?nk
dN_ooooo01Cooooo00?o0000ooooool00000DOooool0063ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0001[ooooo0ol0001Vooooo`?o`][[0oo2dNH00ol0003o^m7[
ok_Aj`0Fooooo`03o`000?oooooooooo04oooooo001Pooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool0000Hooooo`;o0000J?ooool5ol;Jj`03ol;Ai_nkdN_o000000?o
^m7[5_ooool00ol0003oooooooooo`1>ooooo`00H?ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l000005Oooool3o`0000;ooooo00?o0000ooooooooool0Hoooool2ol;Sk`Co
`][[0_njg?401OnkdN_o0000ok_AjonkdN_o/<k_01Kooooo00?o0000ooooooooool0C_ooool0063o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000001?ooooo0_l0001Yoooo
o`Go`^?_00?o`][[ok[LlOnjg?400onjg?400ol0003o/<k_ok3>k`02ok3>kaKooooo00?o0000oooo
ooooool0COooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo
00oooooo0ol0001Yooooo`;o_ncb1?o2hnl2okKVmPCo^]ca00?o[MSfo`000?n`c^l01?n`c^lFoooo
o`03o`000?oooooooooo04cooooo0022ooooo`;o0000Joooool4oko/lP03ol;Skonfi_Ko]^Kf00?o
]^Kf00Ko^]caojgHm_n]f?Ko[MSfo`000?n]f?H2ok3>k`;oY<Sb5_ooool00ol0003oooooooooo`1<
ooooo`00Ooooool3o`0000;ooooo00?o0000ooooooooool0Ioooool4oko/lP?o[Nog0_nfi_H2ojKR
n`Co[MSf00?o0000oik@nOnTb?801?nTb?8Dooooo`?o0000COooool007cooooo0ol0001]ooooo`?o
^OCb00?o_ncbojg_mon]koL00_n]koL00onFj?[oY^;kojKRn`03ojKRn`04ojgHm_nNd?WoW]3io`00
00;oW]3i1?nTb?8Gooooo`03o`000?oooooooooo04[ooooo001jooooo`;o0000K_ooool4okWdlP;o
VO7^00?o[NogoiKXn_nFj?X00onFj?X2ojKRn`?oUMOn0onNd?T01?l0003oW]3iojC8l_nTb?83oiRo
laKooooo00?o0000ooooooooool0B_ooool007Oooooo0ol0001^ooooo`?o[?O/00?o^OCboiWak_nI
lNh01?mhhn/2oiKXnPCoQM[n1?nEeoh2oik@n@03o`000?nC`oOoTl?g00GoV;oc5_ooool00ol0003o
ooooooooo`19ooooo`00MOooool2o`0000;ooooo00?o0000ooooooooool0J_ooool4ojcgk004ogcV
eOmCclWoDlo9oe??b@;oN>?[1?mXeOD2ohGJoP?oP<Kn1?n;a_/00onC`oOo0000oi?3m`02oi?3m`;o
V;oc0_n@^?8Gooooo`03o`000?oooooooooo04Sooooo001booooo`?o00001Oooool00ol0003ooooo
ooooo`1Wooooo`?oVoCO00?o[?O/ogcVeOlQ[;@00_lQ[;@2odK7g0?oG/;l1?m^a?l5oh36oPCoRlKk
00Co0000oi?3mon=^??oSKSc1On@^?8Fooooo`03o`000?oooooooooo04Sooooo001`ooooo`;o0000
L?ooool01?l0003oVoCOoi_dgonKm=l4ocnnj@CoBKgd1?mN`_`4ofk4o`;oP<Kn0_n1]?H4ohRgm003
o`000?n=^??oSKSc00;oSKSc1On@^?8Fooooo`03o`000?oooooooooo04Oooooo000hooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000Pooooo`?o0000K_ooool4o`0000;o
VoCO0omb^_`4ofV^n@CoIjWg1?m`[?H4ogN_mPCoPKCf0on8]o@00ol0003oR;Odohfhl`03ohfhl`;o
T;Sb0_n=/^lEooooo`?o0000B?ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A401kooooo0_l00003ooooo`03o`000?oooooooooo
06Sooooo1Ol00002ohW/d0;oQ<_n1?mb^_`4ofV^n@CoIjWg1?m`[?H4ogN_mPCoPKCf0_n8]o@00ol0
003oRj[Zohf_k@04ohf_k@CoSK;_5_ooool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`0Yooooo`00>?ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h07?ooool3o`0006kooooo00?oI]B^
o`000?l000000_l00002ohW/d0CoSICF1?n2SmL4ogb=f@CoNXkK1?mnUMl4oh:Lh`CoQjCW0_n;Z^X0
0ol0003oRj[Zoh^ZjP05ohf_k@CoSK;_5_ooool00ol0003oooooooooo`05ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0:_ooool003Sooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Sooooo0ol0001`ooooo`Co00000_mn
iLH3oifLd`CoSICF1?n2SmL4ogb=f@CoNXkK1?mnUMl4oh:Lh`CoQjCW00?oRj[Zo`000?n;Z^X00_n;
Z^X2ohf_k@;oTZ_W1OnA/>`Fooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooo
oa0@400;ooooo`Go0000:oooool003Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMg
MomVIVKooooo01Gooooo0ol0001`ooooo`Co00000_mniLH00onXXLooWIcCoifLd`02oifLd`CoSICF
1?n2SmL4ogb=f@CoNXkK1?mnUMl5oh:Lh`CoQjCW00Co0000oh^Zj_nAY>;oTJCR1OnBZnL5oi6`k1Go
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgM
gOoooooo0000;?ooool003Sooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooo
oooo017ooooo0ol00003ooooo`03o`000?oooooooooo06_ooooo1?l00002ogcTaP?oZ:7?1OnMW=<4
ohfDePCoPXoG1?mlSMT4ogZ>f`CoOYGO0_n2W><2ohbCe@CoSicL00?o0000oi6Th_nAY>800_nAY>85
oi:[i`;oTK3/0_nH/NTFooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0002cooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@017ooooo0_l0001booooo`Co00000_mli<H2ok2RbPCo
Z:7?0_nMW=<2oiR5_@CoSX2o1?n7OL84ohEna@CoQ8?91?n9Rll5ohbCe@?oSicL00?o0000oi6Th_nA
Y>800onAY>82oi:[i`;oVZ[R1OnH/NTFooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03ogMgMoo<c<co000002cooooo000hooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00kooooo0ol00019ooooo`03od400?mC003o
D`0000;oD`001?mT0003og@02`?oO@HC0_mN0004ogP001Cooooo1?l00002ohGZd@Co/:;:0onXXLl0
0onQR[coV8FmoiR5_@03oiR5_@CoSX2o1?n7OL84ohEna@CoQ8?91?n9Rll4ohbCe@?oSicL00Co0000
ohnLg?nAY>;oTJCR0_nJX]X5oiZZhPGoV;7Y5?ooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0<ooooo`03onk^k_m4A4Co000002cooooo001Iooooo`?o0000Aoooool00ol`003o@@00od40
0002od4000CoD`000omT0004og@02`CoO@HC0_n231H3ogP000;oN`004?ooool4o`0000;oQN[A0_n^
W/L5ok2RbP03ojRQconQR[coXHZl00GoV8Fm1?n>P;l4ohMm`PCoQGk51?n4PlT4ohV;c`GoS9?E0_n?
W=`00ol0003oV9WBoiZRfP04oiZRfPGoVZ[R0_nH/NT2oj6eia?ooooo00Co0000oooooooooooo0000
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0:oooool005Kooooo
0ol00003ooooo`03o`000?oooooooooo047ooooo00?o8@00oc000?l`00001?m10004oe<000?oI000
1?md00/5ogd64`?oPP`F00?oN000og/00?mk00000omk000<ooooo`04o`P00?l0003o0000o`0000;o
T_3O1?n^W/L4ok2RbP03ojV>^OnQR[coXHZl00;oXHZl1?nHQKd4ohj0_`CoQgg21?n5O/D4ohB3b@Go
RH_?0_n<TmD2oiJ?bP;oV9WB00?o0000oiRId_nHVM801?nJX]X4oiZZhP03ojB_gonQ]NOoXKGW00?o
XKGW5_ooool00ol0003oooooooooo`10ooooo`00E?ooool2o`0004Kooooo00Ko5@00ob400?lQ003o
8@00oc000?mN02h4of<2<0CoJ@Ha0om_2c44ogD?<P?oNA0_0_mm1Q<4oh8<5P?oP0PB0_mk0005ofX0
00?oBP000oooool3o`P000;o00000_nBl=l00onUU<Co[Yk7ojjNa`03ojjNa`03ok2Rb_nYS[WoZHji
00;oZHji0onQR[`5oiR5_@CoSX2o1?n7OL84ohEna@CoQ8?90_n9Rll2oi:6``GoUXo:00CoV9WBo`00
0?nHVM;oV9WB1OnJX]X00onJZ^;oY:oOojB_g`02ojB_g`CoXKGW5_ooool00ol0003oooooooooo`10
ooooo`00DOooool3o`0004Gooooo00Co2`00oaD00?lE003o8@000_mK02d3oeh0;PCoH`8`1?mY1S43
ofl;<@CoM@lb1?mi42l2ogX?:P?oPP`F1?n02183og801P;oJP001?m:00000ol;003o<000o`P00002
o`P000;o00000_nBl=l2ojFDa0Co[Yk700?oZHfhojV>^OnYS[T00onYS[T3oj6:_0GoV8Fm1?n>P;l2
ohMm`P;oS7Fd1?n<N;P4ohim_0GoTXK31?nFSlX00onHVM;o0000oiRIdP02oiRIdP;oVZ;J0_nTYmP5
ojB_g`;oXKGW0onZ^nHFooooo`03o`000?oooooooooo03oooooo001>ooooo`Go0000@oooool3o`/0
0003oaD00?mH02coF`0]00?oF`0]0_mN02h4of<2<0CoJ@Ha0om_2c44ogD?<PGoNA0_0omj3bX00on2
31KoP0PBoh084P03oh084PCoLP060omJ0004oc000003o`P00?l<003o000000;oWO?[1?nUU<@3ojjN
a`;oZHfh1OnYS[T4oj6:_0?oV8Fm00?oUWZbohmf/_n?M[800_n?M[84ohae]0GoS7Rh1?n>OK`4oi:6
``GoUXo:00Co0000oiRId_nTWm3oY9o@1OnTYmP3ojB_g`03ojfgh?nZ^nKoZ[_V00CoZ[_V5_ooool0
0ol0003oooooooooo`0nooooo`00C?ooool2o`0000Gooooo00?o0000ooooooooool0?_ooool01?l6
003o2`00oeD0;?mE02`3oeP0;0?oF`0]0omN02h4of<2<0?oJ@Ha1?m_2c44ogD?<PCoNA0_1?mj3bX3
ogH78@;oP0PB1?mb00H3oeX000Co<0000_l<0002oigcj`;oUhS11OnUU<@00on^W/OoZHfhojV=^002
ojV=^0GoZHji0onQR[`01?nHQKgoUWZboiIj/_nFN[84ohmf/PGoS7Fd1?n<N;P4ohim_0CoTXK31?nF
SlX00onRUlWo0000ojBOd003ojBOd0GoY:OH00CoY:oOojfgh?n]]n3o[KOP1?nZ^nH00on``>Gooooo
ooooo`0Dooooo`03o`000?oooooooooo03kooooo0019ooooo`?o0000A_ooool00ol2003oD`0[oeD0
;003oeD0;0;oF00/1?mK02d3oeh0;PCoH`8`0omY1S44ofl;<@CoM@lb0omi42l5ogX?:PCoMPLQ1?mY
0103oe<000Co;`0000Co3000oj7ckonQlnooQGRm0onGR<44ojFDa003ojF8]_nYSKSoZHfh00?oZHfh
1OnYS[T2oj6:_003oieo/_nFN[;oUWZb00?oUWZb1?n?M[84ohae]0CoS7Rh1?n>OK`5oi:6``03oiJ?
b_nRUlWoXYO900;oXYO900Co0000ojBOd?nTWm3oY9o@1?nTYmP00on_/][o[KOPojfgh003ojfgh003
ojZki_n``>Go/<3U00;o/<3U5?ooool3o`0003oooooo000Rooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h08?ooool2o`0004Gooooo00Co0000o`800?l2003o0P000_mC02/3oeD0;0?oF00/0omK02d3oeh0
;P;oH`8`0_mW3d<3ofP?@PCoJPlo1?m[3C`3of/9=@03ogT@;omj3b[oNPlZ00;oNPlZ1Omf1b44ofT0
40?oD`000ol_0002oj7ck`?oQGRm1?nGR<400onUU<CoYHRfojF8]P02ojF8]PCoZHfh1?nYS[T00onV
Q[;oWGnboieo/P02oieo/PCoUWZb1?n?M[84ohae]0GoS7Rh1?n>OK`2oi:6``;oWXk21OnRUlT00ol0
003oY9o@ojBOd002ojBOd003ojBWf?n_/][o[k;J00;o[k;J0on]]n000ond_^;o/<3Uok30i@04ok30
iAGooooo00?o0000ooooooooool0?Oooool002;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Moooo
o`?o00000_ooool00ol0003oooooooooo`0oooooo`?o000000?o0P00oe80:_mB02X00_mC02/4oeD0
;0?oF00/0omK02d00omN02koI@i4ofD>A004ofL?@`?oJ0m21?mZ3cl4of/=?0?oJ`Te0omX0R/2ogX?
:PCoMPLQ1?mY0103oe<00004obl00?l6003oV_;[oi[bj`;oO6fg1?n5N;d2oiN8`@03oi^0]?nUR;Ko
YHRf00?oYHRf1OnYSKP2ojV>^@;oYXJb1?nMOk84oiIj/PCoSgJb1On<MK@4ohah^0;oSWfl0_nIQK`5
oij>`PCoXYO900Go0000ojBOd?nTWm3oY9o@ok2/e005ojnbfP03ojfgh?nd_^;o];kR00;o];kR1?n`
`>D2okG5iQGooooo00?o0000ooooooooool0??ooool002;ooooo00Go410@oooooooooooooooooa0@
400Kooooo`;o0000A_ooool2o`000003odl0:?mB02[oDP0Z00;oDP0Z0_mC02/3oeD0;0?oF00/0_mK
02d00omT3TGoI@i4ofD>A002ofD>A0?oI`m31?mX3d83ofX??`CoJ`dl1?m[2CD4ofP2:`CoH00J0om>
0002ofT04003oe<00?la003o1P0000;oV_;[1?mlKKL2ohEh_@;oSWBb0onKP;@5ojF8]PGoZHfh00?o
ZHjiojJ6/_nVQ[800_nVQ[84oieo/P?oUWZb1On?M[84ohae]0;oS7Rh0_nFO[L5oiV5_0CoWXk21?nR
UlT00ol0003oY9o@ok2/e003ok2/e0?o[k;J00?o]kgNokBnh_nd_^801?nd_^800on``>Go]LGVokG5
iP03okG5iQGooooo00?o0000ooooooooool0>oooool002;ooooo00Go0000ooooooooooooooooo`00
000Hooooo`?o0000A_ooool3o`0000;oC`0X0omB02X3oe<0:`?oE@0/00?oF00/of<>AOmS3TD00omT
3TD3ofD>A0CoI`m30omX3d84ofX??`CoJ`dl0om[2CD5ofP2:`CoH00J0om>0003oc400004ogoWe?n6
J:WoQVRYohIXZ@CoR6f^1?n>M;84oi^0]0GoYHRf0onYSKP00onYRKCoYXJbojJ6/P03ojJ6/PCoWGnb
1?nFN[84ohmf/P;oS7Fd0_nBN;<4oiIn]`GoVHFl1?nNS/84oj:Gb@03o`000?n`[=Co/:cD00?o/:cD
00?o[k;JokNmg_ng_Mh00_ng_Mh4okBnhP;o^<OU1?neaNH00onfb>Soooooooooo`0Cooooo`03o`00
0?oooooooooo03_ooooo000Rooooo`05o`000?ooooooooooooooool000005_ooool3o`0004Kooooo
0_l00002od/09@;oC`0X1?mB02X2oe<0:`;oE@0/00?oH`e5of<>AOmS3TD00_mS3TD3of@>A@?oI@i4
1?mW3d<3ofP?@P?oJPlo1?m[3C`4of/9=@CoJ08[1?mP01X3odh00004oc400?l0003oRfVUoh]YY@Co
QVRY1?n8KJh5ohid/P?oVh2d1OnUR;H01?nYSKSoZHVdojV9]?nYRK@5ojJ6/PCoWGnb1?nFN[82ohmf
/P;oTgNa1?nBN;<5oiIn]`CoVHFl1OnNS/801OnRUlWo/:K>ok2Vc_l0003o/:K>00?o/:cD00?o^[_K
okNmg_ng_Mh01?ng_Mh00ond_^;o^<OUokS7i@03okS7i@03okG5i_nfb>So]/SX00;o]/SX5Oooool0
0ol0003oooooooooo`0jooooo`008_ooool01Ol@413ooooooooooooooooo410@01?ooooo0ol00002
ooooo`03o`000?oooooooooo04;ooooo00?o0000od@08Om;02D00om;02D2odl0:0?oDP0Z0_mC02/4
of<=A@?oH`i50omT3TD4ofD>A0?oI`m31?mX3d83ofX??`CoJ`dl1?m[2CD4ofP2:`CoH00J00CoCP00
o`000?nBJj;oTV^R1?n;JJD4ohIXZ@CoR6f^1?n>M;83oi^0]0CoYHRf00?oZ8ZeojV9]?nYRK@00onY
RK@4ojJ6/PGoWGnb0_nFN[800onEN;3oTgNaoi=g/@02oi=g/@GoTWRc1?nFO[L5oiV5_0?oWXk200Go
[Ik8ok2Vc_n`Y/ko/:K>o`000002ok2VcP04ok2/e?nj^m_o^[_KokZkf`Co]kgN0_nlbnD4okS7i@03
okS=jOnfb>So]/SX00?o]/SX5_ooool00ol0003oooooooooo`0iooooo`008_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg013ooooo0ol00019ooooo`03o`000?m4027oA00Q00?oB`0U0om?02P3oe80:PGo
H`e51?mS3TD3of@>A@?oI@i41?mW3d<4ofP?@P?oJPlo1?m[3C`00om[2CGoD00]oe00;@04od806@?o
:@0000?o0000oiM/WonBJj801?nBJj83oh]YY@CoQVRY1?n8KJh4ohid/PCoVh2d0_nUR;H2ojR:]@Go
ZHVd1OnVQ[83oieo/P04oiYk/?nEN;3oUGR`oiEh/0GoTgNa1?nBN;<4oiIn]`GoVHFl00?oWXk2ojfN
b?n]W/P00_n]W/P2ok2VcP03o`000?n`Y/ko_K[G00Go^[_K00?o]kgNokc;iOnlbnD00onlbnD00onh
anGo^<gYokS=j@02okS=j@?o]/SX0_ndb^/Dooooo`;o0000>oooool002;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0>ooooo`;o0000B_ooool01?l0003o?00Lod@08Om40244od/09@;oC`0X0_mB02X0
0omR34CoH`e5of<=A@04of<=A@CoH`i50omT3TD3ofD>A0CoI`m30omX3d82ofX??`03oed7@OmH03[o
F00j00;oF00j1?m@02d4od806@;o:@000onGK9l5oi9[XP?oRfVU1?n6J:T4ohQ][PCoSWBb1?nKP;@0
0onUR;KoZ8ZeojR:]@02ojR:]@CoZHVd1OnVQ[801?nMOk;oVW^`oiYk/?nJNk04oiEh/0CoTgNa1?nB
N;<5oiIn]`?oVHFl00?oZ9K3ojfNb?n]W/P00on]W/P2ok2VcP04o`000?nm^]Oo_K[Gokfje`?o^[_K
0_o2dNH4okc;i@03ok_DkOnhcNWo^<gY00Co^<gY00?o]/SXokC:jondb^/00_ndb^/Eooooo`03o`00
0?oooooooooo03Sooooo000booooo`Go0000B?ooool01?l0003o?00Loc`07?ll01`2od@08@?oB`0U
0_m?02P01?mQ2d?oHPa4of8<A?mR34@6of<=A@?oH`i51?mT3TD3ofD>A0?oI`m30_mX3d82of4=AP?o
G@M11?mH03X3oe00;@Co@P0I00?o:@00oiY/WOnJK9d01?nGK9l4oi9[XP?oRfVU1?n6J:T4ohQ][PGo
SWBb0_nKP;@00onSQ[KoZ8ZeojR:]@03ojR:]@GoZHVd0onVQ[800onQP[7oVW^`oiYk/003oiYk/0?o
UGR`1?nCMk45oi9h/`CoUWjg00?oVHFlojRF`onXU/<00_nXU/<5ojfNb0;o00000onm^]L00onj^m_o
`]7Vol;AiP03ol;AiP03okc;iOnke>go^mC]00;o^mC]1?nhcNT00onddNoo]<[[okC:j`02okC:j`03
ojo9k_oooooooooo01Cooooo00?o0000ooooooooool0=oooool0033ooooo0_l0001<ooooo`04o`00
0?ll01co?00Loc`070;oA00Q1?m;02D3of4;@`;oHPa41_mS3DD4of<>A@CoI0i50_mU3T@2ofL?@`;o
Ha191?mQ3DH3oed7@@CoF00j0om@02d3od806@04oiA/XOnJK9goVVbMoiY/W@CoUfbO1?nBJj83oh]Y
Y@CoQVRY1On8KJh4ohid/P04oi^0]?nSQ[KoXhJfoj>6]PCoZ8Ze1OnYRK@01?nVQ[;oXH:aoj62/OnQ
P[45oiYk/0?oUGR`1?nCMk45oi9h/`;oUWjg0_nSSKd5ojRF``;o[Ik80ol000000onm^]Oo0000okfj
e`02okfje`Go`]7V0_nngo05ok_Dk@03okS=jOnddNoo]=7_00;o]=7_00?o]<[[ojo9k_n_bNh00_n_
bNhEooooo`03o`000?oooooooooo03Oooooo000]ooooo`?o0000COooool00ol0003o<00Doc`07002
oc`070;oA00Q00?oB`0Uoel9@_mO2D800omQ2d<3of8<A0KoH`e51?mS3TD3of@>A@;oI@i400?oIA9<
of<@BOmS44T00_mS44T3of4=AP?oG@M11?mH03X4oe00;@03od806OnEJiooVF^L00CoVVbM1?nGK9l4
oi9[XPCoRfVU1?n6J:T4ohQ][P;oSWBb0_nHO[D4oj>6]PGoZ8Ze0onYRK@00onUQ[?oXH:aoj62/@03
oj62/@CoVW^`0onEN;05oi=g/@?oTWRc00?oW8Fioj>=_OnSSKd00onSSKd3ojRF``?o00001?nm]m<0
0onm^]Oo0000okfje`02olSIiP?o`]7V1?nngo02ok_Dk@;o]=_d1?nddNl2ojgAl`Go[lW^5Oooool0
0ol0003oooooooooo`0fooooo`00;?ooool2o`0004kooooo00?o0000oc005?ll01`00_ll01`00om4
027oG0Dooel9@P03oel9@P?oH@]30omR34@6of<=A@?oH`i50_mT3TD2ofHDC@?oIA9<0omS44T4of4=
AP?oG@M11?mH03X3oe00;@04od806OnIJicoVF^LoiU[W0CoVVbM1?nGK9l5oi9[XP?oRfVU1?n6J:T2
ohQ][P;oTgRb1OnHO[D3oj>6]PGoZ8Ze00CoZHVdojF6/onUQ[?oYHJc1OnQP[44oiYk/0CoUGR`1?nC
Mk400onBN;?oW8Fioib5^@02oib5^@CoXhfm0ol000000onXU/?o^k7@okfgd`05okfgd`03okfjeol0
003ob=WV00;ob=WV00?o`]7VokkOl?nngo000_nngo000on`ioSo]=_dokCKm003okCKm003okCAkon]
dO?o[M7c00?o[M7c0_n_bNh3ojO7l1Gooooo00?o0000ooooooooool0=Oooool002cooooo0ol0001;
ooooo`04o`000?lQ00Wo<00Doc0050?o?00L0_mL1Cl3oel9@PCoH@]30_mR34@6of<=A@;oH`i50_mW
54h4ofHDC@?oIA9<0omS44T4of4=AP?oG@M11?mH03X2oe00;@03oiEZW_nIJicoVF^L00;oVF^L1?nJ
K9d4oiM/W`GoTV^R0_n;JJD00onGM:WoTGB^oi5d[P02oi5d[PCoTgRb1OnHO[D4oj>6]P?oZ8Ze00?o
YXRdojF6/onUQ[<00onUQ[<4oj62/@GoVW^`0onEN;02oi=g/@;oVGnf1OnLQKT01?nSSKgo0000o`00
0?l00003ojRF``?o^k7@1?nm]m<01Oo<h^Sob=WVolSIi_l0003ob=WV00?o`Nkb00?o_]o`ok3Wn?n`
ioP00_n`ioP2okCKm0CoZ=Wi0_n]dO<3oj?=mPGoYlO`5?ooool00ol0003oooooooooo`0eooooo`00
;?ooool01?l0003oooooo`000?l00019ooooo`04o`000?lQ00Wo8@09oc0050;o?00L00?oF00koe`5
?omL1Cl01?mO2D83of4;@`?oHPa41OmS3DD00omW5DkoIaA>ofLDCP02ofLDCPCoIQA=0_mU4T`4of<@
B@?oH@e61?mM1d43oeP0>P04oe00;OnEJYkoUFZNoiMYV`GoVF^L1?nJK9d4oiM/W`CoTV^R00?oRfVU
oiMdZOnGM:T01?nAM:h5oi=h/PCoV7je1?nSQ[H01?nXR[GoYXRdojJ8]?nVR;@5ojF6/`CoXH:a1OnJ
Nk02oiEh/003oiQm]?nIOkKoVGnf00?oVGnf0_nLQKT3o`0000CoXhfm00?oZ9K3ok^ad?nk/M000_nk
/M03okfgd`?oc>;X00?ob=WVo`000?o1k_800_o1k_83oj;al`;o/>Oh0_nMhOd4ojSIn@;oW=;k1OnS
cOH2ojO7l0;oW/7a4oooool00ol0003oooooo`000008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c00Iooooo`00;?ooool2o`0000;ooooo
00?o0000ooooooooool0AOooool00ol0003o8@09ob402@02oc0050?oF00k0_mL1Cl4oel9@P?oH@]3
0omR34@2of<=A@04ofPFC_mW5DkoIaE>ofLECPCoIaA>0omV54d3ofDBC0?oHa191?mQ3DH3oed7@@;o
F00j0onDJId00onEJYkoUfVKoiMYV`05oiU[W0CoVVbM1?nGK9l3oi9[XP03oiifYOnGM:WoUgBY00;o
UgBY1?nAM:h4oi=h/PGoV7je0_nSQ[H00onTQkKoYXRdojJ8]003ojJ8]0CoYHJc1OnQP[43oiYk/004
oiYm/onHOKCoV7fdoiQm]0CoVGnf0ol00003oib5^@?oXhfm00?o]Z[=ok^ad?nk/M001?nk/M001?nm
]m?oc>;XolcRj?o<h^P3ok_ik@03o`000?nRlO?oX_7c00;oX_7c00?oQN?hoigQoOnMhOd00onMhOd0
0onXfOWoW=;koicBn`03oicBn`;oXlgf0_nKa?@5oik1lAGooooo00?o0000ooooooooool01Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40
6Oooool002_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`13ooooo`05o`/00?lQ
00Wo8@09oc005?mA03D00omH03/3oe`5?`?oG`U21?mQ2d<2of8<A004of<=AOmX5TkoJ1I>ofPFCP?o
IaE>0omW54h4ofHDC@?oIA9<0omS44T4of4=AP;oG@M10_nCJ9d3oiAYW@03oiEXVonGJI_oUfVK00;o
UfVK1?nIJi`4oiY/W@CoUfbO00CoTV^RoiifYOnNMZGoWWJU1?nGM:T4oi5d[PCoTgRb1OnHO[D00onS
Q[KoY8NfojB7]P05ojJ8]0GoYHJc1?nQP[401?nJNk3oVWfcoiYm/onJOK<4oiQm]004oiUo]_l0003o
0000oiUo]PGoW8Fi00?oXhfmokJZcOnfZ/d00_nfZ/d4ok^ad0?oc^SY00Coc>;Xok_ikOnknNgo^oW]
0_mjiM400ol0003oX_7cohGSn003ohGSn0;oWN7m1?n@doh2oicBn`;oU/Gg1OnKa?@4oik1lAGooooo
00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooo
ooooooooo`00000Iooooo`00:oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo047o
oooo0_l;0002ob402@;oD@0e0omH03/2oe`5?`CoG`U20omQ2d<2of8<A0GoJ1I>0_mW5Dh4ofLDCPCo
IQA=0omU4T`3of<@B@?oH@e600?oG@M1oi=XWOnCJ9d00_nCJ9d01?nDJIgoUFRKoiEXVonEJ9/4oiMY
V`CoVF^L1?nJK9d3oiM/W`03oj5fX_nNMZGoWWJU00?oWWJU0onGM:T4oi5d[PGoTgRb0onHO[D00onM
P[KoY8NfojB7]P02ojB7]PCoYXRd1OnUQ[<2oj62/@;oWX6c1OnJOK<01?nHOKCo0000o`000?l00004
oiUo]P?oW8Fi00?o[j7:okJZcOnfZ/d00onfZ/d3ok^ad0?oc^SY0_nWn=P01_nknNgoN^GAog[UdOmj
iM7oFmCLo`0000?oL<gn1?n0dOl2oi3CoP?oSlCi1?nFaOL4oi_4m0;oW/7a0onI^^lEooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRH
V?lQ8B406Oooool002_ooooo0ol00005ooooo`03o`000?oooooooooo03oooooo0_l;00001?lQ00Wo
B00]oe40=OmA03D4oeP0>`;oG0Do1?mO2D82of4;@`OoJ1I>0omW5Dh4ofLDCP?oIQA=1?mU4T`2of<@
B@;oH@e60onBIi`3oi=XW@03oi=WVonEJ9_oUFRK00;oUFRK1?nGJI/4oiU[W0CoVVbM0_nGK9l2oj5f
XPGoWWJU0onGM:T5oi5d[PCoTgRb00CoV7jeoif2]_nMP[KoWH:f1?nTQkH5ojJ8]0?oYHJc00?oXHBe
oij1/onNPK<00_nNPK<3oiYm/`?o00000_nHOK@5oiUo]P03oib5^On_XL[o[j7:00;o[j7:1OnfZ/d0
1?nk/M3oc^SYolkXjOo>j>T2ojOhf003o`000?mC`OSoGlOk00?oGlOk00?oL<gno`000?n4^?L00_n4
^?L4ohRon@GoSlCi0_nFaOL00onF^>ooUk[`oiNjl003oiNjl0GoVK[_5Oooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<01Wo
oooo000[ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0?Oooool2o`/00003ob40
2Om802goB00]00;oD@0e0omH03/3oe`5?`?oG`U200?oH@]3ofPFC_mX5Th01omX5Th3ofLECP?oIaA>
1?mV54d3ofDBC0;oHa190onAIY`3oi9WW004oi=XWOnCIi_oTfNKoi=WV`CoUFRK1?nGJI/4oiU[W0Co
VVbM00CoUfbOoj5fX_nQMZ;oXGJR1OnNMZD3oiMdZ@GoTGB^0_nCN;82oi]o]0GoWH:f0onTQkH5ojJ8
]004ojF6/onQQ;GoXHBeoj64]@CoWX6c0ol00002oiYm/`CoV7fd0onIOkH00onXVLOo[j7:ojnQbP03
ojnQbPCo]Z[=0oo<kN/00oo>j>WoYoSHoh>Vj`04oh>Vj`CoPZob00?oQ;Sgo`000?n4^?L00_n4^?L4
ohRon@;oSlCi0_nD/nd4oiJhk`GoUk[`0_nI^^l2oiVfk1Gooooo00?o0000ooooooooool00oooool0
1Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool06oooool002_ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0kooooo`03o`000?l;003o2`0000;oB00]0omA03D3
oeP0>`;oG0Do0_mO2D82ofPEC@[oJ1I>0_mW5Dh4ofLDCPCoIQA=0omU4T`00omS44WoTFJLoi5VW002
oi5VW0;oTVNL00?oTVJKoi=WVonCIi/00_nCIi/4oiEXV`CoUfVK1?nIJi`4oiY/W@GoXGJR1?nNMZD4
oiMdZ@?oTGB^00?oW7faoi]o]?nKOk@00_nKOk@5oif2]PCoY8Nf0onVR;@00onTQkKoXHBeoj64]@03
oj64]@?o000000?oWX6coiYm/onJOK<00_nJOK<4oiQm]003oiUo]_nXVLOoZ9W700;oZ9W71On_XLX0
0onfZ/goc>g[olc]j`02olc]j`04oh;S]?n5WN?oQIgSohFMh`GoPjK[1?n2[o801?n4^?Oo0000oi:S
hOnBXn44oi>/j0GoU;?]1?nF^>l2oiNjl0;oVK7Y1OnI]^`Cooooo`?o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P06oooool0013ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0iooooo`03o`000?l;003o2`0000?oB00]0_mA03D4oeP0>`03
oe`5?omX54_oJ1E=00?oJ1E=2_mX5Th2ofLECPCoIaA>0omV54d2ofDBC0?oT6FL0onAIY`01?nAII_o
TVJKoi9VVonBIY/5oi=WV`?oUFRK1?nGJI/5oiU[W0?oVVbM1OnQMZ84oiifY@CoUgBY00CoTGB^oiam
/OnLOK7oW7fa1OnKOk@4oif2]PCoY8Nf00CoYXRdojB7]_nTQkKoY8Nf0_nQQ;D3o`0000CoWX6c1OnJ
OK<2oiQm]003oj>CaOnXVLOoZ9W700?oZ9W71?n_XLX3olK/k`04olc]jon2hkCoP^>dohREf@CoQIgS
0_n3Y^/2oi>@c@CoTYWG00?oTZ?Qo`000?nBXn400_nBXn44oi>/j0CoU;?]0_nF^>l3oiV]i0CoVK7Y
1OnI]^`Eooooo`09o`000?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<
odA4A?l0003o410@6Oooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`04ooooo`?o00002_ooool00ol0003oooooooooo`0gooooo`;o000000?o
2`00oc/07om802d00_m802d2oe40=@?oF00k00?oG0DoofPDBomX54/01?mX5Dd9ofPFCP?oIaE>1?mW
54h2ofHDC@?oSVBL0on@II`01?nAIYcoTFFKoi5UVonAII/3oi9VV`GoTfNK0onEJ9/4oiMYV`GoVF^L
0_nJK9d00onSMZ3oXGJRoj5fXP03oj5fXPGoWWJU0_nGM:T00onSOjgoW7faoiam/@03oiam/@CoVgnd
1OnMP[H2ojB7]P04oj>8^?nTQkKoY8NfojB7]P?o00000onQQ;D5oij1/`CoVWfc00CoV7fdoj>CaOnS
TlGoXi?51?nXVLL3ojnQbP?oa^c_0_l00002ohREf@03oiB0^onCQlCoThO400;oThO41OnCT<d4oi:I
e`03oi:ShOl0003oTZ?Q00;oTZ?Q0_nC[>P00onKXMSoVZOOoiZWg`03oiZWg`GoVJgT1?nI/NT2oiVf
k0;oWKCX5Oooool00ol0003oooooooooo`0_ooooo`002?ooool6o`0000;ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go00001Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
03Gooooo0ol000001?lk01ooB00]odP0;Om802d3oe40=@03oeP0>omW4TSoIa9800?oJ1A;0omX5Dd:
ofPFCP?oIaE>0omW54h00omV54goSF>MohiTW003ohiTW0;oT6FL00?oSfBKoi5UVonAII/00_nAII/4
oi9VV`CoTfNK1?nEJ9/4oiMYV`CoVF^L00CoVVbMoj=fX?nSMZ3oXgJP1?nQMZ85oiifY@03oiMdZOnS
OjgoXgn]00GoW7fa1?nKOk@5oif2]P04ojB7]_nSR;SoXhRhojB7]P;o00000_nTQkH4oj64]@GoWX6c
0_nJOK<2oj6Aa0CoXi?51OnXVLL01On_XL[oa^c_olK/koo6k>oo000000;oUGZc1?nDP;/4oi>7a0Co
Ti3=1OnBVML01?nBXn7o0000oibJdOnLV]44oi^Qf0GoVZOO0_nI[N@2oinVf`CoWZgR1OnM]>PEoooo
o`03o`000?oooooooooo02kooooo000@ooooo`05o`000?ooooooooooooooool000002oooool01?m4
A4CogMgMooooool00006ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0<oooool2
o`000003obX03Olk01oo>`0O00?oB00]00?oD@0eofD>A?mW4TP00omW4TP2ofPDB`CoJ1E=2_mX5Th2
ofLECP;oIaA>1?n=Hid2ohiTW0;oSF:K0on?I9/4oi5UV`CoTVJK1?nCIi/4oiEXV`CoUfVK0onIJi`0
0onPLiooXgJPoj=fX002oj=fX0CoXGJR1OnNMZD4oj=o[@CoW7fa1OnKOk@3oif2]P03oj27^?nSR;So
000000;o00001?nTQkH5oj64]@?oWX6c00?oXi?5oj6Aa?nQTL@00onQTL@3oj>Ca@CoZ9W70onmjO<0
0oo6k>ooUGZcoiEj/`03oiEj/`?oU82k1?nCQl@5oi>@c@;oTYWG0_nMTlT01?nLV]7o0000oibJdOnL
V]44oi^Qf0CoVZOO00?oX:3DoinVfonOY]/00onOY]/4oij]hP;oWKCX0onV^>HEooooo`03o`000?oo
oooooooo02gooooo000@ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEoooo
ool00006ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<Oooool2o`0000;o:P0=
00?o>`0OodP0;Om802d00_m802d2ofD>A0?oIa980omX54/4ofPEC@[oJ1I>00?oIaE>oheSWOn=Hid0
1?n=Hid00on<HI_oSF:KoheRV`02oheRV`?oSfBK1?nAII/4oi9VV`CoTfNK1?nEJ9/4oiMYV`;oVF^L
0_nPLil4oj=fX0GoXGJR0onNMZD00onZPj[oXgn]oj=o[@02oj=o[@GoW7fa1?nKOk@00onMP[KoX8Nh
o`000002o`0000?oXhRh1OnTQkH4oj64]@03oij1/onSTlGoXi?500;oXi?51?nQTL@4oj>Ca@03ojRI
aonmjO?o_NWc00;o_NWc0_nFMZd5oiEj/`?oU82k1OnCQl@2oi>@c@;oWXg21OnMTlT01?nLV]7o0000
oibJdOnLV]44oi^Qf003oiZWgonPX=CoX:3D00;oX:3D1OnOY]/2oij]hP03ojJbhOnV^>KoY[SV00Co
Y[SV5?ooool00ol0003oooooooooo`0]ooooo`004?ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l000001_ooool2o`0000oooooo0_l0000`ooooo`;o00000_lZ00d2oc/07`;o
B00]00CoHPTnofD>A?mU3TCoI@i40omW4TP3ofPDB`?oJ1E=2_mX5Th01?mW5DkoS6>NoheSWOn=Hid2
oh]PV`?oS66K1?n=HY/4ohmTV`?oTFFK1?nBIY/4oi=WV`CoUFRK1?nGJI/01?nIJicoX7>Ooj1cWonP
Lil4oj=fX0GoXGJR0_nNMZD3ojZ3ZP?oXgn]1OnLOK42oi]o]004oj67^?l0003o0000o`0000?oX8Nh
0onSR;P5ojB7]P;oXHBe0_nUV<L5oj>Ca@CoXI740onSTlD3ok7Sn003okgYlonFMZgoUWJ]00?oUWJ]
1?nEN[<4oiB0^`?oThO400?oWhRkoij=`_nNSL800onNSL84oifCb@;oW9[A00Co0000oibJdOnKXMSo
Vj7H0_nRVlh5oj2Pe0CoWjKK00?oYjgKojJbhOnV/^400_nV/^44ojJhiP03ojfni_oooooooooo01?o
oooo00?o0000ooooooooool0;?ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
onk^k_m4A4Co000000Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0/ooooo`04
o`000?lD003o:P0=obX03@?o>`0O0omR2Ch2ofD>A0CoIa980_mX54/4ofPEC@SoJ1I>00CoQejKohUO
Von9Gi_oREnK1?n;H9/3ohaQV`CoSF:K1?n?I9/3oi5UV`CoTVJK1?nCIi/4oiEXV`?oUfVK00?oW72O
oj1cWonPLil00onPLil3oj=fX0GoXGJR00?oWWJUojZ3Z_nZPjX00_nZPjX3oj=o[@CoW7fa00CoYHVg
o`000?l0003o00000_nQQkP4oj27^0CoXhRh0onTQkH00onYWL_oYIS7ojFHa`03ojFHa`CoXi?51OnQ
TL@01?nSTlGo/N?hok7Sn?nahoP3oiMcZ@CoUWJ]1OnEN[<3oiB0^`03oi>7a?nOR;_oWhRk00;oWhRk
1?nNSL85oifCb@;oW9[A00?o0000oj:Kc_nRVlh00onRVlh5oj2Pe003oinVfonW[M_oYjgK00;oYjgK
1?nV/^400onV^>Ko[KkVojfniP02ojfniQ?ooooo0_l0000^ooooo`004?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo02[ooooo00?o0000oa@00?lD00000_lZ00d00olk01ooG@0cof89?P02of89?P?oI@i4
0omW4TP3ofPDB`CoJ1E=1?mX5Th00on5GIcoQejKohMNV`02ohMNV`?oREnK1?n;H9/3ohaQV`CoSF:K
1?n?I9/4oi5UV`?oTVJK1OnCIi/3oiEXV`;oUfVK0_nLL9l5oj1cW`?oXgJP1OnQMZ85ojZ3ZPCoXgn]
00CoW7fao`000?l0003o00001OnQQkP4oj27^0CoXhRh00?oY8NfojVMbonYWL/00_nYWL/4ojFHa`Go
Xi?50_nQTL@4ojSOnP03ok7Sn?nHLJGoUg>Y00;oUg>Y1?nFMZd5oiEj/`;oU82k00?oX8Bfoin8^onO
R;/00onOR;/4oij=`PCoWI?900GoYIC3ojBGb?nTUlSo0000ojBGb005oj:KcP;oX:3D0_nYZ=H5ojN]
f`;oY[;Q0on^^n<4ojfniQGooooo00?o0000ooooooooool0:oooool002Wooooo0_l0000Dooooo`03
o`000?oooooooooo02Sooooo00?o0000oa@00?lD00000_lZ00d3oed0<`?oHPTn0omU3T@3ofLBB0?o
J1A;1?mX5Dd00omX5TkoQEnOohEMW002ohEMW0CoQejK0on9Gi/4oh]PV`CoS66K0on=HY/4ohmTV`Co
TFFK0onBIY/5oi=WV`?oUFRK00CoUfVKoia`WonLL9ooW72O1OnPLil4oj=fX0?oXGJR00?o[XBXojZ3
Z_nZPjX00onZPjX2oj=o[@?o00001?nURKL4oj67^0GoX8Nh0_nSR;P00on[XlooZIg;ojVMb`03ojVM
b`CoYIS71?nSTlD2oj7Oo0CoZ=oj0onHLJD3oiMcZ@GoUWJ]0onEN[<00onQPK7oX8Bfoj24]P02oj24
]PCoWhRk1OnNSL801?nMTlWoYIC3ojFD`onUU<<3ojBGb003o`000?nRVlkoXY_>00;oXY_>00?oZjKA
ojVXe_nYZ=H00onYZ=H3ojN]f`03ok2ihOn^^n?o[[_S00Co[[_S0_n]_^H2ok74j1Gooooo00?o0000
ooooooooool0:_ooool002Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Uoooo
o`;o00000olD00001?lZ00goG@0coed0<omM03<3of89?P?oI@i40omW4TP4ofPDB`?oJ1E=00CoJ1I>
ohEOWon5GiooQEnO0on5GI`3ohMNV`CoREnK0on;H9/4ohaQV`?oSF:K1?n?I9/4oi5UV`CoTVJK1?nC
Ii/2oiEXV`03oiY_X?nLL9ooW72O00?oW72O1?nPLil4oj=fX0;oXGJR0on^Q:P4ojZ3ZP;o000000?o
Xgn]ojj?]OnURKL01?nURKL5oj67^0CoX8Nh00CoXhRhoj^Scon[XlooZj??1?nYWL/5ojFHa`03oj>C
aOnQgocoXMol00?oXMol00?oZ=ojoiQ_XonHLJD00onHLJD3oiMcZ@GoUWJ]00CoUGZcoj61/OnQPK7o
XH6a1?nPQ;H5oin8^`?oWXg200?oYi:oojFD`onUU<<00onUU<<3ojBGb003o`000?nRVlkoZjKA00?o
ZjKA1?nYZ=H00onW[M_o/;WQok2ih@02ok2ih@Co[[_S00?o/lKXok74j?naa>P00onaa>PDooooo`03
o`000?oooooooooo02[ooooo000Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
8oooool3o`0000;o500000?o:P0=oeD08_mM03<00_mM03<3of89?P?oI@i40omW4TP3ofPDB`;oJ1E=
0_n<IZ84ohEOW`?oQEfL0on7GY/4ohUOV`?oRf2K1?n<HI/4oheRV`?oSfBK1?nAII/4oi9VV`CoTfNK
00?oUFRKoiY_X?nJKj001OnLL9l4oj1cW`CoXgJP00?oXGJRojj4Z?n^Q:P00_n^Q:P01_nZPj[o0000
o`000?l0003oZX>Zoj=o[@?o[Xne1?nURKL5oj67^0;oX8Nh0_n[Z=@4oj^Sc`GoZIg;0_nUV<L4oiSS
o@;oXMol1?nHKj<4oiQaY@CoUg>Y0onFMZd00onROjkoXH6aoj61/@03oj61/@?oX8Bf1OnOR;/00onN
SL;oYi:oojNB_`02ojNB_`CoYIC30onTUlP00on^YLko0000oj^Vd@03oj^Vd@?oZJSF00?o/[WOok2i
hOn`^N401?n`^N400on^^n?o/lKXok?6j002ok?6j0?o/LCX0_nabN/Dooooo`03o`000?oooooooooo
02Wooooo000Yooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool08Oooool3o`0000?o
500000?oE@0Roed0<omM03<00_mM03<3of89?P?oI@i40omW4TP01?mX54_oU6nUoiA_YOnDKjD3ohaV
XPCoQEnO0on5GI`3ohMNV`CoREnK0on;H9/4ohaQV`CoSF:K0on?I9/4oi5UV`CoTVJK0onCIi/01?nG
KJ7oVVnPoiY_X?nJKj05oia`W`CoX7>O1?nSMZ03ojj4Z0?o00001?nZPjX4ojj?]@GoYHVg0onQQkP0
0on`[mOoZjSDoj^Xe003oj^Xe0CoZj??0_nYWL/4ohOWm@;oV>?m1?nIKj44oiQ_X`CoV76U1?nGLjT0
1?nFMZgoXWn^oj9o[_nROjh5oj61/@CoX8Bf0onOR;/00onYTKcoYi:oojNB_`03ojNB_`CoYIC300Go
Y9O8ojjUc_n^YLko[ZG>o`000005oj^Vd@04ojVXe_nb^Moo/[WOok:ig`Co/;WQ0_ndb>T4ok?6j003
ok74j?nabN_o/LW[00?o/LW[5?ooool00ol0003oooooooooo`0Xooooo`00:Oooool3o`0001Oooooo
00?o0000ooooooooool07Oooool5o`0000;o500000?oA`05oeD08_mE02800omM03<3of89?P?oI@i4
0_mW4TP3oiihZ0?oU6nU1?n<IZ83ohEOW`?oQEfL0on7GY/4ohUOV`CoRf2K0on<HI/4oheRV`CoSfBK
0onAII/4oi9VV`04oi=WVonGKJ7oUffQoiM]X@CoVVnP1?nLL9l5oj1cW`?oXgJP0ol00002ojj4Z0Co
ZX>Z00?o^YRdojj?]On^SkD00_n^SkD5ojF9]`03oj67^?n`[mOo/:oG00;o/:oG1?n[Z=@3oj^Sc`?o
H]SE0_n7ioD01?nKNJcoVVjOoiY^WonJKYl4oiU_X@CoV6nS1OnHLJD3oiMcZ@GoXWn^1?nQPK44oj24
]P03oin8^onYTKcoZI6l00;oZI6l1?nWT[l3ojFD``03ok6Uc?n^YLko[ZG>00?o[ZG>00Go0000oj^V
dOn[Y]7oZjKAokFkgP05ok:ig`03ok2ihOndb>Wo]<SY00?o]<SY0_nca^P2ok;?k`Co/LW[00?o[<O^
ooooooooool04Oooool2o`0002[ooooo000Yooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool06Oooool00olT003o0000o`000005o`0000?oA`0500?oE@0Roed0<omM03<00_mM03<3of89
?P04ofD>A?nUP:_oYH2[ojF0Z`CoWWRX0onDKjD4ohaVXP?oQEnO0on5GI`4ohMNV`?oREnK1?n;H9/3
ohaQV`CoSF:K1?n?I9/3oi5UV`?oTVJK00?oUVfQoiM]XOnGKJ400_nGKJ44oiY_X0CoW72O1OnPLil3
o`000003ok25Yon^Q:So[XBX00?o[XBX0_nZPjX3okZH]0Co[Xne0onURKL00onh^][o/:oGok2_e`03
ok2_e`GoZjSD00CoZj??oi]eYonKMJOoVgFW0_nKMjT00onJKYkoVVjOoiY^W`03oiY^W`?oVFnQ1?nH
Kj<5oiQaY@;oUg>Y00?oXgj[oj9o[_nROjh00onROjh5oj61/@;oX8Bf00?o[96jojVA_?nYTK`00onY
TK`5ojNB_`04ojFD`onaYLco/JG<ok6Uc0Go[ZG>00?o0000okFkg_ne^mh00_ne^mh3ok:ig`;o]/g/
1?ndb>T00onaeo?o//o_ok;?k`03ok;?k`03ok79jon/anko[<O^00;o[<O^5?ooool00ol0003ooooo
ooooo`0Wooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
1Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01;ooooo0ol[0003ob@00003o`00
0?l[003o000000?o000000Co;@00odL01Om700GoA`050_mE0284oed0<`03of89?_nVQ:ooYXB_00Go
YH2[0onNN:P3oiA_Y@CoS6JR0on5Gil3ohEMW0CoQejK0on9Gi/4oh]PV`?oS66K1?n=HY/4ohmTV`?o
TFFK00CoTVJKoiI]XOnFKJ7oUVfQ1OnGKJ43oiY_X0CoW72O0_nPLil3o`000004oj=fX?n`QJOo/8FW
ok25Y`Go[XBX00?oZX>ZokZH]?njV;@00_njV;@4ojj?]@03ojF9]onh^][o^;[J00;o^;[J1On`[mL2
oj^Xe003oiYbYOnKMJOoVgFW00?oVgFW00?oVgNYoiY^W_nJKYh01OnJKYl3oiU_X@GoV6nS1?nHLJD0
1?nGLjWoXgj[oj=nZonSOZ/4oj9o[PGoXH6a00CoX8BfojbA^_n/TK[o[96j1?nYTK`4ojNB_`03okBW
c?naYLco/JG<00;o/JG<1?n^YLh00onh`N3o0000okFkgP03okFkgP03ok:igonfcNco]/g/00?o]/g/
00?o]<SYok7Glonaeo<00_naeo<2ok;?k`;o[<kb1On/anhEooooo`03o`000?oooooooooo02Kooooo
000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A005ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03Oooool00om1`l;o
B000oe@00002oe@000?oBP000ol[00001?l9003o0000o`000?l00002obd000;oA`050omE02801?mM
03?o/IJkok6F^onTQK<4ojJ4[`CoYH2[1?nNN:P3oiA_Y@?oS6JR0on5Gil3ohEMW0CoQejK0on9Gi/4
oh]PV`CoS66K0on=HY/4ohmTV`;oTFFK00?oUFbRoiI]XOnFKJ400_nFKJ45oiM]X@?oVVnP0onLL9l3
o`0000?oX7>O1?n`QJL5ojj4Z0Go^YRd1?n^SkD6okRjfP;o/:oG00?oVG2RoiYbYOnJLZD00onJLZD3
oi]eY`04oi]^W_nJKYkoVVjNoiY^WPGoVVjO0onIKj45oiQ_X`?oV76U00?oY7jZoj=nZonSOZ/00_nS
OZ/4oj9o[PCoXH6a00?o[i>jojbA^_n/TKX00_n/TKX5ojVA_004ojNB_ondYlco]:O<okBWc0Go/JG<
00?o[ZG>okS1h?nh`N000_nh`N000ol0003o]K_NokFkgP02okOEl0Co]/g/00?o[^3hok7Glonaeo<0
0_naeo<2ojSEm`Co[<kb0_n/anh3ojK4kQCooooo00?o0000ooooooooool09_ooool000Kooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP06ooooo`;o0000
7Oooool00ol0003oooooooooo`09ooooo`04od73`_m8003oB000odP000?oE0000om:0003ob/000;o
2@0000Co0000o`800?l]003o;@000om700D01?mE02;oYiK4ojNFa?naU[/3ojB5/`CoYXB_1?nUP:/4
oiihZ0?oU6nU0on<IZ84ohEOW`?oQEfL0on7GY/4ohUOV`?oRf2K1?n<HI/3oheRV`?oSfBK00CoTVZR
oiE/X_nEK:;oUFbR1OnFKJ44oiM]X@?oVVnP00?oW72Oo`000?l000000_nLL9l3oj1cW`03ojb3Z?n`
QJOo/8FW00;o/8FW1On^Q:P00oo2X;Ko^YRdokZH]003okZH]0;o[Xne0_o8c=d4okRjfP04oiU_X?nI
L:;oVG2RoiU`XPGoVW:U00CoVgFWoi]^W_nKKYkoVfjN1?nJKYh4oiY^W`?oVFnQ1OnHKj<01?nHLJGo
Y7jZojAnZ_nTOZX4oj=nZ`GoXWn^0_nQPK43ojnC^P?o[96j1?nYTK`00oni[Lko]:O<okBWc003okBW
c0?o/JG<0_nlb^D4okS1h003okGPm_l0003o]mG`00?o]mG`00?o]/g/ojkPn?n^h?P00_n^h?P00ona
eo?oZ=GgojSEm`03ojSEm`;o[<kb0_nTb?85ojK4kQCooooo00?o0000ooooooooool09Oooool000ko
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`05ooooo`03o`000?l]003o;@0000?oB0000omD0003odX0
00;o;`000ol90002o`8000;o;@0000CoA`05oi^Ec?nKULcoViG<0_nWU/@00onIPKSoY8FcojB5/`02
ojB5/`CoYXB_1?nUP:/4oiihZ0?oU6nU0on<IZ84ohEOW`?oQEfL0on7GY/4ohUOV`?oRf2K1?n<HI/3
oheRV`04ohmTVonBJZ;oTVZRoi9ZXP?oUFbR1OnFKJ44oiM]X@04oiY_X?l0003o0000o`0000CoW72O
0_nPLil3ojb3Z0?o/8FW1?n^Q:P2ol:P]PGo^YRd00?o[XneolS<gOo8c=d00_o8c=d01?nh^][oVFnP
oiU_X?nIKj04oiU`XP?oVW:U1OnKKYh4oiY^WPCoVVjO1?nIKj43oiQ_X`03ojEnZOnTOZ[oY7jZ00?o
Y7jZ0onSOZ/5oj9o[P03oj61/On_Tk[o[i>j00;o[i>j1?n/TKX00onYTKco^Jg>okV]cP02okV]cPCo
]:O<00?o/JG<okc:iOnlb^D00onlb^D00onh`N3o]N3fokGPmP02okGPmP03o`000?ngeO3oXnWk00?o
XnWk0_n^h?P3oj7Kn`;oZ=Gg0_nQboH5ojC8lP;oY/C^0_nR_nhEooooo`03o`000?oooooooooo02Co
oooo000>ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`04ooooo`03
o`000?oooooooooo01kooooo0_l00002ooooo`?o000000?o;@00odH00?mB00000_mB0003oeH000?o
BP000_l_00000ol9003o0000o`800002o`800004obd00?nBU=;oRWbnohYl_P?oSgjl0onIPKP5ojB5
/`?oYXB_1?nUP:/2oiihZ0;oUWJ^0on8JZX3oh1QYP?oNU^R00CoQEnOohEMW?n5GIcoQEfL0on7GY/4
ohUOV`?oRf2K1?n<HI/2oheRV`03ohmXXOnBJZ;oTVZR00;oTVZR1?nEK:84oiI]X@;oUffQ0ol00003
oiY_X0CoW72O00?oX7>Oojb3Z?n/PjP00_n/PjP4ok25Y`;o[XBX0oo2X;H4okZH]0;of^GM0oo8c=d0
0onJKYkoVFnPoiU_X002oiU_X0CoVG2R0_nJLZD7oi]^WP?oVVjN1?nJKYl4oiU_X@;oV6nS0_nUOZT5
ojAnZPCoXgj[0onROjh00oncUk_o[i>jojnC^P03ojnC^PCo[96j1Oni[Lh3okBWc0;o_m[]1?nlb^D3
oj_]n@;o]N3f00?oR^Wbo`000?n:jO800_nSjO/3oiCNoP;oXM_k0_nLc?P5oj7;mP;oY<Sb0onP_nl4
oj:okQ?ooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Go
c<c<ob4Q8Ol0003o8B4Qolc<c009ooooo`003_ooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool2o`00027ooooo0_l000001?lW003oAP00odH00?m60003oe8000?o
EP000om:00001Ol_003o0000o`000?l0003o0P0000?oS7jn1On:O;h3ohmn_0?oVH6h1?nTQK<4ojJ4
[`;oYH2[00?oWWnaoiIf[_nFMZh00_nFMZh3ohQZZP?oP66V1?mjFj83ogiLX0?oQejK1?n9Gi/2oh]P
V`03ohaUX?n>Ij7oSVNQ00;oSVNQ0on?J:45oi9ZXP?oUFbR0onFKJ43o`0000;oUffQ1?nJKj03oia`
W`03ojJ1[?n/PjSo[8>X00?o[8>X1?n`QJL00on^Q:So`Z2fol:P]P03ol:P]P;o^YRd1?oJiMd00oo8
c=goVVjNoiY^WP04oiU_X0CoVG2R00?oVW:Uoi]^W_nKKYh01_nKKYh3oiY^WPCoVVjO1?nIKj400onH
Kj?oYGjYojEnZ@02ojEnZ@CoY7jZ1?nSOZ/00onROjko/iNkok>G^`02ok>G^`Go[i>j0_n/TKX2okff
dPGo^Jg>00?o]:O<okoJkOnof^d00_nof^d00onlb^GoZngioj_]n@02oj_]n@;oFM?A0_n:jO800on1
gOco0000oh7Mo002oiCNoP?oUL_j1?nLc?P2oj7;mP?oW[k_1OnP_nl2oj:okP;oXK_[5?ooool00ol0
003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@09ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`;o00008Oooool3obL000?oAP000omB0003oeH00006odX0
0?l_003o5000oa@00?l0003oBl[J1?nHQKd3ohan_PCoRWbn0on?O[`3oiV1^0CoY8Fc1?nVQ:l00onU
P:_oWWnaoiio/@04oiIf[PCoR6ZZ0_n0HJH4ogYKXP?oOUbP0on4Gil4ohQRX0?oS6FP1?n>Ij43ohmX
X@GoTVZR0onEK:83o`000003oiI]XOnGKJ7oUffQ00?oUffQ0onJKj001?nLL9ooYX6/ojJ1[?nVPJ`5
ojb3Z0Co/8FW1_o2X;H00onjV;Cof^GMom[Ug@02om[Ug@04oie_WOnJKYkoVVjNoiY^WPGoVFnP0onI
L:89oi]^WP?oVVjN1OnJKYl3oiU_X@GoYGjY1?nTOZX4oj=nZ`Go/iNk1On_TkX01?n/TK[o_KKBokff
d_nm]]84okV]cP;o^o3c0_nof^d4ohS[j@03oj_]nOmIdm7oFM?A00CoImCf0_n1gO`00ol0003oT<Kj
oiG;nP04oiG;nP;oW<ch0_nM_>h5oijnk`;oX;o_0_nP^>T5oj6kjaCooooo00?o0000ooooooooool0
1?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000009oooo
o`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`03o`000?oooooooooo01oooooo00?o9`00obh00?l^00000_ln0003od8000Co?`000omAcN80
0on[T[coXX^loj:;_002oj:;_0?oV8Fm0on<O[h4ohYl_P?oSgjl0onIPKP4ojB5/`;oYXB_0_nPPk@4
oiio/@?oUWJ^1?n8JZX3oh1QYP?oNU^R0omnG:03ohAOW`CoR6:P0on<IJ04ohiWX@CoSfRQ1?nBJZ83
o`0000CoUVfQ1OnGKJ42oiY_X003oj:1/?nVPJcoYX6/00?oYX6/1?n/PjP4ok25Y`03olV[^oo2X;Ko
`Z2f00?o`Z2f0_oIoMP01?oJiMgoWFnMoie_WOnMKid3oiY^WPGoVFnP0_nIL:800onLKikoVfjNoi]^
WP07oi]^WP?oVVjN1OnJKYl2oiU_X@03ojIoZ_nUOZWoYGjY00?oYGjY1OnTOZX2oj=nZ`;o^9no1?nc
Uk/4ojnC^P03olC7g?nm]];o_KKB00?o_KKB00Co^Jg>ok_`lonkl??o^o3c0oll_:X2ohS[j@03od_0
lomCbO7oDlWa00;oS[7^1On<_OH2oi36nP04o`000?n@a_[oUL_joiG;nP;oVkO/1OnM_>h2oijnk`;o
WkCW1OnP^>T3oj6kj`03oj>kj_oooooooooo01;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P09ooooo`009oooool00ol0
003oooooooooo`0Mooooo`04oaH00?l^003o;P00obh000;o?P000om20002ocl000?oA<KG00?o]JS;
oj^B_?n[T[`00_n[T[`3oj:;_0?oV8Fm0on<O[h5ohYl_P?oSgjl0onIPKP2ojB5/`03oib3]onPPkCo
X8>d00;oX8>d1?nNOk44oiIf[P?oR6ZZ0on0HJH3ogYKXP?oOUbP0on4Gil4ohQRX0CoS6FP0on>Ij44
ohmXX@04oi9ZX_l0003o0000o`0000?oUFbR1OnFKJ44oiM]X@03oiY_X?nRPK3oXX6`00GoYX6/1On/
PjP2ok25Y`;obJ^k1?o2X;H2omWmf003oim_VonMKigoWFnM00;oWFnM0onJKYh5oiU_X003oiU`X_nL
KikoW6nN00WoVfjN0onJKYh5oiY^W`04oiU_XOnVOj[oYWnZojIoZPCoYGjY1OnTOZX01?nSOZ_o^9no
okRO_onhWkl5ok>G^`03ojnC^_o4amcoa<OL00;oa<OL0onm]]83ohk^f@04ok_`lonETm3oUI?@oiFC
d0GoT:7O1?n>/Nh2ohbmmP;oVjSO0_nK/>L00ol0003oVk3Woi^`i`04oi^gk0;oWKc^0_nP/><5oind
i`CoX;SY00?oXK_[oj>kj_nS^nX00_nS^nXDooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`02Oooool002Oooooo0_l0000K
ooooo`?o5P000ol^00001?ln003obLgLolW=g?o9cM`3okn^b@Co^j_91On[T[`3oj:;_0CoV8Fm0on<
O[h4ohYl_P?oSgjl0onIPKP00onTQK?oW8>goib3]`05oj23]0?oWWna1?nFMZh3ohQZZP?oP66V0omj
Fj84ogiLX0?oQ5nO0on8HZ04ohaUX0?oSVNQ0on?J:42o`0000?oTVZR0onEK:85oiI]X@?oUffQ00?o
WX6doj:1/?nRPK000_nRPK04ojJ1[0Go[8>X00Co/8FWolV[^oo9Zk_obJ^k0oo2X;H2omWmf0;oWfnK
1?nMKid4oiY^WP?oVFnP00?oWW2Noia_W_nLKih00_nLKih8oi]^WPCoVVjN0onJKYl00onXPZ_oYWnZ
ojIoZP02ojIoZPCoYGjY1?nTOZX00onn[<So^9nookRO_`02okRO_`Co/iNk00?ob>7[olC7g?o4am`0
0oo4am`01?nm]];oS^kIohk^fOn>k]T3oiV9`@CoUI?@1On@XMl2ohjakP03oifOe_nKZ=ooVjSO00?o
VjSO0_nK/>L00ol0003oVk3Woi^`i`02oi^gk003oj2Zg_nP/>?oX;3S00?oX;3S1?nO]>L2oj2hj@?o
XkOW1?nS^nXEooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?nj^[[ooooookZj^_l@41002Oooool002Oooooo00?o0000ooooooooool05oooool2o`00
0003oaH00?l0003obnGZ00?obnGZ0oo:bmX00oo9cMco_jk9okn^b@02okn^b@?o^j_90_naUk`4oj^B
_0CoXX^l0onHQKd2ohan_P03ohYc/on7LkKoQg>f00;oQg>f0on8M[P3oi5l^0CoW8>g1?nPPk@3oiio
/@CoUWJ^0on8JZX3oh1QYP?oNU^R1?mnG:03ohAOW`?oR6:P1?n<IJ03ohiWX@?o000000?oSfRQoi9Z
X_nBJZ800_nBJZ84oiE/XPCoUVfQ00CoUffQoij1]?nNPKCoWX6d1?nRPK04ojJ1[0Co[8>X00?ob[[;
olV[^oo9Zk/00oo9Zk/00oo2X;KofOgHomWmf003oim_V`CoWFnM1?nJKYh2oiU_X0;oWW2N1?nLKih8
oi]^WPCoVVjN0_nJKYl2ojR2Z`CoYWnZ1OnUOZT2ojAnZP?o_Zc81?nhWkl2ok>G^`?ob>7[0oo4am`5
oif3]`CoVHW11?nETm02oi2Qg`;oXIS<1?nMWmH5oi^Xg`;oVk3W00?o0000oj6Tf?nPZ]h00onPZ]h5
oj2`h`;oWkCW0_nT]>@5oj>gi`;oXk_Z0_nV_>TBooooo`?o00001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000009ooooo`009oooool00ol0003ooooooooo
o`0Dooooo`?o6ZNd0_nel_@4olSOj@03ol_Uj_o:bm[ob/_J00;ob/_J00?o`K;;okn^bOno[/T00ono
[/T01?nkZlWo/INlok6G_?naUk`5oj^B_0;oXX^l00CoVgfaoiAi/_nDNK;oU7Vb0on:Lk<4ohMc]P?o
R7Jh1?nAO;P3oib3]`CoX8>d1?nNOk43oiIf[PCoR6ZZ0_n0HJH4ogYKXP?oOUbP0on4Gil3ohQRX0Co
S6FP0ol000001?n>Ij7oSfRQohmXXOn?J:45oi9ZXP?oUFbR0onFKJ400onNPkKoWX6doij1]003oij1
]0?oXX6`1OnVPJ`2ojb3Z0?ob[[;1?o9Zk/00onFiIooXW6Koim_V`03oim_V`CoWFnM1?nJKYh01?nI
Kj3oWW2Noii`W_nNL9h4oia_WPWoVfjN0onJKYh00onJKYooZ8:[ojR2Z`02ojR2Z`?oYWnZ1OnUOZT0
0onTOZ[o_Zc8okj/b002okj/b0Co^9no00?o/iNkolSQjoo8hN/00oo8hN/00oo4amcoXH2_oif3]`04
oif3]`CoVHW10_nETm02ojBC``GoXIS<1?nMWmH2oi^Xg`;oXioA0_nQY=P00ol0003oXJCHoj6Tf004
oj2ZgP;oX;3S0_nU/>05ojBdi0;oXkOW0_nW^NH5ojJljACooooo00Wo0000ooooooooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Wooooo000Vooooo`?o
00003oooool3odK3j@;oF=7R0_n7j^h3okGbm0Cob=oY0_o8b]`3ol[;fP?o`K;;0ono[/T00oneW;oo
/INlok6G_002ok6G_0GoZi:l00?oXX^loi]m/OnKOK400onDNK84ohYc/`?oQg>f1?n8M[P3oi5l^0?o
W8>g1OnPPk@3oiio/@?oUWJ^1?n8JZX3oh1QYP?oNU^R0omnG:03ohAOW`CoR6:P0ol00004ohiWX@Co
SfRQ1?nBJZ83oiE/XP04oiI]XOnNPkKoWX>foij3]PGoWX6d0onRPK05ojJ1[003ojb3Z?o:^/_ob[[;
00;ob[[;0oo9Zk/01?nFiIooXW6Koj9aVonRLI/3oim_V`GoWFnM0onJKYh5oii`WP?oW6nN2OnKKYh2
oiY^WP03ojZ6[_nXPZ_oZ8:[00?oZ8:[0onVOjX4ojEnZ@03olO4eonn[<So_Zc800?o_Zc80onhWkl3
ojoij@;ob>7[00?oYX6/oj60[onQP:l00_nQP:l4oif3]`?oVHW100?oZI6lojBC`onTTl<00onTTl<4
oj6Hc0;oWIoF0_nVVl/5oj>Od@;oXJCH00Co0000oj6Tf?nPZ]koX:[N0_nV[M`5ojF`h0;oY;CT0onX
]n@4ojNiiP;oY[cY0_nY_nTEooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooo
oooo00Gooooo0om`_oh4ofO5oP;oF/Oi0ombfOP3oiSXnP?o^>Wf0oo5fNP00oo8gnWob<[LolS:g003
olS:g003ol[;f_o1//_o`K;;00?o`K;;00Co_jk9okFL_oneW;oo]Ibo1?naUk`3oj^B_003oj>3/_nK
OK7oVgfa00;oVgfa0onDNK83ohYc/`CoQg>f0on8M[P3oi5l^0CoW8>g1?nPPk@2oiio/@04oiIl]?n:
L[;oRW:bohYb/P?oNFB_00CoR6ZZoh1QY_n0HJKoP66V0omjFj83ogiLX0?oQ5nO00CoR6:Po`000?l0
003o00000on<IJ04ohiWX@CoSfRQ1?nBJZ82oiE/XP03oij4]onNPkKoWX>f00?oWX>f1?nNPK@3oj:1
/0CoYX6/00?o`=GZolZjboo:^//01?o:^//00oo9Zk_oXW6Koj9aV`03oj9aV`?oWfnK1OnMKid2oiY^
WP03oj5dX?nNL9koWW2N00?oWW2N0onLKih9oi]^WP03oiY^W_nZQZkoZXJ^00GoZ8:[1?nVOjX2ojEn
Z@?oalCG1Onn[<P01?nhWkoo[oWYojoijOnQP;02oi^5^P;oYX6/1?nQP:l5oif3]`04oiV9`OnYTKco
ZI6lojVA_0CoY9?30onQV<`00onZV/KoYY_;ojJKb`03ojJKb`CoXioA0_nQY=P00onYZ]So0000ojJ]
g004ojJ]g0?oYK3P00?oZKGQojRgi?nX]n@01?nX]n@2ojNiiP;oZ[kX1?nY_nTDooooo`03o`000?oo
oooooooo01kooooo000Kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooogV`
mP02ogV`mPCoM[Sj0om`_oh2ofO5oP?oO]Co1?nLgod01?nHj?[o^>WfokSYm_nhjOH4olGIj0;oa/[M
0oo8b]`00oo1]/oo`K;;ol6bb`03ol6bb`03okNR`oneW;oo]Ibo00;o]Ibo1?naUk`01?n[T[coXh>b
oj>3/_nSPk84oi]m/@?oU7Vb0on:Lk<4ohMc]P?oR7Jh1?nAO;P3oib3]`;oX8>d0_nIP;L3oiIl]0?o
RW:b1?miI:l3ofmK[0?oNU^R0omnG:001?n4Gioo0000o`000?l00003ohQRX0CoS6FP0on>Ij44ohmX
X@;oTVZR0_nJP[L4oij4]`CoWX>f1?nNPK@4oj:1/0;oYX6/0oo0eNX4olZjb`03oiUXV?nTLicoXW6K
00CoXW6K0onOKi/5oie_W@03oiY^W_nQM:3oXGBP00GoWW2N0onLKih8oi]^WP03ojb</onZQZkoZXJ^
00;oZXJ^1?nXPZ/4ojIoZP03ojEnZOo7a=OoalCG00;oalCG1?nn[<P00ol0003oXH2`oj60/002oj60
/003oi^5^_nVPJcoYX6/00;oYX6/0onQP:l4oif3]`03ojjA^OnYTKcoZI6l00;oZI6l1OnTTl<01?nQ
V<coZY[6ojZJa_nZV/H4ojJKb`?oXioA00?o[:WDojVZf?nYZ]P00_nYZ]P00ol0003oYZgLojJ]g003
ojJ]g004ojF`h?nY]N7oZKGQojVeh@CoZ;OT00?oZkgWojZnj?nZ_^P00onZ_^P2ojVoj@;oZl;Z5?oo
ool00ol0003oooooooooo`0Mooooo`006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o
0000ooooooooool00omi/?H2ogJhnP?oRL;j1?n6c?h01?mne?ooW=omoicOoOnLgod4okCOm@03okSY
m_o5fNSoaMWX00;oaMWX1?o6b]d01?o8b]co`KK?ol6fcoo1]/l3ol6bb`?o]j;30oneW;l3ok6G_003
ojN8]?nSPk;oXh>b00;oXh>b1?nKOK43oiAi/PCoRW>c0on7LkH4ohQf^0?oTGbh0_nLPkL00onHP;So
VH2goiV0]`02oiV0]`CoUWbd0on:L[83ogUT[`?oKe^/0_m[EjT00omjFj;oOUbPo`000002o`0000?o
Q5nO0on8HZ04ohaUX0?oSVNQ0_n?J:42oiIn]`CoVX:g1?nNQ;L4oij3]PGoWX6d0onRPK000onVPJco
`=GZol3EjP02ol3EjP?ob[[;00?oVFRHojAcW?nTLi`01OnRLI/4oim_V`CoWFnM1?nQM:04oii`WP?o
W6nN1onKKYh2ojb</`CoZXJ^1OnXPZ/2ojIoZP;ocNg[1Oo7a=L01?nn[<SoYWnZojIoZ_nVOjX4oj60
/0GoYX6/1?nQP:l2oif3]`?o[Y6i0onYTK`4ojBC``03ojnK`onZV/KoZY[600;oZY[61OnVVl/01?nS
Wm7o[:WDojbYe?n/ZM@3ojVZf004o`000?nYZ]SoYZgLojJ]g0;o[;CO1OnY]N400onX]nCoZkgWoj^m
i`02oj^mi`?oZ[kX00?o[<?[oj_2j_n[`^X00on[`^XCooooo`;o00007_ooool001_ooooo00Go410@
oooooooooooooooooa0@4006ooooo`;o00000_ooool4oh^gl`CoRL;j0_n6c?h2oikDn`?o/MCb0ond
goD4ol3Dj@03olGIj?o6b]goa/[M00;oa/[M00?o`;WCol6fcoo1]/l00oo1]/l00oo1//_o]j;3okNR
``02okNR``Co]Ibo00?o/INlojN8]?nWR;@01OnSPk83oi]m/@CoU7Vb0on:Lk<3ohMc]PCoR7Jh0_nA
O;P01?n@NkSoV82hoiR0^?nHP;P5oiV0]`?oUWbd0on:L[83ogUT[`?oKe^/00CoJeNYo`000?l0003o
00000omnG:03ohAOW`?oR6:P1?n<IJ02ohiWX@03oiEl]OnFO[OoUWjg00;oUWjg1OnJP[L3oij4]`Go
WX>f1?nNPK@2oj:1/0?oU^_h1?o0eNX00oo:^/_oVfVGoiUXV003ojAcW0CoXW6K1?nOKi/3oie_W@03
ojMkX_nQM:3oXGBP00;oXGBP1?nNL9h4oia_WPGoVfjN1?n/S;<3ojZ6[PGoZ8:[00?oYWnZolg]joo=
kN/00_o=kN/2olO4e`;oZh6W1OnVOjX2oj60/003ojb5ZonVPJcoYX6/00?oYX6/1?nQP:l00onMPkOo
[Y6iojjA^@02ojjA^@CoZI6l00?oY9?3ojnK`on_Vl<00_n_Vl<4ojZJaP;oYY_;0_n`Z]85ojbYe0;o
ZJ[H00?o[kKNo`000?n/]=l01?n/]=l2ojVeh@;o[KkV1On[_NL00onZ_^So[<?[ojc3j`02ojc3j`?o
Zl;Z00?oZl?[ooooooooool04?ooool00ol0003oooooo`00000Nooooo`006oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool00_ooool2oh^gl`?oWKg_1?nNb?D00onNe?_o
/MCbok7DlP03ok7DlP03okCOmOo0e>Wo`=CY00;o`=CY0_o2bN03olK:g@?o`;WC0oo1]/l00onhZ<Wo
]j;3okNR``03okNR``?o]Ibo00?oZXjhojN8]?nWR;@00_nWR;@4oj>3/PCoVgfa0onDNK82ohYc/`04
ohmd/On<M;?oS7Bcohad/`CoRgJf1?n@NkP3oiR0^0CoVH2g0onFO;@3ohYb/P?oNFB_0_m_Fj`2o`00
00;oJeNY0omeGZX01?mnG:3oQ5nOohAOWon4Gil3ohQRX0;oS6FP0_nCN;43oiEl]@GoUWjg1?nJP[L4
oij4]`CoWX>f0_nNPK@4ocZn^@;oU^_h0onIJ9L4oi]YU`CoY7>L1?nRLI/4oim_V`;oWFnM0_nWNj84
oj5dX0CoWW2N1?nLKih3oi]^WP03ok6E^_n/S;?o[8bc00?o[8bc0onZQZh4ojR2Z`?oNMf[0_o=kN/0
0onFK:3oZh6Woj^1Y`02oj^1Y`GoYWnZ00CoXH2`ojb5Zon/QJ_o[8F[1?nVPJ`4oj60[`Go[Y6i1?nY
TK`5ojnK``?oZY[600?o]ZoBok2Zd_n`Z]800on`Z]83ojbYe003ok>jgon_]]ko[kKN00;o[kKN00Co
0000ojbdgon/]=oo[;CO0_n_`NL4ojfniP;oZkgW0on]a>/4ojc3j`03oj_2j_n[`n_oZl?[00;oZl?[
5?ooool00ol0003oooooooooo`0Kooooo`006oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00oooool5oifmk`;oW/Se1?n^b^l2ok7DlPCo^loY00?o`=CYol;9h?o2bN00
0_o2bN000oo6b]go`;WCol2id`03ol2id`04ol6fconhZ<Wo^:S9okRXb@Go]j;300Co]IboojZ>^?nZ
S[SoZXjh0onWR;@4oj>3/PCoVgfa0_nDNK801?nFN;3oSgBaohmd/On?M;43ohad/`GoRgJf0on@NkP3
oiR0^0CoVH2g1?nFO;@2ohYb/P;oNFB_0ol00002ofmK[0;oJeNY1?meGZX3oh=X[0?oS72^1?nCN;44
oiEl]@CoUWjg1?nJP[L4oij4]`;oWX>f0_n1EiL3oh=HUPCoSf2G1?nIJ9L3oi]YU`03ojEeWOnTLico
Y7>L00;oY7>L1?nRLI/4oim_V`03oie_WOnWNj;oYg^R00;oYg^R0onQM:04oii`WPCoW6nN0_nKKYh2
ok6E^PGo[8bc1?nZQZh2ojR2Z`;oNMf[00GoVFbLoiI/X?nFK:3oUVbPojn4YP04oj^1Y`GoYWnZ1?n/
QJ/5ojJ1[0;oXH2_0_ndU[P5ojjA^@;oZI6l0_nfX/@5ojnK``04ojZJa_nf[m;o]ZoBokJ_dPGo/:[B
00Co[:WDok>jgonc^]oo/k[O0on_]]h00ol0003o[;COojo1i`04ojo1i`;o[KkV0_n]and5ojg4j`;o
[<?[0_n[aN`3oj_3j`03ojW3k?oooooooooo01?ooooo00?o0000ooooooooool06_ooool001_ooooo
00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo00Gooooo0onM_Nl2oj_1jPCo
[/[_0_nhbNL4ok_?j@;o_/SR0oo2bN03okjmf0?o`;WC00?o^:k?okRXbOnhZ<T00_nhZ<T4okNR``03
ojbD_OnZS[SoZXjh00;oZXjh0onWR;@4oj>3/P;oVgfa0_nKO;03oiIh/0CoSgBa0on<M;<4oh]f]P?o
T7^h0onHP;P5oiV0]`?oUWbd00CoRW:bo`000?l0003o00000_miI:l3ofmK[0?oJeNY0omeGZX3oh=X
[0?oS72^1OnCN;43oiEl]@CoUWjg1OnJP[L2oij4]`;oQ5ZI1?n1EiL2oh=HUPCoSf2G1?nIJ9L2oi]Y
U`;oYGFM1?nTLi`5oj9aV`?oWfnK1OnWNj83oj5dX0GoWW2N0onLKih00onKKYko/IFjok6E^P02ok6E
^PCo[8bc1?nZQZh00onXPZ_oVFbLoiU/W002oiU/W0;oUVbP0on_Q:H3oj^1Y`CoYWnZ00?o]8f]ojb5
Zon/QJ/00_n/QJ/5ojJ1[004oj60[ondU[So]9JhokBF^0Go[Y6i00CoZI6lokJRa?nfX/Co]Z;41?n_
Vl<00onk^=Oo]ZoBokJ_dP02okJ_dPCo/:[B00?o]l?Sok>jgonc^]l00onc^]l2ojnfgP03ok75jOl0
003o[l7W00?o[l7W00?o[Lc`ojg7kOn]and00on]and2ojg4j`;oZlO^1On[aN`01?n[`n_oZL?/ojW3
k?nY`n`Dooooo`03o`000?oooooooooo01[ooooo000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2o`0000Oooooo00?oWKg_oj_1j_n[`NX00_n[`NX00on^b^oo^<WWokS9i`03okS9i`03ok_?
jOnnb>;o_/SR00?o_/SR00?o`/WPokjmf?nn_MP00onn_MP01?o0^M?o^:k?okR^conh[/l4okRXb@03
okNR`on/U;go[9Bm00;o[9Bm0onZS[P4ojN8]0;oXh>b00?oWh2boi]l/?nKO;000_nKO;04oiIh/0?o
SgBa0on<M;<4oh]f]PCoT7^h0onHP;P4oiV0]`04oiIl]?l0003o0000o`0000;oP7:k0omiI:l3ofmK
[0?oJeNY0omeGZX4oh=X[0?oS72^1?nCN;43oiEl]@GoUWjg1?nJP[L01?nNQ;OoN5>JohAJVOn4FYT4
oh5GU`?oPeRF0on?H9L4oiUXU`04oi]YUonUMIgoYGFMojEeW@CoY7>L1OnRLI/3oim_V`GoYg^R0onQ
M:05oii`WP;oW6nN00?o^:?4ok6E^_naUKX00onaUKX5ojb</`;oZXJ^0_nLK9/4oiU/W003oiI/X?n_
Q:Ko[hBV00;o[hBV1?n[PJL2ojIoZP?o]8f]0on/QJ/4ojJ1[003ok^O^ondU[So]9Jh00;o]9Jh1?n^
TKT00ono[l[o]Z;4okJRa002okJRa0?o[i_30_nk^=L5okJ_dP03ok2Zd_ng`n?o]l?S00;o]l?S0onc
^]l00onbcNko/LGYok75j@02ok75j@03o`000?n_`NOo[Lc`00?o[Lc`0_n]and2oj[9l0GoZlO^0_n[
aN`2ojW5k@GoZL?/5?ooool00ol0003oooooooooo`0Iooooo`006oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo00?o0000ooooooooool01oooool3oj_1jP?o]<?U0onhbNL3okc6hP?o_/SR0_nm
`=`4okjmf003okRdeOnh[/oo^:k?00;o^:k?0onhZ<T00on]VlGo[9BmojbD_@03ojbD_@CoZXjh0onW
R;@00onSPk;oWh2boin0/P04oi]l/0CoUWR`0on?M;43ohad/`GoRgJf0on@NkP3oiR0^0;oVH2g0ol0
0002ohml^P?oP7:k0omXI;/3ofmK[0?oJeNY0omeGZX4oh=X[0?oS72^1?nCN;44oiEl]@CoUWjg0_nJ
P[L3og]EVP;oN5>J00?oQ5ZIoh5GUon1EiL00_n1EiL3oh=HUP?oSf2G0onIJ9L00onRM9ooYGFMojEe
W@02ojEeW@CoY7>L1OnRLI/2oim_V`03ok24Y_nWNj;oYg^R00?oYg^R0onQM:05oii`WP04oia_W_nh
XlCo^:?4okRSa0Co/IFj1On/S;<00onZQZkoW6bKoia/V`02oia/V`?oVFbL1On_Q:H4oj^1Y`03ojIo
Z_ndSJgo]8f]00;o]8f]1?n/QJ/2ojJ1[0?o^ink1?ndU[P01?n^TKWo_jo:okn_b_no[lX5okJRa003
ojnK`onk^=Oo^kSG00;o^kSG0onf[m82ok_Ck0Co]l?S00?o/k[Ook;=k_nbcNh00_nbcNh2ok75j@;o
[=;d00Co0000ojg<l?n]c?3o[Lc`0_nXcO<4oj[9l0;oZlO^0onXanl4ojW5k@;oZL?/0_nW`N`Doooo
o`03o`000?oooooooooo01Wooooo000Uooooo`03o`000?oooooooooo00Sooooo00?oZl7ZokC3iOnd
`nD00ond`nD00onhbNOo_<KRokc6hP03okc6hP03okk8h_nm`=co_L3L00;o_L3L00?o_[gHokRdeOnh
]=D00_nh]=D4okR^c`04okRXbOn]VlGo[I_5ojfKa@Co[9Bm1?nZS[P2ojN8]003oj:5]OnOP;;oWh2b
00;oWh2b1?nKO;03oiIh/0CoSgBa0on<M;<4oh]f]P;oT7^h00?oTWfioiJ1^_nFPKX00ol00002oiF0
^PCoSgbj0on0L[/2ofQT^`;oEUbm0_m_Fj`2of]GZ@CoMEjZ0on3J:`3oha`[PGoTgRa0onEO;D2oiIn
]`04ohEOW_moFYcoOeZLogmJW0?oNeFJ0omhDiX4oh5GU`?oPeRF0on?H9L2oiUXU`;oXWBO1?nUMId4
ojAcW0GoXW6K00CoWfnKok24Y_n`Q:Ko/8BV1?nWNj84oj5dX0?oWW2N00?o`KgGokRSa?nhXl@00_nh
Xl@5ok6E^P?o[8bc00?oWVjKoia/VonLK9/00onLK9/3oiU/W0Go[hBV1?n[PJL5okB=[@Co[8F[00?o
YX6/ok^O^onkWk/00_nkWk/4okBF^0Go_jo:0onfX/@2ol7<hPCo^kSG00?o]ZoBok_Ck?nkdn`00onk
dn`2okO3h`?o[mOe0_nbcNh2ojKInP?o[=;d00?o0000ojcBm?n]c?001?nXcO<2oj[9l0;oYlSa1OnX
anl2ojW5k@;oYl;]1?nW`N`Booooo`03o`000?oooooo000001[ooooo000Uooooo`03o`000?oooooo
oooo00[ooooo0ond`nD2ok[3h@Co_<KR0_nl`]h3okg0g0;o^K[J1?nh]=D3okR^c`03ojjSc?n]VlGo
[I_500;o[I_51On/U;d2ojZ>^004oj:9^_nRQKGoXXFeoj:5]@CoWh2b1?nKO;04oiIh/0?oSgBa0on<
M;<2oh]f]P;oT7Zg0_nBOKT3o`0000;oUX6j0onEP;X4ohml^P?oP7:k0omXI;/3oeIL_@;oJeNY1?me
GZX3oh=X[0?oS72^1OnCN;42oiEl]@04oe7=`_n5GikoQEnNohEOWP?oOeZL0omkEIX3ogQCVP?oNUFK
00CoPENGoh=HU_n3F9KoPeRF0on?H9L01?nIJ9OoXWBOoj9dWonRM9l4ojEeW@GoY7>L1?nRLI/4ok24
YPCoYg^R1?nQM:02oii`WP?o`KgG0onhXl@5ok6E^P04ojb</onNKY_oWVjKoii^V`GoW6bK0_nIK9`2
okF;Z@Co[hBV1?n[PJL5okB=[@Co[8F[1OnkWk/3okBF^0;ocLoK1?no[lX00onfX/Co`LcRol7<hP03
ol7<hP;o^kSG0oncj?L2ok_Ck0;oX^;l1?n_eoD00onIg_koY]WjojKInP03ojKInP;o[=;d00?oY=3g
o`000?nTd?L00_nXcO<2ojC:l`GoYlSa0_nXanl2ojK3kPGoYl;]0_nW`N`2ojK0k1Cooooo00?o0000
ooooooooool05oooool002Gooooo0_l0000<ooooo`03okC3iOnj`n7o^/?Q00;o^/?Q00?o_<KRokc2
g_nl`]h00onl`]h00onm`=co^K[JokVjfP02okVjfPCo^;CE00Co^:k?ojjSc?n^Xlco[Z?<0on]VlD5
ojbD_@03ojZ>^?nRRK[oXXVj00CoXXFe0onOP;84oi]l/0CoUWR`0_n?M;401?nDN[?oTWZeoi9j]OnB
N[D4oi1j]`;o00000_nBOKT3oiJ1^PCoUH2j0on?O;X3oh1b^`?oJ6Bk0omFG;d2odaM``04of]GZOme
GZ[oMEjZogENZP?oPfR/1?n<L:h3oi=h/@;oU^_h0_n:I:03ohEOWP?oOeZL0omkEIX3ogQCVPCoNUFK
0on0Fid2ohmPU`03oi=YWonRM9ooXWBO00?oXWBO1?nUMId4ojAcW0?oXW6K00?o^I6^ok24Y_n`Q:H0
0_n`Q:H5ojMkXP?oXGBP00?oWW2Nol6meoo1_ML00_o1_ML4okRSa0;o/IFj0onTM9d3oii^V`GoW6bK
00CoVFbLokF;ZOneRjWo]H^Y1On_Q:H2oj^1Y`;oa:>h1OndSJd2ojb5Z`;oak?71OnkWk/01?ndU[So
cLoKolg?foo=cm/3okn_bP;o^nWd1?o1c>82ogcVh`;o/nSg0omlh?L4oj;Ro003ojoGmOnIg_koVMkn
00;oVMkn0_nVfOX3oicBnP;oY=3g00?oX<Weo`000?nPbOD01?nTb_<2ojO8l@;oYL?_1OnV`nh2ojO2
k@OoY/3/4oooool00ol0003oooooooooo`0Gooooo`009?ooool00ol0003oooooooooo`0=ooooo`?o
^/?Q0onla>03okc2gP03okVog_ni^][o^K[J00Co^K[J0_nh]=D00on_Zm?o[Z?<ojjSc002ojjSc0Co
[I_50_n/U;d2oj:?`@CoXXVj0onRQKD4oin0/P?oVgb`0_nFN;02oiUn]0?oU7Zc1?nBN[D3o`0000Co
TWfi0onFPKX4oiF0^PCoSgbj0on0L[/2ofQT^`CoEUbm0_m<GL<3ogENZPCoPfR/0on<L:h01?nCN;7o
U^_hoiK[n?nFjoP3ohYTX0?oQEnN0omoFY`3og]EVP?oN5>J1?mjEI/3oh1KW@?oTfVO1OnRM9l4ojEe
W@CoY7>L0_nRLI/2okVA[PCo/8BV1OnWNj82oj5dX0;oa^o_1Oo1_ML2okRSa0;o[h:S1?nTM9d4oii^
V`CoW6bK1?neRjT5ojn4YP04oj^1Yoo4XkSoa:>holBS^0Go]8f]00Co[8F[olNcaoo7/lOoak?71?nk
Wk/00onjo>?ocLoKolg?f`03olg?f`03okn_b_nkjOCo^nWd00;o^nWd00Co`LcRogcVhomli^?oO>KS
0olf_=@2ogcPm`?oI<oh1?mofod2oiWNoP?oTm3m0_nLd_X2oi_7mP?oX<We00Co0000oj39mOnTb_?o
Y<[c0_nS`^l4ojG3k`;oY/?^0onU_n`6ojK0k0;oY[o[5?ooool00ol0003oooooooooo`0Fooooo`00
9?ooool00ol0003oooooooooo`0>ooooo`03ok[3hOnla>3o_<CP00?o_<CP00Co_<;NokVog_ni_mko
^KoN1?ni^]X00ona/m[o[j_Cojn[d`02ojn[d`Co[Z?<0_n]VlD00onQU/WoXXo1oj:?`@02oj:?`@Co
XXVj0onRQKD4oin0/P;oVgb`00?oW86eoiUn]?nIO[@00_nIO[@4oiAj/`?o00001?n@N[L3oi9m^@Co
UX6j0onEP;X4ohml^P?oP7:k0omXI;/3oeIL_@;oC5g30omRMm84oh=X[0;oS72^0onLc?P2oheXX`?o
RVBP0on5Gih4ogmJW0;oNeFJ1?mhDiX3ogYEV`?oP5^M0onCJIl5oj9dW`CoYGFM1?nTLi`01?nRLI_o
^I6^okVA[_niTJh4ok24YPGoYg^R00?oXGBPolK_koo6knl00_o6knl2ol6me`;oZG^Q1?n_PZ<4ojAd
W@CoWVjK0onLK9/00onkU[7o]H^YokF;Z@02okF;Z@Go[hBV1?o4XkP4okB=[@03om3Ri?o7/lOoak?7
00;oak?70onkWk/3ok[lh`;ocLoK1?mNeLL2ok_Ym0;oO:;Z1?mU]_`3oe?0n@;oI<oh0_n7`_/5ohS:
o@;oTm3m0_nH`O@5oi_7mP;oX<We00?o0000oj70konS`^l01?nS`^l2ojG3k`;oY;k/1OnU_n`2ojK0
k0;oY[k[1?nV_n/Dooooo`03o`000?oooooooooo01Gooooo000Tooooo`?o00003oooool4okc4h0;o
^l?Q1?ni_mh00oni^][o/K?Jok6cfP02ok6cfPCo[j_C0_n^Xl`00onRW]7oXIK9oj6Fb@02oj6Fb@Co
XXo10onRRKX4oj:5]@;oWh2b00CoWHFioib1]OnLPKGoW86e1OnIO[@3o`0000?oTWZe1?n@N[L4oi9m
^@?oUX6j0_nEP;X2oiROf@CoSZ7Q0om_Vn/2obR6j`?oEUbm0om<GL<2of9gdPKoRJ7T00?oW<choi1/
YOn=J:<00_n=J:<4ohYTX0;oQEnN1?moFY`3og]EVP?oN5>J0omjEI/3oh1KW@CoTfVO1?nRM9l4ojEe
W@CoY7>L1OniTJh4ok24YP?oYg^R0ol00002olK_k`05ojamX?nYNj7oZG^QojUkXOo:YkD01?n_PZ<4
ojAdW@CoWVjK0_nLK9/3ok^F/@?o]H^Y1?n_Q:H2on;Qd`Coa:>h0_ndSJd3om3Ri0Coak?700Co^ink
ok[lhonjo>?o^_cS0onQSKl4oi>DdP;oO:;Z0_nOWM84oiFXh`GoR[Cb0on7`_/2ohS:o@?oU[S_1?nH
`O@2oi_7mP;oWkc]0onQ`>l01?l0003oXL3_oj?2konS`^l2oj>lj`GoY;k/0_nU_n`2ojJmjPGoY[k[
0_nV_n/2ojNnja;ooooo0_l00009ooooo`Co000000?o410@ooooooooool01oooool002Cooooo00?o
0000ooooooooool04?ooool00onla>3o^l?Qok_3h@03ok_3h@;o^KoN0_nc^ml5ok6cfP;o[j_C00?o
Y:OHoj:NdOnRW]400_nRW]43oj6Fb@CoXXo11?nRRKX3oj:5]@03oin0/_nMQKWoWHFi00CoW86e00Co
VGjdo`000?l0003o00000onDN[<4oi9j]@?oT7Zg1?nBOKT2oiJ1^P03oi^Le?nHWmWoV9oI00?oV9oI
1?n>XN43ofnKj`Co:8K[00?oEUbmodaM`om<GL<00omRMm84ohVQi0?oQf2M0on=J:<4ohYTX0?oQEnN
0omoFY`3og]EVP?oN5>J0omjEI/4oh1KW@?oTfVO1?nRM9l4ojEeW@?oY7>L00?obJo0okVA[_niTJh0
0oniTJh4ok24YP;oYg^R0onbPZ04ojamX0;oZG^Q0oo:YkD3ojn2X`CoY7BM1?nNKY/00onLK9_o^iJa
ok^F/@02ok^F/@Co]H^Y0_n_Q:H3on;Qd`Coa:>h00?o]8f]om3Ri?o@h^@00oo@h^@2olNca`;oVI39
0on/S[H3oj6=_`?oTiCB00?oZY[6oinMd_nOWM800onOWM84oiFXh`;oR[Cb0_nNYM/4oiV_iPGoU[S_
0_nH`O@2oingj@CoWkc]0_nQ`>l00onS^NWo0000oj>ij@04oj>lj`;oY;k/0_nV_>T5ojJmjP;oY[k[
0_nW_NX5ojNnja?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`002Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooo
ooooo`0Booooo`?o^l?Q00?o]/?Tok>kgonc^ml00onc^ml3ok6cfP03ojN`g_nTYmSoY:OH00;oY:OH
0onRW]43oj6Fb@CoXXo11?nRRKX2oj:5]@03oib9__nMQKWoWHFi00;oWHFi00CoW86eo`000?l0003o
00000onIO[@4oiAj/`?oTWZe0_n@N[L00onITL[oVIK?oiVFc`02oiVFc`CoVicD1OnHWmT2ohjQh@;o
TFbU0on>J:<3oh]UX@?oRF>O00GoRF6Nof9gd_mRMm;oHWOBohVQi002ohQQWP?oQf2M0on5Gid3oh9M
WP04ohYTX?n5GikoQEnNohEOWP?oOeZL0omkEIX3ogQCVP?oNUFK1?n0Fid3oi=YW`CoXWBO1?nUMId2
ojAcW0?obJo01?niTJh4ok24YP03ojMkX_n9FI?o/X:P00;o/X:P1?n/OJ000onYNj7obZNeolZW]@02
olZW]@?o[h:S1OnTM9d3oii^V`Go^iJa1?neRjT00on_Q:Koh^7Con;Qd`02on;Qd`?oa:>h0ol00002
om3Ri0CoZHbg00?oVI39ojb>]_n/S[H00_n/S[H4oj6=_`04oi>Dd_nZV/KoZY[6ojZJaPGoWigB0_nE
Z><00onUX=7oWZGKoijUf`03oijUf`CoVJoV0_nF^>l2oj6ah`GoWkOY0_nO_>d2oj>fiP;oXkWY00?o
0000oj>ijOnS^NT00_nS_>/2ojFji`CoY[cY0_nV_NX2ojNlj@GoYkgZ0_nW_^/2ojRojQCooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`002Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooo
ooooo`0Cooooo`04ok_3hOnf`nCo]/?TokK3i0Go/k_O00Co/K?JojN`g_nW/=koYk3N0onTYmP3oj:N
d@CoXIK90_nRSl400onET/koV8g6oiR=aP02oiR=aPCoW8Vn00CoWHFio`000?l0003o00000_nLPKD5
oiUn]0?oU7Zc0_nBN[D00onKSlOoVI7:oiVAbP02oiVAbPCoVIK?1?nKW=@2oiROf@;oU76Y1?nAK:D3
ohiXX`?oRfFQ0on9Hil4ohUQWP?oR66N0on7H9d3ohEOW@CoPUfN0omlFYl3ogmJW0?oNeFJ0omhDiX3
ogYEV`CoP5^M0onCJIl4oj9dW`CoYGFM00?oY7>LolV_`?o9[l000_o9[l04okVA[P?o/8BV0_n:F904
ok:2X0Co[7fP1Oo:YkD3ojn2X`GoY7BM0onNKY/00oo5[/?o^iJaok^F/@02ok^F/@Co]H^Y00?o[X:V
o`000?oRhM<00ooRhM<01?o4XkSoY7bXojAlZ?nEN[<3ok>>/0CoZHbg1On/S[H3oj6=_`03okFL_onZ
V/KoZY[600;oZY[61?nOWM800on]WlWoYJ3AojFPd@02ojFPd@CoWZGK0_nI[nH3ojB/g@CoXK7S0_nO
]nT2ojFbhPGoXkKV0_nS^NT00ol0003oY[SVojFji`04ojFji`;oY[cY0_nW^nL4ojNlj@;oYkgZ0onX
_^T4ojRojQ?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`002Oooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003ooooooooo
o`0Eooooo`Co]/?T0_nc^ml3ojZii0?oYk3N1?nTYmP3oj:Nd@;oXIK900?oTYSFoiFBc_nET/h00_nE
T/h4oiR=aP;oW8Vn0_l00002oif5^@CoW86e1?nIO[@2oiAj/`03oib?aOnKSlOoVho700;oVho70onI
TLX5oiVFc`;oVicD00?oGMKDoiQh[OnDLJT00onDLJT3oi5/Y@?oSVRS1?n;IJ43ohUSW`?oRF6N0on8
HIh3ohMPW@?oQEnM1?n2GIh3ogaJW`;oLeJR00CoOeZLog]EV_mkEI[oNeFJ0omhDiX4ogYEV`?oP5^M
0onCJIl5oj9dW`?oYGFM1Oo9[l04okVA[P03ok24Y_n:F93oRUR@00;oRUR@1?nbPZ04ojamX003oi_C
K_o:YkGobZNe00;obZNe1?n_PZ<4ojAdW@;oWVjK0_o5[/<5ok^F/@;o]H^Y00?o[HBYojj2Y_n^PZH0
0_n^PZH5ojAlZ0Go/hj`0_nYS;L2okVF/`Go[8jf00CoXHfookFL_oneW;oo]Ibo1?nZV/H01?nOWM;o
[Io9ojfObOn]WlT5ojFPd@;oWZGK0_nZZMH5ojB/g@;oXK7S00?oYjoMojFbh_nU/^800onU/^82oj>f
iP;oYkKT0onV^>H01?l0003oY[SVojFjionU^^L2ojNiiPGoYk_W0_nW_>T2ojRmj@GoZ;kY0_nX_nX2
ojS0jQ?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`002Oooool01Ol0
003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`0001Kooooo0_nf`n@3
ojk1j0CoZ[WT0onW/=h2ojBWf004oiJXh_nAWmgoTIoMoi6Og@CoTYSF0onET/h3oiR=aP?o000000?o
W8Vnoif5^OnMQKT00_nMQKT3oib1]@;oVGjd0_nNTLH4oib?a@?oVho71?nITLX2oiVFc`?oPnGd1?nH
N:d3oiAaZ@?oTFbU0on>J:<4oh]UX@?oRF>O0on9HIh3ohQQWPCoQf2M0on5Gid3oh9MWP?oO5ZO0omc
EZ83og]EVP?oN5>J1?mjEI/3oh1KW@?oTfVO1OnRM9l3ojEeW@03om_Zg_o9[l3obJo000?obJo00_ni
TJh2ohYGS`?oRUR@00?o^HNQok:2X?nbPZ000onbPZ02ojamX0;oVm=^1?o:YkD4ojn2X`CoY7BM00Co
WVjKolF^`oo5[/?oaJk31OnkU[401?neRjWo[HBYoknCZ_noTjX3ojj2YPCoY7bX0_noVK04ok>>/004
ojV<]oniU[?o^IJcokVF/`Co[8jf00?o_ZFookFL_oneW;l00_neW;l3ojZJaP03okJTa_n]WlWo[Io9
00?o[Io90onUX=400on`Z];oZZWFojZYeP03ojZYeP;oY:cM0_n[[]X4ojN_g@?oYK;R00?oZKGRojNf
i?nW]^@00onW]^@3ojJhiP03o`000?nW^NKoYkWV00?oYkWV0onW^nL00onX_>SoZ;gYojRmj@03ojRm
j@;oZ;kY0_nY_nX5ojS0jQ7ooooo0ol00007ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo
01Sooooo1?n^`NP2ojZii003oingj_nJ/>KoV[3V00;oV[3V0onFZ>83oi6Og@?oTYSF0onET/h3o`00
0003oiR=a_nLRKkoW8Vn00;oW8Vn0onMQKT2oib1]@03oifDbOnNTLKoWY7600?oWY760onLSlD3oi^?
a`?oVI7:1?nFh_d00on3iOCoWX2boij0/P03oiQh[@?oU76Y1?nAK:D2ohiXX`CoRfFQ0on9Hil3ohUQ
WP?oR66N1?n7H9d3ohEOW@?oPUfN0omlFYl3og=FXP;oKeRX00?oNeFJogQCV_mhDiX00_mhDiX3ogYE
V`?oP5^M0onCJIl5oj9dW`;oYGFM0_oKj]h5olV_`004okVA[_n:EhooRUN?ohYGS`;oRUR@0oniQj44
ok:2X004ojamX?nKdfko^hfVokV?Z`GobZNe0on_PZ<3ojAdW@03olKWk_o5[/?oaJk300?oaJk30onk
U[400oncQjKo[HBYoknCZP02oknCZPCo[X:V0_nTO:P3oknI/0Co/hj`1?niU[<3ojb>]P;o_ZFo1One
W;l01?nZV/Ko]ZC6okJTa_nfY<H4ojfOb@03ojFPdOn`Z];o/:[B00;o/:[B0onZZMH00on`/MSoZjkJ
oj^^fP03oj^^fPCoYjoM00CoYK;RojVeh_nY]N;oZKGR1?nW]^@01OnV^>KoZ;WUojRiiOl0003oZ;WU
00CoYkWV00?oYk_WojRlj?nX_>P00_nX_>P3ojRmj@03ojVojOnY_n[oZKoZ00?oZKoZ0_nX`>X2ojW1
j`kooooo1?l000000ooooooo0000ooooo`06ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05
oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Wooooo0_n^`NP2ojBok0?oWkOZ1?nJ/>H3oiJXhP?oTIoM0_nBV=H3o`000003oiFBc_nHSLKoV8g6
00;oV8g60onLRKh2oif5^@03oiRFd?nMU<WoWIC900;oWIC91?nNTLH3oib?a@CoVho700CoVI7:oiKR
oOnFh_goU^;m0_nSRKP3oij0/P?oV7R]0onDLJT4oi5/Y@?oSVRS0on;IJ43ohUSW`CoRF6N0_n8HIh4
ohMPW@?oQEnM0on2GIh4ogaJW`;oLeJR0om_F:P4ogQCVP?oNUFK0on0Fid4oi=YW`CoXWBO00?oYGFM
om_Zg_oKj]h00_oKj]h2olV_`0?oReN>0on:Ehl2ohYHT0?o^HNQ1?nbPZ000on/OJ3o^hfVok^=YP02
okV?Z`CobZNe0on_PZ<00onTM9goa^O^olKWkP02olKWkPCoaJk300Go^iJaok>7Y_ncQjKo/hNVojf4
Z@03oknCZPCo[X:V00?oY7bXoknI/?noVK000_noVK04ok>>/003olNX^_niU[?o^IJc00;o^IJc00?o
[8jfokjU_onnYKl00_nnYKl3okFL_`03ol:bb_nfY<Ko]ZC600;o]ZC60on]WlT00oni/=7o/:[Bok2Z
dP04ok2ZdP04ojZYe_n`/MSo/;7Hok2af0CoZjkJ0_nW[md2ojbfh0GoZKGR0_nW]^@2ojVii0?oZ;WU
00Co0000ojRiiOnW^NKoYkWV0_nY_>L4ojRlj003ojRmjOnY_nWoZKoY00;oZKoY0onY_nX00onY`>[o
ZL7[ojW1j`03ojW1j`[ooooo0ol00005ooooo`03o`000?oooooooooo00?ooooo00?oEEEEofIVI_l0
00002oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001Oooool2o`0001_ooooo1?nT_n`3oingjP;oV[3V00CoS[3^ohJ[kOn6ZngoQZ_]0_mlXn`3
o`0000;oNYoY0omlW>H3ohFJh0?oTIWH1?nHU]03oifDb@CoWY761?nLSlD2oi^?a`;oW]km00?oZI>o
oj>9^?nSRKP00_nSRKP3oij0/P?oV7R]0onDLJT4oi5/Y@?oSVRS0on;IJ43ohUSW`CoRF6N0on8HIh3
ohMPW@?oQEnM0on2GIh4ogaJW`?oLeJR0_m_F:P2ofaR]@;oN5>J0omjEI/4oh1KW@?oTfVO0onRM9l0
0omef:7oSUZ?ohiJS`04ohaHSPCoReN>0on:Ehl00on:F93o^HNQokV7X@02okV7X@Co/X:P1?nkSJH0
1OniSj_ocjF]olnU[Oo?YJgobZNe00;o[h:S00?o[WfOoj1`W?nPL9`01?o6inh2olF^``Go/hNV1?no
TjX4ojj2YPKo_iV`0_ncS[02olNX^PCo^IJc1OnnYKl2okFL_`;o`[;:1OnfY<H01?n]WlWo^K3AokV`
dOni/=44ok2ZdP03okJhfon`/MSo/;7H00?o/;7H0_n[[]X2ojnih0Co[;KP0_nY]N82oj^ji0GoZKWT
0_nX^ND00onY_>Oo0000ojVli`04ojVli`;oZ;cX0_nY_^T4ojVoj@03ojVoj_nY`>[oZL3Z00;oZL3Z
1?nY`N/6ooooo`Co00002?ooool00ol0003oooooooooo`0Aooooo`002Oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo01_o
oooo0_nT_n`00onK_?3oU;K^oiBfkP02oiBfkP?oS[3^00CoQZ_]o`000?l0003o00000_mlXn`4ogZO
j@?oO9cV0on5V^03oi6If0?oV9K@0onMU<T5oijAaP;oW8o50onMfod00onNg_goZI>oojVC_`04oj>9
^0?oWX2b0onHN:d4oiAaZ@?oTFbU0on>J:<3oh]UX@?oRF>O1?n9HIh3ohQQWP?oQf2M0on5Gid4oh9M
WP?oO5ZO0omcEZ82ofmHZ0CoK6:e0omjEI/4oh1KW@?oTfVO00?oXWBOoi1MTOn@GI400on>FXl4ohaH
SPCoReN>0on:Ehl5okV7X@Co/X:P1?nkSJH01?niSj_ocjF]olnU[Oo?YJd4ojimW`CoX72L00CoUfZM
ok^@ZOnkT:Wo^i2Y1OncQjH4oknCZPCo[X:V00?objfkoknI/?noVK000onoVK001?ncS[3oajRjolNX
^_o7Z;X4okVF/`03oljlbOnnYKoo_ZFo00;o_ZFo00?o]Ibool:bb_o2//X00_o2//X3okJTaP03oknl
f?ni/=7o^K3A00?o^K3A00?o/:[BokJhfonf^=/00_nf^=/3ok2af003ok>ohon_^N3o[kWP00?o[kWP
0_n/]^02ojjni@CoZk[T0_nY^N@2ojZnj0?oZKcW00Co0000ojVlionY_>OoZKcW0_nY_nT5ojVnj@;o
ZKoY0_nY`NX3ojW0jP;oZ/7[1?nY`N/2ooooo`?o00003?ooool00ol0003oooooooooo`0Aooooo`00
8_ooool00ol0003oooooooooo`0Mooooo`?oVkc`1?nD]^h3o`0000?oQZ_]0omlXn`4ogZOj@?oO9cV
0_n5V^03oi6If0CoV9K@0onMU<T2oijAaPCoTm[n0_nMfod00on_W/KoZI>oojVC_`02ojVC_`CoXhVh
0onNP;83oiQh[@?oU76Y0onAK:D3ohiXX`CoRfFQ0_n9Hil4ohUQWP?oR66N0on7H9d3ohEOW@CoPUfN
0omlFYl3og=FXP?oKeRX0om/H[D3of5le`CoP5^M0_nCJIl01?nCHICoT5fAoi1MTOn@GI44ohiJS`?o
S5R>1?n;Ehh3ohYGS`Go^HNQ0onbPZ05ok^=YPCocjF]1On^OIl3oj1`W0Co^i2Y1?ncQjH2ombo_0Co
_i>Z0_n^PZH2ol^]^`Go_iV`1Oo7Z;X2okVF/`;oc[c90onnYKl00oo=cmco`[;:ol:bbP03ol:bbP03
okJTa_no_=So_kcH00;o_kcH0oni/=42okc8h`Co][SK00?o/;7Hok>ohonc_n<00_nc_n<3ojnih003
ojk4jOn^_^Go[[kU00?o[[kU0_n[^^@2oj_1jPCoZ[kX0_nY_>L00onY`>[o0000ojW0jP04ojVoj@;o
ZKkY0_nY`N/5ojW1jP03ojW0j_nZ`N_oZ/7[00;oZ/7[1?nY`N/00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo01kooooo0onK_?000onD]^ko0000
o`000002ohjglP?oQKGe1?mh/oP3of:_nP?oBj_i0olcY_801?l]Z>goTIWHoi6If?nAVMP2oiRFd0?o
F/Ki1?moe_l2oi?JoP04ok>Xc_n_W/Ko[ik6ojnNaPCoZI>o1?nSRKP3oij0/P?oV7R]0onDLJT3oi5/
Y@?oSVRS1?n;IJ43ohUSW`?oRF6N0on8HIh3ohMPW@?oQEnM1?n2GIh3ogaJW`?oLeJR0om_F:P4ofaR
]@CoHGcG00?o:JWYofA:W_mG@ih00_nCHI@3oi1MT@CoSUZ?0on<F8h4oh]GSP;oRUN?00?o]hRSokV7
XOniQj401?niQj42ok:2X0Go^hfV00Co0000olnU[Oo?YJgocjF]1On^OIl3oj1`W0Co^i2Y0oncQjH3
ombo_0Co_i>Z00Co[X:Vol^]^oo;[K_objfk1?noVK000ooRhm?oajRjolNX^P03olNX^P03okVF/oo>
_<Woc[c900;oc[c900Co_ZFoolg?g?o=cmcocLoL0oo2//X2olCFj0Go_kcH00?o^K3Aokc8honlb><0
0_nlb><2okJhf`;o/l[[1?nc_n<00on_^N3o[/CYojk4j@02ojk4j@?o[[kU00?oZlK]oj_1j_n[`NX0
0on[`NX2ojZnj0;oZL;/0onY`>X01?l0003oZL3ZojVojOnY_nT2ojW2k0CoZL7[0_nY`NX2ojW2j`Co
Z/7[00?oZL;[ojW1jonY`N/00onY`N/@ooooo`03o`000?oooooooooo013ooooo000Rooooo`;o0000
8?ooool3o`000003oiBjl_n>]o;oS[Ob00;oS[Ob0on5]OD2ogRcn0;oNkom1?mR_od2ocZfkP?oE<gY
0_nKk?T3okoSl@;o`LoU0oo3c>400ong/]Co/jS>ok>XcP02ok>XcPCo[ik60onYTkl2oj>9^0;oTgbg
0on>M[<3oh]`[`?oR6b]0on6JZ`3ohAYZ`CoRfFQ0on9Hil3ohUQWP?oR66N1?n7H9d3ohEOW@?oPUfN
1?mlFYl2og=FXP?oKeRX1?m/H[D3of5le`?oI4ZN0_mG@ih01?nCHICoT5fAoi1MTOn@GI44ohiJS`?o
S5R>1?n;Ehh2ohYGS`;o]hRS1OniQj400onbPZ3o]8NUok^=YP03ok^=YP;o00000oo?YJd5ojimW`;o
X72L0_o1WkH4ok^@Z@;o/hNV0ooL_k`4oknCZPGobjfk0_noVK03on;Sd`?oajRj00?ocNgZoljlbOo>
_<T00_o>_<T2ojCgh0CocLoL00?o`[;:olCFj?o4e^P00_o4e^P2oknlf0;o^=kc1?nlb><00on/f_So
/l[[ok?:j`03ok?:j`;o/koS0_n]cO04ojk4j@03ojjniOn[a^goZlK]00;oZlK]0_n[`NX2ojO6k`Go
ZL;/0_nY`>X00onX`ngo0000ojW2k004ojW2k0;oZL7[0_nY`n`4ojW2j`03oj[1jonY`^_oZL;[00;o
ZL;[1?nY`N/@ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo01cooooo
0ol000000oooooooU;[boiBjlP02oiBjlP;oS[Ob0_n>^o@4ohNmn0?oNkom0_mR_od2og_EoPCoXn;l
00?oVnciokoSlOnoho401Oo1cnD01?o3c>7o]k;DokNbe?ng/]@4ok>XcP;o[ik600CoWXg2oiR4_?nH
Q;coV8Bl1?nCO;L3ohif/`?oRg2_0on8K:d3ohIZ[0?oQ6V[1?n3J:`3ohA[[P?oRF6N0on8HIh4ohMP
W@?oQEnM0on2GIh4ogaJW`?oLeJR0om_F:P4ofaR]@03of5leomaDj3oI4ZN00;oI4ZN0_mG@ih01?nC
HICoT5fAoi1MTOn@GI44ohiJS`?oS5R>1?n;Ehh01?n:Ehoo]hRSokN8XongR:<5okV7X@03ok:2X?nd
QjGo]8NU00?o^hfV00?oZH2Wo`000?o?YJd00oo?YJd4ojimW`04oj1`W?o1WkKo`Infol6O]PCo^i2Y
00?o/hNVombo_?oL_k`00ooL_k`2oknCZP;oeo;S1?o;[K/00onoVK3oh^?Con;Sd`02on;Sd`03olNX
^_o=kN[ocNgZ00;ocNgZ0_o>_<T4ojCgh0;ocLoL0onGk?H2olCFj0;oQ>Kc1?nhg_<00onlb>?o[=[h
ojcJn002ojcJn0;o/l[[0_nSeoX5ojg=l0;o[/CY0onWc?<2oj_6k@;oY<_d1?nWa^l2ojW2k0;oY/G`
0onX`nd01?l0003oZ<?]ojW2k?nY`^`2ojS4k@GoZL?/0_nY`^/2ojW2k0?oZL;[0_nY`^`4ojW1j`oo
oooo00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool06Oooool3o`0000Kooooo
0onB^_84ohjkm0;oQkgh0onBa_T2oh_>oPCoX]Oj0_nSh_`2ok[NlP;o_]7X1?o1cnD00oni^][o]k;D
okNbe002okNbe0?o/jS>00?oXiO8oij=`_nNSL800_nNSL83oiR4_0?oTgbg0on>M[<4oh]`[`?oR6b]
0on6JZ`2ohAYZ`CoPfR/0on4Jjh3ohI_/P?oQGBh1?n7H9d3ohEOW@?oPUfN1?mlFYl3og=FXP?oKeRX
0_m/H[D01?m/E:CoMURRog5CX?maDj03ofA:WP?oEd>N0on@GI44ohiJS`?oS5R>1?n;Ehh01?n:Ehoo
]hRSokN8XongR:<5okV7X@?o]8NU0_nkSJH4ojV0Y`?ocjF]0on^OIl00oo1d^Oo`Infol6O]P02ol6O
]PCo^i2Y00?o0000ombo_?oL_k`00ooL_k`01?noTj[oeo;SomObhooGl^<3ol^]^`03ok>@/_nGS/Wo
000000;oh^?C0_nJTLT01OlW003ocNgZolg]j_o=kN[oc[c900?oY?OP00?oJZ?boifQf?nMXMP00_nG
k?H00om`YO7o08o4o`2?a004ohCVl`;o^=kc0on7god2ojcJn0?oQ=[n0onSeoX2ojg=l0?oWm;j0_nW
c?<2oic?n@GoY<_d0_nWa^l2oj;7l`CoY/G`0_nX`nd00onVaNoo0000ojS4k@04ojS4k@;oZL?/0_nX
`nd5ojW2k003ojW2jonY`^coZL;/00;oZL;/0_nY`N/00onX`N_oooooooooo`0=ooooo`03o`000?oo
oooooooo013ooooo000Rooooo`03o`000?oooooooooo01Kooooo0ol0000:ooooo`?oT[[b0_n>^o@3
oiG0m@;oT/Ki0onQcOL3oj;GnP?o/mOc00?o^]kbokkAj?nndNP00_nndNP00oo1cnGo^K[JokVjfP02
okVjfPCo]k;D00Co/jS>oj>Gb?nSUlSoXiO80onNSL83oiR4_0CoTgbg0on>M[<3oh]`[`?oR6b]0on6
JZ`3ohAYZ`?oPfR/0on4Jjh3ohI_/P?oQGBh1?n4O<84oh>9d@CoO:?/00?o7ZCRoh=JV_n3FYX00_mn
EiX2ofmHZ0;oN5BL0om/E:@3og5CX0;oI4ZN0omG@ih00omMBJ;oT5fAoi1MT@04ohiJS`?oS5R>1?n;
Ehh4okN8X`Go^HNQ0ondQjD00onkSJKoYW^TojV0Y`05ojV0Y`03oj^;]?n^OIoo`M;W00;o`M;W1?o1
WkH4ok^@Z@04ojF6/oncQjKog;nlombo_0?oYWnZ1?oGl^<00oo;[K_o/i2bok>@/P05ok>C]@04oiZA
bOneW;ko]IbnokFL_P?oWigB00?o]J33oifQf?nMXMP00onMXMP4og2Ul@?o@Jgf1?l/[^L3oe?8lP;o
Q=[n0omZbod4oh_Do`;oWm;j0_n>d?h4oic?n@;oY<_d0_nLb_L5oj;7l`;oY/G`0_nRa_83ojK5k`03
o`000?nXa>goZ<C]00;oY/C_1OnX`nd2ojW2k0?oZ<;]0_nY`^`2ojS1k0CoZ<7[3_ooool00ol0003o
ooooooooo`0@ooooo`008_ooool2o`0001Cooooo0ol0000>ooooo`CoUk_a0_nE`?D2oio5l`GoXLgg
00CoX]Ojok?Glonceo?o/mOc0_nicn/3okkAj0?o^L3O1?ni^]X2okNbe003ojRPc_nSUlSoXiO800;o
XiO80onNSL83oiR4_0CoTgbg0on>M[<3oh]`[`?oR6b]0on6JZ`3ohAYZ`?oPfR/1?n4Jjh3ohI_/P?o
QGBh0on4O<85oh>9d@;oO:?/00CoQUjLoh=JV_n3FY[oPeZJ0omnEiX3ogQDW0?oK5BT0_l]C/401?ma
Dj3oI4ZNofA:W_mTBYh2oeM3WP;oGDVR00?oT5fAohiJSon>FXl00_n>FXl3ohaHSP?oReN>00?o[h>V
okN8XongR:<00_ngR:<4okV7X@Co]8NU00?o^hfVojIkY?nVNj@01OnYP:L00on[RkCo_HjUol7Bi`03
ol7Bi`Co`Inf0_nkT:T00onjSjWo/hNVok>7YP02ok>7YPCoYWnZ00?o`iR[ok>@/_ncT;800oncT;85
ok>C]@Go]Ibn00CoWigBokFP`oneX<?o]J330onMXMP00onbYlkoWJ_Qoif[h@02oif[h@GoP;Kg0omL
^O`4oeO0n`;oJ/_m0omX`_h3og_<o`CoS]3n0_nLcoT2oi?;n`CoW<[g0_nRao<2oig7m@GoX/Kb0_nV
aNl00onSaO7o0000ojK4k`03ojK4k`;oZ<?]0_nW`nh4ojS2k@03ojO2kOnX`NcoZ<7/00?oZ<7/1?nX
`N/=ooooo`03o`000?oooooooooo013ooooo000Qooooo`;o00004_ooool3o`0001;ooooo0_nG^o42
oijmk`CoWlGc0_nQcOL4ojk@lP03ok?Glonicn_o^Lo[00;o^Lo[00?o_]7XokW0goni`=l00oni`=l2
okVjfP03ojfXdonXX<koZ:3>00;oZ:3>0onSUlP4oij=`P?oV8Bl0onCO;L3ohif/`?oRg2_0on8K:d3
ohIZ[0?oQ6V[1?n3J:`3ohA[[P?oQVnb0on5M;P4ohAl`P?oPhWA00CoRfFPohINW?n6GYcoQUjL0on3
FYX3ogiGVP?oN5BL1?m/E:@2obe>`@?oI4ZN0omG@ih2oee9XPCoSUZ?0on<F8h2oh]GSP?o[h>V1?ng
R:<2okV7X@03ojUoY_ndQjGo]8NU00;o]8NU0onVNj@5ojV0Y`?o_HjU0oo1d^L4ol6O]P03ok^@ZOnj
SjWo^XnY00Co/hNV0onVOjX3ol>HZ`?o/i2b00?o`ib`ok>C]OncTkD00oncTkD5okFL_PGo]J3300Co
WJ7Hok:Wc_nbYlko/ZO>1?nMZn42oh2fm`?oWKCX1?n2^OP3ofjnoP;oJ<;n0_mf__d5ogc5oP?oQ/Wn
1?nCbo/2oic:m`?oU/Sh0onMaoD2oj;6lP;oWlGc0onSaO401?l0003oXlGaojK4konVa>l2ojG3k`Co
Yl?^00?oZ<;]ojO2kOnW`^d00_nW`^d2ojS1k0;oYl7/1OnX`N/<ooooo`03o`000?oooooooooo013o
oooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo00oooooo0_l0000Fooooo`CoW[g_0_nOaO<4oj[8k`;o
[]3b0onec>/2okW?j`;o^<?R1?ni`=l00on`/=So[JSCojfXd`02ojfXd`?oZ:3>1?nSUlP3oij=`P?o
V8Bl0onCO;L3ohif/`CoRg2_0_n8K:d3ohIZ[0?oQ6V[1?n3J:`3ohA[[P?oQVnb0on5M;P4ohAl`P04
oh>9dOn;IJ3oRfFPoh]UX0?oQUjL0on3FYX3ogiGVPCoN5BL0om/E:@2obe>`@?oI4ZN0omG@ih2oee9
XP;oM5^W0_n>FXl3ohaHSP03oh]GS_n_PjKo[h>V00;o[h>V1?ngR:<2okV7X@03ojUoY_ndQjGo]8NU
00;o]8NU0onVNj@5ojV0Y`Go_HjU00CoZ7jVol6O]_o1WkKob9j]0onjSjT2olZO[@Co/hNV0_nVOjX3
ol>HZ`;o/i2b0oo3W;03ok>C]@;oaZBf0oneW;h00oo2YKco]J33okFP``02okFP``03ol:Z`_nbYlko
/ZO>00?o/ZO>0_nMZn42ok2_eP?oWKCX0_n]^>44oiRjk`CoQ;ci0omf__d2ogc5oP;oPL3k1On5a?`3
ohk7n`;oU/Sh0_nCa?P5oi[5m@?oWlGc0_nSaO400onRa?7o0000oj;4l@04ojG3k`;oYl?^0onV`^h2
ojO2k@;oY/7]1?nW`N`2ojS1j`;oYl3/3Oooool00ol0003oooooooooo`0?ooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool03?ooool3o`0001Wooooo0_nN_Nl3ojO0j`?oZ/S_0_nbanT3okG<j`;o]lCT1?nh`n80
0oni`=oo/;3Hok2`f002ok2`f0Co[JSC0onXX<h2oj>Gb004oiJ<a_n@QL?oT8G3oi25``?oRgo10on5
Nl03oh5i`@?oOG[400CoRg2_ohQ/[On8K:goR6b]0on6JZ`3ohAYZ`?oPfR/1?n4Jjh3ohI_/P?oQGBh
0_n4O<82ogALZ0;oKUVY00CoRfFPohINW?n6GYcoQUjL0on3FYX3ogiGVPCoN5BL1?m/E:@01?l]C/7o
TVbTofA:W_mTBYh3oeM3WP;oGDVR1?mdFjL2ohaHSP03oiMcZOn_PjKo[h>V00?o[h>V1?ngR:<00oni
Qj7oZGnVojUoYP03okB7Y@04oiMaYOnVNjCoYW^TojIkY0CoZH2W00?obIj/okf>YOnmSZD00onmSZD0
1?nXOZKob9j]olRN[Oo8WZd3okZ?Z@;obYn]1?ncQjH00onVOj[o`iR[ol>HZ`02ol>HZ`03ok>@/_o3
W;3o`ib`00;o`ib`0_ncTkD3olJT]P;o]Ibn0oo2YK`2okFP``?o`Z[20onbYlh00onm[/[o/:oFok2_
eP03ok2_eP03oifdj?n]^>7o[KSQ00;o[KSQ0_nH^^l2ojFkj@?oTk_c1On4_?T3oh70n`;oQLCl0_n7
_oT4ohg2n@CoTlCh0_nJaOD2oiS2m@GoWL?c0_nRa?400ol0003oX<;`oj?2k`03oj?2k`;oY/;^0_nU
`Nh5ojK1k@;oYl7/1_nW`>`<ooooo`03o`000?oooooooooo00oooooo0007ooooo`05oa0@4?oooooo
ooooooooool@41002oooool5o`0000Gooooo0_l0000:ooooo`?o00007Oooool5ojO0j`03oj[8konb
anWo//OY00;o//OY00?o]Lc[okO4i?nga>@00_nga>@2okS3hP?o/kOL1?n`/=P2ojfXd`04oj6Kc_nK
Tl[oVi?:oi^CbPCoUXc60on@QL<3oh]o`@?oQG_00on1NL43ogeja0?oNWo<0on6JZ`3ohAYZ`?oPfR/
1?n4Jjh3ohI_/P;oQGBh0omkHj`2ogALZ0?oKUVY0on6GY`3oh=JVP?oOUNJ1?mhE9`3ofaDY0;oJER[
0_nBK:@01?mTBYkoEd>NoeM3W_mG@ih3oee9XP?oM5^W0onGLjT5ojn3YPCo]hRS0onYOjH3okB7Y@04
oiMaYOnVNjCoYW^TojIkY0?oZH2W0_o9WZ`5okf>Y@Gob9j]00Co^XnYolZO[Oo:WjgobYn]1?ncQjH5
ol>HZ`Go`ib`00?o/i>eolJT]_o6Y;H00_o6Y;H00oneW;ko`ZFlol:U_002ol:U_003okFP`oo2Z/;o
`Z[200;o`Z[200?o/ZO>okf^b_nm[/X00_nm[/X3ok2_eP03okbge?n]^>7o[KSQ00;o[KSQ00?o][_N
ojFkjOnU^nT00onU^nT3oi>kl`;oQ;ci0_n>^oD5ohRmn0?oQkoi1?n=`_T2oi?4n0;oT/7f1?nH`_D2
oig3l`;oW<7b0_nP`_000ol0003oX<;`oj32l002oj?2k`;oX/7_1?nU`Nh4ojK1k@WoYl3/2oooool0
0ol0003oooooooooo`0?ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo00001_ooool00ol0003oooooooooo`06ooooo`?o00008Oooool2ojO0j`Co[l;W0_nb
anT2okK4i@?o]lCT00?o];_Ook>gg?nc]m`01?nc]m`2ok2`f003ojJSdonQVlkoXI_>00;oXI_>0onK
TlX3oiJ<aP?oT8G30on;Ol43ohEk`0?oPGW10ommN/@3ogYoc0CoMX[J1?mYX?401?l_[^_oYIO6ojFG
a_nUUlH4oiB1^`;oQg2b0omkHj`3ogALZ0;oKUVY0_m^GJh00on6GYcoPeZJoh=JVP02oh=JVP?oOUNJ
0omhE9`2ofaDY004ogM[^?mYF:_oJER[of9AZ0;oTVbT0omG@ih3oee9XP?oM5^W1?nGLjT4ojn3YPCo
]hRS1?nYOjH00ondQjGoUg6UoiMaY@04ojIkY0;oZH2W0oo9WZ`4okf>Y@03oncMa?o8WZgob9j]00;o
b9j]00Co^XnYolZO[Oo:WjgobYn]1?ncQjH00oo9Xk;o`iR[ol>HZ`02ol>HZ`03omZe/oo3W;3o`ib`
00;o`ib`1Oo6Y;H5ol:U_0Go`Z[21Onm[/X00on`[mKo_;ODokbge002okbge003ojfhhOnf^mko][_N
00;o][_N0_nU^nT2ojfoi`GoW;g_0on>^oD2ohRmn0;oS[_e1?n;_?L4ohjnm`CoT/7f0_nH`_D2oiS0
l`CoW<7b0_nP`_000ol0003oWl3`oj;1k`04oj;1k`;oYL7^0_nT`>d4ojK1k@;oYl3/0_nV`>`5ojO0
k0[ooooo00?o0000ooooooooool03oooool000Oooooo00Go0000ooooooooooooooooo`00000;oooo
o`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool00oooool3o`0002Kooooo0on_`^L2
okC3i@Co]/CU00Co]lCTokBkgond^moo];_O1?nc]m`00onZZmOoYZ?CojJSd`02ojJSd`?oXI_>0onK
TlX3oiJ<aP?oT8G30on;Ol43ohEk`0?oPGW11?mmN/@3ogYoc0CoMX[J0_mYX?42oi=m^0?oR72a0omm
IZh00onDPK_oQg2bohM`/P03og]S[0?oM5bX0_m^FJT3ofiM[PCoPeZJ0omnEiX3ogQDW003ofaDY?n_
hoWoMf^h00;oJER[0_mRDJP00onBK:CoPebLoh=LW002oeM3WP;oGDVR1?mdFjL3oiMcZ@Go[h>V0_ng
R:<00onHLjSoZGnVojUoYP02ojUoYP03okB7YOnGLJGoUg6U00CoYW^T00?oZH2WolVN[?o9WZ`00_o9
WZ`3okf>Y@;ok=g41?o8WZd4olZO[@?o/hNV0_o9Xk83ol>HZ`;of[Fc1?o3W;000ooD][coaZBfolJT
]P02olJT]P03om:f__o2YKco`ZFl00;o`ZFl00?ob[;2ol:Z`_o2Z/800_o2Z/800oo:]<Go_Jk:okf^
bP02okf^bP04olJhcOnl]mCo_;ODokbge0;oa;kD0onf^mh2ok_2g`Co[KoW0_nL_Nl2oj6nk@GoU;_b
0on>^oD4oh^lm`;oS[kg00?oSkceoi:nm?nB__@00onB__@4oiS0l`;oW<7b0_nK_o42oio0l004o`00
0?nO`?3oX/7_oj;1k`;oX/3^1OnT`>d2ojK1k@03ojG0k?nV`>coY/3/00?oY/3/0_nW`>`2ojK0k0[o
oooo00?o0000ooooooooool03oooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
ogMgMoo<c<co000000Gooooo00Co0000oooooooooooooooo0ol0000Zooooo`03ojo2iond`nGo]<?U
00;o]<?U0_nfa>D2okFohPCo];_O00?o/kOLojZ[eonZZmL00_nZZmL3ojJSd`CoXI_>0onKTlX3oiJ<
aP?oT8G30on;Ol43ohEk`0?oPGW10ommN/@4ogYoc0;oMX[J0onPSL02oi=m^0?oR72a1?mmIZh2ogEP
[@03ohM`/_mkHjcoNf>/00?oM5bX0om^FJT2ofiM[P;oM6bk0_n3FYX3ogiGVP;oN5BL0_n_hoT2ogM[
^0?oJER[0_mRDJP3oh=LW003oeM3W_mMBJ;oGDVR00CoM5^W0onGLjT5ojn3YP03okN8XonHLjSoV7>X
00CoZGnV0onGLJD4ojIkY0GobIj/0_nmSZD3oncMa0Cob9j]00?oi?3EolZO[Oo:Wjd00_o:Wjd01?nc
QjKobJ>bolVS/_o9Xk83ol>HZ`;of[Fc0oo3W;02omBf_0?oaZBf0_oB][h3ol:U_0;ob[;20oo2Z/82
olZda@?o_Jk:0oo6^<d00onl]mCoa;kDolBne002olBne003okJkg_nk`]oo^l;O00;o^l;O0_n]_nL2
ok32i`CoXKk]0_nD^o82oiRml@?oTK_c1On>^o@3ohnlm@;oT[kd0_nC_?<4oiNnlPGoVkoa0_nO`?00
0ol0003oX/3^oj;0kP03oj;0kP;oY<3]0_nT_nd4ojG0k0;oY/3/0_nV_n`5ojK0k0Wooooo00?o0000
ooooooooool03oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co
000000Gooooo1?l0000^ooooo`?o]<?U0_ne`n@4okFohP;o];_O00?o[[?LojZ[eonZZmL00onZZmL4
ojJSd`;oXI_>00CoUigGoi6Ge_nAUmKoTIOF0on<U=H3ohJBf0?oPI?L1?mjV^D3og>Yl`CoHKkm00Co
bn7XojbOb_n/Wl[o[9o:0onPSL03oi=m^0?oR72a0ommIZh3ogEP[@?oNf>/0_mdG:P3ofiIZ@?oKUf^
0omdK;/3ogiGVP03ogQDW?n_hoWo[n?i00;oHdnV00CoMf^hofUHZomYF:_oJER[0_mRDJP2ofmO/004
oh=LW?mfDY[oGDVRoee9XPCoM5^W0onGLjT5ojn3YP04okN8XonHLjSoV7>XoiQcZ0?oZGnV1?nGLJD3
ojIkY003om>h_oo9WZcobIj/00;obIj/00?o_HjUoncMa?o/gL@00oo/gL@2olRN[@;oi?3E1?o:Wjd0
0oncQjKobJ>bolVS/P02olVS/P03ol>HZooJ]K?of[Fc00;of[Fc00?o`ib`omBf_?oD][`00_oD][`0
0oo6Y;Kod[Jnom:f_P02om:f_P03ol:U_?o://;ob[;200;ob[;200?o`Z[2olZdaOo:]<D00_o:]<D0
0onm[/[oa[S=olJhc@02olJhc@Goa;kD1?nk`]l00onnan7o/<;Wok32i`03ok32i`;oXKk]0_nT`Nh4
oiRml@?oTK_c0_n>^o@2oi2jl`CoTK_c1?nC_?<4oiNnlP;oVkoa0_nK__02oinok`04o`000?nO_noo
X/3^oj;0kP;oXKo^1OnT_nd2ojG0k0;oYKo/1?nV_n`2ojK0k0;oY[o/2Oooool00ol0003ooooooooo
o`0?ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01?oo
ool2o`00037ooooo00?o]<?UokG3i?ne`n@00_ne`n@2okFohP03ok6khOn^/mco[[?L00;o[[?L1OnZ
ZmL2ojJSd`03oibSf_nGWMOoUigG00;oUigG0onAUmH3ohbDeP?oQY;H0on1Tm`4ogZJi@?oLjWc00?o
HKkmolS^k_nf/M@01?n/WlX3oj2=`0?oTgfh0on8L;43ogeV[P?oMF2]0omYG[<2ogALZ0?oKUVY0om^
GJh3ogA/^`GoR9;G0_mfGJT2of=?YP03ogM[^?mYF:_oJER[00;oHU6X0om_Gk02ogIBVP;oGDVR0omd
FjL3oiMcZ@Go[h>V1?nHLjP2ojUoYP;oPfNZ0onGLJD2ojIkY0;odkRo1?o9WZ`00onFKJ7oWg>QoncM
a003oncMa004olRN[OoTl=Goi?3EonC`e@?obYn]00?od]gQolVS/_o9Xk800oo9Xk800oo3V:_of[Fc
omZe/`02omZe/`Goe;Jl1OoB][h5olZb`PGob[C500Coc[k;olJhcOo6^<goa[S=0_o;`M43olBne0;o
b<GG00?o^l;Ookk7hOnnan400_nnan42ok32i`;o//KY1OnT`Nh2oiRml@03oiZmlOnC^o;oTk_b00?o
Tk_b0on@^_<4oi6kl`;oTkcc0_nC^o84oiRll@CoVkk`0_nO_nl00ol0003oWkk_oj6okP03oj6okP;o
Y;o]0_nS_nd5ojFok0SoY[o/2?ooool00ol0003oooooooooo`0?ooooo`008_ooool00ol0003ooooo
ooooo`0_ooooo`?o]L?T00?o//;Vok6khOna^n400_na^n44ojjcg0;oZZ_G0_nQZ]d4oibSfP?oUigG
0onAUmH4ohbDeP?oQY;H0on1Tm`2ogZJi@04o`000?o2l_3o`_;`okc1g@Co][7D0on/WlX4oj2=`0;o
Tgfh0on8L;43ogeV[P?oMF2]0omYG[<2oeMWb003ogALZ?m^FJWoKUVY00?oKUf^1?mdK;/3ohRBe`?o
MUfY0omSCjH2ofUHZ`?oHU6X0_m_Gk03oi24``04oee9X_mdFjOoM5^WogAKY`CoUg>Y0on_PjH00omo
I:WoV7>XoiQcZ002oiQcZ004ojUoY_mLGK[oPfNZoh=WZP?oUg6U00CoYW^Tom>h_ooC^;oodkRo1?o9
WZ`00onFKJ7oWg>QoimcX@02oimcX@CoV7BY00?o_inhonC`eOo:Wjd00ooBgN44olVS/PGof[Fc00?o
io;BomBf_?oD][`00_oD][`01?oLhMWod[Jnom:f__oB][h2omC8cP?ob[;20_o>_l`3olZda@?oc[k;
00?oa[S=ol_1dOo;`M400_o;`M401Oo4_]Cob<GGolS5eoo8aMOob/_K00?o_/OQ0_nobn<4ok;6j@;o
Y<7^0_nU`^h4oiZml@;oTk_b0_nD^_84oi6ilPCoTK[b1?nC^o82oiRll@;oV;_`0onK_>l3oinnk`04
o`000?nO_^ooXKo^oj6okP;oXKk]1?nS_nd4ojFok0SoY[o/2Oooool00ol0003oooooooooo`0>oooo
o`008oooool00ol0003oooooooooo`0_ooooo`04okG3i?nb`^Ko//;Vok;2iPCo/K_Q0_n^/m`2ojFa
h@CoXJ[M1?nLXmX3oiNMe`?oTIOF0_n<U=H2oh6fm`CoL/7n0_mDao@3ol;bl0?o_<7M1?nf/M@3ojbO
bP?oX8g00onCOKP2ohQ`/@CoOFJ^0_meH:d4ofUN/`;oEfO80om^FJT3ofiM[PCoM6bk00?oR9;GohYc
/omfGJT00_mfGJT3of=?YP03oeA@/?mYF:_oHU6X00;oHU6X0om_Gk03oi24``CoM5^W0onGLjT2ojn3
YP04oe1;[?mIBJCoV7>XoiQcZ0?oDDNW0omLGKX2oiMaY@03ojJYfOoC^;oodkRo00?odkRo0_o9WZ`2
oiI]X@CoWg>Q1?nHM:T00onlSZKo_inhom;Mh@03om;Mh@CobJ>b00CogoCJomZe/ooJ]K?of[Fc0_oW
l]83omBf_0?og>7I00?od[JnomC8c_oDb<h00_oDb<h00oo://;oc[o<oljoc002oljoc005olZdaOo>
_/_oc[k;oljnboo?am801?o;`M401?o=b=Gob<GGolS5eoo8aML3ol[;f`03okk7hOnobn?o_l_S00;o
_l_S0_nba^T2ok;8jPCoYL;^0_nJ_O42oiZml0CoU;[b1?nA^O82oi6jlP;oT[Sa0onD^O45oiRkl0?o
Vkc_0_nO_^l00ol0003oW[g^oj6nk@04oj6nk@;oXko]0_nS_^`4ojFok0SoY[o/2?ooool00ol0003o
ooooooooo`0>ooooo`009?ooool00ol0003oooooooooo`0_ooooo`Co//;V0_na^n42ojRii@CoYK7Q
1?nQZ]d2oibSfP03oiB^jOn?[N_oSjg[00;oSjg[1?n8[nl3oh6fm`;oL/7n00CoIm_TokSam?nhlOCo
^?7d0_nnc>D4okc1g@;o][7D00CoWYO<oi>:aonCR/OoTh[70on8O/83oged_`?oR72a0ommIZh3ogEP
[@?oJEjc1?mGIlP01?l0M<ooKUf^ofiM[_m^GJh2ogA/^`;oMVfk0_mMFK@00on:Lk?oMUfYogIMZ@03
of=?YP;oE52`00?oJER[of9AZ?mRDJP00om_Gk04oi24``03ohQn`OmdFjOoM5^W00?oUg>Y00?o[h>V
oe1;[?m@Bj`00_m6D;T2oeU9Y0;oDDNW0omLGKX4ojJYf@CodkRo00CobIj/oiI]XOnFKJ7oUVfQ1?nO
Lj43oiQdZ@;o_8jV0_noWkP3om;Mh@?obJ>b0ooOm=X00ooJ]K?oio;BonObdP02onObdP04omBf_?oL
hMWog>7IomcQf@;oW>ch0ooDb<h00oo8f>Goc[o<oljoc002oljoc004ol[7eoo>_/_oc[k;oljnb`?o
clOB0_o;`M43olg8e@03olS5eoo:bm_ob/_K00;ob/_K1?nobn<00onncNGo//SZok;8jP03ok;8jP;o
YL;^0_nT`^h4oiZml0;oU;[b0_nD^O43oi6hl@GoT[Sa0onD^O42oiRkl0;oV;[_1OnK^nl00onN_Nko
0000oijmkP02oj6nk@;oXKg]1OnS_^`3ojFok0OoY[o/0_nV_n/7ooooo`03o`000?oooooooooo00ko
oooo000Uooooo`;o0000<?ooool2ok;2iP;oZL3Z1?nX^ND2ojFah@;oW;GY1?nI/NP3oiB^j@CoSjg[
0_n8[nl3ohCAo`;oN]_k00?oN>CLokSam?nhlO@01Onnc>D2okc1g@03ojRTdonNUlcoWYO<00;oWYO<
0onCR/L3ohQn`P;oOGBo0omeLL43ogeV[P?oMF2]0omYG[<3oeMWb004o`000?nc]][o/kKJok>ffP?o
T8c;0omfKK/2oeeI]0;oMUfY0omSCjH3oeA@/0?oHU6X0_m_Gk03oi24``04ogAkc?n8O/7oR7k1ohQn
`@;oUg>Y0_mFBJL00omEDk?oD4^/oe1;[003odI@^@;oDDNW1?mLGKX4ojJYf@;odkRo0_n;K:T3oiI]
X@CoWg>Q0onHM:T2okb>YP;o_inh00Goj<6^ooWEXooieJ?od]gQolVS/P02omodfP04ooWW[ooWg<Wo
/:WAok2Yd@;oio;B0om]N<d00ooLhMWoW>choic/n002oic/n005omC8c_o8f>Gob=SUolSHiOo>_l`0
1?o:amL00oo>_/_oclOBolo7dP02olo7dP03ol_1dOo=b=GocLSE00;ocLSE00Coc/kIol[;foo:bm_o
b/_K0_o:cmh00onobn?o_/gUokk=i@02okk=i@;o//SZ0onab>/2ojC2kP;oY<7^0onJ_?05oiBil@?o
TKSa0_nB^?42oi>gl0CoUKS`1?nH^^l2oi^kk`;oVk_^0_nO_>d00ol0003oWkc]oj6mk@03oj6mk@Co
Xkk/1?nU_n`4ojJok0GoY[o[1_ooool00ol0003oooooooooo`0>ooooo`009oooool00ol0003ooooo
ooooo`0^ooooo`CoZL3Z0_nX^ND3oijik0?oW;GY1?nI/NP3oiB^j@;oSjg[0on;b?`2ohCAo`;oP^Gb
0_nak?P3okcBj`;o_/cU0_n_/=T4ojRTd`?oWYO<0onCR/L3ohQn`P?oOGBo0_meLL43ofieb0?oMF2]
1?mYG[<00omGIlSoc]oUolkOi@03ok>ffP?oT8c;0omfKK/2oeeI]003oeiN^_mfGJWoMUfY00?oHdnV
0omDD;02oaeWf`?oKen`00CoT8C3ogAkc?mdNlco>dFb0_n8O/42of]IZ`?oETVW0_m@Bj`5odI@^@04
oe57YomLGK[oG5fjoeaM^P;oYZWI00?odOo<ojFDa?nUU<@00on;K:T3oiI]X@GoWg>Q00?oV7BYokb>
Y_nlSZH00_nlSZH01?noWkSoj<6^ooWEXooieJ<2oocOX`;onNN_0ooWg<T3ok2Yd@?oKGS=0_lnFlP0
0ol0:K;o5J3HoaFPf003olSHi@03ojc?loo:amOob/OG00?ob/OG00Coa<_Oolo7d_o?am;oclOB0_o>
c=L3olg8e@?oc/kI00?ob/_Kol[?g_o:cmh00_o9dN03okk=i@;o_LgW0onab>/2ok37j`CoY<7^0onJ
_?02oiBil@;oUKS_1?nB]o04oi>gl0CoUKS`0_nH^^l2oiVikPCoVk_^0_nO_>d00ol0003oWkc]oj6m
k@02oj6mk@GoXkk/0_nU_n`2ojFnk0CoY[o/1?nV_n/6ooooo`03o`000?oooooooooo00kooooo000X
ooooo`03o`000?oooooooooo02kooooo0_nY`>X3oj2nkPCoW[W/0onL]NT2oiVaj0;oTkkd1?n?`OP2
oh_8o0;oR^3m0onZi?X01Onak?So_=;[okcBjonld^_o/kWN00Go[k3I0onXY=<3oijGc0?oTh[70on8
O/83oged_`?oMG710_m^MLP5og:>g`05ogg<oooCm^Goc]oUolkOiOnSWLh00on;PL<2og1Y^`;oT8c;
0_mfKK/3oeeI]003oeiN^_mfGJWoHdnV00;oHdnV1?mDD;000olMIm_ogOWJomgifP02ok[9iP?oM7_<
00?o>dFbohQn`Om[FJ/00_m[FJ/2oeI9Y`;oJfRm1?m6D;T2ooS^Y0;oG5fj0_o^l<L01?oJbl_oJ@00
ojFDa?nUU<@3oh]/Z@CoUVfQ1?nOLj400onHM:Wo_8jVokb>YP02okb>YP;oj<6^0_oieJ<2oocOX`03
ooWW[ooWg<Woimc900;oimc90onKULd3og=fa`04ofehcOlnFlSo8U?:ob9CbP;o0ggO00Cob=SUojc?
lon/co?o[<oc0oo:amL3olC;g`03olo7d_o>c=Ooc/cG00;oc/cG00CocLSEolk>fOo>c]Woc/kI0_o>
dM`00oo:cmkobM7PolWAh002olWAh003okk=iOnmcNOo_LgW00;o_LgW00?o/LS[ok37jon`an/00_n`
an/2ojC1kP03oj>nkOnJ^^koV[[^00?oV[[^0onE^>l4oi:gl0;oTkO`0_nD]^l3oiFgk`GoVKW^0_nK
^nh01?nL^^goWkc]oinlkOl00002oinlk@?oXKg]0_nS_^`2ojBnk0GoYKk/0_nV_n`6ojJoj`Gooooo
00?o0000ooooooooool03_ooool002Wooooo00?o0000ooooooooool0;oooool4oj2nkP;oW[W/0_nH
_?44oiJllP?oTkkd0_n?`OP2ohoGo`?oY]cj0_nZi?X3okSDk`04okcBjonc^Mko/kWNok>igPGo[k3I
0onXY=<3oijGc0?oTh[70on8O/82oged_`?oMG710om^MLP3og:>g`;odoKU00?o^[_Joj>Mc_nSWLh0
0_nSWLh3oh^1``?oL6Vk0omfKK/2oeeI]0;oGUjj0omSCjH2oeA@/0;oXN[j00?ogOWJokBmh?nd_N00
0omhOld2ogAkc0;o>dFb0om[FJ/3oeI9Y`;oJfRm00KoAU2iojcam_n/lOKofm[FolkZQ_nkff`2onk`
a`;of/_;00?oJ@00oaLk^?nUU<@00on;K:T4oiI]X@CoWg>Q1OnlSZH01?oT]ZKonMFSooWEXooieJ<2
oocOX`04ooWW[ooWg<Woimc9onOLb@;oa/3E0onKULd3og=fa`;oGFW60_lRDlX2obMkiP05o`=mgon/
co?o[<ocojc?loo:amL00oo4bml2oko9hP?oc/cG0_o>cm/00oo>c]Woc]7LolkAg002olkAg004olkB
gOo9dN3obM7PolWAh0;ob=7Q0_nmcNL3ok_<i`;o/<O[0_n^a>X4oj>nk@;oV[[^0_nK^>d4oiJfkPCo
TkG^1?nD]^l3oiFgk`;oVKW^0_nI^>d4oibjk@;oWkc]00?o0000oinkk?nR_>`01?nR_>`3ojBnk0Co
YKk/2OnV_n/4ooooo`03o`000?oooooooooo00kooooo000Zooooo`;o0000<Oooool3oiZll0CoV;ca
0_nF_?82oiK7n0CoTlkl00CoSmOoojKLn_nVg?[oY]cj0oncd_02okSDk`;o];oS1?nc^Mh2ojn`f@;o
XIkA0onHU<h3oi2<c0?oQHG<0omlQ=03og2;g@?oMG710om^MLP00ombS]oodoKUom?fi@03okZkfP?o
Xig>0on;PL<3og1Y^`?oHf:l0_mMFK@2oeiN^PGoL83D00?oXN[jom__gond_N000_nd_N03ogQoc@;o
C5Bi0_lkAK800omCD[?oJeV[of]IZ`03oeI9Y`CoJfRm0_oKf]H00onkffcok_37onk`a`04om[;b`03
ofT00?lG>kSoYIC400;oRfbY1?nFKJ44oimcX@Co_8jV0_oT]ZH2ookKV0;ol^F100Codn5bon?j[ooS
nZooimc90oo6`=D3oi^Ec@?oLgK70omMJLH2ob9CbP;o9g_V1OnI`O@00oo4bmoo_lWRoko9hP02oko9
hP05olk<eoo>cm_oc/oKolk?foo=d=/00oo>dM`3olkBg@03olWAh?o8dN7ob=7Q00;oa]3Q0onkc>L2
ok[9iPCo[/CZ0_nS_^d2oj>lj`CoVkS]1?nF]^h2oi>ekP;oUK?/0onE]>d4oiJfk@CoVKS]0_nL^^d2
oifik0;oWk_/00?o0000oinkk?nR_>`00onR_>`5ojBmk0?oYKk/2OnV_n/3ooooo`03o`000?oooooo
oooo00kooooo000/ooooo`03o`000?oooooooooo02oooooo0onJ_?02oiRll@?oV<7d0onFaoP2oi?>
o0;oXm?h0_n_co43ok?Bl0;o]<?U1?nd_n<2ok>igP03ojNWe_nQW]7oXIkA00;oXIkA0onHU<h4oi2<
c0?oQHG<0omlQ=03og2;g@?oHJSg00?oP>SFolcli?o<o>@00_o:en<4okZkfP;oXig>0on;PL<3og1Y
^`?oHf:l0_mCJ/d00omMFKCoGUjjoeiN^P03og20e004oj[SQooKkmoofnoOom__g`?o];gP0_mhOld3
odaD^@;o>dFb00?oDe:cof]IZomFBJL00_mFBJL4of]X_@05om_Je_o>jXKom>ZkooCZ^ooXckd00ooJ
bl/01?o9/L;oJ@00oaLk^?lG>kP2oh]/Z@CoUVfQ0onOLj42okJ6XP?o_8jV0_oT]ZH2ookKV0;ol^F1
00?odn5bon?j[ooHkN801Oo6`=D3oi^Ec@?oLgK70_mMJLH2oe=[c@?oE8CS0_nI`O@2oiRfk@Co_lWR
00Co_lSQolk?foo>cm_oc/oK0oo=d=/01?o>dMcoc];MolkBgOo>d]d2olgBg@03olSAhOo6d>7oa]3Q
00;oa]3Q00?o^lcWok[9i_njbNH00_njbNH2ojk4jP03ojg1j?nS_>_oXkc[00?oXkc[0_nK^>d2oibe
jP?oUk?[1OnE/n`3oiFdk@;oU[K]0_nH]N`3oiZgk0GoWKW/0_nO^n`00ol0003oX;_/oj:lk003oj:l
k0;oY;g/0_nT_N/4ojFnj`WoY[o[0oooool00ol0003oooooooooo`0=ooooo`00;Oooool00ol0003o
ooooooooo`0_ooooo`CoV[c`0_nH`O@2oj74l@CoXL_e00?oXm?hojo?lOn_co400_n_co400oncd_3o
]<?UokC3i@02okC3i@;o];oS00?oZjoJojNWe_nWYmH00_nWYmH4oj6Nd@?oV9C>0on@S<`3ohF5c0Co
O8C@0om`Rmd01?mQZ?OoON:iolcli?o<o>@4ol[Gh`;o^[_J00CoVi_Coh>5cOn3QLgoPhG=0on;PL<3
og1Y^`;oHf:l0omCJ/d3oeiN^P03og20e?nRk:SofnoO00;ofnoO00Co/<7Wogj=f?mnSMSoOXgH0omh
Old2odaD^@;o>dFb0_mCD[<4oeI9Y`;oJfRm0_oKf]H00onkffcom>ZkooCZ^`02onS?_@04om[;boo9
/L;obK72olVa`P;o5c^h0_n;K:T4oiI]X@;oWg>Q0onfQZ83okb>YP;oi;JV00Goo]^Hoo;UPOobiH7o
dn5bon?j[`03omS]hP;oa/3E0_nSX=83oh^7b@?oMWK50omMJLH2oe=[c@?oE8CS1?nH]^d00onobN;o
_lSQoko8h@02oko8h@04olk?foo=d=_ocM3Kolg@f`;oc]3K00?oc];MolgBgOo=d]d00oo=d]d3olK@
h@03olG=hOnjbNKo^/WV00;o^/WV00?o^<GTojg1j?n]`NP00_n]`NP2oj>lj`;oXkSX1OnL]NX3oiNc
j`;oUK?/0_nG/^X3oiNcj`GoV;G/0onJ]n`2oifik0;oW[W[0_nP^n`00ol0003oX;_/oj2kk002oj:l
k003oj>ljonT_N_oY;g[00?oY;g[0_nU_^/2ojJnj`KoY[o[0_nW_n/3ooooo`03o`000?oooooooooo
00gooooo000^ooooo`03o`000?oooooooooo02oooooo0_nJ_?02oj6nkPCoXLCa0_nQboD3ojc:k`;o
[loa0_nba>P3okC3i@03ojjeg_n[[m[oZjoJ00;oZjoJ1?nWYmH3oj6Nd@?oV9C>1?n@S<`3ohF5c0;o
O8C@0on6^?H00on:f_oo^o[[ok_jj`03ol[Xk0;ob]OS00?o[K;Loi^KdonKVm<00_nKVm<2oh>5c@?o
LgW:0om`JK/3of=R_0CoDf[=00GoB;KgolGnc_oHo]Kof?kFom__g`03ok31i`;oOXgH0_m8G/H01Omh
OlgoC5BiodaD^Om<E;Wo>dFb00;oDe:c0omoO<D01OmFBJOoJfRmom_Je_oKf]Kodo2A00;om>Zk0ooX
ckd4olVa`P;o5c^h00?oEdbZoh]/ZOn;K:T00onFKJ42oimcX@?o]XJR0_nlSZH2onBfYP;oo]^H0_ob
iH42ok7jdP;of>gR00?o/;SOoj>Pd_nSX=800_nSX=84oh^7b@;oMWK50_m^LlL00omMJLKoDf_=oe=[
c@03ogF>g@03oeB4honH]^goV;K]00;oX;?U0onob>43ol;8g`05olg@foo>d=_oc]3Kolk@foo?dMX0
1_o=d]d01Oo6d>7oaLgQolG=hOo5cN7o^/WV00Co^<GT0_n]`NP2ojfli@CoXkSX0_nL]NX2oifbi`?o
VK7Y1OnG/^X3oiNcj`;oV;G/0_nJ]>X4oibfj`CoW[W[0_nP^n`00ol0003oXK[[oj>lj`03oj>lj`;o
Y;g[0_nU_N/5ojJnj`?oY[o[1OnW_n/2ooooo`03o`000?oooooooooo00gooooo000_ooooo`03o`00
0?oooooooooo02oooooo1?nQ_^h2oj74l@?oZLG]0_n/b^l2ok34j@Co//CX00Co]<?Uojjeg_n^]Mko
[[GN1?n[[mX2ojNWeP04oifUfonGX=[oUj3JoiNPfP?oSi_K1?n:W=l5ohBRi`;oQ[Sf00?oOnOVok_j
jonkn^/00oo:j>`00oniaN?o[K;Lojfbg002ojfbg0?oVi_C0on3QLd2og=ibP?oHWC?0omSH[`2oe=Z
c@;oZ^Kj0_o5o/h00ooHo]Kod>GVom3UiP03ok31i`?oOXgH0_m8G/H3odaD^@04oahg/?lkAK;oDe:c
oe=B/`GoOgc500Cofm[Fok_KK?odj[_om>Zk0ooXckd00ooJ^k_obK72olVa`P02ol6T_0;o5c^h00?o
EdbZoh]/ZOnFKJ400_nFKJ400onOLj7o]XJRokJ6XP02okJ6XP;o_8jV0_oT]ZH2ookKV003oo;UPOna
n];o/O[B00;o]<_[0on`^=l4oj>PdP?oRhO90omfM/D3ofica`;oDf_=0omeS]d5oj2ci@05oko8hOo2
b=oo`/SOol;8goo6b=`00oo>d=/3oloAfPCocM;M00Coc=3MolG=hOo5cN7oaLgQ0oo3b^02okS5i0;o
]l7R1?n]_>D2oj>hj0;oXkGU1?nM/^L3oiVaj@;oUk;Z0_nI/>L4oiVbj@CoV[CZ1?nL]^/2oijij`06
oinhj_nQ^^_oXK[[oj6jjol0003oXK[[1?nS_>/4ojFmj`CoY[k[1?nV_n/4ojNoj`;ooooo00?o0000
ooooooooool03Oooool0033ooooo0_l0000`ooooo`;oXKk^0_nX`>/3ojW5k@;o[/?Y1?n`a>T2ok;4
j0;o[k[Q1?n^]Mh2oj^_fP03oj>[gOnMYM_oWJGK00;oWJGK0onGX=X3ohnKf`CoRYcO0_n4X^L3ohSJ
o`;o/?7f0oo3k_001?o:j>co^LGSokW5honiaN<4ojfbg0?oVi_C0_n3QLd3og=ibP;oHWC?1OmeV>L0
1?nZi_[oaOk>olGnc_oHo]H4om3UiP?o/<7W0_mnSMP2odQNaP;o>UC200?oC5Bioahg/?lN=k000_mC
D[<4ogmla@04omOdhooCl97om>ZkooCZ^`?oj<nm0_oJ^k/01?o9/L;o`JBlol6T_?o1Y;`2oaLk^0;o
EdbZ0_nFKJ400onHLZKo]XJRokJ6XP04okJ6XP07okb>Y_oT]ZKoi;JVookKV?obiH7odn5bojO7l004
okC;j`?o/;SO0onSX=83oh^7b@?oMWK50om^LlL3og5lc`?oMHkM0_nP/nD2oj^eh0?o`/SO0oo6b=`0
0oo>d=_ocm7JoloAfP02oloAfP03om3Af_o=d]goc=3M00?oc=3M00GoaLgQol?:h?o3b^3o`l[Pol77
g`05okO1hP;o[KcU00?o[;WSoj>eiOnS]ND00onS]ND2oifbi`03oij`i?nK[nKoVjoV00;oVjoV1?nI
/>L4oiVbj@;oV[CZ0_nL/nP3oiffj@CoWkSZ0_nQ^^/00ol0003oX[[Zoj>lj`04oj>lj`?oYKg[1OnV
_^/2ojJoj`KoYko[00?oooooo`000?ooool03_ooool003;ooooo00?o0000ooooooooool0;_ooool4
ojS0j`03ojW5kOn^`nWo[/?Y00;o[/?Y0_n`a>T2ojnmi0Co[k[Q0_n^]Mh2ojNag`?oXj_M1?nMYM/3
oiNPfP?oSi_K0_n:W=l3ohc4nP04ohSJoon`lOKo/?7fok3amP?o`nk`0_nod^P4okW5h`;o[K;L00Co
Ui[DohV=dOn9SM7oRHgA0omgQ=<2og=ibP?oHWC?0omeV>L01?n:kN?oaOk>olGnc_o@o]/2om[dh0;o
d>GV0_nc`ND2ohFFg0?oHG??0_m8G/H2ocYD`P04odaD^OlN=k3oEgWIoeMif@?oOgc500?oeoCSom?`
TOoZnK400_odj[/2onS?_@?of[^k1Oo1Y;`00olG>kSoEdbZoeM<ZP03oiQbYPKo]XJR0_oT]ZH2ookK
V004oo;UPOnWao3oYlO`ojO7l0;o]<_[00CoXJ;EoiRHd_nHV=;oV9SB0on?S<`3oh:0b003oh^7bOmf
M/GoMWK500?oKW?70omaO<l4ohbIfPCoZkGP00?o`/SOolK8g?o6b=`00_o6b=`01?o:bm[ocm7JoloA
f_o?dMX2om3AfP04om7AfOo<d=goc=3Molc@g@?oblkL00Co`l[Pol77goo1amoo`LOO0_ng`N82okFm
h@Co[;WS0_nS]ND2ojBbhPCoW[3T1?nK[nH2oiV`i`03oi^_iOnK/NOoVk7W00;oVk7W1OnL/nP3oiff
j@;oWkSZ0_nQ^>T2oj:jjP04o`000?nR^^[oXkc[oj>lj`;oY;cZ1?nU_N/4ojJnj`SoYko[00?ooooo
o`000?ooool03_ooool003?ooooo00?o0000ooooooooool0;_ooool2ojS0j`?o[L7X0_n^`nT2ojo0
iPCo[kgT0_n_^^42ojZfhPCoYk7O0onSZmd2oifUf`03oiR]i_nC[nWoTjoY00;oTjoY1?n=]?42ohc4
nP?oY>;l0onfk?H00oo3k_3o_m;XokoBj002okoBj0;o^LGS00?oYZWIoiNJe?nGV]@00_nGV]@3ohV=
d@;oMhCC0ombS]l3of9dc`03ogFHionjlo;o^_?b00;od?kK0_oJm>000oo>hNKo/l7Uok?1i@03ok?1
i@;oQIKL0_mQLll2ocaKb0?o>UC20_lN=k02oeMif@04ogmlaOoGm>?oeoCSojSbm@;ok^?40_oYd[d0
1OoXckgof[^komZk^ooJ^k_od;2i00Co`JBl00?oZIC0oeM<Z_mGC:X01?nHLZH5okJ6XP;oi;JV0_on
fiP2ojO7l0;oYZCD0onQX]D4oiRHdP?oShc<0on2P<P3ogYja`?oKW?70omaO<l4ohbIfP;oZkGP0_nf
^M`3olK8g0?ob/_J00?ocm7Jom3Af_o@dMX00ooAdMT01Oo<d=goblkLol_>g?o;c]cobLcL00?o`LOO
0_nn`mh4okFmh@;o[;WS0_n[]N04ojBbhP?oW[3T0_nK[nH2oif^h`CoVjoU1?nK/NL2oibcj0;oW[?W
0onO]^P5oj6hj@;oX[[Z00?o0000oj>jjOnT_>X00onT_>X2ojFmj`;oY[gZ1?nV_^/8ojNoj`03o`00
0?oooooooooo00gooooo000dooooo`03o`000?oooooooooo02kooooo0on]`NP2ojk1j0Co[l3V0_n_
_N@2ojbji0CoZ[KR0_nW/Ml00onQ/^CoWJoToif_i002oif_i0?oV:gV1?nC[nT2ohfdl@?oW=7j00Co
Y>;lokK/m_nfk?Ko]^cf0onmfNh2okoBj0;o/KSN1?nVZMT3oiNJe0?oRHgA0omgQ=<4og:>g`03ogNd
n?njlo;o^_?b00;od?kK0_oJm>03olkQiP;o/l7U0_nBZ>@3ofB1fP;oHG??0_llFlP2ocYD`P;o<fOG
0omGNMT2ojSbm@03on7]fOo^hlCok^?400;ojM:m0ooJ^k/2om2`^@?o`JBl0_nmWkX00olG>kSoEdbZ
oeM<ZP03oiQbYPGo]XJR00Cog[>[onBfY_onfiSol^F11OnVY=@3oj6Re@?oV9SB0on?S<`3oh:0b0?o
NW[70omlO/X4og5lc`;oS9WJ00?oWZ?IokJig?nf^M`00onf^M`01?o6b=cob/_Jol[;f_o:bmX2olk=
f@03om3Af_oAdMWodM7I00;odM7I0oo;c]`3olW<g003ol77gonn`mko_/?N00;o_/?N0_ne_N400onc
^]koZkGPoj^eh003oj^eh0;oY;;R00?oY:oPoj2^h_nP[^800_nP[^84oif^h`CoVjoU0_nK/NL2oif`
i@CoW[?W0onO]^P2oj6hj@;oX[SX0onS^^T01Ol0003oXk[YojBlj_nT_>[oYKcY00GoY[gZ0_nV_^/0
0onW_^[oYko[ojNoj`05ojNoj`03ooooool0003ooooo00kooooo000eooooo`;o0000;oooool00on]
`NSo[/7Xojk1j002ojk1j0;o[l3V0_n/_^L4ojbji0;oZ[KR00?oYKKUoj6bi?nQ/^@00_nQ/^@4oif_
i0?oV:gV0_nC[nT3oi[5mP;oW=7j0_n/hoT3okSJl@;o_MW^0_nf`n@4ok6hgP?oYZWI1?nGV]@3ohV=
d@?oMhCC0_mbS]l2oiS:n@;o]OCb0_o;mnT2olk_jP;oc^7V0_ndbNX4oi:Xi0;oI87J0_mCL]<2ocaK
b0;oE7_L00Co>UC2oc=WeolcImOoEgWI0_nXl_D00ooQkMWok^?4onkSa003onWB_@03on75_?oJ^k_o
d;2i00?od;2i00Go`JBlokfO^_nmWk[o_InjojVD`002oeM<ZP?oV7:V1?nfQZ82omjcZ`04ookKV?oe
jXkoZJ3=ojVPc@CoYZCD0onQX]D4oiRHdP?oShc<0on2P<P3ogYja`;oO7k:1?n6Rm44oijSf@?o][WL
0_no`=X00oo:bm[oc/gIolk=f@02olk=f@04om7@fOoAdMWodM7Iom7Af@;od=7I00GoblkLolW<g?o9
c=cobLcLolK9g004okk3gP03ok^ogOnc^]ko/k[N00;o/k[N0_n[]N02ojZbgPCoY:oP1?nP[^82oif^
h`;oWjgQ0onM[^<5oif`i@;oW[?W00?oX;?Uoj6fionQ]^L00_nQ]^L4oj:hj0;oXk[Y00?o0000ojFj
j?nU_>T00onU_>T2ojJmjP;oYkgZ1?nW_^X2ojNoj`Kooooo00?o0000ooooooooool03?ooool003Oo
oooo00?o0000ooooooooool0;_ooool2ojk1j0;o[<7Y1?n/_^L2ojbji0;oYkWV0onU]^D4oj6bi0;o
WJoT0_nL^^h4oiVml@;oV/Gf0onTf?X01?n/hoWo^=[aokSJlOnhf_42okO;j@Co]/?T0_na^=h01?nR
[=koV:;KoiRRfonHX]/4oh^Jg0?oQI[P1On3YN/00onHb_Wo]OCbol_gj@02ol_gj@;oc^oZ0_o3gN`4
okC9jP?oTZST0_mTPMX3oe=bd`;o?5_80_mDNm`2oc=We`;oV=Om00?ohNgIonkSa?o^hl@00ooYd[d2
on75_003omZk^oo@/;Wod;2i00;od;2i1OnmWkX2oeM<ZP?oV7:V1?nfQZ82omjcZ`;omNZ>0onYX<d2
ojJTe004ojBIb_nITlcoVI?<oiVCc0CoSX_<0on4Q</3ogiobP?oNW[70omlO/X4ohJ;d@CoWZ?I00Go
][WLoko0f_no`=[o_l3JolK6f@03olk=f@?odM3I00?odM7Iom3AfOo@dMT00oo?d=X01Oo9c=coa/WL
olK9g?o6bMco_/?N00Co^koM0_nc^]h2ok6gg@CoZ[;N1?nT[n02oj2^hP03oj6]gonO[N7oWjgQ00?o
WjgQ0onM[^<2oif`i@;oX;3S1?nP/nD4oj6fi`;oX[SX00KoY;SWojFjj?nU^^SoYK[Xo`000?nU^^P2
ojFlj@;oY[cY1?nW_NX2ojNnjPWooooo00?o0000ooooooooool03?ooool003Sooooo00?o0000oooo
ooooool0;_ooool4ojc1j@;o[;kW0_nX_NP4ojNiiP?oYKKU0_nQ/^@2oijik0CoW;[^0_nI_O43oj3>
n0;oY=Sj0onaeo@00onhf_7o]l_YokO;j@02okO;j@;o]/?T00?oZ[CPoj:/g_nR[=h00_nR[=h3oiRR
f`CoRi[L0on5V^02oh>Uj`;oWMKl0onkk?@00oo;mnWoc^oZolk_jP04ol?Mk0;o]<WZ00CoVKCZogRF
homhU^?oN9KS0_mBNM/00omTPM[oDg;Coe=bd`03oe=ifP?oE7_L00?oV=Omon7]fOoQkMT00_o^hl@2
onWB_@?ohLFl1Oo@/;T00oo8Z;[o_InjokfO^P02okfO^P03omQZ0?mGC:[oV7:V00;oV7:V0onfQZ83
omjcZ`05ooGZS_n]W<GoZJ3=ojVPcOn]W<D01?nTVLX3oiVCc0?oSX_<1?n4Q</2ogiobP?oOX7<00Co
NW[7oganb_mlO/[oO7k:0on6Rm42oijSf@;o[JoI0ono`=X3olK6f@04olk=fOoAd=WodM3Iom7@f@;o
d];I00?od=7Iolo@f_o?d=X00_o?d=X3olK9g0;o`lKL0onk_md00onh_=co/KOMok6gg@03ok6gg@;o
Z[;N00?oZ[3LojF^g_nU[]h00_nU[]h4oj6]g`;oWjgQ0_nQ[=l4oj2^h@CoX;3S0_nP/nD2oj>ci0?o
XkKV1?nT^>L2ojFjj003ojJkj?l0003oY[cY00CoY[cY0_nW_NX<ooooo`03o`000?oooooooooo00co
oooo000iooooo`03o`000?oooooooooo02kooooo0_n/`NT2ojW0j`CoZ;gX0_nW^NH2oj>lj`CoXK[[
0onN^N`2oibjkP?oWlOd0_nPc_P3oj_Bm0;o/MOd0ondc^d2okO;j@;o[kcT0onZ]>04oj:/gP?oV:;K
0on;V]`2ohFJh0?oT;Wb00CoWMKlok_/m?nkk?Co^ncd0_o7lNh3olSWk0;o`mg/0_nbbn`3oiVdjP?o
N9KS0_mBNM/3oe=bd`?oDgWJ0onL^Nd3olWFh`03omKBeOoYd[gohLFl00?ohLFl00Cof;^mom2`^Oo@
/;Wod;2i0_o8Z;X5okfO^P03oeM<Z_nHLZKoV7:V00;oV7:V0_nfQZ82omjcZ`;omNZ>00?o/ig1ojfL
aOn]W<D00_n]W<D3ojBIbPCoVI?<0on>Rl`3ohB4b`?oOWo:0omnPL`3ohR;d0CoUi_E1?n][mT00ono
`=[oa/KIolK6f@02olK6f@?odM3I0ooBd]T01?oBdm[ocm3Jolo@f_o?d=X2olg?f`03olK9g?o3a]co
`lKL00;o`lKL00Co^koMokRlg?nh_=co^;cL0ona]md00on_]=coZ[3LojZ`g002ojZ`g0CoYJkN0_nQ
[Ml2oj>/g@CoXJcO1?nP[^42oj2`h`03oj>`h_nS/nCoXk?T00?oXk?T0onS]^H2ojBhi`;oY[WV0onV
^nP00ol0003oY[cYojJlj@0@ooooo`03o`000?oooooooooo00cooooo000jooooo`;o0000;oooool4
ojW0j`;oZ;gX0_nT_N/4oj>lj`;oXK[[0_nP`>l4oik3lP;oWlOd0onWc?<2oj_Bm0;o/<k_0ondc^d2
ok32i`Co[kcT0onZ]>02oj:/gP03oiZXgonDYN7oU:GQ00;oU:GQ1?n=Z>P2oi2ilP?oZMSh00?o^ncd
olOak_o7lNh00oo8in`3ol7Jk0?o//_/0onI]>X3ogRFh`05oe9ifomGOmgoEgoMoeMogOmCL]<00omC
NMX01?nL^NgobMKSolWFhoo9e^<2omKBe@04omO<cooQaKcohLFlon75_0?of;^m00?od;2iolRX^_o8
Z;X00_o8Z;X4okfO^P03o`00G_mGC:[oV7:V00;oV7:V00Co]XJRomjcZooN/j_og[>[0_oejXh00onc
WL7o[Ic5ojfLa@03ojfLa@?oY9W:0_nITl`01?nFS/WoRXS;ohZ8bon:R</4ohB4b`;oOWo:1?mnPL`3
ohR;d0CoUi_E0_n][mT2okRjfP?oa/KI0_o<c=X01?oAd=Wod];Iom;BfOoBd]T3om;CfP05olo@f_o=
cm_ocLoKolg?foo9cM`00oo3a]`00ono`mgo^;cLokRlg003okRlg004ok6ggOn_]=co[kCLojndg0Co
Z[3L0_nU[]h00onU[=coXjcMoj>/g@03oj>/g@?oXJcO0_nP[^42oj>^h0CoXk3R0_nS/n@2ojFdh`?o
Y[KU1OnV^NH2ojJkj003o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool003cooooo
00?o0000ooooooooool0;Oooool2ojW0j`;oYKo/1?nT_N/2oj>lj`;oXKo^1?nP`>l2oik3lP?oY<Sb
0_nWc?<2ojc<l0Co/<k_00?o]<k]ok32ion``^L00_n``^L2ojnli003ojNchOnR[MooXZgO00;oXZgO
0onJZ=l4oiBUh@;oSJSX0onM`o<2ojWHn0;o^^Wd0oo4inl01?o8inco`M[/ol7Jk?o1f^`2okG>k0?o
XKk^0on0Y^`2of>?iP;oBWkR0omGOmd3og^PjP?obMKS0ooFd]D2omO<c`03on75_?oH^kgof;^m00;o
f;^m1Oo8Z;X5okfO^P05oeM<Z_nHLZKoV7:VoiQbY_nfQZ800ooN/j/01?oejXko/ig1ok>M`OncWL43
ojfLa@04ojjK`onSULKoXiG6oj>EaPCoUXk90_n:R</4oh63c0?oOhC>0omnPL`4ohR;d0;oUi_E00?o
YJWIokRjf_nh^]X00onh^]X00oo6a]Woc<cJolc<fP03om3AfP05om;BfOoBdm[od]?Jom;Cf_o@e=`0
0oo=cm/3olW=g004ol?6g?no`mgo_l?Moko3g@;o^;cL0_ne^M`4ojndg0;oZ[3L0_nY[]/4ojF/g0;o
XjcM0_nT[=`4oj>/gPCoXjkP0_nS/>82ojFah@CoYKCS0onV]^D2ojJiiPGooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0<ooooo`00?Oooool00ol0003oooooooooo`0]ooooo`CoYKo/
0_nT_N/2oj:ok@CoXKo^0_nP`>l3oj?4l@;oY<Sb0_nYbO04ojc<l0;o/<k_0on`a>T2ok32i`;oZ[SS
0onW/n44oj:]g`?oVZSO0_nDYN42oiZgk0?oWL?c0on_fOH01?njjOCoa>O_olCWkoo4inl3olCPk@03
ol7Jk?nec^co]Lk/00;o]Lk/0onQ_^h3oh2Vk0;oHhoV0_m:O^83oeMog@?oNj3Z00CobMKSomKBeOoF
d]Goe];E0ooGc<l5omRk_@04olnd`?o8Z;[ob:RjolRX^P;o`jNm1?nmWkX01?l005koV7:VoiQbY_nT
WLh3omjcZ`;omNZ>0oncWL401?n]W<Go[Y_3ojjK`on^Vl<4oj>EaP?oUXk90on:R</3oh63c0?oOhC>
0on4Rm84oi>HePCoYJWI0onh^]X2ol74g003olc<f_o@dM[od=7J00;od=7J0ooBdmX3om3Dg005olg?
foo9cMcobLgLolW=g?o6bmh00ono`md2ok_0gPCo]KWL0_n_]=`2ojfbg0CoZJkK0_nU[=`00onV[=_o
Y:cLojB/g003ojB/g0CoXjcN0_nS[^000onU[mkoYK7QojFah@03ojFah@?oYKCS0_nV]^D9ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool003kooooo00?o0000ooooooooool0
;Oooool2ojFok0;oXko]1?nR_nd2oj6okP?oXl;_0_nSa?42ojO6l0CoZLW`0_n/c?03ojk5j`;o/<CY
0_n/_>D4ojZhh`?oYk?Q0_nR[Ml2oijai@CoV[7W0onJ]n`01?nM`o?o[mWfojoIm_n_fOH3okgQl@04
olCWkoo4h>goa>3]olCPk@?o_mK[0_nec^`01?n[a>coTkG^oi>ek_nC]Nh3ofjNkP?oEXo[0_m:O^83
ofRFj@CoXK_[00Coe];EomO<cooGc<ooelc?0_oAa<h3omRk_@?ockC000Cob:Rjol>W_Oo3Ykgo`jNm
0onmWkX00onmXKco]iblojBMcP03ojBMcP;og[>[0_oejXh2ok>M`@03okJO`On^Vl?o[Y_300?o[Y_3
0onSULH4oiJ>b@?oRXS;0on1Pl`3ogn4cP?oQ8_B1?nCV=H3ojFYf@03okRjf_o1a=co`LCL00;o`LCL
00CoalgOom3Af_o@dM[od=7J0_oAeM`01?oBdm[od=CLom3Dg?o@e=`3olgCgP05olW=g?o6bmkoa/_N
olK;g_no`md01?nk`=h2okFig0;o/[OM1?n]/]`2ojV^f`03ojR]fonV[=_oYZcK00;oYZcK1?nT[=`2
oj>/gP;oYJgM1?nU[mh2ojFahA3ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<
ooooo`00?oooool2o`0002oooooo0onS_nd2oj:ok@?oXl3^0_nS`^l2ojG3k`CoYlK`0_nYbO03ojc5
k0;o[/G[0_n/_nL4ojbli@;oZ[SS00?oYKKToj:ci?nR/n@00_nR/n@4oijai@;oV[7W0_nO_nl4ojG:
l`04ojoIm_nmhO7o_N7aokgQl@;o`n7^00?o`m[[okoFjonoe^/00_noe^/00onic^[oZlC/oj_4k002
oj_4k0?oTkG^0om^W^h3oeJ?j`;oB8WZ0omXU^T2oj6kj`?o//KY00?oelc?om74c_oAa<h00_oAa<h0
0ooH^kgockC0olnd`002olnd`0Go`jNm00Go_InjokfQ_?nmXKco_J6lokNL_003ojBMcP;og[>[00?o
mNZ>okNN__ncWL400onfWl44ojjK``;oXiG600?oY9S9oiJAc?nFTL`00_nFTL`3ohZ<c`?oPXWB1?mo
Q<h2ohB;dPCoTiSF0_nUZMT2ok2hgP?o`LCL0oo7cMl00oo@dM[odMGLom7Eg003om7HgP05om3Dg?o=
dmkocM?NolgCg_o9d^400oo6bmh2ol78h0?o^l3N00?o]kgOok:ggOnb]md00onb]md2ojfbg003oj^`
fonX[M_oZ:gK00;oZ:gK1?nV[=/2ojB/g0;oYZcK1?nU[Md2ojF_gQCooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0;ooooo`00@Oooool00ol0003oooooooooo`0]ooooo`CoXko]0_nS
`>h2ojG1k@CoYL?_0_nWa_02oj[4k@?o[<G/0_n/`>T4ojboi`;o[;cU0_nX^ND3ojFfi0CoX[?T0_nN
/ND2oinij`CoWko_0_nUb_<2ok;Gl`?o^]ca00Go`n7^ol?Jjoo3f^_o`m[[okoFj`04okW>jP;oZlC/
0_nR_nh3ohVbl@?oHika0_m=Tnl00omFSn_oB8WZodR9jP03ogJXlP?o//KY0_nea^L3om74cP;ob;kA
0oo?]<000oo6/LGo`jNmol>W_@02ol>W_@03oknW`OnmXKco_J6l00;o_J6l00?o]iblojBMc_nTWLh0
0_nTWLh00ooejXko]ijnokNN_P04okJO`@?o[Y_300?o/9o6ojBHbOnTV<T00_nTV<T3oiJAc0CoRXc?
0_n2RM84oh>>eP?oRiSJ0_nCV=H2oifXgPCo/;SN00Co`LCLolO=goo7cMooalgO0_o;eN401?oAeMco
dMSNom7Hg_oAf=h2oloJh@03olgCg_o9d^7obM;Q00;obM;Q00?oa/_Nol78h?o1b>000_o1b>001?nk
`=ko]kgOokNmgong_Ml3ok:gg@03ojnegOn[/=_oZk3K00;oZk3K1?nX[M/2ojJ/f`03ojN/fonV[=_o
YZcK00?oYZcK0_nU[MdHooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool0
04;ooooo00?o0000ooooooooool0;Oooool2oj>ok@;oYKo/1?nU`Nd2ojG3k`;oZ<?/1?nZa>d00on/
aNco[<3Yojc0j@02ojc0j@;o[;oW0_nY^nH4ojRii@?oYKKT0_nR/n@2oj2fj0CoWkW[0_nO_nl3oj[<
lP04ok;Glonjg?7o^]caok[Ll@;o_]W]0_o3f^/3okoCj@;o^LkZ0onbb>/3oj:okP?oRK;a0omSW_42
odfCk`?oBiC`0omfZ?800onba^Wo]LKWokG6i`02okG6i`03om74c_o8_]7ob;kA00;ob;kA00CockC0
olJaaOo6/LGoa[750_o3Ykd2oknW`@Co_J6l00Co]iblok^Q__nTWLkoY9g>0ongW[h2okZR`@Co]Yo1
00Co[Y_3ok2Oa_n`WlKo/9o60onTV<T4oiJAc0?oRXc?0on2RM84oh>>eP;oRiSJ1OnMZ=h2ok2hgP?o
^LGS00?oalgOol_EhOo;eN400oo<fn@01OoAf=kocm[QoloJhOo?f^7obm[T00?obM;Q00?oaM7Sol78
h?o1b>000_o1b>000onla^;o]kgOokNmg`02okNmg`03ok:ggOn_]Mgo[kGM00;o[kGM0on[/=/4ojR]
f`CoYjcK0_nV[=/Mooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool004?o
oooo00?o0000ooooooooool0;Oooool4ojFok0;oYL7]0_nW`N`4ojS3k0;oZ/C]0on[`NX2ojc0j@;o
Z[gW1?nY^nH2ojRii@;oYKSV0onS]nH4oj2fj0;oWkW[0onVa>l2oj[<lP;o/mCa00Co^]caokkIkOnn
fNgo_]W]0_nneN/3okoCj@?o^lkX0_nbb>/2ojk5j`CoW;g_0on3/_<2oefQm0;oB9Sb0_m;U?05ognc
m@;o]LKW00?o[l?XolRndOo8_]400_o8_]400onm^]Ooa[75olJaa@02olJaa@03ol>W_OnoYl7o_jO1
00;o_jO10_nmXK`00onmYL7o^j6nok^Q_P03ok^Q_P04okNN__njX/7o^Z;1okZR`@?o]Yo100?o^:C5
ok2Oa_n`WlH00_n`WlH4ojBHb@?oUY7<1?n:S<l3oh:9dP?oPhkF0on;V=X2oifXgP;oYkOU1?niaN<2
oko@i`05ol_EhOo<fnCoc=_TolcKi?o;g^H00oo?f^43ol_Ji005olWBhOo5dN?oaM7SolGAhoo1b>00
1?nla^82okNmg`;o/[_P1?n_]Md2oj^`f`;oZJoL1?nX[M/2ojN/fb3ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`00A?ooool00ol0003oooooooooo`0]ooooo`;oYKo/0_nW
`>/4ojO1k0;oZ<?/0onZ`N/2oj_1jP;oZ[kX1?nZ_NL2ojVkiP;oYkWV1?nU^>H3oj>giP;oX;KX0onS
_^`2ojK4k`;o[Lga0_nce?43okWEkP03okkIkOnneN_o_]G[00;o_]G[00Co_m?Yok_>j?nkc^So^lkX
0_ngbNP4ojk5j`;oW;g_0_nJ__43oh6dmP;oGJGf0om8V?800om9VoCoOk?eogncm@02ogbfn0Co[l?X
00?ob;kAokfjeonm^]L00_nm^]L2olJaa@03okj`c?noYl7o_jO100?o_jO100Co_J6lokfU`OnmYL7o
_JG10onkXKh00onmY/?o^Z;1okZR`@03okZR`@04okJO`OnhY<Go^:C5okRTa@Co/9o60_nTV<T01?nU
WLkoV9OAoiRGdOnHUm44ohfCe@?oQI?I0on8V]h4oi>Wh`CoYkOU00Go^LGSoko@ionod>Oo_m3Wol;I
j`03olcKi0?obmkV00Cocm[Qol_Ji?o;f^Cobm[T0_o6f^P2olGAh`?o_loW0_nla^800onf`nCo/[_P
ok:kh003ok:kh0;o[kGM00?oZk?NojV_g?nY[m`00onY[m`2ojR]fbCooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`00AOooool2o`0002oooooo0onW`>/2ojO1k0?oZL7[0_nZ
`N/2ojVoj@CoZ[kX0_nZ_NL2ojRki`CoYkWV0_nU^>H00onT^nWoY;cZojBljP02ojBljP;oXkk/0_nX
a^l3ojg=l@;o/m3_0onieNh3okcDk0;o_]G[0onmd>P00onkc^So]lWXokO9j002okO9j0;o[/G[0_n[
a>`4oiZnl@?oPKCf0omMYOH2odJLm0;oAYge0oml]_P2ojo3j003oj:nkOnm^]Oo_K[G00?o_K[G00Co
a[75okj`c?nn/<co_[3<0onoYl400onkZlWo_JG1okfU`@03okfU`@04ok^Q__nmY/?o_JK3okfV``Co
^Z;11?nhY<D3ok2OaP03ok2Tc?nUWLkoYIg>00;oYIg>0onHUm44ohfCe@?oQI?I0on8V]h4oi>Wh`;o
YkOU0on_a^`01Onod>Oo`]W[ol;Ijoo2fN_oc=_T00?obmkV0oo8hNX00oo;f^Coa][XolKJj002ol3I
k0?o_loW00?o^<gZokK3i?nf`n@00_nf`n@2ok:kh0;o[KWR1?n[/mh2ojV_g2Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0;ooooo`00Aoooool00ol0003oooooooooo`0]ooooo`Co
Z<3[0_nY`N/2ojW0jPCoZKoY0_nZ_^P2ojRmj0CoZ;_W0_nW^NH00onU^nWoY;_YojBkj@02ojBkj@;o
Y;cZ0_nW`^d4ojS6k`03ojg=lOncd>oo/m3_00;o/m3_00Co^MG^okcDk?nle>co_=C/0onld>T2okg@
j0?o^lcW0_ngbNP2okG7j0CoZlC/0_nJ__400onJ_o;oP[Ogoh:gm`02oh:gm`;oGZWh0om5W_D2odJM
m@?oL[;i0onR_^d3okfje`03ok2gg_nn/<co_[3<00?o_[3<00Co_jO1ok^[bOnkZlWo^j_91?nmYL44
okfV``?o^Z;10_nmZLH4okRTa@04ok2Oa_n`Y<co/:C<ok2Tc0CoYIg>0onHUm43ohfCe@?oQI?I1?n8
V]h2oi>Wh`;oVkS/0on_a^`01?ncdo7o`]W[ol;Ijoo2fN/3ol?Pk@04ol_Ni_o8hN[ob>7ZolSQjP;o
`n7^00?oa][Xol3Ik?o0fN`00_o0fN`01?nocnOo^<gZokS=j_nhcNX2okK3i0;o[l7W1?n]^N82oj^c
gRcooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`00B?ooool00ol0003o
ooooooooo`0]ooooo`;oZ<3[0_nY`>/4ojW0jP;oZKoY0_nX_^T4ojRmj0;oZ;_W00?oY[cYojFkjOnU
^nT00_nU^nT2ojBkj@;oYKo/1?nW`^d2ojS6k`?o[/__0_ncd>l3okOAk@04okcDk?nld>Wo_=3Yokc@
j@;o_<gW0onkc>L00onibNKo]LOXokG7j003okG7j0;oZlC/0_nZ`n`3oiZolP;oP[Og0_n5^OL2of>/
n0?oAIke0_loVo@3og:bn@?oX[k]00Co_K[Gok2gg_n`]mko/;ON0onn/<`00one/]Ko^j_9ok^[b@02
ok^[b@?o_JG10_nmZlP4okfV``04okZR`OnmZLKo_JW6okfYaP?o^:C500?o^:_<ok2Tc?n`Y<`00on`
Y<`2ojFMcP04ojJWeonJX][oVZ;JoiZRfPCoT9oN0on:XN@3ohn[j0GoVkS/00Go[lK/ok?ClOncdo7o
/m?aol;Ij`03ol?Pk@;o`>C`00Cob>7Zol?Qk_o3hNko`n7^0_nmhO42ol3Ik0?o^=O`0_nhcNX2ok3:
k@Co[l7W0_n]^N8`ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool004Wo
oooo00?o0000ooooooooool0;Oooool4ojW0j`;oZL3Z0_nX_nX4ojRnj@;oZ;gX00?oY[gYojJljOnV
_>T00_nV_>T2ojFkj@;oYKg[1?nU_n`2ojO2k@?oZlK^0_n^bnl3ok?=k@;o]m7]0onicnX00onld>Wo
_<gWokc=i`02okc=i`04ok_<ionibNKo^LWVokW9iP;o]LOX0onca^P4oj[3k0CoVkoa0on5^OL3of>/
n0;oAioe0_lhUo800oloVoCoHZ_hof:[n003oi2hl@Co/;ON00Co_[3<okFbe_ne/]Ko]K;F1?nkZlT0
1?nmYL7o_J_8okf[b?nmZlP3okfV``03okj^b_nmZLKo_JW600?o_JW600Co^:C5okR[c?nhZlco^:_<
0on`Y<`00ona[]GoYZOGojJWe`02ojJWe`?oVZ;J1?n@Wmh3ohZQi0?oSj_X0_nK^>`3oj77l`;o/m?a
0onegO@00oo3h>go`>C`ol3Tl003okcVl`03ol?Qk_nmhO7o_N7a00?o]=oe0_nheo000on^e??o/<[]
ok3:k@03ok3:k@;o[l7W=?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo
001:ooooo`;o0000;_ooool2ojW0j`;oZ<3[1?nX_nX2ojRnj@;oYkkZ0onV_NT2ojJlj@KoYKg[0_nU
_n`3ojS3k@;oZlK^0_n^bNh3ok?=k@;o]/g[0onicnX3ok[=j0;o_<gW0_nkb^H2okW9iP?o^<OV0_nc
a^P2ok?5j0CoZ/?/0_nK_o42oifol0CoR;Wf0_mY[OP2od^PmP;o>9Ob0om>XOH3oi2hl@;o/;ON0_nO
]NP4okFbeP;o^j_900?o]k3Bokf[b?nmZlP00onmZlP01?nmY/?o_Zk:okj^b_nn[/X3okfYaP03okfa
c_nhZlco^:_<00;o^:_<00?o/:C<ok6^eOna[]D00_na[]D3ojJWe`CoVZ;J0_n@Wmh00onC[NSoSk7]
ohnak@02ohnak@CoU;_b0_nQao<3ojGDn0;o]Mgd00Co]>Cgok3Wn?n`ioSo/>Oh0_nli_<2okGWmP05
okgQlOndgoGo]=oeokCOmOnZg?T01?n^e?<2ok3:kCWooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0:ooooo`00C?ooool00ol0003oooooooooo`0/ooooo`CoZ<3[0_nX_nX3ojNoj`?o
YkkZ00?oY[gYojFmjonU_N/01_nU_N/3ojK1k0;oZ<?]0_n[a^d4ojk9kP03ok?=kOnfcN_o]/g[00;o
]/g[00Go^LoZok[=j?njcNSo^/gXok[:i`03ok_:iP;o^/SU0onhanH2okO6i@Co/lGX0_nZ`n`3oj_3
j`?oWKo`0_n8^OH01?n=^??oL:kgog2^mom`[_L3od^PmP04ocBDlOm>XOKoCZ7fodjQmP;oNK3f1OnO
]NP2okFbeP03ojVdhOng/=;o]k3B00;o]k3B0onmZlP00onk/m;o_Zk:okj^bP02okj^bP03okfYa_nm
/Lko_K7>00;o_K7>0_nhZl`2okVde@Co/JkE0_nVYmL2ojNch@?oW:kT1?nC[NP4ohnak@;oU;_b0_nH
b_T2ojGDn0?oY=kk00Co]>Cgok3Wn?n`ioSo/>Oh0_nZj?X2okGWmP?o[NGi00Co]=oeoj[LnOnZg?Wo
Z]ci0_n^e?<looooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool004gooooo
00?o0000ooooooooool0;?ooool2ojS0j`?oYl3[0_nW_n/00onV_n_oY[k[ojJnj`02ojJnj`GoYKg[
0onU_n`2ojK1k0;oZ<C]1?n[a^d2ojk9kP?o/L[/0_nfcN/3okO<j@05ok[=j?njb^Oo^/[Wok[:ionk
b^H01?njb>D00onhanKo]lKUokO6i@02okO6i@;o/lGX0onca>L2oj_3j`03ojc1jOnO_^koWkk^00;o
Wkk^0on=^?<3og2^m`?oDJ7f0_leT_02ocjHl`;oH:Kf0_nO]NP2ohbcl0CoZKCQ1?ng/=801?nmZlSo
^k?Bok^cd_nk/m82okj^bP;o_KOC0onm/Lh00onm_=So^KCEokVde@03okVde@;o/JkE0_na^Ml4ojNc
h@?oW:kT0_nC[NP2oiJml`CoT/7g0_nHb_T3oiWGo@;oY=kk0_nRi?`01?n`ioSoZ^Sjoj[Xn_nZj?X2
oj;Xn`;o[NGi0_nShoa3ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool0
04kooooo00?o0000ooooooooool0;Oooool2ojO0j`03ojJok?nV_n_oY[o[00;oY[o[0_nV_^/8ojFo
k0;oY/;]1?nXa>d2oj_6k@?o[/O]0_nab^`3ok?:j`;o]lcY0_nhbNP2ok[:i`?o^LSU0_njb>D3okW6
i0;o]lKU0_ngaN@3ok?4i`03ok?3iOn/`NWo[<7Y00;o[<7Y0_nO_^h2oj6lk0?oTKOa0omg[_D2oeZR
m@05oe6Qm_leT_3o=I;`ocFBl?lbT_000omPY_H3ohbcl0?oZKCQ0_ng/=82ok6ggPCo^k?B00?o_Zk:
okfgdonm]m<00_nm]m<01?nm/Lko_KcHokflf?nm_=P3okVde@;o^<3P1?na^Ml2ojNch@03ojO1k?nM
_NooWKg_00?oWKg_0onF_O<2oi;1m`?oTlol0_nIeod2oiSNoP;oX^Cl0_nMi_`2oiOVo0;oX^Sk0_nJ
iOa7ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool004oooooo0_l0000^
ooooo`?oY[o/0_nV_n/8ojFok0;oYL7]1?nV`^d2ojS4k@?oZ/G]0_n^and2ok38k0?o/l[[00Co]<SY
okS9j?nhbNSo^<WX0_nhb>H3okW8i@;o^LKU0onia^@2okW5h`Co]lGT00Co/lCWok?3iOnc`nGo/l?U
0_n/`NT2ojfni`CoXKc/0onA]o43ogN^m@?oFZ;e0_lkU?43oc2@k`;oBIge0_md[oL2ojVdh@;oVkS]
1?na]mh2ok^cdP;o^;gM0onm]m<2ok_2g`Co_KcH00?o^KCEokS0h?nh`>000_nh`>02ok6ig`03ok36
jonW`NcoYl7/00;oYl7/0_nM_Nl3oic;n0?oU/cj0_nCco`3oi;IoP;oV=kn00CoTn?mohoTo?n?i?co
SnCl0_nGi_`00onBiOcoooooooooo`1:ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02_ooool0057ooooo00?o0000ooooooooool0;?ooool00onV_ncoYKo/ojFok006ojFok0;oYL3]
1?nU`Nd2ojK2k@?oZ<?]0_nZaNd2ojc6k0Co/<S/00Go/l[[okC8jOndb>Wo]<SYokS9j004okS8iP03
okW8iOnia^Go^LKU00;o^LKU00?o^LKTokW5honiaN<00_niaN<2okO5i0;o]l?S0_nc`nD2ok?0i0Co
[KkW0_nQ_>`2oj>hj0CoU;C]0omn[O82ofBSm0;oAiOb0_l`T>l3ocZGlP?oM:og0onK^>d2ok6ggP;o
Z;o[1?nh_Md00onm]m?o^l;Ook_2g`02ok_2g`;o_KcH00?o^lOTokS0h?nh`>000_nh`>000ondc>co
/<K[ok36j`02ok36j`;oYl7/0onTc_H2oic;n0?oV=Om0_nCeoh2ohoMoP;oS]on0on;h_`2ohoTo003
ohcTnooooooooooo04gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`00
D_ooool00ol0003oooooooooo`0[ooooo`WoYKo/0onU`>d2ojG1k@?oY/;]0_nX`nd2ojW4k@Co[<K/
0_n`b>`2ok77jP;o]<SY0oneanP2okS8iP?o^<KU0_nia^D3okW5i0;o^LGS00Co^LCSokO3hong`n?o
]l?S0_ng`^84ok?0i0;o[KkW0on]^n@3oj>hj0;oU;C]00CoUk7YohF/k_n5[>koQJc^0om_YO83odNG
lP04ocJBl?ljUo;o>YObocZGlP?oGj_i0on:^oH4ojRoj`;o^;gM0_nbanT3ok_2g`03okK=jonkanCo
^lOT00;o^lOT00?o^<3PokC<k?ndc>`00_ndc>`2ok36j`?oZm;d0_nTc_H2oikIo0;oV=Om0onBgOh2
ohoMoP?oRn7m0_n;h_`00on9ho_oooooooooo`1Aooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02_ooool005?ooooo00?o0000ooooooooool0:oooool7ojFok0;oYL3/1?nU`Nd2ojK2
k@;oZ<;]1?nYa>d2ojc6k0;o[/G[0_naanX2ok;6j@?o]LOX0_nea^L3okS6i@;o]lGT0oniaN@00onh
a>?o^LCSokW4h`02okW4h`03okO3hong`^;o]l;R00;o]l;R0_nc`>@3ok>nhP;o[K_T00Co[;SRojBf
iOnT]^GoY;KU1?nG/NT3ohF/kP?oKjGb0_mEW?<3od:Hl`;o=IKa0_m?YoP01?mOZoWoR[_fohZkm_n:
^oH2ojRoj`03oi_6m_nbanWo//OY00?o//OY00Co^l;OokK=jonfcN_o]/g[0_nkan@3okGBk`;o]<c/
0on^eoH2oj_Bm0;oXmck0_nNfO`3oiOOoP;oT]gn00CoSN7moh_Ro?n;h_coRn;l0_n:h_aGooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool005Cooooo0_l0000]ooooo`CoYKo/
1?nU`>`2ojG1k@;oY/7]1?nX`^d2ojW4k@;oZlC/0_n^aN/2ojo5jPCo//KY00?o]LOXokG6ionea^L0
0_nea^L00onha^Go]lGTokO5i002okO5i004okW5i?nha>?o^<CSokS4h`;o^LCS0onh`^82okO2hP;o
][oQ0onc_^800onb^n3o[;SRojbhhP02ojbhhP?oY;KU0_nG/NT2oiZ_iP?oS:_[0omjYnl2ofBRl`Co
@YSc00Co>YWcodnWn?m?YoSoCjOh0omh_?`3oi_6mP;o//OY0onXd?@2okK=j`?o[MOf0_ned^l3ojcL
n0;o[]Of0_nTgo/2oj?Ln`?oV^7m0_nGgoh01?n@h_goS>?lohcSo?n<ho`2oh_Ro5[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`09ooooo`00E_ooool00ol0003oooooooooo`0[oooo
o`CoYKo/0_nU`>`2ojK0k0CoY/7]0_nX`^d3ojW2k003oj_4k?n/`n_o[<?[00Co[lGZ0_nba^T3ok;5
j0;o]LKW0onea>H2okO5i004okO4i?nha>?o^<CSokS4h`;o^<?R0onh`^82okS0h@Co][oQ00Co/kkR
ok:kh?nb^n3o/[_P0_n/^>82ojbeh0?oY;;R1?nJ[nH3ohb[j`?oNZO_0omTX_<2oe:Om@?oAj7f0om8
YoP3ofVko@?oSL_m0_nXd?@3oicFo0;o[MOf0_nRgO`2ojcLn0?oXN7l0_nTgo/3oi[So@;oV^7m00Co
TN?mohgSo?n=hocoSN?l0_n<hoaNooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2Oooool005Oooooo00?o0000ooooooooool0:oooool2ojFok0;oY[o/1?nV`>`2ojK1k@?oYl7/0_nY
`^`00onZ`^_o[<?[ojc3j`02ojc3j`;o[lGZ0on_a>T2ok;5j0;o//CW0onea>H00onea>Go]lCTokO4
i002okO4i003okS4honh`n;o^<?R00;o^<?R00?o^<;RokS0hOnh`>400_nh`>42okJoh@04okFmgonb
^n3o/[_Pok:kh0;o/KSN1?n/]N03ojBbhP;oVZoV0_nM[N<3oi6[i`?oQ:S/0omcY_42ofBWmP?oAj7f
0om=ZoT3of:lo@CoP<go0_nLe_`2oi3Io`;oX]gl0onFh?h2oj7Qo004oiKSoOn>hocoS^?lohkSo0;o
T>Cl00?oS>?kooooooooool0I?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wo
oooo001Hooooo`03o`000?oooooooooo02cooooo0onV_n`2ojK0k0?oYl3/0_nW`N`00onX`NcoZ/;[
oj[2j`02oj[2j`;o[<?[0on]`nX2ojo4j@;o/<?X1?nba>L01?nea>Ko]LCUokG4iOnea>D2okO4i0?o
]l?S0_nh`n83okO1h@;o^<3Q00?o]kkOokFmgone_Ml00_ne_Ml00onb^n3o/KSNok6hgP02ok6hgP;o
[;GP0_n[/mh3ojF`h0CoWJgS0onAZnL3ohBXk0?oLjKa0omTYoH3oeRYn@?oEk;k0omS_od3ogS>o`;o
T=Wo0on8f_l2oiKPoP04ohgQoOn9hOcoRN7lohWQo0;oS^?l00?oR^?kooooooooool0J?ooool01Ol0
003ooooooooooooooooo000000_ooooo001Iooooo`03o`000?oooooooooo02cooooo1?nV_n`3ojO0
k0CoZ<7/0_nZ`^/3oj_2j`;o[L?Z0_n]`^T4ok33j0;o//CW0_nb`nH2okG4i@;o]L?U0ong`n<2okK2
h`?o]l7Q00?o][oQokNngong_]l00_ng_]l2okFmg`?o/k[N0_na^=h2ojneg@CoZk?N0onU/>02oif]
h`04oin/h?nGZnCoUj_ToiN[i0?oSJ[Y1?n1Znl3ogJ]m@?oJk;j1?mW^_d3ofc5oP;oMm3o0_mkdol2
ohCKoP?oQMgm0_n9hO`00on9h_coooooooooo`1[ooooo`05o`000?ooooooooooooooool000002ooo
ool005[ooooo0_l0000]ooooo`;oY[o/0_nW`>/3ojO0k0;oZ<7/0onY`N/2oj_2j`;oZl;Z1?n]`^T5
ok33j003ok;3i_nb`^Ko//;V00Co]L?U00?o]l?SokK2honf`^<00_nf`^<01?ng`N7o][oQokJohOnf
_n42okNng`;o]KcO0onc^]h00onb^=go[kGMojneg@03ojneg@;oZk?N00CoZ[3LojF^g_nU[]koYJkN
1?nO[>03oiN[i0?oSJ[Y0_n1Znl2ohf^k0?oQK?c1?mm^OT3ogS2oP?oMl_o0_mkdol2oh?Ho`;oS]_o
0_n;goeaooooo`04o`000?ooooooooooo`0000_ooooo001Looooo`03o`000?oooooooooo02_ooooo
1?nW`>/01?nW`>coZ<7[ojS1jonX`N/4ojW1j`CoZl;Z0_n]`^T2ojk2j@?o/<?X00?o/<;Wok;2i_nb
`^H00_nb`^H2okG3i@?o]<;T0_nf`^<2okK0hP?o][oQ00?o]KgPokFlgone_=l00_ne_=l01?nc^]ko
/[SMok:hgOnb^=d3ojneg@03ojjcg?nZ/=coZ[3L00;oZ[3L0onU[]h2oin/h0;oXJ_N0onKZn84oiF/
iP?oSJk/0on5/o<2ogfin@?oSKog0on8b?d2ohG@o`;oT]Gn0_n>fomeooooo`03o`000?oooooo0000
00_ooooo001Mooooo`03o`000?oooooooooo02_ooooo0_nW`>/2ojS0j`CoZ<7[1?nY`N/2oj_2jP;o
[<7Z1?n^`^T01?n``nSo/<;Wok32ion``^L5ok;2iP;o]<;T0_nd`N@4okK0hP04okJohOne_N3o]KgP
okFmh0;o]KcO0_nc^]h4ok:hg@04ojnegOn^/mco[[?Lojjcg0?oZ[3L0_nU[]h2ojJ]g0CoXJ_N0onK
Zn82oiF/iP04oib^i?nG/NWoUk7YoiNaj@GoT[O`0_n=_oL00onK`oCoUlgjoiO=nP02oiO=nP;oT]Gn
N?ooool01?l0003oooooooooool0000:ooooo`00G_ooool00ol0003oooooooooo`0[ooooo`CoZ<3[
1?nX`N/2ojW1j`;oZ/7Z1?n/`NX2ojk2j@;o[/;X1?n``^L3ok;2iP;o//7U1?nd`N@2okK0hP;o];oR
0_ne_N02ok>lh0Co/k[N0_nb^=d00on`]Mgo[[?Lojjcg002ojjcg0;oZ[3L0_nY[m/4ojJ]g0;oXJ_N
00CoXj_Moj2/gonP[=ooX:cO1?nL[^@3oiNaj@;oT[O`0onN^nd3oi_3m0;oUlgjO?ooool00ol0003o
ooooo`00000:ooooo`00Goooool2o`0002cooooo1?nX`>/2ojS1j`?oZL3[0onZ`NX2ojc1jP;o[<7Y
0_n^`^P2ojk1j0Co/<;W00?o//;Vok;1iOnb`ND00_nb`ND2okC1i004ok>ohond_n;o];oRokBohP;o
/kgQ1?nc_>02ok>jgP03ok6hg_n`]Mgo/;GM00;o/;GM0_n^/m`2ojbaf`CoZJoK0_nV[M`2ojJ/f`?o
Xj_M0onP[=l2oib^i0;oX[3R1?nP]>L2oijkkH?ooooo0_l0000:ooooo`00HOooool00ol0003ooooo
ooooo`0Zooooo`GoZ<3[1?nY`>/4oj[1jP?o[<7Y1?n^`NP2ok32i`?o[l7W0_nb`ND00ona`>Go/koS
ok>oh`02ok>oh`03okBoh_nc_N7o/kgQ00;o/kgQ0_nc_>000ona^]oo/KSNok6hgP02ok6hgP;o/;GM
0_n^/m`4ojbaf`;oZJoK0_nY[M/4ojJ/f`;oXj_M0_nP[=l2ojB]gPCoX[3R0_nP]>N5ooooo`?o0000
2_ooool006;ooooo00?o0000ooooooooool0:oooool4ojS0j`CoZL3[0onZ`NX4ojc1j@;o[/7X0on]
`NP2ojo1i`03ojo0iona`>Go/L3U00;o/L3U0_nc_n<3ok:nh`;o/kgQ0_na_>43ok6jg`;o/KSN0_n_
]]h4ojjcg0;o[;7K0_n[[m/4ojV]f`;oYZcK00CoYjcKojF/g?nU[=coYJcL1?nT[Mh2oj:`hXCooooo
1?l0000=ooooo`00Hoooool00ol0003oooooooooo`0[ooooo`CoZ<3[0_nY`>/00onY`>[oZ/7Zoj[1
jP02oj[1jPGo[<7Y0on]`NP4ojo0i`;o/L3U0on`_nD2ok:nh`;o/;gS1?na_>400ona^]oo[kSPojnh
h004ojnfgP;o[[?L0_n//]`4oj^_f`;oZJgK00?oZ:gKojN/fonW[=/00_nW[=/3ojF/g0;oY:gNPooo
ool4o`00017ooooo001Tooooo`;o0000;?ooool2ojS0j`;oZL3[0onY`>X5oj[1jP;o[<7Y0_n[`>T3
ojg1j0;o[l3W0on^`>L2ok2oi@;o[kkU1?n`_N<2ok6lh@03ojnjh_n_^>3o[kSP00;o[kSP0_n_]]h2
ojfdgPCo[;;L0_n[[m/00onY[]_oZ:gKojR]f`02ojR]f`?oYjcK0_nU[=b3ooooo`?o00005Oooool0
06Kooooo00?o0000ooooooooool0:oooool3ojW0j`CoZL3Z0_nZ`NX2oj[0jPCoZl3Y00Co[L7Xojg0
j?n]`>So[L3X0_n^`>L2ojfoi`Co[kkU0_n`_N<00on^_>Co[k[RojnjhP02ojnjhP;o[kSP0_n]]n04
ojfdgP;o[;;L00?oZ[7MojV^fonY[]/00_nY[]/2ojR]fhGooooo1?l0000Hooooo`00Ioooool00ol0
003oooooooooo`0Zooooo`CoZL3[1?nY`>X4oj[0jPCoZl3Y0_n]`>P2ojboj0Co[KoW0_n__^D00on]
_NGo[[cTojjli002ojjli0;o[k[R0_n]^N84ojfgh0;o[KCN00?oZ[?OojZagOnZ/Md00_nZ/Md2ojV^
fhCooooo1?l0000Looooo`00J?ooool00ol0003oooooooooo`0Zooooo`;oZL3[0_nX`>/4ojW0jPCo
Z/3Z1?n[`>T4ojboj0;o[KoW00?o[;kWojfmiOn]_ND00_n]_ND2ojjli0;o[;_T1?n]^N82ojfgh003
oj^fhOnZ/mooZ[?O00;oZ[?O0_nZ/Mf3ooooo`Co00008?ooool006Wooooo0_l0000/ooooo`?oZ<3[
1OnY`>X00onZ`>[oZL3ZojW0jP04oj_0j@;o[;oX0_n[_nP3ojbni`;o[KgU0_n/_NH4ojbki0;o[KWR
00?oZkSSoj^fhOn[]^400_n[]^42ojZcgh;ooooo1?l0000Tooooo`00Joooool00ol0003ooooooooo
o`0Zooooo`CoZ<3[0_nY`>X00onY`>_oZL3ZojW0jP02ojW0jP;oZl3Y0_nZ_nT4oj^oj004ojbnion[
_^OoZkkWoj^ni`?o[;gV0_n/^n@3ojZji@;oZkSS0_n[]^62ooooo`?o0000:?ooool006cooooo00?o
0000ooooooooool0:_ooool3ojS0j`CoZL3[1OnY`>X3ojZoj@;oZkoX0_nZ_nT2oj^ni`;oZKgX1?nZ
_>L2ojZjiH?ooooo1?l0000[ooooo`00KOooool00ol0003oooooooooo`0[ooooo`;oZ<3[0_nY`>/3
ojS0j`;oZL3Z00?oZ;oZojVojOnY_nT00_nY_nT2ojZoj@;oZKkY1?nY_NP2ojZlih;ooooo1?l0000_
ooooo`00K_ooool00ol0003oooooooooo`0Zooooo`SoZ<3[0onX_nX2ojVoj@;oZ;oZ1?nY_^T2ojVm
j87ooooo1?l0000cooooo`00Koooool2o`0002_ooooo2?nX`>/7ojRojP;oZKkYP?ooool4o`0003Oo
oooo001aooooo`03o`000?oooooooooo02[ooooo1onX`>/2ojRojX;ooooo1?l0000kooooo`00L_oo
ool00ol0003oooooooooo`0Zooooo`GoZ<3[P_ooool3o`0003oooooo001cooooo`03o`000?oooooo
oooo02[ooooo00?oZ<3[ooooooooool0Ooooool4o`0004;ooooo001dooooo`;o0000:_ooool00ol0
003oooooooooo`1kooooo`Co0000A_ooool007Kooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`1hooooo`Co0000B_ooool007Oooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1dooooo`Co0000C_ooool007Sooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`1aooooo`?o0000D_ooool007Wooooo0_l0000Tooooo`03o`000?oooooooooo06gooooo1?l0001E
ooooo`00Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo06Wooooo1?l0001Ioooo
o`00O?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06Gooooo1?l0001Mooooo`00
OOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo067ooooo1?l0001Qooooo`00O_oo
ool2o`0001oooooo00?o0000ooooooooool0GOooool4o`0006Gooooo0020ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool0F_ooool3o`0006Wooooo0021ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0E_ooool4o`0006cooooo0022ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0D_ooool4o`00073ooooo0023ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool0C_ooool4o`0007Cooooo0024ooooo`;o00006Oooool00ol0003ooooooooo
o`1:ooooo`Co0000N?ooool008Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`16
ooooo`Co0000O?ooool008Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`13oooo
o`?o0000P?ooool008Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0oooooo`Co
0000Poooool008Wooooo0_l0000Dooooo`03o`000?oooooooooo03_ooooo1?l00027ooooo`00Rooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Oooooo1?l0002;ooooo`00S?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03?ooooo1?l0002?ooooo`00SOooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo033ooooo0ol0002Cooooo`00S_ooool2o`0000oo
oooo00?o0000ooooooooool0;?ooool4o`0009Kooooo002@ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0:?ooool4o`0009[ooooo002Aooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool09?ooool4o`0009kooooo002Booooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool08Oooool4o`000:;ooooo002Cooooo`;o00002Oooool00ol0003oooooooooo`0Moooo
o`Co0000Y_ooool009Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Jooooo`?o
0000Z_ooool009Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`Co0000
[Oooool009Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`Co0000/Ooo
ool009Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000]Oooool0
09Wooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo1?l0002iooooo`00Voooool01?l0003o
ooooooooool00009ooooo`?o0000_Oooool009cooooo00?o0000ooooool000001Oooool4o`000<3o
oooo002Mooooo`;o000000?oooooo`000?l000000_l00034ooooo`00W_ooool2o`000<Sooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo002Zooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool5o`00
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<09?ooooo002Zooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool6o`000006oooooonH
V9So8B4Qonk^k_ooooooA4A41oooool00omgMgOo<S8booooo`03ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q09?ooooo002Zooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^
k^h02Oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000Toooool00:[o
oooo00?o0000ooooooooool01?ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo
<S8booooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B40Toooool00:[ooooo00?o0000oooooooo
ool03_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`02_ooool01Ol0
003oEEEEo`000?l@413oc<c<09?ooooo002Xooooo`03oa0@4?l0003o000000?o00003_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?oEEEEohN7Qoooool0UOooool00:[o
oooo00?o0000ooooooooool02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooo
ooooool03?ooool00ooMgMgo410@oiRHV02Eooooo`00Z_ooool00ol0003oooooooooo`0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000cooooo00Coc<c<odA4A?l0003o410@Toooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -20 0 ]
[.5 .82364 20 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(26.4) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.663 .753 .917 r
.39636 .6972 .40169 .70185 .41061 .69934 .40531 .69451 Mtetra
.663 .747 .912 r
.40531 .69451 .41061 .69934 .41957 .69681 .41428 .69181 Mtetra
.664 .741 .907 r
.41428 .69181 .41957 .69681 .42855 .69428 .42329 .68909 Mtetra
.664 .734 .902 r
.42329 .68909 .42855 .69428 .43756 .69174 .43232 .68636 Mtetra
.665 .728 .897 r
.43232 .68636 .43756 .69174 .4466 .68919 .44139 .68361 Mtetra
.664 .721 .891 r
.44139 .68361 .4466 .68919 .45567 .68663 .45048 .68086 Mtetra
.663 .715 .887 r
.45048 .68086 .45567 .68663 .46478 .68407 .4596 .67812 Mtetra
.661 .709 .883 r
.4596 .67812 .46478 .68407 .47391 .68149 .46875 .67541 Mtetra
.659 .705 .881 r
.46875 .67541 .47391 .68149 .48307 .67891 .47793 .67277 Mtetra
.656 .702 .881 r
.47793 .67277 .48307 .67891 .49227 .67632 .48714 .6702 Mtetra
.651 .702 .884 r
.48714 .6702 .49227 .67632 .50149 .67371 .49639 .66775 Mtetra
.646 .706 .89 r
.49639 .66775 .50149 .67371 .51075 .6711 .50566 .66542 Mtetra
.64 .714 .901 r
.50566 .66542 .51075 .6711 .52004 .66849 .51496 .66322 Mtetra
.633 .728 .916 r
.51496 .66322 .52004 .66849 .52936 .66586 .5243 .66114 Mtetra
.624 .748 .936 r
.5243 .66114 .52936 .66586 .53871 .66322 .53368 .65915 Mtetra
.612 .774 .958 r
.53368 .65915 .53871 .66322 .54809 .66058 .54309 .6572 Mtetra
.596 .803 .979 r
.54309 .6572 .54809 .66058 .55751 .65792 .55253 .65524 Mtetra
.575 .832 .994 r
.55253 .65524 .55751 .65792 .56695 .65526 .56201 .65321 Mtetra
.551 .855 .998 r
.56201 .65321 .56695 .65526 .57643 .65259 .57153 .65106 Mtetra
.525 .869 .991 r
.57153 .65106 .57643 .65259 .58595 .6499 .58108 .64878 Mtetra
.503 .876 .978 r
.58108 .64878 .58595 .6499 .59549 .64721 .59066 .64635 Mtetra
.486 .878 .964 r
.59066 .64635 .59549 .64721 .60507 .64451 .60028 .64383 Mtetra
.472 .877 .953 r
.60028 .64383 .60507 .64451 .61468 .6418 .60993 .64123 Mtetra
.456 .872 .943 r
.60993 .64123 .61468 .6418 .62432 .63908 .61961 .63864 Mtetra
.434 .865 .93 r
.61961 .63864 .62432 .63908 .634 .63636 .62933 .63608 Mtetra
.406 .853 .911 r
.62933 .63608 .634 .63636 .64371 .63362 .63908 .63355 Mtetra
.373 .837 .886 r
.63908 .63355 .64371 .63362 .65345 .63087 .64887 .63103 Mtetra
.342 .822 .855 r
.64887 .63103 .65345 .63087 .66323 .62811 .6587 .62847 Mtetra
.322 .81 .83 r
.6587 .62847 .66323 .62811 .67304 .62535 .66855 .62581 Mtetra
.32 .808 .818 r
.66855 .62581 .67304 .62535 .68289 .62257 .67844 .62302 Mtetra
.336 .818 .823 r
.67844 .62302 .68289 .62257 .69277 .61979 .68835 .6201 Mtetra
.365 .836 .845 r
.68835 .6201 .69277 .61979 .70269 .61699 .6983 .61709 Mtetra
.4 .855 .873 r
.6983 .61709 .70269 .61699 .71264 .61418 .70828 .61402 Mtetra
.431 .869 .901 r
.70828 .61402 .71264 .61418 .72262 .61137 .71829 .61097 Mtetra
.454 .878 .922 r
.71829 .61097 .72262 .61137 .73264 .60854 .72834 .60795 Mtetra
.472 .883 .937 r
.72834 .60795 .73264 .60854 .7427 .60571 .73842 .60496 Mtetra
.487 .887 .948 r
.73842 .60496 .7427 .60571 .75279 .60286 .74854 .60197 Mtetra
.507 .893 .958 r
.74854 .60197 .75279 .60286 .76291 .60001 .7587 .59891 Mtetra
.534 .899 .968 r
.7587 .59891 .76291 .60001 .77308 .59714 .76888 .59575 Mtetra
.57 .903 .979 r
.76888 .59575 .77308 .59714 .78328 .59427 .77908 .59244 Mtetra
.608 .9 .987 r
.77908 .59244 .78328 .59427 .79351 .59138 .78931 .58898 Mtetra
.641 .885 .985 r
.78931 .58898 .79351 .59138 .80378 .58849 .79956 .58541 Mtetra
.664 .86 .974 r
.79956 .58541 .80378 .58849 .81409 .58558 .80984 .58176 Mtetra
.676 .827 .956 r
.80984 .58176 .81409 .58558 .82443 .58267 .82016 .57809 Mtetra
.68 .795 .936 r
.82016 .57809 .82443 .58267 .83482 .57974 .83051 .57446 Mtetra
.677 .766 .917 r
.83051 .57446 .83482 .57974 .84523 .5768 .8409 .57093 Mtetra
.673 .742 .902 r
.8409 .57093 .84523 .5768 .85569 .57385 .85134 .56751 Mtetra
.668 .724 .891 r
.85134 .56751 .85569 .57385 .86618 .57089 .86183 .56422 Mtetra
.663 .712 .884 r
.86183 .56422 .86618 .57089 .87672 .56792 .87236 .56106 Mtetra
.659 .705 .881 r
.87236 .56106 .87672 .56792 .88729 .56494 .88295 .55801 Mtetra
.656 .702 .881 r
.88295 .55801 .88729 .56494 .89789 .56195 .89359 .55505 Mtetra
.654 .702 .883 r
.89359 .55505 .89789 .56195 .90854 .55895 .90427 .55214 Mtetra
.652 .705 .886 r
.90427 .55214 .90854 .55895 .91923 .55594 .915 .54927 Mtetra
.651 .711 .891 r
.915 .54927 .91923 .55594 .92995 .55292 .92577 .54641 Mtetra
.651 .716 .896 r
.92577 .54641 .92995 .55292 .94071 .54988 .93658 .54355 Mtetra
.651 .723 .902 r
.93658 .54355 .94071 .54988 .95152 .54684 .94744 .54067 Mtetra
.651 .73 .907 r
.94744 .54067 .95152 .54684 .96236 .54378 .95833 .53777 Mtetra
.65 .736 .912 r
.95833 .53777 .96236 .54378 .97324 .54071 .96926 .53485 Mtetra
.65 .743 .917 r
.96926 .53485 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.669 .754 .914 r
.391 .69252 .39636 .6972 .40531 .69451 .39997 .68967 Mtetra
.67 .749 .909 r
.39997 .68967 .40531 .69451 .41428 .69181 .40897 .68678 Mtetra
.671 .743 .904 r
.40897 .68678 .41428 .69181 .42329 .68909 .418 .68388 Mtetra
.671 .736 .899 r
.418 .68388 .42329 .68909 .43232 .68636 .42706 .68095 Mtetra
.671 .73 .894 r
.42706 .68095 .43232 .68636 .44139 .68361 .43614 .678 Mtetra
.671 .723 .889 r
.43614 .678 .44139 .68361 .45048 .68086 .44526 .67505 Mtetra
.669 .717 .884 r
.44526 .67505 .45048 .68086 .4596 .67812 .4544 .67213 Mtetra
.666 .71 .881 r
.4544 .67213 .4596 .67812 .46875 .67541 .46357 .66929 Mtetra
.661 .705 .879 r
.46357 .66929 .46875 .67541 .47793 .67277 .47277 .66656 Mtetra
.654 .701 .881 r
.47277 .66656 .47793 .67277 .48714 .6702 .48199 .66402 Mtetra
.646 .699 .885 r
.48199 .66402 .48714 .6702 .49639 .66775 .49125 .6617 Mtetra
.635 .701 .893 r
.49125 .6617 .49639 .66775 .50566 .66542 .50054 .65964 Mtetra
.622 .706 .906 r
.50054 .65964 .50566 .66542 .51496 .66322 .50986 .65787 Mtetra
.607 .718 .923 r
.50986 .65787 .51496 .66322 .5243 .66114 .51922 .65633 Mtetra
.589 .734 .944 r
.51922 .65633 .5243 .66114 .53368 .65915 .52861 .655 Mtetra
.569 .758 .967 r
.52861 .655 .53368 .65915 .54309 .6572 .53805 .65375 Mtetra
.546 .784 .987 r
.53805 .65375 .54309 .6572 .55253 .65524 .54752 .65249 Mtetra
.524 .812 .998 r
.54752 .65249 .55253 .65524 .56201 .65321 .55703 .65109 Mtetra
.505 .835 .999 r
.55703 .65109 .56201 .65321 .57153 .65106 .56659 .64944 Mtetra
.493 .853 .991 r
.56659 .64944 .57153 .65106 .58108 .64878 .57617 .64752 Mtetra
.491 .867 .981 r
.57617 .64752 .58108 .64878 .59066 .64635 .58579 .6453 Mtetra
.491 .874 .973 r
.58579 .6453 .59066 .64635 .60028 .64383 .59544 .64288 Mtetra
.492 .878 .968 r
.59544 .64288 .60028 .64383 .60993 .64123 .60512 .64034 Mtetra
.483 .876 .964 r
.60512 .64034 .60993 .64123 .61961 .63864 .61484 .63781 Mtetra
.464 .87 .958 r
.61484 .63781 .61961 .63864 .62933 .63608 .6246 .63537 Mtetra
.438 .861 .946 r
.6246 .63537 .62933 .63608 .63908 .63355 .6344 .63301 Mtetra
.408 .849 .929 r
.6344 .63301 .63908 .63355 .64887 .63103 .64423 .6307 Mtetra
.388 .842 .909 r
.64423 .6307 .64887 .63103 .6587 .62847 .6541 .62832 Mtetra
.381 .841 .892 r
.6541 .62832 .6587 .62847 .66855 .62581 .664 .62577 Mtetra
.395 .851 .887 r
.664 .62577 .66855 .62581 .67844 .62302 .67392 .62297 Mtetra
.425 .867 .895 r
.67392 .62297 .67844 .62302 .68835 .6201 .68387 .61991 Mtetra
.459 .883 .911 r
.68387 .61991 .68835 .6201 .6983 .61709 .69385 .61669 Mtetra
.49 .895 .93 r
.69385 .61669 .6983 .61709 .70828 .61402 .70385 .61338 Mtetra
.508 .898 .947 r
.70385 .61338 .70828 .61402 .71829 .61097 .71389 .61013 Mtetra
.517 .898 .958 r
.71389 .61013 .71829 .61097 .72834 .60795 .72397 .60697 Mtetra
.521 .895 .964 r
.72397 .60697 .72834 .60795 .73842 .60496 .73409 .60388 Mtetra
.526 .895 .968 r
.73409 .60388 .73842 .60496 .74854 .60197 .74425 .60081 Mtetra
.542 .9 .971 r
.74425 .60081 .74854 .60197 .7587 .59891 .75443 .59761 Mtetra
.569 .907 .976 r
.75443 .59761 .7587 .59891 .76888 .59575 .76463 .59421 Mtetra
.609 .913 .98 r
.76463 .59421 .76888 .59575 .77908 .59244 .77485 .59051 Mtetra
.648 .909 .981 r
.77485 .59051 .77908 .59244 .78931 .58898 .78507 .58651 Mtetra
.681 .894 .974 r
.78507 .58651 .78931 .58898 .79956 .58541 .79531 .58226 Mtetra
.701 .868 .961 r
.79531 .58226 .79956 .58541 .80984 .58176 .80556 .57786 Mtetra
.708 .835 .943 r
.80556 .57786 .80984 .58176 .82016 .57809 .81585 .57344 Mtetra
.706 .801 .924 r
.81585 .57344 .82016 .57809 .83051 .57446 .82616 .5691 Mtetra
.698 .771 .908 r
.82616 .5691 .83051 .57446 .8409 .57093 .83653 .56497 Mtetra
.688 .746 .895 r
.83653 .56497 .8409 .57093 .85134 .56751 .84695 .56107 Mtetra
.677 .726 .886 r
.84695 .56107 .85134 .56751 .86183 .56422 .85744 .55746 Mtetra
.668 .712 .881 r
.85744 .55746 .86183 .56422 .87236 .56106 .86798 .55412 Mtetra
.66 .704 .879 r
.86798 .55412 .87236 .56106 .88295 .55801 .87859 .55101 Mtetra
.654 .7 .88 r
.87859 .55101 .88295 .55801 .89359 .55505 .88925 .54809 Mtetra
.649 .7 .883 r
.88925 .54809 .89359 .55505 .90427 .55214 .89998 .54529 Mtetra
.646 .703 .888 r
.89998 .54529 .90427 .55214 .915 .54927 .91075 .54256 Mtetra
.645 .708 .893 r
.91075 .54256 .915 .54927 .92577 .54641 .92157 .53987 Mtetra
.644 .714 .898 r
.92157 .53987 .92577 .54641 .93658 .54355 .93243 .53718 Mtetra
.644 .72 .904 r
.93243 .53718 .93658 .54355 .94744 .54067 .94333 .53446 Mtetra
.644 .727 .909 r
.94333 .53446 .94744 .54067 .95833 .53777 .95427 .53172 Mtetra
.644 .734 .914 r
.95427 .53172 .95833 .53777 .96926 .53485 .96526 .52896 Mtetra
.644 .74 .919 r
.96526 .52896 .96926 .53485 .98024 .53192 .97628 .52616 Mtetra
.675 .756 .912 r
.38561 .68781 .391 .69252 .39997 .68967 .3946 .6848 Mtetra
.676 .75 .907 r
.3946 .6848 .39997 .68967 .40897 .68678 .40363 .68174 Mtetra
.677 .745 .902 r
.40363 .68174 .40897 .68678 .418 .68388 .41268 .67865 Mtetra
.678 .739 .897 r
.41268 .67865 .418 .68388 .42706 .68095 .42176 .67553 Mtetra
.678 .733 .891 r
.42176 .67553 .42706 .68095 .43614 .678 .43087 .67238 Mtetra
.677 .726 .886 r
.43087 .67238 .43614 .678 .44526 .67505 .44001 .66923 Mtetra
.675 .719 .882 r
.44001 .66923 .44526 .67505 .4544 .67213 .44917 .66612 Mtetra
.67 .712 .879 r
.44917 .66612 .4544 .67213 .46357 .66929 .45836 .66312 Mtetra
.664 .705 .878 r
.45836 .66312 .46357 .66929 .47277 .66656 .46757 .66031 Mtetra
.654 .7 .88 r
.46757 .66031 .47277 .66656 .48199 .66402 .47682 .65776 Mtetra
.64 .696 .886 r
.47682 .65776 .48199 .66402 .49125 .6617 .48609 .65557 Mtetra
.624 .695 .895 r
.48609 .65557 .49125 .6617 .50054 .65964 .49539 .65377 Mtetra
.603 .697 .91 r
.49539 .65377 .50054 .65964 .50986 .65787 .50472 .65241 Mtetra
.579 .705 .928 r
.50472 .65241 .50986 .65787 .51922 .65633 .5141 .65142 Mtetra
.55 .717 .95 r
.5141 .65142 .51922 .65633 .52861 .655 .52351 .65075 Mtetra
.521 .736 .972 r
.52351 .65075 .52861 .655 .53805 .65375 .53297 .6502 Mtetra
.492 .759 .99 r
.53297 .6502 .53805 .65375 .54752 .65249 .54247 .64964 Mtetra
.471 .786 .999 r
.54247 .64964 .54752 .65249 .55703 .65109 .55201 .64884 Mtetra
.466 .814 .998 r
.55201 .64884 .55703 .65109 .56659 .64944 .5616 .64765 Mtetra
.476 .838 .993 r
.5616 .64765 .56659 .64944 .57617 .64752 .57122 .64601 Mtetra
.501 .862 .988 r
.57122 .64601 .57617 .64752 .58579 .6453 .58087 .64388 Mtetra
.524 .875 .987 r
.58087 .64388 .58579 .6453 .59544 .64288 .59055 .64144 Mtetra
.542 .882 .987 r
.59055 .64144 .59544 .64288 .60512 .64034 .60027 .63882 Mtetra
.542 .879 .989 r
.60027 .63882 .60512 .64034 .61484 .63781 .61002 .63623 Mtetra
.528 .872 .99 r
.61002 .63623 .61484 .63781 .6246 .63537 .61981 .63382 Mtetra
.506 .865 .988 r
.61981 .63382 .6246 .63537 .6344 .63301 .62964 .63158 Mtetra
.48 .858 .982 r
.62964 .63158 .6344 .63301 .64423 .6307 .63952 .62948 Mtetra
.469 .861 .974 r
.63952 .62948 .64423 .6307 .6541 .62832 .64943 .62728 Mtetra
.473 .869 .966 r
.64943 .62728 .6541 .62832 .664 .62577 .65937 .62485 Mtetra
.5 .886 .963 r
.65937 .62485 .664 .62577 .67392 .62297 .66933 .62203 Mtetra
.538 .902 .966 r
.66933 .62203 .67392 .62297 .68387 .61991 .67931 .61883 Mtetra
.57 .91 .972 r
.67931 .61883 .68387 .61991 .69385 .61669 .68931 .61539 Mtetra
.592 .912 .978 r
.68931 .61539 .69385 .61669 .70385 .61338 .69934 .61186 Mtetra
.594 .904 .984 r
.69934 .61186 .70385 .61338 .71389 .61013 .70941 .60845 Mtetra
.588 .896 .987 r
.70941 .60845 .71389 .61013 .72397 .60697 .71952 .60523 Mtetra
.576 .89 .989 r
.71952 .60523 .72397 .60697 .73409 .60388 .72968 .60217 Mtetra
.569 .889 .988 r
.72968 .60217 .73409 .60388 .74425 .60081 .73988 .59915 Mtetra
.579 .896 .986 r
.73988 .59915 .74425 .60081 .75443 .59761 .7501 .59594 Mtetra
.603 .905 .984 r
.7501 .59594 .75443 .59761 .76463 .59421 .76033 .59242 Mtetra
.644 .914 .98 r
.76033 .59242 .76463 .59421 .77485 .59051 .77056 .58839 Mtetra
.683 .911 .973 r
.77056 .58839 .77485 .59051 .78507 .58651 .78079 .5839 Mtetra
.716 .897 .961 r
.78079 .5839 .78507 .58651 .79531 .58226 .79101 .579 Mtetra
.733 .871 .945 r
.79101 .579 .79531 .58226 .80556 .57786 .80124 .57385 Mtetra
.736 .838 .927 r
.80124 .57385 .80556 .57786 .81585 .57344 .8115 .56867 Mtetra
.73 .804 .91 r
.8115 .56867 .81585 .57344 .82616 .5691 .82178 .56362 Mtetra
.716 .773 .897 r
.82178 .56362 .82616 .5691 .83653 .56497 .83213 .55888 Mtetra
.702 .748 .887 r
.83213 .55888 .83653 .56497 .84695 .56107 .84253 .55452 Mtetra
.686 .727 .881 r
.84253 .55452 .84695 .56107 .85744 .55746 .85301 .55061 Mtetra
.673 .713 .878 r
.85301 .55061 .85744 .55746 .86798 .55412 .86357 .5471 Mtetra
.661 .703 .878 r
.86357 .5471 .86798 .55412 .87859 .55101 .8742 .54395 Mtetra
.651 .699 .881 r
.8742 .54395 .87859 .55101 .88925 .54809 .88489 .54108 Mtetra
.645 .698 .885 r
.88489 .54108 .88925 .54809 .89998 .54529 .89566 .5384 Mtetra
.64 .7 .89 r
.89566 .5384 .89998 .54529 .91075 .54256 .90647 .53584 Mtetra
.638 .706 .895 r
.90647 .53584 .91075 .54256 .92157 .53987 .91734 .53331 Mtetra
.637 .711 .901 r
.91734 .53331 .92157 .53987 .93243 .53718 .92825 .5308 Mtetra
.638 .718 .906 r
.92825 .5308 .93243 .53718 .94333 .53446 .9392 .52824 Mtetra
.638 .725 .911 r
.9392 .52824 .94333 .53446 .95427 .53172 .95019 .52566 Mtetra
.638 .731 .916 r
.95019 .52566 .95427 .53172 .96526 .52896 .96123 .52303 Mtetra
.638 .738 .921 r
.96123 .52303 .96526 .52896 .97628 .52616 .9723 .52037 Mtetra
.68 .757 .909 r
.38018 .68308 .38561 .68781 .3946 .6848 .3892 .67991 Mtetra
.682 .752 .905 r
.3892 .67991 .3946 .6848 .40363 .68174 .39825 .6767 Mtetra
.683 .747 .9 r
.39825 .6767 .40363 .68174 .41268 .67865 .40732 .67344 Mtetra
.684 .741 .895 r
.40732 .67344 .41268 .67865 .42176 .67553 .41643 .67013 Mtetra
.685 .736 .889 r
.41643 .67013 .42176 .67553 .43087 .67238 .42556 .66678 Mtetra
.684 .729 .885 r
.42556 .66678 .43087 .67238 .44001 .66923 .43472 .66343 Mtetra
.681 .722 .88 r
.43472 .66343 .44001 .66923 .44917 .66612 .44391 .66011 Mtetra
.676 .715 .878 r
.44391 .66011 .44917 .66612 .45836 .66312 .45312 .65695 Mtetra
.667 .707 .878 r
.45312 .65695 .45836 .66312 .46757 .66031 .46235 .65402 Mtetra
.654 .7 .88 r
.46235 .65402 .46757 .66031 .47682 .65776 .47161 .65145 Mtetra
.636 .694 .887 r
.47161 .65145 .47682 .65776 .48609 .65557 .4809 .64935 Mtetra
.614 .689 .897 r
.4809 .64935 .48609 .65557 .49539 .65377 .49021 .64778 Mtetra
.584 .687 .912 r
.49021 .64778 .49539 .65377 .50472 .65241 .49956 .64681 Mtetra
.55 .689 .931 r
.49956 .64681 .50472 .65241 .5141 .65142 .50895 .64635 Mtetra
.508 .695 .953 r
.50895 .64635 .5141 .65142 .52351 .65075 .51838 .64634 Mtetra
.469 .709 .973 r
.51838 .64634 .52351 .65075 .53297 .6502 .52785 .6465 Mtetra
.435 .728 .988 r
.52785 .6465 .53297 .6502 .54247 .64964 .53738 .64662 Mtetra
.422 .757 .995 r
.53738 .64662 .54247 .64964 .55201 .64884 .54695 .6464 Mtetra
.438 .793 .997 r
.54695 .6464 .55201 .64884 .5616 .64765 .55657 .64559 Mtetra
.477 .828 .997 r
.55657 .64559 .5616 .64765 .57122 .64601 .56622 .64411 Mtetra
.535 .86 .996 r
.56622 .64411 .57122 .64601 .58087 .64388 .5759 .64192 Mtetra
.578 .873 .994 r
.5759 .64192 .58087 .64388 .59055 .64144 .58561 .63927 Mtetra
.608 .873 .992 r
.58561 .63927 .59055 .64144 .60027 .63882 .59535 .63636 Mtetra
.611 .861 .99 r
.59535 .63636 .60027 .63882 .61002 .63623 .60512 .63355 Mtetra
.598 .847 .992 r
.60512 .63355 .61002 .63623 .61981 .63382 .61494 .63103 Mtetra
.576 .836 .994 r
.61494 .63103 .61981 .63382 .62964 .63158 .62481 .62886 Mtetra
.551 .83 .997 r
.62481 .62886 .62964 .63158 .63952 .62948 .63472 .62695 Mtetra
.546 .838 .999 r
.63472 .62695 .63952 .62948 .64943 .62728 .64467 .62495 Mtetra
.558 .853 .997 r
.64467 .62495 .64943 .62728 .65937 .62485 .65464 .62266 Mtetra
.592 .872 .994 r
.65464 .62266 .65937 .62485 .66933 .62203 .66464 .61983 Mtetra
.63 .885 .987 r
.66464 .61983 .66933 .62203 .67931 .61883 .67465 .61646 Mtetra
.654 .884 .982 r
.67465 .61646 .67931 .61883 .68931 .61539 .68467 .61278 Mtetra
.666 .877 .978 r
.68467 .61278 .68931 .61539 .69934 .61186 .69473 .60902 Mtetra
.655 .864 .979 r
.69473 .60902 .69934 .61186 .70941 .60845 .70482 .60552 Mtetra
.636 .855 .983 r
.70482 .60552 .70941 .60845 .71952 .60523 .71497 .60236 Mtetra
.614 .852 .988 r
.71497 .60236 .71952 .60523 .72968 .60217 .72518 .5995 Mtetra
.599 .857 .993 r
.72518 .5995 .72968 .60217 .73988 .59915 .73542 .59674 Mtetra
.604 .872 .992 r
.73542 .59674 .73988 .59915 .7501 .59594 .74569 .59372 Mtetra
.627 .889 .988 r
.74569 .59372 .7501 .59594 .76033 .59242 .75597 .59023 Mtetra
.67 .905 .978 r
.75597 .59023 .76033 .59242 .77056 .58839 .76622 .586 Mtetra
.712 .906 .964 r
.76622 .586 .77056 .58839 .78079 .5839 .77646 .58109 Mtetra
.744 .894 .946 r
.77646 .58109 .78079 .5839 .79101 .579 .78667 .57557 Mtetra
.76 .869 .928 r
.78667 .57557 .79101 .579 .80124 .57385 .79688 .56968 Mtetra
.76 .837 .911 r
.79688 .56968 .80124 .57385 .8115 .56867 .80711 .56374 Mtetra
.75 .804 .896 r
.80711 .56374 .8115 .56867 .82178 .56362 .81737 .55798 Mtetra
.732 .774 .886 r
.81737 .55798 .82178 .56362 .83213 .55888 .82769 .55265 Mtetra
.714 .748 .879 r
.82769 .55265 .83213 .55888 .84253 .55452 .83808 .54785 Mtetra
.693 .727 .876 r
.83808 .54785 .84253 .55452 .85301 .55061 .84856 .54366 Mtetra
.676 .712 .875 r
.84856 .54366 .85301 .55061 .86357 .5471 .85913 .54001 Mtetra
.66 .702 .878 r
.85913 .54001 .86357 .5471 .8742 .54395 .86978 .53685 Mtetra
.648 .697 .882 r
.86978 .53685 .8742 .54395 .88489 .54108 .88051 .53406 Mtetra
.64 .696 .887 r
.88051 .53406 .88489 .54108 .89566 .5384 .89131 .53151 Mtetra
.634 .699 .892 r
.89131 .53151 .89566 .5384 .90647 .53584 .90218 .52912 Mtetra
.631 .704 .898 r
.90218 .52912 .90647 .53584 .91734 .53331 .91309 .52677 Mtetra
.63 .71 .904 r
.91309 .52677 .91734 .53331 .92825 .5308 .92405 .52442 Mtetra
.631 .717 .909 r
.92405 .52442 .92825 .5308 .9392 .52824 .93505 .52202 Mtetra
.631 .724 .914 r
.93505 .52202 .9392 .52824 .95019 .52566 .94609 .51957 Mtetra
.632 .73 .918 r
.94609 .51957 .95019 .52566 .96123 .52303 .95717 .51708 Mtetra
.633 .736 .922 r
.95717 .51708 .96123 .52303 .9723 .52037 .96829 .51454 Mtetra
.685 .758 .907 r
.37472 .67831 .38018 .68308 .3892 .67991 .38376 .67501 Mtetra
.686 .754 .903 r
.38376 .67501 .3892 .67991 .39825 .6767 .39283 .67165 Mtetra
.688 .749 .898 r
.39283 .67165 .39825 .6767 .40732 .67344 .40194 .66824 Mtetra
.689 .745 .893 r
.40194 .66824 .40732 .67344 .41643 .67013 .41107 .66476 Mtetra
.691 .739 .888 r
.41107 .66476 .41643 .67013 .42556 .66678 .42022 .66121 Mtetra
.69 .733 .883 r
.42022 .66121 .42556 .66678 .43472 .66343 .42941 .65765 Mtetra
.688 .726 .879 r
.42941 .65765 .43472 .66343 .44391 .66011 .43862 .65413 Mtetra
.681 .718 .877 r
.43862 .65413 .44391 .66011 .45312 .65695 .44785 .65077 Mtetra
.671 .709 .876 r
.44785 .65077 .45312 .65695 .46235 .65402 .4571 .64769 Mtetra
.656 .7 .879 r
.4571 .64769 .46235 .65402 .47161 .65145 .46638 .64506 Mtetra
.633 .691 .886 r
.46638 .64506 .47161 .65145 .4809 .64935 .47568 .64301 Mtetra
.605 .683 .897 r
.47568 .64301 .4809 .64935 .49021 .64778 .48501 .64164 Mtetra
.565 .676 .913 r
.48501 .64164 .49021 .64778 .49956 .64681 .49436 .64104 Mtetra
.521 .672 .932 r
.49436 .64104 .49956 .64681 .50895 .64635 .50376 .64109 Mtetra
.465 .669 .952 r
.50376 .64109 .50895 .64635 .51838 .64634 .51321 .64173 Mtetra
.416 .676 .969 r
.51321 .64173 .51838 .64634 .52785 .6465 .5227 .64259 Mtetra
.378 .692 .981 r
.5227 .64259 .52785 .6465 .53738 .64662 .53225 .64338 Mtetra
.379 .726 .989 r
.53225 .64338 .53738 .64662 .54695 .6464 .54185 .64369 Mtetra
.426 .775 .996 r
.54185 .64369 .54695 .6464 .55657 .64559 .55149 .64317 Mtetra
.501 .822 1 r
.55149 .64317 .55657 .64559 .56622 .64411 .56117 .6417 Mtetra
.587 .855 .994 r
.56117 .6417 .56622 .64411 .5759 .64192 .57088 .63921 Mtetra
.641 .857 .982 r
.57088 .63921 .5759 .64192 .58561 .63927 .58061 .63609 Mtetra
.67 .842 .966 r
.58061 .63609 .58561 .63927 .59535 .63636 .59037 .63261 Mtetra
.667 .816 .955 r
.59037 .63261 .59535 .63636 .60512 .63355 .60016 .62933 Mtetra
.647 .79 .951 r
.60016 .62933 .60512 .63355 .61494 .63103 .61 .62655 Mtetra
.621 .771 .952 r
.61 .62655 .61494 .63103 .62481 .62886 .61989 .62434 Mtetra
.594 .761 .958 r
.61989 .62434 .62481 .62886 .63472 .62695 .62983 .62261 Mtetra
.592 .769 .964 r
.62983 .62261 .63472 .62695 .64467 .62495 .63981 .62084 Mtetra
.608 .786 .966 r
.63981 .62084 .64467 .62495 .65464 .62266 .64982 .61872 Mtetra
.643 .805 .961 r
.64982 .61872 .65464 .62266 .66464 .61983 .65984 .61587 Mtetra
.678 .815 .949 r
.65984 .61587 .66464 .61983 .67465 .61646 .66987 .61229 Mtetra
.694 .811 .938 r
.66987 .61229 .67465 .61646 .68467 .61278 .67992 .60836 Mtetra
.696 .801 .93 r
.67992 .60836 .68467 .61278 .69473 .60902 .68999 .60437 Mtetra
.677 .787 .933 r
.68999 .60437 .69473 .60902 .70482 .60552 .70011 .60087 Mtetra
.651 .78 .943 r
.70011 .60087 .70482 .60552 .71497 .60236 .71031 .59795 Mtetra
.624 .782 .957 r
.71031 .59795 .71497 .60236 .72518 .5995 .72056 .59553 Mtetra
.604 .796 .973 r
.72056 .59553 .72518 .5995 .73542 .59674 .73087 .59331 Mtetra
.61 .825 .983 r
.73087 .59331 .73542 .59674 .74569 .59372 .7412 .59073 Mtetra
.635 .857 .983 r
.7412 .59073 .74569 .59372 .75597 .59023 .75153 .58751 Mtetra
.685 .885 .972 r
.75153 .58751 .75597 .59023 .76622 .586 .76182 .58324 Mtetra
.731 .894 .953 r
.76182 .58324 .76622 .586 .77646 .58109 .77207 .578 Mtetra
.766 .885 .931 r
.77207 .578 .77646 .58109 .78667 .57557 .78228 .57191 Mtetra
.782 .863 .91 r
.78228 .57191 .78667 .57557 .79688 .56968 .79247 .5653 Mtetra
.779 .833 .893 r
.79247 .5653 .79688 .56968 .80711 .56374 .80267 .55861 Mtetra
.767 .802 .881 r
.80267 .55861 .80711 .56374 .81737 .55798 .8129 .55213 Mtetra
.746 .772 .874 r
.8129 .55213 .81737 .55798 .82769 .55265 .8232 .54624 Mtetra
.724 .747 .87 r
.8232 .54624 .82769 .55265 .83808 .54785 .83359 .54101 Mtetra
.699 .725 .87 r
.83359 .54101 .83808 .54785 .84856 .54366 .84407 .53658 Mtetra
.678 .71 .873 r
.84407 .53658 .84856 .54366 .85913 .54001 .85466 .53284 Mtetra
.659 .7 .877 r
.85466 .53284 .85913 .54001 .86978 .53685 .86534 .5297 Mtetra
.644 .695 .883 r
.86534 .5297 .86978 .53685 .88051 .53406 .87611 .52702 Mtetra
.633 .695 .889 r
.87611 .52702 .88051 .53406 .89131 .53151 .88695 .52463 Mtetra
.626 .697 .896 r
.88695 .52463 .89131 .53151 .90218 .52912 .89786 .52242 Mtetra
.624 .703 .902 r
.89786 .52242 .90218 .52912 .91309 .52677 .90882 .52025 Mtetra
.623 .709 .908 r
.90882 .52025 .91309 .52677 .92405 .52442 .91983 .51807 Mtetra
.624 .716 .912 r
.91983 .51807 .92405 .52442 .93505 .52202 .93088 .51581 Mtetra
.625 .723 .917 r
.93088 .51581 .93505 .52202 .94609 .51957 .94196 .51349 Mtetra
.627 .729 .921 r
.94196 .51349 .94609 .51957 .95717 .51708 .95309 .51111 Mtetra
.628 .734 .924 r
.95309 .51111 .95717 .51708 .96829 .51454 .96426 .50866 Mtetra
.688 .758 .905 r
.36922 .67351 .37472 .67831 .38376 .67501 .37829 .67011 Mtetra
.69 .755 .902 r
.37829 .67011 .38376 .67501 .39283 .67165 .38739 .66663 Mtetra
.692 .752 .898 r
.38739 .66663 .39283 .67165 .40194 .66824 .39651 .66308 Mtetra
.694 .748 .893 r
.39651 .66308 .40194 .66824 .41107 .66476 .40567 .65945 Mtetra
.697 .744 .888 r
.40567 .65945 .41107 .66476 .42022 .66121 .41485 .65571 Mtetra
.697 .738 .883 r
.41485 .65571 .42022 .66121 .42941 .65765 .42406 .65195 Mtetra
.695 .731 .879 r
.42406 .65195 .42941 .65765 .43862 .65413 .43329 .64821 Mtetra
.688 .723 .876 r
.43329 .64821 .43862 .65413 .44785 .65077 .44255 .64464 Mtetra
.677 .714 .876 r
.44255 .64464 .44785 .65077 .4571 .64769 .45182 .64139 Mtetra
.659 .703 .88 r
.45182 .64139 .4571 .64769 .46638 .64506 .46112 .63865 Mtetra
.633 .692 .887 r
.46112 .63865 .46638 .64506 .47568 .64301 .47043 .6366 Mtetra
.598 .68 .898 r
.47043 .6366 .47568 .64301 .48501 .64164 .47977 .63537 Mtetra
.549 .666 .914 r
.47977 .63537 .48501 .64164 .49436 .64104 .48914 .63509 Mtetra
.493 .654 .931 r
.48914 .63509 .49436 .64104 .50376 .64109 .49855 .63562 Mtetra
.422 .641 .948 r
.49855 .63562 .50376 .64109 .51321 .64173 .50801 .63689 Mtetra
.364 .641 .961 r
.50801 .63689 .51321 .64173 .5227 .64259 .51752 .63843 Mtetra
.325 .654 .971 r
.51752 .63843 .5227 .64259 .53225 .64338 .52708 .63987 Mtetra
.346 .697 .983 r
.52708 .63987 .53225 .64338 .54185 .64369 .53671 .64065 Mtetra
.429 .762 .996 r
.53671 .64065 .54185 .64369 .55149 .64317 .54637 .64032 Mtetra
.538 .817 .997 r
.54637 .64032 .55149 .64317 .56117 .6417 .55608 .63869 Mtetra
.642 .843 .977 r
.55608 .63869 .56117 .6417 .57088 .63921 .56581 .63566 Mtetra
.694 .831 .948 r
.56581 .63566 .57088 .63921 .58061 .63609 .57556 .63176 Mtetra
.714 .802 .919 r
.57556 .63176 .58061 .63609 .59037 .63261 .58532 .62742 Mtetra
.7 .764 .902 r
.58532 .62742 .59037 .63261 .60016 .62933 .59513 .62341 Mtetra
.67 .731 .895 r
.59513 .62341 .60016 .62933 .61 .62655 .60498 .62019 Mtetra
.637 .705 .896 r
.60498 .62019 .61 .62655 .61989 .62434 .61488 .61789 Mtetra
.604 .69 .903 r
.61488 .61789 .61989 .62434 .62983 .62261 .62485 .61641 Mtetra
.6 .697 .911 r
.62485 .61641 .62983 .62261 .63981 .62084 .63486 .61495 Mtetra
.616 .715 .916 r
.63486 .61495 .63981 .62084 .64982 .61872 .6449 .61307 Mtetra
.655 .739 .911 r
.6449 .61307 .64982 .61872 .65984 .61587 .65495 .6102 Mtetra
.69 .75 .897 r
.65495 .6102 .65984 .61587 .66987 .61229 .66499 .60634 Mtetra
.703 .745 .884 r
.66499 .60634 .66987 .61229 .67992 .60836 .67504 .60205 Mtetra
.7 .733 .877 r
.67504 .60205 .67992 .60836 .68999 .60437 .68513 .59779 Mtetra
.674 .716 .88 r
.68513 .59779 .68999 .60437 .70011 .60087 .69528 .59434 Mtetra
.642 .706 .893 r
.69528 .59434 .70011 .60087 .71031 .59795 .70551 .59181 Mtetra
.608 .707 .915 r
.70551 .59181 .71031 .59795 .72056 .59553 .71584 .59009 Mtetra
.584 .725 .94 r
.71584 .59009 .72056 .59553 .73087 .59331 .72622 .58871 Mtetra
.593 .765 .962 r
.72622 .58871 .73087 .59331 .7412 .59073 .73663 .58689 Mtetra
.625 .813 .972 r
.73663 .58689 .7412 .59073 .75153 .58751 .74702 .58417 Mtetra
.688 .857 .963 r
.74702 .58417 .75153 .58751 .76182 .58324 .75736 .58004 Mtetra
.743 .877 .941 r
.75736 .58004 .76182 .58324 .77207 .578 .76763 .57458 Mtetra
.782 .873 .915 r
.76763 .57458 .77207 .578 .78228 .57191 .77784 .56796 Mtetra
.798 .853 .891 r
.77784 .56796 .78228 .57191 .79247 .5653 .78801 .56065 Mtetra
.795 .825 .876 r
.78801 .56065 .79247 .5653 .80267 .55861 .79819 .55322 Mtetra
.781 .797 .866 r
.79819 .55322 .80267 .55861 .8129 .55213 .80839 .54606 Mtetra
.757 .768 .863 r
.80839 .54606 .8129 .55213 .8232 .54624 .81868 .53964 Mtetra
.731 .745 .862 r
.81868 .53964 .8232 .54624 .83359 .54101 .82906 .53405 Mtetra
.703 .724 .866 r
.82906 .53405 .83359 .54101 .84407 .53658 .83955 .52942 Mtetra
.678 .709 .872 r
.83955 .52942 .84407 .53658 .85466 .53284 .85016 .52564 Mtetra
.656 .699 .878 r
.85016 .52564 .85466 .53284 .86534 .5297 .86087 .52257 Mtetra
.638 .694 .886 r
.86087 .52257 .86534 .5297 .87611 .52702 .87168 .52004 Mtetra
.626 .694 .893 r
.87168 .52004 .87611 .52702 .88695 .52463 .88257 .51782 Mtetra
.618 .697 .901 r
.88257 .51782 .88695 .52463 .89786 .52242 .89353 .5158 Mtetra
.616 .703 .907 r
.89353 .5158 .89786 .52242 .90882 .52025 .90454 .5138 Mtetra
.615 .71 .912 r
.90454 .5138 .90882 .52025 .91983 .51807 .91559 .51177 Mtetra
.618 .717 .917 r
.91559 .51177 .91983 .51807 .93088 .51581 .92668 .50964 Mtetra
.62 .723 .92 r
.92668 .50964 .93088 .51581 .94196 .51349 .93782 .50742 Mtetra
.622 .729 .923 r
.93782 .50742 .94196 .51349 .95309 .51111 .94899 .50512 Mtetra
.624 .734 .926 r
.94899 .50512 .95309 .51111 .96426 .50866 .9602 .50275 Mtetra
.69 .759 .904 r
.36369 .66869 .36922 .67351 .37829 .67011 .37278 .66521 Mtetra
.693 .757 .901 r
.37278 .66521 .37829 .67011 .38739 .66663 .3819 .66164 Mtetra
.695 .755 .898 r
.3819 .66164 .38739 .66663 .39651 .66308 .39105 .65799 Mtetra
.698 .752 .894 r
.39105 .65799 .39651 .66308 .40567 .65945 .40023 .65422 Mtetra
.702 .749 .888 r
.40023 .65422 .40567 .65945 .41485 .65571 .40944 .65032 Mtetra
.703 .744 .884 r
.40944 .65032 .41485 .65571 .42406 .65195 .41867 .64637 Mtetra
.702 .738 .879 r
.41867 .64637 .42406 .65195 .43329 .64821 .42793 .6424 Mtetra
.695 .73 .877 r
.42793 .6424 .43329 .64821 .44255 .64464 .43721 .63861 Mtetra
.684 .72 .877 r
.43721 .63861 .44255 .64464 .45182 .64139 .44651 .63514 Mtetra
.664 .708 .88 r
.44651 .63514 .45182 .64139 .46112 .63865 .45582 .63224 Mtetra
.634 .694 .888 r
.45582 .63224 .46112 .63865 .47043 .6366 .46516 .63013 Mtetra
.594 .677 .899 r
.46516 .63013 .47043 .6366 .47977 .63537 .47451 .62898 Mtetra
.536 .657 .913 r
.47451 .62898 .47977 .63537 .48914 .63509 .48389 .62895 Mtetra
.468 .636 .928 r
.48389 .62895 .48914 .63509 .49855 .63562 .49331 .6299 Mtetra
.382 .612 .941 r
.49331 .6299 .49855 .63562 .50801 .63689 .50277 .63176 Mtetra
.315 .604 .949 r
.50277 .63176 .50801 .63689 .51752 .63843 .5123 .63395 Mtetra
.279 .615 .957 r
.5123 .63395 .51752 .63843 .52708 .63987 .52188 .63602 Mtetra
.324 .67 .976 r
.52188 .63602 .52708 .63987 .53671 .64065 .53152 .63722 Mtetra
.446 .751 .994 r
.53152 .63722 .53671 .64065 .54637 .64032 .54121 .63696 Mtetra
.584 .81 .985 r
.54121 .63696 .54637 .64032 .55608 .63869 .55094 .63497 Mtetra
.693 .823 .945 r
.55094 .63497 .55608 .63869 .56581 .63566 .56069 .63111 Mtetra
.735 .796 .901 r
.56069 .63111 .56581 .63566 .57556 .63176 .57045 .62609 Mtetra
.742 .758 .866 r
.57045 .62609 .57556 .63176 .58532 .62742 .58022 .6205 Mtetra
.718 .715 .846 r
.58022 .6205 .58532 .62742 .59513 .62341 .59002 .61546 Mtetra
.681 .676 .839 r
.59002 .61546 .59513 .62341 .60498 .62019 .59988 .61162 Mtetra
.639 .645 .84 r
.59988 .61162 .60498 .62019 .61488 .61789 .60979 .6092 Mtetra
.6 .625 .848 r
.60979 .6092 .61488 .61789 .62485 .61641 .61978 .60804 Mtetra
.593 .631 .858 r
.61978 .60804 .62485 .61641 .63486 .61495 .62982 .60703 Mtetra
.61 .65 .865 r
.62982 .60703 .63486 .61495 .6449 .61307 .63989 .60549 Mtetra
.654 .678 .861 r
.63989 .60549 .6449 .61307 .65495 .6102 .64995 .6026 Mtetra
.692 .693 .846 r
.64995 .6026 .65495 .6102 .66499 .60634 .66 .59836 Mtetra
.702 .688 .833 r
.66 .59836 .66499 .60634 .67504 .60205 .67005 .59358 Mtetra
.696 .674 .825 r
.67005 .59358 .67504 .60205 .68513 .59779 .68014 .58894 Mtetra
.663 .653 .83 r
.68014 .58894 .68513 .59779 .69528 .59434 .69031 .58557 Mtetra
.623 .637 .844 r
.69031 .58557 .69528 .59434 .70551 .59181 .70059 .58363 Mtetra
.58 .633 .868 r
.70059 .58363 .70551 .59181 .71584 .59009 .71098 .58291 Mtetra
.548 .647 .899 r
.71098 .58291 .71584 .59009 .72622 .58871 .72146 .58275 Mtetra
.558 .695 .932 r
.72146 .58275 .72622 .58871 .73663 .58689 .73196 .58202 Mtetra
.599 .758 .955 r
.73196 .58202 .73663 .58689 .74702 .58417 .74243 .58012 Mtetra
.68 .823 .952 r
.74243 .58012 .74702 .58417 .75736 .58004 .75282 .57632 Mtetra
.747 .855 .929 r
.75282 .57632 .75736 .58004 .76763 .57458 .76312 .57074 Mtetra
.793 .858 .898 r
.76312 .57074 .76763 .57458 .77784 .56796 .77334 .56367 Mtetra
.81 .841 .873 r
.77334 .56367 .77784 .56796 .78801 .56065 .7835 .55568 Mtetra
.806 .816 .859 r
.7835 .55568 .78801 .56065 .79819 .55322 .79365 .54754 Mtetra
.791 .79 .851 r
.79365 .54754 .79819 .55322 .80839 .54606 .80384 .53973 Mtetra
.764 .764 .852 r
.80384 .53973 .80839 .54606 .81868 .53964 .81412 .53284 Mtetra
.737 .741 .855 r
.81412 .53284 .81868 .53964 .82906 .53405 .8245 .52694 Mtetra
.705 .722 .863 r
.8245 .52694 .82906 .53405 .83955 .52942 .83501 .5222 Mtetra
.677 .708 .871 r
.83501 .5222 .83955 .52942 .85016 .52564 .84564 .51844 Mtetra
.651 .699 .881 r
.84564 .51844 .85016 .52564 .86087 .52257 .85639 .51549 Mtetra
.631 .694 .89 r
.85639 .51549 .86087 .52257 .87168 .52004 .86725 .51314 Mtetra
.618 .695 .899 r
.86725 .51314 .87168 .52004 .88257 .51782 .87818 .51112 Mtetra
.609 .698 .907 r
.87818 .51112 .88257 .51782 .89353 .5158 .88919 .50929 Mtetra
.608 .705 .913 r
.88919 .50929 .89353 .5158 .90454 .5138 .90024 .50745 Mtetra
.608 .712 .918 r
.90024 .50745 .90454 .5138 .91559 .51177 .91134 .50555 Mtetra
.613 .719 .921 r
.91134 .50555 .91559 .51177 .92668 .50964 .92248 .50352 Mtetra
.616 .725 .924 r
.92248 .50352 .92668 .50964 .93782 .50742 .93365 .50137 Mtetra
.619 .73 .926 r
.93365 .50137 .93782 .50742 .94899 .50512 .94486 .49913 Mtetra
.621 .734 .927 r
.94486 .49913 .94899 .50512 .9602 .50275 .9561 .4968 Mtetra
.691 .759 .904 r
.35813 .66383 .36369 .66869 .37278 .66521 .36724 .66031 Mtetra
.694 .759 .902 r
.36724 .66031 .37278 .66521 .3819 .66164 .37638 .65669 Mtetra
.697 .758 .899 r
.37638 .65669 .3819 .66164 .39105 .65799 .38555 .65297 Mtetra
.701 .757 .895 r
.38555 .65297 .39105 .65799 .40023 .65422 .39476 .64911 Mtetra
.707 .755 .89 r
.39476 .64911 .40023 .65422 .40944 .65032 .40399 .64507 Mtetra
.708 .752 .886 r
.40399 .64507 .40944 .65032 .41867 .64637 .41325 .64095 Mtetra
.709 .746 .881 r
.41325 .64095 .41867 .64637 .42793 .6424 .42254 .63677 Mtetra
.703 .738 .879 r
.42254 .63677 .42793 .6424 .43721 .63861 .43184 .63275 Mtetra
.692 .729 .879 r
.43184 .63275 .43721 .63861 .44651 .63514 .44116 .62904 Mtetra
.671 .716 .882 r
.44116 .62904 .44651 .63514 .45582 .63224 .4505 .62593 Mtetra
.639 .699 .89 r
.4505 .62593 .45582 .63224 .46516 .63013 .45985 .62369 Mtetra
.594 .679 .9 r
.45985 .62369 .46516 .63013 .47451 .62898 .46922 .62252 Mtetra
.527 .652 .914 r
.46922 .62252 .47451 .62898 .48389 .62895 .47861 .62264 Mtetra
.448 .622 .926 r
.47861 .62264 .48389 .62895 .49331 .6299 .48803 .62393 Mtetra
.347 .585 .932 r
.48803 .62393 .49331 .6299 .50277 .63176 .49751 .6263 Mtetra
.275 .568 .936 r
.49751 .6263 .50277 .63176 .5123 .63395 .50704 .62909 Mtetra
.242 .577 .943 r
.50704 .62909 .5123 .63395 .52188 .63602 .51664 .63175 Mtetra
.315 .646 .968 r
.51664 .63175 .52188 .63602 .53152 .63722 .5263 .63332 Mtetra
.471 .741 .987 r
.5263 .63332 .53152 .63722 .54121 .63696 .53601 .63304 Mtetra
.628 .799 .964 r
.53601 .63304 .54121 .63696 .55094 .63497 .54576 .63053 Mtetra
.733 .801 .906 r
.54576 .63053 .55094 .63497 .56069 .63111 .55553 .6256 Mtetra
.763 .767 .856 r
.55553 .6256 .56069 .63111 .57045 .62609 .5653 .61916 Mtetra
.762 .727 .82 r
.5653 .61916 .57045 .62609 .58022 .6205 .57507 .612 Mtetra
.731 .682 .804 r
.57507 .612 .58022 .6205 .59002 .61546 .58487 .60568 Mtetra
.686 .641 .799 r
.58487 .60568 .59002 .61546 .59988 .61162 .59471 .60111 Mtetra
.636 .605 .802 r
.59471 .60111 .59988 .61162 .60979 .6092 .60464 .59863 Mtetra
.585 .579 .813 r
.60464 .59863 .60979 .6092 .61978 .60804 .61465 .59804 Mtetra
.574 .585 .827 r
.61465 .59804 .61978 .60804 .62982 .60703 .62472 .59773 Mtetra
.594 .611 .838 r
.62472 .59773 .62982 .60703 .63989 .60549 .63481 .59673 Mtetra
.651 .649 .835 r
.63481 .59673 .63989 .60549 .64995 .6026 .64489 .59382 Mtetra
.698 .669 .818 r
.64489 .59382 .64995 .6026 .66 .59836 .65493 .58899 Mtetra
.708 .661 .802 r
.65493 .58899 .66 .59836 .67005 .59358 .66497 .58346 Mtetra
.697 .644 .793 r
.66497 .58346 .67005 .59358 .68014 .58894 .67504 .5782 Mtetra
.654 .614 .797 r
.67504 .5782 .68014 .58894 .69031 .58557 .68522 .57484 Mtetra
.602 .589 .81 r
.68522 .57484 .69031 .58557 .70059 .58363 .69555 .57359 Mtetra
.546 .573 .833 r
.69555 .57359 .70059 .58363 .71098 .58291 .70602 .57411 Mtetra
.501 .578 .865 r
.70602 .57411 .71098 .58291 .72146 .58275 .71659 .5755 Mtetra
.508 .627 .904 r
.71659 .5755 .72146 .58275 .73196 .58202 .72719 .57618 Mtetra
.559 .703 .936 r
.72719 .57618 .73196 .58202 .74243 .58012 .73776 .57534 Mtetra
.663 .787 .94 r
.73776 .57534 .74243 .58012 .75282 .57632 .74822 .57203 Mtetra
.747 .831 .916 r
.74822 .57203 .75282 .57632 .76312 .57074 .75855 .56643 Mtetra
.798 .839 .882 r
.75855 .56643 .76312 .57074 .77334 .56367 .76877 .55893 Mtetra
.818 .826 .856 r
.76877 .55893 .77334 .56367 .7835 .55568 .77892 .55031 Mtetra
.813 .804 .843 r
.77892 .55031 .7835 .55568 .79365 .54754 .78906 .54152 Mtetra
.798 .781 .838 r
.78906 .54152 .79365 .54754 .80384 .53973 .79924 .53313 Mtetra
.769 .758 .843 r
.79924 .53313 .80384 .53973 .81412 .53284 .80951 .52586 Mtetra
.74 .739 .85 r
.80951 .52586 .81412 .53284 .8245 .52694 .8199 .51976 Mtetra
.705 .721 .862 r
.8199 .51976 .8245 .52694 .83501 .5222 .83044 .51499 Mtetra
.673 .708 .874 r
.83044 .51499 .83501 .5222 .84564 .51844 .84111 .51133 Mtetra
.645 .7 .886 r
.84111 .51133 .84564 .51844 .85639 .51549 .8519 .50856 Mtetra
.622 .696 .898 r
.8519 .50856 .85639 .51549 .86725 .51314 .8628 .50642 Mtetra
.608 .698 .907 r
.8628 .50642 .86725 .51314 .87818 .51112 .87379 .5046 Mtetra
.6 .701 .915 r
.87379 .5046 .87818 .51112 .88919 .50929 .88484 .50295 Mtetra
.6 .709 .92 r
.88484 .50295 .88919 .50929 .90024 .50745 .89594 .50124 Mtetra
.602 .715 .924 r
.89594 .50124 .90024 .50745 .91134 .50555 .90708 .49945 Mtetra
.608 .723 .926 r
.90708 .49945 .91134 .50555 .92248 .50352 .91825 .49747 Mtetra
.613 .728 .928 r
.91825 .49747 .92248 .50352 .93365 .50137 .92946 .49536 Mtetra
.617 .732 .928 r
.92946 .49536 .93365 .50137 .94486 .49913 .9407 .49313 Mtetra
.62 .735 .929 r
.9407 .49313 .94486 .49913 .9561 .4968 .95198 .4908 Mtetra
.69 .759 .904 r
.35253 .65894 .35813 .66383 .36724 .66031 .36166 .65542 Mtetra
.694 .76 .903 r
.36166 .65542 .36724 .66031 .37638 .65669 .37082 .6518 Mtetra
.698 .762 .901 r
.37082 .6518 .37638 .65669 .38555 .65297 .38002 .64805 Mtetra
.703 .762 .898 r
.38002 .64805 .38555 .65297 .39476 .64911 .38924 .64414 Mtetra
.71 .762 .893 r
.38924 .64414 .39476 .64911 .40399 .64507 .3985 .64001 Mtetra
.713 .76 .889 r
.3985 .64001 .40399 .64507 .41325 .64095 .40779 .63575 Mtetra
.716 .756 .885 r
.40779 .63575 .41325 .64095 .42254 .63677 .4171 .63138 Mtetra
.711 .75 .882 r
.4171 .63138 .42254 .63677 .43184 .63275 .42643 .62713 Mtetra
.701 .74 .882 r
.42643 .62713 .43184 .63275 .44116 .62904 .43578 .62316 Mtetra
.68 .727 .885 r
.43578 .62316 .44116 .62904 .4505 .62593 .44514 .6198 Mtetra
.646 .709 .893 r
.44514 .6198 .4505 .62593 .45985 .62369 .45451 .61733 Mtetra
.598 .685 .903 r
.45451 .61733 .45985 .62369 .46922 .62252 .4639 .61603 Mtetra
.524 .651 .915 r
.4639 .61603 .46922 .62252 .47861 .62264 .4733 .61618 Mtetra
.436 .612 .923 r
.4733 .61618 .47861 .62264 .48803 .62393 .48273 .61768 Mtetra
.322 .562 .923 r
.48273 .61768 .48803 .62393 .49751 .6263 .49221 .62047 Mtetra
.246 .537 .922 r
.49221 .62047 .49751 .6263 .50704 .62909 .50175 .62378 Mtetra
.218 .543 .928 r
.50175 .62378 .50704 .62909 .51664 .63175 .51136 .62698 Mtetra
.315 .624 .959 r
.51136 .62698 .51664 .63175 .5263 .63332 .52104 .62887 Mtetra
.499 .729 .975 r
.52104 .62887 .5263 .63332 .53601 .63304 .53077 .62851 Mtetra
.666 .783 .936 r
.53077 .62851 .53601 .63304 .54576 .63053 .54054 .62535 Mtetra
.762 .778 .866 r
.54054 .62535 .54576 .63053 .55553 .6256 .55032 .61909 Mtetra
.784 .743 .815 r
.55032 .61909 .55553 .6256 .5653 .61916 .5601 .61093 Mtetra
.777 .703 .781 r
.5601 .61093 .5653 .61916 .57507 .612 .56987 .60186 Mtetra
.74 .658 .769 r
.56987 .60186 .57507 .612 .58487 .60568 .57966 .59403 Mtetra
.689 .614 .767 r
.57966 .59403 .58487 .60568 .59471 .60111 .5895 .58866 Mtetra
.628 .573 .774 r
.5895 .58866 .59471 .60111 .60464 .59863 .59943 .58628 Mtetra
.562 .539 .787 r
.59943 .58628 .60464 .59863 .61465 .59804 .60946 .58662 Mtetra
.545 .545 .805 r
.60946 .58662 .61465 .59804 .62472 .59773 .61956 .58738 Mtetra
.571 .578 .822 r
.61956 .58738 .62472 .59773 .63481 .59673 .62969 .58719 Mtetra
.649 .632 .82 r
.62969 .58719 .63481 .59673 .64489 .59382 .63978 .58426 Mtetra
.709 .659 .798 r
.63978 .58426 .64489 .59382 .65493 .58899 .64981 .57857 Mtetra
.72 .649 .778 r
.64981 .57857 .65493 .58899 .66497 .58346 .65981 .57191 Mtetra
.704 .626 .767 r
.65981 .57191 .66497 .58346 .67504 .5782 .66985 .56567 Mtetra
.65 .586 .77 r
.66985 .56567 .67504 .5782 .68522 .57484 .68003 .56215 Mtetra
.583 .549 .782 r
.68003 .56215 .68522 .57484 .69555 .57359 .6904 .56166 Mtetra
.51 .52 .802 r
.6904 .56166 .69555 .57359 .70602 .57411 .70095 .56366 Mtetra
.446 .511 .832 r
.70095 .56366 .70602 .57411 .71659 .5755 .71163 .56694 Mtetra
.45 .558 .874 r
.71163 .56694 .71659 .5755 .72719 .57618 .72234 .56932 Mtetra
.51 .643 .916 r
.72234 .56932 .72719 .57618 .73776 .57534 .73301 .56978 Mtetra
.639 .749 .928 r
.73301 .56978 .73776 .57534 .74822 .57203 .74354 .5671 Mtetra
.742 .806 .903 r
.74354 .5671 .74822 .57203 .75855 .56643 .75391 .56155 Mtetra
.801 .819 .866 r
.75391 .56155 .75855 .56643 .76877 .55893 .76414 .55368 Mtetra
.822 .809 .838 r
.76414 .55368 .76877 .55893 .77892 .55031 .77428 .54446 Mtetra
.817 .791 .827 r
.77428 .54446 .77892 .55031 .78906 .54152 .78441 .5351 Mtetra
.801 .771 .826 r
.78441 .5351 .78906 .54152 .79924 .53313 .79458 .52625 Mtetra
.771 .751 .835 r
.79458 .52625 .79924 .53313 .80951 .52586 .80487 .51872 Mtetra
.74 .735 .847 r
.80487 .51872 .80951 .52586 .8199 .51976 .81528 .51255 Mtetra
.702 .72 .864 r
.81528 .51255 .8199 .51976 .83044 .51499 .82585 .50787 Mtetra
.667 .71 .88 r
.82585 .50787 .83044 .51499 .84111 .51133 .83657 .5044 Mtetra
.636 .703 .895 r
.83657 .5044 .84111 .51133 .8519 .50856 .84741 .50185 Mtetra
.611 .7 .907 r
.84741 .50185 .8519 .50856 .8628 .50642 .85836 .49994 Mtetra
.597 .703 .917 r
.85836 .49994 .8628 .50642 .87379 .5046 .8694 .49832 Mtetra
.59 .707 .925 r
.8694 .49832 .87379 .5046 .88484 .50295 .88049 .49683 Mtetra
.592 .715 .929 r
.88049 .49683 .88484 .50295 .89594 .50124 .89163 .49522 Mtetra
.596 .721 .932 r
.89163 .49522 .89594 .50124 .90708 .49945 .90281 .49348 Mtetra
.605 .728 .932 r
.90281 .49348 .90708 .49945 .91825 .49747 .91402 .49152 Mtetra
.611 .733 .932 r
.91402 .49152 .91825 .49747 .92946 .49536 .92525 .48939 Mtetra
.616 .735 .931 r
.92525 .48939 .92946 .49536 .9407 .49313 .93653 .48713 Mtetra
.62 .737 .93 r
.93653 .48713 .9407 .49313 .95198 .4908 .94784 .48476 Mtetra
.688 .758 .905 r
.34689 .65403 .35253 .65894 .36166 .65542 .35604 .65055 Mtetra
.692 .761 .905 r
.35604 .65055 .36166 .65542 .37082 .6518 .36522 .64696 Mtetra
.697 .764 .904 r
.36522 .64696 .37082 .6518 .38002 .64805 .37444 .64323 Mtetra
.703 .767 .902 r
.37444 .64323 .38002 .64805 .38924 .64414 .38368 .63931 Mtetra
.711 .769 .898 r
.38368 .63931 .38924 .64414 .3985 .64001 .39297 .63514 Mtetra
.716 .769 .894 r
.39297 .63514 .3985 .64001 .40779 .63575 .40228 .6308 Mtetra
.721 .767 .889 r
.40228 .6308 .40779 .63575 .4171 .63138 .41162 .62629 Mtetra
.718 .762 .887 r
.41162 .62629 .4171 .63138 .42643 .62713 .42098 .62183 Mtetra
.71 .754 .887 r
.42098 .62183 .42643 .62713 .43578 .62316 .43036 .6176 Mtetra
.69 .741 .89 r
.43036 .6176 .43578 .62316 .44514 .6198 .43974 .61394 Mtetra
.657 .723 .897 r
.43974 .61394 .44514 .6198 .45451 .61733 .44914 .61118 Mtetra
.606 .696 .907 r
.44914 .61118 .45451 .61733 .4639 .61603 .45854 .60964 Mtetra
.528 .657 .918 r
.45854 .60964 .4639 .61603 .4733 .61618 .46796 .60966 Mtetra
.434 .61 .922 r
.46796 .60966 .4733 .61618 .48273 .61768 .4774 .61119 Mtetra
.31 .547 .916 r
.4774 .61119 .48273 .61768 .49221 .62047 .48689 .61423 Mtetra
.234 .514 .91 r
.48689 .61423 .49221 .62047 .50175 .62378 .49644 .61793 Mtetra
.209 .516 .914 r
.49644 .61793 .50175 .62378 .51136 .62698 .50605 .62159 Mtetra
.326 .603 .948 r
.50605 .62159 .51136 .62698 .52104 .62887 .51574 .62376 Mtetra
.525 .711 .957 r
.51574 .62376 .52104 .62887 .53077 .62851 .5255 .62333 Mtetra
.693 .765 .907 r
.5255 .62333 .53077 .62851 .54054 .62535 .53529 .61947 Mtetra
.783 .76 .833 r
.53529 .61947 .54054 .62535 .55032 .61909 .54509 .61181 Mtetra
.801 .728 .784 r
.54509 .61181 .55032 .61909 .5601 .61093 .55487 .60178 Mtetra
.792 .691 .754 r
.55487 .60178 .5601 .61093 .56987 .60186 .56464 .59064 Mtetra
.751 .648 .746 r
.56464 .59064 .56987 .60186 .57966 .59403 .57442 .5812 Mtetra
.694 .602 .75 r
.57442 .5812 .57966 .59403 .5895 .58866 .58425 .57509 Mtetra
.616 .554 .761 r
.58425 .57509 .5895 .58866 .59943 .58628 .59419 .57311 Mtetra
.523 .506 .78 r
.59419 .57311 .59943 .58628 .60946 .58662 .60425 .5749 Mtetra
.493 .512 .805 r
.60425 .5749 .60946 .58662 .61956 .58738 .61439 .57728 Mtetra
.527 .561 .833 r
.61439 .57728 .61956 .58738 .62969 .58719 .62457 .57829 Mtetra
.651 .647 .834 r
.62457 .57829 .62969 .58719 .63978 .58426 .63467 .57533 Mtetra
.738 .682 .797 r
.63467 .57533 .63978 .58426 .64981 .57857 .64467 .56839 Mtetra
.748 .665 .769 r
.64467 .56839 .64981 .57857 .65981 .57191 .65463 .56007 Mtetra
.725 .632 .755 r
.65463 .56007 .65981 .57191 .66985 .56567 .66462 .55231 Mtetra
.654 .579 .758 r
.66462 .55231 .66985 .56567 .68003 .56215 .67478 .54834 Mtetra
.567 .526 .769 r
.67478 .54834 .68003 .56215 .6904 .56166 .68518 .54854 Mtetra
.47 .479 .785 r
.68518 .54854 .6904 .56166 .70095 .56366 .6958 .55211 Mtetra
.38 .452 .809 r
.6958 .55211 .70095 .56366 .71163 .56694 .7066 .55744 Mtetra
.379 .495 .851 r
.7066 .55744 .71163 .56694 .72234 .56932 .71742 .56168 Mtetra
.454 .59 .898 r
.71742 .56168 .72234 .56932 .73301 .56978 .72819 .56352 Mtetra
.615 .714 .916 r
.72819 .56352 .73301 .56978 .74354 .5671 .73878 .5615 Mtetra
.736 .78 .889 r
.73878 .5615 .74354 .5671 .75391 .56155 .74919 .55599 Mtetra
.799 .797 .849 r
.74919 .55599 .75391 .56155 .76414 .55368 .75943 .5478 Mtetra
.822 .79 .822 r
.75943 .5478 .76414 .55368 .77428 .54446 .76957 .53806 Mtetra
.816 .775 .814 r
.76957 .53806 .77428 .54446 .78441 .5351 .77971 .52827 Mtetra
.801 .761 .816 r
.77971 .52827 .78441 .5351 .79458 .52625 .78989 .51912 Mtetra
.77 .745 .831 r
.78989 .51912 .79458 .52625 .80487 .51872 .8002 .51151 Mtetra
.737 .733 .848 r
.8002 .51151 .80487 .51872 .81528 .51255 .81065 .50543 Mtetra
.696 .722 .869 r
.81065 .50543 .81528 .51255 .82585 .50787 .82126 .50096 Mtetra
.658 .714 .889 r
.82126 .50096 .82585 .50787 .83657 .5044 .83203 .49775 Mtetra
.625 .709 .906 r
.83203 .49775 .83657 .5044 .84741 .50185 .84293 .49546 Mtetra
.598 .707 .92 r
.84293 .49546 .84741 .50185 .85836 .49994 .85393 .49378 Mtetra
.585 .711 .929 r
.85393 .49378 .85836 .49994 .8694 .49832 .86501 .49233 Mtetra
.58 .715 .936 r
.86501 .49233 .8694 .49832 .88049 .49683 .87615 .49095 Mtetra
.585 .723 .938 r
.87615 .49095 .88049 .49683 .89163 .49522 .88732 .4894 Mtetra
.592 .729 .939 r
.88732 .4894 .89163 .49522 .90281 .49348 .89853 .48766 Mtetra
.603 .735 .937 r
.89853 .48766 .90281 .49348 .91402 .49152 .90977 .48566 Mtetra
.612 .738 .935 r
.90977 .48566 .91402 .49152 .92525 .48939 .92103 .48347 Mtetra
.618 .739 .933 r
.92103 .48347 .92525 .48939 .93653 .48713 .93233 .48113 Mtetra
.623 .739 .93 r
.93233 .48113 .93653 .48713 .94784 .48476 .94366 .47868 Mtetra
.685 .758 .907 r
.34122 .64908 .34689 .65403 .35604 .65055 .35039 .64568 Mtetra
.688 .762 .908 r
.35039 .64568 .35604 .65055 .36522 .64696 .35959 .64217 Mtetra
.694 .767 .908 r
.35959 .64217 .36522 .64696 .37444 .64323 .36882 .63851 Mtetra
.701 .772 .907 r
.36882 .63851 .37444 .64323 .38368 .63931 .37808 .63465 Mtetra
.711 .776 .903 r
.37808 .63465 .38368 .63931 .39297 .63514 .38739 .6305 Mtetra
.718 .779 .9 r
.38739 .6305 .39297 .63514 .40228 .6308 .39672 .62613 Mtetra
.725 .78 .896 r
.39672 .62613 .40228 .6308 .41162 .62629 .40609 .62153 Mtetra
.724 .777 .895 r
.40609 .62153 .41162 .62629 .42098 .62183 .41548 .61692 Mtetra
.719 .771 .894 r
.41548 .61692 .42098 .62183 .43036 .6176 .42488 .61245 Mtetra
.701 .76 .897 r
.42488 .61245 .43036 .6176 .43974 .61394 .4343 .60848 Mtetra
.671 .742 .904 r
.4343 .60848 .43974 .61394 .44914 .61118 .44372 .60534 Mtetra
.62 .714 .913 r
.44372 .60534 .44914 .61118 .45854 .60964 .45315 .60343 Mtetra
.541 .671 .922 r
.45315 .60343 .45854 .60964 .46796 .60966 .46259 .60314 Mtetra
.444 .616 .923 r
.46259 .60314 .46796 .60966 .4774 .61119 .47205 .6045 Mtetra
.317 .544 .912 r
.47205 .6045 .4774 .61119 .48689 .61423 .48154 .60757 Mtetra
.241 .502 .901 r
.48154 .60757 .48689 .61423 .49644 .61793 .49109 .61146 Mtetra
.217 .497 .902 r
.49109 .61146 .49644 .61793 .50605 .62159 .50071 .61547 Mtetra
.343 .583 .932 r
.50071 .61547 .50605 .62159 .51574 .62376 .51042 .6179 Mtetra
.542 .689 .935 r
.51042 .6179 .51574 .62376 .5255 .62333 .52019 .61743 Mtetra
.71 .746 .88 r
.52019 .61743 .5255 .62333 .53529 .61947 .53 .61294 Mtetra
.797 .745 .805 r
.53 .61294 .53529 .61947 .54509 .61181 .53982 .6039 Mtetra
.814 .718 .76 r
.53982 .6039 .54509 .61181 .55487 .60178 .54962 .59196 Mtetra
.805 .686 .733 r
.54962 .59196 .55487 .60178 .56464 .59064 .55939 .57867 Mtetra
.763 .644 .731 r
.55939 .57867 .56464 .59064 .57442 .5812 .56916 .56764 Mtetra
.697 .597 .74 r
.56916 .56764 .57442 .5812 .58425 .57509 .57899 .56095 Mtetra
.597 .537 .758 r
.57899 .56095 .58425 .57509 .59419 .57311 .58893 .55982 Mtetra
.453 .464 .781 r
.58893 .55982 .59419 .57311 .60425 .5749 .59904 .56377 Mtetra
.387 .462 .816 r
.59904 .56377 .60425 .5749 .61439 .57728 .60924 .56846 Mtetra
.431 .54 .867 r
.60924 .56846 .61439 .57728 .62457 .57829 .61947 .57117 Mtetra
.656 .696 .876 r
.61947 .57117 .62457 .57829 .63467 .57533 .62959 .56819 Mtetra
.786 .737 .807 r
.62959 .56819 .63467 .57533 .64467 .56839 .63956 .5595 Mtetra
.793 .703 .765 r
.63956 .5595 .64467 .56839 .65463 .56007 .64945 .54881 Mtetra
.759 .655 .747 r
.64945 .54881 .65463 .56007 .66462 .55231 .65937 .53883 Mtetra
.669 .586 .753 r
.65937 .53883 .66462 .55231 .67478 .54834 .6695 .53395 Mtetra
.555 .513 .763 r
.6695 .53395 .67478 .54834 .68518 .54854 .67991 .53468 Mtetra
.426 .443 .774 r
.67991 .53468 .68518 .54854 .6958 .55211 .6906 .53981 Mtetra
.304 .392 .788 r
.6906 .53981 .6958 .55211 .7066 .55744 .70151 .54726 Mtetra
.301 .433 .829 r
.70151 .54726 .7066 .55744 .71742 .56168 .71244 .55338 Mtetra
.396 .539 .882 r
.71244 .55338 .71742 .56168 .72819 .56352 .7233 .55659 Mtetra
.594 .684 .904 r
.7233 .55659 .72819 .56352 .73878 .5615 .73395 .55518 Mtetra
.73 .756 .873 r
.73395 .55518 .73878 .5615 .74919 .55599 .74439 .54967 Mtetra
.795 .773 .833 r
.74439 .54967 .74919 .55599 .75943 .5478 .75465 .54117 Mtetra
.818 .769 .807 r
.75465 .54117 .75943 .5478 .76957 .53806 .76479 .53103 Mtetra
.812 .758 .803 r
.76479 .53103 .76957 .53806 .77971 .52827 .77494 .52099 Mtetra
.796 .749 .81 r
.77494 .52099 .77971 .52827 .78989 .51912 .78515 .51177 Mtetra
.765 .739 .829 r
.78515 .51177 .78989 .51912 .8002 .51151 .7955 .50429 Mtetra
.73 .732 .852 r
.7955 .50429 .8002 .51151 .81065 .50543 .806 .49849 Mtetra
.687 .725 .879 r
.806 .49849 .81065 .50543 .82126 .50096 .81668 .49436 Mtetra
.645 .72 .903 r
.81668 .49436 .82126 .50096 .83203 .49775 .8275 .4915 Mtetra
.61 .718 .922 r
.8275 .4915 .83203 .49775 .84293 .49546 .83846 .4895 Mtetra
.583 .718 .936 r
.83846 .4895 .84293 .49546 .85393 .49378 .84951 .48803 Mtetra
.573 .722 .944 r
.84951 .48803 .85393 .49378 .86501 .49233 .86063 .4867 Mtetra
.57 .727 .948 r
.86063 .4867 .86501 .49233 .87615 .49095 .87181 .48536 Mtetra
.58 .734 .948 r
.87181 .48536 .87615 .49095 .88732 .4894 .88301 .48379 Mtetra
.591 .739 .946 r
.88301 .48379 .88732 .4894 .89853 .48766 .89425 .482 Mtetra
.604 .743 .943 r
.89425 .482 .89853 .48766 .90977 .48566 .9055 .47991 Mtetra
.614 .745 .939 r
.9055 .47991 .90977 .48566 .92103 .48347 .91679 .4776 Mtetra
.621 .744 .935 r
.91679 .4776 .92103 .48347 .93233 .48113 .9281 .47514 Mtetra
.626 .742 .931 r
.9281 .47514 .93233 .48113 .94366 .47868 .93945 .47256 Mtetra
.68 .757 .909 r
.33552 .6441 .34122 .64908 .35039 .64568 .3447 .6408 Mtetra
.683 .762 .911 r
.3447 .6408 .35039 .64568 .35959 .64217 .35391 .63741 Mtetra
.689 .768 .912 r
.35391 .63741 .35959 .64217 .36882 .63851 .36315 .63385 Mtetra
.697 .775 .911 r
.36315 .63385 .36882 .63851 .37808 .63465 .37244 .63008 Mtetra
.708 .781 .909 r
.37244 .63008 .37808 .63465 .38739 .6305 .38176 .62601 Mtetra
.716 .786 .907 r
.38176 .62601 .38739 .6305 .39672 .62613 .39112 .62169 Mtetra
.726 .79 .903 r
.39112 .62169 .39672 .62613 .40609 .62153 .40051 .61708 Mtetra
.728 .791 .902 r
.40051 .61708 .40609 .62153 .41548 .61692 .40993 .6124 Mtetra
.726 .788 .901 r
.40993 .6124 .41548 .61692 .42488 .61245 .41936 .60774 Mtetra
.712 .78 .905 r
.41936 .60774 .42488 .61245 .4343 .60848 .42881 .60349 Mtetra
.686 .764 .911 r
.42881 .60349 .4343 .60848 .44372 .60534 .43827 .59994 Mtetra
.638 .737 .92 r
.43827 .59994 .44372 .60534 .45315 .60343 .44772 .59756 Mtetra
.562 .693 .929 r
.44772 .59756 .45315 .60343 .46259 .60314 .45718 .59679 Mtetra
.465 .634 .928 r
.45718 .59679 .46259 .60314 .47205 .6045 .46666 .59773 Mtetra
.338 .554 .914 r
.46666 .59773 .47205 .6045 .48154 .60757 .47617 .60055 Mtetra
.265 .504 .898 r
.47617 .60055 .48154 .60757 .49109 .61146 .48572 .60438 Mtetra
.241 .488 .892 r
.48572 .60438 .49109 .61146 .50071 .61547 .49535 .60855 Mtetra
.363 .564 .913 r
.49535 .60855 .50071 .61547 .51042 .6179 .50506 .61118 Mtetra
.551 .663 .911 r
.50506 .61118 .51042 .6179 .52019 .61743 .51485 .61078 Mtetra
.716 .725 .857 r
.51485 .61078 .52019 .61743 .53 .61294 .52468 .60587 Mtetra
.805 .734 .786 r
.52468 .60587 .53 .61294 .53982 .6039 .53453 .59573 Mtetra
.826 .717 .744 r
.53453 .59573 .53982 .6039 .54962 .59196 .54434 .58216 Mtetra
.821 .691 .721 r
.54434 .58216 .54962 .59196 .55939 .57867 .55412 .56694 Mtetra
.779 .654 .725 r
.55412 .56694 .55939 .57867 .56916 .56764 .56389 .55451 Mtetra
.705 .605 .743 r
.56389 .55451 .56916 .56764 .57899 .56095 .57372 .54747 Mtetra
.566 .527 .771 r
.57372 .54747 .57899 .56095 .58893 .55982 .58369 .54763 Mtetra
.31 .395 .789 r
.58369 .54763 .58893 .55982 .59904 .56377 .59385 .55443 Mtetra
.129 .345 .808 r
.59385 .55443 .59904 .56377 .60924 .56846 .60412 .56214 Mtetra
.141 .456 .885 r
.60412 .56214 .60924 .56846 .61947 .57117 .61442 .5671 Mtetra
.645 .808 .962 r
.61442 .5671 .61947 .57117 .62959 .56819 .62458 .5641 Mtetra
.86 .833 .819 r
.62458 .5641 .62959 .56819 .63956 .5595 .63451 .55312 Mtetra
.857 .766 .761 r
.63451 .55312 .63956 .5595 .64945 .54881 .64433 .53935 Mtetra
.81 .699 .743 r
.64433 .53935 .64945 .54881 .65937 .53883 .65415 .52646 Mtetra
.698 .614 .759 r
.65415 .52646 .65937 .53883 .6695 .53395 .66423 .52022 Mtetra
.544 .515 .773 r
.66423 .52022 .6695 .53395 .67991 .53468 .67466 .52125 Mtetra
.367 .413 .777 r
.67466 .52125 .67991 .53468 .6906 .53981 .6854 .52774 Mtetra
.2 .331 .773 r
.6854 .52774 .6906 .53981 .70151 .54726 .6964 .5371 Mtetra
.207 .376 .812 r
.6964 .5371 .70151 .54726 .71244 .55338 .70742 .54483 Mtetra
.341 .501 .872 r
.70742 .54483 .71244 .55338 .7233 .55659 .71835 .54911 Mtetra
.581 .662 .893 r
.71835 .54911 .7233 .55659 .73395 .55518 .72905 .54808 Mtetra
.727 .732 .855 r
.72905 .54808 .73395 .55518 .74439 .54967 .73951 .54245 Mtetra
.788 .748 .816 r
.73951 .54245 .74439 .54967 .75465 .54117 .74978 .53371 Mtetra
.81 .748 .794 r
.74978 .53371 .75465 .54117 .76479 .53103 .75994 .52337 Mtetra
.803 .742 .796 r
.75994 .52337 .76479 .53103 .77494 .52099 .77012 .51334 Mtetra
.788 .739 .807 r
.77012 .51334 .77494 .52099 .78515 .51177 .78038 .50433 Mtetra
.756 .735 .833 r
.78038 .50433 .78515 .51177 .7955 .50429 .79079 .49724 Mtetra
.719 .734 .863 r
.79079 .49724 .7955 .50429 .806 .49849 .80136 .4919 Mtetra
.674 .733 .895 r
.80136 .4919 .806 .49849 .81668 .49436 .81211 .48821 Mtetra
.628 .731 .921 r
.81211 .48821 .81668 .49436 .8275 .4915 .82299 .48573 Mtetra
.593 .731 .94 r
.82299 .48573 .8275 .4915 .83846 .4895 .834 .48398 Mtetra
.567 .73 .951 r
.834 .48398 .83846 .4895 .84951 .48803 .8451 .48266 Mtetra
.562 .735 .957 r
.8451 .48266 .84951 .48803 .86063 .4867 .85626 .48138 Mtetra
.564 .739 .958 r
.85626 .48138 .86063 .4867 .87181 .48536 .86746 .48001 Mtetra
.579 .745 .955 r
.86746 .48001 .87181 .48536 .88301 .48379 .87869 .47836 Mtetra
.593 .748 .951 r
.87869 .47836 .88301 .48379 .89425 .482 .88995 .47643 Mtetra
.608 .751 .946 r
.88995 .47643 .89425 .482 .9055 .47991 .90122 .4742 Mtetra
.619 .751 .94 r
.90122 .4742 .9055 .47991 .91679 .4776 .91252 .47174 Mtetra
.627 .749 .935 r
.91252 .47174 .91679 .4776 .9281 .47514 .92385 .46912 Mtetra
.632 .746 .93 r
.92385 .46912 .9281 .47514 .93945 .47256 .93521 .46639 Mtetra
.674 .756 .912 r
.32977 .63908 .33552 .6441 .3447 .6408 .33897 .63591 Mtetra
.678 .762 .914 r
.33897 .63591 .3447 .6408 .35391 .63741 .34819 .63264 Mtetra
.683 .768 .916 r
.34819 .63264 .35391 .63741 .36315 .63385 .35745 .62923 Mtetra
.691 .776 .916 r
.35745 .62923 .36315 .63385 .37244 .63008 .36675 .62559 Mtetra
.702 .784 .915 r
.36675 .62559 .37244 .63008 .38176 .62601 .37609 .62166 Mtetra
.712 .792 .914 r
.37609 .62166 .38176 .62601 .39112 .62169 .38547 .61746 Mtetra
.723 .799 .911 r
.38547 .61746 .39112 .62169 .40051 .61708 .39488 .61294 Mtetra
.728 .804 .911 r
.39488 .61294 .40051 .61708 .40993 .6124 .40432 .60827 Mtetra
.73 .806 .911 r
.40432 .60827 .40993 .6124 .41936 .60774 .41379 .60352 Mtetra
.721 .802 .915 r
.41379 .60352 .41936 .60774 .42881 .60349 .42327 .59905 Mtetra
.701 .79 .92 r
.42327 .59905 .42881 .60349 .43827 .59994 .43276 .5951 Mtetra
.659 .766 .929 r
.43276 .5951 .43827 .59994 .44772 .59756 .44225 .59218 Mtetra
.59 .724 .936 r
.44225 .59218 .44772 .59756 .45718 .59679 .45174 .59073 Mtetra
.5 .662 .934 r
.45174 .59073 .45718 .59679 .46666 .59773 .46124 .591 Mtetra
.382 .58 .919 r
.46124 .591 .46666 .59773 .47617 .60055 .47077 .59322 Mtetra
.312 .521 .898 r
.47077 .59322 .47617 .60055 .48572 .60438 .48033 .59667 Mtetra
.283 .492 .884 r
.48033 .59667 .48572 .60438 .49535 .60855 .48997 .60074 Mtetra
.388 .548 .892 r
.48997 .60074 .49535 .60855 .50506 .61118 .49968 .60347 Mtetra
.549 .632 .886 r
.49968 .60347 .50506 .61118 .51485 .61078 .50948 .60332 Mtetra
.711 .703 .84 r
.50948 .60332 .51485 .61078 .52468 .60587 .51933 .59836 Mtetra
.806 .726 .776 r
.51933 .59836 .52468 .60587 .53453 .59573 .5292 .58762 Mtetra
.836 .72 .736 r
.5292 .58762 .53453 .59573 .54434 .58216 .53905 .57293 Mtetra
.838 .704 .715 r
.53905 .57293 .54434 .58216 .55412 .56694 .54885 .55622 Mtetra
.798 .673 .726 r
.54885 .55622 .55412 .56694 .56389 .55451 .55863 .54276 Mtetra
.716 .627 .757 r
.55863 .54276 .56389 .55451 .57372 .54747 .56847 .53567 Mtetra
.503 .517 .804 r
.56847 .53567 .57372 .54747 .58369 .54763 .57847 .53763 Mtetra
0 .218 .736 r
.57847 .53763 .58369 .54763 .59385 .55443 .58869 .54801 Mtetra
0 0 .532 r
.58869 .54801 .59385 .55443 .60412 .56214 .59905 .55952 Mtetra
.536 0 0 r
.59905 .55952 .60412 .56214 .61442 .5671 .60945 .56734 Mtetra
.372 .839 .858 r
.60945 .56734 .61442 .5671 .62458 .5641 .61964 .56432 Mtetra
.928 .953 .781 r
.61964 .56432 .62458 .5641 .63451 .55312 .62954 .55045 Mtetra
.933 .849 .737 r
.62954 .55045 .63451 .55312 .64433 .53935 .63928 .53282 Mtetra
.877 .763 .733 r
.63928 .53282 .64433 .53935 .65415 .52646 .64901 .51629 Mtetra
.745 .666 .773 r
.64901 .51629 .65415 .52646 .66423 .52022 .65903 .50819 Mtetra
.536 .534 .8 r
.65903 .50819 .66423 .52022 .67466 .52125 .66945 .50922 Mtetra
.286 .386 .79 r
.66945 .50922 .67466 .52125 .6854 .52774 .68024 .5167 Mtetra
.063 .261 .753 r
.68024 .5167 .6854 .52774 .6964 .5371 .6913 .52751 Mtetra
.103 .323 .797 r
.6913 .52751 .6964 .5371 .70742 .54483 .70238 .53633 Mtetra
.303 .481 .869 r
.70238 .53633 .70742 .54483 .71835 .54911 .71335 .54117 Mtetra
.582 .65 .882 r
.71335 .54117 .71835 .54911 .72905 .54808 .72407 .54016 Mtetra
.726 .711 .836 r
.72407 .54016 .72905 .54808 .73951 .54245 .73453 .53423 Mtetra
.779 .722 .8 r
.73453 .53423 .73951 .54245 .74978 .53371 .74482 .52533 Mtetra
.797 .725 .784 r
.74482 .52533 .74978 .53371 .75994 .52337 .75502 .51504 Mtetra
.79 .725 .791 r
.75502 .51504 .75994 .52337 .77012 .51334 .76526 .50537 Mtetra
.775 .729 .81 r
.76526 .50537 .77012 .51334 .78038 .50433 .77559 .49693 Mtetra
.743 .733 .843 r
.77559 .49693 .78038 .50433 .79079 .49724 .78608 .49049 Mtetra
.703 .739 .879 r
.78608 .49049 .79079 .49724 .80136 .4919 .79674 .48581 Mtetra
.654 .744 .916 r
.79674 .48581 .80136 .4919 .81211 .48821 .80755 .48264 Mtetra
.606 .745 .943 r
.80755 .48264 .81211 .48821 .82299 .48573 .81851 .48053 Mtetra
.572 .747 .959 r
.81851 .48053 .82299 .48573 .834 .48398 .82956 .47898 Mtetra
.552 .747 .967 r
.82956 .47898 .834 .48398 .8451 .48266 .8407 .47771 Mtetra
.554 .751 .969 r
.8407 .47771 .8451 .48266 .85626 .48138 .85188 .47636 Mtetra
.563 .753 .967 r
.85188 .47636 .85626 .48138 .86746 .48001 .86311 .47487 Mtetra
.582 .757 .961 r
.86311 .47487 .86746 .48001 .87869 .47836 .87436 .47305 Mtetra
.598 .758 .955 r
.87436 .47305 .87869 .47836 .88995 .47643 .88563 .47094 Mtetra
.614 .758 .947 r
.88563 .47094 .88995 .47643 .90122 .4742 .89691 .46852 Mtetra
.625 .756 .941 r
.89691 .46852 .90122 .4742 .91252 .47174 .90823 .46588 Mtetra
.633 .753 .934 r
.90823 .46588 .91252 .47174 .92385 .46912 .91957 .46308 Mtetra
.637 .749 .929 r
.91957 .46308 .92385 .46912 .93521 .46639 .93095 .46018 Mtetra
.669 .754 .914 r
.32399 .63404 .32977 .63908 .33897 .63591 .3332 .63098 Mtetra
.672 .76 .917 r
.3332 .63098 .33897 .63591 .34819 .63264 .34244 .62784 Mtetra
.677 .767 .919 r
.34244 .62784 .34819 .63264 .35745 .62923 .35171 .62456 Mtetra
.685 .774 .919 r
.35171 .62456 .35745 .62923 .36675 .62559 .36103 .62108 Mtetra
.695 .783 .919 r
.36103 .62108 .36675 .62559 .37609 .62166 .37038 .61732 Mtetra
.705 .792 .919 r
.37038 .61732 .37609 .62166 .38547 .61746 .37977 .61329 Mtetra
.717 .802 .918 r
.37977 .61329 .38547 .61746 .39488 .61294 .38921 .60894 Mtetra
.724 .81 .919 r
.38921 .60894 .39488 .61294 .40432 .60827 .39867 .60439 Mtetra
.729 .817 .919 r
.39867 .60439 .40432 .60827 .41379 .60352 .40816 .59968 Mtetra
.725 .819 .923 r
.40816 .59968 .41379 .60352 .42327 .59905 .41767 .59509 Mtetra
.712 .813 .928 r
.41767 .59509 .42327 .59905 .43276 .5951 .42719 .59082 Mtetra
.679 .795 .936 r
.42719 .59082 .43276 .5951 .44225 .59218 .43672 .58738 Mtetra
.622 .759 .944 r
.43672 .58738 .44225 .59218 .45174 .59073 .44625 .58518 Mtetra
.543 .701 .943 r
.44625 .58518 .45174 .59073 .46124 .591 .45579 .58457 Mtetra
.437 .621 .929 r
.45579 .58457 .46124 .591 .47077 .59322 .46534 .58588 Mtetra
.371 .554 .904 r
.46534 .58588 .47077 .59322 .48033 .59667 .47492 .58855 Mtetra
.335 .51 .881 r
.47492 .58855 .48033 .59667 .48997 .60074 .48456 .59214 Mtetra
.414 .54 .874 r
.48456 .59214 .48997 .60074 .49968 .60347 .49428 .5948 Mtetra
.541 .603 .865 r
.49428 .5948 .49968 .60347 .50948 .60332 .50409 .59502 Mtetra
.695 .678 .829 r
.50409 .59502 .50948 .60332 .51933 .59836 .51396 .59045 Mtetra
.8 .717 .774 r
.51396 .59045 .51933 .59836 .5292 .58762 .52386 .57989 Mtetra
.842 .728 .738 r
.52386 .57989 .5292 .58762 .53905 .57293 .53374 .56497 Mtetra
.856 .726 .718 r
.53374 .56497 .53905 .57293 .54885 .55622 .54357 .54762 Mtetra
.826 .711 .738 r
.54357 .54762 .54885 .55622 .55863 .54276 .55338 .53366 Mtetra
.737 .677 .792 r
.55338 .53366 .55863 .54276 .56847 .53567 .56324 .52667 Mtetra
.365 .5 .861 r
.56324 .52667 .56847 .53567 .57847 .53763 .57327 .53047 Mtetra
0 0 .424 r
.57327 .53047 .57847 .53763 .58869 .54801 .58355 .54449 Mtetra
.798 .311 0 r
.58355 .54449 .58869 .54801 .59905 .55952 .59401 .55997 Mtetra
.755 .254 .028 r
.59401 .55997 .59905 .55952 .60945 .56734 .6045 .57091 Mtetra
.062 0 0 r
.6045 .57091 .60945 .56734 .61964 .56432 .61475 .56789 Mtetra
.916 .967 .66 r
.61475 .56789 .61964 .56432 .62954 .55045 .62462 .55086 Mtetra
.974 .891 .682 r
.62462 .55086 .62954 .55045 .63928 .53282 .6343 .52922 Mtetra
.933 .818 .709 r
.6343 .52922 .63928 .53282 .64901 .51629 .64394 .50897 Mtetra
.805 .741 .793 r
.64394 .50897 .64901 .51629 .65903 .50819 .65392 .49898 Mtetra
.518 .581 .857 r
.65392 .49898 .65903 .50819 .66945 .50922 .66435 .49986 Mtetra
.135 .35 .811 r
.66435 .49986 .66945 .50922 .68024 .5167 .67516 .50779 Mtetra
0 .173 .71 r
.67516 .50779 .68024 .5167 .6913 .52751 .68624 .51921 Mtetra
0 .286 .785 r
.68624 .51921 .6913 .52751 .70238 .53633 .69733 .52822 Mtetra
.297 .491 .879 r
.69733 .52822 .70238 .53633 .71335 .54117 .7083 .53283 Mtetra
.599 .648 .87 r
.7083 .53283 .71335 .54117 .72407 .54016 .71901 .53137 Mtetra
.727 .693 .817 r
.71901 .53137 .72407 .54016 .73453 .53423 .72947 .52502 Mtetra
.767 .699 .787 r
.72947 .52502 .73453 .53423 .74482 .52533 .73979 .51615 Mtetra
.782 .705 .779 r
.73979 .51615 .74482 .52533 .75502 .51504 .75005 .5063 Mtetra
.774 .712 .794 r
.75005 .5063 .75502 .51504 .76526 .50537 .76037 .49738 Mtetra
.759 .724 .82 r
.76037 .49738 .76526 .50537 .77559 .49693 .77079 .48984 Mtetra
.725 .737 .861 r
.77079 .48984 .77559 .49693 .78608 .49049 .78138 .48426 Mtetra
.682 .75 .903 r
.78138 .48426 .78608 .49049 .79674 .48581 .79213 .48031 Mtetra
.63 .759 .94 r
.79213 .48031 .79674 .48581 .80755 .48264 .80302 .47764 Mtetra
.581 .76 .964 r
.80302 .47764 .80755 .48264 .81851 .48053 .81403 .47583 Mtetra
.555 .763 .975 r
.81403 .47583 .81851 .48053 .82956 .47898 .82513 .47435 Mtetra
.544 .762 .978 r
.82513 .47435 .82956 .47898 .8407 .47771 .83629 .473 Mtetra
.555 .764 .975 r
.83629 .473 .8407 .47771 .85188 .47636 .8475 .4715 Mtetra
.57 .764 .97 r
.8475 .4715 .85188 .47636 .86311 .47487 .85873 .46978 Mtetra
.59 .765 .962 r
.85873 .46978 .86311 .47487 .87436 .47305 .86999 .46774 Mtetra
.607 .763 .954 r
.86999 .46774 .87436 .47305 .88563 .47094 .88127 .46541 Mtetra
.622 .762 .946 r
.88127 .46541 .88563 .47094 .89691 .46852 .89257 .46279 Mtetra
.632 .759 .939 r
.89257 .46279 .89691 .46852 .90823 .46588 .9039 .45996 Mtetra
.639 .755 .933 r
.9039 .45996 .90823 .46588 .91957 .46308 .91525 .45699 Mtetra
.643 .751 .928 r
.91525 .45699 .91957 .46308 .93095 .46018 .92665 .45393 Mtetra
.665 .753 .916 r
.31818 .62896 .32399 .63404 .3332 .63098 .3274 .62599 Mtetra
.667 .758 .918 r
.3274 .62599 .3332 .63098 .34244 .62784 .33665 .62295 Mtetra
.671 .764 .92 r
.33665 .62295 .34244 .62784 .35171 .62456 .34594 .6198 Mtetra
.678 .77 .921 r
.34594 .6198 .35171 .62456 .36103 .62108 .35527 .61646 Mtetra
.687 .779 .921 r
.35527 .61646 .36103 .62108 .37038 .61732 .36463 .61289 Mtetra
.696 .789 .922 r
.36463 .61289 .37038 .61732 .37977 .61329 .37404 .60907 Mtetra
.707 .8 .923 r
.37404 .60907 .37977 .61329 .38921 .60894 .38349 .60497 Mtetra
.715 .812 .925 r
.38349 .60497 .38921 .60894 .39867 .60439 .39297 .60065 Mtetra
.722 .823 .928 r
.39297 .60065 .39867 .60439 .40816 .59968 .40248 .59613 Mtetra
.722 .832 .932 r
.40248 .59613 .40816 .59968 .41767 .59509 .41202 .59158 Mtetra
.718 .834 .937 r
.41202 .59158 .41767 .59509 .42719 .59082 .42157 .58714 Mtetra
.694 .824 .945 r
.42157 .58714 .42719 .59082 .43672 .58738 .43114 .58327 Mtetra
.653 .798 .952 r
.43114 .58327 .43672 .58738 .44625 .58518 .44071 .58031 Mtetra
.59 .748 .953 r
.44071 .58031 .44625 .58518 .45579 .58457 .45029 .57868 Mtetra
.506 .675 .94 r
.45029 .57868 .45579 .58457 .46534 .58588 .45987 .57874 Mtetra
.445 .601 .911 r
.45987 .57874 .46534 .58588 .47492 .58855 .46949 .58021 Mtetra
.405 .542 .881 r
.46949 .58021 .47492 .58855 .48456 .59214 .47914 .58286 Mtetra
.448 .54 .858 r
.47914 .58286 .48456 .59214 .49428 .5948 .48887 .58517 Mtetra
.529 .574 .845 r
.48887 .58517 .49428 .5948 .50409 .59502 .49867 .58584 Mtetra
.667 .649 .823 r
.49867 .58584 .50409 .59502 .51396 .59045 .50855 .5822 Mtetra
.781 .707 .782 r
.50855 .5822 .51396 .59045 .52386 .57989 .51848 .57284 Mtetra
.844 .742 .751 r
.51848 .57284 .52386 .57989 .53374 .56497 .5284 .5589 Mtetra
.876 .762 .732 r
.5284 .5589 .53374 .56497 .54357 .54762 .53827 .54211 Mtetra
.864 .778 .765 r
.53827 .54211 .54357 .54762 .55338 .53366 .54813 .52837 Mtetra
.774 .785 .862 r
.54813 .52837 .55338 .53366 .56324 .52667 .55802 .52153 Mtetra
0 .386 .836 r
.55802 .52153 .56324 .52667 .57327 .53047 .56809 .52687 Mtetra
.831 .361 0 r
.56809 .52687 .57327 .53047 .58355 .54449 .57842 .54407 Mtetra
.86 .422 .164 r
.57842 .54407 .58355 .54449 .59401 .55997 .58896 .56324 Mtetra
.791 .354 .21 r
.58896 .56324 .59401 .55997 .6045 .57091 .59956 .57728 Mtetra
.258 0 0 r
.59956 .57728 .6045 .57091 .61475 .56789 .60987 .57424 Mtetra
.864 .922 .529 r
.60987 .57424 .61475 .56789 .62462 .55086 .61973 .55409 Mtetra
.984 .905 .616 r
.61973 .55409 .62462 .55086 .6343 .52922 .62937 .52872 Mtetra
.973 .865 .672 r
.62937 .52872 .6343 .52922 .64394 .50897 .63897 .50524 Mtetra
.874 .85 .816 r
.63897 .50524 .64394 .50897 .65392 .49898 .64893 .49366 Mtetra
.442 .674 .962 r
.64893 .49366 .65392 .49898 .66435 .49986 .65938 .49434 Mtetra
0 .258 .75 r
.65938 .49434 .66435 .49986 .67516 .50779 .67019 .50202 Mtetra
0 .063 .586 r
.67019 .50202 .67516 .50779 .68624 .51921 .68125 .51283 Mtetra
0 .286 .782 r
.68125 .51283 .68624 .51921 .69733 .52822 .6923 .52079 Mtetra
.345 .543 .904 r
.6923 .52079 .69733 .52822 .7083 .53283 .70321 .52414 Mtetra
.631 .655 .855 r
.70321 .52414 .7083 .53283 .71901 .53137 .71388 .52168 Mtetra
.729 .676 .799 r
.71388 .52168 .71901 .53137 .72947 .52502 .72433 .51481 Mtetra
.752 .677 .778 r
.72433 .51481 .72947 .52502 .73979 .51615 .73469 .50625 Mtetra
.761 .686 .779 r
.73469 .50625 .73979 .51615 .75005 .5063 .74504 .49733 Mtetra
.752 .7 .803 r
.74504 .49733 .75005 .5063 .76037 .49738 .75547 .4896 Mtetra
.736 .722 .839 r
.75547 .4896 .76037 .49738 .77079 .48984 .76601 .4833 Mtetra
.7 .747 .888 r
.76601 .4833 .77079 .48984 .78138 .48426 .77671 .47872 Mtetra
.653 .767 .933 r
.77671 .47872 .78138 .48426 .79213 .48031 .78755 .47551 Mtetra
.6 .778 .966 r
.78755 .47551 .79213 .48031 .80302 .47764 .79851 .47325 Mtetra
.557 .779 .982 r
.79851 .47325 .80302 .47764 .81403 .47583 .80957 .47157 Mtetra
.545 .781 .986 r
.80957 .47157 .81403 .47583 .82513 .47435 .82069 .47001 Mtetra
.547 .779 .984 r
.82069 .47001 .82513 .47435 .83629 .473 .83187 .46843 Mtetra
.565 .777 .978 r
.83187 .46843 .83629 .473 .8475 .4715 .84308 .46665 Mtetra
.584 .773 .97 r
.84308 .46665 .8475 .4715 .85873 .46978 .85432 .46463 Mtetra
.603 .769 .959 r
.85432 .46463 .85873 .46978 .86999 .46774 .86559 .46232 Mtetra
.618 .765 .95 r
.86559 .46232 .86999 .46774 .88127 .46541 .87688 .45976 Mtetra
.63 .762 .942 r
.87688 .45976 .88127 .46541 .89257 .46279 .88819 .45695 Mtetra
.639 .759 .935 r
.88819 .45695 .89257 .46279 .9039 .45996 .89953 .45395 Mtetra
.644 .755 .93 r
.89953 .45395 .9039 .45996 .91525 .45699 .91091 .45083 Mtetra
.647 .752 .926 r
.91091 .45083 .91525 .45699 .92665 .45393 .92232 .44763 Mtetra
.662 .753 .918 r
.31232 .62385 .31818 .62896 .3274 .62599 .32156 .62094 Mtetra
.664 .756 .919 r
.32156 .62094 .3274 .62599 .33665 .62295 .33083 .61796 Mtetra
.667 .76 .92 r
.33083 .61796 .33665 .62295 .34594 .6198 .34013 .61489 Mtetra
.673 .765 .92 r
.34013 .61489 .34594 .6198 .35527 .61646 .34947 .61167 Mtetra
.68 .772 .92 r
.34947 .61167 .35527 .61646 .36463 .61289 .35886 .60825 Mtetra
.687 .78 .922 r
.35886 .60825 .36463 .61289 .37404 .60907 .36828 .60464 Mtetra
.696 .791 .924 r
.36828 .60464 .37404 .60907 .38349 .60497 .37773 .60081 Mtetra
.703 .803 .927 r
.37773 .60081 .38349 .60497 .39297 .60065 .38723 .59678 Mtetra
.71 .817 .932 r
.38723 .59678 .39297 .60065 .40248 .59613 .39676 .59255 Mtetra
.714 .831 .937 r
.39676 .59255 .40248 .59613 .41202 .59158 .40631 .58821 Mtetra
.715 .841 .942 r
.40631 .58821 .41202 .59158 .42157 .58714 .4159 .58381 Mtetra
.701 .842 .95 r
.4159 .58381 .42157 .58714 .43114 .58327 .4255 .57971 Mtetra
.675 .828 .957 r
.4255 .57971 .43114 .58327 .44071 .58031 .43511 .57618 Mtetra
.632 .794 .96 r
.43511 .57618 .44071 .58031 .45029 .57868 .44473 .5736 Mtetra
.573 .735 .952 r
.44473 .5736 .45029 .57868 .45987 .57874 .45436 .57228 Mtetra
.522 .662 .924 r
.45436 .57228 .45987 .57874 .46949 .58021 .46402 .57223 Mtetra
.48 .593 .889 r
.46402 .57223 .46949 .58021 .47914 .58286 .4737 .57343 Mtetra
.487 .559 .854 r
.4737 .57343 .47914 .58286 .48887 .58517 .48344 .57495 Mtetra
.522 .559 .835 r
.48344 .57495 .48887 .58517 .49867 .58584 .49324 .57588 Mtetra
.631 .619 .819 r
.49324 .57588 .49867 .58584 .50855 .5822 .50313 .57349 Mtetra
.744 .688 .798 r
.50313 .57349 .50855 .5822 .51848 .57284 .51307 .56627 Mtetra
.828 .753 .78 r
.51307 .56627 .51848 .57284 .5284 .5589 .52302 .55471 Mtetra
.888 .809 .765 r
.52302 .55471 .5284 .5589 .53827 .54211 .53295 .54004 Mtetra
.901 .881 .806 r
.53295 .54004 .53827 .54211 .54813 .52837 .54286 .52735 Mtetra
.785 .956 .925 r
.54286 .52735 .54813 .52837 .55802 .52153 .5528 .52043 Mtetra
.504 0 0 r
.5528 .52043 .55802 .52153 .56809 .52687 .56289 .526 Mtetra
.856 .41 .14 r
.56289 .526 .56809 .52687 .57842 .54407 .57325 .54424 Mtetra
.868 .444 .204 r
.57325 .54424 .57842 .54407 .58896 .56324 .58383 .56514 Mtetra
.819 .378 .19 r
.58383 .56514 .58896 .56324 .59956 .57728 .59449 .5811 Mtetra
.078 0 0 r
.59449 .5811 .59956 .57728 .60987 .57424 .60485 .57806 Mtetra
.965 .934 .628 r
.60485 .57806 .60987 .57424 .61973 .55409 .61475 .55595 Mtetra
.988 .879 .627 r
.61475 .55595 .61973 .55409 .62937 .52872 .62442 .52881 Mtetra
.978 .869 .66 r
.62442 .52881 .62937 .52872 .63897 .50524 .63406 .50426 Mtetra
.902 .943 .825 r
.63406 .50426 .63897 .50524 .64893 .49366 .64406 .49241 Mtetra
.073 .62 .837 r
.64406 .49241 .64893 .49366 .65938 .49434 .65454 .49314 Mtetra
.522 0 0 r
.65454 .49314 .65938 .49434 .67019 .50202 .66533 .49972 Mtetra
.565 0 0 r
.66533 .49972 .67019 .50202 .68125 .51283 .67631 .50834 Mtetra
0 .383 .822 r
.67631 .50834 .68125 .51283 .6923 .52079 .68726 .51385 Mtetra
.462 .626 .923 r
.68726 .51385 .6923 .52079 .70321 .52414 .69807 .51498 Mtetra
.666 .661 .835 r
.69807 .51498 .70321 .52414 .71388 .52168 .70869 .5112 Mtetra
.727 .662 .785 r
.70869 .5112 .71388 .52168 .72433 .51481 .71914 .50401 Mtetra
.735 .661 .777 r
.71914 .50401 .72433 .51481 .73469 .50625 .72957 .49622 Mtetra
.737 .674 .79 r
.72957 .49622 .73469 .50625 .74504 .49733 .74003 .48873 Mtetra
.726 .7 .825 r
.74003 .48873 .74504 .49733 .75547 .4896 .75059 .48251 Mtetra
.707 .733 .871 r
.75059 .48251 .75547 .4896 .76601 .4833 .76126 .47758 Mtetra
.669 .767 .923 r
.76126 .47758 .76601 .4833 .77671 .47872 .77206 .47394 Mtetra
.619 .787 .962 r
.77206 .47394 .77671 .47872 .78755 .47551 .78298 .47128 Mtetra
.575 .795 .983 r
.78298 .47128 .78755 .47551 .79851 .47325 .79399 .46921 Mtetra
.549 .793 .989 r
.79399 .46921 .79851 .47325 .80957 .47157 .80508 .46745 Mtetra
.554 .792 .988 r
.80508 .46745 .80957 .47157 .82069 .47001 .81622 .46564 Mtetra
.567 .787 .982 r
.81622 .46564 .82069 .47001 .83187 .46843 .8274 .46372 Mtetra
.586 .781 .973 r
.8274 .46372 .83187 .46843 .84308 .46665 .83861 .46159 Mtetra
.602 .774 .962 r
.83861 .46159 .84308 .46665 .85432 .46463 .84986 .45926 Mtetra
.617 .767 .952 r
.84986 .45926 .85432 .46463 .86559 .46232 .86114 .45669 Mtetra
.628 .762 .943 r
.86114 .45669 .86559 .46232 .87688 .45976 .87244 .45392 Mtetra
.637 .759 .936 r
.87244 .45392 .87688 .45976 .88819 .45695 .88377 .45095 Mtetra
.644 .756 .931 r
.88377 .45095 .88819 .45695 .89953 .45395 .89513 .44782 Mtetra
.648 .754 .927 r
.89513 .44782 .89953 .45395 .91091 .45083 .90653 .44458 Mtetra
.65 .752 .924 r
.90653 .44458 .91091 .45083 .92232 .44763 .91796 .44128 Mtetra
.66 .752 .918 r
.30643 .61871 .31232 .62385 .32156 .62094 .31568 .61581 Mtetra
.662 .754 .918 r
.31568 .61581 .32156 .62094 .33083 .61796 .32497 .61285 Mtetra
.665 .756 .918 r
.32497 .61285 .33083 .61796 .34013 .61489 .33429 .6098 Mtetra
.67 .759 .917 r
.33429 .6098 .34013 .61489 .34947 .61167 .34365 .60664 Mtetra
.675 .763 .917 r
.34365 .60664 .34947 .61167 .35886 .60825 .35305 .60333 Mtetra
.68 .769 .918 r
.35305 .60333 .35886 .60825 .36828 .60464 .36248 .59988 Mtetra
.685 .777 .92 r
.36248 .59988 .36828 .60464 .37773 .60081 .37195 .59629 Mtetra
.69 .788 .925 r
.37195 .59629 .37773 .60081 .38723 .59678 .38146 .59256 Mtetra
.695 .802 .931 r
.38146 .59256 .38723 .59678 .39676 .59255 .391 .5887 Mtetra
.699 .819 .939 r
.391 .5887 .39676 .59255 .40631 .58821 .40057 .58472 Mtetra
.702 .835 .947 r
.40057 .58472 .40631 .58821 .4159 .58381 .41017 .58061 Mtetra
.695 .848 .956 r
.41017 .58061 .4159 .58381 .4255 .57971 .4198 .5766 Mtetra
.681 .85 .964 r
.4198 .5766 .4255 .57971 .43511 .57618 .42945 .57283 Mtetra
.659 .836 .968 r
.42945 .57283 .43511 .57618 .44473 .5736 .43911 .56953 Mtetra
.633 .799 .962 r
.43911 .56953 .44473 .5736 .45436 .57228 .4488 .56687 Mtetra
.602 .734 .938 r
.4488 .56687 .45436 .57228 .46402 .57223 .4585 .56509 Mtetra
.567 .66 .9 r
.4585 .56509 .46402 .57223 .4737 .57343 .46823 .56433 Mtetra
.542 .595 .856 r
.46823 .56433 .4737 .57343 .48344 .57495 .47799 .56451 Mtetra
.528 .559 .83 r
.47799 .56451 .48344 .57495 .49324 .57588 .4878 .56528 Mtetra
.591 .588 .818 r
.4878 .56528 .49324 .57588 .50313 .57349 .49768 .56424 Mtetra
.68 .655 .819 r
.49768 .56424 .50313 .57349 .51307 .56627 .50762 .56004 Mtetra
.779 .757 .834 r
.50762 .56004 .51307 .56627 .52302 .55471 .5176 .55237 Mtetra
.874 .884 .839 r
.5176 .55237 .52302 .55471 .53295 .54004 .52759 .54168 Mtetra
.847 .998 .81 r
.52759 .54168 .53295 .54004 .54286 .52735 .53757 .53106 Mtetra
.45 .831 .598 r
.53757 .53106 .54286 .52735 .5528 .52043 .54756 .52364 Mtetra
.552 .036 0 r
.54756 .52364 .5528 .52043 .56289 .526 .55767 .52739 Mtetra
.824 .381 .182 r
.55767 .52739 .56289 .526 .57325 .54424 .56801 .5432 Mtetra
.862 .419 .143 r
.56801 .5432 .57325 .54424 .58383 .56514 .57857 .56257 Mtetra
.813 .328 0 r
.57857 .56257 .58383 .56514 .59449 .5811 .58923 .57832 Mtetra
.607 .863 .991 r
.58923 .57832 .59449 .5811 .60485 .57806 .59963 .57526 Mtetra
.945 .829 .699 r
.59963 .57526 .60485 .57806 .61475 .55595 .60959 .55332 Mtetra
.956 .819 .668 r
.60959 .55332 .61475 .55595 .62442 .52881 .61937 .52769 Mtetra
.965 .863 .689 r
.61937 .52769 .62442 .52881 .63406 .50426 .62916 .50555 Mtetra
.813 1 .81 r
.62916 .50555 .63406 .50426 .64406 .49241 .63929 .4955 Mtetra
.391 0 0 r
.63929 .4955 .64406 .49241 .65454 .49314 .64984 .49671 Mtetra
.572 .062 .001 r
.64984 .49671 .65454 .49314 .66533 .49972 .66058 .50117 Mtetra
.526 0 0 r
.66058 .50117 .66533 .49972 .67631 .50834 .67142 .50573 Mtetra
.144 .628 .92 r
.67142 .50573 .67631 .50834 .68726 .51385 .68221 .50726 Mtetra
.609 .709 .915 r
.68221 .50726 .68726 .51385 .69807 .51498 .69288 .50526 Mtetra
.696 .663 .814 r
.69288 .50526 .69807 .51498 .70869 .5112 .70344 .50005 Mtetra
.72 .649 .778 r
.70344 .50005 .70869 .5112 .71914 .50401 .71391 .49298 Mtetra
.71 .647 .784 r
.71391 .49298 .71914 .50401 .72957 .49622 .72444 .48651 Mtetra
.703 .667 .812 r
.72444 .48651 .72957 .49622 .74003 .48873 .73505 .48097 Mtetra
.691 .709 .861 r
.73505 .48097 .74003 .48873 .75059 .48251 .74575 .47649 Mtetra
.668 .756 .916 r
.74575 .47649 .75059 .48251 .76126 .47758 .75655 .47289 Mtetra
.63 .796 .962 r
.75655 .47289 .76126 .47758 .77206 .47394 .76744 .46996 Mtetra
.59 .813 .985 r
.76744 .46996 .77206 .47394 .78298 .47128 .77841 .46751 Mtetra
.566 .814 .991 r
.77841 .46751 .78298 .47128 .79399 .46921 .78945 .46531 Mtetra
.563 .808 .99 r
.78945 .46531 .79399 .46921 .80508 .46745 .80055 .46321 Mtetra
.58 .8 .983 r
.80055 .46321 .80508 .46745 .81622 .46564 .81168 .46099 Mtetra
.595 .789 .973 r
.81168 .46099 .81622 .46564 .8274 .46372 .82286 .45864 Mtetra
.609 .776 .961 r
.82286 .45864 .8274 .46372 .83861 .46159 .83408 .45615 Mtetra
.62 .767 .95 r
.83408 .45615 .83861 .46159 .84986 .45926 .84533 .45352 Mtetra
.628 .759 .941 r
.84533 .45352 .84986 .45926 .86114 .45669 .85662 .45074 Mtetra
.635 .755 .934 r
.85662 .45074 .86114 .45669 .87244 .45392 .86794 .44782 Mtetra
.642 .753 .929 r
.86794 .44782 .87244 .45392 .88377 .45095 .87929 .44474 Mtetra
.646 .752 .926 r
.87929 .44474 .88377 .45095 .89513 .44782 .89068 .44154 Mtetra
.65 .751 .924 r
.89068 .44154 .89513 .44782 .90653 .44458 .90211 .43825 Mtetra
.652 .751 .922 r
.90211 .43825 .90653 .44458 .91796 .44128 .91357 .43489 Mtetra
.66 .752 .918 r
.3005 .61354 .30643 .61871 .31568 .61581 .30977 .61062 Mtetra
.662 .753 .918 r
.30977 .61062 .31568 .61581 .32497 .61285 .31908 .60764 Mtetra
.665 .754 .916 r
.31908 .60764 .32497 .61285 .33429 .6098 .32842 .60458 Mtetra
.668 .755 .915 r
.32842 .60458 .33429 .6098 .34365 .60664 .3378 .60143 Mtetra
.673 .757 .914 r
.3378 .60143 .34365 .60664 .35305 .60333 .34722 .59816 Mtetra
.676 .76 .914 r
.34722 .59816 .35305 .60333 .36248 .59988 .35667 .59479 Mtetra
.679 .764 .916 r
.35667 .59479 .36248 .59988 .37195 .59629 .36615 .59135 Mtetra
.681 .771 .919 r
.36615 .59135 .37195 .59629 .38146 .59256 .37567 .58785 Mtetra
.682 .781 .925 r
.37567 .58785 .38146 .59256 .391 .5887 .38522 .5843 Mtetra
.683 .794 .934 r
.38522 .5843 .391 .5887 .40057 .58472 .3948 .5807 Mtetra
.684 .811 .943 r
.3948 .5807 .40057 .58472 .41017 .58061 .40442 .57704 Mtetra
.679 .83 .956 r
.40442 .57704 .41017 .58061 .4198 .5766 .41406 .5734 Mtetra
.67 .846 .967 r
.41406 .5734 .4198 .5766 .42945 .57283 .42373 .56984 Mtetra
.665 .854 .972 r
.42373 .56984 .42945 .57283 .43911 .56953 .43343 .56629 Mtetra
.668 .845 .968 r
.43343 .56629 .43911 .56953 .4488 .56687 .44316 .56274 Mtetra
.665 .806 .951 r
.44316 .56274 .4488 .56687 .4585 .56509 .45292 .55942 Mtetra
.652 .743 .916 r
.45292 .55942 .4585 .56509 .46823 .56433 .46271 .55655 Mtetra
.609 .66 .875 r
.46271 .55655 .46823 .56433 .47799 .56451 .47251 .55486 Mtetra
.561 .593 .843 r
.47251 .55486 .47799 .56451 .4878 .56528 .48233 .55462 Mtetra
.566 .575 .822 r
.48233 .55462 .4878 .56528 .49768 .56424 .49221 .55432 Mtetra
.595 .605 .831 r
.49221 .55432 .49768 .56424 .50762 .56004 .50215 .55309 Mtetra
.654 .705 .884 r
.50215 .55309 .50762 .56004 .5176 .55237 .51214 .55011 Mtetra
.724 .904 .959 r
.51214 .55011 .5176 .55237 .52759 .54168 .52217 .54499 Mtetra
.502 .873 .656 r
.52217 .54499 .52759 .54168 .53757 .53106 .53221 .53762 Mtetra
0 0 0 r
.53221 .53762 .53757 .53106 .54756 .52364 .54227 .52969 Mtetra
.398 0 .025 r
.54227 .52969 .54756 .52364 .55767 .52739 .5524 .52928 Mtetra
.71 .213 .057 r
.5524 .52928 .55767 .52739 .56801 .5432 .56268 .53805 Mtetra
.664 .165 0 r
.56268 .53805 .56801 .5432 .57857 .56257 .57313 .55116 Mtetra
0 .17 .701 r
.57313 .55116 .57857 .56257 .58923 .57832 .58371 .56327 Mtetra
.629 .553 .75 r
.58371 .56327 .58923 .57832 .59963 .57526 .5941 .56017 Mtetra
.8 .641 .685 r
.5941 .56017 .59963 .57526 .60959 .55332 .60418 .54183 Mtetra
.839 .687 .694 r
.60418 .54183 .60959 .55332 .61937 .52769 .61417 .52243 Mtetra
.885 .8 .76 r
.61417 .52243 .61937 .52769 .62916 .50555 .62423 .50734 Mtetra
.48 .887 .751 r
.62423 .50734 .62916 .50555 .63929 .4955 .63456 .50146 Mtetra
.493 .026 .073 r
.63456 .50146 .63929 .4955 .64984 .49671 .64518 .50316 Mtetra
.477 .019 .085 r
.64518 .50316 .64984 .49671 .66058 .50117 .65585 .50431 Mtetra
.209 0 0 r
.65585 .50431 .66058 .50117 .67142 .50573 .66649 .5032 Mtetra
.602 .878 .992 r
.66649 .5032 .67142 .50573 .68221 .50726 .67709 .49992 Mtetra
.709 .725 .862 r
.67709 .49992 .68221 .50726 .69288 .50526 .68764 .49487 Mtetra
.707 .656 .797 r
.68764 .49487 .69288 .50526 .70344 .50005 .69817 .48884 Mtetra
.702 .641 .785 r
.69817 .48884 .70344 .50005 .71391 .49298 .70871 .48276 Mtetra
.679 .648 .812 r
.70871 .48276 .71391 .49298 .72444 .48651 .71937 .47815 Mtetra
.658 .68 .859 r
.71937 .47815 .72444 .48651 .73505 .48097 .73013 .47473 Mtetra
.644 .739 .919 r
.73013 .47473 .73505 .48097 .74575 .47649 .74097 .47177 Mtetra
.619 .792 .964 r
.74097 .47177 .74575 .47649 .75655 .47289 .75187 .46906 Mtetra
.6 .825 .986 r
.75187 .46906 .75655 .47289 .76744 .46996 .76281 .46634 Mtetra
.592 .832 .99 r
.76281 .46634 .76744 .46996 .77841 .46751 .7738 .46364 Mtetra
.593 .822 .987 r
.7738 .46364 .77841 .46751 .78945 .46531 .78484 .46102 Mtetra
.602 .807 .979 r
.78484 .46102 .78945 .46531 .80055 .46321 .79593 .45841 Mtetra
.614 .79 .966 r
.79593 .45841 .80055 .46321 .81168 .46099 .80707 .45575 Mtetra
.622 .776 .955 r
.80707 .45575 .81168 .46099 .82286 .45864 .81825 .45303 Mtetra
.627 .763 .945 r
.81825 .45303 .82286 .45864 .83408 .45615 .82947 .45027 Mtetra
.631 .755 .937 r
.82947 .45027 .83408 .45615 .84533 .45352 .84074 .44744 Mtetra
.635 .75 .931 r
.84074 .44744 .84533 .45352 .85662 .45074 .85205 .44453 Mtetra
.639 .748 .928 r
.85205 .44453 .85662 .45074 .86794 .44782 .8634 .44153 Mtetra
.644 .748 .925 r
.8634 .44153 .86794 .44782 .87929 .44474 .87478 .4384 Mtetra
.647 .748 .923 r
.87478 .4384 .87929 .44474 .89068 .44154 .8862 .43516 Mtetra
.65 .749 .922 r
.8862 .43516 .89068 .44154 .90211 .43825 .89765 .43184 Mtetra
.652 .75 .921 r
.89765 .43184 .90211 .43825 .91357 .43489 .90915 .42846 Mtetra
.66 .752 .918 r
.29453 .60833 .3005 .61354 .30977 .61062 .30382 .60538 Mtetra
.663 .753 .917 r
.30382 .60538 .30977 .61062 .31908 .60764 .31315 .60237 Mtetra
.666 .753 .915 r
.31315 .60237 .31908 .60764 .32842 .60458 .32252 .59928 Mtetra
.669 .753 .914 r
.32252 .59928 .32842 .60458 .3378 .60143 .33192 .5961 Mtetra
.674 .754 .911 r
.33192 .5961 .3378 .60143 .34722 .59816 .34135 .59279 Mtetra
.676 .754 .909 r
.34135 .59279 .34722 .59816 .35667 .59479 .35083 .5894 Mtetra
.678 .754 .909 r
.35083 .5894 .35667 .59479 .36615 .59135 .36033 .58596 Mtetra
.677 .755 .91 r
.36033 .58596 .36615 .59135 .37567 .58785 .36987 .58253 Mtetra
.674 .757 .913 r
.36987 .58253 .37567 .58785 .38522 .5843 .37943 .57915 Mtetra
.67 .763 .92 r
.37943 .57915 .38522 .5843 .3948 .5807 .38902 .57586 Mtetra
.663 .775 .932 r
.38902 .57586 .3948 .5807 .40442 .57704 .39864 .57272 Mtetra
.654 .794 .949 r
.39864 .57272 .40442 .57704 .41406 .5734 .40829 .5697 Mtetra
.638 .817 .969 r
.40829 .5697 .41406 .5734 .42373 .56984 .41796 .56684 Mtetra
.641 .85 .98 r
.41796 .56684 .42373 .56984 .43343 .56629 .42768 .56368 Mtetra
.666 .873 .977 r
.42768 .56368 .43343 .56629 .44316 .56274 .43745 .55994 Mtetra
.699 .872 .963 r
.43745 .55994 .44316 .56274 .45292 .55942 .44726 .55564 Mtetra
.726 .834 .932 r
.44726 .55564 .45292 .55942 .46271 .55655 .45711 .55082 Mtetra
.692 .754 .899 r
.45711 .55082 .46271 .55655 .47251 .55486 .46697 .54684 Mtetra
.631 .665 .864 r
.46697 .54684 .47251 .55486 .48233 .55462 .47684 .54451 Mtetra
.577 .592 .832 r
.47684 .54451 .48233 .55462 .49221 .55432 .48673 .54383 Mtetra
.519 .555 .833 r
.48673 .54383 .49221 .55432 .50215 .55309 .49665 .54477 Mtetra
.445 .571 .887 r
.49665 .54477 .50215 .55309 .51214 .55011 .50663 .54662 Mtetra
.206 .633 .95 r
.50663 .54662 .51214 .55011 .52217 .54499 .51668 .54824 Mtetra
.011 0 0 r
.51668 .54824 .52217 .54499 .53221 .53762 .52679 .54532 Mtetra
0 0 0 r
.52679 .54532 .53221 .53762 .54227 .52969 .53691 .53727 Mtetra
.022 0 0 r
.53691 .53727 .54227 .52969 .5524 .52928 .54706 .53043 Mtetra
.284 .781 .755 r
.54706 .53043 .5524 .52928 .56268 .53805 .55725 .52722 Mtetra
.496 .539 .831 r
.55725 .52722 .56268 .53805 .57313 .55116 .56754 .52884 Mtetra
.488 .412 .697 r
.56754 .52884 .57313 .55116 .58371 .56327 .57795 .53333 Mtetra
.6 .457 .658 r
.57795 .53333 .58371 .56327 .5941 .56017 .58829 .53019 Mtetra
.667 .501 .651 r
.58829 .53019 .5941 .56017 .60418 .54183 .59851 .5194 Mtetra
.667 .526 .683 r
.59851 .5194 .60418 .54183 .61417 .52243 .60879 .51147 Mtetra
.642 .614 .806 r
.60879 .51147 .61417 .52243 .62423 .50734 .61922 .50838 Mtetra
.188 0 0 r
.61922 .50838 .62423 .50734 .63456 .50146 .6298 .50895 Mtetra
.513 .075 .144 r
.6298 .50895 .63456 .50146 .64518 .50316 .64049 .51076 Mtetra
.285 0 .028 r
.64049 .51076 .64518 .50316 .65585 .50431 .65105 .50739 Mtetra
.501 .866 .634 r
.65105 .50739 .65585 .50431 .66649 .5032 .66147 .49941 Mtetra
.816 .867 .885 r
.66147 .49941 .66649 .5032 .67709 .49992 .67188 .4912 Mtetra
.747 .704 .812 r
.67188 .4912 .67709 .49992 .68764 .49487 .68234 .48387 Mtetra
.696 .642 .791 r
.68234 .48387 .68764 .49487 .69817 .48884 .69291 .4782 Mtetra
.663 .633 .809 r
.69291 .4782 .69817 .48884 .70871 .48276 .70358 .47419 Mtetra
.624 .66 .865 r
.70358 .47419 .70871 .48276 .71937 .47815 .7144 .47187 Mtetra
.578 .712 .934 r
.7144 .47187 .71937 .47815 .73013 .47473 .72531 .47041 Mtetra
.57 .79 .982 r
.72531 .47041 .73013 .47473 .74097 .47177 .73624 .46843 Mtetra
.574 .838 .995 r
.73624 .46843 .74097 .47177 .75187 .46906 .74719 .46586 Mtetra
.606 .858 .991 r
.74719 .46586 .75187 .46906 .76281 .46634 .75814 .4627 Mtetra
.635 .849 .982 r
.75814 .4627 .76281 .46634 .7738 .46364 .76911 .45924 Mtetra
.64 .818 .968 r
.76911 .45924 .7738 .46364 .78484 .46102 .78013 .45593 Mtetra
.641 .789 .953 r
.78013 .45593 .78484 .46102 .79593 .45841 .79122 .45276 Mtetra
.639 .766 .94 r
.79122 .45276 .79593 .45841 .80707 .45575 .80235 .44972 Mtetra
.637 .752 .932 r
.80235 .44972 .80707 .45575 .81825 .45303 .81355 .44679 Mtetra
.635 .744 .927 r
.81355 .44679 .81825 .45303 .82947 .45027 .82479 .44391 Mtetra
.635 .741 .925 r
.82479 .44391 .82947 .45027 .84074 .44744 .83609 .44103 Mtetra
.636 .74 .924 r
.83609 .44103 .84074 .44744 .85205 .44453 .84743 .4381 Mtetra
.639 .742 .923 r
.84743 .4381 .85205 .44453 .8634 .44153 .85881 .43509 Mtetra
.643 .744 .922 r
.85881 .43509 .8634 .44153 .87478 .4384 .87022 .43195 Mtetra
.647 .746 .922 r
.87022 .43195 .87478 .4384 .8862 .43516 .88167 .42871 Mtetra
.649 .748 .922 r
.88167 .42871 .8862 .43516 .89765 .43184 .89316 .42538 Mtetra
.652 .749 .921 r
.89316 .42538 .89765 .43184 .90915 .42846 .90469 .42197 Mtetra
.66 .752 .919 r
.28853 .60308 .29453 .60833 .30382 .60538 .29784 .60014 Mtetra
.662 .754 .918 r
.29784 .60014 .30382 .60538 .31315 .60237 .30718 .59713 Mtetra
.665 .755 .917 r
.30718 .59713 .31315 .60237 .32252 .59928 .31657 .59404 Mtetra
.669 .756 .916 r
.31657 .59404 .32252 .59928 .33192 .5961 .32599 .59082 Mtetra
.675 .758 .913 r
.32599 .59082 .33192 .5961 .34135 .59279 .33545 .58746 Mtetra
.678 .757 .911 r
.33545 .58746 .34135 .59279 .35083 .5894 .34495 .584 Mtetra
.681 .756 .908 r
.34495 .584 .35083 .5894 .36033 .58596 .35448 .58044 Mtetra
.68 .752 .906 r
.35448 .58044 .36033 .58596 .36987 .58253 .36404 .5769 Mtetra
.677 .748 .905 r
.36404 .5769 .36987 .58253 .37943 .57915 .37363 .57345 Mtetra
.667 .744 .907 r
.37363 .57345 .37943 .57915 .38902 .57586 .38324 .57022 Mtetra
.652 .742 .916 r
.38324 .57022 .38902 .57586 .39864 .57272 .39286 .56735 Mtetra
.634 .748 .931 r
.39286 .56735 .39864 .57272 .40829 .5697 .40251 .56488 Mtetra
.604 .762 .954 r
.40251 .56488 .40829 .5697 .41796 .56684 .41218 .56287 Mtetra
.605 .799 .974 r
.41218 .56287 .41796 .56684 .42768 .56368 .4219 .56059 Mtetra
.631 .846 .982 r
.4219 .56059 .42768 .56368 .43745 .55994 .43168 .55757 Mtetra
.687 .889 .972 r
.43168 .55757 .43745 .55994 .44726 .55564 .44152 .55333 Mtetra
.756 .899 .941 r
.44152 .55333 .44726 .55564 .45711 .55082 .45143 .54759 Mtetra
.763 .862 .922 r
.45143 .54759 .45711 .55082 .46697 .54684 .46135 .54167 Mtetra
.731 .784 .895 r
.46135 .54167 .46697 .54684 .47684 .54451 .47129 .53651 Mtetra
.641 .671 .863 r
.47129 .53651 .47684 .54451 .48673 .54383 .48122 .53384 Mtetra
.516 .566 .845 r
.48122 .53384 .48673 .54383 .49665 .54477 .49114 .53472 Mtetra
.319 .455 .841 r
.49114 .53472 .49665 .54477 .50663 .54662 .50111 .53945 Mtetra
0 .282 .782 r
.50111 .53945 .50663 .54662 .51668 .54824 .51114 .54685 Mtetra
0 .459 .719 r
.51114 .54685 .51668 .54824 .52679 .54532 .52128 .54905 Mtetra
0 0 0 r
.52128 .54905 .52679 .54532 .53691 .53727 .53147 .54294 Mtetra
.636 .882 .538 r
.53147 .54294 .53691 .53727 .54706 .53043 .54165 .53063 Mtetra
.944 .927 .758 r
.54165 .53063 .54706 .53043 .55725 .52722 .55179 .51466 Mtetra
.766 .647 .73 r
.55179 .51466 .55725 .52722 .56754 .52884 .56193 .50305 Mtetra
.628 .487 .671 r
.56193 .50305 .56754 .52884 .57795 .53333 .57215 .49788 Mtetra
.594 .439 .641 r
.57215 .49788 .57795 .53333 .58829 .53019 .58243 .49469 Mtetra
.576 .426 .641 r
.58243 .49469 .58829 .53019 .59851 .5194 .59279 .4935 Mtetra
.487 .394 .676 r
.59279 .4935 .59851 .5194 .60879 .51147 .60335 .49877 Mtetra
.159 .301 .76 r
.60335 .49877 .60879 .51147 .61922 .50838 .61412 .50846 Mtetra
.559 0 0 r
.61412 .50846 .61922 .50838 .6298 .50895 .62491 .51452 Mtetra
.389 0 0 r
.62491 .51452 .6298 .50895 .64049 .51076 .63559 .51434 Mtetra
.501 .854 .599 r
.63559 .51434 .64049 .51076 .65105 .50739 .64602 .50577 Mtetra
.921 .917 .796 r
.64602 .50577 .65105 .50739 .66147 .49941 .65625 .4919 Mtetra
.82 .751 .788 r
.65625 .4919 .66147 .49941 .67188 .4912 .66657 .48071 Mtetra
.729 .665 .786 r
.66657 .48071 .67188 .4912 .68234 .48387 .67705 .4734 Mtetra
.657 .634 .815 r
.67705 .4734 .68234 .48387 .69291 .4782 .68773 .46969 Mtetra
.583 .643 .876 r
.68773 .46969 .69291 .4782 .70358 .47419 .69858 .46853 Mtetra
.508 .705 .959 r
.69858 .46853 .70358 .47419 .7144 .47187 .70953 .46815 Mtetra
.442 .76 .996 r
.70953 .46815 .7144 .47187 .72531 .47041 .72053 .4676 Mtetra
.514 .836 .999 r
.72053 .4676 .72531 .47041 .73624 .46843 .7315 .46551 Mtetra
.607 .87 .992 r
.7315 .46551 .73624 .46843 .74719 .46586 .74243 .46217 Mtetra
.669 .858 .972 r
.74243 .46217 .74719 .46586 .75814 .4627 .75336 .45806 Mtetra
.69 .824 .947 r
.75336 .45806 .75814 .4627 .76911 .45924 .7643 .45368 Mtetra
.674 .783 .931 r
.7643 .45368 .76911 .45924 .78013 .45593 .77531 .44977 Mtetra
.66 .756 .921 r
.77531 .44977 .78013 .45593 .79122 .45276 .7864 .44626 Mtetra
.646 .739 .917 r
.7864 .44626 .79122 .45276 .80235 .44972 .79756 .44312 Mtetra
.637 .733 .918 r
.79756 .44312 .80235 .44972 .81355 .44679 .80879 .44022 Mtetra
.632 .733 .92 r
.80879 .44022 .81355 .44679 .82479 .44391 .82007 .43741 Mtetra
.631 .736 .923 r
.82007 .43741 .82479 .44391 .83609 .44103 .83141 .43461 Mtetra
.634 .741 .925 r
.83141 .43461 .83609 .44103 .84743 .4381 .84278 .43171 Mtetra
.637 .744 .926 r
.84278 .43171 .84743 .4381 .85881 .43509 .8542 .42871 Mtetra
.643 .748 .925 r
.8542 .42871 .85881 .43509 .87022 .43195 .86564 .42555 Mtetra
.647 .75 .924 r
.86564 .42555 .87022 .43195 .88167 .42871 .87713 .42227 Mtetra
.65 .751 .923 r
.87713 .42227 .88167 .42871 .89316 .42538 .88865 .41889 Mtetra
.652 .751 .922 r
.88865 .41889 .89316 .42538 .90469 .42197 .90021 .41544 Mtetra
.656 .752 .92 r
.28248 .59781 .28853 .60308 .29784 .60014 .2918 .59492 Mtetra
.659 .755 .921 r
.2918 .59492 .29784 .60014 .30718 .59713 .30117 .59197 Mtetra
.662 .758 .922 r
.30117 .59197 .30718 .59713 .31657 .59404 .31057 .58892 Mtetra
.667 .762 .921 r
.31057 .58892 .31657 .59404 .32599 .59082 .32001 .58573 Mtetra
.675 .765 .919 r
.32001 .58573 .32599 .59082 .33545 .58746 .32949 .58235 Mtetra
.681 .767 .916 r
.32949 .58235 .33545 .58746 .34495 .584 .33901 .57879 Mtetra
.688 .766 .911 r
.33901 .57879 .34495 .584 .35448 .58044 .34858 .57504 Mtetra
.69 .76 .905 r
.34858 .57504 .35448 .58044 .36404 .5769 .35817 .57122 Mtetra
.689 .75 .899 r
.35817 .57122 .36404 .5769 .37363 .57345 .3678 .56741 Mtetra
.677 .736 .895 r
.3678 .56741 .37363 .57345 .38324 .57022 .37744 .56388 Mtetra
.657 .721 .896 r
.37744 .56388 .38324 .57022 .39286 .56735 .38709 .56089 Mtetra
.628 .708 .904 r
.38709 .56089 .39286 .56735 .40251 .56488 .39675 .55863 Mtetra
.581 .7 .924 r
.39675 .55863 .40251 .56488 .41218 .56287 .40641 .55734 Mtetra
.56 .72 .948 r
.40641 .55734 .41218 .56287 .4219 .56059 .41611 .55624 Mtetra
.555 .768 .977 r
.41611 .55624 .4219 .56059 .43168 .55757 .42587 .55481 Mtetra
.61 .856 .99 r
.42587 .55481 .43168 .55757 .44152 .55333 .43571 .55194 Mtetra
.709 .931 .963 r
.43571 .55194 .44152 .55333 .45143 .54759 .44564 .54683 Mtetra
.782 .958 .926 r
.44564 .54683 .45143 .54759 .46135 .54167 .45563 .53989 Mtetra
.831 .917 .894 r
.45563 .53989 .46135 .54167 .47129 .53651 .46565 .53164 Mtetra
.762 .801 .884 r
.46565 .53164 .47129 .53651 .48122 .53384 .47566 .5254 Mtetra
.622 .653 .86 r
.47566 .5254 .48122 .53384 .49114 .53472 .48563 .52327 Mtetra
.375 .458 .818 r
.48563 .52327 .49114 .53472 .50111 .53945 .49559 .52765 Mtetra
.012 .22 .729 r
.49559 .52765 .50111 .53945 .51114 .54685 .50559 .53815 Mtetra
.068 .339 .816 r
.50559 .53815 .51114 .54685 .52128 .54905 .51572 .54529 Mtetra
.524 .789 .993 r
.51572 .54529 .52128 .54905 .53147 .54294 .52595 .54388 Mtetra
.931 .957 .773 r
.52595 .54388 .53147 .54294 .54165 .53063 .53619 .5293 Mtetra
.962 .831 .667 r
.53619 .5293 .54165 .53063 .55179 .51466 .54632 .50317 Mtetra
.858 .691 .674 r
.54632 .50317 .55179 .51466 .56193 .50305 .55637 .47957 Mtetra
.724 .556 .662 r
.55637 .47957 .56193 .50305 .57215 .49788 .56644 .46453 Mtetra
.596 .444 .645 r
.56644 .46453 .57215 .49788 .58243 .49469 .57665 .4613 Mtetra
.459 .35 .643 r
.57665 .4613 .58243 .49469 .59279 .4935 .58713 .4699 Mtetra
.18 .199 .643 r
.58713 .4699 .59279 .4935 .60335 .49877 .59792 .48715 Mtetra
0 0 .438 r
.59792 .48715 .60335 .49877 .61412 .50846 .60894 .50701 Mtetra
.608 .039 0 r
.60894 .50701 .61412 .50846 .62491 .51452 .61982 .51532 Mtetra
.493 .904 .84 r
.61982 .51532 .62491 .51452 .63559 .51434 .63039 .51036 Mtetra
.892 .847 .792 r
.63039 .51036 .63559 .51434 .64602 .50577 .64069 .49674 Mtetra
.855 .728 .723 r
.64069 .49674 .64602 .50577 .65625 .4919 .65083 .47969 Mtetra
.764 .655 .742 r
.65083 .47969 .65625 .4919 .66657 .48071 .66118 .4688 Mtetra
.663 .613 .788 r
.66118 .4688 .66657 .48071 .67705 .4734 .67181 .46449 Mtetra
.544 .614 .873 r
.67181 .46449 .67705 .4734 .68773 .46969 .68268 .46438 Mtetra
.325 .625 .959 r
.68268 .46438 .68773 .46969 .69858 .46853 .69372 .46633 Mtetra
.195 .681 .927 r
.69372 .46633 .69858 .46853 .70953 .46815 .70477 .46695 Mtetra
.294 .775 .919 r
.70477 .46695 .70953 .46815 .72053 .4676 .71577 .46571 Mtetra
.57 .898 .984 r
.71577 .46571 .72053 .4676 .7315 .46551 .72669 .46219 Mtetra
.706 .884 .963 r
.72669 .46219 .7315 .46551 .74243 .46217 .73756 .45717 Mtetra
.726 .82 .923 r
.73756 .45717 .74243 .46217 .75336 .45806 .74843 .45181 Mtetra
.716 .772 .897 r
.74843 .45181 .75336 .45806 .7643 .45368 .75935 .44664 Mtetra
.682 .735 .891 r
.75935 .44664 .7643 .45368 .77531 .44977 .77037 .44246 Mtetra
.656 .718 .894 r
.77037 .44246 .77531 .44977 .7864 .44626 .7815 .43903 Mtetra
.637 .713 .902 r
.7815 .43903 .7864 .44626 .79756 .44312 .79271 .43616 Mtetra
.624 .717 .913 r
.79271 .43616 .79756 .44312 .80879 .44022 .80399 .43358 Mtetra
.622 .728 .922 r
.80399 .43358 .80879 .44022 .82007 .43741 .81533 .43101 Mtetra
.623 .738 .929 r
.81533 .43101 .82007 .43741 .83141 .43461 .82671 .42838 Mtetra
.63 .747 .932 r
.82671 .42838 .83141 .43461 .84278 .43171 .83813 .42553 Mtetra
.636 .753 .933 r
.83813 .42553 .84278 .43171 .8542 .42871 .84957 .42251 Mtetra
.644 .756 .931 r
.84957 .42251 .8542 .42871 .86564 .42555 .86105 .41928 Mtetra
.649 .757 .928 r
.86105 .41928 .86564 .42555 .87713 .42227 .87256 .4159 Mtetra
.653 .756 .925 r
.87256 .4159 .87713 .42227 .88865 .41889 .8841 .41242 Mtetra
.655 .754 .922 r
.8841 .41242 .88865 .41889 .90021 .41544 .89569 .40886 Mtetra
.652 .75 .922 r
.27639 .59249 .28248 .59781 .2918 .59492 .28573 .5897 Mtetra
.653 .755 .925 r
.28573 .5897 .2918 .59492 .30117 .59197 .2951 .58686 Mtetra
.656 .761 .927 r
.2951 .58686 .30117 .59197 .31057 .58892 .30452 .58393 Mtetra
.662 .767 .928 r
.30452 .58393 .31057 .58892 .32001 .58573 .31397 .58085 Mtetra
.67 .774 .928 r
.31397 .58085 .32001 .58573 .32949 .58235 .32347 .57757 Mtetra
.679 .78 .926 r
.32347 .57757 .32949 .58235 .33901 .57879 .33301 .57403 Mtetra
.691 .784 .922 r
.33301 .57403 .33901 .57879 .34858 .57504 .34261 .57019 Mtetra
.699 .783 .916 r
.34261 .57019 .34858 .57504 .35817 .57122 .35224 .56613 Mtetra
.705 .776 .907 r
.35224 .56613 .35817 .57122 .3678 .56741 .36191 .56188 Mtetra
.697 .759 .9 r
.36191 .56188 .3678 .56741 .37744 .56388 .37159 .5578 Mtetra
.68 .737 .894 r
.37159 .5578 .37744 .56388 .38709 .56089 .38129 .55417 Mtetra
.646 .707 .892 r
.38129 .55417 .38709 .56089 .39675 .55863 .39098 .55144 Mtetra
.592 .674 .897 r
.39098 .55144 .39675 .55863 .40641 .55734 .40066 .55004 Mtetra
.55 .654 .904 r
.40066 .55004 .40641 .55734 .41611 .55624 .41036 .54954 Mtetra
.504 .655 .927 r
.41036 .54954 .41611 .55624 .42587 .55481 .42008 .54969 Mtetra
.523 .725 .966 r
.42008 .54969 .42587 .55481 .43571 .55194 .42988 .54898 Mtetra
.6 .846 .991 r
.42988 .54898 .43571 .55194 .44564 .54683 .43979 .54628 Mtetra
.723 .961 .943 r
.43979 .54628 .44564 .54683 .45563 .53989 .4498 .5404 Mtetra
.847 .982 .865 r
.4498 .5404 .45563 .53989 .46565 .53164 .4599 .53088 Mtetra
.859 .946 .873 r
.4599 .53088 .46565 .53164 .47566 .5254 .47 .52134 Mtetra
.79 .835 .887 r
.47 .52134 .47566 .5254 .48563 .52327 .48006 .51424 Mtetra
.543 .604 .865 r
.48006 .51424 .48563 .52327 .49559 .52765 .49007 .5142 Mtetra
.234 .336 .764 r
.49007 .5142 .49559 .52765 .50559 .53815 .50007 .52234 Mtetra
.261 .32 .735 r
.50007 .52234 .50559 .53815 .51572 .54529 .51017 .53141 Mtetra
.404 .437 .781 r
.51017 .53141 .51572 .54529 .52595 .54388 .52039 .53617 Mtetra
.8 .734 .791 r
.52039 .53617 .52595 .54388 .53619 .5293 .53067 .52601 Mtetra
.943 .803 .675 r
.53067 .52601 .53619 .5293 .54632 .50317 .54087 .50045 Mtetra
.951 .811 .668 r
.54087 .50045 .54632 .50317 .55637 .47957 .55097 .47424 Mtetra
.905 .786 .718 r
.55097 .47424 .55637 .47957 .56644 .46453 .56104 .45498 Mtetra
.651 .644 .83 r
.56104 .45498 .56644 .46453 .57665 .4613 .57127 .45172 Mtetra
0 .064 .627 r
.57127 .45172 .57665 .4613 .58713 .4699 .58182 .46451 Mtetra
.817 .36 0 r
.58182 .46451 .58713 .4699 .59792 .48715 .59265 .48433 Mtetra
.845 .381 .029 r
.59265 .48433 .59792 .48715 .60894 .50701 .60365 .50359 Mtetra
0 .457 .833 r
.60365 .50359 .60894 .50701 .61982 .51532 .61443 .50739 Mtetra
.814 .741 .783 r
.61443 .50739 .61982 .51532 .63039 .51036 .62484 .49615 Mtetra
.791 .647 .703 r
.62484 .49615 .63039 .51036 .64069 .49674 .63509 .48053 Mtetra
.767 .619 .696 r
.63509 .48053 .64069 .49674 .65083 .47969 .64533 .46581 Mtetra
.69 .601 .752 r
.64533 .46581 .65083 .47969 .66118 .4688 .65587 .45934 Mtetra
.515 .586 .865 r
.65587 .45934 .66118 .4688 .67181 .46449 .66674 .46004 Mtetra
.139 .549 .924 r
.66674 .46004 .67181 .46449 .68268 .46438 .6778 .46325 Mtetra
.225 0 0 r
.6778 .46325 .68268 .46438 .69372 .46633 .68894 .46645 Mtetra
.042 .611 .72 r
.68894 .46645 .69372 .46633 .70477 .46695 .69997 .46597 Mtetra
.524 .905 .951 r
.69997 .46597 .70477 .46695 .71577 .46571 .71087 .46222 Mtetra
.739 .884 .947 r
.71087 .46222 .71577 .46571 .72669 .46219 .7217 .45644 Mtetra
.761 .802 .886 r
.7217 .45644 .72669 .46219 .73756 .45717 .73249 .44975 Mtetra
.73 .741 .86 r
.73249 .44975 .73756 .45717 .74843 .45181 .74335 .44373 Mtetra
.702 .714 .857 r
.74335 .44373 .74843 .45181 .75935 .44664 .7543 .43862 Mtetra
.665 .701 .874 r
.7543 .43862 .75935 .44664 .77037 .44246 .76539 .43487 Mtetra
.634 .701 .894 r
.76539 .43487 .77037 .44246 .7815 .43903 .77658 .43206 Mtetra
.615 .713 .915 r
.77658 .43206 .7815 .43903 .79271 .43616 .78787 .42971 Mtetra
.603 .727 .932 r
.78787 .42971 .79271 .43616 .80399 .43358 .79922 .42755 Mtetra
.608 .745 .942 r
.79922 .42755 .80399 .43358 .81533 .43101 .81061 .42519 Mtetra
.615 .757 .947 r
.81061 .42519 .81533 .43101 .82671 .42838 .82203 .4226 Mtetra
.628 .766 .946 r
.82203 .4226 .82671 .42838 .83813 .42553 .83347 .41969 Mtetra
.638 .769 .942 r
.83347 .41969 .83813 .42553 .84957 .42251 .84494 .41652 Mtetra
.648 .768 .936 r
.84494 .41652 .84957 .42251 .86105 .41928 .85644 .41313 Mtetra
.654 .765 .931 r
.85644 .41313 .86105 .41928 .87256 .4159 .86797 .40958 Mtetra
.658 .761 .926 r
.86797 .40958 .87256 .4159 .8841 .41242 .87953 .40593 Mtetra
.659 .757 .922 r
.87953 .40593 .8841 .41242 .89569 .40886 .89113 .40224 Mtetra
.646 .749 .924 r
.27027 .58715 .27639 .59249 .28573 .5897 .27961 .58447 Mtetra
.645 .754 .928 r
.27961 .58447 .28573 .5897 .2951 .58686 .28899 .58178 Mtetra
.647 .761 .932 r
.28899 .58178 .2951 .58686 .30452 .58393 .29841 .57904 Mtetra
.651 .769 .936 r
.29841 .57904 .30452 .58393 .31397 .58085 .30788 .57616 Mtetra
.658 .78 .939 r
.30788 .57616 .31397 .58085 .32347 .57757 .31738 .57311 Mtetra
.669 .792 .94 r
.31738 .57311 .32347 .57757 .33301 .57403 .32694 .56977 Mtetra
.685 .804 .938 r
.32694 .56977 .33301 .57403 .34261 .57019 .33655 .56604 Mtetra
.701 .812 .934 r
.33655 .56604 .34261 .57019 .35224 .56613 .34621 .56192 Mtetra
.718 .813 .924 r
.34621 .56192 .35224 .56613 .36191 .56188 .35592 .55733 Mtetra
.722 .801 .913 r
.35592 .55733 .36191 .56188 .37159 .5578 .36567 .55258 Mtetra
.718 .777 .899 r
.36567 .55258 .37159 .5578 .38129 .55417 .37544 .54787 Mtetra
.689 .735 .886 r
.37544 .54787 .38129 .55417 .39098 .55144 .3852 .54392 Mtetra
.64 .683 .875 r
.3852 .54392 .39098 .55144 .40066 .55004 .39494 .54129 Mtetra
.579 .627 .863 r
.39494 .54129 .40066 .55004 .41036 .54954 .40466 .54034 Mtetra
.494 .575 .866 r
.40466 .54034 .41036 .54954 .42008 .54969 .41436 .54137 Mtetra
.447 .577 .89 r
.41436 .54137 .42008 .54969 .42988 .54898 .4241 .54298 Mtetra
.411 .641 .951 r
.4241 .54298 .42988 .54898 .43979 .54628 .43392 .54411 Mtetra
.546 .862 .996 r
.43392 .54411 .43979 .54628 .4498 .5404 .44389 .54162 Mtetra
.752 .993 .868 r
.44389 .54162 .4498 .5404 .4599 .53088 .45401 .53376 Mtetra
.823 .997 .77 r
.45401 .53376 .4599 .53088 .47 .52134 .4642 .52256 Mtetra
.907 .973 .8 r
.4642 .52256 .47 .52134 .48006 .51424 .4744 .50981 Mtetra
.804 .823 .866 r
.4744 .50981 .48006 .51424 .49007 .5142 .48452 .50186 Mtetra
.561 .549 .798 r
.48452 .50186 .49007 .5142 .50007 .52234 .49458 .50167 Mtetra
.42 .377 .705 r
.49458 .50167 .50007 .52234 .51017 .53141 .50466 .50825 Mtetra
.342 .31 .678 r
.50466 .50825 .51017 .53141 .52039 .53617 .51482 .5188 Mtetra
.539 .48 .738 r
.51482 .5188 .52039 .53617 .53067 .52601 .5251 .51983 Mtetra
.84 .776 .791 r
.5251 .51983 .53067 .52601 .54087 .50045 .53541 .50801 Mtetra
.694 .865 .463 r
.53541 .50801 .54087 .50045 .55097 .47424 .54567 .49163 Mtetra
.033 0 .14 r
.54567 .49163 .55097 .47424 .56104 .45498 .5559 .47623 Mtetra
.463 .152 .351 r
.5559 .47623 .56104 .45498 .57127 .45172 .56624 .47297 Mtetra
.634 .309 .403 r
.56624 .47297 .57127 .45172 .58182 .46451 .57682 .48189 Mtetra
.656 .313 .38 r
.57682 .48189 .58182 .46451 .59265 .48433 .58753 .49184 Mtetra
.613 .179 .193 r
.58753 .49184 .59265 .48433 .60365 .50359 .59826 .49725 Mtetra
.775 .774 .852 r
.59826 .49725 .60365 .50359 .61443 .50739 .60877 .48973 Mtetra
.775 .614 .68 r
.60877 .48973 .61443 .50739 .62484 .49615 .61901 .47258 Mtetra
.71 .548 .668 r
.61901 .47258 .62484 .49615 .63509 .48053 .62933 .4594 Mtetra
.653 .525 .695 r
.62933 .4594 .63509 .48053 .64533 .46581 .63986 .45304 Mtetra
.511 .52 .802 r
.63986 .45304 .64533 .46581 .65587 .45934 .65072 .45455 Mtetra
0 .318 .776 r
.65072 .45455 .65587 .45934 .66674 .46004 .66185 .46096 Mtetra
.505 0 0 r
.66185 .46096 .66674 .46004 .6778 .46325 .67302 .46582 Mtetra
.364 0 0 r
.67302 .46582 .6778 .46325 .68894 .46645 .68413 .46731 Mtetra
.356 .827 .787 r
.68413 .46731 .68894 .46645 .69997 .46597 .69503 .46331 Mtetra
.801 .925 .918 r
.69503 .46331 .69997 .46597 .71087 .46222 .70576 .45561 Mtetra
.786 .78 .847 r
.70576 .45561 .71087 .46222 .7217 .45644 .71648 .44739 Mtetra
.749 .708 .813 r
.71648 .44739 .7217 .45644 .73249 .44975 .72724 .43975 Mtetra
.7 .669 .816 r
.72724 .43975 .73249 .44975 .74335 .44373 .73815 .43415 Mtetra
.662 .662 .839 r
.73815 .43415 .74335 .44373 .7543 .43862 .7492 .43025 Mtetra
.625 .675 .878 r
.7492 .43025 .7543 .43862 .76539 .43487 .7604 .42773 Mtetra
.591 .697 .917 r
.7604 .42773 .76539 .43487 .77658 .43206 .77171 .42598 Mtetra
.577 .73 .947 r
.77171 .42598 .77658 .43206 .78787 .42971 .78308 .42428 Mtetra
.574 .756 .964 r
.78308 .42428 .78787 .42971 .79922 .42755 .79449 .42243 Mtetra
.593 .778 .968 r
.79449 .42243 .79922 .42755 .81061 .42519 .80592 .42009 Mtetra
.612 .788 .966 r
.80592 .42009 .81061 .42519 .82203 .4226 .81736 .41733 Mtetra
.632 .79 .958 r
.81736 .41733 .82203 .4226 .83347 .41969 .82882 .41417 Mtetra
.647 .787 .949 r
.82882 .41417 .83347 .41969 .84494 .41652 .8403 .41072 Mtetra
.656 .78 .94 r
.8403 .41072 .84494 .41652 .85644 .41313 .85181 .40707 Mtetra
.662 .773 .932 r
.85181 .40707 .85644 .41313 .86797 .40958 .86335 .40329 Mtetra
.664 .766 .926 r
.86335 .40329 .86797 .40958 .87953 .40593 .87493 .39943 Mtetra
.664 .76 .921 r
.87493 .39943 .87953 .40593 .89113 .40224 .88655 .39556 Mtetra
.642 .748 .926 r
.2641 .58177 .27027 .58715 .27961 .58447 .27346 .57914 Mtetra
.64 .75 .929 r
.27346 .57914 .27961 .58447 .28899 .58178 .28285 .57655 Mtetra
.639 .754 .932 r
.28285 .57655 .28899 .58178 .29841 .57904 .29228 .57395 Mtetra
.641 .761 .935 r
.29228 .57395 .29841 .57904 .30788 .57616 .30175 .57128 Mtetra
.643 .77 .94 r
.30175 .57128 .30788 .57616 .31738 .57311 .31126 .56854 Mtetra
.651 .785 .946 r
.31126 .56854 .31738 .57311 .32694 .56977 .32082 .56557 Mtetra
.664 .804 .95 r
.32082 .56557 .32694 .56977 .33655 .56604 .33043 .56226 Mtetra
.684 .825 .951 r
.33043 .56226 .33655 .56604 .34621 .56192 .3401 .55847 Mtetra
.711 .844 .946 r
.3401 .55847 .34621 .56192 .35592 .55733 .34983 .55403 Mtetra
.732 .853 .938 r
.34983 .55403 .35592 .55733 .36567 .55258 .35962 .54905 Mtetra
.751 .845 .922 r
.35962 .54905 .36567 .55258 .37544 .54787 .36946 .5435 Mtetra
.741 .813 .908 r
.36946 .5435 .37544 .54787 .3852 .54392 .3793 .53815 Mtetra
.712 .759 .89 r
.3793 .53815 .3852 .54392 .39494 .54129 .38915 .53351 Mtetra
.645 .68 .868 r
.38915 .53351 .39494 .54129 .40466 .54034 .39894 .5307 Mtetra
.548 .593 .85 r
.39894 .5307 .40466 .54034 .41436 .54137 .40869 .53058 Mtetra
.466 .525 .835 r
.40869 .53058 .41436 .54137 .4241 .54298 .41842 .53261 Mtetra
.369 .482 .843 r
.41842 .53261 .4241 .54298 .43392 .54411 .42816 .53635 Mtetra
.426 .586 .907 r
.42816 .53635 .43392 .54411 .44389 .54162 .43804 .53803 Mtetra
.617 .828 .981 r
.43804 .53803 .44389 .54162 .45401 .53376 .44808 .53524 Mtetra
.762 .996 .852 r
.44808 .53524 .45401 .53376 .4642 .52256 .45827 .52687 Mtetra
.851 .982 .694 r
.45827 .52687 .4642 .52256 .4744 .50981 .46857 .51288 Mtetra
.89 .988 .742 r
.46857 .51288 .4744 .50981 .48452 .50186 .47883 .49907 Mtetra
.857 .879 .854 r
.47883 .49907 .48452 .50186 .49458 .50167 .48902 .48912 Mtetra
.582 .558 .793 r
.48902 .48912 .49458 .50167 .50466 .50825 .49914 .48819 Mtetra
.347 .334 .703 r
.49914 .48819 .50466 .50825 .51482 .5188 .50927 .49704 Mtetra
.363 .333 .692 r
.50927 .49704 .51482 .5188 .5251 .51983 .51951 .50613 Mtetra
.378 .426 .784 r
.51951 .50613 .5251 .51983 .53541 .50801 .52986 .51136 Mtetra
.287 0 0 r
.52986 .51136 .53541 .50801 .54567 .49163 .54027 .5112 Mtetra
.412 .095 .315 r
.54027 .5112 .54567 .49163 .5559 .47623 .55071 .50616 Mtetra
.489 .202 .404 r
.55071 .50616 .5559 .47623 .56624 .47297 .56119 .50291 Mtetra
.512 .222 .411 r
.56119 .50291 .56624 .47297 .57682 .48189 .57174 .50147 Mtetra
.384 .07 .305 r
.57174 .50147 .57682 .48189 .58753 .49184 .58225 .49512 Mtetra
.767 .974 .699 r
.58225 .49512 .58753 .49184 .59826 .49725 .59268 .48334 Mtetra
.794 .651 .704 r
.59268 .48334 .59826 .49725 .60877 .48973 .603 .46763 Mtetra
.735 .57 .668 r
.603 .46763 .60877 .48973 .61901 .47258 .61328 .45213 Mtetra
.647 .524 .7 r
.61328 .45213 .61901 .47258 .62933 .4594 .62382 .44647 Mtetra
.443 .478 .801 r
.62382 .44647 .62933 .4594 .63986 .45304 .6347 .44995 Mtetra
.426 0 0 r
.6347 .44995 .63986 .45304 .65072 .45455 .6458 .45737 Mtetra
.655 .141 .008 r
.6458 .45737 .65072 .45455 .66185 .46096 .65703 .46501 Mtetra
.447 0 0 r
.65703 .46501 .66185 .46096 .67302 .46582 .66813 .46697 Mtetra
.294 .785 .742 r
.66813 .46697 .67302 .46582 .68413 .46731 .67904 .46325 Mtetra
.813 .87 .889 r
.67904 .46325 .68413 .46731 .69503 .46331 .68976 .45494 Mtetra
.801 .738 .794 r
.68976 .45494 .69503 .46331 .70576 .45561 .70037 .44452 Mtetra
.746 .67 .775 r
.70037 .44452 .70576 .45561 .71648 .44739 .71108 .43582 Mtetra
.706 .645 .786 r
.71108 .43582 .71648 .44739 .72724 .43975 .72193 .42931 Mtetra
.655 .641 .824 r
.72193 .42931 .72724 .43975 .73815 .43415 .73298 .42556 Mtetra
.602 .659 .878 r
.73298 .42556 .73815 .43415 .7492 .43025 .7442 .42368 Mtetra
.556 .702 .938 r
.7442 .42368 .7492 .43025 .7604 .42773 .75553 .42256 Mtetra
.515 .74 .976 r
.75553 .42256 .7604 .42773 .77171 .42598 .76693 .42164 Mtetra
.523 .781 .991 r
.76693 .42164 .77171 .42598 .78308 .42428 .77835 .42014 Mtetra
.551 .803 .992 r
.77835 .42014 .78308 .42428 .79449 .42243 .78979 .41809 Mtetra
.595 .814 .984 r
.78979 .41809 .79449 .42243 .80592 .42009 .80122 .41536 Mtetra
.628 .812 .97 r
.80122 .41536 .80592 .42009 .81736 .41733 .81266 .41212 Mtetra
.649 .801 .955 r
.81266 .41212 .81736 .41733 .82882 .41417 .82412 .40854 Mtetra
.662 .789 .942 r
.82412 .40854 .82882 .41417 .8403 .41072 .8356 .40471 Mtetra
.666 .778 .933 r
.8356 .40471 .8403 .41072 .85181 .40707 .84712 .40079 Mtetra
.668 .77 .926 r
.84712 .40079 .85181 .40707 .86335 .40329 .85868 .39681 Mtetra
.669 .764 .921 r
.85868 .39681 .86335 .40329 .87493 .39943 .87028 .39281 Mtetra
.667 .759 .919 r
.87028 .39281 .87493 .39943 .88655 .39556 .88193 .38884 Mtetra
.643 .748 .925 r
.25789 .57635 .2641 .58177 .27346 .57914 .26727 .57368 Mtetra
.64 .746 .926 r
.26727 .57368 .27346 .57914 .28285 .57655 .27669 .57106 Mtetra
.638 .746 .927 r
.27669 .57106 .28285 .57655 .29228 .57395 .28613 .5685 Mtetra
.635 .747 .929 r
.28613 .5685 .29228 .57395 .30175 .57128 .29561 .56599 Mtetra
.63 .752 .935 r
.29561 .56599 .30175 .57128 .31126 .56854 .30512 .56355 Mtetra
.63 .765 .944 r
.30512 .56355 .31126 .56854 .32082 .56557 .31467 .56104 Mtetra
.632 .784 .955 r
.31467 .56104 .32082 .56557 .33043 .56226 .32426 .55842 Mtetra
.645 .816 .966 r
.32426 .55842 .33043 .56226 .3401 .55847 .33391 .55538 Mtetra
.669 .854 .97 r
.33391 .55538 .3401 .55847 .34983 .55403 .34364 .55171 Mtetra
.703 .891 .966 r
.34364 .55171 .34983 .55403 .35962 .54905 .35343 .54716 Mtetra
.751 .912 .947 r
.35343 .54716 .35962 .54905 .36946 .5435 .36332 .54145 Mtetra
.779 .906 .929 r
.36332 .54145 .36946 .5435 .3793 .53815 .37325 .53502 Mtetra
.791 .864 .903 r
.37325 .53502 .3793 .53815 .38915 .53351 .38322 .52813 Mtetra
.746 .78 .881 r
.38322 .52813 .38915 .53351 .39894 .5307 .39316 .52235 Mtetra
.663 .673 .849 r
.39316 .52235 .39894 .5307 .40869 .53058 .40303 .51887 Mtetra
.559 .558 .809 r
.40303 .51887 .40869 .53058 .41842 .53261 .41283 .51865 Mtetra
.434 .453 .78 r
.41283 .51865 .41842 .53261 .42816 .53635 .42256 .52236 Mtetra
.377 .419 .777 r
.42256 .52236 .42816 .53635 .43804 .53803 .43233 .52746 Mtetra
.326 .454 .837 r
.43233 .52746 .43804 .53803 .44808 .53524 .4422 .53199 Mtetra
.456 .785 .999 r
.4422 .53199 .44808 .53524 .45827 .52687 .45227 .53104 Mtetra
.584 .905 .65 r
.45227 .53104 .45827 .52687 .46857 .51288 .46255 .52204 Mtetra
0 0 0 r
.46255 .52204 .46857 .51288 .47883 .49907 .47291 .50733 Mtetra
.753 .89 .486 r
.47291 .50733 .47883 .49907 .48902 .48912 .48329 .48953 Mtetra
.894 .969 .826 r
.48329 .48953 .48902 .48912 .49914 .48819 .49355 .47779 Mtetra
.593 .602 .83 r
.49355 .47779 .49914 .48819 .50927 .49704 .50373 .47641 Mtetra
.331 .32 .696 r
.50373 .47641 .50927 .49704 .51951 .50613 .51392 .48597 Mtetra
0 .093 .611 r
.51392 .48597 .51951 .50613 .52986 .51136 .52424 .50437 Mtetra
.7 .239 0 r
.52424 .50437 .52986 .51136 .54027 .5112 .53472 .52067 Mtetra
.668 .267 .276 r
.53472 .52067 .54027 .5112 .55071 .50616 .54531 .52915 Mtetra
.466 .157 .357 r
.54531 .52915 .55071 .50616 .56119 .50291 .55591 .52591 Mtetra
.199 0 .262 r
.55591 .52591 .56119 .50291 .57174 .50147 .56641 .51091 Mtetra
.784 .86 .417 r
.56641 .51091 .57174 .50147 .58225 .49512 .57675 .48801 Mtetra
.912 .757 .676 r
.57675 .48801 .58225 .49512 .59268 .48334 .58696 .46292 Mtetra
.751 .586 .672 r
.58696 .46292 .59268 .48334 .603 .46763 .59727 .44668 Mtetra
.639 .517 .698 r
.59727 .44668 .603 .46763 .61328 .45213 .60781 .44144 Mtetra
.315 .446 .834 r
.60781 .44144 .61328 .45213 .62382 .44647 .61868 .44666 Mtetra
.736 .217 0 r
.61868 .44666 .62382 .44647 .6347 .44995 .62985 .45806 Mtetra
.666 .24 .227 r
.62985 .45806 .6347 .44995 .6458 .45737 .64105 .46638 Mtetra
.533 .108 .181 r
.64105 .46638 .6458 .45737 .65703 .46501 .65214 .46892 Mtetra
0 0 0 r
.65214 .46892 .65703 .46501 .66813 .46697 .66297 .46329 Mtetra
.871 .878 .839 r
.66297 .46329 .66813 .46697 .67904 .46325 .67358 .45205 Mtetra
.787 .684 .751 r
.67358 .45205 .67904 .46325 .68976 .45494 .68415 .4402 Mtetra
.738 .621 .728 r
.68415 .4402 .68976 .45494 .70037 .44452 .69477 .42974 Mtetra
.683 .592 .748 r
.69477 .42974 .70037 .44452 .71108 .43582 .70562 .42329 Mtetra
.632 .594 .794 r
.70562 .42329 .71108 .43582 .72193 .42931 .71668 .42017 Mtetra
.563 .627 .873 r
.71668 .42017 .72193 .42931 .73298 .42556 .72794 .41942 Mtetra
.46 .673 .956 r
.72794 .41942 .73298 .42556 .7442 .42368 .73934 .41984 Mtetra
.391 .737 .992 r
.73934 .41984 .7442 .42368 .75553 .42256 .75078 .41978 Mtetra
.38 .777 .986 r
.75078 .41978 .75553 .42256 .76693 .42164 .76224 .419 Mtetra
.473 .833 .994 r
.76224 .419 .76693 .42164 .77835 .42014 .77367 .41701 Mtetra
.566 .855 .997 r
.77367 .41701 .77835 .42014 .78979 .41809 .78508 .41411 Mtetra
.63 .846 .982 r
.78508 .41411 .78979 .41809 .80122 .41536 .79649 .41055 Mtetra
.663 .823 .961 r
.79649 .41055 .80122 .41536 .81266 .41212 .8079 .40656 Mtetra
.672 .797 .941 r
.8079 .40656 .81266 .41212 .82412 .40854 .81935 .40244 Mtetra
.676 .779 .928 r
.81935 .40244 .82412 .40854 .8356 .40471 .83084 .39825 Mtetra
.673 .766 .92 r
.83084 .39825 .8356 .40471 .84712 .40079 .84237 .39414 Mtetra
.671 .759 .917 r
.84237 .39414 .84712 .40079 .85868 .39681 .85395 .39006 Mtetra
.669 .756 .916 r
.85395 .39006 .85868 .39681 .87028 .39281 .86559 .38603 Mtetra
.666 .755 .916 r
.86559 .38603 .87028 .39281 .88193 .38884 .87727 .38207 Mtetra
.651 .75 .922 r
.25164 .57089 .25789 .57635 .26727 .57368 .26106 .56804 Mtetra
.648 .744 .919 r
.26106 .56804 .26727 .57368 .27669 .57106 .2705 .56524 Mtetra
.644 .737 .916 r
.2705 .56524 .27669 .57106 .28613 .5685 .27997 .56253 Mtetra
.639 .73 .915 r
.27997 .56253 .28613 .5685 .29561 .56599 .28947 .55995 Mtetra
.63 .726 .917 r
.28947 .55995 .29561 .56599 .30512 .56355 .299 .55756 Mtetra
.622 .727 .921 r
.299 .55756 .30512 .56355 .31467 .56104 .30855 .55532 Mtetra
.613 .734 .932 r
.30855 .55532 .31467 .56104 .32426 .55842 .31812 .55324 Mtetra
.614 .756 .946 r
.31812 .55324 .32426 .55842 .33391 .55538 .32775 .55103 Mtetra
.62 .791 .964 r
.32775 .55103 .33391 .55538 .34364 .55171 .33743 .54852 Mtetra
.649 .847 .976 r
.33743 .54852 .34364 .55171 .35343 .54716 .3472 .54519 Mtetra
.696 .905 .97 r
.3472 .54519 .35343 .54716 .36332 .54145 .35706 .54059 Mtetra
.743 .949 .946 r
.35706 .54059 .36332 .54145 .37325 .53502 .36701 .53463 Mtetra
.801 .962 .913 r
.36701 .53463 .37325 .53502 .38322 .52813 .37705 .52708 Mtetra
.818 .941 .907 r
.37705 .52708 .38322 .52813 .39316 .52235 .38712 .51922 Mtetra
.799 .866 .898 r
.38712 .51922 .39316 .52235 .40303 .51887 .39717 .51197 Mtetra
.701 .726 .869 r
.39717 .51197 .40303 .51887 .41283 .51865 .40713 .50741 Mtetra
.561 .568 .818 r
.40713 .50741 .41283 .51865 .42256 .52236 .41699 .50705 Mtetra
.446 .443 .762 r
.41699 .50705 .42256 .52236 .43233 .52746 .42678 .51077 Mtetra
.329 .354 .736 r
.42678 .51077 .43233 .52746 .4422 .53199 .43655 .51815 Mtetra
.358 .411 .78 r
.43655 .51815 .4422 .53199 .45227 .53104 .44647 .52359 Mtetra
.513 .643 .914 r
.44647 .52359 .45227 .53104 .46255 .52204 .45659 .52365 Mtetra
.688 .981 .844 r
.45659 .52365 .46255 .52204 .47291 .50733 .4669 .5162 Mtetra
0 0 0 r
.4669 .5162 .47291 .50733 .48329 .48953 .47732 .50115 Mtetra
.47732 .50115 .48329 .48953 .49355 .47779 .48773 .48539 Mtetra
.48773 .48539 .49355 .47779 .50373 .47641 .49806 .47346 Mtetra
.415 .78 .995 r
.49806 .47346 .50373 .47641 .51392 .48597 .50832 .47268 Mtetra
.049 .222 .721 r
.50832 .47268 .51392 .48597 .52424 .50437 .51861 .48376 Mtetra
.214 .244 .677 r
.51861 .48376 .52424 .50437 .53472 .52067 .52903 .49681 Mtetra
.381 .335 .682 r
.52903 .49681 .53472 .52067 .54531 .52915 .53958 .50594 Mtetra
.608 .487 .689 r
.53958 .50594 .54531 .52915 .55591 .52591 .55015 .50266 Mtetra
.731 .563 .664 r
.55015 .50266 .55591 .52591 .56641 .51091 .56063 .48693 Mtetra
.754 .574 .653 r
.56063 .48693 .56641 .51091 .57675 .48801 .57102 .46722 Mtetra
.759 .59 .667 r
.57102 .46722 .57675 .48801 .58696 .46292 .58137 .44943 Mtetra
.682 .603 .761 r
.58137 .44943 .58696 .46292 .59727 .44668 .59191 .44355 Mtetra
0 .293 .687 r
.59191 .44355 .59727 .44668 .60781 .44144 .60275 .44891 Mtetra
.686 .257 .224 r
.60275 .44891 .60781 .44144 .61868 .44666 .61379 .45818 Mtetra
.656 .266 .294 r
.61379 .45818 .61868 .44666 .62985 .45806 .62494 .46678 Mtetra
.479 .049 .143 r
.62494 .46678 .62985 .45806 .64105 .46638 .63594 .46771 Mtetra
.574 .937 .806 r
.63594 .46771 .64105 .46638 .65214 .46892 .64674 .46101 Mtetra
.829 .754 .78 r
.64674 .46101 .65214 .46892 .66297 .46329 .65734 .44881 Mtetra
.779 .643 .711 r
.65734 .44881 .66297 .46329 .67358 .45205 .66783 .4346 Mtetra
.719 .588 .708 r
.66783 .4346 .67358 .45205 .68415 .4402 .67847 .42409 Mtetra
.674 .575 .736 r
.67847 .42409 .68415 .4402 .69477 .42974 .68931 .41774 Mtetra
.607 .59 .808 r
.68931 .41774 .69477 .42974 .70562 .42329 .70041 .41568 Mtetra
.478 .629 .919 r
.70041 .41568 .70562 .42329 .71668 .42017 .71172 .4164 Mtetra
.257 .661 .965 r
.71172 .4164 .71668 .42017 .72794 .41942 .72314 .41775 Mtetra
.078 .617 .855 r
.72314 .41775 .72794 .41942 .73934 .41984 .73463 .4188 Mtetra
.185 .708 .867 r
.73463 .4188 .73934 .41984 .75078 .41978 .74608 .41823 Mtetra
.386 .824 .952 r
.74608 .41823 .75078 .41978 .76224 .419 .75749 .41625 Mtetra
.575 .875 .994 r
.75749 .41625 .76224 .419 .77367 .41701 .76887 .41296 Mtetra
.661 .853 .974 r
.76887 .41296 .77367 .41701 .78508 .41411 .78023 .40882 Mtetra
.685 .811 .943 r
.78023 .40882 .78508 .41411 .79649 .41055 .7916 .40435 Mtetra
.691 .78 .92 r
.7916 .40435 .79649 .41055 .8079 .40656 .803 .39975 Mtetra
.684 .757 .907 r
.803 .39975 .8079 .40656 .81935 .40244 .81445 .39531 Mtetra
.678 .746 .902 r
.81445 .39531 .81935 .40244 .83084 .39825 .82596 .39101 Mtetra
.671 .74 .902 r
.82596 .39101 .83084 .39825 .84237 .39414 .83753 .38691 Mtetra
.666 .739 .905 r
.83753 .38691 .84237 .39414 .85395 .39006 .84916 .38294 Mtetra
.663 .742 .909 r
.84916 .38294 .85395 .39006 .86559 .38603 .86085 .37907 Mtetra
.66 .747 .915 r
.86085 .37907 .86559 .38603 .87727 .38207 .87259 .37524 Mtetra
.662 .753 .917 r
.24535 .5654 .25164 .57089 .26106 .56804 .25481 .56226 Mtetra
.662 .743 .911 r
.25481 .56226 .26106 .56804 .2705 .56524 .2643 .55912 Mtetra
.658 .732 .904 r
.2643 .55912 .2705 .56524 .27997 .56253 .27381 .55607 Mtetra
.651 .719 .898 r
.27381 .55607 .27997 .56253 .28947 .55995 .28335 .55318 Mtetra
.641 .707 .895 r
.28335 .55318 .28947 .55995 .299 .55756 .2929 .55054 Mtetra
.628 .695 .893 r
.2929 .55054 .299 .55756 .30855 .55532 .30247 .54821 Mtetra
.61 .687 .897 r
.30247 .54821 .30855 .55532 .31812 .55324 .31205 .54631 Mtetra
.595 .688 .907 r
.31205 .54631 .31812 .55324 .32775 .55103 .32166 .54471 Mtetra
.576 .702 .928 r
.32166 .54471 .32775 .55103 .33743 .54852 .33129 .54339 Mtetra
.576 .748 .959 r
.33129 .54339 .33743 .54852 .3472 .54519 .34098 .54178 Mtetra
.584 .823 .99 r
.34098 .54178 .3472 .54519 .35706 .54059 .35076 .53947 Mtetra
.608 .917 .977 r
.35076 .53947 .35706 .54059 .36701 .53463 .36064 .53566 Mtetra
.653 .969 .892 r
.36064 .53566 .36701 .53463 .37705 .52708 .37066 .52967 Mtetra
.692 .978 .805 r
.37066 .52967 .37705 .52708 .38712 .51922 .38079 .52164 Mtetra
.813 1 .814 r
.38079 .52164 .38712 .51922 .39717 .51197 .39101 .51159 Mtetra
.859 .953 .872 r
.39101 .51159 .39717 .51197 .40713 .50741 .4012 .50194 Mtetra
.784 .786 .854 r
.4012 .50194 .40713 .50741 .41699 .50705 .41132 .4944 Mtetra
.625 .579 .783 r
.41132 .4944 .41699 .50705 .42678 .51077 .4213 .49171 Mtetra
.471 .422 .721 r
.4213 .49171 .42678 .51077 .43655 .51815 .43114 .4955 Mtetra
.394 .347 .687 r
.43114 .4955 .43655 .51815 .44647 .52359 .44096 .50321 Mtetra
.309 .308 .695 r
.44096 .50321 .44647 .52359 .45659 .52365 .45084 .51285 Mtetra
.246 .404 .824 r
.45084 .51285 .45659 .52365 .4669 .5162 .46091 .51872 Mtetra
.091 0 0 r
.46091 .51872 .4669 .5162 .47732 .50115 .47119 .51731 Mtetra
.178 0 .162 r
.47119 .51731 .47732 .50115 .48773 .48539 .48163 .50716 Mtetra
.033 0 .169 r
.48163 .50716 .48773 .48539 .49806 .47346 .49215 .48903 Mtetra
0 0 0 r
.49215 .48903 .49806 .47346 .50832 .47268 .50261 .47077 Mtetra
.919 .886 .784 r
.50261 .47077 .50832 .47268 .51861 .48376 .51301 .45605 Mtetra
.662 .503 .658 r
.51301 .45605 .51861 .48376 .52903 .49681 .52338 .44655 Mtetra
.585 .409 .61 r
.52338 .44655 .52903 .49681 .53958 .50594 .53375 .44233 Mtetra
.573 .39 .595 r
.53375 .44233 .53958 .50594 .55015 .50266 .54417 .43897 Mtetra
.568 .386 .595 r
.54417 .43897 .55015 .50266 .56063 .48693 .55463 .43648 Mtetra
.534 .373 .609 r
.55463 .43648 .56063 .48693 .57102 .46722 .56521 .43929 Mtetra
.433 .35 .664 r
.56521 .43929 .57102 .46722 .58137 .44943 .57594 .44738 Mtetra
.715 .182 0 r
.57594 .44738 .58137 .44943 .59191 .44355 .58687 .45908 Mtetra
.678 .318 .357 r
.58687 .45908 .59191 .44355 .60275 .44891 .59793 .4707 Mtetra
.565 .238 .374 r
.59793 .4707 .60275 .44891 .61379 .45818 .60892 .47431 Mtetra
.37 .029 .251 r
.60892 .47431 .61379 .45818 .62494 .46678 .61975 .46907 Mtetra
.833 .992 .74 r
.61975 .46907 .62494 .46678 .63594 .46771 .63038 .45644 Mtetra
.829 .697 .718 r
.63038 .45644 .63594 .46771 .64674 .46101 .64084 .43994 Mtetra
.735 .576 .676 r
.64084 .43994 .64674 .46101 .65734 .44881 .65134 .42535 Mtetra
.688 .536 .675 r
.65134 .42535 .65734 .44881 .66783 .4346 .66197 .41473 Mtetra
.624 .517 .712 r
.66197 .41473 .66783 .4346 .67847 .42409 .6729 .41071 Mtetra
.526 .525 .797 r
.6729 .41071 .67847 .42409 .68931 .41774 .68411 .41165 Mtetra
.259 .562 .935 r
.68411 .41165 .68931 .41774 .70041 .41568 .69551 .41477 Mtetra
.267 0 0 r
.69551 .41477 .70041 .41568 .71172 .4164 .70703 .41832 Mtetra
.313 0 0 r
.70703 .41832 .71172 .4164 .72314 .41775 .71852 .41983 Mtetra
.15 0 0 r
.71852 .41983 .72314 .41775 .73463 .4188 .72995 .41924 Mtetra
.259 .768 .785 r
.72995 .41924 .73463 .4188 .74608 .41823 .74131 .4164 Mtetra
.604 .92 .974 r
.74131 .4164 .74608 .41823 .75749 .41625 .7526 .41201 Mtetra
.706 .86 .955 r
.7526 .41201 .75749 .41625 .76887 .41296 .76388 .40689 Mtetra
.718 .794 .911 r
.76388 .40689 .76887 .41296 .78023 .40882 .77518 .40146 Mtetra
.704 .747 .886 r
.77518 .40146 .78023 .40882 .7916 .40435 .78653 .39631 Mtetra
.691 .724 .874 r
.78653 .39631 .7916 .40435 .803 .39975 .79794 .39147 Mtetra
.677 .712 .874 r
.79794 .39147 .803 .39975 .81445 .39531 .80942 .38707 Mtetra
.667 .71 .879 r
.80942 .38707 .81445 .39531 .82596 .39101 .82098 .38299 Mtetra
.66 .713 .888 r
.82098 .38299 .82596 .39101 .83753 .38691 .83261 .37916 Mtetra
.655 .72 .897 r
.83261 .37916 .83753 .38691 .84916 .38294 .84431 .37551 Mtetra
.651 .729 .906 r
.84431 .37551 .84916 .38294 .86085 .37907 .85606 .37194 Mtetra
.65 .739 .915 r
.85606 .37194 .86085 .37907 .87259 .37524 .86786 .36837 Mtetra
.672 .755 .913 r
.23902 .55988 .24535 .5654 .25481 .56226 .24851 .55648 Mtetra
.673 .747 .906 r
.24851 .55648 .25481 .56226 .2643 .55912 .25805 .55303 Mtetra
.671 .737 .899 r
.25805 .55303 .2643 .55912 .27381 .55607 .26761 .54959 Mtetra
.667 .724 .892 r
.26761 .54959 .27381 .55607 .28335 .55318 .27719 .54625 Mtetra
.66 .709 .884 r
.27719 .54625 .28335 .55318 .2929 .55054 .2868 .54306 Mtetra
.647 .69 .876 r
.2868 .54306 .2929 .55054 .30247 .54821 .29642 .5402 Mtetra
.629 .669 .87 r
.29642 .5402 .30247 .54821 .31205 .54631 .30605 .53781 Mtetra
.607 .649 .865 r
.30605 .53781 .31205 .54631 .32166 .54471 .31567 .536 Mtetra
.578 .632 .868 r
.31567 .536 .32166 .54471 .33129 .54339 .3253 .53494 Mtetra
.559 .631 .879 r
.3253 .53494 .33129 .54339 .34098 .54178 .33495 .5343 Mtetra
.537 .65 .908 r
.33495 .5343 .34098 .54178 .35076 .53947 .34463 .53391 Mtetra
.551 .725 .955 r
.34463 .53391 .35076 .53947 .36064 .53566 .35441 .53278 Mtetra
.59 .849 .993 r
.35441 .53278 .36064 .53566 .37066 .52967 .3643 .5301 Mtetra
.623 .954 .92 r
.3643 .5301 .37066 .52967 .38079 .52164 .37435 .52493 Mtetra
.663 .961 .756 r
.37435 .52493 .38079 .52164 .39101 .51159 .38456 .51647 Mtetra
.673 .938 .659 r
.38456 .51647 .39101 .51159 .4012 .50194 .39486 .50596 Mtetra
.795 .986 .728 r
.39486 .50596 .4012 .50194 .41132 .4944 .40519 .49431 Mtetra
.846 .968 .879 r
.40519 .49431 .41132 .4944 .4213 .49171 .41542 .48502 Mtetra
.701 .737 .879 r
.41542 .48502 .4213 .49171 .43114 .4955 .42552 .48046 Mtetra
.516 .49 .766 r
.42552 .48046 .43114 .4955 .44096 .50321 .43549 .48186 Mtetra
.379 .346 .696 r
.43549 .48186 .44096 .50321 .45084 .51285 .44537 .48958 Mtetra
.352 .316 .679 r
.44537 .48958 .45084 .51285 .46091 .51872 .45531 .49906 Mtetra
.358 .347 .711 r
.45531 .49906 .46091 .51872 .47119 .51731 .46541 .50691 Mtetra
.523 .573 .847 r
.46541 .50691 .47119 .51731 .48163 .50716 .47572 .50735 Mtetra
.832 .984 .874 r
.47572 .50735 .48163 .50716 .49215 .48903 .4862 .49799 Mtetra
.616 .815 .403 r
.4862 .49799 .49215 .48903 .50261 .47077 .49675 .48162 Mtetra
.664 .804 .355 r
.49675 .48162 .50261 .47077 .51301 .45605 .50728 .46123 Mtetra
.877 .962 .629 r
.50728 .46123 .51301 .45605 .52338 .44655 .51773 .44399 Mtetra
.872 .896 .848 r
.51773 .44399 .52338 .44655 .53375 .44233 .52814 .43321 Mtetra
.652 .662 .847 r
.52814 .43321 .53375 .44233 .54417 .43897 .53857 .42983 Mtetra
.315 .489 .871 r
.53857 .42983 .54417 .43897 .55463 .43648 .5491 .43386 Mtetra
.669 .124 0 r
.5491 .43386 .55463 .43648 .56521 .43929 .55978 .4444 Mtetra
.765 .33 .218 r
.55978 .4444 .56521 .43929 .57594 .44738 .57065 .45817 Mtetra
.677 .282 .291 r
.57065 .45817 .57594 .44738 .58687 .45908 .58159 .46795 Mtetra
.535 .106 .173 r
.58159 .46795 .58687 .45908 .59793 .4707 .59252 .4707 Mtetra
.716 .982 .902 r
.59252 .4707 .59793 .4707 .60892 .47431 .6033 .46354 Mtetra
.819 .7 .734 r
.6033 .46354 .60892 .47431 .61975 .46907 .61389 .44887 Mtetra
.754 .591 .674 r
.61389 .44887 .61975 .46907 .63038 .45644 .6244 .4325 Mtetra
.72 .554 .664 r
.6244 .4325 .63038 .45644 .64084 .43994 .63492 .41787 Mtetra
.669 .531 .688 r
.63492 .41787 .64084 .43994 .65134 .42535 .64565 .40965 Mtetra
.602 .539 .756 r
.64565 .40965 .65134 .42535 .66197 .41473 .65664 .40749 Mtetra
.344 .571 .924 r
.65664 .40749 .66197 .41473 .6729 .41071 .66789 .41016 Mtetra
.428 0 0 r
.66789 .41016 .6729 .41071 .68411 .41165 .67934 .41527 Mtetra
.519 0 0 r
.67934 .41527 .68411 .41165 .69551 .41477 .69085 .41925 Mtetra
.44 0 0 r
.69085 .41925 .69551 .41477 .70703 .41832 .70233 .42114 Mtetra
.13 0 0 r
.70233 .42114 .70703 .41832 .71852 .41983 .7137 .41966 Mtetra
.45 .882 .885 r
.7137 .41966 .71852 .41983 .72995 .41924 .72498 .41562 Mtetra
.723 .888 .956 r
.72498 .41562 .72995 .41924 .74131 .4164 .73619 .40997 Mtetra
.745 .789 .888 r
.73619 .40997 .74131 .4164 .7526 .41201 .74738 .40354 Mtetra
.723 .723 .85 r
.74738 .40354 .7526 .41201 .76388 .40689 .75861 .39737 Mtetra
.705 .692 .835 r
.75861 .39737 .76388 .40689 .77518 .40146 .76991 .39162 Mtetra
.684 .676 .836 r
.76991 .39162 .77518 .40146 .78653 .39631 .78129 .38663 Mtetra
.67 .674 .845 r
.78129 .38663 .78653 .39631 .79794 .39147 .79277 .38224 Mtetra
.658 .68 .86 r
.79277 .38224 .79794 .39147 .80942 .38707 .80433 .37835 Mtetra
.65 .69 .874 r
.80433 .37835 .80942 .38707 .82098 .38299 .81596 .37479 Mtetra
.645 .703 .889 r
.81596 .37479 .82098 .38299 .83261 .37916 .82766 .37139 Mtetra
.642 .715 .901 r
.82766 .37139 .83261 .37916 .84431 .37551 .83943 .36808 Mtetra
.64 .726 .911 r
.83943 .36808 .84431 .37551 .85606 .37194 .85124 .36479 Mtetra
.641 .737 .918 r
.85124 .36479 .85606 .37194 .86786 .36837 .8631 .36144 Mtetra
.676 .756 .911 r
.23264 .55431 .23902 .55988 .24851 .55648 .24217 .55079 Mtetra
.68 .753 .907 r
.24217 .55079 .24851 .55648 .25805 .55303 .25174 .54715 Mtetra
.682 .748 .901 r
.25174 .54715 .25805 .55303 .26761 .54959 .26134 .54343 Mtetra
.683 .739 .894 r
.26134 .54343 .26761 .54959 .27719 .54625 .27098 .53964 Mtetra
.683 .726 .883 r
.27098 .53964 .27719 .54625 .2868 .54306 .28065 .53578 Mtetra
.676 .705 .87 r
.28065 .53578 .2868 .54306 .29642 .5402 .29035 .53206 Mtetra
.663 .679 .855 r
.29035 .53206 .29642 .5402 .30605 .53781 .30005 .5286 Mtetra
.641 .646 .84 r
.30005 .5286 .30605 .53781 .31567 .536 .30976 .52574 Mtetra
.611 .612 .827 r
.30976 .52574 .31567 .536 .3253 .53494 .31944 .52378 Mtetra
.577 .579 .818 r
.31944 .52378 .3253 .53494 .33495 .5343 .32911 .52287 Mtetra
.532 .552 .821 r
.32911 .52287 .33495 .5343 .34463 .53391 .33875 .52324 Mtetra
.501 .551 .84 r
.33875 .52324 .34463 .53391 .35441 .53278 .34841 .52424 Mtetra
.46 .585 .892 r
.34841 .52424 .35441 .53278 .3643 .5301 .35813 .52547 Mtetra
.441 .721 .984 r
.35813 .52547 .3643 .5301 .37435 .52493 .36796 .52537 Mtetra
.333 .816 .849 r
.36796 .52537 .37435 .52493 .38456 .51647 .37797 .52272 Mtetra
0 0 0 r
.37797 .52272 .38456 .51647 .39486 .50596 .38816 .51645 Mtetra
.38816 .51645 .39486 .50596 .40519 .49431 .39855 .50578 Mtetra
.39855 .50578 .40519 .49431 .41542 .48502 .40901 .49254 Mtetra
.681 .888 .52 r
.40901 .49254 .41542 .48502 .42552 .48046 .41948 .47819 Mtetra
.876 .888 .839 r
.41948 .47819 .42552 .48046 .43549 .48186 .42984 .46708 Mtetra
.664 .577 .747 r
.42984 .46708 .43549 .48186 .44537 .48958 .44003 .46188 Mtetra
.539 .42 .666 r
.44003 .46188 .44537 .48958 .45531 .49906 .4501 .46309 Mtetra
.461 .343 .631 r
.4501 .46309 .45531 .49906 .46541 .50691 .4601 .47071 Mtetra
.421 .314 .627 r
.4601 .47071 .46541 .50691 .47572 .50735 .47017 .48117 Mtetra
.358 .306 .662 r
.47017 .48117 .47572 .50735 .4862 .49799 .48037 .49161 Mtetra
.02 .404 .855 r
.48037 .49161 .4862 .49799 .49675 .48162 .49074 .49693 Mtetra
.454 .096 .267 r
.49074 .49693 .49675 .48162 .50728 .46123 .50126 .49541 Mtetra
.462 .181 .401 r
.50126 .49541 .50728 .46123 .51773 .44399 .51184 .48999 Mtetra
.47 .208 .433 r
.51184 .48999 .51773 .44399 .52814 .43321 .52245 .48292 Mtetra
.507 .243 .449 r
.52245 .48292 .52814 .43321 .53857 .42983 .53309 .47956 Mtetra
.534 .266 .455 r
.53309 .47956 .53857 .42983 .5491 .43386 .54379 .47993 Mtetra
.521 .25 .445 r
.54379 .47993 .5491 .43386 .55978 .4444 .55455 .47865 Mtetra
.466 .185 .403 r
.55455 .47865 .55978 .4444 .57065 .45817 .56531 .47346 Mtetra
.089 0 .114 r
.56531 .47346 .57065 .45817 .58159 .46795 .57599 .46136 Mtetra
.887 .781 .739 r
.57599 .46136 .58159 .46795 .59252 .4707 .58656 .44405 Mtetra
.727 .549 .65 r
.58656 .44405 .59252 .4707 .6033 .46354 .59708 .42668 Mtetra
.672 .489 .629 r
.59708 .42668 .6033 .46354 .61389 .44887 .60762 .41214 Mtetra
.626 .458 .634 r
.60762 .41214 .61389 .44887 .6244 .4325 .61831 .40407 Mtetra
.576 .445 .666 r
.61831 .40407 .6244 .4325 .63492 .41787 .62923 .4025 Mtetra
.428 .44 .77 r
.62923 .4025 .63492 .41787 .64565 .40965 .64042 .40695 Mtetra
.469 0 0 r
.64042 .40695 .64565 .40965 .65664 .40749 .65183 .41473 Mtetra
.627 .176 .161 r
.65183 .41473 .65664 .40749 .66789 .41016 .66333 .42142 Mtetra
.568 .164 .236 r
.66333 .42142 .66789 .41016 .67934 .41527 .67481 .42552 Mtetra
.443 .029 .158 r
.67481 .42552 .67934 .41527 .69085 .41925 .68618 .42513 Mtetra
.134 0 0 r
.68618 .42513 .69085 .41925 .70233 .42114 .69741 .42102 Mtetra
.661 .971 .894 r
.69741 .42102 .70233 .42114 .7137 .41966 .70854 .41428 Mtetra
.795 .834 .881 r
.70854 .41428 .7137 .41966 .72498 .41562 .7196 .40616 Mtetra
.75 .71 .814 r
.7196 .40616 .72498 .41562 .73619 .40997 .7307 .39825 Mtetra
.717 .656 .787 r
.7307 .39825 .73619 .40997 .74738 .40354 .74185 .39098 Mtetra
.687 .629 .785 r
.74185 .39098 .74738 .40354 .75861 .39737 .75311 .38503 Mtetra
.667 .623 .795 r
.75311 .38503 .75861 .39737 .76991 .39162 .76449 .38015 Mtetra
.651 .63 .816 r
.76449 .38015 .76991 .39162 .78129 .38663 .77598 .3762 Mtetra
.639 .644 .84 r
.77598 .3762 .78129 .38663 .79277 .38224 .78756 .37287 Mtetra
.633 .666 .865 r
.78756 .37287 .79277 .38224 .80433 .37835 .79922 .36982 Mtetra
.629 .687 .886 r
.79922 .36982 .80433 .37835 .81596 .37479 .81094 .36691 Mtetra
.63 .708 .902 r
.81094 .36691 .81596 .37479 .82766 .37139 .82272 .36393 Mtetra
.631 .722 .913 r
.82272 .36393 .82766 .37139 .83943 .36808 .83454 .36088 Mtetra
.633 .732 .919 r
.83454 .36088 .83943 .36808 .85124 .36479 .8464 .35773 Mtetra
.637 .74 .923 r
.8464 .35773 .85124 .36479 .8631 .36144 .85831 .35446 Mtetra
.669 .754 .915 r
.22623 .54871 .23264 .55431 .24217 .55079 .23576 .54534 Mtetra
.674 .762 .917 r
.23576 .54534 .24217 .55079 .25174 .54715 .24533 .54184 Mtetra
.68 .768 .918 r
.24533 .54184 .25174 .54715 .26134 .54343 .25495 .53817 Mtetra
.688 .773 .916 r
.25495 .53817 .26134 .54343 .27098 .53964 .26462 .53429 Mtetra
.698 .772 .909 r
.26462 .53429 .27098 .53964 .28065 .53578 .27434 .53012 Mtetra
.702 .763 .9 r
.27434 .53012 .28065 .53578 .29035 .53206 .2841 .52579 Mtetra
.702 .744 .884 r
.2841 .52579 .29035 .53206 .30005 .5286 .2939 .52133 Mtetra
.689 .712 .866 r
.2939 .52133 .30005 .5286 .30976 .52574 .3037 .51712 Mtetra
.667 .671 .845 r
.3037 .51712 .30976 .52574 .31944 .52378 .31351 .51344 Mtetra
.631 .62 .822 r
.31351 .51344 .31944 .52378 .32911 .52287 .32328 .51077 Mtetra
.584 .568 .801 r
.32328 .51077 .32911 .52287 .33875 .52324 .33301 .50959 Mtetra
.54 .521 .784 r
.33301 .50959 .33875 .52324 .34841 .52424 .3427 .50994 Mtetra
.487 .483 .778 r
.3427 .50994 .34841 .52424 .35813 .52547 .35236 .51198 Mtetra
.46 .48 .792 r
.35236 .51198 .35813 .52547 .36796 .52537 .36206 .51456 Mtetra
.441 .519 .843 r
.36206 .51456 .36796 .52537 .37797 .52272 .37185 .51682 Mtetra
.485 .691 .959 r
.37185 .51682 .37797 .52272 .38816 .51645 .38181 .51669 Mtetra
.523 .915 .914 r
.38181 .51669 .38816 .51645 .39855 .50578 .39198 .51257 Mtetra
0 0 0 r
.39198 .51257 .39855 .50578 .40901 .49254 .40236 .50394 Mtetra
.40236 .50394 .40901 .49254 .41948 .47819 .41289 .49067 Mtetra
.41289 .49067 .41948 .47819 .42984 .46708 .42344 .47621 Mtetra
.42344 .47621 .42984 .46708 .44003 .46188 .43393 .46297 Mtetra
.79 .996 .864 r
.43393 .46297 .44003 .46188 .4501 .46309 .44428 .45423 Mtetra
.619 .654 .862 r
.44428 .45423 .4501 .46309 .4601 .47071 .4545 .45195 Mtetra
.46 .421 .727 r
.4545 .45195 .4601 .47071 .47017 .48117 .46464 .4559 Mtetra
.378 .324 .67 r
.46464 .4559 .47017 .48117 .48037 .49161 .4748 .46504 Mtetra
.393 .328 .665 r
.4748 .46504 .48037 .49161 .49074 .49693 .48507 .47405 Mtetra
.433 .375 .693 r
.48507 .47405 .49074 .49693 .50126 .49541 .49549 .4802 Mtetra
.496 .482 .772 r
.49549 .4802 .50126 .49541 .51184 .48999 .50603 .48222 Mtetra
.613 .688 .896 r
.50603 .48222 .51184 .48999 .52245 .48292 .51666 .47997 Mtetra
.612 .868 .991 r
.51666 .47997 .52245 .48292 .53309 .47956 .52734 .47659 Mtetra
.677 .887 .975 r
.52734 .47659 .53309 .47956 .54379 .47993 .53805 .47208 Mtetra
.781 .743 .818 r
.53805 .47208 .54379 .47993 .55455 .47865 .54877 .46328 Mtetra
.759 .626 .712 r
.54877 .46328 .55455 .47865 .56531 .47346 .55945 .4503 Mtetra
.734 .566 .665 r
.55945 .4503 .56531 .47346 .57599 .46136 .57006 .4344 Mtetra
.716 .541 .652 r
.57006 .4344 .57599 .46136 .58656 .44405 .58064 .41833 Mtetra
.68 .522 .665 r
.58064 .41833 .58656 .44405 .59708 .42668 .59128 .40747 Mtetra
.633 .527 .715 r
.59128 .40747 .59708 .42668 .60762 .41214 .60206 .40289 Mtetra
.437 .561 .882 r
.60206 .40289 .60762 .41214 .61831 .40407 .61306 .40485 Mtetra
.58 .012 0 r
.61306 .40485 .61831 .40407 .62923 .4025 .62427 .41142 Mtetra
.648 .222 .222 r
.62427 .41142 .62923 .4025 .64042 .40695 .63565 .41927 Mtetra
.617 .223 .275 r
.63565 .41927 .64042 .40695 .65183 .41473 .6471 .42594 Mtetra
.517 .111 .211 r
.6471 .42594 .65183 .41473 .66333 .42142 .65847 .4279 Mtetra
.253 0 0 r
.65847 .4279 .66333 .42142 .67481 .42552 .66973 .42526 Mtetra
.675 .973 .905 r
.66973 .42526 .67481 .42552 .68618 .42513 .68083 .41853 Mtetra
.804 .795 .844 r
.68083 .41853 .68618 .42513 .69741 .42102 .69184 .40932 Mtetra
.754 .671 .77 r
.69184 .40932 .69741 .42102 .70854 .41428 .70283 .39976 Mtetra
.722 .621 .744 r
.70283 .39976 .70854 .41428 .7196 .40616 .71385 .39074 Mtetra
.691 .595 .744 r
.71385 .39074 .7196 .40616 .7307 .39825 .72499 .38345 Mtetra
.669 .591 .759 r
.72499 .38345 .7307 .39825 .74185 .39098 .73625 .37772 Mtetra
.648 .6 .786 r
.73625 .37772 .74185 .39098 .75311 .38503 .74766 .37352 Mtetra
.631 .619 .821 r
.74766 .37352 .75311 .38503 .76449 .38015 .75918 .37038 Mtetra
.619 .65 .859 r
.75918 .37038 .76449 .38015 .77598 .3762 .77079 .36779 Mtetra
.609 .681 .893 r
.77079 .36779 .77598 .3762 .78756 .37287 .78249 .36545 Mtetra
.61 .713 .918 r
.78249 .36545 .78756 .37287 .79922 .36982 .79423 .36298 Mtetra
.612 .734 .932 r
.79423 .36298 .79922 .36982 .81094 .36691 .80601 .36034 Mtetra
.622 .749 .937 r
.80601 .36034 .81094 .36691 .82272 .36393 .81782 .35741 Mtetra
.63 .755 .937 r
.81782 .35741 .82272 .36393 .83454 .36088 .82967 .35425 Mtetra
.637 .756 .934 r
.82967 .35425 .83454 .36088 .8464 .35773 .84155 .35091 Mtetra
.643 .752 .928 r
.84155 .35091 .8464 .35773 .85831 .35446 .85348 .34743 Mtetra
.652 .75 .922 r
.21976 .54307 .22623 .54871 .23576 .54534 .22928 .54009 Mtetra
.654 .766 .931 r
.22928 .54009 .23576 .54534 .24533 .54184 .23884 .53703 Mtetra
.661 .784 .94 r
.23884 .53703 .24533 .54184 .25495 .53817 .24845 .53378 Mtetra
.672 .804 .946 r
.24845 .53378 .25495 .53817 .26462 .53429 .25811 .53022 Mtetra
.689 .82 .946 r
.25811 .53022 .26462 .53429 .27434 .53012 .26784 .52625 Mtetra
.707 .831 .941 r
.26784 .52625 .27434 .53012 .2841 .52579 .27764 .52182 Mtetra
.728 .83 .928 r
.27764 .52182 .2841 .52579 .2939 .52133 .2875 .51682 Mtetra
.738 .811 .91 r
.2875 .51682 .2939 .52133 .3037 .51712 .29741 .51146 Mtetra
.739 .773 .881 r
.29741 .51146 .3037 .51712 .31351 .51344 .30736 .50584 Mtetra
.715 .713 .847 r
.30736 .50584 .31351 .51344 .32328 .51077 .31732 .50056 Mtetra
.677 .644 .809 r
.31732 .50056 .32328 .51077 .33301 .50959 .32724 .49608 Mtetra
.626 .57 .772 r
.32724 .49608 .33301 .50959 .3427 .50994 .33711 .49316 Mtetra
.568 .502 .741 r
.33711 .49316 .3427 .50994 .35236 .51198 .3469 .49251 Mtetra
.518 .449 .718 r
.3469 .49251 .35236 .51198 .36206 .51456 .35662 .49413 Mtetra
.461 .406 .71 r
.35662 .49413 .36206 .51456 .37185 .51682 .36629 .49818 Mtetra
.42 .395 .725 r
.36629 .49818 .37185 .51682 .38181 .51669 .37599 .50325 Mtetra
.352 .419 .791 r
.37599 .50325 .38181 .51669 .39198 .51257 .38579 .50823 Mtetra
.118 .557 .919 r
.38579 .50823 .39198 .51257 .40236 .50394 .39577 .5108 Mtetra
.31 0 0 r
.39577 .5108 .40236 .50394 .41289 .49067 .40597 .50916 Mtetra
.323 0 .243 r
.40597 .50916 .41289 .49067 .42344 .47621 .41639 .50228 Mtetra
.267 0 .286 r
.41639 .50228 .42344 .47621 .43393 .46297 .427 .48973 Mtetra
.199 0 .264 r
.427 .48973 .43393 .46297 .44428 .45423 .43767 .47416 Mtetra
0 0 .116 r
.43767 .47416 .44428 .45423 .4545 .45195 .44833 .45749 Mtetra
.816 .961 .634 r
.44833 .45749 .4545 .45195 .46464 .4559 .45891 .44245 Mtetra
.759 .64 .729 r
.45891 .44245 .46464 .4559 .4748 .46504 .46939 .43091 Mtetra
.62 .457 .64 r
.46939 .43091 .4748 .46504 .48507 .47405 .4798 .42423 Mtetra
.565 .394 .608 r
.4798 .42423 .48507 .47405 .49549 .4802 .49017 .42237 Mtetra
.548 .374 .597 r
.49017 .42237 .49549 .4802 .50603 .48222 .50058 .42269 Mtetra
.547 .372 .596 r
.50058 .42269 .50603 .48222 .51666 .47997 .51105 .4231 Mtetra
.572 .393 .6 r
.51105 .4231 .51666 .47997 .52734 .47659 .52159 .41965 Mtetra
.595 .41 .6 r
.52159 .41965 .52734 .47659 .53805 .47208 .53216 .41233 Mtetra
.592 .405 .597 r
.53216 .41233 .53805 .47208 .54877 .46328 .54274 .4051 Mtetra
.581 .398 .599 r
.54274 .4051 .54877 .46328 .55945 .4503 .55337 .40004 Mtetra
.552 .385 .608 r
.55337 .40004 .55945 .4503 .57006 .4344 .56408 .39984 Mtetra
.497 .373 .641 r
.56408 .39984 .57006 .4344 .58064 .41833 .57493 .40455 Mtetra
.231 .341 .77 r
.57493 .40455 .58064 .41833 .59128 .40747 .58595 .41282 Mtetra
.702 .241 .155 r
.58595 .41282 .59128 .40747 .60206 .40289 .59712 .4228 Mtetra
.628 .283 .367 r
.59712 .4228 .60206 .40289 .61306 .40485 .60841 .4317 Mtetra
.583 .265 .396 r
.60841 .4317 .61306 .40485 .62427 .41142 .61973 .43758 Mtetra
.515 .203 .375 r
.61973 .43758 .62427 .41142 .63565 .41927 .63098 .43772 Mtetra
.387 .055 .275 r
.63098 .43772 .63565 .41927 .6471 .42594 .6421 .4325 Mtetra
0 0 0 r
.6421 .4325 .6471 .42594 .65847 .4279 .65309 .42299 Mtetra
.867 .848 .823 r
.65309 .42299 .65847 .4279 .66973 .42526 .66398 .41098 Mtetra
.762 .642 .729 r
.66398 .41098 .66973 .42526 .68083 .41853 .67484 .39885 Mtetra
.712 .572 .696 r
.67484 .39885 .68083 .41853 .69184 .40932 .68575 .38773 Mtetra
.675 .54 .692 r
.68575 .38773 .69184 .40932 .70283 .39976 .69677 .37908 Mtetra
.65 .53 .704 r
.69677 .37908 .70283 .39976 .71385 .39074 .70794 .37277 Mtetra
.626 .536 .733 r
.70794 .37277 .71385 .39074 .72499 .38345 .71928 .36878 Mtetra
.605 .558 .775 r
.71928 .36878 .72499 .38345 .73625 .37772 .73077 .3664 Mtetra
.587 .601 .834 r
.73077 .3664 .73625 .37772 .74766 .37352 .74237 .36486 Mtetra
.566 .654 .895 r
.74237 .36486 .74766 .37352 .75918 .37038 .75406 .36368 Mtetra
.559 .714 .944 r
.75406 .36368 .75918 .37038 .77079 .36779 .7658 .36223 Mtetra
.558 .758 .971 r
.7658 .36223 .77079 .36779 .78249 .36545 .77757 .36041 Mtetra
.578 .79 .979 r
.77757 .36041 .78249 .36545 .79423 .36298 .78935 .358 Mtetra
.601 .803 .977 r
.78935 .358 .79423 .36298 .80601 .36034 .80116 .35511 Mtetra
.626 .804 .968 r
.80116 .35511 .80601 .36034 .81782 .35741 .81298 .35178 Mtetra
.643 .796 .956 r
.81298 .35178 .81782 .35741 .82967 .35425 .82482 .34814 Mtetra
.654 .783 .943 r
.82482 .34814 .82967 .35425 .84155 .35091 .83669 .34429 Mtetra
.659 .768 .93 r
.83669 .34429 .84155 .35091 .85348 .34743 .84861 .34035 Mtetra
.631 .745 .93 r
.21326 .53739 .21976 .54307 .22928 .54009 .22275 .53485 Mtetra
.628 .761 .942 r
.22275 .53485 .22928 .54009 .23884 .53703 .23229 .53231 Mtetra
.629 .782 .955 r
.23229 .53231 .23884 .53703 .24845 .53378 .24187 .52965 Mtetra
.635 .808 .966 r
.24187 .52965 .24845 .53378 .25811 .53022 .25151 .52676 Mtetra
.644 .837 .974 r
.25151 .52676 .25811 .53022 .26784 .52625 .26121 .52352 Mtetra
.661 .871 .978 r
.26121 .52352 .26784 .52625 .27764 .52182 .27098 .51976 Mtetra
.688 .901 .972 r
.27098 .51976 .27764 .52182 .2875 .51682 .28084 .5153 Mtetra
.717 .924 .962 r
.28084 .5153 .2875 .51682 .29741 .51146 .29078 .51009 Mtetra
.756 .932 .945 r
.29078 .51009 .29741 .51146 .30736 .50584 .3008 .504 Mtetra
.778 .916 .931 r
.3008 .504 .30736 .50584 .31732 .50056 .31087 .49742 Mtetra
.787 .867 .908 r
.31087 .49742 .31732 .50056 .32724 .49608 .32098 .49055 Mtetra
.755 .783 .876 r
.32098 .49055 .32724 .49608 .33711 .49316 .33106 .4843 Mtetra
.696 .68 .831 r
.33106 .4843 .33711 .49316 .3469 .49251 .34109 .47937 Mtetra
.622 .574 .779 r
.34109 .47937 .3469 .49251 .35662 .49413 .35103 .47662 Mtetra
.547 .484 .736 r
.35103 .47662 .35662 .49413 .36629 .49818 .36087 .47681 Mtetra
.492 .42 .703 r
.36087 .47681 .36629 .49818 .37599 .50325 .37063 .47975 Mtetra
.44 .373 .686 r
.37063 .47975 .37599 .50325 .38579 .50823 .38036 .48531 Mtetra
.418 .362 .689 r
.38036 .48531 .38579 .50823 .39577 .5108 .39015 .49162 Mtetra
.409 .385 .721 r
.39015 .49162 .39577 .5108 .40597 .50916 .40006 .49716 Mtetra
.467 .514 .823 r
.40006 .49716 .40597 .50916 .41639 .50228 .41019 .49914 Mtetra
.626 .86 .987 r
.41019 .49914 .41639 .50228 .427 .48973 .42056 .49576 Mtetra
0 0 0 r
.42056 .49576 .427 .48973 .43767 .47416 .4311 .48747 Mtetra
.4311 .48747 .43767 .47416 .44833 .45749 .44177 .47478 Mtetra
0 0 .073 r
.44177 .47478 .44833 .45749 .45891 .44245 .45246 .4601 Mtetra
.008 0 .092 r
.45246 .4601 .45891 .44245 .46939 .43091 .46312 .44553 Mtetra
.086 0 .08 r
.46312 .44553 .46939 .43091 .4798 .42423 .47369 .43489 Mtetra
.217 0 .051 r
.47369 .43489 .4798 .42423 .49017 .42237 .48418 .4294 Mtetra
.278 0 0 r
.48418 .4294 .49017 .42237 .50058 .42269 .49468 .42712 Mtetra
.49468 .42712 .50058 .42269 .51105 .4231 .50521 .4264 Mtetra
0 0 0 r
.50521 .4264 .51105 .4231 .52159 .41965 .5158 .42293 Mtetra
.367 .799 .622 r
.5158 .42293 .52159 .41965 .53216 .41233 .52644 .41672 Mtetra
0 0 0 r
.52644 .41672 .53216 .41233 .54274 .4051 .53711 .41207 Mtetra
.329 0 0 r
.53711 .41207 .54274 .4051 .55337 .40004 .54783 .41063 Mtetra
.562 .152 .222 r
.54783 .41063 .55337 .40004 .56408 .39984 .55866 .41439 Mtetra
.63 .256 .317 r
.55866 .41439 .56408 .39984 .57493 .40455 .56964 .42215 Mtetra
.622 .266 .346 r
.56964 .42215 .57493 .40455 .58595 .41282 .58074 .43007 Mtetra
.595 .237 .331 r
.58074 .43007 .58595 .41282 .59712 .4228 .59192 .436 Mtetra
.511 .124 .244 r
.59192 .436 .59712 .4228 .60841 .4317 .6031 .4375 Mtetra
.151 0 0 r
.6031 .4375 .60841 .4317 .61973 .43758 .61423 .43402 Mtetra
.826 .895 .891 r
.61423 .43402 .61973 .43758 .63098 .43772 .62523 .42509 Mtetra
.782 .669 .739 r
.62523 .42509 .63098 .43772 .6421 .4325 .63611 .41249 Mtetra
.732 .582 .687 r
.63611 .41249 .6421 .4325 .65309 .42299 .64695 .39907 Mtetra
.704 .546 .671 r
.64695 .39907 .65309 .42299 .66398 .41098 .65779 .38638 Mtetra
.676 .526 .674 r
.65779 .38638 .66398 .41098 .67484 .39885 .66873 .37637 Mtetra
.655 .522 .69 r
.66873 .37637 .67484 .39885 .68575 .38773 .67981 .36914 Mtetra
.627 .531 .726 r
.67981 .36914 .68575 .38773 .69677 .37908 .69107 .36493 Mtetra
.596 .56 .784 r
.69107 .36493 .69677 .37908 .70794 .37277 .70249 .36296 Mtetra
.551 .615 .87 r
.70249 .36296 .70794 .37277 .71928 .36878 .71405 .36236 Mtetra
.473 .682 .957 r
.71405 .36236 .71928 .36878 .73077 .3664 .72573 .3624 Mtetra
.394 .742 .992 r
.72573 .3624 .73077 .3664 .74237 .36486 .73745 .36216 Mtetra
.348 .769 .976 r
.73745 .36216 .74237 .36486 .75406 .36368 .74922 .36142 Mtetra
.395 .811 .974 r
.74922 .36142 .75406 .36368 .7658 .36223 .76099 .35977 Mtetra
.472 .847 .987 r
.76099 .35977 .7658 .36223 .77757 .36041 .77277 .35735 Mtetra
.558 .865 .996 r
.77277 .35735 .77757 .36041 .78935 .358 .78454 .35419 Mtetra
.616 .86 .989 r
.78454 .35419 .78935 .358 .80116 .35511 .79632 .35049 Mtetra
.65 .84 .973 r
.79632 .35049 .80116 .35511 .81298 .35178 .80812 .34642 Mtetra
.668 .818 .956 r
.80812 .34642 .81298 .35178 .82482 .34814 .81994 .3421 Mtetra
.675 .796 .939 r
.81994 .3421 .82482 .34814 .83669 .34429 .8318 .33766 Mtetra
.676 .776 .926 r
.8318 .33766 .83669 .34429 .84861 .34035 .8437 .33321 Mtetra
.615 .741 .935 r
.20671 .53168 .21326 .53739 .22275 .53485 .21619 .52944 Mtetra
.606 .75 .946 r
.21619 .52944 .22275 .53485 .23229 .53231 .22571 .52731 Mtetra
.6 .764 .958 r
.22571 .52731 .23229 .53231 .24187 .52965 .23526 .5252 Mtetra
.593 .785 .972 r
.23526 .5252 .24187 .52965 .25151 .52676 .24486 .52305 Mtetra
.581 .813 .987 r
.24486 .52305 .25151 .52676 .26121 .52352 .2545 .52083 Mtetra
.573 .851 .996 r
.2545 .52083 .26121 .52352 .27098 .51976 .26421 .51829 Mtetra
.559 .89 .986 r
.26421 .51829 .27098 .51976 .28084 .5153 .274 .51526 Mtetra
.541 .917 .94 r
.274 .51526 .28084 .5153 .29078 .51009 .28388 .51143 Mtetra
.536 .925 .866 r
.28388 .51143 .29078 .51009 .3008 .504 .29386 .50654 Mtetra
.545 .923 .793 r
.29386 .50654 .3008 .504 .31087 .49742 .30395 .50047 Mtetra
.623 .952 .781 r
.30395 .50047 .31087 .49742 .32098 .49055 .31415 .49304 Mtetra
.728 .99 .827 r
.31415 .49304 .32098 .49055 .33106 .4843 .32441 .4847 Mtetra
.831 .977 .884 r
.32441 .4847 .33106 .4843 .34109 .47937 .33472 .47572 Mtetra
.82 .849 .87 r
.33472 .47572 .34109 .47937 .35103 .47662 .34501 .46719 Mtetra
.738 .685 .799 r
.34501 .46719 .35103 .47662 .36087 .47681 .35523 .45994 Mtetra
.65 .55 .728 r
.35523 .45994 .36087 .47681 .37063 .47975 .36536 .45494 Mtetra
.581 .46 .679 r
.36536 .45494 .37063 .47975 .38036 .48531 .37538 .45304 Mtetra
.533 .4 .646 r
.37538 .45304 .38036 .48531 .39015 .49162 .3853 .45444 Mtetra
.492 .36 .628 r
.3853 .45444 .39015 .49162 .40006 .49716 .39515 .45932 Mtetra
.463 .338 .624 r
.39515 .45932 .40006 .49716 .41019 .49914 .405 .46651 Mtetra
.424 .325 .638 r
.405 .46651 .41019 .49914 .42056 .49576 .41491 .4751 Mtetra
.342 .331 .702 r
.41491 .4751 .42056 .49576 .4311 .48747 .42495 .48327 Mtetra
0 .201 .631 r
.42495 .48327 .4311 .48747 .44177 .47478 .43515 .48967 Mtetra
.565 .196 .3 r
.43515 .48967 .44177 .47478 .45246 .4601 .44552 .49339 Mtetra
.524 .229 .407 r
.44552 .49339 .45246 .4601 .46312 .44553 .45603 .49397 Mtetra
.512 .241 .44 r
.45603 .49397 .46312 .44553 .47369 .43489 .46665 .49232 Mtetra
.505 .243 .451 r
.46665 .49232 .47369 .43489 .48418 .4294 .47735 .48898 Mtetra
.499 .239 .452 r
.47735 .48898 .48418 .4294 .49468 .42712 .48811 .48444 Mtetra
.494 .234 .448 r
.48811 .48444 .49468 .42712 .50521 .4264 .4989 .47952 Mtetra
.502 .237 .445 r
.4989 .47952 .50521 .4264 .5158 .42293 .50972 .47608 Mtetra
.513 .246 .447 r
.50972 .47608 .5158 .42293 .52644 .41672 .52057 .47414 Mtetra
.513 .249 .453 r
.52057 .47414 .52644 .41672 .53711 .41207 .53149 .47181 Mtetra
.506 .246 .454 r
.53149 .47181 .53711 .41207 .54783 .41063 .54244 .46829 Mtetra
.493 .233 .449 r
.54244 .46829 .54783 .41063 .55866 .41439 .55343 .46305 Mtetra
.465 .201 .429 r
.55343 .46305 .55866 .41439 .56964 .42215 .56441 .45557 Mtetra
.38 .105 .366 r
.56441 .45557 .56964 .42215 .58074 .43007 .57537 .44488 Mtetra
.002 0 .058 r
.57537 .44488 .58074 .43007 .59192 .436 .58627 .43145 Mtetra
.901 .842 .777 r
.58627 .43145 .59192 .436 .6031 .4375 .59711 .4162 Mtetra
.744 .581 .674 r
.59711 .4162 .6031 .4375 .61423 .43402 .6079 .40047 Mtetra
.679 .5 .637 r
.6079 .40047 .61423 .43402 .62523 .42509 .61869 .38612 Mtetra
.648 .468 .626 r
.61869 .38612 .62523 .42509 .63611 .41249 .62953 .3741 Mtetra
.624 .452 .63 r
.62953 .3741 .63611 .41249 .64695 .39907 .64047 .3656 Mtetra
.604 .45 .646 r
.64047 .3656 .64695 .39907 .65779 .38638 .65157 .36046 Mtetra
.579 .459 .679 r
.65157 .36046 .65779 .38638 .66873 .37637 .66283 .3585 Mtetra
.543 .488 .744 r
.66283 .3585 .66873 .37637 .67981 .36914 .67427 .35884 Mtetra
.462 .556 .866 r
.67427 .35884 .67981 .36914 .69107 .36493 .68584 .36053 Mtetra
.208 .612 .95 r
.68584 .36053 .69107 .36493 .70249 .36296 .69753 .36269 Mtetra
.127 0 0 r
.69753 .36269 .70249 .36296 .71405 .36236 .70926 .3642 Mtetra
.221 0 0 r
.70926 .3642 .71405 .36236 .72573 .3624 .72103 .36479 Mtetra
.145 0 0 r
.72103 .36479 .72573 .3624 .73745 .36216 .73279 .36399 Mtetra
0 0 0 r
.73279 .36399 .73745 .36216 .74922 .36142 .74453 .36197 Mtetra
.26 .768 .772 r
.74453 .36197 .74922 .36142 .76099 .35977 .75625 .35884 Mtetra
.482 .892 .927 r
.75625 .35884 .76099 .35977 .77277 .35735 .76796 .35489 Mtetra
.614 .911 .982 r
.76796 .35489 .77277 .35735 .78454 .35419 .77968 .35041 Mtetra
.671 .882 .977 r
.77968 .35041 .78454 .35419 .79632 .35049 .79142 .3456 Mtetra
.688 .845 .958 r
.79142 .3456 .79632 .35049 .80812 .34642 .80319 .34071 Mtetra
.693 .815 .941 r
.80319 .34071 .80812 .34642 .81994 .3421 .815 .33576 Mtetra
.692 .793 .928 r
.815 .33576 .81994 .3421 .8318 .33766 .82686 .33084 Mtetra
.688 .776 .918 r
.82686 .33084 .8318 .33766 .8437 .33321 .83876 .32602 Mtetra
.621 .742 .933 r
.20012 .52592 .20671 .53168 .21619 .52944 .20963 .52354 Mtetra
.614 .736 .933 r
.20963 .52354 .21619 .52944 .22571 .52731 .21917 .52131 Mtetra
.606 .731 .933 r
.21917 .52131 .22571 .52731 .23526 .5252 .22874 .51924 Mtetra
.596 .73 .938 r
.22874 .51924 .23526 .5252 .24486 .52305 .23833 .51735 Mtetra
.58 .734 .948 r
.23833 .51735 .24486 .52305 .2545 .52083 .24794 .51568 Mtetra
.568 .752 .964 r
.24794 .51568 .2545 .52083 .26421 .51829 .2576 .51406 Mtetra
.55 .784 .986 r
.2576 .51406 .26421 .51829 .274 .51526 .2673 .5124 Mtetra
.532 .834 .999 r
.2673 .5124 .274 .51526 .28388 .51143 .27708 .51035 Mtetra
.496 .878 .971 r
.27708 .51035 .28388 .51143 .29386 .50654 .28695 .50762 Mtetra
.428 .871 .849 r
.28695 .50762 .29386 .50654 .30395 .50047 .29693 .50382 Mtetra
.362 .808 .666 r
.29693 .50382 .30395 .50047 .31415 .49304 .30705 .49855 Mtetra
0 0 0 r
.30705 .49855 .31415 .49304 .32441 .4847 .31728 .49171 Mtetra
.31728 .49171 .32441 .4847 .33472 .47572 .32764 .48311 Mtetra
.32764 .48311 .33472 .47572 .34501 .46719 .33806 .47339 Mtetra
.567 .87 .569 r
.33806 .47339 .34501 .46719 .35523 .45994 .34852 .463 Mtetra
.768 .993 .789 r
.34852 .463 .35523 .45994 .36536 .45494 .35895 .45313 Mtetra
.827 .92 .898 r
.35895 .45313 .36536 .45494 .37538 .45304 .36931 .44474 Mtetra
.721 .706 .836 r
.36931 .44474 .37538 .45304 .3853 .45444 .37956 .43887 Mtetra
.606 .539 .753 r
.37956 .43887 .3853 .45444 .39515 .45932 .38969 .43643 Mtetra
.526 .434 .693 r
.38969 .43643 .39515 .45932 .405 .46651 .39972 .43774 Mtetra
.469 .368 .658 r
.39972 .43774 .405 .46651 .41491 .4751 .40969 .44286 Mtetra
.448 .343 .642 r
.40969 .44286 .41491 .4751 .42495 .48327 .41969 .44984 Mtetra
.445 .338 .638 r
.41969 .44984 .42495 .48327 .43515 .48967 .42978 .4573 Mtetra
.46 .352 .644 r
.42978 .4573 .43515 .48967 .44552 .49339 .44 .46365 Mtetra
.494 .384 .658 r
.44 .46365 .44552 .49339 .45603 .49397 .45039 .4675 Mtetra
.556 .44 .675 r
.45039 .4675 .45603 .49397 .46665 .49232 .46094 .4671 Mtetra
.618 .485 .678 r
.46094 .4671 .46665 .49232 .47735 .48898 .47163 .46228 Mtetra
.64 .494 .668 r
.47163 .46228 .47735 .48898 .48811 .48444 .48238 .45517 Mtetra
.636 .483 .657 r
.48238 .45517 .48811 .48444 .4989 .47952 .49315 .4477 Mtetra
.59 .444 .651 r
.49315 .4477 .4989 .47952 .50972 .47608 .50391 .44422 Mtetra
.544 .413 .652 r
.50391 .44422 .50972 .47608 .52057 .47414 .51471 .44473 Mtetra
.548 .424 .663 r
.51471 .44473 .52057 .47414 .53149 .47181 .52557 .4449 Mtetra
.58 .455 .674 r
.52557 .4449 .53149 .47181 .54244 .46829 .53649 .44277 Mtetra
.637 .498 .676 r
.53649 .44277 .54244 .46829 .55343 .46305 .54743 .43619 Mtetra
.675 .517 .663 r
.54743 .43619 .55343 .46305 .56441 .45557 .55835 .42532 Mtetra
.684 .512 .647 r
.55835 .42532 .56441 .45557 .57537 .44488 .56923 .41187 Mtetra
.683 .504 .638 r
.56923 .41187 .57537 .44488 .58627 .43145 .58007 .39728 Mtetra
.676 .496 .635 r
.58007 .39728 .58627 .43145 .59711 .4162 .59089 .38313 Mtetra
.666 .492 .64 r
.59089 .38313 .59711 .4162 .6079 .40047 .60172 .37085 Mtetra
.643 .486 .655 r
.60172 .37085 .6079 .40047 .61869 .38612 .61264 .3624 Mtetra
.618 .493 .688 r
.61264 .3624 .61869 .38612 .62953 .3741 .62369 .35777 Mtetra
.574 .521 .757 r
.62369 .35777 .62953 .3741 .64047 .3656 .6349 .35662 Mtetra
.448 .583 .896 r
.6349 .35662 .64047 .3656 .65157 .36046 .64627 .35808 Mtetra
0 .48 .794 r
.64627 .35808 .65157 .36046 .66283 .3585 .65779 .36107 Mtetra
.459 0 0 r
.65779 .36107 .66283 .3585 .67427 .35884 .66942 .3646 Mtetra
.493 0 .001 r
.66942 .3646 .67427 .35884 .68584 .36053 .68112 .36747 Mtetra
.465 0 .036 r
.68112 .36747 .68584 .36053 .69753 .36269 .69286 .36921 Mtetra
.381 0 0 r
.69286 .36921 .69753 .36269 .70926 .3642 .70459 .36916 Mtetra
.237 0 0 r
.70459 .36916 .70926 .3642 .72103 .36479 .71629 .36749 Mtetra
0 0 0 r
.71629 .36749 .72103 .36479 .73279 .36399 .72796 .3643 Mtetra
.403 .857 .833 r
.72796 .3643 .73279 .36399 .74453 .36197 .7396 .35999 Mtetra
.629 .93 .969 r
.7396 .35999 .74453 .36197 .75625 .35884 .75125 .35497 Mtetra
.702 .887 .966 r
.75125 .35497 .75625 .35884 .76796 .35489 .7629 .34954 Mtetra
.713 .834 .94 r
.7629 .34954 .76796 .35489 .77968 .35041 .77458 .34406 Mtetra
.71 .797 .919 r
.77458 .34406 .77968 .35041 .79142 .3456 .78631 .33862 Mtetra
.7 .774 .909 r
.78631 .33862 .79142 .3456 .80319 .34071 .79809 .33341 Mtetra
.694 .762 .904 r
.79809 .33341 .80319 .34071 .815 .33576 .80993 .32837 Mtetra
.688 .758 .905 r
.80993 .32837 .815 .33576 .82686 .33084 .82183 .32349 Mtetra
.683 .758 .909 r
.82183 .32349 .82686 .33084 .83876 .32602 .83378 .31877 Mtetra
.646 .749 .924 r
.19348 .52013 .20012 .52592 .20963 .52354 .20306 .5172 Mtetra
.641 .73 .913 r
.20306 .5172 .20963 .52354 .21917 .52131 .21267 .5144 Mtetra
.631 .709 .903 r
.21267 .5144 .21917 .52131 .22874 .51924 .22229 .51183 Mtetra
.617 .69 .895 r
.22229 .51183 .22874 .51924 .23833 .51735 .23193 .5096 Mtetra
.598 .674 .893 r
.23193 .5096 .23833 .51735 .24794 .51568 .24156 .50783 Mtetra
.578 .664 .897 r
.24156 .50783 .24794 .51568 .2576 .51406 .25121 .50649 Mtetra
.552 .663 .91 r
.25121 .50649 .2576 .51406 .2673 .5124 .26086 .50564 Mtetra
.527 .68 .935 r
.26086 .50564 .2673 .5124 .27708 .51035 .27054 .50505 Mtetra
.484 .718 .974 r
.27054 .50505 .27708 .51035 .28695 .50762 .28026 .50459 Mtetra
.407 .777 .994 r
.28026 .50459 .28695 .50762 .29693 .50382 .29006 .50382 Mtetra
.216 .739 .829 r
.29006 .50382 .29693 .50382 .30705 .49855 .29996 .50238 Mtetra
.025 0 0 r
.29996 .50238 .30705 .49855 .31728 .49171 .30998 .49975 Mtetra
.143 0 0 r
.30998 .49975 .31728 .49171 .32764 .48311 .32015 .49542 Mtetra
.19 0 .056 r
.32015 .49542 .32764 .48311 .33806 .47339 .33046 .48918 Mtetra
.185 0 .123 r
.33046 .48918 .33806 .47339 .34852 .463 .34091 .48079 Mtetra
.166 0 .145 r
.34091 .48079 .34852 .463 .35895 .45313 .35146 .47073 Mtetra
.104 0 .113 r
.35146 .47073 .35895 .45313 .36931 .44474 .36207 .45935 Mtetra
0 0 0 r
.36207 .45935 .36931 .44474 .37956 .43887 .3727 .44728 Mtetra
.3727 .44728 .37956 .43887 .38969 .43643 .38332 .43512 Mtetra
.88 .922 .848 r
.38332 .43512 .38969 .43643 .39972 .43774 .39388 .42399 Mtetra
.732 .625 .739 r
.39388 .42399 .39972 .43774 .40969 .44286 .40437 .41457 Mtetra
.645 .489 .658 r
.40437 .41457 .40969 .44286 .41969 .44984 .41482 .4065 Mtetra
.604 .429 .618 r
.41482 .4065 .41969 .44984 .42978 .4573 .42524 .39969 Mtetra
.581 .396 .596 r
.42524 .39969 .42978 .4573 .44 .46365 .43563 .39425 Mtetra
.569 .38 .585 r
.43563 .39425 .44 .46365 .45039 .4675 .44603 .38965 Mtetra
.574 .379 .579 r
.44603 .38965 .45039 .4675 .46094 .4671 .4565 .38341 Mtetra
.58 .381 .576 r
.4565 .38341 .46094 .4671 .47163 .46228 .46703 .3751 Mtetra
.578 .378 .574 r
.46703 .3751 .47163 .46228 .48238 .45517 .47757 .36686 Mtetra
.572 .373 .573 r
.47757 .36686 .48238 .45517 .49315 .4477 .4881 .35993 Mtetra
.558 .363 .572 r
.4881 .35993 .49315 .4477 .50391 .44422 .49863 .35635 Mtetra
.544 .352 .571 r
.49863 .35635 .50391 .44422 .51471 .44473 .50917 .35613 Mtetra
.537 .347 .571 r
.50917 .35613 .51471 .44473 .52557 .4449 .51978 .35724 Mtetra
.51978 .35724 .52557 .4449 .53649 .44277 .53046 .35843 Mtetra
.547 .356 .574 r
.53046 .35843 .53649 .44277 .54743 .43619 .5412 .35756 Mtetra
.555 .365 .578 r
.5412 .35756 .54743 .43619 .55835 .42532 .55199 .35503 Mtetra
.553 .368 .584 r
.55199 .35503 .55835 .42532 .56923 .41187 .56284 .35336 Mtetra
.547 .371 .595 r
.56284 .35336 .56923 .41187 .58007 .39728 .57377 .35308 Mtetra
.538 .382 .617 r
.57377 .35308 .58007 .39728 .59089 .38313 .58479 .3541 Mtetra
.516 .403 .664 r
.58479 .3541 .59089 .38313 .60172 .37085 .59592 .35649 Mtetra
.411 .449 .79 r
.59592 .35649 .60172 .37085 .61264 .3624 .60717 .36064 Mtetra
.359 0 0 r
.60717 .36064 .61264 .3624 .62369 .35777 .61856 .36588 Mtetra
.583 .132 .147 r
.61856 .36588 .62369 .35777 .6349 .35662 .63006 .37106 Mtetra
.568 .184 .274 r
.63006 .37106 .6349 .35662 .64627 .35808 .64164 .37555 Mtetra
.545 .183 .304 r
.64164 .37555 .64627 .35808 .65779 .36107 .65327 .37872 Mtetra
.515 .156 .295 r
.65327 .37872 .65779 .36107 .66942 .3646 .66493 .38021 Mtetra
.463 .093 .251 r
.66493 .38021 .66942 .3646 .68112 .36747 .67657 .37949 Mtetra
.376 0 .153 r
.67657 .37949 .68112 .36747 .69286 .36921 .68817 .37681 Mtetra
.185 0 0 r
.68817 .37681 .69286 .36921 .70459 .36916 .69974 .37238 Mtetra
0 0 0 r
.69974 .37238 .70459 .36916 .71629 .36749 .71127 .3667 Mtetra
.654 .964 .922 r
.71127 .3667 .71629 .36749 .72796 .3643 .7228 .36033 Mtetra
.753 .894 .941 r
.7228 .36033 .72796 .3643 .7396 .35999 .73434 .35362 Mtetra
.745 .806 .901 r
.73434 .35362 .7396 .35999 .75125 .35497 .74591 .34703 Mtetra
.727 .753 .873 r
.74591 .34703 .75125 .35497 .7629 .34954 .75753 .3407 Mtetra
.708 .723 .861 r
.75753 .3407 .7629 .34954 .77458 .34406 .76922 .33487 Mtetra
.694 .709 .859 r
.76922 .33487 .77458 .34406 .78631 .33862 .78098 .32948 Mtetra
.682 .706 .866 r
.78098 .32948 .78631 .33862 .79809 .33341 .79282 .32457 Mtetra
.673 .711 .876 r
.79282 .32457 .79809 .33341 .80993 .32837 .80474 .32 Mtetra
.667 .722 .89 r
.80474 .32 .80993 .32837 .82183 .32349 .81672 .31566 Mtetra
.664 .737 .905 r
.81672 .31566 .82183 .32349 .83378 .31877 .82876 .31146 Mtetra
.675 .756 .912 r
.18679 .51429 .19348 .52013 .20306 .5172 .19646 .51065 Mtetra
.671 .732 .896 r
.19646 .51065 .20306 .5172 .21267 .5144 .20617 .50705 Mtetra
.662 .707 .881 r
.20617 .50705 .21267 .5144 .22229 .51183 .21588 .50364 Mtetra
.648 .68 .866 r
.21588 .50364 .22229 .51183 .23193 .5096 .2256 .50054 Mtetra
.63 .653 .854 r
.2256 .50054 .23193 .5096 .24156 .50783 .23532 .4979 Mtetra
.609 .625 .842 r
.23532 .4979 .24156 .50783 .25121 .50649 .24503 .49583 Mtetra
.584 .599 .833 r
.24503 .49583 .25121 .50649 .26086 .50564 .25473 .49447 Mtetra
.561 .578 .829 r
.25473 .49447 .26086 .50564 .27054 .50505 .26442 .49379 Mtetra
.534 .564 .832 r
.26442 .49379 .27054 .50505 .28026 .50459 .2741 .49382 Mtetra
.512 .563 .845 r
.2741 .49382 .28026 .50459 .29006 .50382 .28381 .49429 Mtetra
.486 .581 .875 r
.28381 .49429 .29006 .50382 .29996 .50238 .29356 .49505 Mtetra
.463 .637 .93 r
.29356 .49505 .29996 .50238 .30998 .49975 .30339 .49554 Mtetra
.41 .734 .991 r
.30339 .49554 .30998 .49975 .32015 .49542 .31333 .49534 Mtetra
.232 .749 .84 r
.31333 .49534 .32015 .49542 .33046 .48918 .3234 .49381 Mtetra
.004 0 0 r
.3234 .49381 .33046 .48918 .34091 .48079 .33363 .49038 Mtetra
.134 0 0 r
.33363 .49038 .34091 .48079 .35146 .47073 .34401 .48492 Mtetra
.174 0 .086 r
.34401 .48492 .35146 .47073 .36207 .45935 .35453 .47724 Mtetra
.183 0 .152 r
.35453 .47724 .36207 .45935 .3727 .44728 .36516 .4675 Mtetra
.167 0 .175 r
.36516 .4675 .3727 .44728 .38332 .43512 .37588 .45591 Mtetra
.146 0 .173 r
.37588 .45591 .38332 .43512 .39388 .42399 .38663 .44333 Mtetra
.1 0 .137 r
.38663 .44333 .39388 .42399 .40437 .41457 .39737 .43047 Mtetra
.018 0 .049 r
.39737 .43047 .40437 .41457 .41482 .4065 .40807 .41828 Mtetra
0 0 0 r
.40807 .41828 .41482 .4065 .42524 .39969 .4187 .40751 Mtetra
.4187 .40751 .42524 .39969 .43563 .39425 .42926 .39892 Mtetra
.42926 .39892 .43563 .39425 .44603 .38965 .43977 .39273 Mtetra
.43977 .39273 .44603 .38965 .4565 .38341 .45027 .38785 Mtetra
.45027 .38785 .4565 .38341 .46703 .3751 .46078 .38384 Mtetra
.28 0 .01 r
.46078 .38384 .46703 .3751 .47757 .36686 .47132 .38085 Mtetra
.4 .023 .204 r
.47132 .38085 .47757 .36686 .4881 .35993 .48189 .37839 Mtetra
.409 .066 .27 r
.48189 .37839 .4881 .35993 .49863 .35635 .49252 .37481 Mtetra
.38 .04 .259 r
.49252 .37481 .49863 .35635 .50917 .35613 .5032 .3701 Mtetra
.343 0 .178 r
.5032 .3701 .50917 .35613 .51978 .35724 .51391 .36592 Mtetra
.273 0 .006 r
.51391 .36592 .51978 .35724 .53046 .35843 .52466 .36276 Mtetra
.135 0 0 r
.52466 .36276 .53046 .35843 .5412 .35756 .53546 .36048 Mtetra
.159 0 0 r
.53546 .36048 .5412 .35756 .55199 .35503 .54632 .35952 Mtetra
.412 0 0 r
.54632 .35952 .55199 .35503 .56284 .35336 .55727 .361 Mtetra
.544 .086 .116 r
.55727 .361 .56284 .35336 .57377 .35308 .56832 .36471 Mtetra
.585 .178 .238 r
.56832 .36471 .57377 .35308 .58479 .3541 .5795 .36988 Mtetra
.592 .218 .303 r
.5795 .36988 .58479 .3541 .59592 .35649 .59079 .37577 Mtetra
.582 .228 .334 r
.59079 .37577 .59592 .35649 .60717 .36064 .6022 .38139 Mtetra
.567 .22 .341 r
.6022 .38139 .60717 .36064 .61856 .36588 .61368 .38605 Mtetra
.539 .191 .327 r
.61368 .38605 .61856 .36588 .63006 .37106 .62522 .38884 Mtetra
.499 .141 .289 r
.62522 .38884 .63006 .37106 .64164 .37555 .63677 .38955 Mtetra
.428 .045 .209 r
.63677 .38955 .64164 .37555 .65327 .37872 .64832 .38798 Mtetra
.276 0 .026 r
.64832 .38798 .65327 .37872 .66493 .38021 .65984 .38434 Mtetra
0 0 0 r
.65984 .38434 .66493 .38021 .67657 .37949 .67132 .37874 Mtetra
.695 .974 .918 r
.67132 .37874 .67657 .37949 .68817 .37681 .68277 .37176 Mtetra
.783 .857 .905 r
.68277 .37176 .68817 .37681 .69974 .37238 .69421 .36405 Mtetra
.762 .752 .843 r
.69421 .36405 .69974 .37238 .71127 .3667 .70564 .35605 Mtetra
.734 .691 .809 r
.70564 .35605 .71127 .3667 .7228 .36033 .71712 .34832 Mtetra
.714 .659 .794 r
.71712 .34832 .7228 .36033 .73434 .35362 .72864 .34104 Mtetra
.696 .642 .792 r
.72864 .34104 .73434 .35362 .74591 .34703 .74023 .33449 Mtetra
.683 .637 .797 r
.74023 .33449 .74591 .34703 .75753 .3407 .7519 .32863 Mtetra
.67 .639 .81 r
.7519 .32863 .75753 .3407 .76922 .33487 .76367 .32351 Mtetra
.661 .648 .826 r
.76367 .32351 .76922 .33487 .78098 .32948 .77552 .31896 Mtetra
.652 .661 .846 r
.77552 .31896 .78098 .32948 .79282 .32457 .78746 .3149 Mtetra
.645 .678 .867 r
.78746 .3149 .79282 .32457 .80474 .32 .79947 .31116 Mtetra
.641 .698 .888 r
.79947 .31116 .80474 .32 .81672 .31566 .81156 .30761 Mtetra
.639 .721 .907 r
.81156 .30761 .81672 .31566 .82876 .31146 .82371 .3041 Mtetra
.697 .76 .901 r
.18006 .50842 .18679 .51429 .19646 .51065 .18982 .50414 Mtetra
.696 .741 .886 r
.18982 .50414 .19646 .51065 .20617 .50705 .19961 .49978 Mtetra
.69 .718 .87 r
.19961 .49978 .20617 .50705 .21588 .50364 .20943 .49546 Mtetra
.681 .692 .854 r
.20943 .49546 .21588 .50364 .2256 .50054 .21926 .49128 Mtetra
.668 .663 .836 r
.21926 .49128 .2256 .50054 .23532 .4979 .22911 .48734 Mtetra
.65 .63 .817 r
.22911 .48734 .23532 .4979 .24503 .49583 .23894 .48383 Mtetra
.628 .596 .799 r
.23894 .48383 .24503 .49583 .25473 .49447 .24877 .48093 Mtetra
.604 .562 .78 r
.24877 .48093 .25473 .49447 .26442 .49379 .25857 .47877 Mtetra
.578 .529 .765 r
.25857 .47877 .26442 .49379 .2741 .49382 .26834 .47753 Mtetra
.553 .502 .752 r
.26834 .47753 .2741 .49382 .28381 .49429 .27809 .47722 Mtetra
.528 .479 .745 r
.27809 .47722 .28381 .49429 .29356 .49505 .28783 .47789 Mtetra
.506 .465 .746 r
.28783 .47789 .29356 .49505 .30339 .49554 .29757 .47936 Mtetra
.482 .462 .759 r
.29757 .47936 .30339 .49554 .31333 .49534 .30734 .48148 Mtetra
.461 .482 .794 r
.30734 .48148 .31333 .49534 .3234 .49381 .31717 .48374 Mtetra
.425 .539 .869 r
.31717 .48374 .3234 .49381 .33363 .49038 .32708 .48572 Mtetra
.282 .652 .968 r
.32708 .48572 .33363 .49038 .34401 .48492 .33712 .48694 Mtetra
.186 0 0 r
.33712 .48694 .34401 .48492 .35453 .47724 .34728 .48696 Mtetra
.381 0 .09 r
.34728 .48696 .35453 .47724 .36516 .4675 .35757 .48571 Mtetra
.423 .073 .266 r
.35757 .48571 .36516 .4675 .37588 .45591 .36798 .48303 Mtetra
.435 .126 .341 r
.36798 .48303 .37588 .45591 .38663 .44333 .37851 .47872 Mtetra
.44 .153 .379 r
.37851 .47872 .38663 .44333 .39737 .43047 .38914 .4729 Mtetra
.458 .181 .405 r
.38914 .4729 .39737 .43047 .40807 .41828 .39979 .46708 Mtetra
.477 .206 .424 r
.39979 .46708 .40807 .41828 .4187 .40751 .41043 .46217 Mtetra
.493 .226 .437 r
.41043 .46217 .4187 .40751 .42926 .39892 .42107 .45842 Mtetra
.509 .244 .448 r
.42107 .45842 .42926 .39892 .43977 .39273 .4317 .45647 Mtetra
.533 .267 .458 r
.4317 .45647 .43977 .39273 .45027 .38785 .44229 .45807 Mtetra
.551 .286 .467 r
.44229 .45807 .45027 .38785 .46078 .38384 .45289 .46307 Mtetra
.552 .29 .473 r
.45289 .46307 .46078 .38384 .47132 .38085 .46356 .4687 Mtetra
.542 .286 .476 r
.46356 .4687 .47132 .38085 .48189 .37839 .47438 .47244 Mtetra
.512 .263 .473 r
.47438 .47244 .48189 .37839 .49252 .37481 .48537 .46892 Mtetra
.48 .236 .467 r
.48537 .46892 .49252 .37481 .5032 .3701 .49647 .45812 Mtetra
.467 .223 .461 r
.49647 .45812 .5032 .3701 .51391 .36592 .50757 .44539 Mtetra
.462 .216 .455 r
.50757 .44539 .51391 .36592 .52466 .36276 .51866 .43327 Mtetra
.474 .221 .45 r
.51866 .43327 .52466 .36276 .53546 .36048 .52973 .42453 Mtetra
.491 .232 .448 r
.52973 .42453 .53546 .36048 .54632 .35952 .54084 .41937 Mtetra
.501 .236 .445 r
.54084 .41937 .54632 .35952 .55727 .361 .55199 .41602 Mtetra
.506 .237 .44 r
.55199 .41602 .55727 .361 .56832 .36471 .56321 .41385 Mtetra
.51 .234 .432 r
.56321 .41385 .56832 .36471 .5795 .36988 .5745 .4126 Mtetra
.506 .222 .418 r
.5745 .4126 .5795 .36988 .59079 .37577 .58585 .41137 Mtetra
.483 .19 .392 r
.58585 .41137 .59079 .37577 .6022 .38139 .59722 .40861 Mtetra
.439 .131 .344 r
.59722 .40861 .6022 .38139 .61368 .38605 .60861 .40417 Mtetra
.349 .008 .238 r
.60861 .40417 .61368 .38605 .62522 .38884 .62 .39828 Mtetra
.088 0 0 r
.62 .39828 .62522 .38884 .63677 .38955 .63138 .39106 Mtetra
.649 .964 .795 r
.63138 .39106 .63677 .38955 .64832 .38798 .64273 .38261 Mtetra
.816 .846 .871 r
.64273 .38261 .64832 .38798 .65984 .38434 .65406 .37335 Mtetra
.762 .694 .787 r
.65406 .37335 .65984 .38434 .67132 .37874 .66539 .36379 Mtetra
.725 .623 .745 r
.66539 .36379 .67132 .37874 .68277 .37176 .67673 .35434 Mtetra
.698 .586 .726 r
.67673 .35434 .68277 .37176 .69421 .36405 .68812 .34556 Mtetra
.681 .568 .721 r
.68812 .34556 .69421 .36405 .70564 .35605 .69955 .33757 Mtetra
.667 .56 .725 r
.69955 .33757 .70564 .35605 .71712 .34832 .71107 .3306 Mtetra
.657 .561 .735 r
.71107 .3306 .71712 .34832 .72864 .34104 .72267 .32457 Mtetra
.647 .567 .751 r
.72267 .32457 .72864 .34104 .74023 .33449 .73436 .31948 Mtetra
.639 .58 .772 r
.73436 .31948 .74023 .33449 .7519 .32863 .74615 .31516 Mtetra
.632 .598 .797 r
.74615 .31516 .7519 .32863 .76367 .32351 .75804 .31147 Mtetra
.625 .619 .824 r
.75804 .31147 .76367 .32351 .77552 .31896 .77001 .30823 Mtetra
.621 .643 .85 r
.77001 .30823 .77552 .31896 .78746 .3149 .78206 .30523 Mtetra
.617 .666 .875 r
.78206 .30523 .78746 .3149 .79947 .31116 .79418 .30238 Mtetra
.615 .69 .897 r
.79418 .30238 .79947 .31116 .81156 .30761 .80637 .29957 Mtetra
.616 .713 .915 r
.80637 .29957 .81156 .30761 .82371 .3041 .81861 .29669 Mtetra
.7 .761 .899 r
.17328 .5025 .18006 .50842 .18982 .50414 .18307 .4981 Mtetra
.704 .759 .894 r
.18307 .4981 .18982 .50414 .19961 .49978 .19291 .49353 Mtetra
.707 .753 .888 r
.19291 .49353 .19961 .49978 .20943 .49546 .20279 .48881 Mtetra
.708 .742 .878 r
.20279 .48881 .20943 .49546 .21926 .49128 .2127 .48398 Mtetra
.707 .724 .863 r
.2127 .48398 .21926 .49128 .22911 .48734 .22265 .47903 Mtetra
.698 .696 .845 r
.22265 .47903 .22911 .48734 .23894 .48383 .23263 .47414 Mtetra
.683 .662 .823 r
.23263 .47414 .23894 .48383 .24877 .48093 .24261 .46946 Mtetra
.662 .622 .798 r
.24261 .46946 .24877 .48093 .25857 .47877 .25259 .46521 Mtetra
.637 .58 .773 r
.25259 .46521 .25857 .47877 .26834 .47753 .26254 .46159 Mtetra
.611 .539 .748 r
.26254 .46159 .26834 .47753 .27809 .47722 .27247 .4588 Mtetra
.584 .501 .726 r
.27247 .4588 .27809 .47722 .28783 .47789 .28237 .45703 Mtetra
.559 .468 .707 r
.28237 .45703 .28783 .47789 .29757 .47936 .29223 .45636 Mtetra
.535 .439 .693 r
.29223 .45636 .29757 .47936 .30734 .48148 .30206 .4569 Mtetra
.518 .419 .683 r
.30206 .4569 .30734 .48148 .31717 .48374 .31189 .45844 Mtetra
.502 .406 .678 r
.31189 .45844 .31717 .48374 .32708 .48572 .32174 .46083 Mtetra
.494 .403 .681 r
.32174 .46083 .32708 .48572 .33712 .48694 .33164 .46359 Mtetra
.491 .41 .692 r
.33164 .46359 .33712 .48694 .34728 .48696 .34161 .46634 Mtetra
.486 .426 .715 r
.34161 .46634 .34728 .48696 .35757 .48571 .35167 .46895 Mtetra
.481 .459 .756 r
.35167 .46895 .35757 .48571 .36798 .48303 .36183 .47117 Mtetra
.494 .54 .833 r
.36183 .47117 .36798 .48303 .37851 .47872 .37212 .47217 Mtetra
.509 .694 .952 r
.37212 .47217 .37851 .47872 .38914 .4729 .38255 .47159 Mtetra
.297 .775 .924 r
.38255 .47159 .38914 .4729 .39979 .46708 .39306 .47037 Mtetra
.116 0 0 r
.39306 .47037 .39979 .46708 .41043 .46217 .40364 .46888 Mtetra
.236 0 0 r
.40364 .46888 .41043 .46217 .42107 .45842 .4143 .46655 Mtetra
.265 0 0 r
.4143 .46655 .42107 .45842 .4317 .45647 .42502 .46386 Mtetra
.397 0 .015 r
.42502 .46386 .4317 .45647 .44229 .45807 .43572 .46389 Mtetra
.516 .026 .032 r
.43572 .46389 .44229 .45807 .45289 .46307 .4464 .46708 Mtetra
.515 0 0 r
.4464 .46708 .45289 .46307 .46356 .4687 .45717 .47079 Mtetra
.371 0 0 r
.45717 .47079 .46356 .4687 .47438 .47244 .46805 .47297 Mtetra
.372 .84 .843 r
.46805 .47297 .47438 .47244 .48537 .46892 .47909 .46943 Mtetra
.791 .994 .872 r
.47909 .46943 .48537 .46892 .49647 .45812 .49024 .46016 Mtetra
.792 .998 .8 r
.49024 .46016 .49647 .45812 .50757 .44539 .50141 .44932 Mtetra
.639 .932 .676 r
.50141 .44932 .50757 .44539 .51866 .43327 .51257 .43898 Mtetra
0 0 0 r
.51257 .43898 .51866 .43327 .52973 .42453 .52372 .4318 Mtetra
.129 0 0 r
.52372 .4318 .52973 .42453 .54084 .41937 .53491 .42736 Mtetra
.142 0 0 r
.53491 .42736 .54084 .41937 .55199 .41602 .54614 .42255 Mtetra
0 0 0 r
.54614 .42255 .55199 .41602 .56321 .41385 .55739 .41688 Mtetra
.335 .784 .631 r
.55739 .41688 .56321 .41385 .5745 .4126 .56867 .41092 Mtetra
.725 .954 .948 r
.56867 .41092 .5745 .4126 .58585 .41137 .57998 .40431 Mtetra
.779 .784 .857 r
.57998 .40431 .58585 .41137 .59722 .40861 .59127 .39608 Mtetra
.746 .662 .768 r
.59127 .39608 .59722 .40861 .60861 .40417 .60255 .38659 Mtetra
.712 .591 .719 r
.60255 .38659 .60861 .40417 .62 .39828 .61382 .37667 Mtetra
.69 .551 .692 r
.61382 .37667 .62 .39828 .63138 .39106 .6251 .36659 Mtetra
.677 .528 .677 r
.6251 .36659 .63138 .39106 .64273 .38261 .63637 .35647 Mtetra
.666 .515 .67 r
.63637 .35647 .64273 .38261 .65406 .37335 .64765 .34671 Mtetra
.655 .506 .669 r
.64765 .34671 .65406 .37335 .66539 .36379 .65898 .3378 Mtetra
.647 .503 .674 r
.65898 .3378 .66539 .36379 .67673 .35434 .67037 .32991 Mtetra
.638 .505 .684 r
.67037 .32991 .67673 .35434 .68812 .34556 .68183 .32325 Mtetra
.631 .512 .7 r
.68183 .32325 .68812 .34556 .69955 .33757 .69339 .31771 Mtetra
.624 .524 .721 r
.69339 .31771 .69955 .33757 .71107 .3306 .70503 .31323 Mtetra
.617 .542 .747 r
.70503 .31323 .71107 .3306 .72267 .32457 .71678 .30959 Mtetra
.611 .565 .779 r
.71678 .30959 .72267 .32457 .73436 .31948 .72862 .30661 Mtetra
.605 .593 .813 r
.72862 .30661 .73436 .31948 .74615 .31516 .74055 .30408 Mtetra
.601 .625 .848 r
.74055 .30408 .74615 .31516 .75804 .31147 .75256 .30176 Mtetra
.597 .656 .878 r
.75256 .30176 .75804 .31147 .77001 .30823 .76464 .29952 Mtetra
.599 .684 .901 r
.76464 .29952 .77001 .30823 .78206 .30523 .77677 .29715 Mtetra
.601 .705 .917 r
.77677 .29715 .78206 .30523 .79418 .30238 .78895 .29467 Mtetra
.604 .718 .925 r
.78895 .29467 .79418 .30238 .80637 .29957 .80119 .29203 Mtetra
.61 .728 .929 r
.80119 .29203 .80637 .29957 .81861 .29669 .81347 .28921 Mtetra
.687 .758 .906 r
.16646 .49655 .17328 .5025 .18307 .4981 .17623 .49248 Mtetra
.696 .772 .91 r
.17623 .49248 .18307 .4981 .19291 .49353 .18606 .4882 Mtetra
.707 .784 .912 r
.18606 .4882 .19291 .49353 .20279 .48881 .19595 .48361 Mtetra
.719 .791 .909 r
.19595 .48361 .20279 .48881 .2127 .48398 .2059 .47867 Mtetra
.733 .79 .898 r
.2059 .47867 .2127 .48398 .22265 .47903 .21593 .47324 Mtetra
.739 .776 .883 r
.21593 .47324 .22265 .47903 .23263 .47414 .22601 .46745 Mtetra
.74 .75 .86 r
.22601 .46745 .23263 .47414 .24261 .46946 .23613 .46135 Mtetra
.729 .712 .834 r
.23613 .46135 .24261 .46946 .25259 .46521 .24629 .45516 Mtetra
.711 .667 .805 r
.24629 .45516 .25259 .46521 .26254 .46159 .25646 .44906 Mtetra
.686 .618 .774 r
.25646 .44906 .26254 .46159 .27247 .4588 .26663 .44329 Mtetra
.659 .57 .743 r
.26663 .44329 .27247 .4588 .28237 .45703 .27677 .43806 Mtetra
.631 .524 .715 r
.27677 .43806 .28237 .45703 .29223 .45636 .28689 .43361 Mtetra
.603 .484 .69 r
.28689 .43361 .29223 .45636 .30206 .4569 .29696 .43016 Mtetra
.579 .45 .669 r
.29696 .43016 .30206 .4569 .31189 .45844 .307 .42784 Mtetra
.558 .422 .652 r
.307 .42784 .31189 .45844 .32174 .46083 .317 .42678 Mtetra
.544 .403 .639 r
.317 .42678 .32174 .46083 .33164 .46359 .327 .42667 Mtetra
.535 .389 .63 r
.327 .42667 .33164 .46359 .34161 .46634 .33701 .42735 Mtetra
.526 .379 .624 r
.33701 .42735 .34161 .46634 .35167 .46895 .34705 .42878 Mtetra
.52 .373 .621 r
.34705 .42878 .35167 .46895 .36183 .47117 .35712 .43079 Mtetra
.523 .375 .621 r
.35712 .43079 .36183 .47117 .37212 .47217 .36728 .43257 Mtetra
.532 .383 .624 r
.36728 .43257 .37212 .47217 .38255 .47159 .37755 .43355 Mtetra
.543 .394 .629 r
.37755 .43355 .38255 .47159 .39306 .47037 .38794 .43352 Mtetra
.559 .409 .633 r
.38794 .43352 .39306 .47037 .40364 .46888 .39844 .43204 Mtetra
.587 .428 .634 r
.39844 .43204 .40364 .46888 .4143 .46655 .40909 .42785 Mtetra
.609 .44 .628 r
.40909 .42785 .4143 .46655 .42502 .46386 .41987 .42093 Mtetra
.604 .429 .619 r
.41987 .42093 .42502 .46386 .43572 .46389 .43067 .4138 Mtetra
.589 .409 .606 r
.43067 .4138 .43572 .46389 .4464 .46708 .44148 .40748 Mtetra
.577 .391 .593 r
.44148 .40748 .4464 .46708 .45717 .47079 .45229 .40179 Mtetra
.566 .377 .583 r
.45229 .40179 .45717 .47079 .46805 .47297 .46311 .39693 Mtetra
.557 .366 .577 r
.46311 .39693 .46805 .47297 .47909 .46943 .47395 .3933 Mtetra
.551 .361 .577 r
.47395 .3933 .47909 .46943 .49024 .46016 .48482 .3909 Mtetra
.548 .363 .582 r
.48482 .3909 .49024 .46016 .50141 .44932 .49573 .38935 Mtetra
.546 .368 .591 r
.49573 .38935 .50141 .44932 .51257 .43898 .5067 .38843 Mtetra
.542 .375 .605 r
.5067 .38843 .51257 .43898 .52372 .4318 .51773 .38833 Mtetra
.545 .387 .618 r
.51773 .38833 .52372 .4318 .53491 .42736 .52882 .38804 Mtetra
.572 .414 .629 r
.52882 .38804 .53491 .42736 .54614 .42255 .53998 .385 Mtetra
.599 .437 .633 r
.53998 .385 .54614 .42255 .55739 .41688 .55116 .37922 Mtetra
.612 .445 .632 r
.55116 .37922 .55739 .41688 .56867 .41092 .56235 .37195 Mtetra
.618 .447 .628 r
.56235 .37195 .56867 .41092 .57998 .40431 .57355 .36364 Mtetra
.621 .446 .624 r
.57355 .36364 .57998 .40431 .59127 .39608 .58475 .35451 Mtetra
.621 .444 .621 r
.58475 .35451 .59127 .39608 .60255 .38659 .59595 .34512 Mtetra
.617 .441 .622 r
.59595 .34512 .60255 .38659 .61382 .37667 .60717 .33629 Mtetra
.613 .44 .625 r
.60717 .33629 .61382 .37667 .6251 .36659 .61842 .32823 Mtetra
.61 .442 .63 r
.61842 .32823 .6251 .36659 .63637 .35647 .62972 .32095 Mtetra
.607 .446 .638 r
.62972 .32095 .63637 .35647 .64765 .34671 .64107 .31464 Mtetra
.6 .451 .651 r
.64107 .31464 .64765 .34671 .65898 .3378 .65251 .30961 Mtetra
.594 .46 .668 r
.65251 .30961 .65898 .3378 .67037 .32991 .66403 .30573 Mtetra
.588 .475 .692 r
.66403 .30573 .67037 .32991 .68183 .32325 .67565 .30289 Mtetra
.581 .495 .722 r
.67565 .30289 .68183 .32325 .69339 .31771 .68738 .30085 Mtetra
.574 .522 .759 r
.68738 .30085 .69339 .31771 .70503 .31323 .69919 .29938 Mtetra
.567 .557 .802 r
.69919 .29938 .70503 .31323 .71678 .30959 .7111 .29825 Mtetra
.56 .599 .849 r
.7111 .29825 .71678 .30959 .72862 .30661 .72308 .29722 Mtetra
.555 .643 .892 r
.72308 .29722 .72862 .30661 .74055 .30408 .73513 .29611 Mtetra
.557 .686 .926 r
.73513 .29611 .74055 .30408 .75256 .30176 .74724 .29468 Mtetra
.563 .72 .946 r
.74724 .29468 .75256 .30176 .76464 .29952 .75938 .29288 Mtetra
.581 .744 .954 r
.75938 .29288 .76464 .29952 .77677 .29715 .77156 .29058 Mtetra
.597 .755 .954 r
.77156 .29058 .77677 .29715 .78895 .29467 .78377 .2879 Mtetra
.611 .756 .947 r
.78377 .2879 .78895 .29467 .80119 .29203 .79601 .28491 Mtetra
.622 .749 .938 r
.79601 .28491 .80119 .29203 .81347 .28921 .8083 .28168 Mtetra
.668 .754 .915 r
.15958 .49055 .16646 .49655 .17623 .49248 .16933 .48699 Mtetra
.675 .774 .924 r
.16933 .48699 .17623 .49248 .18606 .4882 .17912 .48323 Mtetra
.688 .795 .931 r
.17912 .48323 .18606 .4882 .19595 .48361 .18898 .47915 Mtetra
.704 .817 .935 r
.18898 .47915 .19595 .48361 .2059 .47867 .19892 .47463 Mtetra
.726 .836 .932 r
.19892 .47463 .2059 .47867 .21593 .47324 .20894 .46952 Mtetra
.745 .849 .928 r
.20894 .46952 .21593 .47324 .22601 .46745 .21904 .46387 Mtetra
.763 .855 .918 r
.21904 .46387 .22601 .46745 .23613 .46135 .22922 .45763 Mtetra
.774 .851 .909 r
.22922 .45763 .23613 .46135 .24629 .45516 .23945 .451 Mtetra
.779 .836 .896 r
.23945 .451 .24629 .45516 .25646 .44906 .24972 .44408 Mtetra
.775 .809 .88 r
.24972 .44408 .25646 .44906 .26663 .44329 .26002 .43705 Mtetra
.762 .771 .86 r
.26002 .43705 .26663 .44329 .27677 .43806 .27032 .43011 Mtetra
.74 .722 .835 r
.27032 .43011 .27677 .43806 .28689 .43361 .28062 .42344 Mtetra
.711 .668 .805 r
.28062 .42344 .28689 .43361 .29696 .43016 .29091 .41727 Mtetra
.677 .611 .774 r
.29091 .41727 .29696 .43016 .307 .42784 .30116 .41183 Mtetra
.642 .557 .743 r
.30116 .41183 .307 .42784 .317 .42678 .31137 .40735 Mtetra
.614 .512 .715 r
.31137 .40735 .317 .42678 .327 .42667 .32157 .40375 Mtetra
.591 .476 .691 r
.32157 .40375 .327 .42667 .33701 .42735 .33175 .40101 Mtetra
.572 .448 .672 r
.33175 .40101 .33701 .42735 .34705 .42878 .34192 .39914 Mtetra
.558 .425 .657 r
.34192 .39914 .34705 .42878 .35712 .43079 .3521 .39808 Mtetra
.549 .41 .644 r
.3521 .39808 .35712 .43079 .36728 .43257 .3623 .39755 Mtetra
.546 .402 .637 r
.3623 .39755 .36728 .43257 .37755 .43355 .37256 .39722 Mtetra
.552 .403 .633 r
.37256 .39722 .37755 .43355 .38794 .43352 .3829 .39632 Mtetra
.565 .411 .631 r
.3829 .39632 .38794 .43352 .39844 .43204 .39336 .39415 Mtetra
.589 .426 .629 r
.39336 .39415 .39844 .43204 .40909 .42785 .40395 .38953 Mtetra
.613 .443 .628 r
.40395 .38953 .40909 .42785 .41987 .42093 .41468 .38206 Mtetra
.63 .454 .626 r
.41468 .38206 .41987 .42093 .43067 .4138 .42549 .37241 Mtetra
.634 .453 .62 r
.42549 .37241 .43067 .4138 .44148 .40748 .43634 .3614 Mtetra
.625 .439 .611 r
.43634 .3614 .44148 .40748 .45229 .40179 .44717 .35049 Mtetra
.605 .418 .602 r
.44717 .35049 .45229 .40179 .46311 .39693 .45797 .34138 Mtetra
.565 .385 .596 r
.45797 .34138 .46311 .39693 .47395 .3933 .46867 .33769 Mtetra
.526 .356 .594 r
.46867 .33769 .47395 .3933 .48482 .3909 .47934 .33941 Mtetra
.51 .349 .599 r
.47934 .33941 .48482 .3909 .49573 .38935 .49007 .34296 Mtetra
.506 .353 .608 r
.49007 .34296 .49573 .38935 .5067 .38843 .50089 .34664 Mtetra
.517 .369 .619 r
.50089 .34664 .5067 .38843 .51773 .38833 .51181 .34897 Mtetra
.54 .39 .627 r
.51181 .34897 .51773 .38833 .52882 .38804 .52282 .34913 Mtetra
.569 .412 .629 r
.52282 .34913 .52882 .38804 .53998 .385 .53389 .34641 Mtetra
.592 .428 .629 r
.53389 .34641 .53998 .385 .55116 .37922 .54499 .34122 Mtetra
.604 .438 .63 r
.54499 .34122 .55116 .37922 .56235 .37195 .55612 .33473 Mtetra
.61 .444 .632 r
.55612 .33473 .56235 .37195 .57355 .36364 .56727 .32765 Mtetra
.611 .447 .636 r
.56727 .32765 .57355 .36364 .58475 .35451 .57844 .32076 Mtetra
.61 .452 .643 r
.57844 .32076 .58475 .35451 .59595 .34512 .58965 .31441 Mtetra
.608 .46 .654 r
.58965 .31441 .59595 .34512 .60717 .33629 .6009 .30887 Mtetra
.605 .469 .67 r
.6009 .30887 .60717 .33629 .61842 .32823 .61221 .30421 Mtetra
.601 .483 .69 r
.61221 .30421 .61842 .32823 .62972 .32095 .6236 .30043 Mtetra
.595 .501 .717 r
.6236 .30043 .62972 .32095 .64107 .31464 .63506 .29754 Mtetra
.583 .523 .754 r
.63506 .29754 .64107 .31464 .65251 .30961 .64661 .29564 Mtetra
.567 .554 .799 r
.64661 .29564 .65251 .30961 .66403 .30573 .65827 .29452 Mtetra
.546 .592 .851 r
.65827 .29452 .66403 .30573 .67565 .30289 .67001 .29389 Mtetra
.519 .633 .903 r
.67001 .29389 .67565 .30289 .68738 .30085 .68184 .29357 Mtetra
.489 .673 .946 r
.68184 .29357 .68738 .30085 .69919 .29938 .69376 .29334 Mtetra
.463 .707 .974 r
.69376 .29334 .69919 .29938 .7111 .29825 .70575 .29301 Mtetra
.455 .736 .988 r
.70575 .29301 .7111 .29825 .72308 .29722 .71779 .29239 Mtetra
.467 .759 .994 r
.71779 .29239 .72308 .29722 .73513 .29611 .72989 .29137 Mtetra
.502 .781 .995 r
.72989 .29137 .73513 .29611 .74724 .29468 .74203 .28975 Mtetra
.541 .794 .991 r
.74203 .28975 .74724 .29468 .75938 .29288 .75419 .28756 Mtetra
.584 .798 .981 r
.75419 .28756 .75938 .29288 .77156 .29058 .76637 .28476 Mtetra
.613 .792 .968 r
.76637 .28476 .77156 .29058 .78377 .2879 .77857 .2815 Mtetra
.632 .78 .952 r
.77857 .2815 .78377 .2879 .79601 .28491 .79081 .2779 Mtetra
.643 .764 .936 r
.79081 .2779 .79601 .28491 .8083 .28168 .80308 .27409 Mtetra
.644 .748 .925 r
.15266 .48451 .15958 .49055 .16933 .48699 .16236 .4815 Mtetra
.646 .769 .938 r
.16236 .4815 .16933 .48699 .17912 .48323 .17211 .47839 Mtetra
.653 .795 .951 r
.17211 .47839 .17912 .48323 .18898 .47915 .18192 .47507 Mtetra
.662 .826 .962 r
.18192 .47507 .18898 .47915 .19892 .47463 .1918 .47143 Mtetra
.675 .862 .97 r
.1918 .47143 .19892 .47463 .20894 .46952 .20175 .46735 Mtetra
.684 .901 .974 r
.20175 .46735 .20894 .46952 .21904 .46387 .21178 .46279 Mtetra
.689 .937 .965 r
.21178 .46279 .21904 .46387 .22922 .45763 .22189 .45768 Mtetra
.68 .961 .941 r
.22189 .45768 .22922 .45763 .23945 .451 .23208 .45207 Mtetra
.661 .97 .903 r
.23208 .45207 .23945 .451 .24972 .44408 .24233 .44598 Mtetra
.636 .965 .859 r
.24233 .44598 .24972 .44408 .26002 .43705 .25263 .4395 Mtetra
.62 .957 .826 r
.25263 .4395 .26002 .43705 .27032 .43011 .26298 .43271 Mtetra
.625 .958 .817 r
.26298 .43271 .27032 .43011 .28062 .42344 .27336 .42566 Mtetra
.663 .973 .841 r
.27336 .42566 .28062 .42344 .29091 .41727 .28378 .41843 Mtetra
.715 .984 .891 r
.28378 .41843 .29091 .41727 .30116 .41183 .2942 .41128 Mtetra
.759 .963 .932 r
.2942 .41128 .30116 .41183 .31137 .40735 .30463 .40439 Mtetra
.77 .889 .929 r
.30463 .40439 .31137 .40735 .32157 .40375 .31504 .39784 Mtetra
.744 .785 .886 r
.31504 .39784 .32157 .40375 .33175 .40101 .32545 .39173 Mtetra
.707 .688 .829 r
.32545 .39173 .33175 .40101 .34192 .39914 .33586 .38604 Mtetra
.67 .607 .776 r
.33586 .38604 .34192 .39914 .3521 .39808 .34627 .38084 Mtetra
.631 .541 .734 r
.34627 .38084 .3521 .39808 .3623 .39755 .35665 .37661 Mtetra
.6 .495 .706 r
.35665 .37661 .3623 .39755 .37256 .39722 .36702 .37348 Mtetra
.589 .472 .687 r
.36702 .37348 .37256 .39722 .3829 .39632 .37741 .37067 Mtetra
.589 .462 .676 r
.37741 .37067 .3829 .39632 .39336 .39415 .38786 .36764 Mtetra
.595 .464 .671 r
.38786 .36764 .39336 .39415 .40395 .38953 .39838 .364 Mtetra
.614 .48 .675 r
.39838 .364 .40395 .38953 .41468 .38206 .40898 .35911 Mtetra
.658 .521 .684 r
.40898 .35911 .41468 .38206 .42549 .37241 .41972 .3513 Mtetra
.699 .555 .687 r
.41972 .3513 .42549 .37241 .43634 .3614 .43055 .34062 Mtetra
.71 .563 .687 r
.43055 .34062 .43634 .3614 .44717 .35049 .4414 .32905 Mtetra
.693 .549 .686 r
.4414 .32905 .44717 .35049 .45797 .34138 .45221 .31877 Mtetra
.605 .489 .694 r
.45221 .31877 .45797 .34138 .46867 .33769 .46289 .31504 Mtetra
.485 .412 .699 r
.46289 .31504 .46867 .33769 .47934 .33941 .4735 .31786 Mtetra
.45 .398 .708 r
.4735 .31786 .47934 .33941 .49007 .34296 .48419 .322 Mtetra
.469 .415 .714 r
.48419 .322 .49007 .34296 .50089 .34664 .49497 .32527 Mtetra
.534 .454 .711 r
.49497 .32527 .50089 .34664 .51181 .34897 .50587 .32566 Mtetra
.584 .474 .694 r
.50587 .32566 .51181 .34897 .52282 .34913 .51685 .32313 Mtetra
.597 .469 .677 r
.51685 .32313 .52282 .34913 .53389 .34641 .52788 .31934 Mtetra
.603 .468 .671 r
.52788 .31934 .53389 .34641 .54499 .34122 .53895 .31492 Mtetra
.607 .474 .674 r
.53895 .31492 .54499 .34122 .55612 .33473 .55006 .31029 Mtetra
.607 .483 .685 r
.55006 .31029 .55612 .33473 .56727 .32765 .56121 .30597 Mtetra
.597 .493 .706 r
.56121 .30597 .56727 .32765 .57844 .32076 .57242 .30277 Mtetra
.587 .516 .742 r
.57242 .30277 .57844 .32076 .58965 .31441 .58371 .30056 Mtetra
.582 .562 .797 r
.58371 .30056 .58965 .31441 .6009 .30887 .59506 .29885 Mtetra
.565 .627 .872 r
.59506 .29885 .6009 .30887 .61221 .30421 .60648 .29758 Mtetra
.51 .704 .958 r
.60648 .29758 .61221 .30421 .6236 .30043 .61799 .29676 Mtetra
.37 .751 .989 r
.61799 .29676 .6236 .30043 .63506 .29754 .62957 .2963 Mtetra
.141 .676 .852 r
.62957 .2963 .63506 .29754 .64661 .29564 .64124 .29613 Mtetra
.035 0 0 r
.64124 .29613 .64661 .29564 .65827 .29452 .653 .29603 Mtetra
.108 0 0 r
.653 .29603 .65827 .29452 .67001 .29389 .66482 .29576 Mtetra
.114 0 0 r
.66482 .29576 .67001 .29389 .68184 .29357 .67671 .29525 Mtetra
.07 0 0 r
.67671 .29525 .68184 .29357 .69376 .29334 .68865 .29441 Mtetra
0 0 0 r
.68865 .29441 .69376 .29334 .70575 .29301 .70065 .29318 Mtetra
.155 .697 .766 r
.70065 .29318 .70575 .29301 .71779 .29239 .71269 .29146 Mtetra
.312 .797 .892 r
.71269 .29146 .71779 .29239 .72989 .29137 .72477 .28922 Mtetra
.457 .855 .972 r
.72477 .28922 .72989 .29137 .74203 .28975 .73688 .28641 Mtetra
.556 .864 .996 r
.73688 .28641 .74203 .28975 .75419 .28756 .74901 .2831 Mtetra
.615 .847 .987 r
.74901 .2831 .75419 .28756 .76637 .28476 .76116 .27933 Mtetra
.646 .823 .968 r
.76116 .27933 .76637 .28476 .77857 .2815 .77335 .27522 Mtetra
.66 .798 .948 r
.77335 .27522 .77857 .2815 .79081 .2779 .78556 .27088 Mtetra
.666 .775 .931 r
.78556 .27088 .79081 .2779 .80308 .27409 .79782 .26643 Mtetra
.62 .742 .934 r
.14569 .47843 .15266 .48451 .16236 .4815 .15536 .4759 Mtetra
.612 .757 .948 r
.15536 .4759 .16236 .4815 .17211 .47839 .16505 .47346 Mtetra
.6 .78 .966 r
.16505 .47346 .17211 .47839 .18192 .47507 .17478 .47109 Mtetra
.58 .811 .987 r
.17478 .47109 .18192 .47507 .1918 .47143 .18455 .46876 Mtetra
.534 .846 .999 r
.18455 .46876 .1918 .47143 .20175 .46735 .19436 .46646 Mtetra
.439 .857 .954 r
.19436 .46646 .20175 .46735 .21178 .46279 .20422 .46403 Mtetra
.267 .773 .78 r
.20422 .46403 .21178 .46279 .22189 .45768 .21414 .46138 Mtetra
0 0 0 r
.21414 .46138 .22189 .45768 .23208 .45207 .22414 .45836 Mtetra
.075 0 0 r
.22414 .45836 .23208 .45207 .24233 .44598 .23423 .45482 Mtetra
.159 0 0 r
.23423 .45482 .24233 .44598 .25263 .4395 .24441 .4507 Mtetra
.203 0 .008 r
.24441 .4507 .25263 .4395 .26298 .43271 .25467 .44593 Mtetra
.223 0 .068 r
.25467 .44593 .26298 .43271 .27336 .42566 .26502 .44044 Mtetra
.225 0 .1 r
.26502 .44044 .27336 .42566 .28378 .41843 .27545 .43417 Mtetra
.223 0 .117 r
.27545 .43417 .28378 .41843 .2942 .41128 .28595 .42737 Mtetra
.215 0 .12 r
.28595 .42737 .2942 .41128 .30463 .40439 .29649 .42016 Mtetra
.2 0 .108 r
.29649 .42016 .30463 .40439 .31504 .39784 .30707 .41275 Mtetra
.177 0 .082 r
.30707 .41275 .31504 .39784 .32545 .39173 .31766 .40528 Mtetra
.131 0 .031 r
.31766 .40528 .32545 .39173 .33586 .38604 .32828 .39768 Mtetra
.059 0 0 r
.32828 .39768 .33586 .38604 .34627 .38084 .33891 .39008 Mtetra
.016 0 0 r
.33891 .39008 .34627 .38084 .35665 .37661 .34949 .38351 Mtetra
.004 0 0 r
.34949 .38351 .35665 .37661 .36702 .37348 .36002 .37846 Mtetra
0 0 0 r
.36002 .37846 .36702 .37348 .37741 .37067 .37054 .37436 Mtetra
.37054 .37436 .37741 .37067 .38786 .36764 .38106 .37106 Mtetra
.079 0 0 r
.38106 .37106 .38786 .36764 .39838 .364 .39156 .36921 Mtetra
.27 0 0 r
.39156 .36921 .39838 .364 .40898 .35911 .40207 .36833 Mtetra
.261 0 0 r
.40207 .36833 .40898 .35911 .41972 .3513 .41273 .36519 Mtetra
.227 0 .096 r
.41273 .36519 .41972 .3513 .43055 .34062 .42353 .3589 Mtetra
.241 0 .175 r
.42353 .3589 .43055 .34062 .4414 .32905 .43442 .35062 Mtetra
.285 0 .232 r
.43442 .35062 .4414 .32905 .45221 .31877 .44532 .34203 Mtetra
.419 .091 .3 r
.44532 .34203 .45221 .31877 .46289 .31504 .45612 .33829 Mtetra
.508 .172 .332 r
.45612 .33829 .46289 .31504 .4735 .31786 .46689 .33941 Mtetra
.501 .157 .316 r
.46689 .33941 .4735 .31786 .48419 .322 .47773 .34024 Mtetra
.451 .092 .265 r
.47773 .34024 .48419 .322 .49497 .32527 .48867 .33908 Mtetra
.316 0 .14 r
.48867 .33908 .49497 .32527 .50587 .32566 .49969 .33476 Mtetra
.058 0 0 r
.49969 .33476 .50587 .32566 .51685 .32313 .51077 .32815 Mtetra
0 0 0 r
.51077 .32815 .51685 .32313 .52788 .31934 .52187 .32251 Mtetra
.52187 .32251 .52788 .31934 .53895 .31492 .53301 .31833 Mtetra
.53301 .31833 .53895 .31492 .55006 .31029 .5442 .31497 Mtetra
.133 0 0 r
.5442 .31497 .55006 .31029 .56121 .30597 .55544 .31256 Mtetra
.321 0 0 r
.55544 .31256 .56121 .30597 .57242 .30277 .56677 .31171 Mtetra
.417 0 .065 r
.56677 .31171 .57242 .30277 .58371 .30056 .57818 .31192 Mtetra
.443 .022 .144 r
.57818 .31192 .58371 .30056 .59506 .29885 .58966 .31213 Mtetra
.454 .053 .188 r
.58966 .31213 .59506 .29885 .60648 .29758 .60122 .31223 Mtetra
.461 .072 .214 r
.60122 .31223 .60648 .29758 .61799 .29676 .61286 .31228 Mtetra
.46 .078 .227 r
.61286 .31228 .61799 .29676 .62957 .2963 .62457 .31213 Mtetra
.452 .073 .228 r
.62457 .31213 .62957 .2963 .64124 .29613 .63634 .31158 Mtetra
.436 .055 .216 r
.63634 .31158 .64124 .29613 .653 .29603 .64816 .31048 Mtetra
.408 .021 .189 r
.64816 .31048 .653 .29603 .66482 .29576 .66003 .30859 Mtetra
.369 0 .142 r
.66003 .30859 .66482 .29576 .67671 .29525 .67192 .30597 Mtetra
.31 0 .066 r
.67192 .30597 .67671 .29525 .68865 .29441 .68384 .30266 Mtetra
.217 0 0 r
.68384 .30266 .68865 .29441 .70065 .29318 .69579 .29876 Mtetra
.061 0 0 r
.69579 .29876 .70065 .29318 .71269 .29146 .70775 .29431 Mtetra
0 0 0 r
.70775 .29431 .71269 .29146 .72477 .28922 .71975 .28947 Mtetra
.454 .885 .842 r
.71975 .28947 .72477 .28922 .73688 .28641 .73177 .28439 Mtetra
.617 .932 .965 r
.73177 .28439 .73688 .28641 .74901 .2831 .74382 .27918 Mtetra
.674 .89 .977 r
.74382 .27918 .74901 .2831 .76116 .27933 .75592 .27399 Mtetra
.688 .843 .958 r
.75592 .27399 .76116 .27933 .77335 .27522 .76807 .26883 Mtetra
.688 .807 .938 r
.76807 .26883 .77335 .27522 .78556 .27088 .78027 .26373 Mtetra
.684 .78 .923 r
.78027 .26373 .78556 .27088 .79782 .26643 .79252 .25872 Mtetra
.601 .736 .94 r
.13868 .4723 .14569 .47843 .15536 .4759 .14832 .47012 Mtetra
.579 .743 .954 r
.14832 .47012 .15536 .4759 .16505 .47346 .15797 .46826 Mtetra
.546 .754 .973 r
.15797 .46826 .16505 .47346 .17478 .47109 .16762 .46677 Mtetra
.485 .766 .993 r
.16762 .46677 .17478 .47109 .18455 .46876 .17727 .46571 Mtetra
.356 .757 .984 r
.17727 .46571 .18455 .46876 .19436 .46646 .18692 .46523 Mtetra
.151 .682 .861 r
.18692 .46523 .19436 .46646 .20422 .46403 .19659 .46506 Mtetra
.097 0 0 r
.19659 .46506 .20422 .46403 .21414 .46138 .20629 .46507 Mtetra
.257 0 0 r
.20629 .46507 .21414 .46138 .22414 .45836 .21608 .4649 Mtetra
.327 0 0 r
.21608 .4649 .22414 .45836 .23423 .45482 .22596 .46426 Mtetra
.356 0 .049 r
.22596 .46426 .23423 .45482 .24441 .4507 .23595 .46299 Mtetra
.362 0 .124 r
.23595 .46299 .24441 .4507 .25467 .44593 .24607 .46086 Mtetra
.359 0 .171 r
.24607 .46086 .25467 .44593 .26502 .44044 .25631 .45778 Mtetra
.349 0 .201 r
.25631 .45778 .26502 .44044 .27545 .43417 .26669 .4536 Mtetra
.343 0 .223 r
.26669 .4536 .27545 .43417 .28595 .42737 .27716 .4485 Mtetra
.337 0 .238 r
.27716 .4485 .28595 .42737 .29649 .42016 .28773 .44258 Mtetra
.334 .004 .248 r
.28773 .44258 .29649 .42016 .30707 .41275 .29836 .43606 Mtetra
.331 .007 .255 r
.29836 .43606 .30707 .41275 .31766 .40528 .30905 .42909 Mtetra
.321 0 .255 r
.30905 .42909 .31766 .40528 .32828 .39768 .31979 .42152 Mtetra
.309 0 .251 r
.31979 .42152 .32828 .39768 .33891 .39008 .33058 .41345 Mtetra
.325 .002 .255 r
.33058 .41345 .33891 .39008 .34949 .38351 .34133 .40611 Mtetra
.356 .027 .263 r
.34133 .40611 .34949 .38351 .36002 .37846 .35203 .40019 Mtetra
.378 .043 .265 r
.35203 .40019 .36002 .37846 .37054 .37436 .3627 .39538 Mtetra
.407 .066 .271 r
.3627 .39538 .37054 .37436 .38106 .37106 .37334 .39194 Mtetra
.479 .133 .301 r
.37334 .39194 .38106 .37106 .39156 .36921 .38388 .39177 Mtetra
.537 .196 .337 r
.38388 .39177 .39156 .36921 .40207 .36833 .39435 .39481 Mtetra
.527 .2 .356 r
.39435 .39481 .40207 .36833 .41273 .36519 .40494 .39715 Mtetra
.499 .189 .372 r
.40494 .39715 .41273 .36519 .42353 .3589 .41569 .39712 Mtetra
.471 .177 .384 r
.41569 .39712 .42353 .3589 .43442 .35062 .42659 .3942 Mtetra
.454 .171 .393 r
.42659 .3942 .43442 .35062 .44532 .34203 .43761 .38893 Mtetra
.475 .194 .407 r
.43761 .38893 .44532 .34203 .45612 .33829 .44863 .38521 Mtetra
.489 .206 .411 r
.44863 .38521 .45612 .33829 .46689 .33941 .45966 .38303 Mtetra
.463 .179 .396 r
.45966 .38303 .46689 .33941 .47773 .34024 .47078 .37852 Mtetra
.417 .13 .368 r
.47078 .37852 .47773 .34024 .48867 .33908 .48199 .37108 Mtetra
.353 .062 .324 r
.48199 .37108 .48867 .33908 .49969 .33476 .49323 .36124 Mtetra
.295 0 .274 r
.49323 .36124 .49969 .33476 .51077 .32815 .50449 .35067 Mtetra
.333 .009 .258 r
.50449 .35067 .51077 .32815 .52187 .32251 .51573 .34333 Mtetra
.397 .056 .266 r
.51573 .34333 .52187 .32251 .53301 .31833 .527 .33928 Mtetra
.429 .085 .279 r
.527 .33928 .53301 .31833 .5442 .31497 .53832 .33663 Mtetra
.455 .112 .294 r
.53832 .33663 .5442 .31497 .55544 .31256 .54971 .33511 Mtetra
.483 .141 .31 r
.54971 .33511 .55544 .31256 .56677 .31171 .56117 .33503 Mtetra
.497 .157 .32 r
.56117 .33503 .56677 .31171 .57818 .31192 .57272 .33571 Mtetra
.49 .152 .321 r
.57272 .33571 .57818 .31192 .58966 .31213 .58434 .3359 Mtetra
.48 .143 .317 r
.58434 .3359 .58966 .31213 .60122 .31223 .59603 .33549 Mtetra
.471 .133 .31 r
.59603 .33549 .60122 .31223 .61286 .31228 .60779 .33463 Mtetra
.458 .116 .298 r
.60779 .33463 .61286 .31228 .62457 .31213 .61959 .33315 Mtetra
.437 .091 .28 r
.61959 .33315 .62457 .31213 .63634 .31158 .63144 .33084 Mtetra
.408 .055 .252 r
.63144 .33084 .63634 .31158 .64816 .31048 .64331 .32758 Mtetra
.363 .001 .21 r
.64331 .32758 .64816 .31048 .66003 .30859 .6552 .32319 Mtetra
.302 0 .148 r
.6552 .32319 .66003 .30859 .67192 .30597 .66709 .31781 Mtetra
.213 0 .053 r
.66709 .31781 .67192 .30597 .68384 .30266 .67897 .31153 Mtetra
.076 0 0 r
.67897 .31153 .68384 .30266 .69579 .29876 .69086 .30459 Mtetra
0 0 0 r
.69086 .30459 .69579 .29876 .70775 .29431 .70274 .29713 Mtetra
.419 .828 .635 r
.70274 .29713 .70775 .29431 .71975 .28947 .71464 .28949 Mtetra
.641 .966 .866 r
.71464 .28949 .71975 .28947 .73177 .28439 .72657 .28202 Mtetra
.73 .956 .946 r
.72657 .28202 .73177 .28439 .74382 .27918 .73855 .27485 Mtetra
.735 .895 .952 r
.73855 .27485 .74382 .27918 .75592 .27399 .75061 .26827 Mtetra
.723 .843 .938 r
.75061 .26827 .75592 .27399 .76807 .26883 .76273 .26214 Mtetra
.709 .805 .925 r
.76273 .26214 .76807 .26883 .78027 .26373 .77492 .25638 Mtetra
.697 .781 .916 r
.77492 .25638 .78027 .26373 .79252 .25872 .78718 .25095 Mtetra
.588 .732 .943 r
.13161 .46613 .13868 .4723 .14832 .47012 .14124 .46417 Mtetra
.561 .732 .955 r
.14124 .46417 .14832 .47012 .15797 .46826 .15087 .46262 Mtetra
.522 .73 .969 r
.15087 .46262 .15797 .46826 .16762 .46677 .16049 .46155 Mtetra
.467 .725 .982 r
.16049 .46155 .16762 .46677 .17727 .46571 .17011 .46101 Mtetra
.375 .706 .985 r
.17011 .46101 .17727 .46571 .18692 .46523 .1797 .46119 Mtetra
.296 .691 .975 r
.1797 .46119 .18692 .46523 .19659 .46506 .18932 .46171 Mtetra
.227 .677 .952 r
.18932 .46171 .19659 .46506 .20629 .46507 .19898 .46235 Mtetra
.206 .684 .934 r
.19898 .46235 .20629 .46507 .21608 .4649 .20873 .46276 Mtetra
.239 .721 .932 r
.20873 .46276 .21608 .4649 .22596 .46426 .2186 .46256 Mtetra
.282 .757 .934 r
.2186 .46256 .22596 .46426 .23595 .46299 .22858 .46176 Mtetra
.334 .797 .934 r
.22858 .46176 .23595 .46299 .24607 .46086 .23868 .46025 Mtetra
.368 .827 .92 r
.23868 .46025 .24607 .46086 .25631 .45778 .24889 .45805 Mtetra
.379 .842 .88 r
.24889 .45805 .25631 .45778 .26669 .4536 .2592 .45511 Mtetra
.336 .816 .79 r
.2592 .45511 .26669 .4536 .27716 .4485 .26961 .45155 Mtetra
0 0 0 r
.26961 .45155 .27716 .4485 .28773 .44258 .2801 .44742 Mtetra
.2801 .44742 .28773 .44258 .29836 .43606 .29066 .4428 Mtetra
.29066 .4428 .29836 .43606 .30905 .42909 .30129 .43778 Mtetra
.037 0 0 r
.30129 .43778 .30905 .42909 .31979 .42152 .31199 .43207 Mtetra
.081 0 0 r
.31199 .43207 .31979 .42152 .33058 .41345 .32276 .42568 Mtetra
.158 0 .005 r
.32276 .42568 .33058 .41345 .34133 .40611 .33354 .41944 Mtetra
.225 0 .068 r
.33354 .41944 .34133 .40611 .35203 .40019 .34432 .41383 Mtetra
.25 0 .088 r
.34432 .41383 .35203 .40019 .3627 .39538 .3551 .40855 Mtetra
.28 0 .095 r
.3551 .40855 .3627 .39538 .37334 .39194 .36588 .40411 Mtetra
.42 .008 .149 r
.36588 .40411 .37334 .39194 .38388 .39177 .37652 .40352 Mtetra
.548 .135 .211 r
.37652 .40352 .38388 .39177 .39435 .39481 .38703 .4073 Mtetra
.567 .162 .233 r
.38703 .4073 .39435 .39481 .40494 .39715 .39761 .41194 Mtetra
.544 .155 .255 r
.39761 .41194 .40494 .39715 .41569 .39712 .40832 .41554 Mtetra
.484 .12 .272 r
.40832 .41554 .41569 .39712 .42659 .3942 .41922 .41609 Mtetra
.423 .081 .28 r
.41922 .41609 .42659 .3942 .43761 .38893 .4303 .41319 Mtetra
.418 .088 .296 r
.4303 .41319 .43761 .38893 .44863 .38521 .44145 .40947 Mtetra
.401 .073 .29 r
.44145 .40947 .44863 .38521 .45966 .38303 .45266 .40492 Mtetra
.3 0 .231 r
.45266 .40492 .45966 .38303 .47078 .37852 .46399 .3969 Mtetra
.141 0 .125 r
.46399 .3969 .47078 .37852 .48199 .37108 .47537 .3858 Mtetra
0 0 0 r
.47537 .3858 .48199 .37108 .49323 .36124 .48676 .37363 Mtetra
.48676 .37363 .49323 .36124 .50449 .35067 .49814 .36229 Mtetra
.138 0 0 r
.49814 .36229 .50449 .35067 .51573 .34333 .50948 .35535 Mtetra
.328 0 .097 r
.50948 .35535 .51573 .34333 .527 .33928 .52085 .35229 Mtetra
.374 0 .14 r
.52085 .35229 .527 .33928 .53832 .33663 .53227 .35009 Mtetra
.391 0 .156 r
.53227 .35009 .53832 .33663 .54971 .33511 .54375 .34823 Mtetra
.408 .004 .157 r
.54375 .34823 .54971 .33511 .56117 .33503 .5553 .34702 Mtetra
.402 0 .129 r
.5553 .34702 .56117 .33503 .57272 .33571 .56693 .34597 Mtetra
.352 0 .06 r
.56693 .34597 .57272 .33571 .58434 .3359 .57861 .34422 Mtetra
.278 0 0 r
.57861 .34422 .58434 .3359 .59603 .33549 .59034 .34179 Mtetra
.183 0 0 r
.59034 .34179 .59603 .33549 .60779 .33463 .60212 .33893 Mtetra
.036 0 0 r
.60212 .33893 .60779 .33463 .61959 .33315 .61395 .33559 Mtetra
0 0 0 r
.61395 .33559 .61959 .33315 .63144 .33084 .62581 .33166 Mtetra
.383 .844 .802 r
.62581 .33166 .63144 .33084 .64331 .32758 .6377 .32707 Mtetra
.553 .929 .912 r
.6377 .32707 .64331 .32758 .6552 .32319 .64961 .32173 Mtetra
.652 .952 .947 r
.64961 .32173 .6552 .32319 .66709 .31781 .66153 .31566 Mtetra
.714 .954 .95 r
.66153 .31566 .66709 .31781 .67897 .31153 .67345 .30884 Mtetra
.753 .948 .943 r
.67345 .30884 .67897 .31153 .69086 .30459 .68537 .30139 Mtetra
.781 .937 .931 r
.68537 .30139 .69086 .30459 .70274 .29713 .69728 .29329 Mtetra
.793 .919 .923 r
.69728 .29329 .70274 .29713 .71464 .28949 .7092 .28494 Mtetra
.79 .896 .918 r
.7092 .28494 .71464 .28949 .72657 .28202 .72114 .27669 Mtetra
.779 .869 .915 r
.72114 .27669 .72657 .28202 .73855 .27485 .73312 .26878 Mtetra
.755 .84 .916 r
.73312 .26878 .73855 .27485 .75061 .26827 .74518 .2616 Mtetra
.736 .816 .914 r
.74518 .2616 .75061 .26827 .76273 .26214 .75731 .25497 Mtetra
.719 .795 .911 r
.75731 .25497 .76273 .26214 .77492 .25638 .76952 .24883 Mtetra
.704 .779 .909 r
.76952 .24883 .77492 .25638 .78718 .25095 .7818 .24311 Mtetra
.589 .733 .943 r
.12449 .45992 .13161 .46613 .14124 .46417 .13414 .45793 Mtetra
.566 .725 .948 r
.13414 .45793 .14124 .46417 .15087 .46262 .14379 .45632 Mtetra
.543 .715 .952 r
.14379 .45632 .15087 .46262 .16049 .46155 .15344 .45509 Mtetra
.518 .701 .953 r
.15344 .45509 .16049 .46155 .17011 .46101 .1631 .45425 Mtetra
.489 .679 .95 r
.1631 .45425 .17011 .46101 .1797 .46119 .17276 .45391 Mtetra
.492 .663 .938 r
.17276 .45391 .1797 .46119 .18932 .46171 .18247 .45366 Mtetra
.515 .649 .918 r
.18247 .45366 .18932 .46171 .19898 .46235 .19225 .45324 Mtetra
.545 .632 .888 r
.19225 .45324 .19898 .46235 .20873 .46276 .20212 .45242 Mtetra
.578 .617 .855 r
.20212 .45242 .20873 .46276 .2186 .46256 .21212 .45092 Mtetra
.592 .597 .826 r
.21212 .45092 .2186 .46256 .22858 .46176 .2222 .44901 Mtetra
.598 .582 .806 r
.2222 .44901 .22858 .46176 .23868 .46025 .23235 .44683 Mtetra
.6 .573 .795 r
.23235 .44683 .23868 .46025 .24889 .45805 .24257 .44452 Mtetra
.599 .571 .794 r
.24257 .44452 .24889 .45805 .2592 .45511 .25283 .44221 Mtetra
.602 .582 .804 r
.25283 .44221 .2592 .45511 .26961 .45155 .26314 .43987 Mtetra
.605 .606 .825 r
.26314 .43987 .26961 .45155 .2801 .44742 .27351 .43749 Mtetra
.609 .645 .86 r
.27351 .43749 .2801 .44742 .29066 .4428 .28392 .43506 Mtetra
.611 .704 .91 r
.28392 .43506 .29066 .4428 .30129 .43778 .29439 .43255 Mtetra
.616 .791 .965 r
.29439 .43255 .30129 .43778 .31199 .43207 .30494 .42961 Mtetra
.594 .884 .991 r
.30494 .42961 .31199 .43207 .32276 .42568 .31557 .42607 Mtetra
.476 .895 .895 r
.31557 .42607 .32276 .42568 .33354 .41944 .32627 .42199 Mtetra
.337 .805 .715 r
.32627 .42199 .33354 .41944 .34432 .41383 .33705 .41736 Mtetra
.348 .797 .653 r
.33705 .41736 .34432 .41383 .3551 .40855 .34792 .41173 Mtetra
.425 .85 .706 r
.34792 .41173 .3551 .40855 .36588 .40411 .35884 .40564 Mtetra
.196 .72 .715 r
.35884 .40564 .36588 .40411 .37652 .40352 .36962 .40294 Mtetra
.17 0 0 r
.36962 .40294 .37652 .40352 .38703 .4073 .38026 .40476 Mtetra
0 .348 .671 r
.38026 .40476 .38703 .4073 .39761 .41194 .39089 .40864 Mtetra
0 .35 .71 r
.39089 .40864 .39761 .41194 .40832 .41554 .40159 .41296 Mtetra
.024 .564 .845 r
.40159 .41296 .40832 .41554 .41922 .41609 .41249 .41471 Mtetra
.345 .805 .935 r
.41249 .41471 .41922 .41609 .4303 .41319 .42358 .4129 Mtetra
.459 .882 .914 r
.42358 .4129 .4303 .41319 .44145 .40947 .43478 .40915 Mtetra
.622 .951 .931 r
.43478 .40915 .44145 .40947 .45266 .40492 .44607 .40347 Mtetra
.821 .959 .901 r
.44607 .40347 .45266 .40492 .46399 .3969 .45748 .3942 Mtetra
.876 .913 .85 r
.45748 .3942 .46399 .3969 .47537 .3858 .46894 .38232 Mtetra
.866 .894 .853 r
.46894 .38232 .47537 .3858 .48676 .37363 .48038 .37086 Mtetra
.83 .925 .896 r
.48038 .37086 .48676 .37363 .49814 .36229 .49179 .36145 Mtetra
.577 .93 .945 r
.49179 .36145 .49814 .36229 .50948 .35535 .50318 .3566 Mtetra
0 0 0 r
.50318 .3566 .50948 .35535 .52085 .35229 .5146 .35518 Mtetra
.045 0 0 r
.5146 .35518 .52085 .35229 .53227 .35009 .52609 .35329 Mtetra
0 0 0 r
.52609 .35329 .53227 .35009 .54375 .34823 .53763 .35039 Mtetra
.53763 .35039 .54375 .34823 .5553 .34702 .54923 .34694 Mtetra
.431 .872 .883 r
.54923 .34694 .5553 .34702 .56693 .34597 .56087 .34294 Mtetra
.639 .899 .984 r
.56087 .34294 .56693 .34597 .57861 .34422 .57255 .33831 Mtetra
.692 .814 .94 r
.57255 .33831 .57861 .34422 .59034 .34179 .58427 .33325 Mtetra
.688 .732 .884 r
.58427 .33325 .59034 .34179 .60212 .33893 .59602 .3281 Mtetra
.677 .673 .839 r
.59602 .3281 .60212 .33893 .61395 .33559 .60782 .32288 Mtetra
.667 .635 .808 r
.60782 .32288 .61395 .33559 .62581 .33166 .61966 .31762 Mtetra
.66 .611 .789 r
.61966 .31762 .62581 .33166 .6377 .32707 .63154 .31232 Mtetra
.656 .6 .78 r
.63154 .31232 .6377 .32707 .64961 .32173 .64346 .30702 Mtetra
.659 .602 .781 r
.64346 .30702 .64961 .32173 .66153 .31566 .65542 .30158 Mtetra
.668 .616 .788 r
.65542 .30158 .66153 .31566 .67345 .30884 .6674 .29584 Mtetra
.683 .641 .801 r
.6674 .29584 .67345 .30884 .68537 .30139 .67941 .28967 Mtetra
.707 .674 .816 r
.67941 .28967 .68537 .30139 .69728 .29329 .69141 .28278 Mtetra
.725 .706 .832 r
.69141 .28278 .69728 .29329 .7092 .28494 .70342 .27548 Mtetra
.739 .736 .848 r
.70342 .27548 .7092 .28494 .72114 .27669 .71544 .26796 Mtetra
.743 .757 .863 r
.71544 .26796 .72114 .27669 .73312 .26878 .7275 .26054 Mtetra
.735 .768 .88 r
.7275 .26054 .73312 .26878 .74518 .2616 .73962 .25362 Mtetra
.726 .773 .891 r
.73962 .25362 .74518 .2616 .75731 .25497 .7518 .2471 Mtetra
.715 .774 .898 r
.7518 .2471 .75731 .25497 .76952 .24883 .76405 .24096 Mtetra
.703 .771 .904 r
.76405 .24096 .76952 .24883 .7818 .24311 .77637 .23521 Mtetra
.613 .74 .936 r
.11732 .45366 .12449 .45992 .13414 .45793 .12704 .45119 Mtetra
.607 .723 .927 r
.12704 .45119 .13414 .45793 .14379 .45632 .13679 .44887 Mtetra
.605 .7 .911 r
.13679 .44887 .14379 .45632 .15344 .45509 .14657 .44664 Mtetra
.604 .672 .888 r
.14657 .44664 .15344 .45509 .1631 .45425 .15639 .44445 Mtetra
.603 .638 .858 r
.15639 .44445 .1631 .45425 .17276 .45391 .16625 .44229 Mtetra
.605 .602 .822 r
.16625 .44229 .17276 .45391 .18247 .45366 .17618 .43995 Mtetra
.61 .571 .786 r
.17618 .43995 .18247 .45366 .19225 .45324 .18618 .43726 Mtetra
.608 .543 .755 r
.18618 .43726 .19225 .45324 .20212 .45242 .19626 .43432 Mtetra
.607 .521 .732 r
.19626 .43432 .20212 .45242 .21212 .45092 .2064 .43114 Mtetra
.598 .503 .717 r
.2064 .43114 .21212 .45092 .2222 .44901 .21656 .42814 Mtetra
.586 .488 .71 r
.21656 .42814 .2222 .44901 .23235 .44683 .22672 .42567 Mtetra
.576 .48 .708 r
.22672 .42567 .23235 .44683 .24257 .44452 .23688 .42367 Mtetra
.566 .476 .712 r
.23688 .42367 .24257 .44452 .25283 .44221 .24704 .4222 Mtetra
.562 .48 .72 r
.24704 .4222 .25283 .44221 .26314 .43987 .25724 .42098 Mtetra
.561 .489 .732 r
.25724 .42098 .26314 .43987 .27351 .43749 .26749 .41985 Mtetra
.557 .499 .746 r
.26749 .41985 .27351 .43749 .28392 .43506 .27777 .41892 Mtetra
.552 .513 .766 r
.27777 .41892 .28392 .43506 .29439 .43255 .2881 .41819 Mtetra
.552 .537 .792 r
.2881 .41819 .29439 .43255 .30494 .42961 .29849 .41742 Mtetra
.56 .578 .828 r
.29849 .41742 .30494 .42961 .31557 .42607 .30896 .41635 Mtetra
.599 .649 .871 r
.30896 .41635 .31557 .42607 .32627 .42199 .31957 .41414 Mtetra
.661 .722 .895 r
.31957 .41414 .32627 .42199 .33705 .41736 .33032 .41025 Mtetra
.733 .764 .877 r
.33032 .41025 .33705 .41736 .34792 .41173 .34125 .40401 Mtetra
.769 .755 .84 r
.34125 .40401 .34792 .41173 .35884 .40564 .35231 .39586 Mtetra
.703 .691 .835 r
.35231 .39586 .35884 .40564 .36962 .40294 .36327 .39004 Mtetra
.586 .581 .814 r
.36327 .39004 .36962 .40294 .38026 .40476 .37407 .38811 Mtetra
.514 .489 .766 r
.37407 .38811 .38026 .40476 .39089 .40864 .38482 .38873 Mtetra
.483 .437 .73 r
.38482 .38873 .39089 .40864 .40159 .41296 .39558 .39082 Mtetra
.525 .447 .71 r
.39558 .39082 .40159 .41296 .41249 .41471 .40649 .39131 Mtetra
.574 .47 .698 r
.40649 .39131 .41249 .41471 .42358 .4129 .41756 .38915 Mtetra
.599 .484 .694 r
.41756 .38915 .42358 .4129 .43478 .40915 .42873 .38536 Mtetra
.622 .499 .691 r
.42873 .38536 .43478 .40915 .44607 .40347 .43999 .37994 Mtetra
.657 .522 .688 r
.43999 .37994 .44607 .40347 .45748 .3942 .45135 .37184 Mtetra
.682 .543 .69 r
.45135 .37184 .45748 .3942 .46894 .38232 .46276 .36213 Mtetra
.675 .553 .709 r
.46276 .36213 .46894 .38232 .48038 .37086 .47415 .35387 Mtetra
.653 .568 .746 r
.47415 .35387 .48038 .37086 .49179 .36145 .48553 .34818 Mtetra
.579 .576 .814 r
.48553 .34818 .49179 .36145 .50318 .3566 .4969 .34641 Mtetra
.478 .588 .886 r
.4969 .34641 .50318 .3566 .5146 .35518 .50832 .34701 Mtetra
.547 .681 .926 r
.50832 .34701 .5146 .35518 .52609 .35329 .51983 .34568 Mtetra
.644 .74 .918 r
.51983 .34568 .52609 .35329 .53763 .35039 .5314 .34198 Mtetra
.697 .736 .881 r
.5314 .34198 .53763 .35039 .54923 .34694 .54301 .33656 Mtetra
.712 .696 .832 r
.54301 .33656 .54923 .34694 .56087 .34294 .55465 .32997 Mtetra
.699 .644 .791 r
.55465 .32997 .56087 .34294 .57255 .33831 .56632 .32306 Mtetra
.684 .606 .763 r
.56632 .32306 .57255 .33831 .58427 .33325 .57801 .3161 Mtetra
.669 .578 .744 r
.57801 .3161 .58427 .33325 .59602 .3281 .58973 .30934 Mtetra
.657 .557 .73 r
.58973 .30934 .59602 .3281 .60782 .32288 .60149 .30276 Mtetra
.649 .542 .719 r
.60149 .30276 .60782 .32288 .61966 .31762 .61328 .29627 Mtetra
.64 .528 .71 r
.61328 .29627 .61966 .31762 .63154 .31232 .62511 .29002 Mtetra
.629 .515 .705 r
.62511 .29002 .63154 .31232 .64346 .30702 .637 .28432 Mtetra
.62 .507 .703 r
.637 .28432 .64346 .30702 .65542 .30158 .64895 .27909 Mtetra
.613 .505 .706 r
.64895 .27909 .65542 .30158 .6674 .29584 .66096 .2744 Mtetra
.613 .512 .715 r
.66096 .2744 .6674 .29584 .67941 .28967 .67303 .26989 Mtetra
.623 .531 .729 r
.67303 .26989 .67941 .28967 .69141 .28278 .68513 .26513 Mtetra
.635 .558 .75 r
.68513 .26513 .69141 .28278 .70342 .27548 .69727 .26011 Mtetra
.653 .594 .775 r
.69727 .26011 .70342 .27548 .71544 .26796 .70944 .25471 Mtetra
.669 .632 .804 r
.70944 .25471 .71544 .26796 .7275 .26054 .72164 .24912 Mtetra
.679 .671 .835 r
.72164 .24912 .7275 .26054 .73962 .25362 .73388 .24354 Mtetra
.686 .704 .861 r
.73388 .24354 .73962 .25362 .7518 .2471 .74616 .238 Mtetra
.689 .731 .882 r
.74616 .238 .7518 .2471 .76405 .24096 .7585 .23256 Mtetra
.687 .75 .899 r
.7585 .23256 .76405 .24096 .77637 .23521 .7709 .22725 Mtetra
.648 .749 .923 r
.1101 .44736 .11732 .45366 .12704 .45119 .11994 .44411 Mtetra
.655 .728 .903 r
.11994 .44411 .12704 .45119 .13679 .44887 .12983 .44068 Mtetra
.661 .699 .874 r
.12983 .44068 .13679 .44887 .14657 .44664 .1398 .43697 Mtetra
.664 .665 .841 r
.1398 .43697 .14657 .44664 .15639 .44445 .14984 .4329 Mtetra
.666 .63 .804 r
.14984 .4329 .15639 .44445 .16625 .44229 .15997 .42833 Mtetra
.66 .593 .769 r
.15997 .42833 .16625 .44229 .17618 .43995 .17018 .42339 Mtetra
.653 .561 .738 r
.17018 .42339 .17618 .43995 .18618 .43726 .18045 .41807 Mtetra
.639 .531 .716 r
.18045 .41807 .18618 .43726 .19626 .43432 .19074 .41286 Mtetra
.622 .506 .7 r
.19074 .41286 .19626 .43432 .2064 .43114 .20101 .40812 Mtetra
.604 .485 .691 r
.20101 .40812 .2064 .43114 .21656 .42814 .21122 .40426 Mtetra
.58 .465 .687 r
.21122 .40426 .21656 .42814 .22672 .42567 .22135 .40173 Mtetra
.564 .455 .688 r
.22135 .40173 .22672 .42567 .23688 .42367 .23144 .40012 Mtetra
.551 .449 .691 r
.23144 .40012 .23688 .42367 .24704 .4222 .24152 .39924 Mtetra
.546 .449 .696 r
.24152 .39924 .24704 .4222 .25724 .42098 .25163 .39862 Mtetra
.548 .455 .701 r
.25163 .39862 .25724 .42098 .26749 .41985 .26181 .39792 Mtetra
.541 .454 .706 r
.26181 .39792 .26749 .41985 .27777 .41892 .27202 .39755 Mtetra
.53 .451 .711 r
.27202 .39755 .27777 .41892 .2881 .41819 .28225 .39769 Mtetra
.52 .452 .72 r
.28225 .39769 .2881 .41819 .29849 .41742 .29252 .39823 Mtetra
.515 .46 .734 r
.29252 .39823 .29849 .41742 .30896 .41635 .30285 .39893 Mtetra
.552 .501 .752 r
.30285 .39893 .30896 .41635 .31957 .41414 .31335 .39812 Mtetra
.615 .552 .761 r
.31335 .39812 .31957 .41414 .33032 .41025 .32407 .39474 Mtetra
.682 .593 .75 r
.32407 .39474 .33032 .41025 .34125 .40401 .33504 .38793 Mtetra
.723 .609 .729 r
.33504 .38793 .34125 .40401 .35231 .39586 .3462 .37796 Mtetra
.698 .58 .719 r
.3462 .37796 .35231 .39586 .36327 .39004 .35732 .36901 Mtetra
.643 .526 .705 r
.35732 .36901 .36327 .39004 .37407 .38811 .3683 .36289 Mtetra
.592 .47 .682 r
.3683 .36289 .37407 .38811 .38482 .38873 .3792 .35927 Mtetra
.556 .428 .661 r
.3792 .35927 .38482 .38873 .39558 .39082 .39005 .35769 Mtetra
.559 .418 .646 r
.39005 .35769 .39558 .39082 .40649 .39131 .40099 .35565 Mtetra
.571 .419 .637 r
.40099 .35565 .40649 .39131 .41756 .38915 .41202 .35236 Mtetra
.575 .42 .633 r
.41202 .35236 .41756 .38915 .42873 .38536 .42312 .34851 Mtetra
.581 .424 .633 r
.42312 .34851 .42873 .38536 .43999 .37994 .43428 .34412 Mtetra
.595 .436 .636 r
.43428 .34412 .43999 .37994 .45135 .37184 .44552 .33846 Mtetra
.605 .449 .644 r
.44552 .33846 .45135 .37184 .46276 .36213 .4568 .33233 Mtetra
.588 .45 .66 r
.4568 .33233 .46276 .36213 .47415 .35387 .46807 .32825 Mtetra
.559 .449 .685 r
.46807 .32825 .47415 .35387 .48553 .34818 .47935 .3267 Mtetra
.505 .441 .718 r
.47935 .3267 .48553 .34818 .4969 .34641 .49067 .32801 Mtetra
.47 .447 .751 r
.49067 .32801 .4969 .34641 .50832 .34701 .50206 .33038 Mtetra
.551 .516 .77 r
.50206 .33038 .50832 .34701 .51983 .34568 .51356 .32955 Mtetra
.63 .567 .765 r
.51356 .32955 .51983 .34568 .5314 .34198 .52513 .32525 Mtetra
.674 .584 .747 r
.52513 .32525 .5314 .34198 .54301 .33656 .53673 .31834 Mtetra
.688 .578 .726 r
.53673 .31834 .54301 .33656 .55465 .32997 .54836 .30986 Mtetra
.675 .556 .712 r
.54836 .30986 .55465 .32997 .56632 .32306 .56 .30154 Mtetra
.663 .539 .703 r
.56 .30154 .56632 .32306 .57801 .3161 .57166 .29361 Mtetra
.652 .526 .698 r
.57166 .29361 .57801 .3161 .58973 .30934 .58335 .28618 Mtetra
.644 .518 .695 r
.58335 .28618 .58973 .30934 .60149 .30276 .59508 .27909 Mtetra
.644 .515 .691 r
.59508 .27909 .60149 .30276 .61328 .29627 .60683 .27189 Mtetra
.637 .507 .688 r
.60683 .27189 .61328 .29627 .62511 .29002 .61861 .26495 Mtetra
.625 .496 .685 r
.61861 .26495 .62511 .29002 .637 .28432 .63045 .25876 Mtetra
.611 .485 .684 r
.63045 .25876 .637 .28432 .64895 .27909 .64237 .2535 Mtetra
.592 .473 .686 r
.64237 .2535 .64895 .27909 .66096 .2744 .65438 .24961 Mtetra
.581 .471 .693 r
.65438 .24961 .66096 .2744 .67303 .26989 .66649 .24663 Mtetra
.576 .477 .705 r
.66649 .24663 .67303 .26989 .68513 .26513 .67868 .24414 Mtetra
.577 .494 .724 r
.67868 .24414 .68513 .26513 .69727 .26011 .69095 .24177 Mtetra
.59 .525 .75 r
.69095 .24177 .69727 .26011 .70944 .25471 .70327 .23901 Mtetra
.604 .564 .782 r
.70327 .23901 .70944 .25471 .72164 .24912 .71563 .23585 Mtetra
.624 .611 .817 r
.71563 .23585 .72164 .24912 .73388 .24354 .72801 .23218 Mtetra
.64 .655 .849 r
.72801 .23218 .73388 .24354 .74616 .238 .74043 .22812 Mtetra
.653 .696 .878 r
.74043 .22812 .74616 .238 .7585 .23256 .75289 .22377 Mtetra
.661 .73 .901 r
.75289 .22377 .7585 .23256 .7709 .22725 .76539 .21923 Mtetra
.684 .758 .907 r
.10283 .44102 .1101 .44736 .11994 .44411 .1128 .43682 Mtetra
.695 .733 .88 r
.1128 .43682 .11994 .44411 .12983 .44068 .12287 .43214 Mtetra
.702 .703 .848 r
.12287 .43214 .12983 .44068 .1398 .43697 .13303 .4269 Mtetra
.705 .672 .815 r
.13303 .4269 .1398 .43697 .14984 .4329 .14329 .42104 Mtetra
.706 .642 .783 r
.14329 .42104 .14984 .4329 .15997 .42833 .15367 .41438 Mtetra
.697 .611 .756 r
.15367 .41438 .15997 .42833 .17018 .42339 .16411 .40734 Mtetra
.686 .583 .735 r
.16411 .40734 .17018 .42339 .18045 .41807 .17458 .40016 Mtetra
.667 .557 .721 r
.17458 .40016 .18045 .41807 .19074 .41286 .18501 .3935 Mtetra
.643 .532 .713 r
.18501 .3935 .19074 .41286 .20101 .40812 .19535 .38794 Mtetra
.618 .512 .711 r
.19535 .38794 .20101 .40812 .21122 .40426 .20559 .38368 Mtetra
.587 .49 .711 r
.20559 .38368 .21122 .40426 .22135 .40173 .2157 .38107 Mtetra
.569 .479 .712 r
.2157 .38107 .22135 .40173 .23144 .40012 .22577 .37934 Mtetra
.56 .472 .713 r
.22577 .37934 .23144 .40012 .24152 .39924 .23586 .37806 Mtetra
.559 .469 .71 r
.23586 .37806 .24152 .39924 .25163 .39862 .246 .3768 Mtetra
.565 .469 .704 r
.246 .3768 .25163 .39862 .26181 .39792 .25622 .37521 Mtetra
.554 .457 .698 r
.25622 .37521 .26181 .39792 .27202 .39755 .26645 .37411 Mtetra
.536 .441 .694 r
.26645 .37411 .27202 .39755 .28225 .39769 .27667 .37393 Mtetra
.518 .427 .692 r
.27667 .37393 .28225 .39769 .29252 .39823 .28689 .37464 Mtetra
.503 .419 .694 r
.28689 .37464 .29252 .39823 .30285 .39893 .29713 .37602 Mtetra
.535 .445 .7 r
.29713 .37602 .30285 .39893 .31335 .39812 .30754 .37588 Mtetra
.589 .484 .702 r
.30754 .37588 .31335 .39812 .32407 .39474 .31821 .37287 Mtetra
.65 .524 .697 r
.31821 .37287 .32407 .39474 .33504 .38793 .32917 .36598 Mtetra
.695 .551 .687 r
.32917 .36598 .33504 .38793 .3462 .37796 .34036 .35527 Mtetra
.691 .545 .683 r
.34036 .35527 .3462 .37796 .35732 .36901 .35156 .34451 Mtetra
.664 .519 .677 r
.35156 .34451 .35732 .36901 .3683 .36289 .36267 .33548 Mtetra
.629 .484 .666 r
.36267 .33548 .3683 .36289 .3792 .35927 .37368 .32858 Mtetra
.595 .449 .653 r
.37368 .32858 .3792 .35927 .39005 .35769 .38462 .32384 Mtetra
.584 .432 .641 r
.38462 .32384 .39005 .35769 .40099 .35565 .39557 .31953 Mtetra
.581 .424 .634 r
.39557 .31953 .40099 .35565 .41202 .35236 .40658 .31515 Mtetra
.574 .417 .63 r
.40658 .31515 .41202 .35236 .42312 .34851 .4176 .31125 Mtetra
.569 .413 .63 r
.4176 .31125 .42312 .34851 .43428 .34412 .42866 .30783 Mtetra
.571 .417 .634 r
.42866 .30783 .43428 .34412 .44552 .33846 .43976 .30436 Mtetra
.569 .422 .642 r
.43976 .30436 .44552 .33846 .4568 .33233 .45091 .3013 Mtetra
.544 .415 .655 r
.45091 .3013 .4568 .33233 .46807 .32825 .46206 .30043 Mtetra
.511 .406 .672 r
.46206 .30043 .46807 .32825 .47935 .3267 .47325 .30172 Mtetra
.473 .397 .689 r
.47325 .30172 .47935 .3267 .49067 .32801 .4845 .30477 Mtetra
.469 .406 .703 r
.4845 .30477 .49067 .32801 .50206 .33038 .49584 .30779 Mtetra
.548 .461 .709 r
.49584 .30779 .50206 .33038 .51356 .32955 .50731 .30696 Mtetra
.614 .502 .703 r
.50731 .30696 .51356 .32955 .52513 .32525 .51886 .3022 Mtetra
.653 .523 .693 r
.51886 .3022 .52513 .32525 .53673 .31834 .53044 .29451 Mtetra
.668 .528 .685 r
.53044 .29451 .53673 .31834 .54836 .30986 .54204 .28526 Mtetra
.657 .517 .682 r
.54204 .28526 .54836 .30986 .56 .30154 .55365 .27669 Mtetra
.645 .509 .682 r
.55365 .27669 .56 .30154 .57166 .29361 .56529 .269 Mtetra
.634 .503 .686 r
.56529 .269 .57166 .29361 .58335 .28618 .57697 .26223 Mtetra
.63 .505 .691 r
.57697 .26223 .58335 .28618 .59508 .27909 .58869 .25597 Mtetra
.638 .514 .696 r
.58869 .25597 .59508 .27909 .60683 .27189 .60044 .24934 Mtetra
.64 .519 .7 r
.60044 .24934 .60683 .27189 .61861 .26495 .61222 .24274 Mtetra
.635 .518 .704 r
.61222 .24274 .61861 .26495 .63045 .25876 .62404 .23658 Mtetra
.621 .511 .707 r
.62404 .23658 .63045 .25876 .64237 .2535 .63593 .23133 Mtetra
.595 .495 .711 r
.63593 .23133 .64237 .2535 .65438 .24961 .64794 .22777 Mtetra
.573 .484 .716 r
.64794 .22777 .65438 .24961 .66649 .24663 .66006 .22555 Mtetra
.552 .478 .725 r
.66006 .22555 .66649 .24663 .67868 .24414 .6723 .22449 Mtetra
.542 .484 .741 r
.6723 .22449 .67868 .24414 .69095 .24177 .68466 .22396 Mtetra
.544 .504 .762 r
.68466 .22396 .69095 .24177 .70327 .23901 .69708 .2233 Mtetra
.553 .535 .79 r
.69708 .2233 .70327 .23901 .71563 .23585 .70958 .22226 Mtetra
.575 .58 .821 r
.70958 .22226 .71563 .23585 .72801 .23218 .72209 .22038 Mtetra
.594 .625 .852 r
.72209 .22038 .72801 .23218 .74043 .22812 .73464 .21785 Mtetra
.612 .669 .881 r
.73464 .21785 .74043 .22812 .75289 .22377 .74722 .21475 Mtetra
.629 .711 .905 r
.74722 .21475 .75289 .22377 .76539 .21923 .75983 .21113 Mtetra
.71 .762 .893 r
.09551 .43462 .10283 .44102 .1128 .43682 .10561 .4296 Mtetra
.724 .742 .866 r
.10561 .4296 .1128 .43682 .12287 .43214 .11582 .42386 Mtetra
.732 .718 .838 r
.11582 .42386 .12287 .43214 .13303 .4269 .12615 .4174 Mtetra
.735 .693 .81 r
.12615 .4174 .13303 .4269 .14329 .42104 .13659 .4102 Mtetra
.739 .671 .784 r
.13659 .4102 .14329 .42104 .15367 .41438 .14715 .40208 Mtetra
.73 .647 .766 r
.14715 .40208 .15367 .41438 .16411 .40734 .15775 .39374 Mtetra
.717 .625 .754 r
.15775 .39374 .16411 .40734 .17458 .40016 .16834 .38561 Mtetra
.696 .605 .75 r
.16834 .38561 .17458 .40016 .18501 .3935 .17884 .37834 Mtetra
.666 .583 .753 r
.17884 .37834 .18501 .3935 .19535 .38794 .18919 .37266 Mtetra
.638 .567 .759 r
.18919 .37266 .19535 .38794 .20559 .38368 .19942 .36837 Mtetra
.604 .549 .766 r
.19942 .36837 .20559 .38368 .2157 .38107 .20954 .36561 Mtetra
.59 .54 .767 r
.20954 .36561 .2157 .38107 .22577 .37934 .21966 .36335 Mtetra
.594 .537 .76 r
.21966 .36335 .22577 .37934 .23586 .37806 .22984 .36088 Mtetra
.599 .527 .745 r
.22984 .36088 .23586 .37806 .246 .3768 .2401 .35804 Mtetra
.607 .518 .727 r
.2401 .35804 .246 .3768 .25622 .37521 .25046 .35458 Mtetra
.59 .493 .713 r
.25046 .35458 .25622 .37521 .26645 .37411 .26081 .35175 Mtetra
.56 .463 .701 r
.26081 .35175 .26645 .37411 .27667 .37393 .2711 .35027 Mtetra
.532 .437 .692 r
.2711 .35027 .27667 .37393 .28689 .37464 .28134 .35019 Mtetra
.507 .416 .687 r
.28134 .35019 .28689 .37464 .29713 .37602 .29155 .35135 Mtetra
.531 .431 .686 r
.29155 .35135 .29713 .37602 .30754 .37588 .30191 .35135 Mtetra
.578 .463 .686 r
.30191 .35135 .30754 .37588 .31821 .37287 .31252 .34867 Mtetra
.634 .501 .683 r
.31252 .34867 .31821 .37287 .32917 .36598 .32342 .34224 Mtetra
.682 .534 .678 r
.32342 .34224 .32917 .36598 .34036 .35527 .33458 .33189 Mtetra
.692 .542 .678 r
.33458 .33189 .34036 .35527 .35156 .34451 .34579 .32071 Mtetra
.682 .534 .677 r
.34579 .32071 .35156 .34451 .36267 .33548 .35695 .31027 Mtetra
.659 .512 .673 r
.35695 .31027 .36267 .33548 .37368 .32858 .36804 .30139 Mtetra
.629 .484 .666 r
.36804 .30139 .37368 .32858 .38462 .32384 .37904 .29446 Mtetra
.611 .464 .657 r
.37904 .29446 .38462 .32384 .39557 .31953 .39002 .28848 Mtetra
.598 .45 .651 r
.39002 .28848 .39557 .31953 .40658 .31515 .401 .28329 Mtetra
.582 .436 .648 r
.401 .28329 .40658 .31515 .4176 .31125 .41197 .27934 Mtetra
.566 .425 .649 r
.41197 .27934 .4176 .31125 .42866 .30783 .42294 .27664 Mtetra
.556 .421 .652 r
.42294 .27664 .42866 .30783 .43976 .30436 .43394 .27473 Mtetra
.544 .419 .66 r
.43394 .27473 .43976 .30436 .45091 .3013 .44498 .27379 Mtetra
.513 .408 .672 r
.44498 .27379 .45091 .3013 .46206 .30043 .45604 .27482 Mtetra
.481 .397 .684 r
.45604 .27482 .46206 .30043 .47325 .30172 .46715 .27744 Mtetra
.462 .393 .694 r
.46715 .27744 .47325 .30172 .4845 .30477 .47835 .28083 Mtetra
.479 .407 .698 r
.47835 .28083 .4845 .30477 .49584 .30779 .48966 .2834 Mtetra
.555 .454 .694 r
.48966 .2834 .49584 .30779 .50731 .30696 .50109 .28202 Mtetra
.612 .487 .686 r
.50109 .28202 .50731 .30696 .51886 .3022 .51261 .27683 Mtetra
.646 .506 .678 r
.51261 .27683 .51886 .3022 .53044 .29451 .52416 .26892 Mtetra
.659 .513 .675 r
.52416 .26892 .53044 .29451 .54204 .28526 .53574 .2598 Mtetra
.644 .505 .678 r
.53574 .2598 .54204 .28526 .55365 .27669 .54733 .25194 Mtetra
.629 .499 .685 r
.54733 .25194 .55365 .27669 .56529 .269 .55896 .24549 Mtetra
.614 .497 .696 r
.55896 .24549 .56529 .269 .57697 .26223 .57064 .24042 Mtetra
.61 .505 .71 r
.57064 .24042 .57697 .26223 .58869 .25597 .58238 .23599 Mtetra
.626 .529 .724 r
.58238 .23599 .58869 .25597 .60044 .24934 .59415 .23091 Mtetra
.639 .55 .738 r
.59415 .23091 .60044 .24934 .61222 .24274 .60596 .22544 Mtetra
.648 .567 .749 r
.60596 .22544 .61222 .24274 .62404 .23658 .6178 .21976 Mtetra
.641 .568 .757 r
.6178 .21976 .62404 .23658 .63593 .23133 .62969 .21459 Mtetra
.61 .552 .765 r
.62969 .21459 .63593 .23133 .64794 .22777 .64169 .21098 Mtetra
.578 .534 .769 r
.64169 .21098 .64794 .22777 .66006 .22555 .65381 .20883 Mtetra
.539 .513 .775 r
.65381 .20883 .66006 .22555 .6723 .22449 .66608 .2083 Mtetra
.514 .506 .785 r
.66608 .2083 .6723 .22449 .68466 .22396 .67848 .2087 Mtetra
.505 .514 .799 r
.67848 .2087 .68466 .22396 .69708 .2233 .69098 .20931 Mtetra
.507 .536 .821 r
.69098 .20931 .69708 .2233 .70958 .22226 .70356 .20971 Mtetra
.531 .577 .846 r
.70356 .20971 .70958 .22226 .72209 .22038 .71618 .20916 Mtetra
.552 .617 .871 r
.71618 .20916 .72209 .22038 .73464 .21785 .72884 .20785 Mtetra
.574 .659 .895 r
.72884 .20785 .73464 .21785 .74722 .21475 .74152 .20579 Mtetra
.598 .7 .915 r
.74152 .20579 .74722 .21475 .75983 .21113 .75422 .20298 Mtetra
.718 .764 .888 r
.08813 .42819 .09551 .43462 .10561 .4296 .09829 .42287 Mtetra
.737 .759 .87 r
.09829 .42287 .10561 .4296 .11582 .42386 .10858 .41676 Mtetra
.75 .751 .853 r
.10858 .41676 .11582 .42386 .12615 .4174 .11898 .40993 Mtetra
.76 .744 .838 r
.11898 .40993 .12615 .4174 .13659 .4102 .12948 .4024 Mtetra
.771 .738 .823 r
.12948 .4024 .13659 .4102 .14715 .40208 .1401 .39407 Mtetra
.77 .734 .82 r
.1401 .39407 .14715 .40208 .15775 .39374 .15073 .38571 Mtetra
.761 .733 .827 r
.15073 .38571 .15775 .39374 .16834 .38561 .1613 .37786 Mtetra
.744 .737 .845 r
.1613 .37786 .16834 .38561 .17884 .37834 .17178 .37102 Mtetra
.707 .742 .878 r
.17178 .37102 .17884 .37834 .18919 .37266 .1821 .36584 Mtetra
.674 .749 .907 r
.1821 .36584 .18919 .37266 .19942 .36837 .19234 .36174 Mtetra
.638 .746 .927 r
.19234 .36174 .19942 .36837 .20954 .36561 .20252 .35855 Mtetra
.647 .736 .915 r
.20252 .35855 .20954 .36561 .21966 .36335 .21276 .35515 Mtetra
.681 .714 .874 r
.21276 .35515 .21966 .36335 .22984 .36088 .22315 .35065 Mtetra
.691 .672 .826 r
.22315 .35065 .22984 .36088 .2401 .35804 .23366 .34525 Mtetra
.692 .629 .781 r
.23366 .34525 .2401 .35804 .25046 .35458 .24428 .33892 Mtetra
.66 .578 .751 r
.24428 .33892 .25046 .35458 .26081 .35175 .25486 .33332 Mtetra
.614 .525 .73 r
.25486 .33332 .26081 .35175 .2711 .35027 .26532 .3295 Mtetra
.569 .48 .714 r
.26532 .3295 .2711 .35027 .28134 .35019 .27566 .32762 Mtetra
.527 .44 .701 r
.27566 .32762 .28134 .35019 .29155 .35135 .28592 .32773 Mtetra
.535 .439 .693 r
.28592 .32773 .29155 .35135 .30191 .35135 .29626 .32744 Mtetra
.569 .46 .69 r
.29626 .32744 .30191 .35135 .31252 .34867 .3068 .3253 Mtetra
.619 .496 .69 r
.3068 .3253 .31252 .34867 .32342 .34224 .3176 .32012 Mtetra
.67 .534 .691 r
.3176 .32012 .32342 .34224 .33458 .33189 .32864 .31151 Mtetra
.693 .559 .699 r
.32864 .31151 .33458 .33189 .34579 .32071 .33976 .30174 Mtetra
.701 .573 .708 r
.33976 .30174 .34579 .32071 .35695 .31027 .35088 .292 Mtetra
.693 .574 .717 r
.35088 .292 .35695 .31027 .36804 .30139 .36196 .2832 Mtetra
.673 .564 .723 r
.36196 .2832 .36804 .30139 .37904 .29446 .37297 .27584 Mtetra
.656 .551 .724 r
.37297 .27584 .37904 .29446 .39002 .28848 .38397 .26946 Mtetra
.637 .537 .724 r
.38397 .26946 .39002 .28848 .401 .28329 .39494 .26409 Mtetra
.612 .521 .727 r
.39494 .26409 .401 .28329 .41197 .27934 .4059 .2601 Mtetra
.585 .505 .73 r
.4059 .2601 .41197 .27934 .42294 .27664 .41685 .2575 Mtetra
.564 .494 .734 r
.41685 .2575 .42294 .27664 .43394 .27473 .42782 .25592 Mtetra
.542 .484 .74 r
.42782 .25592 .43394 .27473 .44498 .27379 .43883 .25534 Mtetra
.505 .465 .747 r
.43883 .25534 .44498 .27379 .45604 .27482 .44987 .25621 Mtetra
.479 .449 .746 r
.44987 .25621 .45604 .27482 .46715 .27744 .46098 .25804 Mtetra
.481 .443 .738 r
.46098 .25804 .46715 .27744 .47835 .28083 .47217 .25992 Mtetra
.512 .45 .723 r
.47217 .25992 .47835 .28083 .48966 .2834 .48347 .26064 Mtetra
.579 .479 .704 r
.48347 .26064 .48966 .2834 .50109 .28202 .49489 .25791 Mtetra
.623 .498 .689 r
.49489 .25791 .50109 .28202 .51261 .27683 .50638 .25209 Mtetra
.645 .509 .682 r
.50638 .25209 .51261 .27683 .52416 .26892 .51791 .24438 Mtetra
.651 .513 .682 r
.51791 .24438 .52416 .26892 .53574 .2598 .52946 .23626 Mtetra
.629 .505 .693 r
.52946 .23626 .53574 .2598 .54733 .25194 .54104 .23015 Mtetra
.605 .501 .71 r
.54104 .23015 .54733 .25194 .55896 .24549 .55268 .22601 Mtetra
.577 .504 .735 r
.55268 .22601 .55896 .24549 .57064 .24042 .56439 .22368 Mtetra
.565 .525 .77 r
.56439 .22368 .57064 .24042 .58238 .23599 .57617 .22211 Mtetra
.592 .58 .809 r
.57617 .22211 .58238 .23599 .59415 .23091 .58801 .2196 Mtetra
.624 .644 .85 r
.58801 .2196 .59415 .23091 .60596 .22544 .59989 .21616 Mtetra
.664 .71 .882 r
.59989 .21616 .60596 .22544 .6178 .21976 .61179 .21159 Mtetra
.675 .746 .905 r
.61179 .21159 .6178 .21976 .62969 .21459 .62373 .20679 Mtetra
.642 .746 .924 r
.62373 .20679 .62969 .21459 .64169 .21098 .63576 .20293 Mtetra
.597 .719 .93 r
.63576 .20293 .64169 .21098 .65381 .20883 .64789 .20019 Mtetra
.525 .668 .927 r
.64789 .20019 .65381 .20883 .66608 .2083 .66016 .19916 Mtetra
.481 .631 .919 r
.66016 .19916 .66608 .2083 .67848 .2087 .67256 .19919 Mtetra
.459 .609 .912 r
.67256 .19919 .67848 .2087 .69098 .20931 .68509 .19977 Mtetra
.461 .61 .911 r
.68509 .19977 .69098 .20931 .70356 .20971 .6977 .20032 Mtetra
.496 .635 .915 r
.6977 .20032 .70356 .20971 .71618 .20916 .71037 .20005 Mtetra
.524 .659 .92 r
.71037 .20005 .71618 .20916 .72884 .20785 .72307 .19907 Mtetra
.554 .684 .926 r
.72307 .19907 .72884 .20785 .74152 .20579 .73581 .19732 Mtetra
.585 .711 .93 r
.73581 .19732 .74152 .20579 .75422 .20298 .74857 .19475 Mtetra
.712 .763 .892 r
.0807 .4217 .08813 .42819 .09829 .42287 .09086 .41656 Mtetra
.734 .772 .883 r
.09086 .41656 .09829 .42287 .10858 .41676 .10114 .41066 Mtetra
.751 .78 .877 r
.10114 .41066 .10858 .41676 .11898 .40993 .11154 .40412 Mtetra
.766 .791 .873 r
.11154 .40412 .11898 .40993 .12948 .4024 .12201 .39706 Mtetra
.781 .806 .872 r
.12201 .39706 .12948 .4024 .1401 .39407 .13257 .38945 Mtetra
.783 .829 .888 r
.13257 .38945 .1401 .39407 .15073 .38571 .14313 .38202 Mtetra
.768 .862 .919 r
.14313 .38202 .15073 .38571 .1613 .37786 .15361 .37538 Mtetra
.728 .903 .957 r
.15361 .37538 .1613 .37786 .17178 .37102 .16399 .36976 Mtetra
.608 .918 .976 r
.16399 .36976 .17178 .37102 .1821 .36584 .17423 .36563 Mtetra
.493 .895 .935 r
.17423 .36563 .1821 .36584 .19234 .36174 .18445 .3621 Mtetra
.437 .874 .897 r
.18445 .3621 .19234 .36174 .20252 .35855 .1947 .35866 Mtetra
.561 .928 .933 r
.1947 .35866 .20252 .35855 .21276 .35515 .20509 .35418 Mtetra
.739 .952 .946 r
.20509 .35418 .21276 .35515 .22315 .35065 .21571 .3477 Mtetra
.802 .893 .908 r
.21571 .3477 .22315 .35065 .23366 .34525 .2265 .33979 Mtetra
.809 .813 .853 r
.2265 .33979 .23366 .34525 .24428 .33892 .2374 .33065 Mtetra
.768 .738 .825 r
.2374 .33065 .24428 .33892 .25486 .33332 .24825 .32228 Mtetra
.704 .664 .807 r
.24825 .32228 .25486 .33332 .26532 .3295 .25893 .31597 Mtetra
.635 .593 .79 r
.25893 .31597 .26532 .3295 .27566 .32762 .26944 .31208 Mtetra
.56 .526 .774 r
.26944 .31208 .27566 .32762 .28592 .32773 .27978 .31082 Mtetra
.546 .502 .758 r
.27978 .31082 .28592 .32773 .29626 .32744 .29015 .31006 Mtetra
.566 .509 .751 r
.29015 .31006 .29626 .32744 .3068 .3253 .30063 .30851 Mtetra
.614 .543 .752 r
.30063 .30851 .3068 .3253 .3176 .32012 .31131 .30492 Mtetra
.673 .593 .758 r
.31131 .30492 .3176 .32012 .32864 .31151 .32221 .29871 Mtetra
.71 .642 .779 r
.32221 .29871 .32864 .31151 .33976 .30174 .3332 .29132 Mtetra
.738 .693 .807 r
.3332 .29132 .33976 .30174 .35088 .292 .34424 .2835 Mtetra
.749 .738 .841 r
.34424 .2835 .35088 .292 .36196 .2832 .35527 .27603 Mtetra
.743 .772 .877 r
.35527 .27603 .36196 .2832 .37297 .27584 .36629 .26937 Mtetra
.729 .791 .902 r
.36629 .26937 .37297 .27584 .38397 .26946 .37729 .26341 Mtetra
.703 .8 .925 r
.37729 .26341 .38397 .26946 .39494 .26409 .38829 .25826 Mtetra
.658 .797 .949 r
.38829 .25826 .39494 .26409 .4059 .2601 .39928 .25425 Mtetra
.604 .779 .965 r
.39928 .25425 .4059 .2601 .41685 .2575 .41027 .25136 Mtetra
.56 .753 .968 r
.41027 .25136 .41685 .2575 .42782 .25592 .42129 .24931 Mtetra
.525 .722 .963 r
.42129 .24931 .42782 .25592 .43883 .25534 .43235 .24796 Mtetra
.489 .68 .95 r
.43235 .24796 .43883 .25534 .44987 .25621 .44344 .24742 Mtetra
.489 .636 .919 r
.44344 .24742 .44987 .25621 .46098 .25804 .45461 .24726 Mtetra
.527 .602 .872 r
.45461 .24726 .46098 .25804 .47217 .25992 .46585 .24667 Mtetra
.573 .576 .818 r
.46585 .24667 .47217 .25992 .48347 .26064 .47719 .2449 Mtetra
.632 .572 .769 r
.47719 .2449 .48347 .26064 .49489 .25791 .48862 .24048 Mtetra
.662 .57 .741 r
.48862 .24048 .49489 .25791 .50638 .25209 .50012 .23399 Mtetra
.671 .569 .732 r
.50012 .23399 .50638 .25209 .51791 .24438 .51165 .22667 Mtetra
.666 .57 .738 r
.51165 .22667 .51791 .24438 .52946 .23626 .5232 .21987 Mtetra
.623 .561 .764 r
.5232 .21987 .52946 .23626 .54104 .23015 .53479 .21574 Mtetra
.568 .558 .802 r
.53479 .21574 .54104 .23015 .55268 .22601 .54645 .21406 Mtetra
.49 .561 .855 r
.54645 .21406 .55268 .22601 .56439 .22368 .5582 .21451 Mtetra
.417 .592 .915 r
.5582 .21451 .56439 .22368 .57617 .22211 .57005 .21575 Mtetra
.422 .691 .975 r
.57005 .21575 .57617 .22211 .58801 .2196 .58197 .21575 Mtetra
.431 .791 .996 r
.58197 .21575 .58801 .2196 .59989 .21616 .59394 .21429 Mtetra
.489 .879 .964 r
.59394 .21429 .59989 .21616 .61179 .21159 .60593 .21077 Mtetra
.505 .905 .921 r
.60593 .21077 .61179 .21159 .62373 .20679 .61795 .20619 Mtetra
.479 .895 .906 r
.61795 .20619 .62373 .20679 .63576 .20293 .63002 .20169 Mtetra
.469 .883 .935 r
.63002 .20169 .63576 .20293 .64789 .20019 .64216 .19781 Mtetra
.413 .83 .969 r
.64216 .19781 .64789 .20019 .66016 .19916 .65443 .19547 Mtetra
.4 .783 .991 r
.65443 .19547 .66016 .19916 .67256 .19919 .66682 .19419 Mtetra
.399 .735 .991 r
.66682 .19419 .67256 .19919 .68509 .19977 .67934 .19373 Mtetra
.423 .71 .983 r
.67934 .19373 .68509 .19977 .6977 .20032 .69195 .19348 Mtetra
.479 .711 .972 r
.69195 .19348 .6977 .20032 .71037 .20005 .70462 .19266 Mtetra
.518 .713 .96 r
.70462 .19266 .71037 .20005 .72307 .19907 .71734 .1913 Mtetra
.555 .719 .95 r
.71734 .1913 .72307 .19907 .73581 .19732 .7301 .18928 Mtetra
.591 .729 .939 r
.7301 .18928 .73581 .19732 .74857 .19475 .74288 .18646 Mtetra
.691 .759 .904 r
.07322 .41517 .0807 .4217 .09086 .41656 .08331 .41065 Mtetra
.715 .783 .906 r
.08331 .41065 .09086 .41656 .10114 .41066 .09352 .40549 Mtetra
.733 .809 .912 r
.09352 .40549 .10114 .41066 .11154 .40412 .10383 .39986 Mtetra
.745 .841 .923 r
.10383 .39986 .11154 .40412 .12201 .39706 .1142 .39392 Mtetra
.753 .88 .937 r
.1142 .39392 .12201 .39706 .13257 .38945 .12462 .38775 Mtetra
.724 .926 .959 r
.12462 .38775 .13257 .38945 .14313 .38202 .13501 .38201 Mtetra
.601 .939 .945 r
.13501 .38201 .14313 .38202 .15361 .37538 .14531 .3773 Mtetra
.343 .819 .782 r
.14531 .3773 .15361 .37538 .16399 .36976 .15552 .37362 Mtetra
.001 0 0 r
.15552 .37362 .16399 .36976 .17423 .36563 .16561 .37126 Mtetra
.136 0 0 r
.16561 .37126 .17423 .36563 .18445 .3621 .17574 .36912 Mtetra
.157 0 0 r
.17574 .36912 .18445 .3621 .1947 .35866 .18597 .36647 Mtetra
.055 0 0 r
.18597 .36647 .1947 .35866 .20509 .35418 .19641 .3622 Mtetra
0 0 0 r
.19641 .3622 .20509 .35418 .21571 .3477 .20715 .35531 Mtetra
.20715 .35531 .21571 .3477 .2265 .33979 .21809 .34657 Mtetra
.561 .879 .601 r
.21809 .34657 .2265 .33979 .2374 .33065 .22917 .33633 Mtetra
.593 .911 .66 r
.22917 .33633 .2374 .33065 .24825 .32228 .24021 .32668 Mtetra
.519 .891 .695 r
.24021 .32668 .24825 .32228 .25893 .31597 .25107 .31903 Mtetra
.377 .827 .715 r
.25107 .31903 .25893 .31597 .26944 .31208 .26174 .31387 Mtetra
0 0 0 r
.26174 .31387 .26944 .31208 .27978 .31082 .27221 .3116 Mtetra
.081 .64 .708 r
.27221 .3116 .27978 .31082 .29015 .31006 .28265 .31046 Mtetra
.108 .662 .747 r
.28265 .31046 .29015 .31006 .30063 .30851 .29314 .30936 Mtetra
.212 .737 .772 r
.29314 .30936 .30063 .30851 .31131 .30492 .30378 .30713 Mtetra
.304 .789 .728 r
.30378 .30713 .31131 .30492 .32221 .29871 .31459 .30308 Mtetra
0 0 0 r
.31459 .30308 .32221 .29871 .3332 .29132 .32551 .29805 Mtetra
.32551 .29805 .3332 .29132 .34424 .2835 .33649 .2924 Mtetra
.034 0 0 r
.33649 .2924 .34424 .2835 .35527 .27603 .34752 .28671 Mtetra
.131 0 0 r
.34752 .28671 .35527 .27603 .36629 .26937 .35856 .28129 Mtetra
.19 0 0 r
.35856 .28129 .36629 .26937 .37729 .26341 .36962 .27617 Mtetra
.234 0 .038 r
.36962 .27617 .37729 .26341 .38829 .25826 .3807 .27148 Mtetra
.275 0 .069 r
.3807 .27148 .38829 .25826 .39928 .25425 .39179 .26745 Mtetra
.304 0 .083 r
.39179 .26745 .39928 .25425 .41027 .25136 .4029 .26408 Mtetra
.314 0 .078 r
.4029 .26408 .41027 .25136 .42129 .24931 .41404 .26114 Mtetra
.313 0 .057 r
.41404 .26114 .42129 .24931 .43235 .24796 .42523 .25851 Mtetra
.303 0 .018 r
.42523 .25851 .43235 .24796 .44344 .24742 .43647 .25616 Mtetra
.259 0 0 r
.43647 .25616 .44344 .24742 .45461 .24726 .44776 .25377 Mtetra
.142 0 0 r
.44776 .25377 .45461 .24726 .46585 .24667 .45913 .25076 Mtetra
0 0 0 r
.45913 .25076 .46585 .24667 .47719 .2449 .47058 .24675 Mtetra
.452 .877 .775 r
.47058 .24675 .47719 .2449 .48862 .24048 .4821 .24091 Mtetra
.641 .966 .882 r
.4821 .24091 .48862 .24048 .50012 .23399 .49366 .23391 Mtetra
.663 .97 .904 r
.49366 .23391 .50012 .23399 .51165 .22667 .50526 .22695 Mtetra
.56 .935 .883 r
.50526 .22695 .51165 .22667 .5232 .21987 .51688 .22112 Mtetra
.199 .723 .721 r
.51688 .22112 .5232 .21987 .53479 .21574 .52854 .21822 Mtetra
.147 0 0 r
.52854 .21822 .53479 .21574 .54645 .21406 .54027 .21787 Mtetra
.354 0 0 r
.54027 .21787 .54645 .21406 .5582 .21451 .5521 .21959 Mtetra
.416 0 0 r
.5521 .21959 .5582 .21451 .57005 .21575 .56404 .22192 Mtetra
.363 0 0 r
.56404 .22192 .57005 .21575 .58197 .21575 .57605 .22272 Mtetra
.286 0 0 r
.57605 .22272 .58197 .21575 .59394 .21429 .58812 .22165 Mtetra
.147 0 0 r
.58812 .22165 .59394 .21429 .60593 .21077 .6002 .21788 Mtetra
.033 0 0 r
.6002 .21788 .60593 .21077 .61795 .20619 .61229 .21244 Mtetra
0 0 0 r
.61229 .21244 .61795 .20619 .63002 .20169 .6244 .20647 Mtetra
.6244 .20647 .63002 .20169 .64216 .19781 .63657 .2007 Mtetra
.63657 .2007 .64216 .19781 .65443 .19547 .64883 .19631 Mtetra
.241 .754 .752 r
.64883 .19631 .65443 .19547 .66682 .19419 .6612 .19298 Mtetra
.313 .796 .9 r
.6612 .19298 .66682 .19419 .67934 .19373 .67368 .19072 Mtetra
.398 .806 .98 r
.67368 .19072 .67934 .19373 .69195 .19348 .68626 .18891 Mtetra
.487 .802 1 r
.68626 .18891 .69195 .19348 .70462 .19266 .69891 .18686 Mtetra
.54 .783 .988 r
.69891 .18686 .70462 .19266 .71734 .1913 .71161 .18449 Mtetra
.581 .766 .967 r
.71161 .18449 .71734 .1913 .7301 .18928 .72436 .18164 Mtetra
.617 .756 .945 r
.72436 .18164 .7301 .18928 .74288 .18646 .73713 .1781 Mtetra
.656 .751 .92 r
.06568 .40859 .07322 .41517 .08331 .41065 .07566 .405 Mtetra
.676 .786 .933 r
.07566 .405 .08331 .41065 .09352 .40549 .08576 .40092 Mtetra
.685 .826 .95 r
.08576 .40092 .09352 .40549 .10383 .39986 .09592 .39656 Mtetra
.679 .87 .971 r
.09592 .39656 .10383 .39986 .1142 .39392 .10612 .39213 Mtetra
.644 .911 .981 r
.10612 .39213 .1142 .39392 .12462 .38775 .11635 .38779 Mtetra
.503 .901 .931 r
.11635 .38779 .12462 .38775 .13501 .38201 .12654 .38407 Mtetra
.182 .709 .696 r
.12654 .38407 .13501 .38201 .14531 .3773 .13662 .38151 Mtetra
.108 0 0 r
.13662 .38151 .14531 .3773 .15552 .37362 .14664 .37993 Mtetra
.299 0 0 r
.14664 .37993 .15552 .37362 .16561 .37126 .15658 .37944 Mtetra
.336 0 0 r
.15658 .37944 .16561 .37126 .17574 .36912 .1666 .37882 Mtetra
.308 0 0 r
.1666 .37882 .17574 .36912 .18597 .36647 .17678 .3772 Mtetra
.213 0 0 r
.17678 .3772 .18597 .36647 .19641 .3622 .18723 .37357 Mtetra
.034 0 0 r
.18723 .37357 .19641 .3622 .20715 .35531 .19803 .36695 Mtetra
0 0 0 r
.19803 .36695 .20715 .35531 .21809 .34657 .20906 .35823 Mtetra
.20906 .35823 .21809 .34657 .22917 .33633 .22027 .34782 Mtetra
.22027 .34782 .22917 .33633 .24021 .32668 .23144 .33776 Mtetra
.23144 .33776 .24021 .32668 .25107 .31903 .24245 .3295 Mtetra
.065 0 0 r
.24245 .3295 .25107 .31903 .26174 .31387 .25326 .32363 Mtetra
.237 0 0 r
.25326 .32363 .26174 .31387 .27221 .3116 .26386 .3207 Mtetra
.313 0 0 r
.26386 .3207 .27221 .3116 .28265 .31046 .27439 .31932 Mtetra
.349 0 0 r
.27439 .31932 .28265 .31046 .29314 .30936 .28491 .31871 Mtetra
.34 0 .001 r
.28491 .31871 .29314 .30936 .30378 .30713 .29553 .31776 Mtetra
.313 0 .02 r
.29553 .31776 .30378 .30713 .31459 .30308 .30628 .31579 Mtetra
.316 0 .072 r
.30628 .31579 .31459 .30308 .32551 .29805 .31714 .31312 Mtetra
.325 0 .123 r
.31714 .31312 .32551 .29805 .33649 .2924 .32809 .3098 Mtetra
.341 0 .167 r
.32809 .3098 .33649 .2924 .34752 .28671 .3391 .30615 Mtetra
.355 0 .199 r
.3391 .30615 .34752 .28671 .35856 .28129 .35018 .3023 Mtetra
.364 .007 .22 r
.35018 .3023 .35856 .28129 .36962 .27617 .36131 .29829 Mtetra
.37 .019 .233 r
.36131 .29829 .36962 .27617 .3807 .27148 .37249 .29418 Mtetra
.376 .028 .241 r
.37249 .29418 .3807 .27148 .39179 .26745 .38372 .29015 Mtetra
.378 .029 .242 r
.38372 .29015 .39179 .26745 .4029 .26408 .39498 .28617 Mtetra
.372 .021 .234 r
.39498 .28617 .4029 .26408 .41404 .26114 .4063 .28211 Mtetra
.36 .004 .218 r
.4063 .28211 .41404 .26114 .42523 .25851 .41767 .27788 Mtetra
.342 0 .193 r
.41767 .27788 .42523 .25851 .43647 .25616 .4291 .27346 Mtetra
.31 0 .153 r
.4291 .27346 .43647 .25616 .44776 .25377 .44058 .26869 Mtetra
.252 0 .088 r
.44058 .26869 .44776 .25377 .45913 .25076 .45212 .26328 Mtetra
.167 0 0 r
.45212 .26328 .45913 .25076 .47058 .24675 .46371 .25714 Mtetra
.038 0 0 r
.46371 .25714 .47058 .24675 .4821 .24091 .47535 .24996 Mtetra
0 0 0 r
.47535 .24996 .4821 .24091 .49366 .23391 .48702 .24243 Mtetra
.48702 .24243 .49366 .23391 .50526 .22695 .49871 .23565 Mtetra
.098 0 0 r
.49871 .23565 .50526 .22695 .51688 .22112 .51043 .23047 Mtetra
.284 0 0 r
.51043 .23047 .51688 .22112 .52854 .21822 .52218 .22826 Mtetra
.4 0 .045 r
.52218 .22826 .52854 .21822 .54027 .21787 .53401 .22851 Mtetra
.467 .015 .094 r
.53401 .22851 .54027 .21787 .5521 .21959 .54594 .2306 Mtetra
.479 .031 .107 r
.54594 .2306 .5521 .21959 .56404 .22192 .55797 .23307 Mtetra
.427 0 .085 r
.55797 .23307 .56404 .22192 .57605 .22272 .57009 .23384 Mtetra
.351 0 .048 r
.57009 .23384 .57605 .22272 .58812 .22165 .58225 .23245 Mtetra
.219 0 0 r
.58225 .23245 .58812 .22165 .6002 .21788 .59443 .22799 Mtetra
.098 0 0 r
.59443 .22799 .6002 .21788 .61229 .21244 .6066 .22146 Mtetra
0 0 0 r
.6066 .22146 .61229 .21244 .6244 .20647 .61877 .21387 Mtetra
.61877 .21387 .6244 .20647 .63657 .2007 .63097 .20613 Mtetra
.63097 .20613 .63657 .2007 .64883 .19631 .64324 .19952 Mtetra
.64324 .19952 .64883 .19631 .6612 .19298 .6556 .1939 Mtetra
.326 .808 .771 r
.6556 .1939 .6612 .19298 .67368 .19072 .66805 .1895 Mtetra
.438 .869 .924 r
.66805 .1895 .67368 .19072 .68626 .18891 .68059 .18573 Mtetra
.539 .875 .99 r
.68059 .18573 .68626 .18891 .69891 .18686 .69321 .18205 Mtetra
.593 .845 .992 r
.69321 .18205 .69891 .18686 .71161 .18449 .70588 .17829 Mtetra
.627 .81 .97 r
.70588 .17829 .71161 .18449 .72436 .18164 .7186 .17425 Mtetra
.655 .782 .942 r
.7186 .17425 .72436 .18164 .73713 .1781 .73134 .16968 Mtetra
.602 .737 .939 r
.05808 .40196 .06568 .40859 .07566 .405 .06793 .39951 Mtetra
.61 .779 .961 r
.06793 .39951 .07566 .405 .08576 .40092 .07786 .39675 Mtetra
.599 .823 .985 r
.07786 .39675 .08576 .40092 .09592 .39656 .08785 .39388 Mtetra
.551 .86 .997 r
.08785 .39388 .09592 .39656 .10612 .39213 .09787 .39111 Mtetra
.435 .854 .955 r
.09787 .39111 .10612 .39213 .11635 .38779 .10789 .38862 Mtetra
.196 .726 .777 r
.10789 .38862 .11635 .38779 .12654 .38407 .11788 .38677 Mtetra
.105 0 0 r
.11788 .38677 .12654 .38407 .13662 .38151 .12779 .38602 Mtetra
.27 0 0 r
.12779 .38602 .13662 .38151 .14664 .37993 .13767 .38596 Mtetra
.364 0 0 r
.13767 .38596 .14664 .37993 .15658 .37944 .14753 .38657 Mtetra
.352 0 0 r
.14753 .38657 .15658 .37944 .1666 .37882 .15753 .38663 Mtetra
.271 0 0 r
.15753 .38663 .1666 .37882 .17678 .3772 .16775 .38522 Mtetra
.106 0 0 r
.16775 .38522 .17678 .3772 .18723 .37357 .17828 .38153 Mtetra
0 0 0 r
.17828 .38153 .18723 .37357 .19803 .36695 .18917 .37475 Mtetra
.18917 .37475 .19803 .36695 .20906 .35823 .2003 .36582 Mtetra
.529 .853 .564 r
.2003 .36582 .20906 .35823 .22027 .34782 .21161 .35527 Mtetra
.508 .842 .556 r
.21161 .35527 .22027 .34782 .23144 .33776 .22288 .34505 Mtetra
0 0 0 r
.22288 .34505 .23144 .33776 .24245 .3295 .23399 .33654 Mtetra
.23399 .33654 .24245 .3295 .25326 .32363 .2449 .33044 Mtetra
.112 0 0 r
.2449 .33044 .25326 .32363 .26386 .3207 .25558 .32733 Mtetra
.26 0 0 r
.25558 .32733 .26386 .3207 .27439 .31932 .26615 .3262 Mtetra
.354 0 0 r
.26615 .3262 .27439 .31932 .28491 .31871 .27667 .32644 Mtetra
.387 0 0 r
.27667 .32644 .28491 .31871 .29553 .31776 .28724 .32701 Mtetra
.391 0 .024 r
.28724 .32701 .29553 .31776 .30628 .31579 .29792 .32721 Mtetra
.396 0 .084 r
.29792 .32721 .30628 .31579 .31714 .31312 .30869 .32696 Mtetra
.395 0 .133 r
.30869 .32696 .31714 .31312 .32809 .3098 .31958 .32606 Mtetra
.395 .002 .172 r
.31958 .32606 .32809 .3098 .3391 .30615 .33057 .32455 Mtetra
.391 .014 .198 r
.33057 .32455 .3391 .30615 .35018 .3023 .34167 .32239 Mtetra
.385 .019 .214 r
.34167 .32239 .35018 .3023 .36131 .29829 .35285 .31957 Mtetra
.376 .017 .223 r
.35285 .31957 .36131 .29829 .37249 .29418 .36413 .3161 Mtetra
.366 .012 .225 r
.36413 .3161 .37249 .29418 .38372 .29015 .37549 .31205 Mtetra
.352 0 .219 r
.37549 .31205 .38372 .29015 .39498 .28617 .38692 .30744 Mtetra
.33 0 .203 r
.38692 .30744 .39498 .28617 .4063 .28211 .39842 .30216 Mtetra
.299 0 .177 r
.39842 .30216 .4063 .28211 .41767 .27788 .40998 .29621 Mtetra
.257 0 .137 r
.40998 .29621 .41767 .27788 .4291 .27346 .4216 .28961 Mtetra
.197 0 .078 r
.4216 .28961 .4291 .27346 .44058 .26869 .43327 .28238 Mtetra
.108 0 0 r
.43327 .28238 .44058 .26869 .45212 .26328 .44499 .27448 Mtetra
0 0 0 r
.44499 .27448 .45212 .26328 .46371 .25714 .45674 .26611 Mtetra
.45674 .26611 .46371 .25714 .47535 .24996 .46851 .25736 Mtetra
.46851 .25736 .47535 .24996 .48702 .24243 .48029 .24892 Mtetra
.48029 .24892 .48702 .24243 .49871 .23565 .49208 .24186 Mtetra
.49208 .24186 .49871 .23565 .51043 .23047 .50388 .2368 Mtetra
.201 0 0 r
.50388 .2368 .51043 .23047 .52218 .22826 .51572 .2348 Mtetra
.348 0 0 r
.51572 .2348 .52218 .22826 .53401 .22851 .52762 .23525 Mtetra
.433 0 0 r
.52762 .23525 .53401 .22851 .54594 .2306 .53963 .23748 Mtetra
.447 0 0 r
.53963 .23748 .54594 .2306 .55797 .23307 .55174 .24006 Mtetra
.378 0 0 r
.55174 .24006 .55797 .23307 .57009 .23384 .56394 .241 Mtetra
.273 0 0 r
.56394 .241 .57009 .23384 .58225 .23245 .5762 .23975 Mtetra
.094 0 0 r
.5762 .23975 .58225 .23245 .59443 .22799 .58848 .2353 Mtetra
0 0 0 r
.58848 .2353 .59443 .22799 .6066 .22146 .60075 .22851 Mtetra
.60075 .22851 .6066 .22146 .61877 .21387 .61301 .22018 Mtetra
.61301 .22018 .61877 .21387 .63097 .20613 .62527 .21127 Mtetra
.62527 .21127 .63097 .20613 .64324 .19952 .63758 .20302 Mtetra
.63758 .20302 .64324 .19952 .6556 .1939 .64994 .19549 Mtetra
.434 .863 .749 r
.64994 .19549 .6556 .1939 .66805 .1895 .66238 .18908 Mtetra
.532 .922 .89 r
.66238 .18908 .66805 .1895 .68059 .18573 .6749 .18333 Mtetra
.616 .929 .968 r
.6749 .18333 .68059 .18573 .69321 .18205 .68748 .17786 Mtetra
.66 .894 .981 r
.68748 .17786 .69321 .18205 .70588 .17829 .70012 .1725 Mtetra
.684 .848 .962 r
.70012 .1725 .70588 .17829 .7186 .17425 .71279 .16701 Mtetra
.698 .806 .932 r
.71279 .16701 .7186 .17425 .73134 .16968 .7255 .16118 Mtetra
.538 .715 .954 r
.05043 .39529 .05808 .40196 .06793 .39951 .06014 .39391 Mtetra
.531 .751 .977 r
.06014 .39391 .06793 .39951 .07786 .39675 .06991 .39238 Mtetra
.497 .784 .996 r
.06991 .39238 .07786 .39675 .08785 .39388 .07974 .39087 Mtetra
.418 .797 .992 r
.07974 .39087 .08785 .39388 .09787 .39111 .08958 .38956 Mtetra
.269 .755 .92 r
.08958 .38956 .09787 .39111 .10789 .38862 .09943 .38864 Mtetra
.05 .618 .738 r
.09943 .38864 .10789 .38862 .11788 .38677 .10927 .38828 Mtetra
.179 0 0 r
.10927 .38828 .11788 .38677 .12779 .38602 .11905 .3888 Mtetra
.285 0 0 r
.11905 .3888 .12779 .38602 .13767 .38596 .12885 .3897 Mtetra
.336 0 0 r
.12885 .3897 .13767 .38596 .14753 .38657 .1387 .39079 Mtetra
.277 0 0 r
.1387 .39079 .14753 .38657 .15753 .38663 .14873 .39099 Mtetra
.115 0 0 r
.14873 .39099 .15753 .38663 .16775 .38522 .15902 .38944 Mtetra
0 0 0 r
.15902 .38944 .16775 .38522 .17828 .38153 .16962 .38557 Mtetra
.489 .885 .725 r
.16962 .38557 .17828 .38153 .18917 .37475 .18058 .37876 Mtetra
.651 .96 .773 r
.18058 .37876 .18917 .37475 .2003 .36582 .19177 .36998 Mtetra
.725 .983 .776 r
.19177 .36998 .2003 .36582 .21161 .35527 .20311 .35982 Mtetra
.679 .964 .748 r
.20311 .35982 .21161 .35527 .22288 .34505 .21441 .35001 Mtetra
.522 .888 .679 r
.21441 .35001 .22288 .34505 .23399 .33654 .22557 .34183 Mtetra
0 0 0 r
.22557 .34183 .23399 .33654 .2449 .33044 .23653 .33598 Mtetra
.056 0 0 r
.23653 .33598 .2449 .33044 .25558 .32733 .24726 .33304 Mtetra
.251 0 0 r
.24726 .33304 .25558 .32733 .26615 .3262 .25786 .33227 Mtetra
.376 0 0 r
.25786 .33227 .26615 .3262 .27667 .32644 .26838 .33322 Mtetra
.428 0 0 r
.26838 .33322 .27667 .32644 .28724 .32701 .27892 .33494 Mtetra
.444 0 .015 r
.27892 .33494 .28724 .32701 .29792 .32721 .28954 .33676 Mtetra
.447 0 .063 r
.28954 .33676 .29792 .32721 .30869 .32696 .30026 .33832 Mtetra
.436 0 .1 r
.30026 .33832 .30869 .32696 .31958 .32606 .31111 .33925 Mtetra
.422 0 .129 r
.31111 .33925 .31958 .32606 .33057 .32455 .32209 .33939 Mtetra
.402 0 .147 r
.32209 .33939 .33057 .32455 .34167 .32239 .3332 .33857 Mtetra
.379 0 .156 r
.3332 .33857 .34167 .32239 .35285 .31957 .34444 .3367 Mtetra
.353 0 .157 r
.34444 .3367 .35285 .31957 .36413 .3161 .35581 .33372 Mtetra
.324 0 .15 r
.35581 .33372 .36413 .3161 .37549 .31205 .36728 .32966 Mtetra
.289 0 .134 r
.36728 .32966 .37549 .31205 .38692 .30744 .37886 .32453 Mtetra
.242 0 .105 r
.37886 .32453 .38692 .30744 .39842 .30216 .39052 .31828 Mtetra
.184 0 .063 r
.39052 .31828 .39842 .30216 .40998 .29621 .40226 .31097 Mtetra
.108 0 .003 r
.40226 .31097 .40998 .29621 .4216 .28961 .41406 .30267 Mtetra
.014 0 0 r
.41406 .30267 .4216 .28961 .43327 .28238 .4259 .29356 Mtetra
0 0 0 r
.4259 .29356 .43327 .28238 .44499 .27448 .43778 .2838 Mtetra
.43778 .2838 .44499 .27448 .45674 .26611 .44967 .27375 Mtetra
.44967 .27375 .45674 .26611 .46851 .25736 .46156 .26379 Mtetra
.46156 .26379 .46851 .25736 .48029 .24892 .47345 .25459 Mtetra
.47345 .25459 .48029 .24892 .49208 .24186 .48534 .24712 Mtetra
.48534 .24712 .49208 .24186 .50388 .2368 .49722 .24184 Mtetra
.12 0 0 r
.49722 .24184 .50388 .2368 .51572 .2348 .50914 .23955 Mtetra
.273 0 0 r
.50914 .23955 .51572 .2348 .52762 .23525 .52112 .23962 Mtetra
.361 0 0 r
.52112 .23962 .52762 .23525 .53963 .23748 .5332 .24138 Mtetra
.368 0 0 r
.5332 .24138 .53963 .23748 .55174 .24006 .54538 .24352 Mtetra
.266 0 0 r
.54538 .24352 .55174 .24006 .56394 .241 .55765 .24426 Mtetra
.108 0 0 r
.55765 .24426 .56394 .241 .5762 .23975 .56998 .24299 Mtetra
0 0 0 r
.56998 .24299 .5762 .23975 .58848 .2353 .58234 .23868 Mtetra
.58234 .23868 .58848 .2353 .60075 .22851 .5947 .23199 Mtetra
.457 .848 .64 r
.5947 .23199 .60075 .22851 .61301 .22018 .60705 .22346 Mtetra
.529 .887 .663 r
.60705 .22346 .61301 .22018 .62527 .21127 .61939 .214 Mtetra
.554 .907 .699 r
.61939 .214 .62527 .21127 .63758 .20302 .63175 .20472 Mtetra
.6 .941 .767 r
.63175 .20472 .63758 .20302 .64994 .19549 .64415 .19582 Mtetra
.632 .963 .849 r
.64415 .19582 .64994 .19549 .66238 .18908 .6566 .1878 Mtetra
.679 .97 .92 r
.6566 .1878 .66238 .18908 .6749 .18333 .66911 .18036 Mtetra
.712 .946 .956 r
.66911 .18036 .6749 .18333 .68748 .17786 .68167 .17332 Mtetra
.727 .904 .957 r
.68167 .17332 .68748 .17786 .70012 .1725 .69428 .16647 Mtetra
.732 .857 .94 r
.69428 .16647 .70012 .1725 .71279 .16701 .70693 .15963 Mtetra
.734 .816 .915 r
.70693 .15963 .71279 .16701 .7255 .16118 .71961 .15261 Mtetra
.49 .697 .96 r
.04273 .38856 .05043 .39529 .06014 .39391 .05234 .38784 Mtetra
.48 .717 .974 r
.05234 .38784 .06014 .39391 .06991 .39238 .06203 .38706 Mtetra
.453 .733 .987 r
.06203 .38706 .06991 .39238 .07974 .39087 .07175 .38635 Mtetra
.401 .74 .992 r
.07175 .38635 .07974 .39087 .08958 .38956 .08151 .38584 Mtetra
.316 .726 .978 r
.08151 .38584 .08958 .38956 .09943 .38864 .09128 .3857 Mtetra
.203 .684 .932 r
.09128 .3857 .09943 .38864 .10927 .38828 .10105 .38599 Mtetra
.061 .603 .847 r
.10105 .38599 .10927 .38828 .11905 .3888 .1108 .3869 Mtetra
.006 .568 .801 r
.1108 .3869 .11905 .3888 .12885 .3897 .12061 .38796 Mtetra
.006 .571 .795 r
.12061 .38796 .12885 .3897 .1387 .39079 .1305 .38893 Mtetra
.151 .675 .878 r
.1305 .38893 .1387 .39079 .14873 .39099 .14057 .38897 Mtetra
.378 .808 .966 r
.14057 .38897 .14873 .39099 .15902 .38944 .15089 .38735 Mtetra
.574 .891 .988 r
.15089 .38735 .15902 .38944 .16962 .38557 .1615 .38375 Mtetra
.718 .931 .96 r
.1615 .38375 .16962 .38557 .18058 .37876 .17242 .37773 Mtetra
.773 .954 .932 r
.17242 .37773 .18058 .37876 .19177 .36998 .18354 .37014 Mtetra
.791 .978 .906 r
.18354 .37014 .19177 .36998 .20311 .35982 .19478 .36153 Mtetra
.729 .989 .875 r
.19478 .36153 .20311 .35982 .21441 .35001 .206 .35327 Mtetra
.535 .916 .774 r
.206 .35327 .21441 .35001 .22557 .34183 .21709 .3464 Mtetra
0 0 0 r
.21709 .3464 .22557 .34183 .23653 .33598 .22803 .34147 Mtetra
.093 0 0 r
.22803 .34147 .23653 .33598 .24726 .33304 .23878 .339 Mtetra
.269 0 0 r
.23878 .339 .24726 .33304 .25786 .33227 .24943 .33842 Mtetra
.375 0 0 r
.24943 .33842 .25786 .33227 .26838 .33322 .26001 .33941 Mtetra
.418 0 0 r
.26001 .33941 .26838 .33322 .27892 .33494 .2706 .34117 Mtetra
.428 0 0 r
.2706 .34117 .27892 .33494 .28954 .33676 .28126 .34313 Mtetra
.418 0 0 r
.28126 .34313 .28954 .33676 .30026 .33832 .29203 .34489 Mtetra
.389 0 0 r
.29203 .34489 .30026 .33832 .31111 .33925 .30292 .34606 Mtetra
.349 0 0 r
.30292 .34606 .31111 .33925 .32209 .33939 .31395 .34643 Mtetra
.294 0 0 r
.31395 .34643 .32209 .33939 .3332 .33857 .32513 .34578 Mtetra
.23 0 0 r
.32513 .34578 .3332 .33857 .34444 .3367 .33644 .34404 Mtetra
.155 0 0 r
.33644 .34404 .34444 .3367 .35581 .33372 .34788 .34113 Mtetra
.075 0 0 r
.34788 .34113 .35581 .33372 .36728 .32966 .35943 .33705 Mtetra
0 0 0 r
.35943 .33705 .36728 .32966 .37886 .32453 .3711 .33181 Mtetra
.3711 .33181 .37886 .32453 .39052 .31828 .38286 .32539 Mtetra
.38286 .32539 .39052 .31828 .40226 .31097 .3947 .31786 Mtetra
.3947 .31786 .40226 .31097 .41406 .30267 .4066 .3093 Mtetra
.4066 .3093 .41406 .30267 .4259 .29356 .41855 .29991 Mtetra
.41855 .29991 .4259 .29356 .43778 .2838 .43053 .2899 Mtetra
.465 .819 .544 r
.43053 .2899 .43778 .2838 .44967 .27375 .44252 .27967 Mtetra
.46 .818 .548 r
.44252 .27967 .44967 .27375 .46156 .26379 .45452 .26961 Mtetra
0 0 0 r
.45452 .26961 .46156 .26379 .47345 .25459 .4665 .26033 Mtetra
.4665 .26033 .47345 .25459 .48534 .24712 .47848 .25263 Mtetra
.47848 .25263 .48534 .24712 .49722 .24184 .49046 .24684 Mtetra
.037 0 0 r
.49046 .24684 .49722 .24184 .50914 .23955 .50247 .24354 Mtetra
.14 0 0 r
.50247 .24354 .50914 .23955 .52112 .23962 .51453 .24224 Mtetra
.182 0 0 r
.51453 .24224 .52112 .23962 .5332 .24138 .52666 .24237 Mtetra
.117 0 0 r
.52666 .24237 .5332 .24138 .54538 .24352 .53889 .24287 Mtetra
.105 .657 .797 r
.53889 .24287 .54538 .24352 .55765 .24426 .5512 .24233 Mtetra
.356 .809 .942 r
.5512 .24233 .55765 .24426 .56998 .24299 .56358 .24019 Mtetra
.592 .905 .983 r
.56358 .24019 .56998 .24299 .58234 .23868 .57599 .23555 Mtetra
.708 .934 .962 r
.57599 .23555 .58234 .23868 .5947 .23199 .58842 .22887 Mtetra
.774 .947 .933 r
.58842 .22887 .5947 .23199 .60705 .22346 .60084 .22046 Mtetra
.803 .954 .915 r
.60084 .22046 .60705 .22346 .61939 .214 .61325 .21106 Mtetra
.805 .957 .913 r
.61325 .21106 .61939 .214 .63175 .20472 .62568 .20155 Mtetra
.802 .952 .916 r
.62568 .20155 .63175 .20472 .64415 .19582 .63812 .19218 Mtetra
.786 .94 .928 r
.63812 .19218 .64415 .19582 .6566 .1878 .65061 .18343 Mtetra
.776 .918 .933 r
.65061 .18343 .6566 .1878 .66911 .18036 .66315 .17512 Mtetra
.767 .89 .932 r
.66315 .17512 .66911 .18036 .68167 .17332 .67572 .16717 Mtetra
.76 .861 .924 r
.67572 .16717 .68167 .17332 .69428 .16647 .68834 .15943 Mtetra
.755 .833 .912 r
.68834 .15943 .69428 .16647 .70693 .15963 .701 .15174 Mtetra
.752 .808 .897 r
.701 .15174 .70693 .15963 .71961 .15261 .71368 .14397 Mtetra
.47 .689 .962 r
.03496 .38178 .04273 .38856 .05234 .38784 .04455 .3813 Mtetra
.466 .696 .967 r
.04455 .3813 .05234 .38784 .06203 .38706 .05421 .3808 Mtetra
.454 .702 .973 r
.05421 .3808 .06203 .38706 .07175 .38635 .06391 .38035 Mtetra
.433 .703 .978 r
.06391 .38035 .07175 .38635 .08151 .38584 .07365 .38005 Mtetra
.401 .696 .981 r
.07365 .38005 .08151 .38584 .09128 .3857 .08341 .38001 Mtetra
.37 .686 .98 r
.08341 .38001 .09128 .3857 .10105 .38599 .09321 .38023 Mtetra
.336 .667 .975 r
.09321 .38023 .10105 .38599 .1108 .3869 .10302 .3808 Mtetra
.352 .664 .973 r
.10302 .3808 .1108 .3869 .12061 .38796 .1129 .38136 Mtetra
.392 .666 .969 r
.1129 .38136 .12061 .38796 .1305 .38893 .12287 .38169 Mtetra
.472 .681 .957 r
.12287 .38169 .1305 .38893 .14057 .38897 .13301 .38123 Mtetra
.558 .701 .936 r
.13301 .38123 .14057 .38897 .15089 .38735 .14337 .37949 Mtetra
.626 .722 .916 r
.14337 .37949 .15089 .38735 .1615 .38375 .15395 .37631 Mtetra
.689 .753 .901 r
.15395 .37631 .1615 .38375 .17242 .37773 .16477 .37144 Mtetra
.726 .795 .907 r
.16477 .37144 .17242 .37773 .18354 .37014 .17573 .36552 Mtetra
.751 .85 .925 r
.17573 .36552 .18354 .37014 .19478 .36153 .1868 .35897 Mtetra
.734 .915 .955 r
.1868 .35897 .19478 .36153 .206 .35327 .19786 .35271 Mtetra
.626 .943 .953 r
.19786 .35271 .206 .35327 .21709 .3464 .20884 .34747 Mtetra
.393 .852 .842 r
.20884 .34747 .21709 .3464 .22803 .34147 .21973 .34362 Mtetra
0 0 0 r
.21973 .34362 .22803 .34147 .23878 .339 .2305 .3415 Mtetra
.088 0 0 r
.2305 .3415 .23878 .339 .24943 .33842 .24121 .34073 Mtetra
.192 0 0 r
.24121 .34073 .24943 .33842 .26001 .33941 .25189 .34106 Mtetra
.21 0 0 r
.25189 .34106 .26001 .33941 .2706 .34117 .2626 .34194 Mtetra
.17 0 0 r
.2626 .34194 .2706 .34117 .28126 .34313 .27338 .34294 Mtetra
.08 0 0 r
.27338 .34294 .28126 .34313 .29203 .34489 .28426 .34374 Mtetra
.055 .616 .798 r
.28426 .34374 .29203 .34489 .30292 .34606 .29525 .34403 Mtetra
.208 .712 .906 r
.29525 .34403 .30292 .34606 .31395 .34643 .30637 .34364 Mtetra
.354 .783 .971 r
.30637 .34364 .31395 .34643 .32513 .34578 .31761 .3424 Mtetra
.47 .824 .996 r
.31761 .3424 .32513 .34578 .33644 .34404 .32899 .34024 Mtetra
.558 .848 .998 r
.32899 .34024 .33644 .34404 .34788 .34113 .34048 .33711 Mtetra
.623 .864 .988 r
.34048 .33711 .34788 .34113 .35943 .33705 .35208 .333 Mtetra
.673 .878 .975 r
.35208 .333 .35943 .33705 .3711 .33181 .36378 .32792 Mtetra
.714 .892 .961 r
.36378 .32792 .3711 .33181 .38286 .32539 .37557 .32186 Mtetra
.746 .909 .949 r
.37557 .32186 .38286 .32539 .3947 .31786 .38744 .31487 Mtetra
.772 .929 .936 r
.38744 .31487 .3947 .31786 .4066 .3093 .39937 .30702 Mtetra
.788 .949 .925 r
.39937 .30702 .4066 .3093 .41855 .29991 .41136 .29845 Mtetra
.794 .97 .913 r
.41136 .29845 .41855 .29991 .43053 .2899 .42337 .28936 Mtetra
.783 .986 .898 r
.42337 .28936 .43053 .2899 .44252 .27967 .43541 .28005 Mtetra
.75 .992 .876 r
.43541 .28005 .44252 .27967 .45452 .26961 .44746 .27084 Mtetra
.683 .979 .845 r
.44746 .27084 .45452 .26961 .4665 .26033 .45952 .26217 Mtetra
.571 .936 .804 r
.45952 .26217 .4665 .26033 .47848 .25263 .47157 .25461 Mtetra
.45 .875 .768 r
.47157 .25461 .47848 .25263 .49046 .24684 .48363 .24841 Mtetra
.321 .803 .753 r
.48363 .24841 .49046 .24684 .50247 .24354 .49572 .24397 Mtetra
.273 .778 .806 r
.49572 .24397 .50247 .24354 .51453 .24224 .50785 .24094 Mtetra
.301 .786 .904 r
.50785 .24094 .51453 .24224 .52666 .24237 .52004 .23896 Mtetra
.404 .799 .987 r
.52004 .23896 .52666 .24237 .53889 .24287 .53231 .23729 Mtetra
.529 .788 .992 r
.53231 .23729 .53889 .24287 .5512 .24233 .54465 .23498 Mtetra
.608 .763 .953 r
.54465 .23498 .5512 .24233 .56358 .24019 .55705 .23158 Mtetra
.675 .752 .909 r
.55705 .23158 .56358 .24019 .57599 .23555 .56949 .22645 Mtetra
.715 .754 .883 r
.56949 .22645 .57599 .23555 .58842 .22887 .58195 .21982 Mtetra
.749 .767 .868 r
.58195 .21982 .58842 .22887 .60084 .22046 .59442 .21186 Mtetra
.771 .786 .866 r
.59442 .21186 .60084 .22046 .61325 .21106 .6069 .20306 Mtetra
.781 .806 .872 r
.6069 .20306 .61325 .21106 .62568 .20155 .61939 .19401 Mtetra
.786 .821 .88 r
.61939 .19401 .62568 .20155 .63812 .19218 .6319 .18492 Mtetra
.78 .829 .89 r
.6319 .18492 .63812 .19218 .65061 .18343 .64445 .17619 Mtetra
.774 .83 .895 r
.64445 .17619 .65061 .18343 .66315 .17512 .65703 .1677 Mtetra
.766 .824 .897 r
.65703 .1677 .66315 .17512 .67572 .16717 .66964 .15948 Mtetra
.761 .816 .896 r
.66964 .15948 .67572 .16717 .68834 .15943 .68229 .15139 Mtetra
.757 .806 .892 r
.68229 .15139 .68834 .15943 .701 .15174 .69498 .14334 Mtetra
.756 .797 .886 r
.69498 .14334 .701 .15174 .71368 .14397 .70769 .13525 Mtetra
.487 .696 .961 r
.02714 .37496 .03496 .38178 .04455 .3813 .03678 .37424 Mtetra
.494 .691 .956 r
.03678 .37424 .04455 .3813 .05421 .3808 .04648 .37348 Mtetra
.497 .684 .95 r
.04648 .37348 .05421 .3808 .06391 .38035 .05623 .37272 Mtetra
.498 .676 .944 r
.05623 .37272 .06391 .38035 .07365 .38005 .06604 .37201 Mtetra
.497 .663 .936 r
.06604 .37201 .07365 .38005 .08341 .38001 .07589 .3714 Mtetra
.499 .647 .923 r
.07589 .3714 .08341 .38001 .09321 .38023 .08579 .37086 Mtetra
.5 .626 .907 r
.08579 .37086 .09321 .38023 .10302 .3808 .09573 .37043 Mtetra
.513 .606 .883 r
.09573 .37043 .10302 .3808 .1129 .38136 .10576 .3699 Mtetra
.529 .589 .859 r
.10576 .3699 .1129 .38136 .12287 .38169 .11587 .36914 Mtetra
.551 .578 .835 r
.11587 .36914 .12287 .38169 .13301 .38123 .1261 .36789 Mtetra
.576 .577 .816 r
.1261 .36789 .13301 .38123 .14337 .37949 .13648 .36589 Mtetra
.599 .585 .808 r
.13648 .36589 .14337 .37949 .15395 .37631 .14701 .36313 Mtetra
.625 .604 .81 r
.14701 .36313 .15395 .37631 .16477 .37144 .15769 .35949 Mtetra
.645 .635 .826 r
.15769 .35949 .16477 .37144 .17573 .36552 .16847 .35534 Mtetra
.661 .678 .855 r
.16847 .35534 .17573 .36552 .1868 .35897 .17933 .35088 Mtetra
.665 .732 .9 r
.17933 .35088 .1868 .35897 .19786 .35271 .19021 .34658 Mtetra
.644 .787 .95 r
.19021 .34658 .19786 .35271 .20884 .34747 .20108 .34282 Mtetra
.592 .822 .987 r
.20108 .34282 .20884 .34747 .21973 .34362 .21192 .33974 Mtetra
.51 .82 1 r
.21192 .33974 .21973 .34362 .2305 .3415 .22273 .33751 Mtetra
.458 .795 .999 r
.22273 .33751 .2305 .3415 .24121 .34073 .23354 .33592 Mtetra
.443 .761 .996 r
.23354 .33592 .24121 .34073 .25189 .34106 .24437 .33484 Mtetra
.468 .724 .981 r
.24437 .33484 .25189 .34106 .2626 .34194 .25525 .33397 Mtetra
.502 .681 .946 r
.25525 .33397 .2626 .34194 .27338 .34294 .26619 .33308 Mtetra
.53 .639 .902 r
.26619 .33308 .27338 .34294 .28426 .34374 .27722 .332 Mtetra
.552 .605 .86 r
.27722 .332 .28426 .34374 .29525 .34403 .28834 .33057 Mtetra
.568 .581 .826 r
.28834 .33057 .29525 .34403 .30637 .34364 .29956 .3287 Mtetra
.582 .564 .8 r
.29956 .3287 .30637 .34364 .31761 .3424 .31088 .32629 Mtetra
.593 .555 .781 r
.31088 .32629 .31761 .3424 .32899 .34024 .3223 .32333 Mtetra
.605 .552 .769 r
.3223 .32333 .32899 .34024 .34048 .33711 .33381 .31977 Mtetra
.616 .554 .762 r
.33381 .31977 .34048 .33711 .35208 .333 .34541 .31563 Mtetra
.628 .56 .759 r
.34541 .31563 .35208 .333 .36378 .32792 .35709 .31089 Mtetra
.641 .572 .761 r
.35709 .31089 .36378 .32792 .37557 .32186 .36884 .30555 Mtetra
.655 .588 .767 r
.36884 .30555 .37557 .32186 .38744 .31487 .38067 .29965 Mtetra
.672 .611 .778 r
.38067 .29965 .38744 .31487 .39937 .30702 .39255 .29321 Mtetra
.69 .639 .794 r
.39255 .29321 .39937 .30702 .41136 .29845 .40449 .28631 Mtetra
.71 .675 .815 r
.40449 .28631 .41136 .29845 .42337 .28936 .41647 .27904 Mtetra
.729 .719 .841 r
.41647 .27904 .42337 .28936 .43541 .28005 .42849 .27158 Mtetra
.744 .768 .872 r
.42849 .27158 .43541 .28005 .44746 .27084 .44053 .26408 Mtetra
.751 .818 .905 r
.44053 .26408 .44746 .27084 .45952 .26217 .4526 .25678 Mtetra
.739 .86 .937 r
.4526 .25678 .45952 .26217 .47157 .25461 .46469 .24998 Mtetra
.713 .88 .959 r
.46469 .24998 .47157 .25461 .48363 .24841 .4768 .24383 Mtetra
.675 .874 .973 r
.4768 .24383 .48363 .24841 .49572 .24397 .48895 .23854 Mtetra
.651 .839 .973 r
.48895 .23854 .49572 .24397 .50785 .24094 .50113 .23395 Mtetra
.636 .784 .952 r
.50113 .23395 .50785 .24094 .52004 .23896 .51336 .22989 Mtetra
.633 .721 .911 r
.51336 .22989 .52004 .23896 .53231 .23729 .52566 .226 Mtetra
.637 .669 .864 r
.52566 .226 .53231 .23729 .54465 .23498 .53801 .2218 Mtetra
.644 .635 .827 r
.53801 .2218 .54465 .23498 .55705 .23158 .55041 .21706 Mtetra
.657 .62 .801 r
.55041 .21706 .55705 .23158 .56949 .22645 .56286 .21142 Mtetra
.671 .62 .79 r
.56286 .21142 .56949 .22645 .58195 .21982 .57534 .20497 Mtetra
.687 .631 .788 r
.57534 .20497 .58195 .21982 .59442 .21186 .58785 .19775 Mtetra
.702 .65 .795 r
.58785 .19775 .59442 .21186 .6069 .20306 .60038 .19001 Mtetra
.715 .674 .808 r
.60038 .19001 .6069 .20306 .61939 .19401 .61293 .18201 Mtetra
.726 .698 .823 r
.61293 .18201 .61939 .19401 .6319 .18492 .6255 .1739 Mtetra
.733 .721 .84 r
.6255 .1739 .6319 .18492 .64445 .17619 .63811 .16588 Mtetra
.737 .739 .853 r
.63811 .16588 .64445 .17619 .65703 .1677 .65075 .15792 Mtetra
.74 .754 .864 r
.65075 .15792 .65703 .1677 .66964 .15948 .66343 .15006 Mtetra
.742 .764 .871 r
.66343 .15006 .66964 .15948 .68229 .15139 .67614 .14222 Mtetra
.744 .773 .876 r
.67614 .14222 .68229 .15139 .69498 .14334 .68888 .13437 Mtetra
.746 .78 .88 r
.68888 .13437 .69498 .14334 .70769 .13525 .70165 .12647 Mtetra
.541 .716 .954 r
.01926 .36808 .02714 .37496 .03678 .37424 .02903 .36656 Mtetra
.553 .696 .935 r
.02903 .36656 .03678 .37424 .04648 .37348 .03887 .36496 Mtetra
.563 .675 .914 r
.03887 .36496 .04648 .37348 .05623 .37272 .04877 .36327 Mtetra
.569 .653 .892 r
.04877 .36327 .05623 .37272 .06604 .37201 .05873 .3615 Mtetra
.574 .629 .868 r
.05873 .3615 .06604 .37201 .07589 .3714 .06876 .35963 Mtetra
.577 .604 .843 r
.06876 .35963 .07589 .3714 .08579 .37086 .07885 .35768 Mtetra
.578 .579 .817 r
.07885 .35768 .08579 .37086 .09573 .37043 .08901 .35565 Mtetra
.578 .553 .791 r
.08901 .35565 .09573 .37043 .10576 .3699 .09923 .35352 Mtetra
.577 .532 .768 r
.09923 .35352 .10576 .3699 .11587 .36914 .10952 .3513 Mtetra
.575 .515 .751 r
.10952 .3513 .11587 .36914 .1261 .36789 .11986 .349 Mtetra
.575 .505 .739 r
.11986 .349 .1261 .36789 .13648 .36589 .13028 .3466 Mtetra
.576 .502 .735 r
.13028 .3466 .13648 .36589 .14701 .36313 .14075 .34411 Mtetra
.578 .507 .738 r
.14075 .34411 .14701 .36313 .15769 .35949 .15129 .34153 Mtetra
.583 .52 .75 r
.15129 .34153 .15769 .35949 .16847 .35534 .16189 .33886 Mtetra
.589 .541 .769 r
.16189 .33886 .16847 .35534 .17933 .35088 .17255 .3361 Mtetra
.597 .568 .793 r
.17255 .3361 .17933 .35088 .19021 .34658 .18327 .33324 Mtetra
.603 .594 .815 r
.18327 .33324 .19021 .34658 .20108 .34282 .19405 .3303 Mtetra
.608 .612 .829 r
.19405 .3303 .20108 .34282 .21192 .33974 .2049 .32725 Mtetra
.611 .614 .83 r
.2049 .32725 .21192 .33974 .22273 .33751 .2158 .32412 Mtetra
.61 .599 .815 r
.2158 .32412 .22273 .33751 .23354 .33592 .22677 .32088 Mtetra
.607 .573 .79 r
.22677 .32088 .23354 .33592 .24437 .33484 .23779 .31756 Mtetra
.601 .542 .76 r
.23779 .31756 .24437 .33484 .25525 .33397 .24887 .31413 Mtetra
.595 .513 .732 r
.24887 .31413 .25525 .33397 .26619 .33308 .26002 .31062 Mtetra
.588 .489 .709 r
.26002 .31062 .26619 .33308 .27722 .332 .27122 .307 Mtetra
.583 .47 .69 r
.27122 .307 .27722 .332 .28834 .33057 .28248 .30329 Mtetra
.579 .455 .675 r
.28248 .30329 .28834 .33057 .29956 .3287 .29379 .29948 Mtetra
.576 .445 .665 r
.29379 .29948 .29956 .3287 .31088 .32629 .30516 .29557 Mtetra
.574 .438 .657 r
.30516 .29557 .31088 .32629 .3223 .32333 .31659 .29157 Mtetra
.574 .433 .652 r
.31659 .29157 .3223 .32333 .33381 .31977 .32808 .28747 Mtetra
.574 .432 .65 r
.32808 .28747 .33381 .31977 .34541 .31563 .33962 .28327 Mtetra
.575 .432 .65 r
.33962 .28327 .34541 .31563 .35709 .31089 .35122 .27897 Mtetra
.577 .435 .652 r
.35122 .27897 .35709 .31089 .36884 .30555 .36286 .27457 Mtetra
.58 .441 .657 r
.36286 .27457 .36884 .30555 .38067 .29965 .37457 .27007 Mtetra
.584 .45 .664 r
.37457 .27007 .38067 .29965 .39255 .29321 .38632 .26547 Mtetra
.59 .462 .675 r
.38632 .26547 .39255 .29321 .40449 .28631 .39813 .26078 Mtetra
.597 .479 .689 r
.39813 .26078 .40449 .28631 .41647 .27904 .40999 .25598 Mtetra
.606 .5 .707 r
.40999 .25598 .41647 .27904 .42849 .27158 .42191 .25108 Mtetra
.617 .527 .729 r
.42191 .25108 .42849 .27158 .44053 .26408 .43387 .24608 Mtetra
.63 .558 .755 r
.43387 .24608 .44053 .26408 .4526 .25678 .44588 .24098 Mtetra
.642 .591 .781 r
.44588 .24098 .4526 .25678 .46469 .24998 .45795 .23578 Mtetra
.653 .619 .804 r
.45795 .23578 .46469 .24998 .4768 .24383 .47006 .23048 Mtetra
.66 .637 .816 r
.47006 .23048 .4768 .24383 .48895 .23854 .48222 .22507 Mtetra
.661 .637 .815 r
.48222 .22507 .48895 .23854 .50113 .23395 .49442 .21957 Mtetra
.658 .621 .801 r
.49442 .21957 .50113 .23395 .51336 .22989 .50668 .21396 Mtetra
.651 .596 .78 r
.50668 .21396 .51336 .22989 .52566 .226 .51898 .20825 Mtetra
.643 .571 .758 r
.51898 .20825 .52566 .226 .53801 .2218 .53132 .20244 Mtetra
.637 .551 .741 r
.53132 .20244 .53801 .2218 .55041 .21706 .54371 .19653 Mtetra
.633 .539 .73 r
.54371 .19653 .55041 .21706 .56286 .21142 .55614 .19051 Mtetra
.633 .536 .727 r
.55614 .19051 .56286 .21142 .57534 .20497 .56862 .1844 Mtetra
.636 .54 .73 r
.56862 .1844 .57534 .20497 .58785 .19775 .58114 .17818 Mtetra
.642 .553 .739 r
.58114 .17818 .58785 .19775 .60038 .19001 .5937 .17186 Mtetra
.651 .573 .754 r
.5937 .17186 .60038 .19001 .61293 .18201 .6063 .16543 Mtetra
.662 .597 .772 r
.6063 .16543 .61293 .18201 .6255 .1739 .61894 .15891 Mtetra
.673 .625 .793 r
.61894 .15891 .6255 .1739 .63811 .16588 .63162 .15228 Mtetra
.685 .653 .813 r
.63162 .15228 .63811 .16588 .65075 .15792 .64433 .14555 Mtetra
.695 .681 .832 r
.64433 .14555 .65075 .15792 .66343 .15006 .65709 .13872 Mtetra
.705 .707 .849 r
.65709 .13872 .66343 .15006 .67614 .14222 .66988 .13178 Mtetra
.714 .732 .865 r
.66988 .13178 .67614 .14222 .68888 .13437 .6827 .12475 Mtetra
.722 .756 .88 r
.6827 .12475 .68888 .13437 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Sooooo`03okS1hOl0003ooooo01Gooooo00?o
0000ooooooooool0DOooool0063ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`0Mooooo`?o00000_ooool00ol0003oooooooooo`1Oooooo`?o^<7Q00?o
0000okS1hOooool05Oooool00ol0003oooooooooo`1@ooooo`00H?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol0000Looooo`;o0000IOooool00onf^mgo^<7QokS1h@02okS1h@03o`000?nn
an7ooooo01Cooooo00?o0000ooooool00000DOooool0063ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0001[ooooo0ol0001Uooooo`Co][_M0onh`N400ol0003o_/OQ
okk7h@0Fooooo`03o`000?oooooooooo04oooooo001Pooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool0000Hooooo`;o0000I_ooool00ond]=Wo][_MokJkg@04okJkg@03
okS1hOnnan7o000000?o_/OQ5_ooool00ol0003oooooooooo`1>ooooo`00H?ooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oMgMgolc<c?l000005Oooool3o`0000;ooooo00?o0000oooooooo
ool0HOooool4okBdf@Co][_M00Co_/GPokk7hOnnan7o00000_nnan400oo1c>;oooooooooo`0Doooo
o`03o`000?oooooooooo04kooooo001Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^
k^koA4A4o`00000Cooooo`;o0000Ioooool00ona[]Co];CIokBdf@04okBdf@03okJkgOnnaN3o_/GP
00;o_/GP00?o_/OQo`000?nnan400oo1c>8Fooooo`03o`000?oooooooooo04gooooo001Pooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0?ooooo`?o0000Ioooool4ok6^
e0Co];CI00?o_L?Nokk5h?nnaN001?nnaN000ol0003o`LcRol7<hP03ol7<hQKooooo00?o0000oooo
ooooool0C?ooool008;ooooo0_l0001Xooooo`03ojnWd?na[]Co/JkD00?o/JkD0ond]=T3okg3gPCo
_/GP00?o`LkTo`000?o1c>800oo1c>800oo0c^Goooooooooo`0Dooooo`03o`000?oooooooooo04co
oooo001oooooo`?o00000_ooool00ol0003oooooooooo`1Tooooo`?o[jO@1Ona[]@00ond]=Wo_L?N
okg3gP03okg3gP07okk5h?o1c^Co`LkTol7>i?l0003o`LkTol7<hP04ol3>iACooooo0ol0001=oooo
o`00O?ooool3o`0006_ooooo1?n_Ym04ok6^e003okg1gOnm`mko_L?N00?o_L?N00?o`]3Uol7>i?o1
c^@00_o1c^@00ol0003o`MGYol3>i@04ol3>iAOooooo00?o0000ooooooooool0B_ooool007[ooooo
0_l0001/ooooo`03ojbObon_Ym3o[jO@00Co[jO@00?o/JkDokg1gOnm`Md00_nm`Md3okg3gP?o`]3U
0oo1c^@00oo1eNWo0000ol7Ej@03ol3>i@;o^m3Z5_ooool00ol0003oooooooooo`1:ooooo`00Mooo
ool3o`0006cooooo1?n/Wl/4ojnWd003okbmf_nm`Mgo_L7M00Co_L7M00?o_L?Nol;@iOo2d>D00oo2
d>D01_o1c^Co`MGYol7EjOl0003o`MGYol3>i@Go^m3Z5_ooool00ol0003oooooooooo`19ooooo`00
MOooool2o`0000;ooooo00?o0000ooooooooool0J?ooool00onYV<Go[9o;ojbOb`03ojbOb`?o[jO@
0onl_MX4okg1g@;oa=;U1?o2d>D01Oo2g>co`MGYol7EjOo1eNWo000000;o^m_`1?nkd>X00onbc^ko
ooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo001booooo`?o00001Oooool00ol0003ooooo
ooooo`1Uooooo`CoZIS51On/Wl/00on_Ym3o_;gJokbmfP03okbmfP03okg1gOo4d^Goa=;U00?oa=;U
00?o`]3Uol;Lk?o2g>`00_o2g>`00oo1eNWo^m_`o`000003ok_Kl003ok_@j_nbc^ko//k^00;o//k^
5_ooool00ol0003oooooooooo`18ooooo`00L?ooool2o`0006kooooo00?oYY;1ojVHaOnYV<D00onY
V<D4ojbOb`03ok^heonl_M[o_;gJ00?o_;gJ00?oa]CUolCBiOo4d^D00oo4d^D00oo4hnko`]c/ol;L
k002ol;Lk0;o^^Od00Go^m_`o`000?nkfo3o^m_`ojoImP06ok;>kQKooooo00?o0000ooooooooool0
Aoooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00023ooooo
0ol0001^ooooo`CoYY;11OnYV<D00on/Wl_o^kSGok^he`02ok^he`?o_;gJ0oo6e>D3olCBi@?oa>?^
00?o`]c/ok[Wm?njio@00onjio@00ol0003o[mWfojoImP02ojoImPCo//k^00?oYlSaooooooooool0
4oooool3o`0004Sooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A00Nooooo`;o00000oooool00ol0003oooooooooo`1Yooooo`03
ojB=_OnVT/7oYY;100?oYY;11?nYV<D00oni/];o^kSGok^he`04ok^he`03okbmf_o6e>Goa]CU00?o
a]CU00Coa=;UolCSk_o4hnkoa>?^0_nfl_@4ok[Wm003ojSTnol0003o[mWf00Co[mWf00?o//k^ojO8
lOnWb?400_nWb?4Fooooo`03o`000?oooooooooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo02Wooooo000hooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Looooo`?o0000Koooool4ojB=_@CoYY;10onYV<D3
okVbdPCo^kSG0_o7e><4olKDi@;oa^_^00?oa>?^okKbm?nfl_@00onfl_@01_njioCoZ>CkojSTnonX
i?_o0000ojSTn`;o[mWf0onPcoP5ojO8lAKooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02[ooooo000hooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Hooooo`?o0000L?ooool00onRR[[o
Y8fmojB=_@03ojB=_@GoYY;100?oZIS5okVbd_ni/]800_ni/]83ok^he`CoamCS00Coa]CUolK[k_o6
jnkoa^_^0on]n>/2okKbm0CoWNgg0_nXi?/00ol0003oUmSmoiOHo@05oj3?n0;oYlSa0onM`O4Foooo
o`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000:oooool0
03Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo01Gooooo0ol0001`
ooooo`CoXXZj1?nTSKd4ojJB`@03okN/c_ni/];o^K;B00Co^K;B00?o^kSGolODhoo7e><00_o7e><0
1?o9l>goa^_^olK[k_o6jnh3ojghj`?oR>cS0_nMkOL3ohWOo@03oiOHoOl0003oUmSm00;oUmSm0_nP
coP3oiC4m`GoWL7a5Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
2oooool01?m4A4CogMgMooooool0000/ooooo`00>?ooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool04Oooool3o`0000?ooooo00?o0000ooooooooool0Joooool00onRRK[o
XXZjoj::^P03oj::^PGoY8fm0_nVT/43okN/cPCo^K;B0_o9d^43olODh`?obO3]00?oa^_^ojghjon]
n>/00on8k><4og3Nk0CoRMom00?o0000oiOHoOn:b?`00_n:b?`5oiC4m`;oWL7a0_nG^_0Fooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0002cooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@017ooooo0_l0001booooo`CoXXVj1?nRR[X5ojB=_@03ojJB`Ong[<ko]jc>00;o]jc>0oni
/]84olWBh@04olODhoo9l>gobO3]olW`k@;oXOKI0_m_g;l3oe?>a@;oL=k/0omUc_X3ogc=o`03o`00
0?mlcOooR/Sl00?oR/Sl0_nDa?L2ohjhl`GoUk[`5_ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000/ooooo`00>?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00>ooooo`?o0000L_ooool6oj:9
^PGoXXZj0onTSKd00oncY/_o]jc>okN/cP04okN/cP03okVbd_o9d^7obM;Q00;obM;Q0oo=lnX01?o9
l>goXOKIofoL_om_g;l3ocg1`0CoD<_V1?mUc_X2ogc=o`03o`000?mj]_SoQ;Ke00CoQ;Ke1?n>^?<5
oiNjl1Cooooo0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00
000/ooooo`00FOooool3o`0007;ooooo2?nRRKX5oj::^P03ojB=_OncY/_o/jK;00;o/jK;1?ng[<h2
olO>g`?obM;Q0oo=lnX00onIl<Co0000o`000003ofWDn0CoI/Sm0omV_?d4ofben`04ogZfn?l0003o
N[KhogZfn0GoQ;Ke1?n>^?<2oiNjl0;oUKK^4oooool01?l0003oooooooooool00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0[ooooo`00E_ooool3o`0000?ooooo
00?o0000ooooooooool0K?ooool2oj>=_@[oXXVj0onRR[X00on_XLWo/jK;ok>Vb`03ok>Vb`?o]jc>
1?o7c]l01oo9d^7ocO?Zolgcj_o=ln[oVO34o`000?mhh^l00_mYe?P2ohJ[k@CoNj7[0omeVnT00omV
_?goK;Gkofben`02ofben`04o`000?mj]_SoN[KhogZfn0;oQ;Ke0_n6Z>/4ohf_k@GoUKK^5_ooool0
0ol0003oooooooooo`10ooooo`00E?ooool2o`0007;ooooo00?oY9;2oj>=_OnSSKd00onSSKd9oj:9
^P03oj::^_n_XLWo[j7900;o[j791OncY//00ong[<koalkOolO>g`02olO>g`?oc_CY00?ocO?ZoiW`
a?mhh^l00_nH^>h5ohJ[k@CoNj7[0omeVnT4ogJLj@04o`000?mnX^[oOZ;ZogjRjPGoQZS[1?n=[nd4
oiFfkQKooooo00?o0000ooooooooool0@?ooool0057ooooo0ol0001booooo`?oY9;21OnSSKd8oj:9
^P03oj^Nb_n_XLWo[j7900?o[j791?ncY//2olG9g@?oalkO0oo>m>T00on=j;;oY;k/ojBnk004oiRh
kPCoQZ_]1?mkXN/4ogFKj@?oMYcY00?o0000ogjRj_mnX^X00_mnX^X4ohJXj`CoSJo]0_nE]^h3oiVc
jQKooooo00?o0000ooooooooool0?oooool004kooooo1Ol0001aooooo`03ojJHaonTT/;oY9;200?o
Y9;21?nSSKd6oj:9^PCoZik:1On_XLT00oncY/_oaLWMolG9g@03olG9g@05olO>goo>m>Woc_CYolkd
jOn=j;801?nT_^`4oiRhkP;oQZ_]00?oRH?6oh>1b?n3PLP00_n3PLP3oh63c005ogFKjOmfW>WoMYcY
ogJLjOl000001?mnX^X2ohJXj`;oSIgN1OnBZ>D5oiVcjQKooooo00?o0000ooooooooool0?_ooool0
04cooooo0_l00005ooooo`03o`000?oooooooooo06cooooo1?nVV<L4ojBB`PGoXhfm0onRRKX00onX
W/goZik:oj^NbP03oj^NbPCo[j7900?o_lCNolG9gOo5bMd00oo5bMd3olgdjP03olkdjOn/_^Oo[;kW
00;oY;k/0_nLSL<4oi>8a0CoRH?61?n3PLP3oh63c0?oPHWB00?o0000ohNCf?n7TmP00_n7TmP5ohfM
gPGoTZSU0_nI/nX2oj6fiaKooooo00?o0000ooooooooool0?_ooool004Wooooo0ol0001dooooo`03
ojRNcOnVV<OoYYS700?oYYS71?nTT/85oj>=_@03oj:9^_nXW/goZ9k=00;oZ9k=1?n[W/X3ojnQb@?o
_lCN0oo5bMd3olgdjP04ohOSZOn/_^Oo[;kWojBA`@GoW8g31?nCR<@3ohV3aPCoPh781?n1Pl`3oh69
dP03o`000?n7TmSoQi?H00;oQi?H1On=WMh2oi:Xi@;oW:_Q1OnQ]^LDooooo`?o0000?oooool002;o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Pooooo`;o0000MOooool4ojRNc@CoYYS71OnTT/83oj>=
_@03ojBRdonXW/goZ9k=00?oZ9k=1On[W/X00on_XLWo_lCNoko4gP03oko4gP06olG9gOo=m>[ocOCZ
olgdj_n7hjWo[;kW1?nTTL44oib=``CoThS40on9PlH4oh>1b0CoPH?<0on1RM800ol0003oQi?HohNC
f003ohNCf0;oSIgN0_nHWmX5oib[h@GoXKKW5Oooool00ol0003oooooooooo`0mooooo`008_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01gooooo0ol00002ooooo`03o`000?oooooooooo073ooooo00?o
ZJ?@ojRNcOnXW/d00onXW/d5ojJHa`CoY9;200?oXhfmojBRdonTX]<00_nTX]<4ojRNc@CoZik:00?o
]l7Roko4g_noa=h00onoa=h3olKbkP03olgdj_nY]N7oYI6o00GoY9711?nLSL<4oi>8a0CoRH?61?n3
PLP4oh63c0;oPHWB00Co0000oh69d_n7TmSoQi?H0_nCU=85oiROfPGoW:_Q0_nQ]^L3ojVjiQGooooo
00?o0000ooooooooool0??ooool002;ooooo00Go410@oooooooooooooooooa0@400Kooooo`;o0000
M_ooool4ojVSd0CoZ9k=1OnVV<L2ojBB`P;oXj_M1OnTX]<5ojRNc@03oj^Nb_ng`N;o]l7R00;o]l7R
0onoa=h3olKbkP03ogCIXonUTKooYI6o00;oYI6o1?nTTL45oib=``CoThS40_n9PlH00on=N[WoRW^m
ohYk_@02ohYk_@CoRh730_n=R<X00ol0003oSHS:oi>DdP04oi>DdPCoV9oJ1?nLZn400onW/^3oZK[V
ojVjiP04ojVjiQGooooo00?o0000ooooooooool0>oooool002;ooooo00Go0000oooooooooooooooo
o`00000Hooooo`?o0000MOooool2ojRSd0GoZJ?@1OnXW/d2ojJHa`;oX[SY1OnSZmd4ojBRd`CoZ9k=
00?o[<3XokO1h_ng`N801?ng`N801Onoa=koa_;^olKbk_o6l^koM=VS00GoYI6o1OnTTL44oib=``;o
ThS40_nBNkL3ohej^@GoRW^m1?n;PL<01?n=R<[o0000ohf8b_n=R<X4oi>DdPGoV9oJ00?oW:_QojNb
h?nW/^000_nW/^04ojVjiP03ojnoi_oooooooooo01?ooooo00?o0000ooooooooool0>oooool002;o
oooo00Go0000ooooooooooooooooo`00000Fooooo`?o0000M?ooool00onWW/goZ:?@ojRSd003ojRS
d0GoZJ?@0_nXW/d2oj;8l`GoX[SY1?nSZmd5ojBRd`03ojRNcOn/`>So[<3X00;o[<3X1?ng`N83okG_
mP04olKbk_nSS;coXhbloj><_0CoYI6o1OnTTL42oib=``;oV7jf1?nBNkL4ohej^@CoRW^m1?n;PL<0
1?n=R<[o0000ohf8b_n=R<X5oi>DdP;oV9oJ0_nSYmT6ojNbh003ojVji_n__nKo[koV00;o[koV5Ooo
ool00ol0003oooooooooo`0jooooo`008_ooool01Ol@413ooooooooooooooooo410@01?ooooo0ol0
0002ooooo`03o`000?oooooooooo073ooooo1?nWW/d4ojRSd0CoZJ?@00?oY]Kioj;8lonRb?<00onR
b?<4oj:hj@GoXj_M0_nTX]<3oi_3l`Go[<3X00?o]l7RokG_m_nekoH00_nekoH00onPQkWoXhbloj><
_002oj><_0GoYI6o0_nTTL42oij2]0GoV7jf1?nBNkL3ohej^@CoRW^m1?n;PL<00on=R<[o0000ohf8
bP02ohf8bP;oTiCB0_nOW=45oj>Wf@CoYk;P00?o/;_Qojnoi_n__nH00on__nHFooooo`03o`000?oo
oooooooo03Wooooo000Rooooo`05ogMgMonHV9SooooooiRHV?mgMgL04?ooool3o`0007Kooooo00?o
Y9O7ojNNcOnWW/d00onWW/d5ojRSd003ojVSd?nVe_WoY]Ki00;oY]Ki1OnRb?<4oj:hj@;oXj_M0on7
bOd5oi_3l`;o[<3X1?nGio/00onekoKoX8Nioj27^@02oj27^@?oXhbl1?nUTKl00onRQ;CoWX:doij2
]002oij2]0GoV7jf1?nBNkL3ohej^@GoRW^m1?n;PL<01?l0003oSHS:oiZ@b?nJT<P5oinLd@GoXjOI
00?oYk;Pok2khOn`^n400_n`^n43ojnoiP;o/lGW5?ooool2o`0003_ooooo000Rooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03_ooool2o`0007Sooooo0onTUlL4ojNNc@CoZ:?@0_n/goT5ojKFn@;oX/Sc
1?m=bNL4ofO<o0CoQlWm0_nK`o<4oe_?l@;oUnOk0onLPKD4oj27^@CoXhbl00CoYI6ooj:4]?nRQ;Co
XXBd1OnNP[@4oiQn]PCoTW^g1?n=N[T4ohYk_@;oRh730_nGQ[l00ol0003oVY38oiZ@b002oiZ@b0Co
WicA1?nSYmT00on_]=co/;_Qok2kh@04ok2kh@03ojnoi_ncaNOo/lGW00;o/lGW5Oooool00ol0003o
ooooooooo`0hooooo`00<_ooool5o`0007Gooooo0_nQS/45ojBGa`CoYik=00?oZ:?@ojcOnOn/goT0
0on/goT2ojKFn@?oALO>0on[TK/01?nZTKcoYX>^ojJ3[_nVPjh3oj61/@03oad00?lJZ<co6ZS<00;o
6ZS<0_mKco400onCPKcoWGnboib1]@04oib1]@CoX8Ni0onSS;`00onSQ;?oXXBdoj:4]003oj:4]0Co
WX:d1OnHO[H4oi9k]`?oSGZi0_n:Nkd2oi=n^@?oUhJo0_l00004oiZ@b0GoWicA00?oXjOIojndg?n_
]=`00_n_]=`4ok2kh@03okO6iOncaNOo/lGW00;o/lGW00?o]<OXooooooooool05?ooool00ol0003o
ooooooooo`0gooooo`00<?ooool2o`0007Oooooo00?oWHJjoj6>`OnQS/400onQS/44ojBGa`?oYik=
1?nfhOD2ojcOn@;oD/g00onYTKd3oj^A^`03ojF2[_nVPjkoYX>^00;oYX>^1OnQPK43oiZ0]@03oj5o
[onMOk;oWGnb00;oWGnb1?nLPKD5oj27^@03oj><_?nSQ;?oXhBc00GoXXBd1?nNP[@5oiQn]PCoTW^g
0_n=N[T00onCN[CoTgjioi=n^@02oi=n^@?o000000?oUhJoo`000?nJT<P01?nJT<P2oinLd@;o[J_E
1_n_]=`00on`^n7o]lKUokO6i@02okO6i@03ok?5iondanSo]<OX00;o]<OX5Oooool00ol0003ooooo
ooooo`0gooooo`00;Oooool3o`0007Cooooo0_m@01<00om@00koWHJjoif6^P02oif6^PCoXHk11OnT
UlL00onWW/go]^7eokKQm@02okKQm@03og?Oa?nQT/CoXI;400GoZI6m00CoZi6kojF2[_nUPZkoYH:^
1?nVPjh5oj61/@04oiZ0]OnQOjooXGn_oj5o[`CoWGnb1OnLPKD3oj27^@03oj>3/_nSQ;?oXhBc00;o
XhBc1?nRQ;@5oij2]0?oV7jf00?oUgV_oiAh/OnDN;400_nDN;44oi=j]0?o000000?oTgjioiN6_onG
Q[l00_nGQ[l01Ol0003oVY38oiZ@b?nJT<SoZj7=00Go[J_E1?n_]=`00oniaNCo]lKUokO6i@02okO6
i@03okS;jOndanSo]<OX00Co]<OX5Oooool00ol0003oooooooooo`0fooooo`00;?ooool2o`0007?o
oooo00?oC@0Eoe004om@01<00_nKOk@5oif6^PCoXHk11?nTUlL3okgLk`03okKQmOnBTm7oTY?A00?o
XI;41?nYTKd00onOOk3oYH:^ojF2[P02ojF2[PCoYX>^1?nQPK400onTPJgoXGn_oj5o[`03oj5o[`?o
WGnb1OnLPKD01?nPQkWoXh>boj>3/_nSPk84oj>4/`GoXXBd1?nNP[@01?nHO[KoUgV_oiMi[onGNJl4
oiAh/@04oi=j]?l0003o0000o`0000CoTgji1OnGQ[l00ol0003oZj7=oj^Qc@02oj^Qc@Go[J_E00?o
[kCLokW5i?niaN@00_niaN@00onga^Go^<_YokS;j@02okS;j@Co]<OX0_nbanXEooooo`03o`000?oo
oooooooo03Gooooo000/ooooo`?o0000K_ooool2odH04@;oC@0E00?oV7Z`oi]o]?nKOk@00onKOk@4
oif6^PGoXHk100?oY9O7okgLkonmg>l00_nmg>l01?nBklgoTY?Aoi:CdOnBTm44oj6Ba004ojVA_OnO
Ok3oWgn`oimo/0CoYH:^1OnVPjh2oj61/@;oY86]1OnQOjl4oieo/P?oW86e00?oXH6`oj>3/_nSPk80
0onSPk83oj>4/`GoXXBd0_nNP[@2oial[`GoUgV_00CoU7Rao`000?l0003o00001?nCN[@4oi=n^@?o
UhJo00?oYiS6oj^QcOl000000on[XLd4ojf[e@;o_<CQ0oniaN@2okc@j@Go^<_Y00?o]<OXok;7j_nb
anX00onbanXDooooo`03o`000?oooooooooo03Gooooo000/ooooo`04o`000?oooooo0000o`0006[o
oooo00?o>`09odH04Om601400_m601400om=01GoV7Z`oiQj/005oi]o]0GoWHJj0onQS/43ol3Ai`04
okgLkonBklgoT^o=ohJJg`CoTY?A0_nQT/@00onDN[CoWgn`oimo/003oimo/0CoYH:^1?nVPjh00onQ
PK7oY86]ojB1[@02ojB1[@CoXGn_1?nMOk801?nLPKGoXH6`oj61/?nQPK05oj>3/PCoXhBc0onRQ;@0
0onOOZooW7b_oial[`02oial[`?oUgV_0ol00003oiAh/@CoTgZd1?nCO[T00onGQ[ooYiS6ojNHaP02
ojNHaP03o`000?n[XLgoZj7=00;oZj7=00?o[J_Eokc4hOnla>400onla>400oniaNCo_=3Yokc@j@02
okc@j@;o^<_Y0onec^`4ok;7jP03ojo7k?oooooooooo017ooooo00?o0000ooooool000002?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0
6Oooool002cooooo0_l00002ooooo`03o`000?oooooooooo06Kooooo0_lk00T2odH04@;oUgJ/1?nH
N[04oi]o]0GoWHJj00?oXHk1ol3Aioo0dNL00_o0dNL2ojkjf003o`000?mkLKcoNg6l00CoPg>i0onD
N[@5oimo/0CoYH:^0onVPjh00onXPjcoY86]ojB1[@03ojB1[@CoXGn_1?nMOk85oj61/0CoXh>b1?nS
Q;<01?nRQ;CoWgj_oimn[onOOZl4oial[`?o00000_nGNJl4oiAh/@GoTgZd0_nCO[T00onRS[ooYiS6
ojNHaP03ojNHaP05oj^QcOl0003oZj7=oj^QcOnn`M`01Onla>400oo1en[o_=3Yokc@j@02okc@j@03
okWGl?nec^co]Lk/00Co]Lk/00?o//OZojo7k?n_an`00_n_an`Eooooo`03o`000?oooooooooo00Go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So
8B4Q01Wooooo000[ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Hoooool01?l`
003o>`09oc/02OnELjT4oiMf[0CoV7Z`1OnKOk@3oif6^P;o_/CO0oo0dNL2ojkjf003ogYb__mkLKco
Ng6l00;oNg6l0on3LkT4oiAj]0CoWgn`1?nUPZh2ojJ3[P;oZ8>/1OnTPJd5oj5o[`;oWGnb00?oXX2_
oj61/?nQPK000onQPK04oj>3/PCoXhBc1OnOOZl01?nLO:oo0000o`000?nLO:l4oiMi[`GoU7Ra0onC
N[@00onOQk[oXXjooj:>_`02oj:>_`GoYiS600?oZj7=o`000?nn`M`00_nn`M`3okc4h@?o`MOZ00?o
_=3YokWGl?nieo000_nieo04okG>k003ok3>l?n_anco[lO/00?o[lO/5Oooool00ol0003ooooooooo
o`05ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001Wo
oooo000[ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H?ooool3oc0000?oUG>Y
1OnGMZ`3oiQj/0GoVgnd00?oWHJjokk4gonna=l00onna=l00oo0dNOo[_[Hojkjf002ogYb_PCoNg6l
1?n3LkT3oiAj]0CoWgn`1?nUPZh00onVPjkoZ8>/ojR3[002ojR3[0CoY86]1OnQOjl01?nMOk;oXX2_
oj:0[onRP:l4oj61/0GoXh>b0_nSQ;<2oj>1/0;oWgj_0ol00003oial[`GoUgV_1?nDN;400onCN[Co
WhNjoin7^P02oin7^P?oXXjo1?nWV<H00onm_=Wo_/7Lo`000004okk1g004okc4hOo1en[o`MOZol7G
jP;o_>Gc1Onieo000onec^co/<k`ok3>l002ok3>l0;o[lO/0onZa^hEooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B406Ooo
ool002_ooooo0ol00005ooooo`03o`000?oooooooooo05gooooo00Co8@00oc000?nDL:SoU72X1OnE
LjT4oiMf[0?oV7Z`1?nKOk@00onj^=Oo_/COokk4g`03okk4g`?o_ogP00CoPGNoogYb__mjL[koNW:n
0omkLK`4oh=c^@?oU7Zd1OnOOk02ojF2[P03ojF1[OnXPjcoZ8>/00?oZ8>/1OnTPJd3oj5o[`03ojF2
[_nRP:ooXX2_00;oXX2_1?nQPK05oj>3/P03oj>4/onSPK3oXh6`00?o00000_nOOZl4oial[`GoUgV_
0_nDN;42oib3]`GoWhNj0onRS[l3ojNHaP?o_KcI00Co_/7Lo`000?nn`Mco_/7L0_o7g^X00oo1en[o
_>GcokcUl`03okcUl`;o^MO`0on`eoD3ok3>l0;oZ<cb1OnZa^hEooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`06Oooool0
02_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Kooooo`03oi=_Y_nDL:SoU72X
00;oU72X1OnELjT4oiMf[0CoV7Z`0_nKOk@3okZhe`?o_/CO0onooN02oh=X[0?oNfF_1?mkLK`3oh=c
^@?oU7Zd1OnOOk000onUPZkoYH6]ojF1[@05ojR3[0GoY86]00CoXGn_ojF2[_nUPZkoYH:^1?nRP:l5
oj61/0?oXh>b00GoY8>`o`000?l0003o0000oj>1/004oimn[`GoW7b_0onGNJl00onLPKCoW8>goib3
]`03oib3]`CoWhNj1?nRS[l00onWV<Ko_KcIokflf@03okflf@03okk1g?l0003oamkZ00;oamkZ00?o
^_CbokcUlonliO<00_nliO<2ojcSnPGo/=Oe00?o/<k`ojS<l_nXc?800_nXc?82oj[6kP;oY<?_5Ooo
ool00ol0003oooooooooo`03ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7
ooooo`0Kooooo`00:oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Sooooo00?o
2000oi=_Y_nCKjH01OnDL:P4oiEcZ@CoUgJ/1?nHN[000onKOkCo^[SGokZhe`03okZhe`04okk4gono
oN3o_ogPokomh0?oPfR/0omkIJl3ogIT/@03og]a_?n3LkWoPg>i00;oPg>i0onDN[@3oimo/003oial
[onUPJgoYH6]00;oYH6]1?nXPj`4ojB1[@03ojR4[_nUPZkoYH:^00?oYH:^0onRP:l5oj61/004oj>3
/_l0003o0000o`0000GoXh6`1?nOOZl4oial[`04oiMi[onLPKCoW86doib1]0GoW8>g1OnOQkX2oj:>
_`03okVde?nm_=Wo_KcI00?o_KcI0_o:iN/00oo7g^[o0000olONjP03ok[dlP03okcUlon/ho[o[>?j
00?o[>?j0_n`eoD2ojGBm`CoZ<cb00?oXLOcojC3konT`nl00onT`nlCooooo`?o00001?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P06oooool0013ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`1Eooooo`;oTfjV1?nCKjH4oiA`Z0CoUG>Y1OnGMZ`2
oiQj/0;o]Jc@1Onj^=L2olSli@;oRf^X1?n3J:`2og]U[`CoMVBa0omjJ;801On3LkWoU7ZdoiAj]?nD
N[CoWgn`00?oW7b_1?nUPJd5ojR3[0;oY86]0_nXQ:h5ojF2[PCoXX2_0_nQPK03o`0000CoY8>`1?nS
PK04oimn[`;oW7b_0_nNPK<5oib1]0CoW8>g1OnOQkX01?nRS[oo^KCDokVde?ni]=@3okflf@Cob^G[
00?o0000ok[dl_njm?801?nMk_L2ojcSnP;oWMSl1OnUd_L00onXc?;oXLOcoj77l`02oj77l`GoY<?_
5Oooool02Ol0003oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co
0000oa0@41Wooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o
0000ooooooooool01?ooool3o`0000[ooooo00?o0000ooooooooool0D?ooool2oi9^YPCoTfjV1?nC
KjH4oiA`Z0CoUG>Y1OnGMZ`00onHN[3o]Jc@okF/d002okF/d0?o^[SG0_o8o>D3oh][Z0CoPfR/0omk
IJl3ogIT/@CoNVRb0on>M;45oial[`?oYH6]1OnXPj`00onTPJgoZ8B^ojR4[P02ojR4[PCoYH:^0onR
P:l3o`0000;oY8Ba1OnTPk04oj>1/0?oWgj_00?oXH>doij1/onNPK<00_nNPK<5oib1]0GoW8>g0onO
QkX00ond[=3o^KCDokVde003okVde003okflfOo:iN_ob^G[00;ob^G[00CoY?OMogCReol0003oM>;G
0_nMk_L3ohkMoPCoWMSl0_nUd_L3oic:m`GoXLOc0_nT`nl2oinol1Gooooo00?o0000ooooooooool0
;oooool000Sooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`1<ooooo`GoTVjV1OnCKZH3oi=_YPCoU72X
1OnELjT3oiMf[003ok2Sbone[=3o]Jc@00Co]Jc@00Co^[SGolSliOo8o>GoSV^V0on;JjP4oh=X[0?o
NfF_1?mfI;43ogYX/P?oSWBa1OnLO:l3ojF1[@CoZ8>/00?oZhN_ojR4[_nXQ:h00onXQ:h5ojF2[P;o
000000?oYXJbojB4/OnTQ;400onTQ;44ojB3/0GoXh6`00?oWgj_oj63]?nQPk@01OnNPK<4oib1]0Go
W8>g00?oWhNjokB/d?nd[=000_nd[=03okVde0?obn_/00?ob^G[ojCggOnTmmd00_mdh]L01?mdf_So
0000ogCJn?mdf_P2ohkMoP;oR/_m1OnEc?/4oic:m`;oXLOc0_nL`O85oinol1Gooooo00?o0000oooo
ooooool0;_ooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgooooo
o`0000Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1:ooooo`OoTVjV1?nCKZH3
oi=_YPCoU72X1OnELjT00onGMZco/:?;ok2Sb`02ok2Sb`Co]Jc@0_o;n>T3ohi[YP?oRf^X1?n3J:`3
og]U[`CoMVBa1?mjJ;83ohid/@CoW7b_1?nUPJd2ojR3[0;oZhN_1OnXQ:h2ojF2[P?o000000?oXX2_
ojJ6/_nVQ[801OnTQ;45ojB3/0?oXh6`00?oXhNeoj63]?nQPk@00_nQPk@4oij1/`GoW86d0onLPkL0
0on^Y<go]:c@okB/d003okB/d003okVde?o;jncobn_/00;obn_/0_m[dj84odo<i004ogCJn?l0003o
P<Onoh37oPGoR/_m0_nEc?/2oiBnm0CoV<7d1OnL`O82oinol0?oW;[]5Oooool00ol0003ooooooooo
o`0]ooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo0000
1_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04Kooooo0_nBL:P8oi9^YPCoTfjV
0onCKjH5oiA`Z0?oUG>Y00?o[9c7ok2Sbon`Xl/00on`Xl/3okF/d0;oboSY1?n>JjH3oh][Z0CoPfR/
0omkIJl4ogIT/@CoNVRb0on>M;44oial[`CoYH6]00?oZ8>/oj^7[on[Qjl00_n[Qjl3ojR4[P?o0000
0_nUPZh00onYRK?oYXJbojJ6/P02ojJ6/PCoY8Ba1OnTPk001?nSPK3oXhNeoj>7]OnSQkD4oj63]0Co
WX6c1OnLPK@00onLPkOo[ZC=ojjTc@02ojjTc@Co]:c@00Goano^ol_[k?o;jncobn_/of_CXP03ogBl
o0CoMl;n00CoP<Ono`000?n0aokoP<On0_n:bod3oi2hlPCoU;kd1?nH`O@2oic1lP?oV[O/1OnL^^dD
ooooo`03o`000?oooooooooo02gooooo000@ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0omgMgOoc<c<o`000006ooooo`;o00003oooool2o`0004;ooooo0_nCLJX4oi9`Z0SoTVjV1?nCKZH4
oi=_YPCoU72X00?oUG>YojbLaon/W<L00_n/W<L5ok2Sb`04okF/d?o;n>WoboSYoi1/YPGoSV^V0on;
JjP4oh=X[0?oNfF_0omfI;44ogYX/P?oSWBa1OnLO:l2ojF1[@03ojN5/On[QjooZhN_00?oZhN_0ol0
0002ojR4[P;oYH:^0_nYRK<4ojJ6/PGoY8Ba0onTPk000onVR[SoXhNeoj>7]@03oj>7]@?oXH>d1OnN
PK<3oib1]003oj^MbOn^Y<go[ZC=00?o[ZC=0ond[=03olO_kP03ol_[k?mf]?WoM[Ci00CoM;cl0_mg
`_h01?n>Y>CoSZo]ohj_kOl00002ohj_k@GoT;Sb1?nD__@2oiS1m0;oVKCZ1OnJ]n`2oibjk@;oWKKZ
5Oooool00ol0003oooooooooo`0/ooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?ok^k^odA4A?l000001_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03cooooo
00?oU7B/oi=aZ_nCLJX00_nCLJX4oi9`Z0SoTVjV1?nCKZH4oi=_YP?oU72X00?oYiK4ojbLaon/W<L0
0on/W<L4ok2Sb`;obO;/00Co0000oi1/Y_n@K:KoT6bV1?n>JjH3oh][Z0CoPfR/0omkIJl4ogIT/@?o
NVRb0on>M;45oial[`03ojF1[OnWQK7oYhFa00;oZhN_0ol00005ojR4[P03ojF2[_nYRK?oZHVc00;o
ZHVc0onVQ[85ojB4/@04ojB3/?nVR[SoYXZhojJ:^0GoXhNe0onQPk@5oij1/`03oib1]?n[WLWoZig9
00;oZig91On^Y<d01?nd[=3oano^olO_k_o7knh4oi6>c@CoSiWI1?n>Y>@2ohj_k@03o`000?n>[ngo
SZo]00;oT;Sb0_nHYn04oiV_iPGoVKCZ0_nJ]n`2oif`i@GoWKKZ4oooool2o`0002kooooo000@oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0>?ooool01?nEN;3oU7B/oiAd[?nDM:`5oi=aZP?oTW2X2?nB
KZH5oi=^YP?oTfnV00?oU72XojNFa?nWU/@00_nWU/@4ojbLa`?o/:?;0_o9l^`2oiA_Y@?oT6bV1?n>
JjH2oh][Z003oi5/Y?n;JZOoRfZW00;oRfZW0on2Ij`3ogUU/003ogIT/OmjJ;;oNVRb00;oNVRb0on>
M;43oial[`03oif0/onWQK7oYhFa00?o00000on[Qjl4ojR4[P03ojb>]_nYRK?oZHVc00?oZHVc1?nV
Q[83ojB4/@03ojR>^_nVR[SoYXZh00?oYXZh1?nSQkD4oj63]0?oWX6c00?oZ9[7oj^MbOn[WLT00on[
WLT4ojjTc@;o`?;a00Coano^oi:5`_nBQL;oTXG21?nAS/d4ohnIf@CoSZCT00CoSZo]o`000?nIWmWo
VIoI1OnHYn04oiV_iP;oVKCZ0_nMZ]l5oif`i@CoWKKZ5Oooool00ol0003oooooooooo`0[ooooo`00
:Oooool2o`0001Cooooo00?o0000ooooooooool0=Oooool3oiEh/0CoU7B/1?nCLJX3oi9`Z0WoTVjV
1?nCKZH2oi=_YP03ojBB`_nWU/CoYiK400?oYiK41On/W<L00on`Xl_obO;/olWbk003oiA_Y@?oT6bV
0_n>JjH2oi9ZXP?oTFbT1?n;JZL3oh9W[0CoNFF`0omhIk<01OmjJ;;oSWBaohid/On>M;7oW7b_00;o
WH2c0ol00002ojN5/@GoZhN_0_nXQ:h2ojb>]PGoZHVc1?nVQ[801?nTQ;7oZ8jjojR>^_nXS[X5ojJ:
^0GoXhNe0onQPk@00onNPK?oZ9[7ojRJa`02ojRJa`GoZig900Go[ZC=ol3blOo0l_7o`?;aoiAn^004
oi:5`PGoTHk=0on?VMT2ohjTi0;oVYO@0_nIWmT00ol0003oVIoIoiVOf@04oiRWh0;oVJoV0_nNY=T5
oifZg`GoWK3U0_nM]^X2oj>hj1Gooooo00?o0000ooooooooool0:_ooool002Wooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0booooo`03oiIm]OnEN;3oUGR`00?oUGR`0onDM:`4oi=a
ZPCoTW2X2?nBKZH4oi=^YP04oi=_Y_nTT/;oY9;2ojBB`PCoYiK41?n/W<L2olG]k`03o`000?nDKjGo
U6nU00;oU6nU0_n@K:H00onAJJ7oTVZRoi9ZXP02oi9ZXPCoTFbT1?n;JZL3oh9W[0?oNFF`1?mhIk<3
ohaf]@03oif0/ol0003o000000;oWH2c0onWQK45oj^7[`03ojR4[_n/S[Ko[8jf00;o[8jf1?nYRK<4
ojJ6/PGoZ8jj1?nVR[P5oj>7]@;oXH>d00?oYiW7ojRJaonXV/L00onXV/L4oj^Mb@?o]_Cc00?o`?;a
oiAn^?nDO[P01?nBQL84oi6>c@04oif:_onLT<OoW937oib@a`GoVYO@0_nIWmT00ol0003oVIoIoiVO
f@02oiRWh003oinNd_nNY=WoWZCI00?oWZCI1OnMZ]l2oif`i@;oY;;S1OnS^>PDooooo`03o`000?oo
oooooooo02[ooooo000Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;Oooool2
oiR3^`?oUWfe1OnEN;03oiAd[0CoTg6Z1?nBL:P8oi9^YP;oTfjV0_nPSl84ojBB`PGoYiK400Co[9c7
olG]koo5kNooaNg_0_nILjH2oiA_Y@;oTVZQ0onAJJ44oi9ZXPCoTFbT1?n;JZL3oh9W[0CoNFF`0omh
Ik<01?n<M[Go0000o`000?l00004oif0/`CoYhFa0on[Qjl00on`TkWo[8jfojb>]P03ojb>]PGoZHVc
0_nVQ[82oj^C_PCoZ8jj1OnVR[P3oj>7]@03ojRLbOnWVLOoYiW700;oYiW71OnXV/L00on[WLWo]_Cc
okKdl`02okKdl`04oiIi/OnDO[SoU7jhoiAn^0GoTXG200CoTHk=oif:_onMR[ooWHZo1?nLT<L5oiZG
d0;oVIoI00?o0000oj6Ic?nOW]800onOW]85oijTf@;oWJ[O0_nU[Md5ojBbh`;oXkSX0onY_>LDoooo
o`03o`000?oooooooooo02Wooooo000Yooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0:Oooool00onIR/;oV8>koiR3^`02oiR3^`CoUWfe1?nEN;03oiAd[0CoTg6Z1?nBL:P7oi9^YP03
oif=`onPSl;oX8o200?oX8o20onTT/84ojNFa0?o_^Sb00CoaNg_oiUcY_nILjKoU6bR1?nBJZ43oi5Y
X@GoTVZR0onAK:@4oh]ZY`?oPVN/1?miIK001?mhIk?o0000o`000?l00003ohaf]@CoWH2c1?nWQK40
0on[Qjoo/9>iok2C^@02ok2C^@Co[8jf1OnYRK<01?nVQ[;oZi>noj^C__n[Tkh4ojR>^PGoYXZh00Co
XhNeojRLbOnXW<WoZ9c91?nWVLL4ojRJa`?oY_?b00Co]_CcoiIi/OnFNK7oUWVa1?nDO[P2oi:5`P;o
WhJh1OnMR[l3oib@a`CoVYO@00GoXiC5oj6Ic?nQVLco0000oj6Ic005oinNdP;oWZCI0_nVZMP5ojF]
g@?oY;;S00?oZ[SSojVlionY_>L01?nY_>LDooooo`03o`000?oooooooooo02Sooooo000Yooooo`?o
00005oooool00ol0003oooooooooo`0Tooooo`;oVi;:1?nIR/84oiR3^`?oUWfe1?nEN;03oiAd[0Go
Tg6Z0onBL:P5oi9^YPCoWHg31?nPSl84ojBB`P03ojNFa?nnj?;o_^Sb00;o_^Sb0_nLMZP00onILjKo
U6bRoiA/XP04oi9ZX@CoTFVQ1?nBJZ83oi5/Y0CoRfZW0on2Ij`2ogUU/0?o00000omhIk<3ohaf]@Go
WH2c0_nWQK400on/UKoo/9>iok2C^@03ok2C^@Go[8jf0onYRK<00on_Vl?oZi>noj^C_P02oj^C_PGo
Z8jj0onVR[P00onZX/koZ9c9ojRLb@03ojRLb@CoYiW700?oZ9[7ojKcl_nVlo800_nVlo800onHMJ_o
UWVaoiIi/@02oiIi/@?oU7jh00?oXH>coin6^?nOQ[P00onOQ[P4oif:_`CoW93700?oVYO@oj>DaOnS
U<D00_nSU<D2oj6Ic003o`000?nQVLcoWikB00;oWikB00?oZJGCojJYf?nVZMP00onVZMP4ojF]g@03
ojBbhonZ^>?oZ[SS00;oZ[SS1?nY_>L00on^`^Soooooooooo`0Aooooo`;o0000:_ooool002Wooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Pooooo`03oibId?nKT/[oVi;:00?oVi;:
0onIR/84oiR3^`?oUWfe1?nEN;04oiAd[0CoTg6Z0onBL:P2oi9^YP;oVXg41OnMSL<4oj2?`P?oY9;2
1?nfi?H01?nnj?;oW7JXoiE^Y?nEKZ@3oiA/XPCoTVZQ1?nAJJ44oi9ZXP?oTFbT1On;JZL01?n2Ijco
0000o`000?l00003ogUU/0?oN6Nc0on<M[D5oif0/`04ojN5/On/UKoo[9FoojbE_`Co/9>i1On/S[H0
0onYRK?o[i_3ojnK``02ojnK``CoZi>n1?nXS[X00onVR[SoZZ;>ojZRcP02ojZRcPCoZ9c90onWVLL3
ohg]j@04ojKcl_nHMJ_oV7F[oiQeZ`CoUWVa00?oU7jhoj63/onQPk<00_nQPk<4oin6^0CoWHZo0_nL
T<L2ojFA`0GoXiC50onQVL`00ol0003oWikBojVUd`03ojVUd`GoYZWH0_nU[Md2ojbfh0GoZ[SS00?o
ZKcWojk2j?n^`^P00_n^`^PDooooo`03o`000?oooooooooo02Oooooo000>ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00005ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06oooool2oibMe0CoW9W@1?nKT/X3oiV:`PCoV8>k0onFOKD5oiEh/0?oU7B/1?nC
LJX2oi9`Z003oiN>aonJSLCoVXg400?oVXg41?nMSL<5oj2?`P03ojBB`_nfi?Ko]^Cf00;o]^Cf00?o
V7:WoiE^Y?nEKZ@00_nEKZ@4oiA/XP?oTVZQ1?nAJJ44oi9ZXPCoTFbT0_n;JZL3o`0000;oPVN/1?mi
IK03ogQW/`CoS7Je0onMP;<00onQTL?o[9FoojbE_`02ojbE_`Go/9>i0on/S[H00onbY<[o[i_3ojnK
``03ojnK``CoZi>n0_nXS[X2ojf/ePGoZZ;>1?nXW<T01?nWVLOoSNgYohg]jOn=kNT2oiUcYPGoV7F[
0_nFNK400onSPJooXH>coj63/`03oj63/`CoWhJh0onMR[l00onXSkcoYI70ojFA`003ojFA`0CoXiC5
0onQVL`00ol0003oZJGCojVUd`03ojVUd`CoYZWH00?o[[CMojbfh?n/]^000on/]^02ojZhh`;o/<;W
1On^`^PEooooo`03o`000?oooooooooo02Kooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool05oooool00onKW=CoW9gDoibMe003oibMe0?oW9W@1?nKT/X4oiV:`PCo
V8>k0onFOKD4oiEh/0?oU7B/0_nCLJX2oiB@c0CoUhk71?nJSL@5oif=``?oX8o20_n/h?T3okKTmP;o
V7:W1?nEKZ@4oiA/XP?oTVZQ1?nAJJ44oi9ZXP?oTFbT0ol000000on;JZOoUW>Xohmb[`02ohmb[`Co
PG2g0omhL/04ohaf]@03oif0/onQTL?oXI7300;oXI730on/UKl5ok2C^@03ojb>]_nbY<[o/ZC:00;o
/ZC:1?n_Vl<3oj^C_P03ok2kh_n][=Ko[JcF00?o[JcF1OnZX/h2ojRLb@;oH]S=0_nKLZ<3oiUcYPGo
V7F[00?oUWVaoj>1[onSPJl01OnQPk<5oin6^004oif:_onXSkcoZ8nlojR?_0CoYI701OnSU<D01?nQ
VLcoZj??oj^Scol00005ojVUd`03ojJYf?n^]=go[[CM00;o[[CM0on/]^000ona`nOo/<;Wok32i`03
ok32i`;o[/;X0on`a^/Dooooo`03o`000?oooooooooo02Kooooo0006ooooo`Ko00000_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool2o`0001gooooo00?o0000
ooooooooool04_ooool2oiZHd0CoVicD1?nLWM@3oibId0GoVi;:0onIR/84oiR3^`?oUWfe0_nEN;02
ohfJg0?oTICC1OnDT<`4oiN>a`?oVXg41OnMSL<00onPSl;o[>3iojcPn@03ojcPn@04okKTm_nHLZOo
V7:WoiQbY`CoUFjT1?nDK:84oi9ZX@?oTFVQ1OnBJZ82o`000003oi5/Y?n;JZOoUW>X00;oUW>X0on?
LZl5oh5`]`;oN7;01?n=Q<D5oj6A``Co[9Fo0on`TkT00onf/]Co/ZC:ok:TbP03ok:TbPGo[i_300Co
Zi>nok2kh_n`^n;o/;_R1?n][=H4ojZRcP03o`000?nLLJ7oW76Q00CoVg:S1?nILjH3oiQeZ`03ojF0
[?nSPJooXh6_00;oXh6_1OnQPk<3oin6^003ojZ?^OnXSkcoZ8nl00;oZ8nl1OnUTL02oj>Da@;o[Z?<
1?n[Xll00ol0003oZJGCojVUd`02ok6ef`Go[[CM00?o[;KPok73iona`nL00_na`nL3ok32i`;o/L_]
1On`a^/Dooooo`03o`000?oooooooooo02Gooooo000>ooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
3_ooool00onHTL_oVYS@oiZHd003oiZHd0?oVicD1OnLWM@3oibId0;oVi;:0oma`_h3ogNin`?oP:kb
0on7XnH5ohfJg0?oTICC1?nDT<`4oiN>a`CoVXg40_nMSL<4oioMo0;o[>3i1?nQNjX3oiQbY`?oUFjT
1?nDK:84oi9ZX@CoTFVQ00CoTVZRo`000?l0003o00000_nAK:@00onJLZCoUW>XoiIcZ003oiIcZ0?o
Sg:_1?n1L;L3ogQb`0CoSHC51?nQTL<4ojbE_`03ok2C^Onf/]Co][;D00;o][;D1?nbY<X4ojnK``03
ok7@l?n`^n;o/;_R00;o/;_R1On][=H00onZX/koW76QoiaaX@03oiaaX@CoVg:S1?nILjH01?nHMJ_o
YH2/ojF0[?nUP:`4oj>1[`GoXH>c00?oWhJhojZ?^OnZSkT00_nZSkT3ojR?_0CoYI7000?o/ZC:ojjS
c?n^Xl`00on^Xl`3oj^Sc`03okFig?l0003o/KGK00?o/KGK0on^]=d2ok?6j0Go/L?W00?o/<;Wok7;
kOnabnd00_nabnd2ok36j`;o[LK]5Oooool00ol0003oooooooooo`0Tooooo`003_ooool01Ol0003o
oooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`0Noooo
o`;o00002oooool00onFR/CoV97;oiRAb`02oiRAb`CoVYS@1?nKW=@2oibMe0?oP]7o1Omebol3og72
oP?oMkWk0on0[_83ohNSiPCoSI[L0onAU=<4oiB@c0GoUhk70_nJSL@4ohkIo`;oWmgl0_n^R:d5oj5k
ZP?oV7:W1?nEKZ@3oiA/XPCoTVZQ0_nAJJ43o`0000?oTVZR00?oTFbToiYbY?nJLZ@01OnFLjP3ohmb
[`CoPG2g0omhL/04ohf4a@GoXI730_n/UKl00onb_>7o][;DokJbe003okJbe0Go/ZC:00?o[i_3ok7@
l?nad?000_nad?04ok2khP;o[JcF1?nLL9l4oiaaX@GoVg:S0onILjH5ojF0[0?oXh6_1?nQPk<00on^
TKSoZXniojZ?^@03ojZ?^@CoZ8nl00?oYI70ok:Tb_nbY<X00_nbY<X4ojjSc005oj^Scone^Mco]KWL
okFig?l000001Ona]M/00on^]=go/lKXok?6j002ok?6j0;o/L?W0_nad?04ok7;k@;o[<_`1?n]a^dC
ooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ
8B7o0000ob4Q8Oo<c<`02Oooool000kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00?ooooo0_l0000Qooooo`03o`000?oooooooooo00Cooooo0_nEQKl4oiJ:a0CoV97;
1?nJV=02oi^Le0CoUm;l0on2dOl2ogG;o`;ocm3J00?o/J77ojRC`?nXTl000_nXTl000onMQ[[oMkWk
oh2^lP02oh2^lP?oQj?V1?n=V]`3oi6Dd`CoU93<0_nGS/L4ogSBoP;oS]Wo0onaRZd2ojj8[@03ojV4
[OnQNj[oXG^Z00?oXG^Z0onHLZL4oiE^Y0?oU6bR0onBJZ43o`0000;oTFVQ0_nBJZ82oiQ_XPCoVW:T
1?nFLjP3ohmb[`GoPG2g0_mhL/04ohf4a@GoXI7300Co[9Fook:lhOnb_>7o/[cQ1Onf/]@2ok:TbPCo
XnKk0onad?02ok2khP;oVgFW0_nML9l4oia`W`CoW76Q1OnKLZ<2oiUcYP03ojN1ZonUP:coYH2/00?o
YH2/1?nSPJl2oj63/`?o[Y6h1?nZSkT4ojR?_0Go/ZC:0on^Xl`00onj`=oo]KWLokFig003okFig003
o`000?na]M_o/KGK00;o]Lc[1?nca^P2ok3Hm@Co/M3`00?o/L_]ojc;l?n/bo000on/bo02ojg6k@;o
Z<C^5?ooool00ol0003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@09ooooo`003_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`;o00008oooool01?nCP;coTh6loi>1
_?nCPK`5oiF5_`?oUX[41OnHTL/2oiZHd0?oY<Wc0_nGd_`3ofCJe`04ohGS[Oo=i>SocNCXolo@fPCo
/J770onXTl04oif6^P?oTGZf0on6L;<01?lD003o3Yg<o`jMc?l>WL`4ocFfi`?oF/Sh0_mhd_h2ojj8
[@Go/HZ]00Co[XR]ojV4[OnYQ:goZHB]1?nQNjX3oiQbY`CoUFjT0onDK:83o`000005oi9ZXOnAJJ7o
TFVQoi5YXOnDK:801?nHKj84oiYbY0CoUW>X1?n?LZl4oh5`]`?oN7;01?n=Q<D2oj6A``?oY;g[1?nb
_>42okJbe0CoK]oR0_nSi_/3oiabXPCoW7>T00CoVgFWoie`WonML9ooWG2O1?nLL9l4oiaaX@GoVg:S
00CoVG>VojN1ZonWPJ_oYh6[1?nUP:`4oj>1[`03oj63/on^TKSo[Y6h00;o[Y6h1OnZSkT2ojR?_0;o
]ZS;1OnbY<X01?n^Xlco^/3Ook[0gonj`=l4okFig003okKEl?l0003o]Lc[00?o]Lc[00?o/lKXok3H
mOn`f?D00on`f?D2ok7@l0;oZm7d1?n/bo000onWb?7oZ<C^ojS4kP03ojS4kQCooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00
0009ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c004ooooo`03o`000?oooooooooo01kooooo0_nCPKd4oi>0_0?oTh6l1?nEQKl3oiJ:a0CoV97;
0_nZ^nH3ojC9l`?oX?7c00?oR>[6ohGS[On2ehh00_o=i>P00on`[=?o/J77ok6Qa`03ok6Qa`CoZ9?0
0onMQ[X3oi5j]PCoQW2c0on8L;43oi5e/004oiin/?nRP:koXX2^oj:0[PCo[XR]1?naRZd00on`Rjko
ZHB]ojV4[@02ojV4[@CoXG^Z0onHLZL4oiE^Y0?o000000GoU6bRoi9ZXOnBJZ7oTVZQoi5YX@03oiA/
XPCoV6nR1?nJLZ@4oiIcZ0CoSg:_0_n1L;L2oiBCd0?oNYKR1On<[^d5ojBmj`;o/[cQ0_l00003oiY`
X@?oW76Q1OnLLZ83oiacY0GoWG2O0onLL9l5oiaaX@?oVg:S00?oZX>[ojN1ZonWPJ/00_nWPJ/4ojF0
[0CoXh6_1On^TKP5ojZ?^@04ojR?_?nfZ<_o]ZS;okJXb`Co/ZC:00?o_/kVok[0gonj`=l00onj`=l0
0one^Mco]]G`okKEl002okKEl003o`000?nec>_o]Lc[00?oZn7j0_n`f?D2ojKGn@GoZm7d00?o[<_`
ojO8lOnWb?400_nWb?43ojS4kP03ojC0kOoooooooooo01;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P09ooooo`009ooo
ool00ol0003oooooooooo`0Kooooo`03oi>3`?nCPKgoTh6m00?oTh6m0onCP;`3oi>1_0CoUHFo1?nF
R/@00onHTL_oZ[_VojZkiP03ojZkiP08ojC9lonPlO?oX?7coj3alonjoMoo[OJoohOJT?n^]]l4ok2/
d`Co/J771?nXTl02oif6^P04ohmf/on8Kk7oR6naohQ_/@?oPFZ_00CoQW2cohQ`/On8L;7oR72a0_nA
MK000onCMZooXX2^oj:0[P03oj:0[PCo[XR]0_naRZd2ok2;[PCoZHB]1OnQNjX3oiQbY`?o00001?nD
K:82oi9ZX@03oi=[X_nDK:;oU6bR00;oU6bR1?nHKj84oiYbY0GoUW>X0_n?LZl00onWTKkoU9?@oiBC
d003oiBCd0?oNYKR1On<[^d2ojBmj`04oi5YXOnGKJ7oUffQoiM]X@GoVW2Q0onLLJ45oiabXP;oW7>T
00?oWW6Noie`WonML9l00onML9l3oia`W`GoW76Q0_nKLZ<2ojZ3Z`CoYh6[1OnUP:`2oj>1[`;o/YJi
1On^TKP3ojZ?^@03ok^`confZ<_o]ZS;00?o]ZS;00?o/ZC:okk>i_nnc^H00_nnc^H3ok[0g`;o/n?g
1?nfeO000ol0003oZn7joj_QnP02oj_QnP03oigLoOnVeoWoY]Oi00?oY]Oi0_n[dO@2ojC;m0GoYlSa
00?oZ<C^ojC0kOnT`>d00_nT`>dDooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`02Oooool002Oooooo0_l0000Eooooo`;o
Thg:0onCR<@4oi>3`0CoTh6m0onCP;`3oi>1_0GoUHFo0_nFR/@2ojV]fPCoZ[_V0onkj_@2ok[mg`03
ojgf_on7fY3o[[KO00;o[[KO0on`[=<5ok6Qa`;oZ9?000CoUgjfohmf/on?M[?oSgJc0on8Kk44oh5Z
[`?oQfj_0onCMZl5oj:0[PCo[XR]00?o/HZ]ok2;[_n`Rjh00_n`Rjh3ojV4[@GoXG^Z00?oV7:Wo`00
0?l000000onEKZ@2oiA/XP;oTV^S0onCJj85oiA/XP?oV6nR1?nJLZ@5oiIcZ004ohmb[onWTKkoYi6n
ojNA_PGoU9?@0omjU^82ohb^k@03ohYSX?nAJJ7oTFVQ00;oTFVQ1?nGKJ44oiY`X@?oW76Q1OnLLZ80
0onLLjCoWW6NoiiaWP05oie`W`?oW72O1OnLLJ400onKLZ?oZX>[ojZ3Z`02ojZ3Z`?oYh6[1OnUP:`0
1?nSPJoo/YJiok:F^OnbU[T5ojjA^004ojZ?^Onk/<oo^k3?ok^`c`Co]ZS;0_o0i?05okk>iP03ok[0
gonchoOo/n?g00;o/n?g00Ko]]G`oigYnonMjO_oWNWko`000?n[hOX4oigLo@;oY]Oi0onPcOL4ojC;
m0;oYlSa0onS`Nl4ojC0kAGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4009ooooo`009oooool00ol0003oooooooooo`0A
ooooo`03oi>DdOnCSL[oThg:00?oThg:0onCR<@3oi>3`0CoTh6m1?nCP;`3oi>1_0;oUHFo0_nUX]<5
ojV]fP03ojZki_nkj_Co^n[d00;o^n[d0_njoMl00oninlKoQmZ@ojjfg`03ojjfg`Co/:cC0_naXLL2
oi^4^P?oUgjf1?n?M[<3ohQ_/@?oPFZ_0on7KZl4oi=f[`CoXX2^1?n^R:d5ok2;[PCoZHB]0_nQNjX3
o`0000;oV7:W0_nEKZ@00on?JjGoTV^Soi9[X`02oi9[X`?oTf^R1OnDK:84oiQ_XPCoVW:T0onFLjP0
0on/SKGoYi6nojNA_P02ojNA_PCoU9?@0_nCk_42ohANWP?oRV>P1OnAJJ43oiM]X@CoVW2Q1?nLLJ43
oiabXP03oiibWonNLIkoWW6N00;oWW6N1?nML9l3oia`W`GoW76Q1OnZPj/3ojN1Z`CoYH2/00?o^Inn
ok:F^OnbU[T00_nbU[T4ojjA^003ol?0eonk/<oo^k3?00?o^k3?0_nfZ</4ol3Tl0;o_/kV0onQk_P2
ok?Sm`?oNnC]0_nMjO/2ohkMoP04o`000?n>gOkoWMcmoigLo@;oVLgj1OnPcOL2ojC;m0;oXL7_1OnS
`Nl2ojC0k@;oXkg/4_ooool3o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l000002Oooool002Oooooo00?o0000ooooooooool02oooool01?nBXMkoTi[G
oi>JeonCV]L4oi>Dd@CoThg:0onCR<@3oi>3`0GoTh6m0onCP;`2oi>1_003oinJconUX]?oYJ;C00?o
YJ;C0onY[MX4ol3Ik004ok_Zm?njoMoob_[WokWkaP?oYKcZ1?n^]]l2ok2/d`03oiV6__nKQ;[oVhBj
00?oVhBj0onGO[H3ohmf/`?oR6na0on1JZl4ohM^[`?oTgJ_1OnRP:h2ojj8[@03ok6=[on`Rjko/8^^
00?o/8^^0onYQ:d3o`0000;oUgR^0on>KJT3ohm[Y@CoTV^S1?nCJj84oiA/XPCoV6nR1?nJLZ@00onF
LjSo[8feojb=]@02ojb=]@CoYi6n00CoU9?@oi?^lOnCk_7oPEZK0on4GYh4ohYSX0CoTFVQ0onGKJ44
oiY`X@CoW76Q0_nLLZ82oiibW`CoWW6N1?nML9l4oia`W`?oW76Q00?o[HN]ojZ3ZonZPj/00onZPj/4
ojN1Z`;oYH2/0oniWkh4ok:F^@;o[Y6h0oo3`=L4ok^`c`03okJXboo0i?3o`>C`00;o`>C`0_mWfmD2
oj7^n0;o@/C50omUcoT4ogSHo0;oS]gn00?o0000oi?:n_nCb_X01?nIcOX2oj3=m`;oWko_1OnQ`Nl2
oj?1k`;oX[_[1OnS_N`Dooooo`09o`000?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@09ooooo`009_ooool3o`0000Kooooo00CoT:cYoi6Wi?nA
YnCoTJOT1?nBXMh3oi>Je`CoTiCA0onCSLX3oi>8a0CoTh?01?nCPKd2oi>0_003oiVEc_nOV/ooWi[?
00;oWi[?1OnUX]<00onY[M[o`=W/ol3Ik002ol3Ik0?ob_[W00?o^O_6oj>nkOnS_^d00onU_>X2ojjf
g`03oiR9`_nIQ[koVHJn00;oVHJn1?nKQ;X3oiMn]P?oSgJc0on8Kk43oh5Z[`CoQfj_0onCMZl5oj:0
[P04ojj8[OnaSJoo/Hf_ok6=[`Co/8^^0ol000000onTQ[CoUgR^oiMh[P02oiMh[P?oSVfY0on?JjD5
oi9[X`?oTf^R1?nDK:84oiQ_XP?oVW:T00?o[X^`ojb=]On/SKD00on/SKD4ojNA_P;oe>cU0_n1FY/3
ohANWPCoRV>P1?nAJJ43oiM]X@GoVW2Q0onLLJ401?nLLZ;oWW:OoiibWonNLYl4oiiaWPCoWG2O1?nL
L9l2oiaaX@?o[HN]1?nZPj/4ojN1Z`03ojF0[?niWkko^Inn00;o^Inn1?nbU[T00on^TKSo`l3Gol?0
e`02ol?0e`?o^k3?0onWm^`01Oo0i?3oIm_EofOKeOmWfmGoI;gm00?oFLCi0_mUcoT3ohnfl@CoS/;h
0_nCb_X00ol0003oW;K[oibkkP03oibkkPGoWko_0_nQ`Nl2oj6hj@GoX[_[0_nS_N`2ojBljaGooooo
00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool00_ooool2ohfbk`CoT:cY0onA
Yn@3oi:QgP?oTi[G1?nCU=44oi>=bP?oThS40onCPl02oi>1_@;oTi?@1?nIULh4oinJc`?oYJ;C0_ni
bnP3ol3Ik0?ob_[W00Co0000oj>nkOnS_^goVXc40onGR/@4oiR9`P?oVHJn1?nKQ;X3oiMn]P?oSgJc
0on8Kk44oh5Z[`?oQfj_0onCMZl4oj:0[P03ojJ6/_naSJoo/Hf_00;o/Hf_00Ko/8^^o`000?l0003o
0000ok2;[_nYQ:d2ojB6]0CoUgR^1?n>KJT3ohm[Y@CoTV^S0onCJj84oiA/XPCoV6nR0_nJLZ@2ojj;
/0Go[8fe0onWTKh3omC/i@;oPEZK0on4GYh4ohYSX0CoTFVQ0onGKJ45oiY`X@;oW76Q00?oWW:Poiib
WonNLYl00onNLYl3oiiaWPCoWG2O1?nLL9l00onLLJ7o[HN]ojf7[@02ojf7[@CoZX>[1?nWPJ/5okVO
_P?o/YJi0_o8fnL5ol?0e`04ok^`conWm^coYoK/ogV^m0;oVXk61?nFVMD4oi2Wi@GoSkKa0_n>`_P0
1_nK[^CoW;K[oibfjonL]^_o0000oibfj`CoW;_^0_nO_nl3oj6eiPCoXKSY0_nR^n/3oj>ij@CoY;c[
5?ooool00ol0003oooooooooo`0Nooooo`006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
00?o0000oooooon:]o@00_n:]o@3ohfbk`CoT:cY0onAYn@3oi:QgP?oTi[G1?nCU=43oi>=bP;oThS4
00CoQiKKohfCeOn=TmGoSI?E1OnCTm03oiVEcPGoWi[?00?oYJ;CokW;j?nibnP00_nibnP01?o0fNco
b_[Wol[jioo:n^L2oj>A`PCoVXc40onGR/@3oiR9`P?oVHJn1OnKQ;X3oiMn]P?oSgJc0on8Kk43oh5Z
[`CoQfj_0onCMZl2oj:0[P;oYXJb0_naSJl3o`0000?o/8^^00?o/YBhojB6]?nTQ[@00_nTQ[@3oiMh
[PCoSVfY0on?JjD4oi9[X`?oTf^R1?nDK:84oiQ_XP03oiYbY?n^Rk3o[X^`00;o[X^`1On/SKD01?nW
TKkoe>cUomC/iOoDk>D3oh5JV`CoQ5jN0on:Hj04oi5YX@?oUffQ1OnJL:400onLLJ7oWW:PoiibX005
oiibW`?oWW6N1OnML9l3oia`W`Go[HN]1OnZPj/2ojN1Z`;o`k791OniWkh00onbU[Wob=_WolSKi`02
olSKi`;o`l3G0on=WMh00onPRK_oVXk6oiZ>aP03oiZ>aPCoUYWE1?n@YnD2ohnfl@;oWZKK1?nK[^@3
oibfj`04o`000?nL]^_oW;_^oibkkP;oXJoR1OnQ]NH2oj6hj@;oY;OV1OnS^NT2ojBlj`;oY[gZ5?oo
ool00ol0003oooooooooo`0Mooooo`006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o
0000ooooooooool00on:]o@3ohfbk`;oT:cY0_mo[o<3ogn]l@?oOjW_0omoYN`3ognPj0?oPi_R1?n7
U]/3ohfCe@CoTi?@0onIULh4oinJc`;o/<3V0onibnP3olGdkP04ojKeaOnSTL;oXi72oj>A`PCoVXc4
0onGR/@3oiR9`PCoVHJn1?nKQ;X3oiMn]P?oSgJc0on8Kk43oh5Z[`CoQfj_0onCMZl00onRP:koYXJb
ojJ6/P03o`0000?o/Hf_0_n`Rjh2ok:D^0CoY8Jd0onGN:h4ohi]Z@?oSf^U1?nBJj<3oi=[XPGoU6bR
0onHKj85ojj;/0Go[8fe0_oMi=X00ooDk>GoPUVIoh5JV`02oh5JV`CoQ5jN0on:Hj04oi5YX@CoUffQ
0onJL:401?nLLJ7oWW:PoiibX?nNLZ05oiibW`?oWW6N1OnML9l2oia`W`03ok2=/On]Qjgo[HN]00?o
[HN]1OnZPj/01?nWPJ_o`k79ol>abOo3/LT4okVO_P03ok7ijoo8fnOob=_W00;ob=_W1?nHSlP01?n=
WMkoX8Vkoj29^onPRK/4oiZ>aPCoUYWE0_n@YnD2oj6NdPGoWZKK1?nK[^@2oibfj`03o`000?nRZ]go
XJoR00CoXJoR0_nQ]NH2ojFch`GoY;OV0_nS^NT2ojJji`GoY[gZ4oooool2o`0001kooooo000Koooo
o`05oa0@4?ooooooooooooooool@41001_ooool2o`0000;ooooo0oml/_H3ogj`m0CoOjoc0omo[O43
ognYk`?oOjG/0omoX>P3oh>KhP?oQiKK0on=TmD4oi>Cd0CoVIG>00?oWi[?ok30i_n``>H00on``>H0
1?nibnSoaOC^olGdk_o5m>h2ojZE`0CoXi720onJS<@3oiN:a0CoV8W20onIQ[h2oi^4^P;oT7Rd0on=
M;83ohU`/@?oQ6fa0on0Jk42ohM^[`;oR76c0onFNk<3o`0000;oYXJb1?naSJl01?n`Rjko/YBhok:D
^?nbU;P4ojB6]0CoUgR^0on>KJT3ohm[Y@CoTV^S0onCJj85oiA/XP;oV6nR00?oZ8F`ojj;/?n^Rk00
0on^Rk04ojb=]@?ogNCJ0_n2FIT3oh5JV`CoQ5jN0on:Hj05oi5YX@?oUffQ0_nJL:42oiaaX@CoWW:P
1?nNLYl3oiiaWPGoWG2O00CoW72Ook2=/On`SK7o/8fa1?n]Qjd4ojZ3Z`03om3Hg_o3/LWo`k7900?o
`k7900?o^Innok7ijonanN/00_nanN/00oo8fnOoX8NioiR?b003oiR?b003ojJ7]?nPRK_oX8Vk00;o
X8Vk1OnJS/H2oiJIe@03ojFIbOnQW];oXIkB00?oXIkB1?nNY]/2oi^^i0;oXjCG0onRZ]d01?l0003o
XZ[Moj6_h_nQ[n82ojJ`g`GoYK?S0onT]nH00onW^>GoY[[WojJji`03ojJji`?oY[gZ00?oZ;oZoooo
ooooool04?ooool00ol0003oooooo`00000Nooooo`006oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool00_ooool3ogbbmP?oO[3d1?mo[o<3ogn]l@?oOjW_0omoYN`3ognP
j0?oPi_R0on7U]/3ohfCe@CoTi?@0_nIULh2oj2hjPCo/<3V0ongk_D01?mmh[WoZYG0ojZE`?nZUL04
oj>A`PCoVXc40onGR/@2oiR9`P04ohmh]_n?N;GoSgReohmh]@CoT7Rd0on=M;83ohU`/@?oQ6fa0on0
Jk44ohQa/`04oiIk/ol0003o0000oiIk/`CoYXJb1?naSJl5ok:D^0?oY8Jd1?nGN:h3ohi]Z@?oSf^U
1?nBJj<4oi=[XPCoU6bR00CoV6nRojR5/?nXQK3oZ8F`1On^Rk02ojb=]@?ogNCJ0on2FIT4oh5JV`?o
Q5jN1?n:Hj04oi5YX@?oUffQ00CoVW2QoiaaXOnLLJ7oW76Q1?nNLZ04oiibW`CoWW6N0onML9l00onf
UkSo/8faok2=/@02ok2=/@Go[HN]0_nZPj/3om3HgP?o`k790ol00002ok7ij`CoX8Ni00?oV8o8ojJ7
]?nVQk@00_nVQk@3oj29^`CoVXk600?oZiO2ojFIbOnUVLT00_nUVLT5oj6NdP;oWZKK00?oYZ7@oj>T
eonSY=L00onSY=L3oj:Zg@03o`000?nV/=ooY[3O00?oY[3O1?nU/n<00onT]nKoYkSUojNhi@02ojNh
i@CoY[[W00?oY[gZojRoj_nX_nX00_nX_nXDooooo`03o`000?oooooooooo01_ooooo000Kooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`CoN;3f0omg/_L3ogBc
n@?oK[?j0omV/_/3oej_nP?oEZ[i1?mJZOT2ofBZn0?oN:kd1?n>/nl4oj2hjP03ok30i_ngk_Go]nke
00;o]nke0_nbV[l3ojZE`0CoXi720_nJS<@2oiIm]P?oTGZf0on?N;H3ohmh]@CoT7Rd1?n=M;83ohU`
/@?oQ6fa0_n0Jk42ohQa/`?o00000onFNk<5ojJ6/P;o/Hf_0_niVkX4ok:D^0CoY8Jd0onGN:h4ohi]
Z@?oSf^U1?nBJj<3oi=[XP?oU6bR00?oWgn`ojR5/?nXQK000_nXQK05ojj;/005ojb=]OoMi=[ogNCJ
omgTf_n6FiP00on2FIT4oh5JV`?oQ5jN1?n:Hj04oi5YX@;oUffQ00?oVFnRoiaaXOnLLJ400onLLJ43
oiibX0CoWW:O1?nNLIh2oie`W`;o]YNh1?n`SK45ojf7[@03ojZ3Zoo@f=kod=SN00?od=SN00?o`k79
ojf6[?nWQK001OnWQK02oj27^@03ojb:/OnVQkCoYXNd00?oYXNd1?nPRK/00onJS/KoZiO2oj^G`P02
oj^G`PCoYIW90_nQW]82ojZOb`CoYZ7@1OnSY=L01?nRZ]goZ:kLo`000?nX[]`5ojJ`g`;oYK?S0_nX
]^<5ojNhi@;oY[[W0_nY_NP3ojRojP03oj[1j_oooooooooo01?ooooo00?o0000ooooooooool06_oo
ool001_ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo00Gooooo1?mh
/?H3ogNbm`?oM;?i0om^/oX3ofJbn`?oGZoj0omFZ_T4oeZYn@;oI:[h0omh[_@4ohjck`;oX;SZ1?nB
i?`01?ngk_Go/YZook:J_onbV[l4ojZE`0;oXi7200?oWX>foiIm]_nFOKH00_nFOKH4oi5j]P?oSgRf
0on?N;D4oi1h]0?oSGBb0on9L;43ohA]/@04oh1[/Ol0003o0000o`0000?oR76c0onFNk<5ojJ6/P04
ok6=[oniVk[o^I^jokVK^PCo/YBh1?nTQ[@3oiMh[PCoSVfY0on?JjD4oi9[X`?oTf^R00CoU6bRoimo
/?nOOk3oWgn`1?nXQK04ojj;/0?oh>WI00?ogNCJohIKV?n6FiP00on2FIT4oh5JV`?oQ5jN1?n:Hj02
oi5YX@;oTVVQ0onIKj85oiaaX@?oWW:P1?nNLYl4oiiaWP03oie`WonfUkSo]YNh00;o]YNh1?n`SK43
ojf7[@?oY_K;0_o@f=h00onJLjGoU7F]ojf6[002ojf6[0GoYhF`00CoX8Niojb:/On/R[7o[8Za1?nV
Qk@3oj29^`03ok2H__n[Ul;oZiO200?oZiO20onUVLT00on_XLSoZYo;ojZOb`03ojZOb`CoYZ7@0_nS
Y=L2oj^/f0?oZ:kL00Co0000ojR^g?nV/=ooY[3O0_nZ]N45ojRfh`;oYkSU0_nZ_NL5ojVmj004ojRo
j_nZ`N[oZ/7Zoj[1jQCooooo00?o0000ooooooooool06_ooool001_ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o00001oooool2ogR`mP;oOK;e0omj]oT5og>ko0?oI[gm0om@^OX2oc>_kP;o
39jl0_nTjO/3o`6Ac@04o`6Bbomh[_CoN:kdogR^m0;oS[?_1?mPc_L2oi;To003okNO`OnbV[oo/YZo
00;o/YZo0onZUL000onTR;KoWX>foij3]P02oij3]P?oUWff1?nAN[H3ohmh]P?oSgRe1?n@N;@3ohed
/P?oRG2a00CoQ6fao`000?l0003o00000_n0Jk44ohQa/`CoUW^c0onVQ[800on^Ukoo^I^jokVK^P02
okVK^PCo/YBh0_nTQ[@2oiJDd0?oPgg41?n>KJT3ohm[Y@CoTV^S0_nCJj800onINk7oWgn`oimo/003
oimo/0CoZ8F`0_n^Rk03on3Yf@04oi1RV?n6FiSoQU^HohIKV0?oPUVI0_n1FY/2oh]NU`?oRUnJ1?n;
Hih4oi9YX@?oVFnR1OnLLJ43oiibX0GoWW:O0onNLIh5okJG^0Co/8fa00Co[HN]ojKfbonVm/_oY_K;
1OnJLjD4ojf6[0GoYhF`1?n/R[45ojJ7]004oj29^on`V;ko/9Rnok2H_PGoZiO200CoYIW9ojnQb?n_
XLSo[j781?nZWl/2ojJQd0;o[jgF1On[[=P2ojR^g003ojffgol0003oZ[GQ00CoZ[GQ0_nX]^<2oj^m
iPGoZ[gW0_nY_NP2oj_1jPGoZ/7Z5?ooool00ol0003oooooooooo`0Iooooo`006oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool01oooool4ogfbm@?oN[Oi0_mc^o`4ogo8
oP;oJlcm1?n=g?l00om_f_CoY>WkojCYn`04ol3Qk`CoalkO00?ob=CSolFkdOo5^m400_o5^m400oo2
^m?o]io1okNO`@02okNO`@Co/YZo00?oZYG0ojB8]_nTR;H01?nNPkH4oiIm]P?oTGZf0on?N;H3ohmh
]@CoT7Rd1?n=M;83o`0000;oQ6fa0on0Jk44ohQa/`CoUW^c00CoYXJbojjG_on^Ukoo[YNo1OniVkX2
ok:D^003ok>`eOnFU=3oUYC@00?oUYC@0_n3OL@4og]_^P?oQW:e1?nBN;83oiUk/@GoWgn`1?nXQK00
1?n^Rk3oh>WIon3YfOoPjMT2oi1RV0;oQU^H00CoSEbCohaLU?n<G9CoS5bD1?n;GYL3ohYOVPCoRf>N
1?nBJJ44oiU_XPCoW76Q0onNLZ05oiibW`;oWW6N0_nnZL@4okJG^0Co/8fa00?oYGNPoimcXOnOLj40
0_nOLj43oiYcY@03okB;Zon]QZco[HJ/00;o[HJ/1?nWQK000onfT[;o[8Zaojb:/@02ojb:/@CoYXNd
00?o^9jnok2H__n`V;h00_n`V;h4oj^G`P03okNWbOn_XLSo[j7800;o[j780onZWl/00ond/MGo[jgF
ojn]eP03ojn]eP?oZjcH00?o/;WOojffgon]]]l00_n]]]l01Ol0003oZ[GQojZehOnZ]N7o[KkV00Go
ZkgV0_nZ_NL3oj_2jPCoZl7Z0_nZ`NX2oj[2jaCooooo00?o0000ooooooooool06Oooool002Gooooo
00?o0000ooooooooool02?ooool2ogfbm@?oRKOd1?n7`?X2ogo8oPCoVM;l0_n=g?l2ojgNn0Co_]O/
00?o`>7_olO>goo7c]l00_o7c]l00oo5_=;oaK_AolFkd@03olFkd@Go]io10onbV[l00onZS[SoY8Rf
ojB8]P02ojB8]P?oWX>f1?nFOKH4oi5j]P?oSgRf0on?N;D3oi1h]004ohed/_l0003o0000o`0000?o
RG2a0on4KK43oh1[/@CoR76c0_nFNk<00onMSL;o[YNoojjG_`03ojjG_`Co^I^j00Co/YBhok>`eOnc
/=Go/k3E1?nFU=03oh=ma0?oNfnj0on6L[D4oi9h/PCoVG^a1?nOOk04ojR5/0;od_GV00Coh>WIoi1R
V?n>GI?oSUfC0on=G9<3ohaLU0CoRejG0on:GiX4oh]SWPCoTVVQ1?nIKj84oiaaX@?oWW:P1OnNLYl0
1?nNLIko_ZW4okjYa?nnZL@5okJG^0;o/8fa0_nUMj04oimcX@;oVW>U0ondRj/4ojf6[0;oYhF`0onf
T[84ojb:/@;oYXNd0_nhW[h4ok2H_P?oZiO20_ngYlT5ojnQb004ojZObond/MGo];7EokBae@Go[jgF
00CoZjcHok2igon`^Moo/;WO0on]]]l00ol0003o[KKOojZeh@03ojfniP?oZkgV0_n/a>/5oj_2jP;o
Zl7Z0_n[`n/4oj[2ja;ooooo00?o0000ooooool000006_ooool002Gooooo00?o0000ooooooooool0
2_ooool4ohVgm0;oQl3j0onLaoH2oiWBo0Co[m?c00?o[MkhokkGk?nnen`00_nnen`2olC:g`?oalkO
0oo5_=83olFkd@;o^ZG41OngWl401?nbV[ooZXjhojZ>^?nZS[P3ojB8]PCoWX>f0onFOKH4oi5j]P?o
SgRf0on?N;D01?n@N;Co0000o`000?l00003ohYd]0?oQg>f0on5LkP3oh1[/@CoR76c00CoUW^coif=
`_nMSL;oWHg21?n^Ukl3okVK^P03olC1eonc/=Go/k3E00;o/k3E1?nFU=03oh=ma0CoNfnj0on6L[D4
oi9h/P?oVG^a1OnOOk02ojR5/0?od_GV1?n>GI<3oheLT`?oS5bD1?n;GYL4ohYOVPCoRf>N0onBJJ44
oiU_XPCoW76Q1?nNLZ03oiibW`03olO8fonnZLCo_ZW400;o_ZW41OnfUkP01?n`SK7oYGNPojEgX?nU
Mj04oimcX@03oiYcYOndRj_o]8^[00;o]8^[1?n]QZ`00onWQK3o]Y:bokJB/P02okJB/PCo[8Za00?o
YXNdokRN__nhW[h00_nhW[h4ok2H_P03oj^G`_ngYlWo]jO900;o]jO90on_XLP00oni^MWo];7EokBa
e@02okBae@Co[jgF00?o];oRok2igon`^Ml00on`^Ml2ojffg`03ojo1j?l0003o[KkV00Co[KkV00?o
ZkgVojc4jon/a>/00_n/a>/2oj_2jP;oZlG]1On[`n/2oj[2j`;oZL;[5?ooool00ol0003ooooooooo
o`0Gooooo`009Oooool2o`0000cooooo0_n9]o@2oiZll0?oW<Of0on]bNh3ojoCl`Co^loY00?o_]O/
olC:goo4b]l00_o4b]l00oo7c]ooaKcBolFldP03olFldP04olFkdOnjYLCo^ZG4okZUa0Co]io100?o
[iFlojZ>^?nZS[P00_nZS[P3ojB8]PCoWX>f0onFOKH2oi5j]P;oT7B`0on=L[02oh]b/P;o00000_n<
M;<4ohYd]0?oQg>f0on5LkP3oh=e^`CoSH301?nMSL84ojjG_`03okVK^_o4`MOoa<7G00;oa<7G1?nc
/=D4oiJDd0;oPgg41?mkKkX3ohIb]@CoTWRb0onINk45oimo/005ojR5/?oBmNKod_GVom;ei_n@H9D0
1?n>GI<3oheLT`?oS5bD1On;GYL3ohYOVPCoRf>N0onBJJ44oiU_XPCoW76Q1?nNLZ02oiibW`?oalSK
1?nnZL@2okJG^0;o[GnS1?nUMj04oimcX@Go]8^[1?n]QZ`5okJB/PCo[8Za1OnhW[h3ok2H_P03okne
d?ngYlWo]jO900?o]jO900?o[j78okVifOni^MT00_ni^MT4okBae@03ojn]e_nd_n;o];oR00;o];oR
0on`^Ml00on`an_o[l7Xojo1j002ojo1j003o`000?n]_^Ko[KkV00;o[LO]1?n/a>/00onZankoZlG]
oj_5k@03oj_5k@;oZl?[0_nYa>d5ojW2ja?ooooo00?o0000ooooooooool05oooool002Cooooo00?o
0000ooooooooool03Oooool4oiZll003oic7m_n]bNko[LW^00?o[LW^00?o[m?cok_?jOnkcnT00_nk
cnT2ol37h0?oa<[O0oo2_]H3olFldP03okf[b?njYLCo^ZG400?o^ZG400Co]io1ojnE_?n_UKco[iFl
1?nZS[P4ojB8]P;oWX>f00CoVWb`oiAg[onDMjooU7N_1?n@M;02oheb/0?o000000?oRg:bohad/on<
M;<00_n<M;<3ohYd]0CoQg>f0on5LkP3oh=e^`CoSH300onMSL83ojjG_`;o^l?P1Oo4`ML2ok>`e@;o
RfJS0_n=Ij801?nFU=3oPgg4oh=ma?n3OL@3og]_^P?oQW:e1?nBN;84oiUk/@?oWgn`0onOlnh00ooB
mNKoT62Eoi1PU@04ohiMT`?oSEbC0on<G9@5oh]NU`?oRUnJ1?n;Hih4oi9YX@?oVFnR1OnLLJ43oiib
X003oiibWoo7b=_oalSK00;oalSK0onnZL@00onZOJ?o[GnSojeoX`02ojeoX`GoYGNP0onOLj45okB;
Z`Co[HJ/00?o`jBjokJB/_nfT[800onfT[82ojb:/@;o`J_51?nhW[h00on`V;ko_kG@okned002okne
d0?o]jO900?o_/WSokVifOni^MT01?ni^MT2okBae@;o]l_Y1?nd_n800on`^Moo/<O[ok37j`02ok37
j`;o[l7X0_n/c?000ol0003o[LO]ojg7k@02ojg7k@03ojc4jonZankoZ/O^00;oZ/O^0_n[aNd3ojW5
kPCoZLC]0_nY`^/2ojS1k1Cooooo00?o0000ooooooooool05_ooool002Cooooo00?o0000oooooooo
ool03_ooool2oiZll0?oYl3[0on]bNh2okO8i`?o^loY1?o0an000oo4b]oo`[kFol:neP03ol:neP04
olFld_nmZlSo_J_8okf[b0Co^ZG41?n_UK`5ojZ>^0?oY8Rf00?oWX>foiYl/?nJO;000onDMjl3oi1d
/0?o00000_n=L[03oh]b/P?oS7Bc1?n:M;@3ohMc]P?oQG>h0on3MK/4ohf0`0CoWHg200?o[YNook_3
h?nk`n000_nk`n03olC1e`03ofcI]?n<J:CoS6RT00?oRfJS0on=Ij82oi1YX@CoNfnj0_n6L[D5oi9h
/P?oVG^a00CoWgn`oiock_nOlnkoWo?^0_nCI9L3oi1PU@CoSUfC1?n=G9<3ohaLU0CoRejG0on:GiX4
oh]SWPCoTVVQ0onIKj85oiaaX@;oWW:P0_nim?85olO8f`03okjYa?nZOJ?o_YB/00Go[GnS1?nUMj02
oimcX@;o^iB_1OndRj/2ojf6[0;o`jBj1OnfT[801?n/R[7o`J_5ol6[aOo1ZlD4okRN_PKo_kG@00Co
]jO9okk9honnbN?o_/WS1?ni^MT00ondg?Co]l_YokO;j@03okO;j@;o];oR0on_co42ok37j`;oZM;f
0on/c?001?l0003o[<c`ojg7kOn]and2ojW9l@?oZ/O^0_nWao05ojW5kP;oZLC]0_nX`^d4ojS1k1Co
oooo00?o0000ooooooooool05Oooool002Cooooo0ol0000?ooooo`GoYl3[00?o[LW^okO8iongb>L0
0_ngb>L00onkcnWo`<OPol37h002ol37h003oko0f_o2_]Ko`[kF00?o`[kF00?o_;7?okf[b?nmZlP0
0_nmZlP3okZUa0;o/Yc11?n_UK`4ojZ>^0;oY8Rf00?oWh6coiYl/?nJO;000_nJO;02oiAg[`?o0000
00?oT7B`oheb/?n=L[000_n=L[03oh]b/P?oS7Bc1?n:M;@3ohMc]P?oQG>h0on3MK/4ohf0`0?oWHg2
00?oZKSUok_3h?nk`n001?nk`n000oo4`MOoSVbXohaXY002ohaXY0?oRfJS0on=Ij84oi1YX@03o`1I
]OmkKk[oQW:e00;oQW:e1?nBN;82oiUk/@;oMN7Y00?oUVRKoi=TUonCI9L00_nCI9L3oi1PU@CoSUfC
1?n=G9<3ohaLU0CoRejG0on:GiX4oh]SWPCoTVVQ1?nIKj84oiaaX@03oiibX?nim?;o^OCb00;o^OCb
0_o7b=/2ojenXP04ojYmXonnU:co_YB/okjD[0Co[GnS1?nUMj001?nOLj7o^iB_ok^D[onkU:l5okB;
Z`04ojf6[?o3Y;[o`jBjol>T^PCo]Y:b00?ocL_Hol6[aOo1ZlD00_o1ZlD3okRN_P;obmGQ1?no]M00
0onihoCo_/WSokk9h`03okk9h`03okVifOndg?Co]=cd00;o]=cd0_ngbnT2ojWJn@Co[loa00?oXMSk
ojWBm_nYd_H00onYd_H2ojc<l003ojK=m?l0003oZLWa00CoZLWa00?oZ/O^ojO7l?nWao000_nWao02
ojW5kP;oYl?^1OnX`^d2ojS1k0;oYl7/4_ooool2o`0000Wooooo1?l000000ol@413oooooooooo`07
ooooo`009?ooool00ol0003oooooooooo`0@ooooo`;oYl3[1?n``^L2okO8i`Co^lGR00Co`<OPoko0
f_no`=[o_l3J0oo2_]H3okbac`Co_J_800Co^ZG4ok:L`OnbW<7o/Yc11?n_UK`3ojZ>^004oj>7]onO
PK?oWh6coin1/`?oVWb`0ol000000onDMjooT7B`oi1d/002oi1d/0?oSG:`0on;L[84ohad/`?oRWBd
1?n7LkH3ohEc^0?oPgFk1?n=P<001?nMSL;oZKSUojVhiOnY^>D4ok_3h0?oSVbX0on<J:@3oh]VX`?o
SFNR1?n@JJ43oiI]X@04o`1I]Ol6T=SoTWRboi9h/P;oF<k_0_nQM:000onRLikoUVRKoiIXV`04oi=T
U`?oT62E1?n>GI<4oheLT`?oS5bD1?n;GYL3ohYOVPCoRf>N1?nBJJ44oiU_XP?oW76Q00?oELRQojj1
Xon^PJ<00_n^PJ<5ojenXP04ojYmXonnU:co_YB/okjD[0Co[GnS1?nUMj04ok^D[`Co]8^[00?ogMWB
ol>T^_o3Y;X00oo3Y;X2okJB/P;ocL_H1Oo1ZlD00onhW[kobmGQol_Eh@02ol_Eh@03okned?nihoCo
^N?d00;o^N?d0_nnbN<3oi[[n@;o]=cd0onCgoh4ojWJn@03ojo?lOnQf?_oXMSk00;oXMSk0_nYd_H2
oj3?n0CoY/gd00?o0000ojW9lOnYbO400onUbO82ojO7l0;oYLC_1OnW`nh2ojS2k@OoYl7/4oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo01;ooooo0on``^L2
okK3i0Co^lGR00?o_<;Noko0f_no`=X00ono`=X00oo2_]Ko_;7?okbac`02okbac`?o_J_800?o]:C8
ok:L`OnbW<400_nbW<44ojnE_004ojZ>^?nSQkOoXhNgoj>7]`?oWh6c0ol000001?nJO;3oU7N_oiAg
[onDMjl4oi1d/0CoSG:`0on;L[83ohad/`?oRWBd1?n7LkH3ohEc^0;oPgFk00?oSi?CoiVVg_nIY]h0
0onIY]h4ojVhi@03ok_3h?nBLZcoTW:/00?oSVbX0on<J:@3oh]VX`CoSFNR0on@JJ43oiI]X@CoW76P
0onQM:001?nJKIkoUVRKoiIXVonFJ9/4oi=TU`CoT62E0on>GI<4oheLT`?oS5bD1?n;GYL3ohYOVPCo
Rf>N1?nBJJ44oiU_XP04oiaaXOn=GYGoSEjEojn3Y@Co[X6S1On]OZ84okjD[0Co[GnS1?nUMj000oo8
Zkgo^iB_ok^D[`02ok^D[`;o]8^[0ooMfM84ol>T^P03okJB/_o=bmSocL_H00;ocL_H0oo1ZlD3ojWh
i0;obmGQ0omchN82okWSm0?o@/C80_nJjoT3of;Bl`CoTmon0_nYf_T3oi3Jo`;oXMSk0_nHd?/4oj3?
n0;oY/gd00CoXL[eo`000?nQb_GoXL[e0_nUbO82oj?4l@CoYLC_0_nW`nh2ojK1k@OoYl7/0_nV`>`D
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool000Wooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o
0000ooooooooool04oooool00on``^Oo]/?TokK3i002okK3i003ok_5h_nl`]ko_<;N00;o_<;N0ono
`=X00onk]mKo_;7?okbac`04okbac`04okf[b?ndY<So]:C8okBTb0Co/Yc10_n_UK`00onWSkcoXhNg
oj>7]`02oj>7]`?o000000CoWh6coiYl/?nJO;3oVWb`1?nDMjl3oi1d/0CoSG:`0on;L[82ohad/`04
ohmm^on>OkkoSWnnohio_PCoSH?40on=RLX4ohnCd`GoVJKN0_nY^>D4oi9b[0?oSVbX0on<J:@3oh]V
X`CoSFNR0on@JJ44oiI]X@?oW76P00CoXGBPoiY]W_nJKIkoVVfN0onFJ9/4oi=TU`CoT62E0on>GI<4
oheLT`?oS5bD1?n;GYL4ohYOVPCoRf>N0onBJJ42oiU_XP;oSUfC0_n=GYD3ojn3Y@?o[X6S1On]OZ84
okjD[0Go[GnS0_nUMj02olR[_@Co^iB_00?o]8^[omgId_oMfM800_oMfM83ol>T^P;o[?WW1?o=bmP0
1?o1ZlGoZOSTojWhi?nYn>@3ogZQj`;o@JWg0_n@X=l3ogF/m0GoI;cm0omQa_`4ogWEoP;oT=[o0on=
cOd4oiS@n`;oX<oh0onLbOL2oj7:m@03o`000?nPa?;oXlCa00CoXlCa0_nUa>l2ojC1kPCoY/7]0_nW
`N`7ojK0k1?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`002Oooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003ooooooooo
o`0Eooooo`?o]/?T0_ng`n<5okc2gP04oko0f_nk]mKo^kOFok^gePCo_;7?00?o]:c@okBTb?ndY<P0
0_ndY<P4ok:L`@05ojnE_?nWSkcoYhnlojN?_?nSQkL00_l000001?nSQkOoWh6coin1/onOPK<4oiYl
/0?oU7N_0on@M;02oheb/0;oT7Vf0on?N[P4ohmm^`?oSWnn1?n=Pl@3ohf9bPCoSi?C0_nIY]h2ogWU
i@?oUgV`0onBLZ`4ohi/Z0?oS6RT0_n;IZ<4oheWXPCoT6VQ0onFKJ42oiaaX003oi]`X?nJKIkoVVfN
00;oVVfN1?nFJ9/3oi=TU`CoT62E0on>GI<4oheLT`?oS5bD1?n;GYL4ohYOVPCoRf>N0_nBJJ42ohaK
TP?oSUfC00?oSEjEojn3YOn_PjD00_n_PjD4ojj1X`?o[GjR0_oVelH3okjD[0Go[GnS00CoYGNPolR[
_Oo8Zkgob:^m1?nkU:l00ol0003ogMWBomgIdP03omgIdP03ol>T^_n/nNOo[?WW00;o[?WW0_o=bmP4
oi^GcP;oNZ7[0_nQV</5oi2Pg`?oMJcd0_mT_?d2ohjcl0GoPkgi1?n5aod2ohg=o@;oT/7f1?nGaoL2
oic9m`;oWL7b0onPa?801?l0003oX<Cboj?4lOnSa?42oj;0kPGoY<7^0_nV`Nd2ojFok0OoY/3/0_nV
_n/Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool000Wooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0ol0000Fooooo`03okK3i?ng
`n?o]l?S00;o]l?S0onl`]h2okVmg@Co^kOF00?o_;7?okB/d?nd[=000_nd[=04okBTb0;o/Yc100?o
Z9O4ojN?_?nWSk`00ol00003oj>7]`CoWh6c0onJO;02oiAg[`04oiIl]OnCN[GoTgZeoi=j]@CoT7Vf
1?n?N[P3ohmm^`?oSWnn1?n=Pl@3ohf9bP?oSi?C0onHh_d2oif3]`?oUgV`0onBLZ`4ohi/Z0?oS6RT
0on;IZ<3oheWXPCoT6VQ0onFKJ400onLLJ3oVg2Poi]`X004oiY]WPCoUVRK0onCI9L4oi1PU@?oSUfC
1?n=G9<3ohaLU0CoRejG1?n:GiX4oh]SWP04oi9YXOn<Fi;oS5^BohaKTP?oSUfC1On_PjD4ojj1X`;o
[GjR0ooVelH4okjD[0?o[GnS00?odnGTolR[_Oo8Zkd00oo8Zkd2ok^D[`03oj^7/?n`RJco000000;o
gMWB1?nOQ;H5ojbC_0?oViO>00?o[YNooj6HbonQV</00onQV</2oi2Pg`;oYjCB1?nJZ>04ohjcl0;o
Pkgi0onG/^X3oi>jlPGoT/7f0_nGaoL2oi^nl@CoWL7b0_nPa?800onQ_nko0000oj6okP04oj;0kP;o
Y<7^0_nT_n`5ojFok0;oY/3/0_nV_n`5ojJoja7ooooo0ol00007ooooo`03o`000?oooooooooo00Wo
oooo0009ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`04ooooo`03
o`000?oooooooooo01Sooooo1?ng`n<00onl`]ko^KgMokVmg@02okVmg@;o^kOF0_nc/mT4okB/d0?o
]:C800?oZZ7=ojRGa?nXUl@00ol00002ojN?_0CoXhNg1?nOPK<2oiYl/004oiV0]onFO;GoUWbeoiIl
]@CoTgZe0on@NKH4ohmj^0?oSgfk0on>Okh5ohf3a0?oSHW:00CoSi?CoiSRoOnHh_goSVbV0on;Ij<3
ohQSX@?oQV6O0on5Gih01?n>K:SoS6RTohaXY?n<J:@3oh]VX`?oSFNR1?n@JJ42oiI]X@04oiI]X_nK
L:3oVg2Poi]`X0CoVVfN1?nFJ9/3oi=TU`CoT62E0on>GI<4oheLT`?oS5bD1On;GYL3ohYOVP;oRf>N
0_n9F984ohaKTP?oSUfC1On_PjD4ojj1X`03ojenX_oVelKoi]O600;oi]O61?nnU:`2ojeoX`;odnGT
1Oo8Zkd00onkU:ooZhN`oj^7/005ok29[0;oWhBf0_nhU[D5ojbC_004oi^Gc_n^Ukoo[YNoojjG_`Co
XIS;1OnWY=84oiZXh0;oS[?`0_nO[>05oiNbjP?oTk[b0_nB`OH2oiZjkPGoVkka0_nM`O82oinlk@;o
XKo^00?o0000oj6ok_nQ_nh00_nR`>h2oj>nk@CoY;o/0_nU_n`2ojFnk0GoY[o/1?nV_n/>ooooo`Co
000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`09ooooo`002Oooool01Ol@413ooooo
oooooooooooo410@00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`;o
]l?S0_ne`n@3okVmg@03ok6khOnc/mWo/k?I00?o/k?I1?nd[=000ondY<SoZZ7=o`000002o`0000;o
Z9O41?nWSk`3oj>7]`;oWh6c0_nKQK/3oiV0]`CoUWbe0onCN[D4oi1i]P?oSgZh1?n?OK/3ohio_P;o
SH?40onL]>P3oig:m`?oSVbV0on;Ij<3ohQSX@?oQV6O1on5Gih3ohQRW`?oSFNR0_n@JJ42ohmXXP?o
UVfR1?nKL:03oiY]WPCoUVRK0onCI9L4oi1PU@CoSUfC0on=G9<3ohaLU0GoRejG0on:GiX4ohUHTPCo
S5^B0_n>GI<2ojb4Z@Co[h>U1?n^PJ<00ol000koi]O6onKGaP03onKGaP?o_YB/00?o[GnSom?Ui?oC
iN@00_oCiN@3olR[_@?oZhN`0_nlTjd4ok29[004oin4]_nhU[Go^9JeokRF]@Co[9>l00?o_9jjojjG
_on^Ukl00_n^Ukl3oj6Hb`;o]:G91?nWY=82oiZXh0;oZJWF1OnO[>02oiNbjP;oX[?T1?nM]^X4oiZj
kP;oVkka0_nO^^`5oinlk@;oXKo^00?o0000oj:mk?nS_^d01?nS_^d2ojBok0;oY;k/1?nU_^`4ojJo
k0GoY[o[2_ooool3o`0000Gooooo00?o0000ooooooooool00oooool00omEEEGoIVIVo`00000;oooo
o`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4005
ooooo`;o00006oooool4okG3i004okVmgOna^n7o/K_Qok6kh@Go/k?I0_nd[=03o`0000;oZZ7=0onX
Ul@4ojN?_0;oXhNg00?oVh_1oi^5^onKQK/00onKQK/3oiV0]`?oUWbe0onCN[D4oi1i]PCoSgZh0on?
OK/2ohio_P03oi^Ug?nL]>SoW;CX00CoW;CX00?oWL[goiAcZon>K:H00_n>K:H3oh]WX`?oR6>Q0on6
HIl7ohEOWP?oR6:O0on;I:44ohmXXP?oUVfR1?nKL:03oiY]WPCoUVRK0onCI9L4oi1PU@CoSUfC0on=
G9<4ohaLU0CoRejG0_n:GiX5ohUHTPCoS5^B00CoSUfCojb4ZOn/Q:Wo[8BY1On_PjD3ojj1X`;o[XFZ
1?oVelH2okjD[0?oX7FR0ooCiN@00oo8Zkgo^8fYokR=Z@02oj^7/0?o_9>]1?n`RJ`4okRF]@?o[9>l
0_nlW[X5ojjG_`04oj6HbondYLWo]:G9okBUb@?oYjCB00?o/j_@ojVYe_nYZMH00onYZMH2oin/h0;o
Z[?O1OnR/n@4oiffjP;oV[[^0_nO]nT4oinjk0;oWkc]0_nQ_>`3oj:mk004o`000?nR_NcoXkk]oj>n
k@;oXkg/1OnT_^`2ojFnk0;oYKo/1?nV_n`2ojJoj`;oY/3/1_ooool4o`0000Sooooo00?o0000oooo
ooooool04Oooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`0Kooooo`;o]L?T0_n_`^P4ok6kh@;o/k?I00CoZK;O
o`000?l0003o00000_nYZ]L3ojZQc@CoZ9O40_nWSk`00onLT/WoVh_1oi^;`@02oi^;`@CoVhFk0onI
P;L3oiIl]@CoTgZe0on@NKH4ohmj^0;oSgfk00?oVY_Coi^Ug?nKYM`00_nKYM`4oibdj0?oU7>[0on>
K:H3oh]WX`CoR6>Q0on6HIl6ohEOWP?oR6:O0on;I:44ohmXXPCoUVfR0onKL:04oiY]WP?oUVRK1?nC
I9L3oi1PU@CoSUfC0on=G9<4ohaLU0CoRejG00?oRUnJohUHT_n9F9801?n9F983ohaKTP03oj=o[On/
Q:Wo[8BY00;o[8BY1On_PjD2ojj1X`03okN:Y_n^QJ[o[XFZ00?o^XbV0on/OJ43oj1eXP;o`IN/1?nh
SJT00on[Qk3o_9>]okbC[@02okbC[@Co/8V/00?oajBfokRF]OnhU[D00_nhU[D00on/Tkco_9jjokbN
^P02okbN^P?o[YNo00?o_Z_6okBUbOndYLT00ondYLT01?nWY=;o/j_@ok>[d?ncZm03ojVYeP03ok>f
fonZ/mooZ[?O00?oZ[?O1?nR/n@2oiffjP;oXkKV1OnO]nT2oinjk0;oXK_[1?nQ_>`2oj:mk003o`00
0?nR_NcoXkg/00CoXkg/0_nT_^`2ojBok0GoYKo/0_nV_n`6ojK0k0;ooooo0ol0000<ooooo`03o`00
0?oooooooooo017ooooo000Rooooo`03o`000?oooooooooo01gooooo1?n_`^P2ok6kh@04ojNjiol0
003o0000o`0000;oZK;O1?nYZ]L3ojZQc@;oZ9O400?oVY[BoibBbOnLT/T00_nLT/T3oi^;`@CoVhFk
0onIP;L4oiIl]@?oTgZe0on@NKH2ohmj^0;oVYC=1?nJVm<4oi^Ug003oibdj?nJNk3oVW^`00?oU7>[
0on>K:H3oh]WX`CoR6>Q0on6HIl6ohEOWP?oR6:O0on;I:44ohmXXPCoUVfR0onKL:04oiY]WP?oUVRK
1?nCI9L3oi1PU@CoSUfC1?n=G9<3ohaLU0?oRejG00?oXnj]ohUHT_n9F9801On9F9801?n<Fi;oXgn]
oj=o[OnSOjd4ojb4Z@Go[h>U00Co[X6SokN:Y_ngRZKo[XFZ1?njS:H4ojamX@;oX7FR0_o1Uj`4okR=
Z@Go_9>]0on`RJ`2olNT]PCo^9Je1OnlW[X00on^Ukoo_Z_6okj[aP02okj[aP?o]:G900?o_kG@ok>[
d?ncZm000oncZm001?nYZMKo/kKKok>ffonc]]/5ojZcg`;oX[?T0_nW]n@4oj>fiP;oWkOY0_nS^n/5
oj6kj`;oXKc/1?nR_N`01?l0003oX[g/oj>mk?nS_N`3oj>ok@CoY;o/0_nU_n`2ojG0k@WoY/3/00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0N
ooooo`;o[l;X0_nU_n`2o`0000;oYk[W1?nY/]l2ojVZe`04oiZ/honJXm_oVZ?KoiZSf`CoVY[B0onL
T/T3oi^;`@GoVhFk0onIP;L3oiIl]@;oTgZe1?nIT//5oiZDc@CoVY_C0_nKYM`01?nQQ[OoVW^`oiYk
/?nJNk04oiAcZ`?oSVbV0on;Ij<3ohQSX@?oQV6O1_n5Gih4ohQRW`?oRfBQ0on?J:84oiI]XP?oVg2P
1?nJKIh3oiIXV`CoTfBG0on@H9D4ohiMT`CoSEbC0on<G9@2oh]NU`03oj?^[On;JJKoS6bY00?oS6bY
0onDM:`5oj=o[@?o[8BY1On_PjD3okN:YPGo^XbV1?n/OJ401?nPMJ;o`IN/ol6G[?o1Uj`4okR=Z@03
omBb]onlTjgo_9>]00?o_9>]00Co/8V/olNT]_o7Y;KoajBf1?nhU[D00oo9[l3o_9jjokbN^P02okbN
^PGo_Z_600?o]:G9okned?no]M000_no]M03ok>[d003okZmg?nc]]_o/kKK00?o/kKK0_nZ/ml2ojjl
i0GoYkOT0_nS]^H2ojFmjPCoXk_[0_nQ^n/2oj:nk@OoX[g/00?o0000oj:ok_nS_nd01?nS_nd2ojBo
k0;oY<3]1?nU`>d2ojK0k0;oYL7]1OnV`>`@ooooo`03o`000?oooooooooo013ooooo000Rooooo`;o
00008?ooool3o`0000;oYKo/0onW^^L2ojVbg`03oiZcjOnJ[>?oVZcS00;oVZcS0onJXm/3oiZJdP?o
W9;91?nKRl44oi^5^`?oVH2g0_nFO;D00onIU<koVI;;oiVBb`05oiVBb`GoVYC=0_nJVm<01?l0003o
XHJgoj66]onQQ[L3oiYk/0CoU7>[0on>K:H3oh]WX`?oR6>Q0on6HIl6ohEOWPCoR6:O0on;I:43ohmX
XPCoUVfR0onKL:04oiY]WP?oUVRK1?nCI9L3oi1PU@CoSUfC1?n=G9<3ohaLU004oh]NUoo:olcoRfVV
oh]YYPCoS6bY0onDM:`5oj=o[@Co[8BY0on_PjD4okN:YPGo^XbV1?n/OJ401?nPMJ;o`IN/ol6G[?o1
Uj`3okR=Z@;oe;:g1OnlTjd00on`RJcoajBfolNT]P02olNT]P;o^9Je0_o9[l04okbN^P03olflbonn
ZlKo_Z_600;o_Z_61_no]M001?ncZm3o^[gLokZmg?nj_M`3ok>ff`;o]lGU1?n^_>@2ojNgi0;oZ<7[
1OnU_NX2oj>kj`;oXl3^1?nR_^d2oj:mk0;oXL7_0onR_nh01?l0003oX[o^oj>okOnS_nd2oj;1k`Go
Y<3]0_nU`>d2ojC1kPCoYL7]0_nV`>`2ojG0kA3ooooo00?o0000ooooooooool04?ooool002;ooooo
00?o0000ooooooooool07?ooool3o`000003oooooonU_ncoYKo/00;oW;g_1?nK^Nd3oiZcj@CoVZcS
0onJXm/3oiZJdP?oW9;90onKRl42oi^5^`;oTigJ0onGV=<4oiVDcPKoVI;;1?nJU<d2oeK@bP?oZ96n
0onQQ[L3oiYk/0?oU7>[0on>K:H3oh]WX`?oR6>Q0on6HIl7ohEOWP?oR6:O0on;I:44ohmXXP?oUVfR
0onKL:04oiY]WPCoUVRK0onCI9L3oi1PU@CoSUfC1?n=G9<3ohaLU0;ob_o<0on;JJH4oha/Z@?oU7B/
1?nSOjd4ojb4Z@;o[h>U00Co^i2ZokN:Y_ngRZKo]hZV0_oSakd4okZ<YPCo[7fQ1Oo1Uj`01?nhSJWo
e;:gomBb]ooD/[L4okbC[@03omC1aoo7Y;KoajBf00?oajBf00Co^9JeolV_`?o9[l3obJo00onlW[X2
olflb`?o_Z_60_o9amP4okned003ol;=h_nj_Mco^[gL00?o^[gL00?o/kKKokO5iOngaND00_ngaND2
ojjli0;o[<S^1?nX`N/2ojFmjP;oXlC`1OnS`>h2oj:nk@;oX<?a1?nQ`Nl2oj:okP03o`000?nP`_3o
X/7_00CoX/7_0_nT`>d2oj?2k`GoY<7^0_nU`Nd2ojC1kPCoYL3]3oooool00ol0003oooooooooo`0@
ooooo`008_ooool00ol0003oooooooooo`0Iooooo`?o00001_ooool3oibmk`CoVkW]0onJ/nT2oiZ/
h`;oQ;?c0_mm[O<3ogfYl0?oPjK[0on;XN<5oi>MfP?oUiSC0onIU<h7oiVBb`04oiZDcOmFd<[o[ik6
ojnNaPCoZ96n0onQQ[L3oiYk/0?oU7>[0on>K:H3oh]WX`?oR6>Q0on6HIl7ohEOWP?oR6:O0on;I:44
ohmXXP?oUVfR1?nKL:03oiY]WPCoUVRK0onCI9L4oi1PU@?oSUfC1?n=G9<2ohaLU0;ob_o<00CoUg6V
oh]YY_n;JJKoRfVV1?n<K:T3oiAd[0CoXgn]1?n/Q:T00on_PjGo^i2Zok^@ZP03okN:YP;ohlNm1Onj
S:H3ojamX@03om6c^oo1Ujco`IN/00;o`IN/00?o^8fYomBb]ooD/[L00_oD/[L2okbC[@?oe<771?o7
Y;H5olV_`003okbN^_o=_<_ocKc;00;ocKc;00?o_Z_6olW7f?o9amP00_o9amP00ono]M3o`/gRol;=
hP02ol;=hP;o^[gL0_nidN`4okO5i@03ok3Bl_n/b>ko[<S^00?o[<S^0_nX`N/2ojC9l`CoXlC`0_nS
`>h2oio6m0GoX<?a0_nQ`Nl2oik4l`;oX<;`00Co0000oj32l?nR`NooX/7_0_nP`o45oj?2k`;oY<7^
0_nS`^l5ojC1kP;oYL3]00?oY<3]ooooooooool03Oooool00ol0003oooooooooo`0@ooooo`008_oo
ool00ol0003oooooooooo`0Fooooo`?o00002_ooool3oibmk`;oVkW]0_n@^O83oh^gl`CoQ;?c0_mm
[O<3ogfYl0?oPjK[0on;XN<4oi>MfP?oUiSC1?nIU<h5oiVBb`;o]Z[>1?n_W/H2ojRA_P04oiF0^On?
MkCoSgNdohmg]0?oR72a0on4Jjh3ohi/YP?oRfNS1?n8Hj42ohIQW`OoQEnN0on8HYl3oh]TX@CoSfRR
1?nFKJ83oi]`X0?oVVfN1?nFJ9/3oi=TU`CoT62E0on>GI<4oheLT`03ohaLU?o:olcob_o<00;oUg6V
0on;JJH4oha/Z@?oU7B/1OnSOjd2ojb4Z@03ol:P]_nkT:[o^i2Z00;o^i2Z00Co]hZVon?7_OoSakgo
hlNm1OnjS:H2ojamX@;odK>k1?o1Uj`5omBb]`03okbC[OoD`LOoe<7700;oe<770oo7Y;H2omkPeP?o
bJo00_o@g^<3olflb`;ocNc[0oo9amP2okgRlP?o`/gR0_ndh_H4okWAk003okO5iOn`d_;o/=;b00;o
/=;b0_n/b>h3oj?Am`CoY<Wc0_nSa?03oig:m`?oWlKd0_nP`o42oi_6mPGoW/Cc0_nP`_000ol0003o
WLCcoj33l@03oj33l@;oXl;_0_nQ`o45oj?2k`;oY<7^0_nS`Nh4ojC0k@kooooo00?o0000oooooooo
ool04?ooool002;ooooo0_l0000Dooooo`?o00003_ooool4oiJkl@?oT;Wb0on;]o<2ohBcl`;oMkWk
0_mO]?`3ogfYl0?oPjK[0on;XN<4oi>MfP?oUiSC0_nIU<h2oeG<k`;o^[KE1OnfZ/h2ojnNaP04oib9
_onEP;WoUH2ioiF0^@?oSgNd0on8L;43ohA[[P?oP6N]0omnIjh4ohQSX@?oQV6O1_n5Gih3ohQRW`Co
RfBQ0on?J:84oiI]XP?oVg2P0onJKIh4oiIXV`?oTfBG1?n@H9D3ohiMT`?oSEbC0_o:o]l4oiMaYP?o
RfVV1?n<K:T3oiAd[0GoXgn]00?o[8BYol:P]_o2X;H01?nkT:X01?ngRZKohlNmon?7_OoSakd5okZ<
YP04ojamXOoA/k_odK>kom6c^`Co`IN/00?oeOfmomBb]ooD/[L00_oD/[L6omC1a`03olNT]_oNh=Ko
g^3F00;og^3F00?obJo0om3Nhoo@g^<00_o@g^<00oo=_<_ocNc[olg/j`02olg/j`03olW7f?nmh_;o
_N;b00;o_N;b00?o`/gRokCRm_ndh_H00_ndh_H2okWAk0?oZm_h0_n`d_83oj;In`;oXm7g0_nGd_`4
oi[>nP;oWL[g0_nDc?/5oiS9n@?oVlKf0_nNa?<2oi[6mP?oWLCc00Co0000oig4lonP`o7oX<?a0_nN
`o<4oj73l@;oXl;_0_nQ`_05oj?1kP;oY<3]0_nS_nd=ooooo`03o`000?oooooooooo013ooooo000Q
ooooo`;o00004_ooool3o`0001;ooooo1?nF^o43ohnkm0CoQK[h0omg^O/4oendo0?oBk3i0olj[O<3
ocB_k`?o?KS^0_m8`Nl2okfog0Co^[KE0_nfZ/h2oj>Da@?oW8Vo1?nEP;T3ohmg]0?oR72a0_n4Jjh3
oh1W[@?oOVN^0ommJ;401?n8Hj7oQV6OohIQWon6HIl6ohEOWPCoR6:O0on;I:43ohmXXPCoUVfR0_nK
L:03og5FX`?oMEZT00?oOV:XoiIXVonCI9L00_nCI9L4oi1PU@?oSUfC0_n=G9<2ol[ng`;oXW^X0onG
LJH3oh]YYPCoS6bY1?nDM:`3oj=o[@Co`Z2f1?nkT:X01?o2Uj[ohlNmon?7_OoSakd4okZ<YP03okOk
i_oA/k_odK>k00?odK>k0_o1Uj`2omGm_@?oe;:g0_nBklh4omC1a`;o00000_oNh=H3od_8_@;od=kS
0omKdlT2olg/j`?oQ^Oc0_nmh_83oi7Un`;o]>;f0onKg_d2oj_Kn0?oVm_m0_nRfO/2oiODo@GoUm;l
0_nJc_X2oi3>o@CoU<ck0_nHbOT2oi79n`GoU/Oi0onJa_H2oig4l`03o`000?nJa?GoW/?c00CoW/?c
0_nQ`o42oio3lPCoXL;`0_nS`Nh2oj;0k`GoXko]3?ooool00ol0003oooooooooo`0@ooooo`001ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`0?ooooo`;o00005_ooool4oiJkl@?oSk_d0_n5^_P3oh_1n@CoO<Cn
0_mK`O/3ohSHo`04og3Km?n_i_Wo[nKiojoVn@Co_]W]00?o`m[[okfog?nm_m`00_nm_m`2okZfe@03
ojVOc?nSU<GoXiC500;oXiC50onLRKl4oiF0^@?oSgNd0on8L;43ohA[[P?oP6N]0_mnIjh4ogeX/@?o
O6fg1_n5Gih4ohQRW`?oRfBQ0on?J:82oiI]XP;oN5jX0_mbEj@3og5FX`?oMEZT0omnHZP00onBHICo
TfBGoi1PU@03oi1PU@?oSUfC00?oSEbCol[ngoo:o]l00onRNjP4oiMaYP?oRfVV1?n<K:T3oiAd[003
oj=o[Oo7_]7oakkA00Go`Z2f0_nkT:X3ol:GZP?ohlNm0_njS:H2okOkiPGodK>k00Ko`IN/ojF6/one
S:_o]Hb[omGm_OoD/[L2ojN6/@;o/9W000?oe<77ok2I`?n`VL000_n3U]d2ojVLb@CoRigO1?mCWoD3
oc6^k@CoBlK[0_nAiO/3oh?Fo`;oVmkm0onBe_h2oi_Ko@?oVM?l0onGe?d2oiOBo0?oT=3m1?n@c_d2
oiC<n`?oSL[l0onAbO/2oiK7n@;oT<Kj1OnEaOP00onJa?Go0000oi[4m@02oik3l`;oVl?d1OnO`o82
oj72l0;oWl7`1?nR`>l2oj>ok@;oXKk^3Oooool00ol0003oooooooooo`0?ooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool03?ooool3o`0001Wooooo0_nF^o43oiVll0CoU;kd0on;`OT2ogc4oP?oU<ol0_n8f?l3
ojcLn0?o^MK^0_nnfNd2okg6hP?o_KoL00?o[ZWBojVOc?nYWl`00_nYWl`4oj>Da@?oW8Vo0onEP;T3
ohmg]0?oR72a0on4Jjh3oh1W[@?oOVN^0ommJ;43oga]]`?oNgG10on5Gih4ohQRW`;oRfBQ00?oC<K/
ogeLX?mfEYl00_mfEYl2ofaCX`03ogQNZ?mbEjCoLUNT00?oLEJS1?meFZ@2ogiRZ0;oSW2/1?n@H9D2
ohiMT`;oGmOG00?oXgj[oj9kZ?nRNjP00_nRNjP4oiMaYP?oRfVV1?n<K:T2oiAd[004oiMWV?o7_]7o
akkAolNnd@Go`Z2f00?o^i2Zol:GZ_o2UjX00_o2UjX2onW1[@03ol2F[?njS:Ko]o_V00?o]o_V0ooA
/k/00onlTJ_oYHJcokF<Z`02okF<Z`CoYhJa00?oa9jbok2I`?n`VL000_n`VL05ojVLb@;oRigO00?o
Z:;@oiFTh?nEY>000_nEY>05oh:dm@;oLL;n0_nC]^l4oi7:n`;oT]Kn0onNb_H2oiWCo0;oXL_f1OnG
d?`2oi3@o@;oTl_k1?n<bod2ohg:o0;oRlOl1?n<ao/4oi36nP;oULGh0_nA`oP2oiO3mP03o`000?nG
`oKoUl?f00?oVl?d0_nO`o82oig2lPGoWl7`0_nR`>l2oj2ok`CoXKk^3?ooool00ol0003ooooooooo
o`0?ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00005ooooo`;o00002_oo
ool3o`0001gooooo1OnI_?02oiBnm0;oW<7b1?nIaoL2oiC?o0?oZM?f00?o[=chokWFk_nie^h00_ni
e^h2ok_:i@Co_LKR00Co_KoLojjYd_n^ZM;o[ZWB0onYWl`4oj>Da@?oW8Vo1?nEP;T3ohmg]0;oR72a
0on4Jjh3oh1W[@?oOVN^0ommJ;44oga]]`;oNgG11?mnR]D4oh:al`?oOEbP0omfEYl3ofaCX`;oLUNT
1?maEZ<3ogEJY0;oOV:X1?n>L:`4oiil[@?oXgj[1?nRNjP4oiMaYP?oRfVV0_n<K:T2oiQXV@?o[N?i
0oo7_]44ol:P]P03ohQOVoo1TZOo`I:W00?o`YNZ0_oY`Jd4ol2F[0;o_96[00CodK>kokbAZonlTJ_o
_96[1?neS:/3ojN6/@;oa9jb0on`VL02ol>W_@CoZIc91?nXX]04oiFTh0;oP[Ce0_nOZ=d5oi>fk`;o
TL[k0onT_N/2oik:mP;oZl7Z1?nQboH2oiO@o0?oW/Wf0_nCbo/2oiW7m`CoS/Ok1?n;ao`2ohc7n`;o
Rl?j1?n>`oT4oi73n004oiO3m_l0003oU<7foiC1mPCoVL;d1?nM`_82oio1l0;oW/3`1OnP_nl2oj6n
kP;oX;g^2oooool00ol0003oooooooooo`0?ooooo`001oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CoA4A4omgMgOoooooo00001_ooool00ol0003oooooooooo`06ooooo`?o00008Oooool2
oiVll0?oW[g_1?nL`O82oiW7m`?oYl_c0_nYdoH4okCAk`03okWFk_nkb^Go^l[U00;o^l[U0_nma^80
0onb/]So[ZWBojjYdP02ojjYdPCoZIo<0onSU<D3oib9_`CoUH2i0on?Mk@3ohQ`/@;oQ6^^0on0Ijd3
ogiW[PCoOFRa0omlKKL3og]e`@CoOX[E00?oP[7cohQVYOn8IZD00ommG:03ogIFW`?oK5>S00?oEeBc
og9GY?mbEj@00omaEZ<3ogEJY0?oOV:X0on>L:`4oiil[@?oXgj[1?nRNjP2oiMaYPCoS5nH0_nBI9T3
oicNo@Co[N?i0oo7_]401?o2X;KoTF:HohQOVon8Gi/2ol6BY`?o`YNZ0_oY`Jd3ol2F[0;objJd1Onl
TJ/5okF<Z`03ojN6/Oo4W[;oa9jb00;oa9jb00Co/9W0ol>W_Oo3Ykgo`jNm0onYW<T2okZZb@CoZ:;@
0_nEY>02ojVRc`CoWjSM0_nC]^l2ojR^f`CoY;g[00?o/;GLoj_1j_n[`NX00on[`NX2oj7;mP?oZlC/
0_nNbOH00onWa>koVLOgoiW7m`03oiW7m`;oS/Ok0_nD`_H4ohk3n@CoRl?j0_n>`oT2ohg0n0?oT<3g
0_nD`OH00ol0003oU<7foiC1mP02oiW2m0;oUkoc1?nK`?84oik0l0;oX;o_0_nN_^l5oj2mkP[ooooo
00?o0000ooooooooool03oooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgM
gOmEEEGoooooo`0000Kooooo00?o0000ooooooooool00oooool3o`0002Kooooo1?nN_Nl2oic1lP;o
YLC`0onWbo<2ok3;kPCo]=7_0_nhb^P3ok_:i@03okBig?nb/]So/[;H00;o/[;H1?n^ZM82ojVOc004
oiZ?aonCQl?oThO3oi>7``?oSH301?n7N[h3oh5g_P?oNgK20on4Jjh3oh1W[@;oOVN^1?mmJ;43oga]
]`CoNgG10_mnR]D01?m`GjooU7F]ohQVYOn8IZD4ogeLX0;oMUJO0om/Dj<2oeMD/`04og9GY?maEZ?o
LEJSog5FX`?oMEZT0omnHZP3ohi`[0CoWWb]1?nSOZ/2oj9kZ0OoS5nH00CoTVBIoicNoOnLg_goW=km
0onEJ9`3oi9SV0CoTF:H00CoR5nKol6BYoo1TZOo`I:W0_o2UjX4onW1[@04ol2F[?o;Y[CobjJdol^V
]0Co_96[00?oaYf^okF<ZoneS:/00oneS:/00onWQ[7oa9jbolBN/P02olBN/PGo`jNm00CoZIc9okZZ
bOnjZ/Wo^Z[90onXX]000onbY<[oZJ;?ojVRc`03ojVRc`;oWjSM00?o[JG?ojR^fonX[]/00onX[]/0
0onT_N_o/;GLok2eg002ok2eg0;oZl7Z0_nd^mh4oj_4k003ok>ohonWa>koYlC^00;oYlC^0_nIaoL3
oj72l0CoU<;f0_n>`oT2oi:om@CoSKog1?n=`?P3oi30m`;oU<7f00?o0000oiBnm?nG_o<01?nG_o<2
oi_0lP;oV[ka0onM__05oijnk`;oX;g^0_nO_Nh:ooooo`03o`000?oooooooooo00oooooo0007oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000005ooooo`04o`000?oooooo
ooooooooo`?o0000:_ooool2oijmk`;oY;o/1?nUa?000onWbo?o/<_^ok3;kP02ok3;kP03okCAkonh
b^So^<[X00?o^<[X00Co^l[UokBig?nd^Mco];WL1?nb/]P2ojjYdP03oj2Hc?nJSlOoVXo700;oVXo7
0onCQl<3ohf0`0?oQgZn0on1Mkh3og]f`P?oMW_;0on0Ijd3ogiW[P?oOFRa1?mlKKL2og]e`@;oOF^c
0om`Gjl3ohQVY@?oOEbP0omfEYl3ofaCX`;oEeBc0omaEZ<3ogEJY0?oOV:X0on>L:`5oiil[@?oXgj[
00?oXW^XofiO/OmnNlD00omnNlD5oib`i@03ojV0Z?nEJ9coUFRL00;oUFRL0onBHiP4oi5RV003ohQO
Voo1TZOo`I:W00;o`I:W00?o`YNZonW1[OoY`Jd00_oY`Jd01?o0UZcobjJdol^V]?o;Y[@3okbAZ`;o
aYf^1OneS:/5olBN/PCo`jNm00?odL39okZZbOnjZ/T00onjZ/T01?nXX]3o/ZC:ok:Tb_nbY<X3ojVR
c`03ok>Tb?n]YLoo[JG?00;o[JG?0onX[]/2ok>Zc`?o/;GL00?o^K?CokBkg_nd^mh00ond^mh00on[
a>co/koSok>oh`02ok>oh`;oYlC^0on^_nL2oj72l0;oYkkZ1?nK__44oi:om@;oSKog0_nA^_<3ohnl
m0GoT;ge00?oU;kdo`000?nD__@00_nG_o<2oiNmlPGoV[ka0onM__02oijnk`;oW[g^1OnO_Nh9oooo
o`03o`000?oooooooooo00oooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^
k^koA4A4o`000005ooooo`Co0000;_ooool4ojBok0;oYLC`0on/a^`2ok3;kPCo]<SY0_nhb^P2okFm
h0Co];WL0_nb/]P00onVXM7oX9S<oj2Hc002oj2Hc0?oVXo70onCQl<3ohf0`0CoQgZn0on1Mkh3og]f
`P;oMW_;1?m/RMh2odRVm`?oOFRa0_mlKKL00onOT/OoS7^lohak_003oge[/`?oL5n_0_m[G;001?n8
IZGoOEbPogeLX?mmG:03ogIFW`?oK5>S1?mGE;<00omaEZ?oMEZTogEJY002ogEJY0;oOV:X1?n>L:`4
oiil[@;oXgj[00CoI5>ZofiO/Om^Gk7oKUna1?mnNlD3oib`i@?oZH2X0onEJ9`3oi9SV0CoTF:H00?o
R5nKol6BYoo1TZL00_o1TZL00oo2Uj[ojL6]onW1[@02onW1[@GobjJd0_nlTJ/3olJM[PCo]Hb[1?o4
W[82omZj^@;o`jNm0ooA`<T3okZZb@03okndconbY<[o/ZC:00?o/ZC:00CoZJ;?ok>Tb?ncY<So/jC8
1?n]YLl00onX[]_o/j[?ok>Zc`02ok>Zc`04ok2eg?ni/m?o^K?CokVcd`?o];_N0_nl^=H3ok>oh`;o
^KcL0on^_nL00onc_N7oYkkZojNnjP03ojNnjP;oVkka0_nP^n/3oiNkl0GoTK[c0on?_?@2oi2mm@;o
TK[b00?oU;_bo`000?nD^o800_nD^o83oiNmlP;oV[ka0_nJ_>l5oiblk`?oW[g^0_nO_Nh2oijlkPWo
oooo00?o0000ooooooooool03oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03
ogMgMol0003ooooo00Cooooo0_l0000aooooo`;oY;o/0on[`NX2ojc6k0;o//GX1?ndb>T2okC0h`Co
]KgP0_nd^M`00on[ZMKoYZ7AojJQd@02ojJQd@?oX9S<0onJSlL3oi>7``?oSH301?n7N[h3oh5g_P?o
NgK20omfNl/4ofb9gP04odRVmonb[]Co/ZkDok:^e0?oWi;70on<Nk`2oge[/`?oL5n_0om[G;03ogeL
X0?oMUJO0om/Dj<4oeMD/`03ohAma?meFZCoMEZT00;oMEZT0omnHZP3ohi`[0;oWWb]0omKCZT2ofAC
ZP?oKUna1OmnNlD00onL/>Go33Rho``h^002ojV0Z0?oUFRL1?nBHiP3oi5RV0Go`I:W00Cob=aZonW1
[OoY`JgojL6]0_o4nK84ol^V]003okbAZoo6WJkoaYf^00;oaYf^0oneS:/2olZU/`;oa9jb0ooJ^[T0
0oo3YkgodL39om70b@02om70b@03okZZbOno]<oo_kC?00;o_kC?0onbY<X00ondYlco/jC8ok>Tb002
ok>Tb0?o[JG?00?o]JG8ok>ZconcZ/l00oncZ/l5okVcd`03okBkg_nl^=Ko_;SF00;o_;SF00?o/koS
okVlg?ni_=`00_ni_=`01?n^_nOo/kgQok>mhOnc_N42ojNnjP;o[;_U1OnP^n/3oiNkl0;oTK[c0_nE
]nl5oi:hl@?oTK[b00CoU;_bo`000?nE^O3oUKW`1?nG^_04oiZlk`;oW;c_0_nL^nh4oiflkPCoW[c^
2?ooool00ol0003oooooooooo`0?ooooo`008_ooool00ol0003oooooooooo`0_ooooo`?oZl7Z0_n_
`^L4ok;5j003okC8jOnd`>?o]<3S00?o]<3S0_ne_N000on^/M[oZjWFoj^YeP02oj^YeP?oYZ7A1?nP
V<`3oiZ?a`?oThO30on=P<03ohMj_P?oPGNn1?mkM/83ogIkb`;oK8WN0_o1b>02ok:^e004oi60_On4
L[OoQ7:gohAb]`?oS7^l0ommJk<3og1O[`;oJeb`0_mXH[P01?mmG:3oMUJOogIFWomfEYl4ofaCX`;o
EeBc00?oN6bhohAma?n4OL@00_mQF;801?meFZCoOV:XogiRZ?mnHZP2ohi`[0?oJe2P0omKCZT2o`EW
fP04ofACZ_m^Gk7oKUnaofiO/@;oOW_500OoUi[DoeAA/_mDDK;o01NLo``h^?lf?ZgoZH2X00?oUFRL
1?nBHiP3oi5RV0Go`I:W0_o8g6X01?oY`JgoMEVTogEIY?l^<Z@3ol^V]003olK6f_o6WJkoaYf^00?o
aYf^0_neS:/3olZU/`;oa9jb0ooJ^[T5om70b@Go_kC?00Co/ZC:okBWc?ndYlco]:O<1OncY<P01?n]
YLoo]JG8okFUb?neYLP3ok>Zc`;o_:c:0oni/m<00oo0/lgo_;SFokbheP02okbheP03ol:idOni_=co
^KcL00;o^KcL00Co_[_Gok>mhOnc_N7o/kgQ0_nh^m`4ojbki@;oX;_[0_nU^>L5oibgk0?oUKO_0_nB
^?42oiFfk@?oU;O_0_nE^O000ol0003oUKW`oiFil004oiNjl0;oV[c_00?oV[[^oibkk_nL^nh00onL
^nh4oiflkP;oW[c^00?oW[c]ooooooooool01oooool00ol0003oooooooooo`0>ooooo`008oooool0
0ol0003oooooooooo`0_ooooo`03oj_1j_n_`^Oo[l;W00;o[l;W0_nbaNP3okC2i0?o]<3S00?o/;ON
ojjaf_n^/MX00_n^/MX4oj^YeP?oYZ7A0_nPV<`01?nEVMGoSi?DohnCe?n?Tm@3ohR@e0?oPi3H0oml
U=l5ogJSkP?oJ;_m0oo9gNP2ol78h004oj2AaOnAP;goTH2moi60_@?oQ7:g0omfIkD3oge[/`?oL5n_
0om[G;02ofQR^0?oMUJO1?m/Dj<01OmGE;?oN6bhogQ/^?mTF:ooQ7g400;oHERb0omJD:d00on9Jj[o
MUNQogIGX@03of]@X0CoFdjY00Go1FOJom_Qf_m^Gk7oKUnaoiB>b`03oeQE/`;oE56b00Co01NLo``h
^?lf?Zgo=Sj]0onEJ9`4oi9SV0;oTF:H0_nkT:T3ol6BY`;ob=aZ00CoV72Toi=]Y?nCKJCoTffT0_ml
I:d01?o;Y[Coa/KJolK6f_o6a]X4olJM[P03okF<Zoo:YK?obZFc00;obZFc00?oa9jbomZj^OoJ^[T0
0_oJ^[T01?o[j/_odL39om70bOoA`<T2om3MhP?o_kC?00?o]KWLokBWc?ndYl`00ondYl`3ok>Tb003
okRVaoneYLSo]JG800?o]JG800?o/j[?okb/b_nl[<X00_nl[<X01Oni/m?o`;?=ol2ccOo0/lgo_;SF
00Co`[WA00?o^KcLokjkeonn^mL00_nn^mL00onc_N7o^;_LokRkg002okRkg0;o[;_U0_n_^N44ojFh
i`;oW;O/0_nO]NL3oiVdj`GoUKK]0onD]nl01?nE^O3o0000oiNgkOnG]nd4oiRhkPCoV[[^0_nL^nh2
oibjk@CoWK_]1?nN_>d8ooooo`03o`000?oooooooooo00kooooo000Tooooo`03o`000?oooooooooo
02oooooo0on_`^L2ok?2iPGo]<;T00Co]<3Sok2gg_n`]mko/;ON1?n^/MX2oj^YeP04oj6Wf_nKWmOo
VioGoi^Oe`CoUIWE0on?Tm@3ohR@e0?oPi3H0omlU=l5ogJSkP05ofRkoOo7j^kobMgXolWMj?n]Y<l0
1?nPTLD3oi60_@?oQ7:g0_mfIkD2of]U^@04oge[/om`GjooL5n_og1O[`?oJeb`0_mXH[P3ogN3dP;o
K5>S0_nPg?`00onOU<SoN6bhogQ/^002ofAH[`03ohAma?mQF;;oHERb00?oFU2]0omfEj42of]@X0Co
FdjY00?oe?_Oom_Qf_oKhMX00onDS//2oeQE/`07oeaE/OmDDK;o01NLo`0GW?l<>;So=Sj]of5E[P02
oiEXW0CoTV>H00CoTF:Hok^@ZOnkT:Wo^i2Y0oo1TZL00oo8g6[oV72ToiQ`Y003oi=]Y0?oO6B]0oo6
a]X4olJM[PGobZFc1?oJ^[T3on_Zb`03om70bOo@gN;od=gR00;od=gR00Co_kC?okFig?ne^Mco]KWL
1?ndYl`00oncY<So^:K7okRVa`02okRVa`?o]JG800?o_:W6okb/b_nl[<X00_nl[<X00oo2[lOo`;?=
ol2cc@02ol2cc@Go`[WA00Coa[[?okjkeonn^mOo_[_G0_o1_=D3okRkg003okZkf_n_^N7o[kWQ00?o
[kWQ0_nU^>L2ojRfh`CoWkGW0onI]>/2oiFfk@;oV;?Z1?nG]>`01?nG]ngo0000oiNgkOnG]nd4oiRh
kP;oV[[^0_nK^Nd4oibjk@CoWK_]0_nN_>d2oijkk@Oooooo00?o0000ooooooooool03_ooool002Go
oooo0_l0000`ooooo`03ojo2ionc`^Ko/l;V00;o/l;V0_nd`^@3ok:mhPCo/;ON0_n^/MX00onU[]go
XJOJoj6WfP02oj6WfP?oVioG0onEVMD4ohnCe0?oR93D0on3T=P3ogbDg`;oMZ?^0oo7j^h00ong]]So
[JC?ojfTc`02ojfTc`?oX9750onAP;d3ohAb]`?oMVNe0_m[IKT4og1O[`;oJeb`0omXH[P4ogN3dP03
oj3Lo?nOU<SoWiC800?oN6bh0_mTF:l2of5H/P?oFU2]0_mKF;H01?mfEj7oJe2Pof]@X?m[D:02oe]>
Z@04omCkgon?S<coShc<ohn<c0;oJf2d00?oU8k;oeQE/omHEK<00_mLEK401?mDDK;o01NLo`0GW?lf
?Zd2of5E[P03oiEXW?nBHiSoTV>H00;oTV>H00CoTF:Hok^@ZOnkT:Wo^i2Y0_o1TZL01?o8g6[oV72T
oiQ`Y?nHL:@4oi=]Y0?oO6B]0_o6a]X3olJM[P;od;g81?o:YK<00ooTf<[of[ZiomZj^@03on_Zb`?o
P=fR0_o@gN82oi[Po@?o]KWL0ondYl`00onbZM3o^:K7okRVa`03okRVa`03okFUb?nlZLKo_:W600;o
_:W60_nl[<X3ol:_a`;o`;?=0_o6]//3ol:id@?oa[[?00?o_[_Gol6leOo1_=D00_o1_=D01?nh^mco
^[_JokZkf_nj^mX3ojnih@03ok:hg_nX]^?oZ;KS00?oZ;KS0_nO]NL00onR/nGoW;?Xoibcj002oibc
j0CoV;?Z1?nG]>`01?nG]ngo0000oiVejonI]N/3oiZgk0GoVkW]0_nL^^d2oifik0CoW[[]1?nN^nd6
ooooo`03o`000?oooooooooo00kooooo000Wooooo`03o`000?oooooooooo02kooooo0onc`^H3ok;2
iPCo/[gR0_n`]mh00onY]>7oYJkMojF^g@02ojF^g@CoXJOJ0onKWmL3oiFIe@;oSi?D0_n6[^l4og^g
n@;oJ<Kn00?oKMkIoh_/boo1k_400_o1k_401?o7j^ko]kKHokNff?ng]]P3ojfTc`?oX9750onAP;d3
ohAb]`?oMVNe0_m[IKT3oeY[bP04og1O[om[G;3oJeb`of]L/0;oJ6:h0omgPm800oo8bM[oWiC8oinD
b002oinDb0;oN6bh0_mTF:l00om?C[7oHERboeY@[@02oeY@[@?oFeRf0om[D:001?mKCZWoe?_OomCk
goo=d]d2ohn<c0?oJf2d0omHEK<2oeaE/@;o01NL0_lf?Zd2of5E[P;oTV>H0_nKO;05ok^@Z@03ol6B
Yoo8g6[oV72T00?oV72T0onCKJ@4ogaT[@;o07CE00CoaYf^om2mb?o@_LSod;g80oo:YK<3onCHbP04
omZj^Oo[j/_ojn[;oljmb`?oQ9CK00?o8UW?oi[PoOnJh?d00_nJh?d3okFig004okBWc?nbZM3o/ZW@
ok:Yd0?o^:K700?o^ZW8okbYa_nlZLH00onlZLH00onl[<[o`Zo7ol:_a`02ol:_a`03ol2ccOo6]/_o
a[K;00;oa[K;00Go`[WAolJjcoo6^/ooa[[?olVmcP04ol6le@03ol>me?nj^m[o^[_J00;o^[_J00?o
[kWQok:hg_nb^=h00_nb^=h2ojRfh`;oZ[GQ1?nR/nD4oibcj0;oV;?Z0_nK/^P3oiVcjP;oVKG[00?o
0000oiVejonI]N/00onJ]n`2oi^ik@;oW;S[1OnM^N`2oijjk@;oWk[/0onO^nd6ooooo`03o`000?oo
oooooooo00kooooo000Xooooo`03o`000?oooooooooo02kooooo00?o/l;Vok;2i_nb`^H00onb`^H2
ok:mhP;oZk_U0onY]>44ojF^g@;oXJOJ00?oVJcToi>YiOnCZND00_nCZND3ohfYj0CoQZk_0_mk]oT2
ogkPn003ohW/gOo1k_7o`Nka00;o`Nka0_nmaN44okNff0?o[JC?0onPTLD3oi60_@?oQ7:g0_mfIkD3
of]U^@CoFV_:0_lNS^/3ofQR^003ogN3d_n?TM7oSi7A00?oLW7300?oWiC8ogQ/^?mhK;P00omTF:l0
1?m?C[7oHERboeY@[OmJD:d3oe]H]PGoQI;H0_o=d]d3ohn<c0;oJf2d00?oEdn]oeQE/omHEK<00_mL
EK43of1]b003ocHn[OmQEJkoHEF^00CoVgb`1OnkT:T00oo1TZOoX7b[oj1lZ`03oiQ`Y0?oTffT1?ml
I:d2obQ=`PGod;g800GobZFconCHb_oTf<[oi=S:oh3JV@04oljmb`?oRHS<00?oQ9CKob9Icol0;;D0
0_lTX>/3oi^ejPGo/ZW@00Co^:K7okZYb?njZLSo^ZW81?nlZLH5ol:_a`Goa[K;0oo6^/l3olVmcP;o
`KcE0oo3_M@2okZkfP;o_;_I0onb^=h00onc^=goZ[GQojZeh@03ojZeh@?oX[?U0_nL/nP2oinbi@Go
Vk;X0onI/nX01?nI]N_o0000oi^djOnK]>T4oi^fj`CoW;S[0_nM^N`2oijij`GoWk[/0onO^nd5oooo
o`03o`000?oooooooooo00kooooo000Yooooo`03o`000?oooooooooo02oooooo0_nb`^H3ojc1j@Co
Zk_U0onY]>42ojF^g@;oWK3U0onI[>@4oi>Yi@?oSJWX0_n6[^l2ohSEo`;oR^[`0ongk?H2okc?j0Co
_LGQ0_ng]]P01?nQW];oUI7=oiFAcOnETLd3ohZ5b0?oO7_70on4L[L3ogIW]@;oJfFi1OmJJlX00olN
S^_ofo?Ook>igP02ok>igP?oSi7A0ombLL<00omDF[coN6bhofAH[`02ofAH[`;oCdja0omJD:d3oe]H
]P?oQI;H00Coj?W<olgBgOo=d]gocM;M0_n?S<`2of]P]0;oEdn]00CoF5FcoeaE/OmLEK7oG5Fa0omP
KLP2of5E[PGoVgb`1?nkT:T3oj1lZ`?oV72T0onCKJ@4ogaT[@?oY9g>0oo@_LP3ogkWe`03onCHb_oi
gJcok]6e00?oc[g;0_nnZ/D3ohV8c0;oBF;:00?o02beo`1Rd_l0H]800onK]NX3ok:Yd003ojZYeOnj
ZLSo^ZW800;o^ZW80onlZLH2ol2]a`?o`Zo70_o8]<L3olJfb`;ob[W:00?oa[[?olVmc_o9_Lh00_o9
_Lh00oo1_=Go`kgDol>me002ol>me003okZkf_nl^mWo_;_I00;o_;_I00Co/[SNok>hgOnc^=go/kSM
0onZ]N400on/]MooYK?RojFchP02ojFchPCoWk;U0_nK/^P2oijaiPCoVk;X00CoVkCYo`000?nK]>Wo
VkCY1?nK]^/2oibhj`03oijgj_nN^N_oW[W[00?oW[W[0_nO^^`2oj2jj`CoX;_/1?ooool00ol0003o
ooooooooo`0>ooooo`00:_ooool2o`00037ooooo1?n/`NT2oj^ki@03ojBjjOnQ]NOoXKGW00;oXKGW
1?nM/>D3oiV/i0;oTjWU0_nA`?H4ohc8o003ohSEoon:j_3oR^[`00;o]ncf1OnlcnP2okg5h@03ojZ[
f?nQW];oXIkB00;oXIkB0onETLd3ohZ5b0;oO7_70omeN/X3og24e`?oJfFi0_mJJlX01?n5j^Wod?o@
olcMiOo<gND3ok>igP?oSi7A0ombLL<2oeAJ_003ogQ/^?mTF:ooI5R_00;oCdja0_lnIm800omJD:go
FeRfoe]H]P02oe]H]P03ohFBf?oXnLcob]GS00?oRi[M00?o>eK3ohn<c?m[H;@00_m[H;@2oeM?[@03
oeQE/omLEK7oG5Fa00?oH6g800?o=Sj]of5E[_mQEJh01?nKO;04ok^@Z@?oX7b[0onHL:@4oi=]Y0;o
O6B]0_nZQZh3ojBMcP03om2mb?oRc<;ommb`00;on]jX0_oigJ`2onkA]@04oljmbonnZ/Go_Z[5okjZ
a@?oRHS<0om9H/X00ol0;;Go04W8o`1RdP02ogJPk003oi^ej_nbZM3oZZWE00;oZZWE1?njZLP00onl
ZLKo`:g7ol2]a`02ol2]a`03ol:_aoo8]<Oob;C700;ob;C700Coa[K;olZib_o:^L[ob[W:1Oo9_Lh0
1?o;_loo`kgDol>me?o3_M@2olFne0?o_;_I00?o_KcHok>hgOnc^=d00onc^=d01?nZ]N7o[;GOojbe
gon/]Ml4ojFchP;oWk;U0_nQ/N<4oijaiPCoVk;X00?oVkCYo`000?nM/nP01?nM]NT4oijgjP;oW[W[
0_nO^NX5oj2jj`;oX;_/0_nR_>`3ooooo`03o`000?oooooooooo00kooooo000/ooooo`03o`000?oo
oooooooo02oooooo0_n/`NT2ojFok0?oY;[Y1?nQ]NL2oif`i@;oV;[`1?nD^o83oi70mP;oS<Sl0_n?
ho`2ok3Vn0;o^]C]1?nlcnP00on`]]goZZ_HojZ[f002ojZ[f0?oXIkB0onETLd3ohZ5b0?oO7_70ome
N/X3og24e`?oO;3e00?oZOK1om3od?o<gND00oo<gND3ok>igP;oSi7A0ombLL<3oeAJ_0?oI5R_0_m?
C[42ociWdP;oFeRf00?o0000onSic?oXnL`00oo:eN<2oh^Jg@;o>eK300?oShc<of]P]?m[H;@00omG
Cjd3oeaE/@03of1]b?oGa/[oelK:00;oHEF^1?nKO;03ok^@Z@CoX7b[0onHL:@4oi=]Y004ogaT[OnZ
QZkoZXJ^ojZ6[P;oY9g>0ooRc<801?ogg;3on]jXoo[NZ?oigJ`3onkA]@Go_Z[50on9R<`2odURbP;o
02be0_l0BLP2ogJPk0CoZZWE0onjZLP00onj[Lco`:g7ol2]a`03ol2]a`Cob;C700Coc;W8olZib_o:
^L[ob[W:0_o=_L/3olVmcP?obko?00?o`kgDolFne?o5_]@00_o5_]@01?nl^mWo_KcHokflf?nm_=P2
ok>hg@;o];SL1?n/]Ml2ojFchP;oY[;Q1OnQ/N<3oijaiP;oVk;X0_nN/^H2oifcj003o`000?nM/nSo
WKGY00?oWKGY0_nN]nX2oingj@CoWkWZ0_nP^^/2oj6jj`GoX[c/0oooool00ol0003oooooooooo`0=
ooooo`00;Oooool00ol0003oooooooooo`0_ooooo`CoYKo/0onT^^T2oj6ei`;oVk_^1?nH^_02oiBk
lP?oU=3l0_nBfOh3ojWNnP03ok3Vn?nje>go^]C]00;o^]C]00?o_<oXok2fgOn`]]d00_n`]]d4ojZ[
f0?oXIkB0onETLd2ohZ5b0?oO7_70omeN/X4og24e`03ogb`mOnYm/7odO3X00;odO3X0_o<gND01?nY
[=WoShk?ohn>con?S/l3ofmca`?oLW730_mDF[`3oe]Ya`?oCdja00?o?VOBok3kf?n`nmP00_oXnL`4
ol[Eh`?oRi[M0_lkE/<2of]P]0?oEdn]1?n9N[`2omO6bP03oo7=[?mQEJkoVgb`00CoVgb`00?o^i2Y
olBU^_nPO:/00onPO:/4oiQ`Y0?oTffT1OnZQZh01?nTWLkoh/c2on;<`_ogg;02oo[NZ0;onMf/0oo^
dKD01OoP`k_o_Z[5okjZaOnnZ/Go/Yg200?oRh?50om9H/X00ol0;;Go04W8o`19b002oeR;i`03ogJP
k?nZZMGoZZWE00;oZZWE00Co^ZW8okZ]c?nj[Lco^Zg<0oo0[LL2olBbb@;ob;C70oo<^LP00oo:^L[o
cKg;olfmb`02olfmb`03olVmc_o;_loobko?00;obko?1?o5_]@01?o5`=Go_KcHokflf?nm_=P2okfm
f@Co];SL0_n/]Ml2ojfegPCoY[;Q0_nQ/N<2oj>ahPCoX;7T1?nN/^H01?nM/nSo0000oinci_nO/nH3
oinej0GoWkOY0_nO^NX2oj6ij@CoXK[[0_nR_>`2oj>lj`?ooooo00?o0000ooooooooool03Oooool0
02kooooo00?o0000ooooooooool0;oooool2ojFok0;oW[g^0onM_>h4oi^kkP;oV;[`0onGb?P2oiC@
o0?oY=Ki0_nYg_X3okCDl0;o^]C]0_nc_^84ok2fg@;oZZ_H0_nLW=<3oi>Dd@?oR8gB0on0SML3ogak
a`?oMG[:0_m`Q=L00omEd=Wo/O[>om7`j002om7`j003okk7hOnY[=WoZJcI00;oZJcI0on?S/l2ofmc
a`;oH6_600?oLW73oeAJ_?mDF[`00omKJLL5oh>Tj@;od_o50_oKl]l2ol[Eh`04oinWg?mOMM7oGgGA
oh^Jg@;o>eK300?o@U6lof]P]?mGCjd00_mGCjd5ohUj_004omO6b_oacJcom]BZof5E[PCoVgb`00?o
^i2YolBU^_o4YKX01?nPO:/3oiQ`Y0;oTffT00?oZX2VojZ6[_nZQZh00onZQZh01?oF[k7oh/c2on;<
`_ogg;02oo[NZ004ooWM[?o^dKGok]6eonkA]@?oh<>k00Co_Z[5ok:M`_nbWL;o/Yg20_n;PlD2oeeY
aP03odURb_l@@/3o02be00;o04W80_mHRnL2ojZYe@;oXJOJ1Onj[L`01Oo0[LOoa;;9olBbbOo4//Wo
b;C700Coc;W81Oo=_L/01?o?`/gobko?ol^ocoo;_ll2olg2d003olFne?o5`=GoaL3E00;oaL3E00?o
_KcHokfmfOnm_MT00_nm_MT4okBhg0Co[KGN0_nV/^42ojNbh0CoXk7R1?nP/N@2oijbiP04oj2biOnO
/nKoWk?Vo`0000;oWk?V0onO]NP2oingj@;oXKOX1OnQ^NT2oj6jj`03oj>kj_nS_>_oXkc[00?oXkc[
0_ooool00ol0003oooooooooo`0=ooooo`00;oooool00ol0003oooooooooo`0_ooooo`CoW[g^0onM
_>h2oi^kkP?oVL?e0_nGb?P3oj;>m`;oY=Ki0on`dO82okCDl0;o/l?V1?nc_^82ok2fg@03ojBUeonL
W=?oW9cC00;oW9cC0onCU=44ohR=dP?oP8gG1?meUN@2og2hn`05oiodjonWn>CocOKYolgfjOoAl>P0
0onnan43ojV/f@?oShk?0om_LlL2of1[aP?oE5Zl0omKJLL3oh>Tj@05ol?nf_oBolGofo;Oom_bgoo3
cN801?nOYm`2oemed@?o>eK300?o@U6lof]P]?mGCjd00_mGCjd3ohUj_0;oc;_:00?olLf/ooKDZ_of
e:X00_nKO;000ooakL;oB<O1ogj9e002ogj9e0CoX7b[0onHL:@01?nCKJCoZX2VojZ0Y_nZP:H4ojZ6
[P;oeZna00Goh/c2ooOL/?ojgZSon]jXooWM[002onkA]@Coh<>k1?nbWL83oh^3a@?oGFW600?o44;0
o`19b?l0BLP00omHRnL4oj6WfP?o^Zg<00?o^[7AolBbbOo4//T00_o4//T5olbib004olnoboo=_L_o
cKg;olfmb`?ocl;=00Gobko?olg2d?o=`]3ocL;@olg5d`03olG0e@03olC2eonm_MWo_KgI00;o_KgI
00?o_;gJokBhg?nd^=`00ond^=`2ojfegP03ojfegonW/^3oYk;P00?oYk;P0_nS/N800onT/N;oX[7S
oj:ah`02oj:ah`CoX;;U0_nO/nH00ol0003oXKCUoj6ei`03oj6ei`CoXKOX0_nQ^NT2oj>ij@CoXk_Z
0_nS_>/2ojBmj`;ooooo00?o0000ooooooooool03Oooool0033ooooo0_l0000`ooooo`;oW[g^0_nM
_Nl4oi^olP;oVL?e0_nQb?@3oj;>m`;o[<gb0on`dO82ok;5j0Co/l?V0_nc_^800onY[M[oY:GGojBU
e`02ojBUe`CoW9cC0onCU=43ohR=dPCoP8gG0_meUN@2oiOIoP;oYoST0_o=m^T3ol[Mi`?o_/OQ0onY
[=T3ohn>c`;oKg?70_mPJlH3oe=dePCoFfW700?oPjCYol?nf_oBolD00_oKl]l3ol?=hP?oWjOL0_mO
MM42o`<h^P03oc]F`om2DKco@U6l00?oEdn]0_n9N[`3olbkbP;ok_C500?om]BZoo7]`_oakL800_o6
b=`00om8al7oOXWDogj9e003ogaY/P04oj1lZonHL:CoV72ToiUdZ0CoZX2V0onZQZh3omJ_/@04ooCA
ZoolhJ3oo>6Poo_WW@;onNB^00?ok]6eon33^ooP`k/00_oP`k/4ok:M`P?oRh?50omMJLH01?lcE<Go
6U;<oaYBc?l0BLP2odamh@05oeR;ionQYm[oXJOJoj6Wf_nj[L`01?nj/M42olBbb@;oakS<0oo<^LP3
olnob`05olfmboo?`/gocl;=olo2cOo@a]000oo=`]03olg5d`05olG0eOo4`]Ooa<;GolC2eonm_MT0
1?nl_MX3okBhg003ok>igOn]]Moo[KGO00;o[KGO0_nW/^02ojRch0CoY;7R1?nR/N<2oj2bi@;oX[;T
00CoXKCUo`000?nQ]>GoXKCU1?nQ]NL2oj6gj003oj>gionS^NWoXkWY00?oXkWY0_nS^nX2ojBkj@Co
Y;g[00?oooooo`000?ooool03_ooool003;ooooo00?o0000ooooooooool0;_ooool4oifmk`;oVkob
0_nP`_44oj78m003oj;>mon/cO;o[<gb00;o[<gb00?o/=7bok;5j?nbaNP00_nbaNP2ok?3iP03ojfd
g_nY[M[oZJgJ00;oZJgJ1?nTYML3oibLd`?oTiCA1?n8SM82oh2=e`?oSKWd00?oUmWnojOhi?nWn>@0
0_o=m^T3ol[Mi`04okK2honU[]koYJkNojF^gP?oS9OI0omgQ]D3oeike`;oH6_61?mCM=H01?mdb?oo
`okJol?nf_o0o]h2omSkg@;oe>[T0oo3cN83oinWg0;oGgGA0_l3>;X2od9A_0?oIfo700?oRGZlolbk
b_o<^lX00_o<^lX2onkda@06oj;QROoVhLkogLO3omg7`oo6b=co_:g:0_mnRM@4ogaY/P?oVGBX1?nZ
P:H3ojZ6[P?oeZna00Com=6[oocQX?olhJ3onnNM0_oii:h01?o^fKcoh<>kon33^ooP`k/2olnb_PCo
/Yg20on;PlD3oeeYaP04oc=DaOlJD/co6U;<oaYBc0;oC7gQ0onIYMh5okZad@03olBbbOo7^<coakS<
00;oakS<00?oc;W8olnoboo?_l/00_o?_l/3olo2c@?od<K@00GocL;@olg5doo=aM?ocLGColc7eP03
olC2e`;o`l?J1?nl_MX00ond^=co/kWMok>ig@02ok>ig@?o[KGO1OnX/n03ojBahP;oX[7S0_nS/^<5
oj:bi003oj6diOl0003oXkCU00CoXkKV1?nS]nL2oj>ij@;oY;[X1OnT^nT2ojBmj`03ojJnj_oooooo
000000oooooo000cooooo`03o`000?oooooooooo02kooooo0_nM_Nl2oj6nkPCoX<;a0_nQb?@3ojW8
l0;o[<gb0on`aNX2ok;5j003ojjih_n]]=ko[KCN00;o[KCN1?nY[MX2ojBUe`04oi^VgOnCXMkoTj7N
oi>QgPCoSj7Q1?n9Y^P2ohfim0?oVn[j0_nnl_83olOWk@04ol[Mionf`^?o]/;SokK2h`?oYJkN0on<
UmT3ogN6e@;oGW_G0om]U^P2oe=deP;oWM?k0_o0o]h2omSkg@;oe>[T00Co^lSUojB[g?nTZmcoY:_L
0on4T=P3oe5de`;o0cRj0_m2DK`2ofM_a`Coc;_:0_o^m<D00onRhHWoi^7>omg7``02omg7``?o_:g:
0_mnRM@3ogaY/PCoVGBX1?nZP:H01OnZQZkoeZnaomJ_/OoF[k7om=6[00;oo>6P00ConnNMooWT[_oi
i:konNB^0_o^fK`01?oP`k_ock:nolnb__o?/[h2ok:M`P;oZiK00on>Pl<3ofeaaP;o<eC50_lJD/`2
odekgP04odamhOnIYMkoVJGNoiVUgP?o^[7A0_ni]]H3olNhc0;obKo@0oo?_l/2om74cP03olo2cOo@
a]3od<K@00;od<K@0oo=aM<3olc7eP03olC2eoo3`m[o`l?J00;o`l?J0_nl_MX2ok^ng0?o/kWM00?o
/[WNojfegon]]Ml00_n]]Ml4ojRch0;oY;7R0_nU/^44oj>bh`;oX[;T0_nS/n<2oj>di@03o`000?nS
]>GoXkKV00?oXkKV0_nS]nL2ojBhi`CoY;[X0_nT^nT2ojJlj@CoY[kZ00?o0000ooooooooool03Ooo
ool003Cooooo00?o0000ooooooooool0;_ooool4oj6nkP;oX<;a0onWa>h2ojW8l0;o[/C[0on`aNX0
0on^_NCo[[WRojjihP02ojjihPCo[KCN0_nY[MX00onQZmkoVjKMoi^Vg@02oi^Vg@?oTj7N1?n?XN42
ohVVj0?oUM;m00?oVn[jokkbl_nnl_801?o7ind00onmd>So]/;SokK2h`03okK2h`?oYJkN0on<UmT3
ogN6e@;oGW_G1?m]U^P00onMdo_o`?kNol3ngP02omSkg@;oe>[T0onkb>D3ojB[g0?oQ93H0_mAM=L0
1?l0B<So0cRjoa5Fd?lAE]03ofM_a`;oc;_:0_o^m<D2onKQcPCogLO300?odkJlokb]b_ngX<400_mn
RM@3ogaY/PCoVGBX1?nZP:H01OnZQZkoeZnaomJ_/OoF[k7om=6[00;oo>6P00?onnNMooWT[_oii:h0
0oo^fK`4olnb_PCoZiK01?n>Pl<2ofeaaP;oCFC90_ldH<l00olJD/coCG_NodekgP04oiVUgP03okZa
dOni]]Ko^KKF00;o^KKF00?oakS<olVod?o9_m000_o9_m001Oo?_l_odLC>om74c_oAa<kod/[B00?o
d<K@0_oAb]<00oo=aM?oc<OFolc7eP02olc7eP05ol[:fOo3`m[o`l?Jol?3f_o1a=`01Onk_]`01?nc
^Mgo/[WNok:ig_nb^Mh4ojfeg`?oZ;?P1OnU/^42oj>bh`;oYK;R1?nS/n<2oj>di@05o`000?nS]>Go
XkKVoj>fi_nT]^D01OnT^>L2ojBjj003ojJjj?nV_>WoY[cY00?oY[cY0_nV_^X00ooooooo0000oooo
o`0>ooooo`00=Oooool2o`0002oooooo0_nQ_^h3ojJok0;oYlC^0_n/`nX4ojk4j`04ok35j_n^_NCo
[[gTojjmi0Co[[WR0_n]]=h2ojF`h0?oXJ_N1?nKY]d3oi>QgP;oSj7Q0onC_oD2oiGBo@;o/^Oh0oo0
jO800oo7ingo_M3Xokg@j002okg@j0;o]/;S0_nS[]l3oiBPg0?oOY?M1?mbTn<2ofVTl`;oKIKX0_n;
g?h2okWfl@;ob?G]00?o`mc/ok_8iOnkb>D00_nkb>D4ojB[g0?oQ93H0_mAM=L01?l0B<So0cRjoa5F
d?lAE]03ofM_a`05olbkb_oOh]Kohlo3on??`ooP`k/00ooMal<2om>f_0?o]j3100CoOXWDogaY/_ml
JK;oO6Vb1?nIM:P4ojZ0YPCoeZna00?om=6[oocQX?olhJ000ooii:h3onkI_003om_4`_o?/[kock:n
00;o`ZNo1?n[U/03ohj3``?oKG760_m=I<T3ocAPc`;oCG_N0onDY^44okVfeP03okZkf_o9_m3obKo@
00;obKo@00CoblGEom74c_oAa<kodLC>0ooBb]801Oo@a]3odL[Com7:dooAb]?od<gG00?oc<OF0oo:
b]T01?o3`m[o`LCLol74g?o1a=`3ok^ng003okVog_nb^Mko/[WN00;o/[WN0_n]]Ml2ojffg`CoZ;?P
0_nU/^42ojJbh@GoYK;R0_nS/n<01OnU/n?oYKGTojFei?l0003oYKGT00CoY;KU0_nT^>L2ojJiiPCo
Y[[X0_nV_>T6ooooo`03o`000?oooooooooo00cooooo000gooooo`03o`000?oooooooooo02kooooo
0_nV_n`2oj_1jPCo[<?Z0_n^a>/2ojjoiPCo[[gT0_n^^N82ojRehPCoYK3P0onQZmh2oi^Vg@;oV;3X
1?nC/nd2oi>om@?oY]Si00Co/^Ohol3Yl_o0jO;o`>Wb0oo0f>`2okg@j0;o/;cR1?nS[]l3oiBPg0?o
OY?M1?mbTn<3ofVTl`04oh_Lo_nim_7o^OKaolSek@Co`mc/0_nkb>D00onQZ]goTiODoi>Ge002oi>G
e0?oQ8kE0omaT^<00ol0B<So4EK@oa5Fd002oa5Fd003ohK9o_oOh]Kogn;F00;ohlo30_oP`k/01OoM
al?odkJlom>f_?oC][coc:bi00;o]j3100CoZBX0ogj9e?mlJK;oO6Vb1?nIM:P4ojZ0YP04olbT[ooF
[k7oeZnaooCAZ`;oo>6P00?onnNMooWT[_oii:h00oo^fK`2om_4`P04olnb__o2Ykoo`ZNool:W_`Co
ZiK01?n>Pl<2ofeaaP?oCFC90_ldH<l3oeN0g`?oU:KQ00?o^KKFokZkf_nj^mX00_nj^mX2olVod0?o
blGE00?odLC>om;:d_oBb]800_oBb]83om7:d`?od<gG00Goc<OFol[:fOo:b]Wob/[IolO<g@04ol74
g003ok^ng?ni_mko^KoN00;o^KoN0_nb^Mh2ok6jh0Co[KKO0_nX/n02ojVch0CoY[;Q0_nU/^82ojJc
hPCoYK?S0_nU]N@01?l0003oYKGTojBfiOnT]^D2ojJgi@CoY[WV0_nV^^P9ooooo`03o`000?oooooo
oooo00cooooo000hooooo`03o`000?oooooooooo02kooooo1?n[`NX2ojc3jP;o[/3X1?n^_nH2ojjm
i0;oZ[WT1?nX]N82ojF`h0;oX;7T0onL[nD4oiR`j0;oTk?]0onNb_H2ojKHn@;o/nCg0_nkf_03ol3H
k0;o]lKV1?n`_>83oj>^g`?oU:3L0omnTmd2og:Ch`?oQKWg0_nIf?d2okG^mP?o`NK`0_o3g>`2ok71
iP?oXJ[M1?nCUm@3ohB>e@CoLI;S00?o=:;cokWWmOoOh]H00_oOh]H2on??``?oh<>k0ooC][`2olb/
^@?o]j3100CoZBX0ogaY/_mlJK;oO6Vb0onIM:P3ojZ0YP;oc:B_0_oF[k401?oddJ_oo>6PoocQX?ok
iid2ooWT[P;ok]Vl0ooKa<85ol:W_`;oZiK000?oYiC2oi66a?nAQ/@00_nAQ/@3ogQjb0;oCFC90_m=
K]@00oldH<ooEh3OoeN0g`04oiBYi0Co^[_J00?obKo@ol_5eOo;aMD00_o;aMD01?o<c=Wod/[Bom;:
d_oBb]82om;?eP03om7:doo@cMOod<gG00;od<gG0oo:b]T3olO<g@;o`LCL0_nnaMl3okVogP03okJo
hOna^^3o/K[P00?o/K[P0_n]]]l2ojbfh0CoZK?P0_nV/^42ojNch@CoY[?R0_nU/n<01OnV]>;oY[KT
ojJfi?nV]^Co000000GoY[OU0_nV^NH<ooooo`03o`000?oooooooooo00cooooo000iooooo`03o`00
0?oooooooooo02kooooo0_n[`NX2ojg1j@Co[/3X0_n^_nH2oj^liPCoZ[WT0_nX]N82ojBdi@CoX;7T
0onL[nD2oiR`j0?oWL7b0_nNb_H3oj_Jn003ok?Tmonkf_3o^m[`00;o^m[`00?o`=S/okO6i_nga^H0
0_nga^H2ok2lhP;oYKCT0onG[>D3ohbWi`CoPJO]0_n5^OL3oicKo@04okG^m_o1i_3o`NK`ol7Vl0;o
^MG^1?na`NH3oj6Zg@?oTiOD1?n4S]D2og6Bh`;oYkCR0_o7`MD01?oOh]Kohlo3on??`ooScl<3on33
^`03om^i]ooC][coc:bi00?oc:bi00?o]j31okBJ__ndV[h00omlJK84oiUdZ0;oZX2V0oo<Y:l01?oF
[k7om=6[oocQX?olhJ02on[gZ003ongcaoo^fKcoflC200?oflC200?obk?3ol:W_oo2Ykl00_o2Ykl4
ojND`P?oTHK40omhN/P2of5cc`03odeTbOm=K]CoCFkD00?oEh3O1?nDZN@2okZkfP;o^/7O0oo;aMD3
olc<f@05om;:d_oBcmKod/oFom;?e_oAdm/00oo@cML2olk@f`05ol[:fOo7c=goalcMolO<gOo4cN40
1OnnaMl01?ni_mko][oQokJohOnf_n42ok6jh0;o[k[Q1On/]^02ojVch003ojRdhOnW/n7oYk?Q00?o
Yk?Q0_nV/n800onW/n;oY[CRojJdhP02ojJdhP?oY[KT00?o0000ojJgiOnV]nD04?ooool00ol0003o
ooooooooo`0<ooooo`00>_ooool2o`0002oooooo1?n]`NT2ojk0j0;o[;oW1?n[_>H2ojZii0;oY[SU
1?nT]>D2oj2ai0;oWk[[1?nL^nh2oig1lP?oYM3g0_n[f_P3okKHlP;o^m[`0onhcNT2okO6iP;o[[cT
1?nU]>@3oiN/i@?oS:OW0_n1Ynd3ohk4nP;oW=_m0on_hoP00oo1i_3o^MG^okWEkP02okWEkP;o/L7V
00CoVjSOohnGeon?UmOoSiOG0on@Tm84oiRJe0?oYkCR0oo7`MD00ooC`<Oohlo3on??``03on33^`;o
fkVg00?odkJlolb/^Oo<[;T00_o<[;T3okBJ_P03ojTZ0?mlJK;oO6Vb00CoVGBX00?oZX2VolbT[oo<
Y:l00_o<Y:l01?oae;;oo>6PooO_X?oMk8L2on[gZ003ongcaooLeM7oflC200;oflC20_o;/l<3ol:W
_`;o^J710onWU<84oi66a0?oN7[80_mQLll3ode^e0;oIHWQ00?oEh3OoiBYi?nDZN@00_nH[nL4ok[1
g`05ol_5eOo<c=Woc<cIolc<fOo=dMd00ooBcmH3om7Cf`03om3=eoo>d=_oc]3K00?obm?P00CoalcM
olC=hOo4cN7oa<gQ0_nnaMl2ok_6hP?o][oQ0_nc_n<4ojnjh@;o[;KP0_n[]^44ojRdh@CoYk?Q1?nW
/n84ojJdhP;oY[KT00?o0000ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`00??ooool0
0ol0003oooooooooo`0]ooooo`;o[L7Y0_n/`NT4ojboi`;oZkcV0_nX^nL4ojJhi@;oY;CU0_nQ^NX4
oinjj`;oW;_^0_nQb?@3ojG@m`?o[m?c0_nff?83okO@k0;o^<gY0_nb`^H4ojjli0;oYKCT0_nP]NL3
oiBck0CoSkSb0_n>a?X3oj7Hn`;o[n?h0onbgoH2okWEkP;oY[kZ0onKZ=l3ohnGe`?oT9?B1?nHV]@0
0onW]>;oal7EolO1e@02olO1e@;odl3700?ohlo3on33^ooP`k/00ooK^KL5olb/^@06olNW^OndV[ko
]9ZnokBJ__l0:k?oO6Vb1?nIM:P00onZP:Koc:B_olbT[`02olbT[`03oo7D/_ogkj3omnnP00;oj_NX
00GokO?7omcEdOoLeM7og=GAom_4`P04ol^c``04ol:W_oniXL7o^J71okVQ`@?oYiC21?nAQ/@3ogQj
b0;oHG??0omQO]T00om=K]CoIHWQofF9h@05oiR_i`;o^/7O0_nlan<00oo<c=WocM7MolgAg@02olgA
g@04om;?e_oAdm_odM?Kom7Cf`;ocmOO00?oc]3Kol_Ch?o;dn000_o;dn03olC=h@;o_lgU1?nka^80
0onf_n7o/koSok>oh`02ok>oh`;o[k[Q0_n]^N84oj^fh@CoZ;CQ1?nW/n43ojNchP;oY[CR1Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo000mooooo`03o`000?oooooooooo
02gooooo1?n/`NT2ojboi`;oZKkY1?nX^nL2ojJhi@;oXk[Z1?nQ^NX2oinjj`;oXL?a1?nQb?@01?nU
d?Oo[m?cojoClon_do<2ok??k`?o]m3/0_nda^P4ok;2iP;o[[cT0_nX^>D4oj2ei`?oU;?/0_n?^?83
oi[<n@;oXMSk0onZgoX2ok;OmP;oZ/kc1?nV_^X3oi^Xg`;oSiOG1?n@Tm82oiRJe0;o[ZOA0oo7`MD3
om?0a`;of;g000Goh<>kom^i]ooK^KOofkVgomJd]`03olb/^@;oajNi0ondV[h01?nbV;go02^coiUd
Z?nIM:P2oj6=_`Coc:B_0_oae;801?ogkj3oj_NXon[gZ?o]llL3omcEd@03olVlc_o;/l?obk?300?o
bk?31?niXL44ojND`P;oTHK400GoUHc8oh:5cOn2QLgoPXG=ogQjb002of5cc`?oHGkI0omdUnD2oiR_
i`;oWKKZ0onlan<2okg>i`?ocM7M0oo<e^400ooAdm_ocmOOoloGg`02olcJi0?obm?P0_o7eN@00oo4
cN7o_lgUoko=i@02oko=i@;o^lKR0ongaND2ok>oh`03ok2niOn]^N;o[KWR00?o[KWR0_n[]^400onY
]^;oZ;CQojRdh@03ojRdh@?oYk?Q0_nW/n89ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03?ooool003kooooo00?o0000ooooooooool0;Oooool2ojc1j@?oZL3Z0onY_^T2ojRki`;o
Y;cZ1?nS^^X2oj6ijP;oXL3_1?nQ`o42oj78m0?oZLgc00?o[m?cok??konccnl00_nccnl00ongd>co
]<KXokC6j002okC6j0;o//;V0_n]_>D4ojRhi@;oX;GW0_nR_nh4oi[3m0;oV/ci0onTfOX2oj[OnP?o
ZmSg0onZc_<2ojJnjP04oi6Xi_n:V=_oRYSKohZHf`?oQhoD0_n@Tm800onGU]7o[ZOAojjWd@03ojjW
d@03olO1eOoC`<Oodl3700;odl370_oH_L03om^i]`?oe[Bg00?oc:biolNW^Oo7YkT00_o7YkT01?nd
V[ko/YRmok:H_Ol0:k<4oj6=_`Coc:B_00ColMBbooO_X?ogkj3oGmKK0onUc_H01?oLeM7obKc>olVl
c_o9_<h3ol^c``;o_j[41?niXL42ojND`P03ojJFaOnES<SoUHc800;oUHc80on2QLd3og:2e0?oHGkI
0omdUnD4oiffjP03okc7honmc^Oo_LkW00;o_LkW00CocM7MolcFhOo<e^7oc=KQ0_o;fnD00oo?emoo
c=[TolcJi002olcJi003ol_Ch?o7eNCoamGT00;o`]KY0onocND00onjcNSo]lGUokO5i@02okO5i@03
ok;5j?n`_^Go/;kU00;o/;kU0_n]^N82oj^ii0CoZKKR0_nX]>4@ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03?ooool003oooooo0_l0000_ooooo`;oZL3Z0_nV_n`4ojFnj`?oY;cZ
0_nS^^X3oj:ok@?oXL3_0_nQ`o43ojK8lP;oZLgc0on_cO02ok??k`?o//SZ0_nda^P2ok2oiPCo[KcU
0_nX^>D2ojJmjPCoX[o^0_nJ`o@3oj?An0;oY=Wj0onZf_P2oj_Hm`04oj;<m_nJ^o3oV[_`oiZkl0Co
TJSV0on:V=/2ohN?e0CoUiKA0on^Ym42okj`c0?odl370ooH_L000ooG^[cofkVgomJd]`03omJd]`Go
ajNi1?nbV;d00ol0:k?oXHfooj6=_`02oj6=_`;oc:B_0_oae;800oogkj3o97CRobAdhP02ojG>mP03
ojNbh?o9_<kobKc>00?obKc>00Cobk?3oknZa?noZ/Co_j[40oniXL400ondX<CoYYK5ojJFa@02ojJF
a@?oUHc81?n2QLd2og:2e0?oLhkO1?mdUnD2oiffjP;oXko]0onmc^L2okoDjP03olcFhOo;fnGobm_U
00;obm_U1?o<f^@2olSLj003olOEi?o2e^Wo`]KY00;o`]KY00Go_lgUok[=j?njcNSo^/gXokO5i@04
ok;5j0;o/;kU0_n/_NH4oj^ii0;oZKKR5?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00_ooooo0011ooooo`03o`000?oooooooooo02gooooo1?nV_n`2ojFnj`KoXkk]0_nR_nd2ojC2
k`CoY<G`0_nVb?83oj_:l0;o[lg`0_n`b>`3ok;8jP;o/<;W1?n`_nH2ojfli@;oZ[kX1?nV_NX2oj:o
kP?oYl_b0_nSdOP2oj_Hm`;oZ][h0onXe_L3oj;<mP?oV[_`0onAZ>H3ohZHf`?oQhoD1?nGU]400on^
Ym7o_[3<okj`c002okj`c004om?0aooH_L3of;g0omRm`0;oekZl00?ofkVgomJd]ooF];L00_oF];L0
0ooB/;SoajNiolNW^@02olNW^@Co/YRm00?oV8W2oj6=_onQSKl00_nQSKl00oo<Y:oolMBboo7D/P02
ooO_X0;oKX[M1?nW/^03olVlcP03okb^c?noZ/Co_j[400?o_j[400?o^J71okBPa?ndX<@01?nVU/D4
oiF<b0?oPXG=0ombP]@3og>>g`?oPZCZ1OnS_nd00onmc^Oo_mCZokoDjP02okoJk@?obm_U0_o8gnX0
1?o<f^Cob=cXolSLj?o8g>P2ol;Nk@;o`]KY0onle^d2ok[=j0?o]<g/0_nbaNP00on]a>[o[;gVojbm
iP03ojbmiP;oZkWT6?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0012
ooooo`03o`000?oooooooooo02gooooo0_nV_n`2ojBok0KoXkk]0_nS`Nh4ojC2k`;oY<G`0onXao02
oj_:l0;o[LO]1?n`b>`00onbb>[o/<;Wok32i`02ok32i`;o/;oV0_n]_nL4ojZnj0;oY[gZ0onYa^h2
ojO;lP;o[MCd0_n[f?L3ojkImP;oZ=Kg0_nQboD3oi:ll`?oQJW/0_mjUn<3ogb?fP04ohZHfon7SmCo
QhoDohN?e0;oUiKA00?oXIkAokj`c?nn/<`00onn/<`3omRm`0?oekZl1?oF];L2om:`^0?oajNi0_o3
Y;/4ok:H_@CoXHfo00Goc:B_oo7D/_oae;;omnnPof=fd003ofj:g@CoYk;P00CobKc>okb^c?nl[/co
_:k<0onoZ/@00onhY/Oo]:34okBPa002okBPa0CoYYK50_nES<P01?nJU/ooRi;Eoh^BeOn;T]D3oh2C
g@04og:2e?mcS]ooLhkOog>>g`?oPZCZ0_nS_nd3ojW9l003okoDj_nof^go_m[]00;o_m[]00?obm_U
olSOj_o8gnX00oo4h^h00oo8g>So`]k]ol;Nk@02ok_Nl@?o_=K]00?o]MGaokC=k?ndcN`00_ndcN`0
0on^bnoo[LCZojg4jP02ojg4jP;o[;gV7Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo0013ooooo`03o`000?oooooooooo02gooooo1?nT_n`2oj>nk@;oXko]1?nS`Nh2ojC2
k`;oY/C_0onXao02oj_6k@Co[LO]0_n`b>`3ok34j@;o/<;W0_n^`>L4ojfoi`;oZ[kX0_n[`n/2ojW6
kP?o[loa0_n]e?@3ok7Im0;o[]Wf0on/do@3oj7;m@?oT[cc0on5ZN`2ogZGh`?oO8oJ0on5SmD4oj6N
d@?o_[3<0_o7]<P00ooH_L3oekZlomNj_002omNj_003omJh_?oF];Ooe[Bg00Cod[2h00CoajNiol>T
^oo3Y;_o`jBk0onbV;d01?naV[ooWHg2oj6=_onQSKl3oi_Lo@03oo7D/_mnPlkoOX?>00?oQXoE0_nW
/^02ojJUe@Co_:k<00?o_j[4okRVaonhY/L00_nhY/L3okBPa0;oYYK50_nWWL`4oiZFc`?oRi;E0on0
Tmd3oh:Pi`GoSk?_0_nYbO02ojkBl`;o_m[]0onnh?001?o8gn[oa>;^olCRk_o4h^h2okkTlP03ol;N
kOnkg_7o^mka00;o^mka00Go_=K]okGElOneeO7o]MGaokC=k004ojk;k`;o[LCZ8?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0014ooooo`03o`000?oooooooooo02gooooo
0_nT_n`2ojBok@CoXko]0_nS`Nh3ojG2kP?oY/C_00?oZ<O`oj_6kOn[a^d00_n[a^d2ojg7k@?o[/CZ
0_n`a>T2ojk1j0Co[/3W0_n]_nL01?n/`NWoZl?[oj_3jon[`n/2ojk;k`?o[loa0onceO82ok7Im0?o
/mOc0_n/do@2ojO<l`?oUkoc0on1[?02og6Ij@?oIh[Q0omlSmX3ohF?e@CoXIkA00Co_[3<olNdb?o7
]<SoakC81?oG^[`3omJh_003omJd]ooB/;Sod[2h00;od[2h1?o3Y;/01?nbV;go/IZook6J_onaV[l3
oif=`P;oVmcm0_n5PLL3ogj3cP;oQXoE1OnVYMD2okb^c003okFXc?nhY/Oo^:K700?o^:K70_ndX<@0
0onbY<_oYig<ojNMc003ojNMc0?oVYK?1?n;T]D3oh2Cg@?oPZ3W0_n?/nl2oiW2m0?o[];c0on`foH2
okkPl0;o^nCc00Coa>;^okkTl_nni?;o_^Cb0_ngiOH2ok_Nl@?o/mkf0_neeO43ojgCm0;o[/__9?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0015ooooo`;o0000;oooool3
ojBok@;oXko]0onU`Nd2ojG2kP;oYl;]1?nYa>d2oj_6k@;o[<?[0on^a>X2ojg1j@Co[/7X0_n^`>L0
0on]`NSo[<7Yojc1j@02ojc1j@03oj_3jon^bnoo[/__00;o[/__00Co[loaok?El_nceO;o/mGb0ong
eo42ok?Gl`;o/M;a1?nWc?<3oiNol`?oPJc`0_maVNT2ofN:h@?oLX[K0on5SmD2oj6Nd@;oZZKB1?o7
]<P00oo<]lKoekZlomNj_004omJh_0God[2h1?o3Y;/5ok6J_`?oWHg21?n5PLL2ogj3cP?oQXoE1?nV
YMD01?nl[/co]JS<okFXc?neZ<`3okRVa`03okFYcOnbY<_o/ZC;00;o/ZC;1?nWWL`2oiZFc`03oinS
f?nDX]koU:;N00;oU:;N1?n<YNH4ohjakP?oVL;d00Co[];cok3Km_n`foKo/=_f0_n_h_P2ok_Tl`;o
]^Of0_n^jOT2okOUmP?o[^Ci0_ncg_H2ojWLn@;o[M?d:Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00_ooooo0017ooooo`03o`000?oooooooooo02gooooo1?nU_n`2ojG1k@;oYl7/
1?nW`^d2ojW4k@;oZ/?[1?n/`n/00on^a>[o[L7Yojg1j@02ojg1j@;o[/7X1On]`NP2ojc1j@?o[/O/
0_n^bnl3ok;Al004ok?El_ngeo7o]mOaokOGl@;o]mG_1?nad_42ojO<l`;oWl;a0on;/o43ofnNk@;o
GXgW0_mWR^42og::f`?oQi;H1OnZY]82olNdb0?oc;O600?oekZlomJh_?oF^;`00_oF^;`01?oC]kko
d[2hom:`^?oB/;P2olj_^`;o`jBk0_o0YKh4ok6J_`;oWHg200?oX9;6ohn9bOn?RLT00_n?RLT3oh^;
cP?oQXoE0_nVYMD00onVXM7o]JS<okFXc003okFXc004okRVaoneZLgo]JW=okFYc@Co/ZC;0_nWWL`0
0onYYmCoWj?HoinSf002oinSf0CoU:;N1?n<YNH2ohjakP03oiO3m_nOd?SoWm3h00?oWm3h00?o/=_f
ojoRn?n_h_P00on[ioX00onfioKo[^WiojkYn@03ojGXn`;o[^Ci0_nTh_`2ojWLnBcooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`00B?ooool00ol0003oooooooooo`0]oooo
o`;oYKo/0_nV_n`4ojO1k0;oYl;]0_nY`^`4oj[3j`;o[<?[0on/`^T2ojg1j@Oo[L7X0on^aN/2ojk7
k0?o/Lg^0_nbdO03okKDk`03okOGlOngeNoo]mG_00;o]mG_0_nad_43ojg;k`?oWl;a0on;/o43ofnN
k@04oej=iomEP^7oEH;QoeF2h@;oLX[K0on7T]P4ojZVdP03olNdb?o<]lKoc;O600;oc;O600Coc[W6
omJh_?oF^;coe[Rl0ooC]kh01OoB/;SocZnkolj_^oo>[k_o`jBk00?o`:Fn0onaV[l00on`WLCoX9;6
oj2BaP02oj2BaP?oShW90on;Rlh3oi:CdPCoYZ7A0oneZ<`00onbZm7o]JW=okFYc@02okFYc@?o/ZC;
00?o/ZcCojVWe?nYYm@00_nYYm@4oinSf0;oU:;N0_nK]>X4oiFil0?oUl?f0_nOd?P2oj;Kn`;oX>?l
0_n[ioX3ojCYnP03ojkYnOnUj?_oYNSk00?oVnKl0_nTh_``ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02oooool004Wooooo00?o0000ooooooooool0;Oooool4ojJok0;oYl7/0_nX
`N/4ojW2k0;oZ/?[0on[`NX2ojc2j@03ojc1jOn]`NSo[L7X00Co[L7X0on]`nX2ojk5j`;o/<W/0ona
cNh3okGAkP;o]]C_0onhe>h2okOEk`?o]]3]0_n]bnl01?nXa>goUkW_oiNikonG^Nl3ognYk`?oHIC[
0_m?QND2oeF2h@?oJH[O0on7T]P2ojZVdP;o/JgD0oo<]lH3oljiaP03omJh_?oC]kkodkNn00;odkNn
1?o>[k/5ol2U_P04ok6J_on`WLCo/9g4ok2Ma0?oX9;61?n?RLT3oh^;cP?oTY?B1?nVXM401?neZ<co
/Z_Aok:[dOnbZm44okFYc@04ok:Tbonb[=?o/ZcCok:/d`CoZJOD0_nOXmP2ojBdi0CoVkCZ0_nE^O00
0onJboWoW=?koicCn`03oicCn`03oj;KnonPhocoX>?l00?oV^Ok0_nTjOX01?nKjO[oTNOjoi7Wn_nA
ioX2oi_Vo3Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00B_ooool2
o`0002kooooo0_nV_n`2ojO0j`CoZ<7[0_nY`^`3oj[1jP;oZl7Z00?oZl3Yojc1jOn/`NT00_n/`NT2
ojg1j0;o[L;Y0on]`nX2ojo6j`Co/<W/00Co/Lg^okGAk_nedNko]M7^0onhd^d2okSDkP;o^M7/0_nf
d>d2ok?:j`CoZ<C]0onG^Nl3ognYk`?oHIC[0_m?QND2oeF2h@;oJH[O0on:V]d5ok6]e003olbga_o>
^LKoc[W600;oc[W61?oC]kh2om2g`P;ocZnk0_o:/<43ol2U_P03okfXa?n`WLCo/9g400;o/9g41?nP
T/H3ohn9b@?oRh_>1?nBTm82ojJQd@03ojJVeOnbZm7o/Z_A00?o/Z_A0_neZLd00onc/=Go/ZcCok:/
d`03ok:/d`;oZJOD00?o[;OQojBdi?nT]>@00onT]>@2oi^djP;oWlSd0onJboT2oicCn`;oV]om0onD
iO`2oi[Wn`03oi7XnOn8i_OoR>Kg00;oTNOj>Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00[ooooo001<ooooo`03o`000?oooooooooo02cooooo1?nW`>/2ojS1j`?oZL7[0_nZ`NX0
0onZ`>[oZl3Yoj_0j@02oj_0j@Co[<7Y1?n]`^T00on]`n[o[lK[ojo6j`02ojo6j`;o/<W/0onccNd0
1OnedNko^=;]okSBkOnhd^go^]7[00?o^M7/0_nhcNX4ok?:j`;oZ<C]0_nS_>/3ohnak@?oMj;]0_mF
SNT2odn5i@?oB7gR0_mYR]l3ohZJg@?o/JgD0_nf/mL3oljiaP;oc[_90_oC]kh3om2g`P03olj_^oo:
/<7ob[3100;ob[3100Co`:FnokfXa?nmZ<Co_JS41?n`WL@2oj2BaP04oj:JcOnEU=3oUIC@oiFDd0?o
TYGC1?nHW=H4ojJVe@;o/Z_A0_na/MP4ok>`e@;o/ZcC0_nc^n04ojbgh@;oY;CT0onVao42oio8m0?o
WM[l0_nIfoh2oi7So0;oU>Gl0_n:i_P2oh7Tm@;oR>Kg??ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00[ooooo001=ooooo`03o`000?oooooooooo02cooooo0_nW`>/3ojS0j`;oZL7[
00?oZL3Zoj[0j_nZ`>X00_nZ`>X2oj_0j@;oZl7Z1?n/`NT2ojg2j@?o[/C[0_n_a^/3ok;:k0;o/lg]
0ongcn`01Onhd^go^]7[ok[AjonjdN_o^M7/00Co^<gZ0_ncb^/3ojo3j@?oXkc[0on?/Nd3ogNRk@;o
EXgY0_m3PND2odQmhP?oHhcT0on:V]d00ona[MCo][?GokJce`02okJce`05oljia_o>^lWoc[_9oljk
bOoC]kh01?o@]l85olZ``@Go_JS40_n`WL@00on_Y<coXY[=oj:Jc@02oj:Jc@?oUIC@0onBUM<4oiRL
eP;oYZKE00?oYjgLok6af?na/MP00ona/MP2ok>`e@;o/kkR1?nc^n02ojbgh@?o[LW^0_nVao42oj;J
n`;oWM[l0onChod2oi7So003ohKUmomlho;oO>?b04?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0:ooooo`00C_ooool00ol0003oooooooooo`0]ooooo`?oZ<3[1?nY`>X2oj[0jP;o
Z/7Z1?n[`NX2ojc1j@?o[<?Z0_n^a>/3ojo7k0;o//[/0ondc>`2okO?k0;o^Lo[0_njdN/3ok[>j@;o
^<gZ0onfanL2ojo3j@;oZkgW0onN]^T3ohZ[k0?oLIg/0_mARnT2od>1i@;o?GcT0_mSS>@4ohbQhP?o
][?G00?o]kWKoljkbOo>^lT00_o>^lT01?o<_/kod;O2om2g`_o@]l82olfjb0?ob[310_o6/lL3okfX
a003ok^^cOn_Y<co[jC<00;o[jC<1?nRV/d3oiFDd0?oTYGC0_nHW=H00onLY]goYjgLojN]g002ojN]
g0Co/K7H00?o/k3Eok>nh_nc_^800_nc_^82ok>kh0?o//g^0_n]bNh2ojOMnP;oX][k0onFiO`2oi?S
o@03ohGUm_mhh^ooN>;_04Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:oooo
o`00Coooool2o`0002kooooo0onX`>/2ojW0jP;oZL3[1?nZ`NX2oj_1jP?oZl;Z0_n/`nX2ojk5j`?o
[lO/0_nbbN`3okC<k004okO=jonicn_o^Lo[okW?j`;o^/gY0onjc^T2okW9iP?o]/OW0_nc`^D4oj^m
i`?oW[KY0on:Zn`3og6Mk0;oDH_Y0_lmP>H2oceli0;oG93Y1?n<XN801?nf/mOo]kWKokNifong^M/2
oljkb@?oc;k>00?od;O2olfjb?o=^/P00_o=^/P00oo:/<7oa[?7olJca`02olJca`04okfXa?nk[/go
^jk=ok^^c@?o[jC<0_nRV/d2oj>Ue`?oVIoI1?nGXM/3oibVg@CoYjgL0_na/MP3ok2oi@;o/kkR00?o
/Lo`ok;=k_nbcNh00_nbcNh2oj[PnP;oYmgj0onHio/2oiKUo003ohCUmOmdh>cooooo04_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`00DOooool00ol0003oooooooooo`0/
ooooo`?oZ<3[1?nY`>/2oj[1jP?oZ/7[0_n[`^X2ojc3j`Co[/G[00?o[lO/ok;9k?nbbN`00_nbbN`0
1Ondc>co]lg[okO=jongcN_o^Lo[00Co^/gY00?o^/kYokW9i_nibNH00_nibNH00onfanOo/l;Uok?2
i@02ok?2i@;oZkgW00CoZ;WUoi^bj?nK/^SoVk;X0on7Z>/3ofnLk0?oChcZ0_lmP>H2ocMoiP;oG93Y
0on=ZNT4okNif`03oljkbOo<_/koc;k>00;oc;k>1Oo=^/P5olJca`Co^jk=0_n_Y<`00on^[MKoXjGG
oj>Ue`03oj>Ue`?oVIoI1?nGXM/3oibVg@;oYjgL0_nW_NT3ok2oi@03ojg@l_naco3o/Lo`00;o/Lo`
00Co//g^oj[Pn_nZh?[oZ^3j0_nGjOX2oiSWn`;oP^Gb00?oK]kVooooooooool0COooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00[ooooo001Booooo`03o`000?oooooooooo02_ooooo
1?nX`>/2ojW0j`?oZL7[0_nZ`N/2oj[2j`Co[<?[0_n^aN/3ojo7j`;o//W/0ondb^/01?ngcN_o^LcY
okW<jOnic>T2ok[=j@?o^/[V0_nibNH3okS5i0;o/l;U00?o/;gSojRiiOnX^ND00_nX^ND3oi^bj0?o
QjS[0om_W>`2odn<jP?o>h?X0_lgOnH2oeNEkP?oSJWY0_ng^M/2okFnh@?oc;k>0_o8`]D3olfjb0;o
b;k@0oo6/lL2ol>jd@;o^jk=00?o]kOHojj]e_n^[MH00_n^[MH4oj>Ue`?oVIoI0_nGXM/2oiVbj@?o
WKOZ1OnW_NT01?n`_nGo[M3bojg@l_n]d?82ok7?l0;oYn;k0_nAj?P2oiOYnP;oONG^00?oI][Ooooo
ooooool0DOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo001Cooooo`03
o`000?oooooooooo02_ooooo1OnX`>/4ojW1j`CoZ/;[0_n/`n/3ojg5j`;o[lO[0onab>/2okC:j`;o
]/[Y0_nic>T3okW:i`;o^/[V0onia^D2okS5i003okG1hon`_N?o/;gS00;o/;gS0_nX^ND2ojFei0?o
VJoW0on6Y^X3ofnLk0;oDXo/0_lkPnP3ocF4j@;oEiG^0on:/>l4okFnh@03olbnc_o8`]Gob<;E00;o
b<;E00?ocK[8olRnd?o8_]000_o8_]001Oo6/lOo`k[Aol>jdOo3^]7o^jk=00?o]kOH1?n^[MH2oj>U
e`;oXkCU0onJ/>L4oiVbj@?oWKOZ0_nW_NT3ojC>mP;o[M3b0onQh_`00onWh__oTNShoi7Xn002ogGR
j@03oegFf?oooooooooo05Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09oooo
o`00E?ooool2o`0002gooooo0_nX`>/2ojW0j`CoZL7[0_nZ`^/3oj_3j`;o[LG[0_n_a^/3ok78j`04
ok?8j_nfb^Wo]/[YokK:j@;o]lWX0onib^L2okW7i@?o^LKU00?o]l?SokG1hone`N<00_ne`N<2ok2m
h`;o[[[R1?nU]N@3oiV_i`?oQZKZ0om_W>`2oe:?k0;o?XW/0_leQ>T3oe>JlP?oR[3_0_ne_^42ok73
j0?ob<;E00?o`lOMolRnd?o8_]000_o8_]001?o3a=_o`k[Aol>jdOo3^]42okg2g@Co]kOH0_n^[MH2
oj^ki@CoXkCU0onJ/>L2oiVbj@?oUlCf0onKbOL2ojC>mP?oUmon0_nQh_`01?n9i_OoK=gUoeKAd_mF
dM9Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool005Kooooo00?o0000
ooooooooool0:oooool4ojW0j`;oZL7[0onZ`^/2oj_3j`;o[LC[1?n_a^/01Onab>_o/lSZok?8j_nc
b>[o]/[Y00Co]lWX00?o^L[WokW7iOnianD00_nianD01?nia^Go]l?SokO3hong`n<2okG1h`;o/kgQ
1?n^^^82ojFei0;oXk;S0onH[NH3ohJVj@?oLYo]0_mHUNh2ocj9k0;o=h_]0_mCV_84ohJfm0Co/L?X
00Gob<;Eol?7gOo3amgo`lOMolRnd004ol?4f`03ol>jdOnm`]go_L;M00;o_L;M0_ng]mP2ok?3iPCo
Zk_U0_nS]>D00onNaO?oV<;eoiS2m@03oiS2m@;oUlCf0_n;e_l2ohkJo`?oNMkg0_moh_H00omUfN?o
DLkAoe7>d@1Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool005Oooooo
00?o0000ooooooooool0:oooool2ojW0j`?oZ/3Z0_nZ`^/2ojc2jPCo[LC[0_n_a^/2ok36jP;o/lSZ
0oneanP2okO9j0?o]lOV0_nianD2okS4h`?o]l?S00?o][oQok>mhOnc_N400_nc_N42ojjjhP;oZkOQ
1?nS/^<3oiR]iP?oQZKY0ombWnd2oeREkP;oAY7_0_lgRnd2oe2Om@CoQ[Kd0_na`nP2oj[8k`;o`lOM
0onkcNL2ol?4f`;o_<_V0onm`]d00onfcN_o/l?Vok?3iP03ok?3iP;oZk_U0_nUb_<3oik5l`;oV<;e
0on=e?l2oh_Fo`?oN=ci0_mig_L00omQenCoooooooooo`1Rooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool02Oooool005Sooooo00?o0000ooooooooool0;?ooool2oj[0jP;oZl7Y1?n/
`^X2ojg4j`;o[/CZ0_n`a^X2ok;6j@?o]LOX0_nfa^L3okO7iP;o]lCT1?nha><01?ng`n?o][oQokJo
hOnf_n42ok>mh@;o/K[Q1?n[]n42oj>bh`04oj:ahonH[NKoV:gVoiR]iP?oRJSY0omgX^d3of6Ll0?o
AY7_00Co?I?aoe2OmOm@WoGoD9oe0omo^_T2oj[8k`;oX<cf0onkcNL2ok7Bl@Co_<_V00Co_L;MokK=
jonfcN_o]/g[0_nc`nH3oj[@m0;oYL[c0onIf?d3oi?FoP;oSMCo00CoN]_kofSIkOmXfNgoGmKRJ_oo
ool01Ol0003ooooooooooooooooo000000_ooooo001Iooooo`03o`000?oooooooooo02cooooo1?n[
`NT2ojc2jP;o[L?Y0_n^a>X2ok34j@Co//KY00?o]LOXokK6ionfa^L00_nfa^L00onganKo]lCTokO4
i002okO4i0;o^<CS0_ng`N82okJoh@;o/kcQ1?na^^42oj^gh@03ojVehOnR/N?oX[7S00;oX[7S0onH
[NH3ohVXj@?oMj;]0omQW?02oe2JlP?oAigd0om@YOL3ogRmo0?oX<cf00?o^lgWok7BlOnad_400_na
d_42okc;iP;o/MCb0_nfcN/3oj_Gm`;oZ]3d0onLg?d2oiWHo@;oQmom0_n1gO`2og3LlP03ofOJjOoo
oooooooo06_ooooo00Go0000ooooooooooooooooo`00000;ooooo`00F_ooool2o`0002gooooo0_n[
`NT2ojc1j@?o[L?Y00?o[/?Yok34jOn`a>T00_n`a>T2ok;6j@?o/lGX0_nfa^L3okK4i@;o]lCT00Co
]/;SokO1h_ng`N;o]l7R0_ne_^44ok>lh@;o/K[Q0_n_^>03ojVeh@CoX[7S0onI[^D3ohbZj@?oOZO^
0om/Y?82oefTmP?oAigd0omBZoT4og;0oP?oULol0_nad_42ojCGnP;o/MCb0onTfo/2oj_Gm`?oVmom
0_nLg?d2oh[Qo@;oQmom0_mfg_D00om_gNkoooooooooo`1_ooooo`04o`000?ooooooooooo`0000_o
oooo001Looooo`03o`000?oooooooooo02_ooooo1?n/`NT01?n]`nWo[/?Yojk3jOn^`nT2ok34j@?o
/LCX0_ncaNP2ok?4iP?o]/CU00?o]L?TokK2honf`^<00_nf`^<00ong`N;o]KkQokFnh@02okFnh@;o
/kcQ0_na^^04ojnhh003ojVehOnX/n7oZ;?Q00CoX[7S0onI[^D3ohbZj@?oOZO^0om/Y?83oefTmP?o
DjOh0omH/_/3ofg3oP?oRM7o0_nTeoX3oiKJoP;oY=_k0onCgoh2oi_Oo@04oh[Qo?mmh?OoON3goggP
m`;oNn3f00?oM=oaooooooooool0Loooool00ol0003oooooo`00000;ooooo`00GOooool00ol0003o
ooooooooo`0[ooooo`;o[<7Y0_n^`NP2ojk3j@?o/<?X0_naa>P2ok;3i`Co/lCV00Co]/CUokG3i?ne
`nCo]L?T0_nf`^<3okG0hP;o]KkQ0_nc_>44ok6jh0;o[kSP00?o[KKPojRchOnX/n400_nX/n42oj:a
h`;oX[3R0onJ[^D4oi2]j@?oQJc^0omgZo<3ofZ]n0?oH;7k0omQ^Od3ofg6oP?oP=;o0_nFf_h01?n8
g?koP=cloh3Lo?n0g?`2ohKOo0;oOMoi0_mlh?H2ogSPlgSooooo00Co0000oooooooooooo00002_oo
ool005kooooo00?o0000ooooooooool0:oooool2ojk1j0;o[l;X0on``nP2ok72i`Co//?W0_nca>H2
ok?3i@;o]L?T0_nd`N<3okG0hP;o/kkR1?nc_>42ok6jh003ok2ih?n]]^3o[KKP00;o[KKP0_nX/n42
ojNch@CoX[3R0onJ[^D2oi2]j@04oiF_jOn</>koS;3^ohb`kP?oP[7c1?mh]OT3ofnjo0?oK<7n0om`
bol2og[Co`?oNMKn0_n0g?`2oggMn`;oP>3j0_mlh?Ilooooo`03o`000?oooooo000000[ooooo001O
ooooo`;o0000;?ooool4ojo2j003ok33j?na`^Oo/L;W00;o/L;W0_nb`nL3ok;3iP03ok?3iOnc`NGo
/l7U00Co]<7S00?o]L3Rok>nh_nc_^800_nc_^82ok>lh@03ok6khOn`^N3o/;WP00;o/;WP0_n]]^02
oj^eh0CoYk?Q0_nR/>801?nR/N?oWK3Uoif`iOnM/>D4oiF_j@?oS;3^0on2/O<2ogRen@;oQKch1?mm
`_d3ogS9o`;oMm3o0on1eOl2ogkJo@03ohKNoOoooooooooo087ooooo0_l0000:ooooo`00HOooool0
0ol0003oooooooooo`0Zooooo`;o[l;X0on``^L4ok72i`?o//?V00?o//;Vok?1iOnc`ND00_nc`ND2
okC1h`?o/koS0_nc_^800onb_>;o/K_Qok6kh@02ok6kh@;o/;WP0_n^]n04oj^eh0?oYk?Q1?nR/N<3
oif`i@;oUJoY0_nJ/^P4oiBdk@?oS;Oc0on5_?P2ogg2o@;oRlSl0_n6col3oi?DoP;oSM[oQOooool3
o`0000[ooooo001Rooooo`03o`000?oooooooooo02_ooooo1?n``^L4ok72i`04ok;3i_nb`^Ko//;V
ok;2iP;o/l7U0onb`>@2ok>oh`;o/[kS0onb_>82ok6kh@;o/;WQ1?n^]n02oj^eh0;oZ[CP0onW/n42
oj:ah`;oXk;R1?nO/ND3oiZbj0;oU;C]0_nK]n`4oiJkl@;oTL;g0_n;b?`3oiS=nP;oTmCnQ?ooool4
o`0000gooooo001Sooooo`03o`000?oooooooooo02_ooooo1?n``^L2ok72i`;o/L;V0_nb`^H2ok71
i@?o//3T0_na_n@4ok:nh`03ok:lh_n`^n;o/;_R00Co/;WQ0_n^]n02ojfgh0CoZ[CP0onW/n44oj>b
hP;oWk7U0_nR/n@3oindi`CoVkO/0_nF^o400onO_nooW<Keoic6m@02oic6m@;oV<gjPoooool4o`00
017ooooo001Tooooo`;o0000;?ooool4ok32i`;o/L;V0_na`NH4ok71i@03ok;0i?na_nCo/KoT00;o
/KoT0_nb_^<00on`_N?o/;_Rok2khP02ok2khP;o/;WQ0_n^^>44ojfgh0;oZ[CP00?oZKCPojNchOnW
/n400_nW/n42oj>bhP;oYK;R1?nR/n@3oindi`;oVkO/0_nR^^X3oinok`;oW<KePoooool3o`0001Go
oooo001Vooooo`03o`000?oooooooooo02_ooooo0on``^L4ok71iP;o/L7U0ona`>D2ok6oi003ok2n
i?n`_N?o/;gS00;o/;gS0_n`^n82ojnjhPCo[[SQ0_n]]n000on[]^7oZKCPojVdh002ojVdh0CoYk?Q
1?nU/^82oj:ci003ojFdhonS]^KoXkKV00;oXkKV0_nR^^Z5ooooo`Co00006?ooool006Oooooo00?o
0000ooooooooool0:_ooool4ok32i`;o/L7V0on``NH2ok70i@03ok2oiOn`_^Co/;kT00;o/;kT0_n`
_N<2ojnlh`Co[k[R0_n^^>42ojbhh@?oZkKQ0_nY]>02ojVdh@CoYk?Q0_nU/^800onV/n;oYKCSojFd
h`02ojFdh`;oXkKVQ?ooool4o`0001cooooo001Xooooo`03o`000?oooooooooo02[ooooo1On``^L2
ok31iP;o[l7W0on`_nD2ok2ni0;o[kgU1?n__><2ojnjhP;o[KWR0_n/^>42oj^ghPCoZ[GQ0onY]>43
ojNch@CoY[?R0_nU]>>3ooooo`Co00008?ooool006Wooooo0_l0000/ooooo`;o/<;W0_n_`^P4ojo1
i`03ok2oiOn^_nKo[[oV00Co[kgU0_n__><3ojfki003ojfih_n[^N?oZkWS00CoZkOR0_nZ]N42ojVe
hP;oZ;CQ1?nW/n42ojJchX;ooooo1?l0000Tooooo`00Joooool00ol0003oooooooooo`0Zooooo`Co
[l;X0_n_`NL2ojk0i`?o[[oV0_n__ND3ojfmi@;o[K_T00?oZk[Toj^ihon[^N<00_n[^N<2oj^ghP;o
ZKOS1?nY]N82ojRdh@;oYk?QP_ooool3o`0002Sooooo001/ooooo`03o`000?oooooooooo02[ooooo
0_n_`^P2ojk1j0;o[/3W0_n]_nP4ojfniP;o[KgU00?oZkcVoj^ji?n[^^@00_n[^^@2oj^ih`;oZKST
1?nY]n<2ojVehX?ooooo1?l0000[ooooo`00KOooool00ol0003oooooooooo`0[ooooo`03ojk1j?n/
`NWo[<7Y00Co[KoX0_n]_^H00on[_^OoZkcVoj^liP02oj^liP;oZk[T0_nZ^^D4ojVhi0;oZKOSP_oo
ool4o`0002oooooo001^ooooo`03o`000?oooooooooo02[ooooo1?n/`NT2ojfoj0;oZkoX0on[_^L2
oj^liP;oZK_V1?nZ^^D2ojVhi87ooooo1?l0000cooooo`00Koooool2o`0002_ooooo0_n/`NT2oj_1
j@CoZkoX00CoZkkWojVmj?nY_NSoZKgX0onY^nH2ojZjiH3ooooo1?l0000gooooo`00LOooool00ol0
003oooooooooo`0Zooooo`?oZl7Y0_n[_nP2ojVoj@;oZKgXP_ooool4o`0003_ooooo001booooo`03
o`000?oooooooooo02[ooooo0onY`>X2ojVojH;ooooo0ol0000oooooo`00Loooool00ol0003ooooo
ooooo`0Zooooo`03ojW0j_oooooooooo07oooooo1?l00012ooooo`00M?ooool2o`0002[ooooo00?o
0000ooooooooool0Noooool4o`0004Kooooo001fooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0N?ooool4o`0004[ooooo001gooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0M?ooool4o`0004kooooo001hooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0LOooool3o`0005;ooooo001iooooo`;o00009?ooool00ol0003oooooooooo`1]ooooo`Co0000
EOooool007_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Yooooo`Co0000FOoo
ool007cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Uooooo`Co0000GOooool0
07gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Qooooo`Co0000HOooool007ko
oooo0_l0000Oooooo`03o`000?oooooooooo05gooooo1?l0001Uooooo`00P?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo05[ooooo0ol0001Yooooo`00POooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo05Kooooo1?l0001/ooooo`00P_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo05;ooooo1?l0001`ooooo`00Poooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo04kooooo1?l0001dooooo`00Q?ooool2o`0001Wooooo00?o0000oooooooo
ool0B_ooool4o`0007Sooooo0026ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
A_ooool4o`0007cooooo0027ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@ooo
ool3o`00083ooooo0028ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?oooool4
o`0008?ooooo0029ooooo`;o00005?ooool00ol0003oooooooooo`0kooooo`Co0000Qoooool008_o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0gooooo`Co0000Roooool008cooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0cooooo`Co0000Soooool008gooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0`ooooo`?o0000Toooool008kooooo0_l0000?
ooooo`03o`000?oooooooooo02cooooo1?l0002Fooooo`00T?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo02Sooooo1?l0002Jooooo`00TOooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo02Cooooo1?l0002Nooooo`00T_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo027ooooo1?l0002Rooooo`00Toooool2o`0000Wooooo00?o0000ooooooooool07Ooo
ool4o`000:Kooooo002Eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool3
o`000:[ooooo002Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool4o`00
0:gooooo002Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool4o`000;7o
oooo002Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool4o`000;Gooooo
002Iooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000^Oooool009_ooooo00Co0000
oooooooooooo00002Oooool3o`000;gooooo002Looooo`03o`000?oooooo000000Gooooo1?l00030
ooooo`00WOooool2o`000003ooooool0003o000000;o0000a?ooool009kooooo0_l00038ooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00Z_ooool01OnHV9So0000o`000?m4A4Co^[Zj00Wooooo1Ol0
0003ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooo
ooooo`2Aooooo`00Z_ooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo1_l000001_ooooooV9RH
ob4Q8Oo^k^koooooodA4A0?ooooo00GoEEEEogMgMoooooooV9RHob4Q8@05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`2Booooo`00Z_ooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^
00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`Go0000Toooool00:[ooooo00?o0000oooo
ooooool01?ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003oV9RHoooooonHV9So
8B4Q00_ooooo00CoA4A4omgMgOoooooo0000U?ooool00:[ooooo00?o0000ooooooooool03_ooool0
0omgMgOoIVIVooooo`02ooooo`05o`000?mEEEGo0000oa0@4?o<c<`02oooool01?oMgMgoEEEEoooo
ool0002Dooooo`00Z?ooool00ol@413o0000o`000003o`0000kooooo00Ko0000oooooooooooooooo
oeEEEOn7QhL?ooooo`03ogMgMoo<c<co000009Cooooo002Zooooo`03o`000?oooooooooo00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4003ooooo`03omgMgOl@413oV9RH00kooooo00?ok^k^odA4A?l0
0000U?ooool00:[ooooo00?o0000ooooooooool02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo00Coc<c<odA4A?l0003o410@3Oooool00omgMgOo0000ooooo`2Cooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -20 0 ]
[.5 .82364 20 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(27.2) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.668 .754 .915 r
.39636 .6972 .40169 .70185 .41061 .69934 .40531 .6944 Mtetra
.668 .743 .907 r
.40531 .6944 .41061 .69934 .41957 .69681 .41429 .69159 Mtetra
.666 .733 .9 r
.41429 .69159 .41957 .69681 .42855 .69428 .4233 .68882 Mtetra
.664 .724 .894 r
.4233 .68882 .42855 .69428 .43756 .69174 .43233 .68608 Mtetra
.662 .717 .89 r
.43233 .68608 .43756 .69174 .4466 .68919 .44139 .68341 Mtetra
.658 .712 .888 r
.44139 .68341 .4466 .68919 .45567 .68663 .45048 .68082 Mtetra
.653 .711 .89 r
.45048 .68082 .45567 .68663 .46478 .68407 .4596 .67834 Mtetra
.648 .713 .895 r
.4596 .67834 .46478 .68407 .47391 .68149 .46874 .67599 Mtetra
.641 .719 .904 r
.46874 .67599 .47391 .68149 .48307 .67891 .47792 .67379 Mtetra
.634 .732 .919 r
.47792 .67379 .48307 .67891 .49227 .67632 .48713 .67171 Mtetra
.622 .75 .938 r
.48713 .67171 .49227 .67632 .50149 .67371 .49637 .66977 Mtetra
.608 .776 .961 r
.49637 .66977 .50149 .67371 .51075 .6711 .50564 .6679 Mtetra
.586 .806 .984 r
.50564 .6679 .51075 .6711 .52004 .66849 .51495 .66606 Mtetra
.555 .836 .997 r
.51495 .66606 .52004 .66849 .52936 .66586 .5243 .66418 Mtetra
.516 .857 .994 r
.5243 .66418 .52936 .66586 .53871 .66322 .53368 .66219 Mtetra
.477 .866 .973 r
.53368 .66219 .53871 .66322 .54809 .66058 .5431 .66 Mtetra
.455 .87 .948 r
.5431 .66 .54809 .66058 .55751 .65792 .55255 .65757 Mtetra
.459 .877 .936 r
.55255 .65757 .55751 .65792 .56695 .65526 .56203 .65487 Mtetra
.493 .892 .943 r
.56203 .65487 .56695 .65526 .57643 .65259 .57154 .65191 Mtetra
.542 .906 .963 r
.57154 .65191 .57643 .65259 .58595 .6499 .58108 .64874 Mtetra
.593 .909 .981 r
.58108 .64874 .58595 .6499 .59549 .64721 .59065 .64544 Mtetra
.63 .895 .987 r
.59065 .64544 .59549 .64721 .60507 .64451 .60024 .64209 Mtetra
.65 .87 .981 r
.60024 .64209 .60507 .64451 .61468 .6418 .60987 .63879 Mtetra
.657 .844 .972 r
.60987 .63879 .61468 .6418 .62432 .63908 .61953 .63559 Mtetra
.657 .821 .962 r
.61953 .63559 .62432 .63908 .634 .63636 .62922 .63253 Mtetra
.655 .805 .956 r
.62922 .63253 .634 .63636 .64371 .63362 .63895 .6296 Mtetra
.651 .796 .952 r
.63895 .6296 .64371 .63362 .65345 .63087 .64872 .62677 Mtetra
.649 .792 .951 r
.64872 .62677 .65345 .63087 .66323 .62811 .65852 .62399 Mtetra
.648 .792 .951 r
.65852 .62399 .66323 .62811 .67304 .62535 .66836 .62121 Mtetra
.649 .792 .951 r
.66836 .62121 .67304 .62535 .68289 .62257 .67823 .61842 Mtetra
.67823 .61842 .68289 .62257 .69277 .61979 .68814 .61561 Mtetra
.648 .792 .951 r
.68814 .61561 .69277 .61979 .70269 .61699 .69808 .61281 Mtetra
.645 .791 .952 r
.69808 .61281 .70269 .61699 .71264 .61418 .70806 .61005 Mtetra
.639 .792 .956 r
.70806 .61005 .71264 .61418 .72262 .61137 .71809 .6074 Mtetra
.629 .798 .963 r
.71809 .6074 .72262 .61137 .73264 .60854 .72815 .60487 Mtetra
.614 .808 .974 r
.72815 .60487 .73264 .60854 .7427 .60571 .73827 .60249 Mtetra
.593 .824 .987 r
.73827 .60249 .7427 .60571 .75279 .60286 .74843 .60021 Mtetra
.565 .843 .997 r
.74843 .60021 .75279 .60286 .76291 .60001 .75863 .59798 Mtetra
.529 .859 .995 r
.75863 .59798 .76291 .60001 .77308 .59714 .76887 .59571 Mtetra
.491 .868 .979 r
.76887 .59571 .77308 .59714 .78328 .59427 .77915 .5933 Mtetra
.462 .87 .954 r
.77915 .5933 .78328 .59427 .79351 .59138 .78944 .59068 Mtetra
.457 .875 .936 r
.78944 .59068 .79351 .59138 .80378 .58849 .79976 .58779 Mtetra
.481 .888 .938 r
.79976 .58779 .80378 .58849 .81409 .58558 .81008 .58463 Mtetra
.53 .904 .957 r
.81008 .58463 .81409 .58558 .82443 .58267 .82043 .58121 Mtetra
.587 .911 .977 r
.82043 .58121 .82443 .58267 .83482 .57974 .83079 .5776 Mtetra
.634 .899 .985 r
.83079 .5776 .83482 .57974 .84523 .5768 .84117 .57386 Mtetra
.664 .871 .977 r
.84117 .57386 .84523 .5768 .85569 .57385 .85158 .57007 Mtetra
.677 .834 .959 r
.85158 .57007 .85569 .57385 .86618 .57089 .86203 .56631 Mtetra
.679 .798 .938 r
.86203 .56631 .86618 .57089 .87672 .56792 .87252 .56263 Mtetra
.676 .768 .92 r
.87252 .56263 .87672 .56792 .88729 .56494 .88306 .55907 Mtetra
.672 .744 .905 r
.88306 .55907 .88729 .56494 .89789 .56195 .89365 .55565 Mtetra
.666 .728 .895 r
.89365 .55565 .89789 .56195 .90854 .55895 .9043 .55238 Mtetra
.661 .717 .89 r
.9043 .55238 .90854 .55895 .91923 .55594 .915 .54923 Mtetra
.657 .712 .888 r
.915 .54923 .91923 .55594 .92995 .55292 .92575 .5462 Mtetra
.654 .711 .889 r
.92575 .5462 .92995 .55292 .94071 .54988 .93655 .54326 Mtetra
.651 .713 .893 r
.93655 .54326 .94071 .54988 .95152 .54684 .9474 .54038 Mtetra
.649 .719 .899 r
.9474 .54038 .95152 .54684 .96236 .54378 .9583 .53754 Mtetra
.647 .726 .906 r
.9583 .53754 .96236 .54378 .97324 .54071 .96925 .53473 Mtetra
.646 .736 .915 r
.96925 .53473 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.679 .757 .91 r
.391 .69252 .39636 .6972 .40531 .6944 .39998 .68943 Mtetra
.678 .746 .902 r
.39998 .68943 .40531 .6944 .41429 .69159 .40899 .68635 Mtetra
.675 .735 .896 r
.40899 .68635 .41429 .69159 .4233 .68882 .41802 .68332 Mtetra
.671 .726 .891 r
.41802 .68332 .4233 .68882 .43233 .68608 .42707 .68039 Mtetra
.666 .718 .888 r
.42707 .68039 .43233 .68608 .44139 .68341 .43615 .67758 Mtetra
.659 .712 .887 r
.43615 .67758 .44139 .68341 .45048 .68082 .44526 .67495 Mtetra
.65 .709 .89 r
.44526 .67495 .45048 .68082 .4596 .67834 .45439 .67255 Mtetra
.639 .709 .897 r
.45439 .67255 .4596 .67834 .46874 .67599 .46355 .67041 Mtetra
.625 .712 .908 r
.46355 .67041 .46874 .67599 .47792 .67379 .47274 .66856 Mtetra
.609 .721 .925 r
.47274 .66856 .47792 .67379 .48713 .67171 .48196 .66699 Mtetra
.588 .735 .945 r
.48196 .66699 .48713 .67171 .49637 .66977 .49121 .66568 Mtetra
.562 .756 .969 r
.49121 .66568 .49637 .66977 .50564 .6679 .5005 .66454 Mtetra
.529 .781 .99 r
.5005 .66454 .50564 .6679 .51495 .66606 .50983 .66349 Mtetra
.492 .806 1 r
.50983 .66349 .51495 .66606 .5243 .66418 .51921 .66235 Mtetra
.457 .826 .993 r
.51921 .66235 .5243 .66418 .53368 .66219 .52862 .66099 Mtetra
.436 .842 .973 r
.52862 .66099 .53368 .66219 .5431 .66 .53807 .65926 Mtetra
.447 .861 .954 r
.53807 .65926 .5431 .66 .55255 .65757 .54755 .65703 Mtetra
.485 .885 .95 r
.54755 .65703 .55255 .65757 .56203 .65487 .55706 .65428 Mtetra
.548 .91 .96 r
.55706 .65428 .56203 .65487 .57154 .65191 .5666 .65099 Mtetra
.61 .922 .973 r
.5666 .65099 .57154 .65191 .58108 .64874 .57617 .6473 Mtetra
.659 .916 .978 r
.57617 .6473 .58108 .64874 .59065 .64544 .58576 .64334 Mtetra
.684 .893 .973 r
.58576 .64334 .59065 .64544 .60024 .64209 .59537 .63931 Mtetra
.691 .863 .964 r
.59537 .63931 .60024 .64209 .60987 .63879 .60501 .6354 Mtetra
.687 .833 .954 r
.60501 .6354 .60987 .63879 .61953 .63559 .61469 .63171 Mtetra
.676 .809 .946 r
.61469 .63171 .61953 .63559 .62922 .63253 .6244 .62834 Mtetra
.665 .793 .943 r
.6244 .62834 .62922 .63253 .63895 .6296 .63415 .62523 Mtetra
.656 .783 .942 r
.63415 .62523 .63895 .6296 .64872 .62677 .64394 .62235 Mtetra
.651 .78 .942 r
.64394 .62235 .64872 .62677 .65852 .62399 .65377 .61956 Mtetra
.65 .78 .943 r
.65377 .61956 .65852 .62399 .66836 .62121 .66364 .6168 Mtetra
.651 .782 .943 r
.66364 .6168 .66836 .62121 .67823 .61842 .67353 .61399 Mtetra
.653 .782 .943 r
.67353 .61399 .67823 .61842 .68814 .61561 .68347 .61113 Mtetra
.651 .781 .943 r
.68347 .61113 .68814 .61561 .69808 .61281 .69344 .6083 Mtetra
.647 .779 .944 r
.69344 .6083 .69808 .61281 .70806 .61005 .70344 .60556 Mtetra
.635 .776 .948 r
.70344 .60556 .70806 .61005 .71809 .6074 .7135 .60305 Mtetra
.619 .778 .957 r
.7135 .60305 .71809 .6074 .72815 .60487 .72361 .60081 Mtetra
.595 .783 .97 r
.72361 .60081 .72815 .60487 .73827 .60249 .73378 .59888 Mtetra
.566 .795 .985 r
.73378 .59888 .73827 .60249 .74843 .60021 .74401 .59719 Mtetra
.532 .812 .997 r
.74401 .59719 .74843 .60021 .75863 .59798 .75429 .59562 Mtetra
.494 .829 .999 r
.75429 .59562 .75863 .59798 .76887 .59571 .76462 .59399 Mtetra
.466 .845 .986 r
.76462 .59399 .76887 .59571 .77915 .5933 .77496 .59208 Mtetra
.455 .859 .965 r
.77496 .59208 .77915 .5933 .78944 .59068 .78532 .58977 Mtetra
.476 .879 .952 r
.78532 .58977 .78944 .59068 .79976 .58779 .79568 .58691 Mtetra
.522 .902 .953 r
.79568 .58691 .79976 .58779 .81008 .58463 .80603 .58351 Mtetra
.586 .922 .965 r
.80603 .58351 .81008 .58463 .82043 .58121 .81637 .5796 Mtetra
.645 .925 .974 r
.81637 .5796 .82043 .58121 .83079 .5776 .82671 .5753 Mtetra
.686 .908 .973 r
.82671 .5753 .83079 .5776 .84117 .57386 .83706 .57076 Mtetra
.707 .876 .96 r
.83706 .57076 .84117 .57386 .85158 .57007 .84743 .56613 Mtetra
.711 .838 .943 r
.84743 .56613 .85158 .57007 .86203 .56631 .85784 .56158 Mtetra
.706 .802 .925 r
.85784 .56158 .86203 .56631 .87252 .56263 .86829 .5572 Mtetra
.695 .771 .91 r
.86829 .5572 .87252 .56263 .88306 .55907 .87881 .55309 Mtetra
.685 .747 .898 r
.87881 .55309 .88306 .55907 .89365 .55565 .88938 .54925 Mtetra
.674 .729 .891 r
.88938 .54925 .89365 .55565 .9043 .55238 .90002 .54573 Mtetra
.664 .717 .888 r
.90002 .54573 .9043 .55238 .915 .54923 .91074 .54246 Mtetra
.656 .711 .888 r
.91074 .54246 .915 .54923 .92575 .5462 .92151 .53943 Mtetra
.65 .708 .89 r
.92151 .53943 .92575 .5462 .93655 .54326 .93236 .53659 Mtetra
.645 .71 .895 r
.93236 .53659 .93655 .54326 .9474 .54038 .94326 .53388 Mtetra
.641 .715 .901 r
.94326 .53388 .9474 .54038 .9583 .53754 .95422 .53127 Mtetra
.637 .722 .909 r
.95422 .53127 .9583 .53754 .96925 .53473 .96523 .52871 Mtetra
.635 .731 .918 r
.96523 .52871 .96925 .53473 .98024 .53192 .97628 .52616 Mtetra
.689 .759 .905 r
.38561 .68781 .391 .69252 .39998 .68943 .39462 .68444 Mtetra
.687 .748 .898 r
.39462 .68444 .39998 .68943 .40899 .68635 .40365 .68109 Mtetra
.683 .738 .892 r
.40365 .68109 .40899 .68635 .41802 .68332 .41271 .67782 Mtetra
.678 .729 .888 r
.41271 .67782 .41802 .68332 .42707 .68039 .42178 .67468 Mtetra
.67 .72 .886 r
.42178 .67468 .42707 .68039 .43615 .67758 .43089 .67173 Mtetra
.66 .713 .887 r
.43089 .67173 .43615 .67758 .44526 .67495 .44001 .66904 Mtetra
.647 .708 .891 r
.44001 .66904 .44526 .67495 .45439 .67255 .44916 .66669 Mtetra
.631 .705 .899 r
.44916 .66669 .45439 .67255 .46355 .67041 .45833 .66472 Mtetra
.61 .705 .911 r
.45833 .66472 .46355 .67041 .47274 .66856 .46753 .6632 Mtetra
.585 .709 .928 r
.46753 .6632 .47274 .66856 .48196 .66699 .47676 .6621 Mtetra
.552 .717 .949 r
.47676 .6621 .48196 .66699 .49121 .66568 .48602 .6614 Mtetra
.516 .731 .971 r
.48602 .6614 .49121 .66568 .5005 .66454 .49533 .66096 Mtetra
.472 .748 .989 r
.49533 .66096 .5005 .66454 .50983 .66349 .50468 .66066 Mtetra
.433 .769 .997 r
.50468 .66066 .50983 .66349 .51921 .66235 .51407 .66025 Mtetra
.408 .792 .991 r
.51407 .66025 .51921 .66235 .52862 .66099 .52351 .6595 Mtetra
.414 .82 .978 r
.52351 .6595 .52862 .66099 .53807 .65926 .53299 .65819 Mtetra
.46 .858 .971 r
.53299 .65819 .53807 .65926 .54755 .65703 .5425 .65613 Mtetra
.531 .894 .972 r
.5425 .65613 .54755 .65703 .55706 .65428 .55205 .65327 Mtetra
.614 .92 .975 r
.55205 .65327 .55706 .65428 .5666 .65099 .56162 .6496 Mtetra
.677 .922 .973 r
.56162 .6496 .5666 .65099 .57617 .6473 .57121 .64534 Mtetra
.716 .904 .962 r
.57121 .64534 .57617 .6473 .58576 .64334 .58082 .64068 Mtetra
.728 .874 .949 r
.58082 .64068 .58576 .64334 .59537 .63931 .59045 .63595 Mtetra
.723 .841 .937 r
.59045 .63595 .59537 .63931 .60501 .6354 .60011 .63142 Mtetra
.708 .812 .929 r
.60011 .63142 .60501 .6354 .61469 .63171 .6098 .62728 Mtetra
.689 .788 .926 r
.6098 .62728 .61469 .63171 .6244 .62834 .61953 .62363 Mtetra
.672 .773 .926 r
.61953 .62363 .6244 .62834 .63415 .62523 .6293 .62042 Mtetra
.657 .765 .929 r
.6293 .62042 .63415 .62523 .64394 .62235 .63912 .61754 Mtetra
.651 .764 .932 r
.63912 .61754 .64394 .62235 .65377 .61956 .64898 .6148 Mtetra
.65 .767 .935 r
.64898 .6148 .65377 .61956 .66364 .6168 .65887 .61207 Mtetra
.653 .77 .935 r
.65887 .61207 .66364 .6168 .67353 .61399 .66879 .60924 Mtetra
.657 .771 .934 r
.66879 .60924 .67353 .61399 .68347 .61113 .67875 .60632 Mtetra
.657 .769 .932 r
.67875 .60632 .68347 .61113 .69344 .6083 .68874 .6034 Mtetra
.651 .764 .932 r
.68874 .6034 .69344 .6083 .70344 .60556 .69877 .60062 Mtetra
.635 .758 .937 r
.69877 .60062 .70344 .60556 .7135 .60305 .70886 .59818 Mtetra
.613 .754 .945 r
.70886 .59818 .7135 .60305 .72361 .60081 .71901 .59617 Mtetra
.582 .753 .959 r
.71901 .59617 .72361 .60081 .73378 .59888 .72923 .59468 Mtetra
.545 .759 .976 r
.72923 .59468 .73378 .59888 .74401 .59719 .73953 .59358 Mtetra
.507 .772 .991 r
.73953 .59358 .74401 .59719 .75429 .59562 .74988 .59269 Mtetra
.472 .791 .999 r
.74988 .59269 .75429 .59562 .76462 .59399 .76028 .59174 Mtetra
.456 .818 .995 r
.76028 .59174 .76462 .59399 .77496 .59208 .77071 .59038 Mtetra
.463 .846 .984 r
.77071 .59038 .77496 .59208 .78532 .58977 .78113 .58843 Mtetra
.508 .882 .974 r
.78113 .58843 .78532 .58977 .79568 .58691 .79153 .58564 Mtetra
.571 .911 .972 r
.79153 .58564 .79568 .58691 .80603 .58351 .80191 .58205 Mtetra
.642 .93 .971 r
.80191 .58205 .80603 .58351 .81637 .5796 .81226 .57767 Mtetra
.697 .927 .967 r
.81226 .57767 .81637 .5796 .82671 .5753 .82258 .57271 Mtetra
.73 .905 .956 r
.82258 .57271 .82671 .5753 .83706 .57076 .8329 .56739 Mtetra
.742 .872 .94 r
.8329 .56739 .83706 .57076 .84743 .56613 .84323 .56195 Mtetra
.738 .835 .924 r
.84323 .56195 .84743 .56613 .85784 .56158 .8536 .55665 Mtetra
.728 .801 .91 r
.8536 .55665 .85784 .56158 .86829 .5572 .86402 .55159 Mtetra
.711 .771 .899 r
.86402 .55159 .86829 .5572 .87881 .55309 .87451 .54696 Mtetra
.696 .747 .891 r
.87451 .54696 .87881 .55309 .88938 .54925 .88507 .54275 Mtetra
.68 .729 .887 r
.88507 .54275 .88938 .54925 .90002 .54573 .89572 .539 Mtetra
.667 .717 .886 r
.89572 .539 .90002 .54573 .91074 .54246 .90645 .53564 Mtetra
.655 .71 .888 r
.90645 .53564 .91074 .54246 .92151 .53943 .91726 .53263 Mtetra
.645 .707 .892 r
.91726 .53263 .92151 .53943 .93236 .53659 .92814 .5299 Mtetra
.638 .708 .897 r
.92814 .5299 .93236 .53659 .94326 .53388 .93909 .52736 Mtetra
.632 .712 .904 r
.93909 .52736 .94326 .53388 .95422 .53127 .95011 .52497 Mtetra
.627 .718 .912 r
.95011 .52497 .95422 .53127 .96523 .52871 .96118 .52266 Mtetra
.624 .727 .92 r
.96118 .52266 .96523 .52871 .97628 .52616 .9723 .52037 Mtetra
.698 .76 .9 r
.38018 .68308 .38561 .68781 .39462 .68444 .38922 .67944 Mtetra
.696 .751 .894 r
.38922 .67944 .39462 .68444 .40365 .68109 .39828 .67583 Mtetra
.691 .741 .889 r
.39828 .67583 .40365 .68109 .41271 .67782 .40736 .67232 Mtetra
.684 .731 .886 r
.40736 .67232 .41271 .67782 .42178 .67468 .41646 .66897 Mtetra
.675 .723 .885 r
.41646 .66897 .42178 .67468 .43089 .67173 .42559 .66587 Mtetra
.663 .715 .887 r
.42559 .66587 .43089 .67173 .44001 .66904 .43473 .6631 Mtetra
.646 .707 .892 r
.43473 .6631 .44001 .66904 .44916 .66669 .44389 .66077 Mtetra
.625 .702 .9 r
.44389 .66077 .44916 .66669 .45833 .66472 .45308 .65894 Mtetra
.597 .697 .913 r
.45308 .65894 .45833 .66472 .46753 .6632 .46229 .65769 Mtetra
.564 .696 .93 r
.46229 .65769 .46753 .6632 .47676 .6621 .47153 .65699 Mtetra
.519 .696 .949 r
.47153 .65699 .47676 .6621 .48602 .6614 .4808 .65685 Mtetra
.473 .702 .969 r
.4808 .65685 .48602 .6614 .49533 .66096 .49012 .65706 Mtetra
.421 .71 .983 r
.49012 .65706 .49533 .66096 .50468 .66066 .49948 .65746 Mtetra
.385 .729 .99 r
.49948 .65746 .50468 .66066 .51407 .66025 .50889 .65772 Mtetra
.376 .758 .99 r
.50889 .65772 .51407 .66025 .52351 .6595 .51836 .65754 Mtetra
.411 .801 .988 r
.51836 .65754 .52351 .6595 .53299 .65819 .52786 .65662 Mtetra
.492 .854 .99 r
.52786 .65662 .53299 .65819 .5425 .65613 .53741 .65467 Mtetra
.587 .894 .988 r
.53741 .65467 .5425 .65613 .55205 .65327 .54699 .65165 Mtetra
.676 .912 .975 r
.54699 .65165 .55205 .65327 .56162 .6496 .55659 .64753 Mtetra
.729 .9 .956 r
.55659 .64753 .56162 .6496 .57121 .64534 .5662 .64263 Mtetra
.755 .874 .933 r
.5662 .64263 .57121 .64534 .58082 .64068 .57583 .63721 Mtetra
.755 .841 .916 r
.57583 .63721 .58082 .64068 .59045 .63595 .58548 .63176 Mtetra
.742 .809 .905 r
.58548 .63176 .59045 .63595 .60011 .63142 .59515 .62663 Mtetra
.72 .782 .901 r
.59515 .62663 .60011 .63142 .6098 .62728 .60486 .62208 Mtetra
.694 .761 .903 r
.60486 .62208 .6098 .62728 .61953 .62363 .61461 .61826 Mtetra
.673 .749 .908 r
.61461 .61826 .61953 .62363 .6293 .62042 .62441 .61503 Mtetra
.654 .743 .915 r
.62441 .61503 .6293 .62042 .63912 .61754 .63425 .61227 Mtetra
.647 .746 .921 r
.63425 .61227 .63912 .61754 .64898 .6148 .64413 .60965 Mtetra
.648 .751 .925 r
.64413 .60965 .64898 .6148 .65887 .61207 .65405 .60699 Mtetra
.655 .757 .925 r
.65405 .60699 .65887 .61207 .66879 .60924 .664 .60415 Mtetra
.662 .76 .922 r
.664 .60415 .66879 .60924 .67875 .60632 .67398 .60111 Mtetra
.664 .757 .919 r
.67398 .60111 .67875 .60632 .68874 .6034 .68399 .59803 Mtetra
.658 .749 .917 r
.68399 .59803 .68874 .6034 .69877 .60062 .69404 .5951 Mtetra
.639 .738 .92 r
.69404 .5951 .69877 .60062 .70886 .59818 .70415 .59264 Mtetra
.613 .727 .927 r
.70415 .59264 .70886 .59818 .71901 .59617 .71433 .59078 Mtetra
.574 .718 .94 r
.71433 .59078 .71901 .59617 .72923 .59468 .7246 .58966 Mtetra
.532 .717 .957 r
.7246 .58966 .72923 .59468 .73953 .59358 .73496 .58913 Mtetra
.491 .725 .975 r
.73496 .58913 .73953 .59358 .74988 .59269 .74538 .58894 Mtetra
.458 .744 .99 r
.74538 .58894 .74988 .59269 .76028 .59174 .75586 .58872 Mtetra
.455 .781 .998 r
.75586 .58872 .76028 .59174 .77071 .59038 .76636 .58798 Mtetra
.48 .823 .998 r
.76636 .58798 .77071 .59038 .78113 .58843 .77686 .58646 Mtetra
.545 .873 .993 r
.77686 .58646 .78113 .58843 .79153 .58564 .78731 .58381 Mtetra
.618 .907 .984 r
.78731 .58381 .79153 .58564 .80191 .58205 .79771 .58006 Mtetra
.69 .923 .97 r
.79771 .58006 .80191 .58205 .81226 .57767 .80807 .57526 Mtetra
.738 .915 .953 r
.80807 .57526 .81226 .57767 .82258 .57271 .81838 .56968 Mtetra
.762 .892 .935 r
.81838 .56968 .82258 .57271 .8329 .56739 .82867 .56364 Mtetra
.768 .861 .918 r
.82867 .56364 .8329 .56739 .84323 .56195 .83897 .55743 Mtetra
.759 .827 .905 r
.83897 .55743 .84323 .56195 .8536 .55665 .84931 .55142 Mtetra
.744 .796 .894 r
.84931 .55142 .8536 .55665 .86402 .55159 .8597 .54576 Mtetra
.724 .768 .888 r
.8597 .54576 .86402 .55159 .87451 .54696 .87017 .54066 Mtetra
.704 .746 .884 r
.87017 .54066 .87451 .54696 .88507 .54275 .88073 .53613 Mtetra
.685 .728 .884 r
.88073 .53613 .88507 .54275 .89572 .539 .89139 .5322 Mtetra
.668 .716 .885 r
.89139 .5322 .89572 .539 .90645 .53564 .90214 .52878 Mtetra
.653 .709 .889 r
.90214 .52878 .90645 .53564 .91726 .53263 .91298 .52582 Mtetra
.64 .706 .894 r
.91298 .52582 .91726 .53263 .92814 .5299 .9239 .52321 Mtetra
.631 .706 .9 r
.9239 .52321 .92814 .5299 .93909 .52736 .9349 .52084 Mtetra
.623 .709 .907 r
.9349 .52084 .93909 .52736 .95011 .52497 .94598 .51866 Mtetra
.617 .715 .915 r
.94598 .51866 .95011 .52497 .96118 .52266 .95711 .51659 Mtetra
.614 .723 .923 r
.95711 .51659 .96118 .52266 .9723 .52037 .96829 .51454 Mtetra
.705 .762 .896 r
.37472 .67831 .38018 .68308 .38922 .67944 .38379 .67443 Mtetra
.703 .753 .89 r
.38379 .67443 .38922 .67944 .39828 .67583 .39288 .67058 Mtetra
.698 .744 .887 r
.39288 .67058 .39828 .67583 .40736 .67232 .40199 .66684 Mtetra
.691 .735 .884 r
.40199 .66684 .40736 .67232 .41646 .66897 .41111 .66329 Mtetra
.68 .726 .884 r
.41111 .66329 .41646 .66897 .42559 .66587 .42026 .66002 Mtetra
.666 .717 .887 r
.42026 .66002 .42559 .66587 .43473 .6631 .42942 .65715 Mtetra
.646 .708 .892 r
.42942 .65715 .43473 .6631 .44389 .66077 .4386 .65479 Mtetra
.621 .699 .901 r
.4386 .65479 .44389 .66077 .45308 .65894 .4478 .65303 Mtetra
.587 .69 .913 r
.4478 .65303 .45308 .65894 .46229 .65769 .45702 .65199 Mtetra
.546 .683 .929 r
.45702 .65199 .46229 .65769 .47153 .65699 .46627 .65162 Mtetra
.492 .675 .946 r
.46627 .65162 .47153 .65699 .4808 .65685 .47555 .65195 Mtetra
.439 .672 .962 r
.47555 .65195 .4808 .65685 .49012 .65706 .48488 .65272 Mtetra
.382 .672 .973 r
.48488 .65272 .49012 .65706 .49948 .65746 .49425 .65376 Mtetra
.354 .69 .981 r
.49425 .65376 .49948 .65746 .50889 .65772 .50368 .65463 Mtetra
.364 .726 .988 r
.50368 .65463 .50889 .65772 .51836 .65754 .51316 .65495 Mtetra
.428 .781 .997 r
.51316 .65495 .51836 .65754 .52786 .65662 .5227 .65434 Mtetra
.537 .842 .999 r
.5227 .65434 .52786 .65662 .53741 .65467 .53227 .65243 Mtetra
.64 .876 .985 r
.53227 .65243 .53741 .65467 .54699 .65165 .54188 .64917 Mtetra
.723 .881 .954 r
.54188 .64917 .54699 .65165 .55659 .64753 .5515 .64451 Mtetra
.762 .86 .922 r
.5515 .64451 .55659 .64753 .5662 .64263 .56114 .63889 Mtetra
.776 .83 .894 r
.56114 .63889 .5662 .64263 .57583 .63721 .57079 .63266 Mtetra
.768 .798 .877 r
.57079 .63266 .57583 .63721 .58548 .63176 .58045 .62646 Mtetra
.749 .769 .869 r
.58045 .62646 .58548 .63176 .59515 .62663 .59014 .62075 Mtetra
.723 .744 .869 r
.59014 .62075 .59515 .62663 .60486 .62208 .59987 .61587 Mtetra
.692 .726 .876 r
.59987 .61587 .60486 .62208 .61461 .61826 .60964 .61199 Mtetra
.667 .716 .885 r
.60964 .61199 .61461 .61826 .62441 .61503 .61946 .60889 Mtetra
.646 .714 .897 r
.61946 .60889 .62441 .61503 .63425 .61227 .62933 .60637 Mtetra
.639 .721 .907 r
.62933 .60637 .63425 .61227 .64413 .60965 .63925 .60398 Mtetra
.644 .731 .912 r
.63925 .60398 .64413 .60965 .65405 .60699 .64919 .60146 Mtetra
.656 .741 .912 r
.64919 .60146 .65405 .60699 .664 .60415 .65916 .59859 Mtetra
.669 .746 .908 r
.65916 .59859 .664 .60415 .67398 .60111 .66916 .59538 Mtetra
.674 .741 .902 r
.66916 .59538 .67398 .60111 .68399 .59803 .67918 .59204 Mtetra
.668 .731 .897 r
.67918 .59204 .68399 .59803 .69404 .5951 .68924 .58882 Mtetra
.647 .714 .897 r
.68924 .58882 .69404 .5951 .70415 .59264 .69936 .58619 Mtetra
.617 .697 .901 r
.69936 .58619 .70415 .59264 .71433 .59078 .70957 .58435 Mtetra
.573 .68 .912 r
.70957 .58435 .71433 .59078 .7246 .58966 .71988 .58353 Mtetra
.526 .67 .928 r
.71988 .58353 .7246 .58966 .73496 .58913 .73029 .58354 Mtetra
.482 .671 .947 r
.73029 .58354 .73496 .58913 .74538 .58894 .74078 .58407 Mtetra
.451 .688 .967 r
.74078 .58407 .74538 .58894 .75586 .58872 .75134 .58465 Mtetra
.458 .73 .985 r
.75134 .58465 .75586 .58872 .76636 .58798 .76192 .58461 Mtetra
.496 .784 .996 r
.76192 .58461 .76636 .58798 .77686 .58646 .77248 .5836 Mtetra
.575 .844 .995 r
.77248 .5836 .77686 .58646 .78731 .58381 .78299 .58117 Mtetra
.654 .883 .982 r
.78299 .58117 .78731 .58381 .79771 .58006 .79342 .57735 Mtetra
.724 .899 .958 r
.79342 .57735 .79771 .58006 .80807 .57526 .80379 .5722 Mtetra
.765 .891 .933 r
.80379 .5722 .80807 .57526 .81838 .56968 .81409 .56606 Mtetra
.783 .869 .912 r
.81409 .56606 .81838 .56968 .82867 .56364 .82437 .55936 Mtetra
.785 .842 .895 r
.82437 .55936 .82867 .56364 .83897 .55743 .83464 .55247 Mtetra
.772 .813 .885 r
.83464 .55247 .83897 .55743 .84931 .55142 .84495 .54583 Mtetra
.755 .787 .879 r
.84495 .54583 .84931 .55142 .8597 .54576 .85532 .53964 Mtetra
.732 .762 .877 r
.85532 .53964 .8597 .54576 .87017 .54066 .86579 .53416 Mtetra
.71 .743 .877 r
.86579 .53416 .87017 .54066 .88073 .53613 .87635 .52937 Mtetra
.687 .726 .88 r
.87635 .52937 .88073 .53613 .89139 .5322 .88702 .52532 Mtetra
.667 .715 .884 r
.88702 .52532 .89139 .5322 .90214 .52878 .8978 .5219 Mtetra
.65 .708 .89 r
.8978 .5219 .90214 .52878 .91298 .52582 .90868 .519 Mtetra
.635 .704 .896 r
.90868 .519 .91298 .52582 .9239 .52321 .91965 .51653 Mtetra
.623 .704 .903 r
.91965 .51653 .9239 .52321 .9349 .52084 .9307 .51434 Mtetra
.614 .707 .911 r
.9307 .51434 .9349 .52084 .94598 .51866 .94182 .51236 Mtetra
.608 .712 .918 r
.94182 .51236 .94598 .51866 .95711 .51659 .95301 .5105 Mtetra
.604 .719 .926 r
.95301 .5105 .95711 .51659 .96829 .51454 .96426 .50866 Mtetra
.712 .763 .892 r
.36922 .67351 .37472 .67831 .38379 .67443 .37832 .66942 Mtetra
.71 .755 .888 r
.37832 .66942 .38379 .67443 .39288 .67058 .38744 .66535 Mtetra
.705 .747 .885 r
.38744 .66535 .39288 .67058 .40199 .66684 .39657 .6614 Mtetra
.697 .739 .884 r
.39657 .6614 .40199 .66684 .41111 .66329 .40573 .65766 Mtetra
.686 .73 .884 r
.40573 .65766 .41111 .66329 .42026 .66002 .4149 .65421 Mtetra
.67 .721 .887 r
.4149 .65421 .42026 .66002 .42942 .65715 .42408 .65121 Mtetra
.648 .71 .893 r
.42408 .65121 .42942 .65715 .4386 .65479 .43328 .64878 Mtetra
.62 .699 .901 r
.43328 .64878 .4386 .65479 .4478 .65303 .44249 .64704 Mtetra
.58 .686 .914 r
.44249 .64704 .4478 .65303 .45702 .65199 .45172 .64612 Mtetra
.533 .673 .927 r
.45172 .64612 .45702 .65199 .46627 .65162 .46098 .646 Mtetra
.471 .656 .941 r
.46098 .646 .46627 .65162 .47555 .65195 .47027 .64671 Mtetra
.413 .646 .953 r
.47027 .64671 .47555 .65195 .48488 .65272 .47961 .64795 Mtetra
.355 .639 .962 r
.47961 .64795 .48488 .65272 .49425 .65376 .48899 .64952 Mtetra
.336 .656 .971 r
.48899 .64952 .49425 .65376 .50368 .65463 .49843 .6509 Mtetra
.366 .696 .983 r
.49843 .6509 .50368 .65463 .51316 .65495 .50793 .65165 Mtetra
.454 .759 .995 r
.50793 .65165 .51316 .65495 .5227 .65434 .51749 .65127 Mtetra
.576 .818 .99 r
.51749 .65127 .5227 .65434 .53227 .65243 .52709 .64931 Mtetra
.678 .844 .963 r
.52709 .64931 .53227 .65243 .54188 .64917 .53672 .64573 Mtetra
.749 .84 .92 r
.53672 .64573 .54188 .64917 .5515 .64451 .54638 .64045 Mtetra
.777 .817 .884 r
.54638 .64045 .5515 .64451 .56114 .63889 .55604 .63405 Mtetra
.784 .789 .856 r
.55604 .63405 .56114 .63889 .57079 .63266 .5657 .62697 Mtetra
.772 .761 .843 r
.5657 .62697 .57079 .63266 .58045 .62646 .57538 .62005 Mtetra
.749 .735 .839 r
.57538 .62005 .58045 .62646 .59014 .62075 .58509 .61386 Mtetra
.719 .714 .845 r
.58509 .61386 .59014 .62075 .59987 .61587 .59483 .60879 Mtetra
.684 .698 .857 r
.59483 .60879 .59987 .61587 .60964 .61199 .60462 .60503 Mtetra
.655 .691 .872 r
.60462 .60503 .60964 .61199 .61946 .60889 .61447 .60224 Mtetra
.63 .692 .889 r
.61447 .60224 .61946 .60889 .62933 .60637 .62437 .60012 Mtetra
.626 .705 .902 r
.62437 .60012 .62933 .60637 .63925 .60398 .63432 .59807 Mtetra
.636 .721 .909 r
.63432 .59807 .63925 .60398 .64919 .60146 .6443 .59574 Mtetra
.657 .736 .908 r
.6443 .59574 .64919 .60146 .65916 .59859 .65429 .59286 Mtetra
.677 .743 .901 r
.65429 .59286 .65916 .59859 .66916 .59538 .6643 .58941 Mtetra
.686 .738 .891 r
.6643 .58941 .66916 .59538 .67918 .59204 .67433 .58569 Mtetra
.682 .725 .882 r
.67433 .58569 .67918 .59204 .68924 .58882 .68439 .58203 Mtetra
.659 .703 .88 r
.68439 .58203 .68924 .58882 .69936 .58619 .69452 .57905 Mtetra
.625 .679 .881 r
.69452 .57905 .69936 .58619 .70957 .58435 .70473 .57704 Mtetra
.574 .652 .889 r
.70473 .57704 .70957 .58435 .71988 .58353 .71507 .57637 Mtetra
.521 .632 .901 r
.71507 .57637 .71988 .58353 .73029 .58354 .72552 .57683 Mtetra
.471 .623 .917 r
.72552 .57683 .73029 .58354 .74078 .58407 .73608 .57806 Mtetra
.44 .634 .937 r
.73608 .57806 .74078 .58407 .75134 .58465 .74671 .57945 Mtetra
.452 .676 .96 r
.74671 .57945 .75134 .58465 .76192 .58461 .75737 .58018 Mtetra
.499 .734 .978 r
.75737 .58018 .76192 .58461 .77248 .5836 .768 .57976 Mtetra
.589 .802 .981 r
.768 .57976 .77248 .5836 .78299 .58117 .77856 .57763 Mtetra
.673 .846 .966 r
.77856 .57763 .78299 .58117 .79342 .57735 .78904 .57382 Mtetra
.741 .865 .938 r
.78904 .57382 .79342 .57735 .80379 .5722 .79941 .56839 Mtetra
.779 .86 .91 r
.79941 .56839 .80379 .5722 .81409 .56606 .80972 .56179 Mtetra
.794 .844 .889 r
.80972 .56179 .81409 .56606 .82437 .55936 .81998 .55452 Mtetra
.794 .822 .874 r
.81998 .55452 .82437 .55936 .83464 .55247 .83024 .54704 Mtetra
.78 .799 .868 r
.83024 .54704 .83464 .55247 .84495 .54583 .84054 .53988 Mtetra
.762 .777 .865 r
.84054 .53988 .84495 .54583 .85532 .53964 .8509 .53326 Mtetra
.737 .756 .868 r
.8509 .53326 .85532 .53964 .86579 .53416 .86137 .52749 Mtetra
.713 .74 .872 r
.86137 .52749 .86579 .53416 .87635 .52937 .87194 .52253 Mtetra
.688 .725 .878 r
.87194 .52253 .87635 .52937 .88702 .52532 .88264 .51842 Mtetra
.666 .715 .885 r
.88264 .51842 .88702 .52532 .8978 .5219 .89344 .51503 Mtetra
.645 .708 .893 r
.89344 .51503 .8978 .5219 .90868 .519 .90436 .51223 Mtetra
.629 .704 .9 r
.90436 .51223 .90868 .519 .91965 .51653 .91537 .50989 Mtetra
.616 .704 .908 r
.91537 .50989 .91965 .51653 .9307 .51434 .92647 .50787 Mtetra
.606 .706 .915 r
.92647 .50787 .9307 .51434 .94182 .51236 .93765 .50607 Mtetra
.599 .71 .922 r
.93765 .50607 .94182 .51236 .95301 .5105 .94889 .5044 Mtetra
.595 .716 .928 r
.94889 .5044 .95301 .5105 .96426 .50866 .9602 .50275 Mtetra
.717 .763 .889 r
.36369 .66869 .36922 .67351 .37832 .66942 .37282 .66442 Mtetra
.715 .758 .886 r
.37282 .66442 .37832 .66942 .38744 .66535 .38196 .66017 Mtetra
.71 .751 .884 r
.38196 .66017 .38744 .66535 .39657 .6614 .39113 .65603 Mtetra
.703 .744 .883 r
.39113 .65603 .39657 .6614 .40573 .65766 .40031 .65211 Mtetra
.692 .735 .884 r
.40031 .65211 .40573 .65766 .4149 .65421 .4095 .64848 Mtetra
.675 .726 .888 r
.4095 .64848 .4149 .65421 .42408 .65121 .41871 .64532 Mtetra
.652 .714 .894 r
.41871 .64532 .42408 .65121 .43328 .64878 .42792 .64278 Mtetra
.621 .701 .902 r
.42792 .64278 .43328 .64878 .44249 .64704 .43715 .64098 Mtetra
.578 .684 .913 r
.43715 .64098 .44249 .64704 .45172 .64612 .4464 .6401 Mtetra
.527 .666 .925 r
.4464 .6401 .45172 .64612 .46098 .646 .45567 .64012 Mtetra
.459 .642 .936 r
.45567 .64012 .46098 .646 .47027 .64671 .46497 .64108 Mtetra
.399 .624 .944 r
.46497 .64108 .47027 .64671 .47961 .64795 .47431 .64266 Mtetra
.343 .611 .949 r
.47431 .64266 .47961 .64795 .48899 .64952 .4837 .64465 Mtetra
.337 .627 .958 r
.4837 .64465 .48899 .64952 .49843 .6509 .49316 .64643 Mtetra
.383 .67 .972 r
.49316 .64643 .49843 .6509 .50793 .65165 .50267 .6475 Mtetra
.485 .732 .981 r
.50267 .6475 .50793 .65165 .51749 .65127 .51225 .64724 Mtetra
.61 .785 .965 r
.51225 .64724 .51749 .65127 .52709 .64931 .52187 .64515 Mtetra
.702 .803 .927 r
.52187 .64515 .52709 .64931 .53672 .64573 .53153 .64114 Mtetra
.762 .796 .88 r
.53153 .64114 .53672 .64573 .54638 .64045 .54121 .63517 Mtetra
.782 .774 .846 r
.54121 .63517 .54638 .64045 .55604 .63405 .55089 .62793 Mtetra
.785 .75 .822 r
.55089 .62793 .55604 .63405 .5657 .62697 .56057 .62001 Mtetra
.769 .725 .812 r
.56057 .62001 .5657 .62697 .57538 .62005 .57027 .61241 Mtetra
.743 .703 .813 r
.57027 .61241 .57538 .62005 .58509 .61386 .57999 .60586 Mtetra
.71 .685 .823 r
.57999 .60586 .58509 .61386 .59483 .60879 .58975 .60079 Mtetra
.669 .67 .841 r
.58975 .60079 .59483 .60879 .60462 .60503 .59957 .59738 Mtetra
.635 .666 .862 r
.59957 .59738 .60462 .60503 .61447 .60224 .60944 .59513 Mtetra
.608 .67 .884 r
.60944 .59513 .61447 .60224 .62437 .60012 .61938 .59361 Mtetra
.606 .69 .902 r
.61938 .59361 .62437 .60012 .63432 .59807 .62936 .59206 Mtetra
.624 .714 .911 r
.62936 .59206 .63432 .59807 .6443 .59574 .63937 .58999 Mtetra
.657 .736 .908 r
.63937 .58999 .6443 .59574 .65429 .59286 .64939 .58709 Mtetra
.687 .746 .897 r
.64939 .58709 .65429 .59286 .6643 .58941 .65941 .58334 Mtetra
.701 .741 .882 r
.65941 .58334 .6643 .58941 .67433 .58569 .66944 .57908 Mtetra
.7 .724 .869 r
.66944 .57908 .67433 .58569 .68439 .58203 .67949 .57478 Mtetra
.675 .697 .863 r
.67949 .57478 .68439 .58203 .69452 .57905 .68961 .57121 Mtetra
.638 .666 .861 r
.68961 .57121 .69452 .57905 .70473 .57704 .69983 .56881 Mtetra
.581 .63 .865 r
.69983 .56881 .70473 .57704 .71507 .57637 .71017 .56809 Mtetra
.521 .6 .874 r
.71017 .56809 .71507 .57637 .72552 .57683 .72066 .56888 Mtetra
.466 .581 .886 r
.72066 .56888 .72552 .57683 .73608 .57806 .73127 .57074 Mtetra
.431 .583 .903 r
.73127 .57074 .73608 .57806 .74671 .57945 .74197 .57296 Mtetra
.445 .62 .926 r
.74197 .57296 .74671 .57945 .75737 .58018 .7527 .57449 Mtetra
.496 .679 .947 r
.7527 .57449 .75737 .58018 .768 .57976 .7634 .57475 Mtetra
.591 .751 .954 r
.7634 .57475 .768 .57976 .77856 .57763 .77402 .57301 Mtetra
.677 .8 .941 r
.77402 .57301 .77856 .57763 .78904 .57382 .78454 .56931 Mtetra
.745 .824 .913 r
.78454 .56931 .78904 .57382 .79941 .56839 .79494 .56371 Mtetra
.782 .826 .886 r
.79494 .56371 .79941 .56839 .80972 .56179 .80525 .55675 Mtetra
.796 .815 .867 r
.80525 .55675 .80972 .56179 .81998 .55452 .81551 .54903 Mtetra
.796 .8 .855 r
.81551 .54903 .81998 .55452 .83024 .54704 .82576 .54107 Mtetra
.783 .783 .853 r
.82576 .54107 .83024 .54704 .84054 .53988 .83606 .53352 Mtetra
.765 .766 .854 r
.83606 .53352 .84054 .53988 .8509 .53326 .84642 .5266 Mtetra
.739 .749 .861 r
.84642 .5266 .8509 .53326 .86137 .52749 .8569 .52065 Mtetra
.714 .736 .868 r
.8569 .52065 .86137 .52749 .87194 .52253 .8675 .51561 Mtetra
.687 .724 .878 r
.8675 .51561 .87194 .52253 .88264 .51842 .87822 .51151 Mtetra
.662 .715 .887 r
.87822 .51151 .88264 .51842 .89344 .51503 .88907 .5082 Mtetra
.64 .709 .896 r
.88907 .5082 .89344 .51503 .90436 .51223 .90003 .50552 Mtetra
.622 .705 .905 r
.90003 .50552 .90436 .51223 .91537 .50989 .91108 .50334 Mtetra
.609 .705 .912 r
.91108 .50334 .91537 .50989 .92647 .50787 .92223 .50147 Mtetra
.598 .706 .919 r
.92223 .50147 .92647 .50787 .93765 .50607 .93346 .49982 Mtetra
.591 .709 .926 r
.93346 .49982 .93765 .50607 .94889 .5044 .94475 .4983 Mtetra
.588 .714 .931 r
.94475 .4983 .94889 .5044 .9602 .50275 .9561 .4968 Mtetra
.72 .764 .887 r
.35813 .66383 .36369 .66869 .37282 .66442 .36728 .65944 Mtetra
.719 .76 .885 r
.36728 .65944 .37282 .66442 .38196 .66017 .37645 .65504 Mtetra
.715 .755 .883 r
.37645 .65504 .38196 .66017 .39113 .65603 .38564 .65075 Mtetra
.708 .749 .884 r
.38564 .65075 .39113 .65603 .40031 .65211 .39485 .64666 Mtetra
.697 .741 .885 r
.39485 .64666 .40031 .65211 .4095 .64848 .40407 .64286 Mtetra
.681 .732 .889 r
.40407 .64286 .4095 .64848 .41871 .64532 .4133 .63953 Mtetra
.657 .72 .895 r
.4133 .63953 .41871 .64532 .42792 .64278 .42253 .63683 Mtetra
.625 .706 .904 r
.42253 .63683 .42792 .64278 .43715 .64098 .43178 .63493 Mtetra
.579 .686 .914 r
.43178 .63493 .43715 .64098 .4464 .6401 .44104 .634 Mtetra
.525 .663 .923 r
.44104 .634 .4464 .6401 .45567 .64012 .45032 .63404 Mtetra
.454 .633 .931 r
.45032 .63404 .45567 .64012 .46497 .64108 .45963 .63513 Mtetra
.393 .609 .936 r
.45963 .63513 .46497 .64108 .47431 .64266 .46898 .63693 Mtetra
.34 .591 .938 r
.46898 .63693 .47431 .64266 .4837 .64465 .47838 .63921 Mtetra
.344 .606 .946 r
.47838 .63921 .4837 .64465 .49316 .64643 .48785 .64126 Mtetra
.402 .648 .957 r
.48785 .64126 .49316 .64643 .50267 .6475 .49738 .64253 Mtetra
.512 .708 .959 r
.49738 .64253 .50267 .6475 .51225 .64724 .50697 .64229 Mtetra
.633 .753 .935 r
.50697 .64229 .51225 .64724 .52187 .64515 .51662 .63997 Mtetra
.716 .767 .892 r
.51662 .63997 .52187 .64515 .53153 .64114 .5263 .63547 Mtetra
.767 .76 .846 r
.5263 .63547 .53153 .64114 .54121 .63517 .536 .62876 Mtetra
.783 .742 .815 r
.536 .62876 .54121 .63517 .55089 .62793 .5457 .6207 Mtetra
.783 .723 .796 r
.5457 .6207 .55089 .62793 .56057 .62001 .55541 .61199 Mtetra
.766 .702 .792 r
.55541 .61199 .56057 .62001 .57027 .61241 .56512 .60388 Mtetra
.737 .683 .798 r
.56512 .60388 .57027 .61241 .57999 .60586 .57485 .5972 Mtetra
.699 .667 .815 r
.57485 .5972 .57999 .60586 .58975 .60079 .58463 .59239 Mtetra
.65 .653 .84 r
.58463 .59239 .58975 .60079 .59957 .59738 .59448 .58962 Mtetra
.608 .652 .868 r
.59448 .58962 .59957 .59738 .60944 .59513 .60439 .58815 Mtetra
.574 .661 .896 r
.60439 .58815 .60944 .59513 .61938 .59361 .61437 .5874 Mtetra
.576 .689 .918 r
.61437 .5874 .61938 .59361 .62936 .59206 .62439 .58642 Mtetra
.607 .724 .927 r
.62439 .58642 .62936 .59206 .63937 .58999 .63442 .58466 Mtetra
.656 .753 .921 r
.63442 .58466 .63937 .58999 .64939 .58709 .64447 .58173 Mtetra
.698 .766 .904 r
.64447 .58173 .64939 .58709 .65941 .58334 .6545 .57765 Mtetra
.721 .761 .884 r
.6545 .57765 .65941 .58334 .66944 .57908 .66453 .57277 Mtetra
.723 .741 .866 r
.66453 .57277 .66944 .57908 .67949 .57478 .67457 .56765 Mtetra
.698 .71 .857 r
.67457 .56765 .67949 .57478 .68961 .57121 .68468 .56325 Mtetra
.658 .673 .853 r
.68468 .56325 .68961 .57121 .69983 .56881 .69488 .56017 Mtetra
.593 .627 .855 r
.69488 .56017 .69983 .56881 .71017 .56809 .70522 .55913 Mtetra
.524 .585 .858 r
.70522 .55913 .71017 .56809 .72066 .56888 .71572 .56001 Mtetra
.46 .554 .865 r
.71572 .56001 .72066 .56888 .73127 .57074 .72637 .56236 Mtetra
.419 .545 .877 r
.72637 .56236 .73127 .57074 .74197 .57296 .73713 .56532 Mtetra
.432 .575 .896 r
.73713 .56532 .74197 .57296 .7527 .57449 .74793 .56765 Mtetra
.484 .63 .917 r
.74793 .56765 .7527 .57449 .7634 .57475 .7587 .56863 Mtetra
.583 .704 .926 r
.7587 .56863 .7634 .57475 .77402 .57301 .76938 .56735 Mtetra
.672 .757 .915 r
.76938 .56735 .77402 .57301 .78454 .56931 .77994 .56385 Mtetra
.741 .787 .89 r
.77994 .56385 .78454 .56931 .79494 .56371 .79037 .55819 Mtetra
.779 .795 .866 r
.79037 .55819 .79494 .56371 .80525 .55675 .8007 .55098 Mtetra
.794 .791 .849 r
.8007 .55098 .80525 .55675 .81551 .54903 .81096 .54294 Mtetra
.795 .782 .84 r
.81096 .54294 .81551 .54903 .82576 .54107 .82122 .53465 Mtetra
.782 .769 .841 r
.82122 .53465 .82576 .54107 .83606 .53352 .83152 .52683 Mtetra
.765 .757 .846 r
.83152 .52683 .83606 .53352 .84642 .5266 .84191 .51973 Mtetra
.739 .744 .856 r
.84191 .51973 .84642 .5266 .8569 .52065 .85241 .51371 Mtetra
.713 .734 .867 r
.85241 .51371 .8569 .52065 .8675 .51561 .86303 .50868 Mtetra
.684 .724 .88 r
.86303 .50868 .8675 .51561 .87822 .51151 .87379 .50466 Mtetra
.658 .716 .891 r
.87379 .50466 .87822 .51151 .88907 .5082 .88468 .50147 Mtetra
.635 .711 .902 r
.88468 .50147 .88907 .5082 .90003 .50552 .89568 .49893 Mtetra
.615 .707 .911 r
.89568 .49893 .90003 .50552 .91108 .50334 .90679 .49688 Mtetra
.601 .707 .918 r
.90679 .49688 .91108 .50334 .92223 .50147 .91798 .49514 Mtetra
.591 .707 .924 r
.91798 .49514 .92223 .50147 .93346 .49982 .92925 .49362 Mtetra
.584 .709 .929 r
.92925 .49362 .93346 .49982 .94475 .4983 .94059 .49221 Mtetra
.582 .713 .933 r
.94059 .49221 .94475 .4983 .9561 .4968 .95198 .4908 Mtetra
.722 .764 .886 r
.35253 .65894 .35813 .66383 .36728 .65944 .3617 .65447 Mtetra
.722 .762 .884 r
.3617 .65447 .36728 .65944 .37645 .65504 .3709 .64998 Mtetra
.718 .759 .884 r
.3709 .64998 .37645 .65504 .38564 .65075 .38012 .64557 Mtetra
.712 .754 .885 r
.38012 .64557 .38564 .65075 .39485 .64666 .38935 .64135 Mtetra
.703 .748 .887 r
.38935 .64135 .39485 .64666 .40407 .64286 .3986 .63738 Mtetra
.687 .74 .891 r
.3986 .63738 .40407 .64286 .4133 .63953 .40785 .63388 Mtetra
.664 .728 .897 r
.40785 .63388 .4133 .63953 .42253 .63683 .41711 .631 Mtetra
.631 .713 .905 r
.41711 .631 .42253 .63683 .43178 .63493 .42638 .62892 Mtetra
.584 .691 .915 r
.42638 .62892 .43178 .63493 .44104 .634 .43566 .62785 Mtetra
.529 .665 .923 r
.43566 .62785 .44104 .634 .45032 .63404 .44495 .62782 Mtetra
.456 .63 .928 r
.44495 .62782 .45032 .63404 .45963 .63513 .45427 .62891 Mtetra
.397 .602 .929 r
.45427 .62891 .45963 .63513 .46898 .63693 .46363 .63078 Mtetra
.348 .58 .929 r
.46363 .63078 .46898 .63693 .47838 .63921 .47304 .63319 Mtetra
.362 .593 .934 r
.47304 .63319 .47838 .63921 .48785 .64126 .48252 .63538 Mtetra
.427 .631 .94 r
.48252 .63538 .48785 .64126 .49738 .64253 .49206 .6367 Mtetra
.537 .684 .934 r
.49206 .6367 .49738 .64253 .50697 .64229 .50167 .63638 Mtetra
.65 .723 .902 r
.50167 .63638 .50697 .64229 .51662 .63997 .51134 .63373 Mtetra
.724 .734 .86 r
.51134 .63373 .51662 .63997 .5263 .63547 .52104 .62869 Mtetra
.769 .73 .817 r
.52104 .62869 .5263 .63547 .536 .62876 .53076 .62122 Mtetra
.781 .716 .791 r
.53076 .62122 .536 .62876 .5457 .6207 .54049 .61239 Mtetra
.779 .7 .776 r
.54049 .61239 .5457 .6207 .55541 .61199 .55021 .60304 Mtetra
.76 .683 .777 r
.55021 .60304 .55541 .61199 .56512 .60388 .55993 .59463 Mtetra
.727 .666 .79 r
.55993 .59463 .56512 .60388 .57485 .5972 .56969 .58812 Mtetra
.683 .652 .814 r
.56969 .58812 .57485 .5972 .58463 .59239 .5795 .58393 Mtetra
.619 .639 .849 r
.5795 .58393 .58463 .59239 .59448 .58962 .58938 .58214 Mtetra
.564 .641 .886 r
.58938 .58214 .59448 .58962 .60439 .58815 .59933 .58172 Mtetra
.518 .656 .921 r
.59933 .58172 .60439 .58815 .61437 .5874 .60934 .5819 Mtetra
.526 .696 .947 r
.60934 .5819 .61437 .5874 .62439 .58642 .6194 .5816 Mtetra
.578 .747 .957 r
.6194 .5816 .62439 .58642 .63442 .58466 .62947 .58015 Mtetra
.65 .787 .947 r
.62947 .58015 .63442 .58466 .64447 .58173 .63954 .5772 Mtetra
.712 .803 .922 r
.63954 .5772 .64447 .58173 .6545 .57765 .64959 .57277 Mtetra
.747 .797 .893 r
.64959 .57277 .6545 .57765 .66453 .57277 .65962 .56717 Mtetra
.754 .774 .869 r
.65962 .56717 .66453 .57277 .67457 .56765 .66966 .56108 Mtetra
.73 .738 .857 r
.66966 .56108 .67457 .56765 .68468 .56325 .67973 .55558 Mtetra
.687 .693 .85 r
.67973 .55558 .68468 .56325 .69488 .56017 .6899 .55146 Mtetra
.614 .636 .849 r
.6899 .55146 .69488 .56017 .70522 .55913 .70022 .54976 Mtetra
.536 .582 .849 r
.70022 .54976 .70522 .55913 .71572 .56001 .71072 .55041 Mtetra
.46 .537 .849 r
.71072 .55041 .71572 .56001 .72637 .56236 .72139 .55301 Mtetra
.411 .516 .855 r
.72139 .55301 .72637 .56236 .73713 .56532 .7322 .55659 Mtetra
.421 .538 .87 r
.7322 .55659 .73713 .56532 .74793 .56765 .74306 .55966 Mtetra
.471 .587 .888 r
.74306 .55966 .74793 .56765 .7587 .56863 .7539 .56137 Mtetra
.571 .661 .898 r
.7539 .56137 .7587 .56863 .76938 .56735 .76463 .5606 Mtetra
.661 .717 .89 r
.76463 .5606 .76938 .56735 .77994 .56385 .77524 .55739 Mtetra
.732 .752 .869 r
.77524 .55739 .77994 .56385 .79037 .55819 .7857 .55178 Mtetra
.772 .766 .848 r
.7857 .55178 .79037 .55819 .8007 .55098 .79605 .54447 Mtetra
.788 .768 .834 r
.79605 .54447 .8007 .55098 .81096 .54294 .80634 .53625 Mtetra
.791 .764 .828 r
.80634 .53625 .81096 .54294 .82122 .53465 .81661 .52778 Mtetra
.779 .757 .833 r
.81661 .52778 .82122 .53465 .83152 .52683 .82694 .51985 Mtetra
.762 .749 .841 r
.82694 .51985 .83152 .52683 .84191 .51973 .83735 .51271 Mtetra
.736 .74 .855 r
.83735 .51271 .84191 .51973 .85241 .51371 .84788 .50672 Mtetra
.709 .732 .869 r
.84788 .50672 .85241 .51371 .86303 .50868 .85855 .5018 Mtetra
.679 .725 .884 r
.85855 .5018 .86303 .50868 .87379 .50466 .86935 .49791 Mtetra
.652 .718 .897 r
.86935 .49791 .87379 .50466 .88468 .50147 .88028 .49487 Mtetra
.628 .714 .908 r
.88028 .49487 .88468 .50147 .89568 .49893 .89133 .49247 Mtetra
.608 .71 .917 r
.89133 .49247 .89568 .49893 .90679 .49688 .90248 .49056 Mtetra
.595 .71 .924 r
.90248 .49056 .90679 .49688 .91798 .49514 .91371 .48892 Mtetra
.585 .71 .929 r
.91371 .48892 .91798 .49514 .92925 .49362 .92502 .48747 Mtetra
.579 .711 .933 r
.92502 .48747 .92925 .49362 .94059 .49221 .9364 .48612 Mtetra
.578 .713 .935 r
.9364 .48612 .94059 .49221 .95198 .4908 .94784 .48476 Mtetra
.722 .764 .886 r
.34689 .65403 .35253 .65894 .3617 .65447 .35609 .64951 Mtetra
.723 .764 .885 r
.35609 .64951 .3617 .65447 .3709 .64998 .36532 .64497 Mtetra
.721 .762 .886 r
.36532 .64497 .3709 .64998 .38012 .64557 .37456 .64049 Mtetra
.715 .759 .887 r
.37456 .64049 .38012 .64557 .38935 .64135 .38381 .63616 Mtetra
.707 .755 .889 r
.38381 .63616 .38935 .64135 .3986 .63738 .39308 .63206 Mtetra
.693 .748 .894 r
.39308 .63206 .3986 .63738 .40785 .63388 .40236 .62839 Mtetra
.671 .737 .9 r
.40236 .62839 .40785 .63388 .41711 .631 .41165 .6253 Mtetra
.639 .721 .908 r
.41165 .6253 .41711 .631 .42638 .62892 .42094 .62302 Mtetra
.592 .699 .917 r
.42094 .62302 .42638 .62892 .43566 .62785 .43024 .62175 Mtetra
.537 .67 .924 r
.43024 .62175 .43566 .62785 .44495 .62782 .43955 .62154 Mtetra
.464 .633 .927 r
.43955 .62154 .44495 .62782 .45427 .62891 .44889 .62252 Mtetra
.406 .601 .926 r
.44889 .62252 .45427 .62891 .46363 .63078 .45826 .62433 Mtetra
.36 .576 .923 r
.45826 .62433 .46363 .63078 .47304 .63319 .46768 .62675 Mtetra
.38 .587 .924 r
.46768 .62675 .47304 .63319 .48252 .63538 .47716 .62893 Mtetra
.45 .622 .925 r
.47716 .62893 .48252 .63538 .49206 .6367 .48671 .63019 Mtetra
.558 .669 .912 r
.48671 .63019 .49206 .6367 .50167 .63638 .49634 .62967 Mtetra
.663 .703 .876 r
.49634 .62967 .50167 .63638 .51134 .63373 .50603 .62663 Mtetra
.729 .713 .835 r
.50603 .62663 .51134 .63373 .52104 .62869 .51575 .62102 Mtetra
.77 .71 .796 r
.51575 .62102 .52104 .62869 .53076 .62122 .5255 .61283 Mtetra
.78 .699 .775 r
.5255 .61283 .53076 .62122 .54049 .61239 .53524 .60336 Mtetra
.777 .687 .765 r
.53524 .60336 .54049 .61239 .55021 .60304 .54498 .5936 Mtetra
.754 .674 .772 r
.54498 .5936 .55021 .60304 .55993 .59463 .55473 .58524 Mtetra
.715 .66 .794 r
.55473 .58524 .55993 .59463 .56969 .58812 .56451 .57933 Mtetra
.658 .649 .83 r
.56451 .57933 .56969 .58812 .5795 .58393 .57434 .57617 Mtetra
.567 .635 .879 r
.57434 .57617 .5795 .58393 .58938 .58214 .58426 .5757 Mtetra
.482 .639 .925 r
.58426 .5757 .58938 .58214 .59933 .58172 .59426 .57649 Mtetra
.418 .658 .959 r
.59426 .57649 .59933 .58172 .60934 .5819 .60431 .57757 Mtetra
.442 .712 .981 r
.60431 .57757 .60934 .5819 .6194 .5816 .61441 .57782 Mtetra
.534 .78 .988 r
.61441 .57782 .6194 .5816 .62947 .58015 .62452 .57656 Mtetra
.637 .826 .973 r
.62452 .57656 .62947 .58015 .63954 .5772 .63461 .5736 Mtetra
.718 .846 .943 r
.63461 .5736 .63954 .5772 .64959 .57277 .64469 .56893 Mtetra
.769 .844 .908 r
.64469 .56893 .64959 .57277 .65962 .56717 .65473 .56275 Mtetra
.788 .823 .88 r
.65473 .56275 .65962 .56717 .66966 .56108 .66476 .55571 Mtetra
.772 .788 .866 r
.66476 .55571 .66966 .56108 .67973 .55558 .67481 .54896 Mtetra
.73 .738 .858 r
.67481 .54896 .67973 .55558 .6899 .55146 .68494 .54345 Mtetra
.647 .67 .857 r
.68494 .54345 .6899 .55146 .70022 .54976 .69522 .54067 Mtetra
.556 .601 .853 r
.69522 .54067 .70022 .54976 .71072 .55041 .7057 .54067 Mtetra
.465 .537 .847 r
.7057 .54067 .71072 .55041 .72139 .55301 .71637 .54318 Mtetra
.404 .501 .844 r
.71637 .54318 .72139 .55301 .7322 .55659 .7272 .54712 Mtetra
.408 .513 .853 r
.7272 .54712 .7322 .55659 .74306 .55966 .73811 .5508 Mtetra
.455 .555 .869 r
.73811 .5508 .74306 .55966 .7539 .56137 .749 .55319 Mtetra
.557 .628 .878 r
.749 .55319 .7539 .56137 .76463 .5606 .75979 .55296 Mtetra
.647 .686 .872 r
.75979 .55296 .76463 .5606 .77524 .55739 .77045 .5501 Mtetra
.721 .725 .853 r
.77045 .5501 .77524 .55739 .7857 .55178 .78095 .54466 Mtetra
.763 .744 .835 r
.78095 .54466 .7857 .55178 .79605 .54447 .79134 .53737 Mtetra
.782 .751 .825 r
.79134 .53737 .79605 .54447 .80634 .53625 .80165 .52912 Mtetra
.786 .752 .821 r
.80165 .52912 .80634 .53625 .81661 .52778 .81195 .52061 Mtetra
.775 .748 .828 r
.81195 .52061 .81661 .52778 .82694 .51985 .82231 .5127 Mtetra
.759 .744 .84 r
.82231 .5127 .82694 .51985 .83735 .51271 .83276 .50563 Mtetra
.732 .738 .856 r
.83276 .50563 .83735 .51271 .84788 .50672 .84334 .49977 Mtetra
.704 .733 .873 r
.84334 .49977 .84788 .50672 .85855 .5018 .85405 .49502 Mtetra
.673 .727 .89 r
.85405 .49502 .85855 .5018 .86935 .49791 .8649 .49131 Mtetra
.645 .722 .904 r
.8649 .49131 .86935 .49791 .88028 .49487 .87588 .48843 Mtetra
.621 .718 .915 r
.87588 .48843 .88028 .49487 .89133 .49247 .88697 .48617 Mtetra
.601 .714 .924 r
.88697 .48617 .89133 .49247 .90248 .49056 .89816 .48436 Mtetra
.589 .714 .93 r
.89816 .48436 .90248 .49056 .91371 .48892 .90943 .48279 Mtetra
.58 .713 .933 r
.90943 .48279 .91371 .48892 .92502 .48747 .92078 .48138 Mtetra
.576 .713 .936 r
.92078 .48138 .92502 .48747 .9364 .48612 .93219 .48005 Mtetra
.577 .715 .937 r
.93219 .48005 .9364 .48612 .94784 .48476 .94366 .47868 Mtetra
.721 .764 .886 r
.34122 .64908 .34689 .65403 .35609 .64951 .35044 .64458 Mtetra
.723 .765 .886 r
.35044 .64458 .35609 .64951 .36532 .64497 .35969 .64003 Mtetra
.722 .766 .888 r
.35969 .64003 .36532 .64497 .37456 .64049 .36895 .63551 Mtetra
.717 .765 .89 r
.36895 .63551 .37456 .64049 .38381 .63616 .37823 .63112 Mtetra
.711 .762 .892 r
.37823 .63112 .38381 .63616 .39308 .63206 .38753 .62691 Mtetra
.698 .756 .897 r
.38753 .62691 .39308 .63206 .40236 .62839 .39683 .62308 Mtetra
.678 .747 .903 r
.39683 .62308 .40236 .62839 .41165 .6253 .40615 .61979 Mtetra
.647 .732 .911 r
.40615 .61979 .41165 .6253 .42094 .62302 .41547 .61728 Mtetra
.602 .71 .92 r
.41547 .61728 .42094 .62302 .43024 .62175 .42479 .61575 Mtetra
.548 .68 .926 r
.42479 .61575 .43024 .62175 .43955 .62154 .43412 .6153 Mtetra
.476 .641 .929 r
.43412 .6153 .43955 .62154 .44889 .62252 .44347 .61607 Mtetra
.42 .607 .925 r
.44347 .61607 .44889 .62252 .45826 .62433 .45285 .6177 Mtetra
.378 .579 .92 r
.45285 .6177 .45826 .62433 .46768 .62675 .46228 .61998 Mtetra
.402 .587 .917 r
.46228 .61998 .46768 .62675 .47716 .62893 .47178 .62201 Mtetra
.473 .618 .912 r
.47178 .62201 .47716 .62893 .48671 .63019 .48134 .62308 Mtetra
.577 .659 .893 r
.48134 .62308 .48671 .63019 .49634 .62967 .49099 .62226 Mtetra
.674 .688 .855 r
.49099 .62226 .49634 .62967 .50603 .62663 .50069 .61877 Mtetra
.734 .697 .815 r
.50069 .61877 .50603 .62663 .51575 .62102 .51044 .61259 Mtetra
.771 .696 .781 r
.51044 .61259 .51575 .62102 .5255 .61283 .52021 .60377 Mtetra
.778 .688 .764 r
.52021 .60377 .5255 .61283 .53524 .60336 .52997 .59387 Mtetra
.773 .679 .76 r
.52997 .59387 .53524 .60336 .54498 .5936 .53973 .58405 Mtetra
.746 .669 .775 r
.53973 .58405 .54498 .5936 .55473 .58524 .5495 .57618 Mtetra
.695 .659 .81 r
.5495 .57618 .55473 .58524 .56451 .57933 .55931 .5714 Mtetra
.612 .652 .865 r
.55931 .5714 .56451 .57933 .57434 .57617 .56918 .56976 Mtetra
.45 .627 .928 r
.56918 .56976 .57434 .57617 .58426 .5757 .57915 .57099 Mtetra
.289 .615 .957 r
.57915 .57099 .58426 .5757 .59426 .57649 .58919 .57311 Mtetra
.202 .626 .949 r
.58919 .57311 .59426 .57649 .60431 .57757 .59928 .57492 Mtetra
.279 .707 .968 r
.59928 .57492 .60431 .57757 .61441 .57782 .60941 .57546 Mtetra
.455 .814 .996 r
.60941 .57546 .61441 .57782 .62452 .57656 .61955 .57416 Mtetra
.601 .871 .993 r
.61955 .57416 .62452 .57656 .63461 .5736 .62968 .57119 Mtetra
.703 .898 .967 r
.62968 .57119 .63461 .5736 .64469 .56893 .6398 .56652 Mtetra
.78 .908 .929 r
.6398 .56652 .64469 .56893 .65473 .56275 .64987 .56001 Mtetra
.818 .894 .896 r
.64987 .56001 .65473 .56275 .66476 .55571 .6599 .55221 Mtetra
.821 .863 .879 r
.6599 .55221 .66476 .55571 .67481 .54896 .66993 .54408 Mtetra
.788 .809 .87 r
.66993 .54408 .67481 .54896 .68494 .54345 .68001 .53682 Mtetra
.699 .73 .874 r
.68001 .53682 .68494 .54345 .69522 .54067 .69024 .53245 Mtetra
.594 .642 .868 r
.69024 .53245 .69522 .54067 .7057 .54067 .70067 .53127 Mtetra
.481 .555 .855 r
.70067 .53127 .7057 .54067 .71637 .54318 .71132 .53322 Mtetra
.403 .499 .843 r
.71132 .53322 .71637 .54318 .7272 .54712 .72216 .53717 Mtetra
.398 .497 .843 r
.72216 .53717 .7272 .54712 .73811 .5508 .73309 .54125 Mtetra
.439 .531 .854 r
.73309 .54125 .73811 .5508 .749 .55319 .74404 .54424 Mtetra
.542 .601 .863 r
.74404 .54424 .749 .55319 .75979 .55296 .75488 .54454 Mtetra
.633 .66 .858 r
.75488 .54454 .75979 .55296 .77045 .5501 .76559 .54211 Mtetra
.709 .703 .842 r
.76559 .54211 .77045 .5501 .78095 .54466 .77613 .53693 Mtetra
.753 .726 .827 r
.77613 .53693 .78095 .54466 .79134 .53737 .78656 .52979 Mtetra
.774 .737 .819 r
.78656 .52979 .79134 .53737 .80165 .52912 .79691 .52165 Mtetra
.781 .742 .818 r
.79691 .52165 .80165 .52912 .81195 .52061 .80725 .51323 Mtetra
.77 .742 .828 r
.80725 .51323 .81195 .52061 .82231 .5127 .81766 .50546 Mtetra
.754 .742 .841 r
.81766 .50546 .82231 .5127 .83276 .50563 .82815 .49857 Mtetra
.727 .739 .861 r
.82815 .49857 .83276 .50563 .84334 .49977 .83878 .49293 Mtetra
.698 .735 .88 r
.83878 .49293 .84334 .49977 .85405 .49502 .84954 .4884 Mtetra
.666 .731 .898 r
.84954 .4884 .85405 .49502 .8649 .49131 .86045 .48489 Mtetra
.637 .726 .912 r
.86045 .48489 .8649 .49131 .87588 .48843 .87147 .48218 Mtetra
.614 .723 .923 r
.87147 .48218 .87588 .48843 .88697 .48617 .88261 .48004 Mtetra
.595 .72 .931 r
.88261 .48004 .88697 .48617 .89816 .48436 .89384 .47831 Mtetra
.585 .719 .935 r
.89384 .47831 .89816 .48436 .90943 .48279 .90514 .47676 Mtetra
.578 .717 .938 r
.90514 .47676 .90943 .48279 .92078 .48138 .91652 .47535 Mtetra
.576 .716 .938 r
.91652 .47535 .92078 .48138 .93219 .48005 .92796 .47398 Mtetra
.578 .717 .938 r
.92796 .47398 .93219 .48005 .94366 .47868 .93945 .47256 Mtetra
.719 .764 .888 r
.33552 .6441 .34122 .64908 .35044 .64458 .34476 .63965 Mtetra
.721 .767 .888 r
.34476 .63965 .35044 .64458 .35969 .64003 .35402 .63513 Mtetra
.721 .769 .89 r
.35402 .63513 .35969 .64003 .36895 .63551 .36331 .63062 Mtetra
.718 .769 .893 r
.36331 .63062 .36895 .63551 .37823 .63112 .37261 .6262 Mtetra
.714 .768 .895 r
.37261 .6262 .37823 .63112 .38753 .62691 .38193 .62191 Mtetra
.702 .764 .9 r
.38193 .62191 .38753 .62691 .39683 .62308 .39126 .61794 Mtetra
.685 .756 .906 r
.39126 .61794 .39683 .62308 .40615 .61979 .4006 .61446 Mtetra
.656 .742 .913 r
.4006 .61446 .40615 .61979 .41547 .61728 .40995 .6117 Mtetra
.614 .721 .922 r
.40995 .6117 .41547 .61728 .42479 .61575 .4193 .60989 Mtetra
.561 .692 .928 r
.4193 .60989 .42479 .61575 .43412 .6153 .42865 .60915 Mtetra
.49 .652 .931 r
.42865 .60915 .43412 .6153 .44347 .61607 .43802 .60963 Mtetra
.437 .617 .926 r
.43802 .60963 .44347 .61607 .45285 .6177 .44742 .611 Mtetra
.395 .587 .92 r
.44742 .611 .45285 .6177 .46228 .61998 .45686 .61305 Mtetra
.423 .593 .914 r
.45686 .61305 .46228 .61998 .47178 .62201 .46637 .61485 Mtetra
.494 .62 .905 r
.46637 .61485 .47178 .62201 .48134 .62308 .47595 .61564 Mtetra
.594 .657 .881 r
.47595 .61564 .48134 .62308 .49099 .62226 .48561 .61444 Mtetra
.685 .682 .841 r
.48561 .61444 .49099 .62226 .50069 .61877 .49533 .61047 Mtetra
.74 .69 .803 r
.49533 .61047 .50069 .61877 .51044 .61259 .5051 .60375 Mtetra
.773 .69 .772 r
.5051 .60375 .51044 .61259 .52021 .60377 .51489 .5944 Mtetra
.777 .683 .76 r
.51489 .5944 .52021 .60377 .52997 .59387 .52468 .5843 Mtetra
.768 .677 .763 r
.52468 .5843 .52997 .59387 .53973 .58405 .53447 .57482 Mtetra
.733 .671 .789 r
.53447 .57482 .53973 .58405 .5495 .57618 .54426 .56797 Mtetra
.657 .663 .845 r
.54426 .56797 .5495 .57618 .55931 .5714 .5541 .56491 Mtetra
.504 .65 .923 r
.5541 .56491 .55931 .5714 .56918 .56976 .56402 .56529 Mtetra
.147 .541 .923 r
.56402 .56529 .56918 .56976 .57915 .57099 .57403 .56847 Mtetra
0 .449 .792 r
.57403 .56847 .57915 .57099 .58919 .57311 .58411 .57171 Mtetra
0 .504 .763 r
.58411 .57171 .58919 .57311 .59928 .57492 .59424 .57362 Mtetra
.167 .686 .886 r
.59424 .57362 .59928 .57492 .60941 .57546 .60439 .57374 Mtetra
.46 .843 .985 r
.60439 .57374 .60941 .57546 .61955 .57416 .61455 .57186 Mtetra
.596 .874 .993 r
.61455 .57186 .61955 .57416 .62968 .57119 .62472 .56887 Mtetra
.669 .896 .978 r
.62472 .56887 .62968 .57119 .6398 .56652 .63488 .56475 Mtetra
.757 .934 .944 r
.63488 .56475 .6398 .56652 .64987 .56001 .64501 .55863 Mtetra
.819 .95 .906 r
.64501 .55863 .64987 .56001 .6599 .55221 .65509 .55069 Mtetra
.856 .941 .876 r
.65509 .55069 .6599 .55221 .66993 .54408 .66512 .54139 Mtetra
.851 .897 .869 r
.66512 .54139 .66993 .54408 .68001 .53682 .67514 .53213 Mtetra
.77 .817 .89 r
.67514 .53213 .68001 .53682 .69024 .53245 .68531 .52569 Mtetra
.654 .711 .89 r
.68531 .52569 .69024 .53245 .70067 .53127 .69566 .52271 Mtetra
.514 .595 .873 r
.69566 .52271 .70067 .53127 .71132 .53322 .70627 .52358 Mtetra
.411 .512 .851 r
.70627 .52358 .71132 .53322 .72216 .53717 .71709 .52715 Mtetra
.39 .492 .842 r
.71709 .52715 .72216 .53717 .73309 .54125 .72804 .53138 Mtetra
.422 .514 .848 r
.72804 .53138 .73309 .54125 .74404 .54424 .73902 .53485 Mtetra
.525 .583 .856 r
.73902 .53485 .74404 .54424 .75488 .54454 .74991 .53567 Mtetra
.618 .643 .852 r
.74991 .53567 .75488 .54454 .76559 .54211 .76067 .53368 Mtetra
.697 .689 .838 r
.76067 .53368 .76559 .54211 .77613 .53693 .77126 .52884 Mtetra
.745 .716 .824 r
.77126 .52884 .77613 .53693 .78656 .52979 .78173 .52195 Mtetra
.768 .73 .818 r
.78173 .52195 .78656 .52979 .79691 .52165 .79213 .51401 Mtetra
.775 .738 .818 r
.79213 .51401 .79691 .52165 .80725 .51323 .80252 .50578 Mtetra
.765 .74 .83 r
.80252 .50578 .80725 .51323 .81766 .50546 .81298 .49824 Mtetra
.749 .742 .846 r
.81298 .49824 .81766 .50546 .82815 .49857 .82352 .4916 Mtetra
.72 .74 .867 r
.82352 .4916 .82815 .49857 .83878 .49293 .83421 .48622 Mtetra
.691 .738 .887 r
.83421 .48622 .83878 .49293 .84954 .4884 .84503 .48194 Mtetra
.658 .735 .906 r
.84503 .48194 .84954 .4884 .86045 .48489 .85598 .47865 Mtetra
.629 .731 .921 r
.85598 .47865 .86045 .48489 .87147 .48218 .86706 .4761 Mtetra
.607 .728 .931 r
.86706 .4761 .87147 .48218 .88261 .48004 .87823 .47406 Mtetra
.59 .725 .937 r
.87823 .47406 .88261 .48004 .89384 .47831 .8895 .47237 Mtetra
.582 .724 .94 r
.8895 .47237 .89384 .47831 .90514 .47676 .90083 .47081 Mtetra
.578 .722 .941 r
.90083 .47081 .90514 .47676 .91652 .47535 .91224 .46935 Mtetra
.577 .72 .94 r
.91224 .46935 .91652 .47535 .92796 .47398 .9237 .4679 Mtetra
.58 .72 .938 r
.9237 .4679 .92796 .47398 .93945 .47256 .93521 .46639 Mtetra
.716 .763 .89 r
.32977 .63908 .33552 .6441 .34476 .63965 .33903 .63472 Mtetra
.719 .767 .891 r
.33903 .63472 .34476 .63965 .35402 .63513 .34831 .63027 Mtetra
.72 .771 .893 r
.34831 .63027 .35402 .63513 .36331 .63062 .35762 .6258 Mtetra
.718 .773 .896 r
.35762 .6258 .36331 .63062 .37261 .6262 .36695 .62138 Mtetra
.715 .773 .898 r
.36695 .62138 .37261 .6262 .38193 .62191 .37629 .61704 Mtetra
.706 .771 .903 r
.37629 .61704 .38193 .62191 .39126 .61794 .38565 .61297 Mtetra
.691 .765 .908 r
.38565 .61297 .39126 .61794 .4006 .61446 .39502 .60932 Mtetra
.665 .753 .916 r
.39502 .60932 .4006 .61446 .40995 .6117 .40439 .60632 Mtetra
.626 .733 .924 r
.40439 .60632 .40995 .6117 .4193 .60989 .41377 .60421 Mtetra
.575 .705 .931 r
.41377 .60421 .4193 .60989 .42865 .60915 .42315 .60314 Mtetra
.506 .666 .934 r
.42315 .60314 .42865 .60915 .43802 .60963 .43254 .6033 Mtetra
.453 .63 .93 r
.43254 .6033 .43802 .60963 .44742 .611 .44195 .60436 Mtetra
.412 .599 .923 r
.44195 .60436 .44742 .611 .45686 .61305 .45141 .60613 Mtetra
.441 .604 .915 r
.45141 .60613 .45686 .61305 .46637 .61485 .46093 .60763 Mtetra
.513 .629 .902 r
.46093 .60763 .46637 .61485 .47595 .61564 .47053 .60807 Mtetra
.61 .661 .874 r
.47053 .60807 .47595 .61564 .48561 .61444 .48021 .60646 Mtetra
.696 .683 .833 r
.48021 .60646 .48561 .61444 .49533 .61047 .48995 .60198 Mtetra
.746 .689 .796 r
.48995 .60198 .49533 .61047 .5051 .60375 .49975 .59476 Mtetra
.777 .69 .767 r
.49975 .59476 .5051 .60375 .51489 .5944 .50956 .58503 Mtetra
.776 .683 .761 r
.50956 .58503 .51489 .5944 .52468 .5843 .51937 .57501 Mtetra
.761 .68 .773 r
.51937 .57501 .52468 .5843 .53447 .57482 .52918 .56632 Mtetra
.709 .677 .817 r
.52918 .56632 .53447 .57482 .54426 .56797 .539 .5611 Mtetra
.564 .664 .905 r
.539 .5611 .54426 .56797 .5541 .56491 .54888 .56044 Mtetra
.173 .559 .932 r
.54888 .56044 .5541 .56491 .56402 .56529 .55884 .56334 Mtetra
.415 0 0 r
.55884 .56334 .56402 .56529 .57403 .56847 .5689 .56865 Mtetra
.461 0 0 r
.5689 .56865 .57403 .56847 .58411 .57171 .57903 .57259 Mtetra
.232 0 0 r
.57903 .57259 .58411 .57171 .59424 .57362 .58918 .57357 Mtetra
.201 .729 .817 r
.58918 .57357 .59424 .57362 .60439 .57374 .59933 .57218 Mtetra
.575 .898 .985 r
.59933 .57218 .60439 .57374 .61455 .57186 .60949 .56893 Mtetra
.619 .854 .988 r
.60949 .56893 .61455 .57186 .62472 .56887 .61969 .56592 Mtetra
.602 .849 .991 r
.61969 .56592 .62472 .56887 .63488 .56475 .62993 .56315 Mtetra
.673 .928 .971 r
.62993 .56315 .63488 .56475 .64501 .55863 .64015 .55851 Mtetra
.745 .984 .906 r
.64015 .55851 .64501 .55863 .65509 .55069 .65031 .55148 Mtetra
.835 .998 .829 r
.65031 .55148 .65509 .55069 .66512 .54139 .66037 .54144 Mtetra
.89 .977 .822 r
.66037 .54144 .66512 .54139 .67514 .53213 .67035 .53 Mtetra
.848 .922 .88 r
.67035 .53 .67514 .53213 .68531 .52569 .68044 .52097 Mtetra
.74 .812 .909 r
.68044 .52097 .68531 .52569 .69566 .52271 .6907 .51552 Mtetra
.57 .664 .901 r
.6907 .51552 .69566 .52271 .70627 .52358 .70124 .5147 Mtetra
.433 .544 .87 r
.70124 .5147 .70627 .52358 .71709 .52715 .71202 .51741 Mtetra
.387 .497 .849 r
.71202 .51741 .71709 .52715 .72804 .53138 .72296 .5215 Mtetra
.404 .504 .848 r
.72296 .5215 .72804 .53138 .73902 .53485 .73398 .52533 Mtetra
.507 .571 .855 r
.73398 .52533 .73902 .53485 .74991 .53567 .74491 .5266 Mtetra
.603 .632 .853 r
.74491 .5266 .74991 .53567 .76067 .53368 .75571 .52508 Mtetra
.687 .681 .839 r
.75571 .52508 .76067 .53368 .77126 .52884 .76636 .52063 Mtetra
.737 .711 .826 r
.76636 .52063 .77126 .52884 .78173 .52195 .77688 .51405 Mtetra
.762 .727 .821 r
.77688 .51405 .78173 .52195 .79213 .51401 .78733 .50637 Mtetra
.771 .737 .822 r
.78733 .50637 .79213 .51401 .80252 .50578 .79777 .49839 Mtetra
.76 .741 .836 r
.79777 .49839 .80252 .50578 .81298 .49824 .80828 .49112 Mtetra
.743 .744 .853 r
.80828 .49112 .81298 .49824 .82352 .4916 .81888 .48477 Mtetra
.713 .743 .875 r
.81888 .48477 .82352 .4916 .83421 .48622 .82963 .47969 Mtetra
.682 .742 .896 r
.82963 .47969 .83421 .48622 .84503 .48194 .8405 .47568 Mtetra
.65 .739 .915 r
.8405 .47568 .84503 .48194 .85598 .47865 .85151 .47259 Mtetra
.621 .736 .929 r
.85151 .47259 .85598 .47865 .86706 .4761 .86263 .47018 Mtetra
.601 .733 .937 r
.86263 .47018 .86706 .4761 .87823 .47406 .87384 .46821 Mtetra
.586 .73 .943 r
.87384 .46821 .87823 .47406 .8895 .47237 .88514 .46653 Mtetra
.581 .729 .944 r
.88514 .46653 .8895 .47237 .90083 .47081 .89651 .46493 Mtetra
.579 .727 .944 r
.89651 .46493 .90083 .47081 .91224 .46935 .90793 .46338 Mtetra
.58 .725 .942 r
.90793 .46338 .91224 .46935 .9237 .4679 .91942 .46182 Mtetra
.585 .723 .939 r
.91942 .46182 .9237 .4679 .93521 .46639 .93095 .46018 Mtetra
.712 .763 .892 r
.32399 .63404 .32977 .63908 .33903 .63472 .33327 .62978 Mtetra
.715 .768 .894 r
.33327 .62978 .33903 .63472 .34831 .63027 .34256 .62543 Mtetra
.717 .772 .896 r
.34256 .62543 .34831 .63027 .35762 .6258 .35189 .62104 Mtetra
.717 .776 .899 r
.35189 .62104 .35762 .6258 .36695 .62138 .36124 .61665 Mtetra
.716 .778 .901 r
.36124 .61665 .36695 .62138 .37629 .61704 .37061 .61229 Mtetra
.709 .777 .905 r
.37061 .61229 .37629 .61704 .38565 .61297 .37999 .60813 Mtetra
.696 .772 .91 r
.37999 .60813 .38565 .61297 .39502 .60932 .38939 .60431 Mtetra
.673 .761 .917 r
.38939 .60431 .39502 .60932 .40439 .60632 .39879 .60108 Mtetra
.638 .744 .925 r
.39879 .60108 .40439 .60632 .41377 .60421 .40819 .59866 Mtetra
.591 .717 .932 r
.40819 .59866 .41377 .60421 .42315 .60314 .4176 .59725 Mtetra
.524 .679 .936 r
.4176 .59725 .42315 .60314 .43254 .6033 .42702 .59707 Mtetra
.471 .644 .932 r
.42702 .59707 .43254 .6033 .44195 .60436 .43645 .5978 Mtetra
.428 .611 .926 r
.43645 .5978 .44195 .60436 .45141 .60613 .44593 .59929 Mtetra
.457 .616 .918 r
.44593 .59929 .45141 .60613 .46093 .60763 .45546 .60049 Mtetra
.527 .639 .904 r
.45546 .60049 .46093 .60763 .47053 .60807 .46508 .60061 Mtetra
.623 .67 .874 r
.46508 .60061 .47053 .60807 .48021 .60646 .47477 .59862 Mtetra
.707 .691 .832 r
.47477 .59862 .48021 .60646 .48995 .60198 .48454 .5937 Mtetra
.756 .697 .796 r
.48454 .5937 .48995 .60198 .49975 .59476 .49436 .58604 Mtetra
.784 .697 .768 r
.49436 .58604 .49975 .59476 .50956 .58503 .5042 .57597 Mtetra
.777 .689 .767 r
.5042 .57597 .50956 .58503 .51937 .57501 .51403 .56621 Mtetra
.749 .686 .79 r
.51403 .56621 .51937 .57501 .52918 .56632 .52386 .55863 Mtetra
.661 .68 .857 r
.52386 .55863 .52918 .56632 .539 .5611 .53371 .55548 Mtetra
.325 .597 .944 r
.53371 .55548 .539 .5611 .54888 .56044 .54362 .55774 Mtetra
.39 0 0 r
.54362 .55774 .54888 .56044 .55884 .56334 .55363 .56351 Mtetra
.66 .116 0 r
.55363 .56351 .55884 .56334 .5689 .56865 .56375 .57093 Mtetra
.537 0 0 r
.56375 .57093 .5689 .56865 .57903 .57259 .57391 .57473 Mtetra
.065 0 0 r
.57391 .57473 .57903 .57259 .58918 .57357 .58405 .57315 Mtetra
.607 .941 .944 r
.58405 .57315 .58918 .57357 .59933 .57218 .59418 .5686 Mtetra
.758 .855 .922 r
.59418 .5686 .59933 .57218 .60949 .56893 .60431 .56276 Mtetra
.656 .731 .905 r
.60431 .56276 .60949 .56893 .61969 .56592 .61453 .55973 Mtetra
.525 .679 .935 r
.61453 .55973 .61969 .56592 .62993 .56315 .62488 .55951 Mtetra
.535 .794 .993 r
.62488 .55951 .62993 .56315 .64015 .55851 .63524 .55801 Mtetra
.593 .937 .942 r
.63524 .55801 .64015 .55851 .65031 .55148 .64553 .55352 Mtetra
.76 .988 .765 r
.64553 .55352 .65031 .55148 .66037 .54144 .65565 .5436 Mtetra
.883 .988 .729 r
.65565 .5436 .66037 .54144 .67035 .53 .66561 .53001 Mtetra
.899 .973 .813 r
.66561 .53001 .67035 .53 .68044 .52097 .67562 .51803 Mtetra
.831 .894 .886 r
.67562 .51803 .68044 .52097 .6907 .51552 .68578 .50959 Mtetra
.65 .742 .917 r
.68578 .50959 .6907 .51552 .70124 .5147 .69622 .50663 Mtetra
.471 .59 .89 r
.69622 .50663 .70124 .5147 .71202 .51741 .70696 .50816 Mtetra
.387 .51 .861 r
.70696 .50816 .71202 .51741 .72296 .5215 .71789 .51194 Mtetra
.379 .499 .854 r
.71789 .51194 .72296 .5215 .73398 .52533 .72893 .51606 Mtetra
.486 .567 .863 r
.72893 .51606 .73398 .52533 .74491 .5266 .73989 .51774 Mtetra
.588 .631 .861 r
.73989 .51774 .74491 .5266 .75571 .52508 .75075 .51663 Mtetra
.678 .683 .847 r
.75075 .51663 .75571 .52508 .76636 .52063 .76144 .51252 Mtetra
.732 .713 .833 r
.76144 .51252 .76636 .52063 .77688 .51405 .77201 .50622 Mtetra
.758 .729 .826 r
.77201 .50622 .77688 .51405 .78733 .50637 .78251 .4988 Mtetra
.767 .739 .828 r
.78251 .4988 .78733 .50637 .79777 .49839 .793 .49107 Mtetra
.755 .743 .842 r
.793 .49107 .79777 .49839 .80828 .49112 .80357 .4841 Mtetra
.736 .746 .86 r
.80357 .4841 .80828 .49112 .81888 .48477 .81423 .47806 Mtetra
.704 .745 .883 r
.81423 .47806 .81888 .48477 .82963 .47969 .82503 .47329 Mtetra
.672 .744 .905 r
.82503 .47329 .82963 .47969 .8405 .47568 .83597 .46956 Mtetra
.64 .742 .923 r
.83597 .46956 .8405 .47568 .85151 .47259 .84702 .46667 Mtetra
.613 .739 .935 r
.84702 .46667 .85151 .47259 .86263 .47018 .85819 .4644 Mtetra
.596 .738 .943 r
.85819 .4644 .86263 .47018 .87384 .46821 .86944 .46247 Mtetra
.584 .735 .947 r
.86944 .46247 .87384 .46821 .88514 .46653 .88077 .46077 Mtetra
.582 .734 .947 r
.88077 .46077 .88514 .46653 .89651 .46493 .89216 .45909 Mtetra
.582 .732 .946 r
.89216 .45909 .89651 .46493 .90793 .46338 .90361 .45743 Mtetra
.585 .729 .943 r
.90361 .45743 .90793 .46338 .91942 .46182 .9151 .45572 Mtetra
.59 .727 .938 r
.9151 .45572 .91942 .46182 .93095 .46018 .92665 .45393 Mtetra
.707 .762 .895 r
.31818 .62896 .32399 .63404 .33327 .62978 .32746 .62484 Mtetra
.711 .768 .897 r
.32746 .62484 .33327 .62978 .34256 .62543 .33678 .62061 Mtetra
.713 .774 .9 r
.33678 .62061 .34256 .62543 .35189 .62104 .34612 .61631 Mtetra
.715 .778 .902 r
.34612 .61631 .35189 .62104 .36124 .61665 .35549 .61198 Mtetra
.716 .781 .904 r
.35549 .61198 .36124 .61665 .37061 .61229 .36488 .60763 Mtetra
.711 .782 .907 r
.36488 .60763 .37061 .61229 .37999 .60813 .37429 .60341 Mtetra
.702 .778 .911 r
.37429 .60341 .37999 .60813 .38939 .60431 .38372 .59943 Mtetra
.682 .769 .917 r
.38372 .59943 .38939 .60431 .39879 .60108 .39315 .59596 Mtetra
.651 .753 .924 r
.39315 .59596 .39879 .60108 .40819 .59866 .40258 .59322 Mtetra
.607 .728 .931 r
.40258 .59322 .40819 .59866 .4176 .59725 .41202 .59145 Mtetra
.541 .692 .937 r
.41202 .59145 .4176 .59725 .42702 .59707 .42146 .59093 Mtetra
.487 .656 .935 r
.42146 .59093 .42702 .59707 .43645 .5978 .43092 .59136 Mtetra
.439 .623 .93 r
.43092 .59136 .43645 .5978 .44593 .59929 .44041 .5926 Mtetra
.465 .626 .923 r
.44041 .5926 .44593 .59929 .45546 .60049 .44996 .59359 Mtetra
.534 .651 .91 r
.44996 .59359 .45546 .60049 .46508 .60061 .45959 .59349 Mtetra
.632 .684 .881 r
.45959 .59349 .46508 .60061 .47477 .59862 .46931 .59123 Mtetra
.719 .706 .838 r
.46931 .59123 .47477 .59862 .48454 .5937 .4791 .58596 Mtetra
.767 .712 .8 r
.4791 .58596 .48454 .5937 .49436 .58604 .48894 .57793 Mtetra
.795 .711 .772 r
.48894 .57793 .49436 .58604 .5042 .57597 .49881 .56756 Mtetra
.78 .702 .778 r
.49881 .56756 .5042 .57597 .51403 .56621 .50867 .55814 Mtetra
.733 .696 .815 r
.50867 .55814 .51403 .56621 .52386 .55863 .51852 .55188 Mtetra
.565 .671 .91 r
.51852 .55188 .52386 .55863 .53371 .55548 .52839 .55113 Mtetra
0 .315 .761 r
.52839 .55113 .53371 .55548 .54362 .55774 .53833 .55672 Mtetra
.692 .149 0 r
.53833 .55672 .54362 .55774 .55363 .56351 .54839 .56559 Mtetra
.728 .245 .097 r
.54839 .56559 .55363 .56351 .56375 .57093 .55855 .57491 Mtetra
.506 .002 0 r
.55855 .57491 .56375 .57093 .57391 .57473 .56874 .57738 Mtetra
.442 .851 .677 r
.56874 .57738 .57391 .57473 .58405 .57315 .57886 .57114 Mtetra
.863 .91 .862 r
.57886 .57114 .58405 .57315 .59418 .5686 .58892 .5613 Mtetra
.802 .739 .794 r
.58892 .5613 .59418 .5686 .60431 .56276 .59899 .55136 Mtetra
.642 .602 .794 r
.59899 .55136 .60431 .56276 .61453 .55973 .60922 .5483 Mtetra
.423 .483 .818 r
.60922 .5483 .61453 .55973 .62488 .55951 .61968 .55215 Mtetra
.304 .522 .9 r
.61968 .55215 .62488 .55951 .63524 .55801 .63022 .55591 Mtetra
.251 .717 .947 r
.63022 .55591 .63524 .55801 .64553 .55352 .64072 .55608 Mtetra
.628 .939 .713 r
.64072 .55608 .64553 .55352 .65565 .5436 .65095 .54748 Mtetra
.855 .964 .633 r
.65095 .54748 .65565 .5436 .66561 .53001 .6609 .53194 Mtetra
.918 .977 .72 r
.6609 .53194 .66561 .53001 .67562 .51803 .67083 .5168 Mtetra
.901 .94 .826 r
.67083 .5168 .67562 .51803 .68578 .50959 .68088 .50495 Mtetra
.739 .819 .914 r
.68088 .50495 .68578 .50959 .69622 .50663 .69123 .49951 Mtetra
.521 .647 .913 r
.69123 .49951 .69622 .50663 .70696 .50816 .70191 .49966 Mtetra
.383 .53 .879 r
.70191 .49966 .70696 .50816 .71789 .51194 .71283 .50304 Mtetra
.342 .495 .867 r
.71283 .50304 .71789 .51194 .72893 .51606 .72389 .50742 Mtetra
.458 .57 .88 r
.72389 .50742 .72893 .51606 .73989 .51774 .7349 .50944 Mtetra
.573 .639 .878 r
.7349 .50944 .73989 .51774 .75075 .51663 .74579 .50863 Mtetra
.674 .693 .86 r
.74579 .50863 .75075 .51663 .76144 .51252 .75652 .50474 Mtetra
.731 .722 .842 r
.75652 .50474 .76144 .51252 .77201 .50622 .76713 .49863 Mtetra
.757 .736 .833 r
.76713 .49863 .77201 .50622 .78251 .4988 .77767 .49139 Mtetra
.765 .744 .834 r
.77767 .49139 .78251 .4988 .793 .49107 .78821 .48387 Mtetra
.75 .746 .848 r
.78821 .48387 .793 .49107 .80357 .4841 .79883 .47717 Mtetra
.729 .748 .867 r
.79883 .47717 .80357 .4841 .81423 .47806 .80956 .47144 Mtetra
.695 .746 .891 r
.80956 .47144 .81423 .47806 .82503 .47329 .82042 .46699 Mtetra
.661 .745 .912 r
.82042 .46699 .82503 .47329 .83597 .46956 .83141 .46355 Mtetra
.63 .744 .93 r
.83141 .46355 .83597 .46956 .84702 .46667 .84252 .46087 Mtetra
.605 .742 .941 r
.84252 .46087 .84702 .46667 .85819 .4644 .85373 .45872 Mtetra
.591 .742 .948 r
.85373 .45872 .85819 .4644 .86944 .46247 .86502 .45682 Mtetra
.583 .74 .95 r
.86502 .45682 .86944 .46247 .88077 .46077 .87638 .45507 Mtetra
.585 .739 .949 r
.87638 .45507 .88077 .46077 .89216 .45909 .88779 .45329 Mtetra
.587 .737 .947 r
.88779 .45329 .89216 .45909 .90361 .45743 .89925 .45148 Mtetra
.591 .734 .943 r
.89925 .45148 .90361 .45743 .9151 .45572 .91076 .44961 Mtetra
.597 .731 .938 r
.91076 .44961 .9151 .45572 .92665 .45393 .92232 .44763 Mtetra
.701 .761 .898 r
.31232 .62385 .31818 .62896 .32746 .62484 .32162 .61988 Mtetra
.705 .768 .901 r
.32162 .61988 .32746 .62484 .33678 .62061 .33095 .61581 Mtetra
.709 .775 .904 r
.33095 .61581 .33678 .62061 .34612 .61631 .3403 .61164 Mtetra
.711 .781 .907 r
.3403 .61164 .34612 .61631 .35549 .61198 .34969 .6074 Mtetra
.714 .786 .908 r
.34969 .6074 .35549 .61198 .36488 .60763 .35911 .60307 Mtetra
.712 .787 .911 r
.35911 .60307 .36488 .60763 .37429 .60341 .36854 .59881 Mtetra
.707 .785 .913 r
.36854 .59881 .37429 .60341 .38372 .59943 .378 .59467 Mtetra
.691 .777 .917 r
.378 .59467 .38372 .59943 .39315 .59596 .38746 .59095 Mtetra
.666 .763 .922 r
.38746 .59095 .39315 .59596 .40258 .59322 .39693 .58785 Mtetra
.625 .738 .929 r
.39693 .58785 .40258 .59322 .41202 .59145 .4064 .58569 Mtetra
.562 .702 .935 r
.4064 .58569 .41202 .59145 .42146 .59093 .41587 .58478 Mtetra
.507 .666 .933 r
.41587 .58478 .42146 .59093 .43092 .59136 .42535 .58489 Mtetra
.453 .629 .929 r
.42535 .58489 .43092 .59136 .44041 .5926 .43485 .58592 Mtetra
.469 .63 .923 r
.43485 .58592 .44041 .5926 .44996 .59359 .44442 .5868 Mtetra
.531 .655 .914 r
.44442 .5868 .44996 .59359 .45959 .59349 .45406 .58669 Mtetra
.631 .695 .891 r
.45406 .58669 .45959 .59349 .46931 .59123 .4638 .58444 Mtetra
.724 .725 .85 r
.4638 .58444 .46931 .59123 .4791 .58596 .47361 .57913 Mtetra
.781 .737 .812 r
.47361 .57913 .4791 .58596 .48894 .57793 .48349 .57089 Mtetra
.812 .737 .782 r
.48349 .57089 .48894 .57793 .49881 .56756 .49339 .56017 Mtetra
.79 .726 .793 r
.49339 .56017 .49881 .56756 .50867 .55814 .50327 .55092 Mtetra
.719 .714 .845 r
.50327 .55092 .50867 .55814 .51852 .55188 .51314 .5457 Mtetra
.42 .627 .939 r
.51314 .5457 .51852 .55188 .52839 .55113 .52303 .54707 Mtetra
.522 0 0 r
.52303 .54707 .52839 .55113 .53833 .55672 .53299 .55575 Mtetra
.774 .27 0 r
.53299 .55575 .53833 .55672 .54839 .56559 .54308 .56753 Mtetra
.758 .287 .125 r
.54308 .56753 .54839 .56559 .55855 .57491 .55329 .57845 Mtetra
.338 0 0 r
.55329 .57845 .55855 .57491 .56874 .57738 .56349 .57853 Mtetra
.904 .98 .792 r
.56349 .57853 .56874 .57738 .57886 .57114 .57356 .56579 Mtetra
.891 .785 .738 r
.57356 .56579 .57886 .57114 .58892 .5613 .58354 .54882 Mtetra
.8 .66 .708 r
.58354 .54882 .58892 .5613 .59899 .55136 .59351 .53341 Mtetra
.622 .522 .72 r
.59351 .53341 .59899 .55136 .60922 .5483 .60373 .53032 Mtetra
.336 .344 .72 r
.60373 .53032 .60922 .5483 .61968 .55215 .61431 .53958 Mtetra
.103 .263 .743 r
.61431 .53958 .61968 .55215 .63022 .55591 .62506 .55046 Mtetra
0 .319 .793 r
.62506 .55046 .63022 .55591 .64072 .55608 .63579 .55713 Mtetra
.592 .948 .836 r
.63579 .55713 .64072 .55608 .65095 .54748 .64616 .55091 Mtetra
.91 .966 .652 r
.64616 .55091 .65095 .54748 .6609 .53194 .65613 .53373 Mtetra
.955 .951 .692 r
.65613 .53373 .6609 .53194 .67083 .5168 .666 .51562 Mtetra
.936 .917 .772 r
.666 .51562 .67083 .5168 .68088 .50495 .67596 .5006 Mtetra
.8 .84 .882 r
.67596 .5006 .68088 .50495 .69123 .49951 .68624 .49296 Mtetra
.564 .688 .923 r
.68624 .49296 .69123 .49951 .70191 .49966 .69688 .49201 Mtetra
.364 .547 .901 r
.69688 .49201 .70191 .49966 .71283 .50304 .7078 .49518 Mtetra
.276 .489 .884 r
.7078 .49518 .71283 .50304 .72389 .50742 .7189 .49987 Mtetra
.42 .583 .907 r
.7189 .49987 .72389 .50742 .7349 .50944 .72993 .50204 Mtetra
.565 .663 .904 r
.72993 .50204 .7349 .50944 .74579 .50863 .74084 .50124 Mtetra
.677 .713 .876 r
.74084 .50124 .74579 .50863 .75652 .50474 .7516 .49731 Mtetra
.735 .733 .85 r
.7516 .49731 .75652 .50474 .76713 .49863 .76223 .49116 Mtetra
.757 .74 .837 r
.76223 .49116 .76713 .49863 .77767 .49139 .77281 .48398 Mtetra
.761 .744 .837 r
.77281 .48398 .77767 .49139 .78821 .48387 .7834 .47663 Mtetra
.743 .744 .853 r
.7834 .47663 .78821 .48387 .79883 .47717 .79407 .47022 Mtetra
.719 .745 .872 r
.79407 .47022 .79883 .47717 .80956 .47144 .80486 .46485 Mtetra
.682 .744 .898 r
.80486 .46485 .80956 .47144 .82042 .46699 .81578 .46077 Mtetra
.648 .744 .919 r
.81578 .46077 .82042 .46699 .83141 .46355 .82684 .45765 Mtetra
.619 .745 .936 r
.82684 .45765 .83141 .46355 .84252 .46087 .838 .45519 Mtetra
.597 .745 .947 r
.838 .45519 .84252 .46087 .85373 .45872 .84926 .45316 Mtetra
.588 .747 .953 r
.84926 .45316 .85373 .45872 .86502 .45682 .86058 .45128 Mtetra
.584 .746 .954 r
.86058 .45128 .86502 .45682 .87638 .45507 .87196 .44945 Mtetra
.588 .746 .952 r
.87196 .44945 .87638 .45507 .88779 .45329 .8834 .44754 Mtetra
.593 .744 .948 r
.8834 .44754 .88779 .45329 .89925 .45148 .89487 .44555 Mtetra
.599 .74 .943 r
.89487 .44555 .89925 .45148 .91076 .44961 .9064 .44347 Mtetra
.605 .736 .937 r
.9064 .44347 .91076 .44961 .92232 .44763 .91796 .44128 Mtetra
.694 .76 .902 r
.30643 .61871 .31232 .62385 .32162 .61988 .31574 .61493 Mtetra
.698 .768 .905 r
.31574 .61493 .32162 .61988 .33095 .61581 .32508 .61103 Mtetra
.702 .776 .909 r
.32508 .61103 .33095 .61581 .3403 .61164 .33445 .60703 Mtetra
.707 .784 .912 r
.33445 .60703 .3403 .61164 .34969 .6074 .34385 .60291 Mtetra
.712 .79 .913 r
.34385 .60291 .34969 .6074 .35911 .60307 .35328 .59864 Mtetra
.713 .793 .914 r
.35328 .59864 .35911 .60307 .36854 .59881 .36275 .59434 Mtetra
.712 .793 .914 r
.36275 .59434 .36854 .59881 .378 .59467 .37223 .59005 Mtetra
.701 .786 .917 r
.37223 .59005 .378 .59467 .38746 .59095 .38173 .58605 Mtetra
.681 .772 .919 r
.38173 .58605 .38746 .59095 .39693 .58785 .39124 .58254 Mtetra
.645 .748 .924 r
.39124 .58254 .39693 .58785 .4064 .58569 .40075 .57992 Mtetra
.586 .712 .93 r
.40075 .57992 .4064 .58569 .41587 .58478 .41024 .57855 Mtetra
.53 .674 .929 r
.41024 .57855 .41587 .58478 .42535 .58489 .41975 .57829 Mtetra
.467 .633 .927 r
.41975 .57829 .42535 .58489 .43485 .58592 .42927 .57915 Mtetra
.468 .627 .922 r
.42927 .57915 .43485 .58592 .44442 .5868 .43885 .58006 Mtetra
.512 .65 .919 r
.43885 .58006 .44442 .5868 .45406 .58669 .4485 .58024 Mtetra
.613 .701 .907 r
.4485 .58024 .45406 .58669 .4638 .58444 .45824 .57838 Mtetra
.72 .747 .873 r
.45824 .57838 .4638 .58444 .47361 .57913 .46807 .57346 Mtetra
.794 .771 .833 r
.46807 .57346 .47361 .57913 .48349 .57089 .47798 .56529 Mtetra
.835 .775 .794 r
.47798 .56529 .48349 .57089 .49339 .56017 .48792 .55417 Mtetra
.81 .764 .811 r
.48792 .55417 .49339 .56017 .50327 .55092 .49784 .54473 Mtetra
.716 .744 .873 r
.49784 .54473 .50327 .55092 .51314 .5457 .50773 .53988 Mtetra
.285 .571 .936 r
.50773 .53988 .51314 .5457 .52303 .54707 .51762 .54259 Mtetra
.639 .118 0 r
.51762 .54259 .52303 .54707 .53299 .55575 .5276 .55359 Mtetra
.807 .317 0 r
.5276 .55359 .53299 .55575 .54308 .56753 .53771 .56769 Mtetra
.781 .294 .063 r
.53771 .56769 .54308 .56753 .55329 .57845 .54794 .57981 Mtetra
.258 .761 .725 r
.54794 .57981 .55329 .57845 .56349 .57853 .55815 .57659 Mtetra
.946 .844 .71 r
.55815 .57659 .56349 .57853 .57356 .56579 .56818 .55588 Mtetra
.878 .709 .668 r
.56818 .55588 .57356 .56579 .58354 .54882 .57806 .53032 Mtetra
.795 .617 .66 r
.57806 .53032 .58354 .54882 .59351 .53341 .5879 .50836 Mtetra
.608 .476 .676 r
.5879 .50836 .59351 .53341 .60373 .53032 .59808 .50523 Mtetra
.265 .248 .652 r
.59808 .50523 .60373 .53032 .61431 .53958 .60878 .52099 Mtetra
0 .088 .615 r
.60878 .52099 .61431 .53958 .62506 .55046 .61973 .54042 Mtetra
0 .024 .595 r
.61973 .54042 .62506 .55046 .63579 .55713 .63072 .55506 Mtetra
.559 .878 .992 r
.63072 .55506 .63579 .55713 .64616 .55091 .64124 .55214 Mtetra
.961 .94 .705 r
.64124 .55214 .64616 .55091 .65613 .53373 .65123 .53372 Mtetra
.97 .901 .695 r
.65123 .53372 .65613 .53373 .666 .51562 .66108 .51322 Mtetra
.94 .87 .742 r
.66108 .51322 .666 .51562 .67596 .5006 .67099 .49582 Mtetra
.824 .827 .851 r
.67099 .49582 .67596 .5006 .68624 .49296 .68124 .48678 Mtetra
.579 .709 .932 r
.68124 .48678 .68624 .49296 .69688 .49201 .69188 .48541 Mtetra
.303 .551 .921 r
.69188 .48541 .69688 .49201 .7078 .49518 .70283 .48872 Mtetra
.159 .468 .891 r
.70283 .48872 .7078 .49518 .7189 .49987 .71396 .49378 Mtetra
.37 .611 .943 r
.71396 .49378 .7189 .49987 .72993 .50204 .725 .49585 Mtetra
.57 .709 .936 r
.725 .49585 .72993 .50204 .74084 .50124 .73591 .4946 Mtetra
.693 .744 .89 r
.73591 .4946 .74084 .50124 .7516 .49731 .74667 .49022 Mtetra
.746 .748 .854 r
.74667 .49022 .7516 .49731 .76223 .49116 .75731 .48372 Mtetra
.759 .743 .838 r
.75731 .48372 .76223 .49116 .77281 .48398 .76792 .47647 Mtetra
.757 .741 .838 r
.76792 .47647 .77281 .48398 .7834 .47663 .77854 .46926 Mtetra
.733 .738 .855 r
.77854 .46926 .7834 .47663 .79407 .47022 .78928 .46318 Mtetra
.706 .739 .877 r
.78928 .46318 .79407 .47022 .80486 .46485 .80013 .45824 Mtetra
.667 .739 .904 r
.80013 .45824 .80486 .46485 .81578 .46077 .81113 .4546 Mtetra
.632 .741 .927 r
.81113 .4546 .81578 .46077 .82684 .45765 .82225 .45187 Mtetra
.606 .745 .943 r
.82225 .45187 .82684 .45765 .838 .45519 .83347 .44965 Mtetra
.587 .748 .954 r
.83347 .44965 .838 .45519 .84926 .45316 .84477 .44774 Mtetra
.584 .753 .958 r
.84477 .44774 .84926 .45316 .86058 .45128 .85612 .44585 Mtetra
.585 .753 .958 r
.85612 .44585 .86058 .45128 .87196 .44945 .86753 .44392 Mtetra
.593 .754 .954 r
.86753 .44392 .87196 .44945 .8834 .44754 .87898 .44184 Mtetra
.601 .751 .949 r
.87898 .44184 .8834 .44754 .89487 .44555 .89047 .43963 Mtetra
.607 .746 .943 r
.89047 .43963 .89487 .44555 .9064 .44347 .902 .43732 Mtetra
.614 .741 .936 r
.902 .43732 .9064 .44347 .91796 .44128 .91357 .43489 Mtetra
.686 .758 .906 r
.3005 .61354 .30643 .61871 .31574 .61493 .30981 .60996 Mtetra
.69 .767 .911 r
.30981 .60996 .31574 .61493 .32508 .61103 .31916 .60629 Mtetra
.694 .777 .915 r
.31916 .60629 .32508 .61103 .33445 .60703 .32854 .60249 Mtetra
.7 .787 .918 r
.32854 .60249 .33445 .60703 .34385 .60291 .33796 .59854 Mtetra
.707 .795 .919 r
.33796 .59854 .34385 .60291 .35328 .59864 .34741 .59438 Mtetra
.712 .801 .92 r
.34741 .59438 .35328 .59864 .36275 .59434 .3569 .5901 Mtetra
.716 .803 .919 r
.3569 .5901 .36275 .59434 .37223 .59005 .36642 .58568 Mtetra
.711 .798 .919 r
.36642 .58568 .37223 .59005 .38173 .58605 .37595 .58141 Mtetra
.698 .786 .919 r
.37595 .58141 .38173 .58605 .39124 .58254 .3855 .57746 Mtetra
.667 .763 .922 r
.3855 .57746 .39124 .58254 .40075 .57992 .39505 .57428 Mtetra
.616 .728 .926 r
.39505 .57428 .40075 .57992 .41024 .57855 .40458 .57228 Mtetra
.56 .686 .924 r
.40458 .57228 .41024 .57855 .41975 .57829 .41412 .57148 Mtetra
.492 .638 .92 r
.41412 .57148 .41975 .57829 .42927 .57915 .42366 .572 Mtetra
.473 .618 .913 r
.42366 .572 .42927 .57915 .43885 .58006 .43325 .57294 Mtetra
.486 .626 .913 r
.43325 .57294 .43885 .58006 .4485 .58024 .4429 .57366 Mtetra
.572 .682 .915 r
.4429 .57366 .4485 .58024 .45824 .57838 .45264 .57267 Mtetra
.688 .752 .9 r
.45264 .57267 .45824 .57838 .46807 .57346 .46248 .56882 Mtetra
.794 .806 .862 r
.46248 .56882 .46807 .57346 .47798 .56529 .47241 .56129 Mtetra
.858 .821 .811 r
.47241 .56129 .47798 .56529 .48792 .55417 .48239 .55003 Mtetra
.842 .822 .829 r
.48239 .55003 .48792 .55417 .49784 .54473 .49235 .54001 Mtetra
.748 .802 .896 r
.49235 .54001 .49784 .54473 .50773 .53988 .50227 .53437 Mtetra
.296 .592 .946 r
.50227 .53437 .50773 .53988 .51762 .54259 .51219 .53671 Mtetra
.558 .069 0 r
.51219 .53671 .51762 .54259 .5276 .55359 .52216 .54806 Mtetra
.746 .265 0 r
.52216 .54806 .5276 .55359 .53771 .56769 .53227 .56319 Mtetra
.716 .21 0 r
.53227 .56319 .53771 .56769 .54794 .57981 .54251 .5763 Mtetra
.753 .86 .928 r
.54251 .5763 .54794 .57981 .55815 .57659 .55274 .57052 Mtetra
.919 .758 .666 r
.55274 .57052 .55815 .57659 .56818 .55588 .56274 .54331 Mtetra
.879 .687 .639 r
.56274 .54331 .56818 .55588 .57806 .53032 .57255 .51048 Mtetra
.814 .621 .642 r
.57255 .51048 .57806 .53032 .5879 .50836 .58231 .48271 Mtetra
.607 .473 .673 r
.58231 .48271 .5879 .50836 .59808 .50523 .59245 .47954 Mtetra
.114 .14 .61 r
.59245 .47954 .59808 .50523 .60878 .52099 .60322 .50104 Mtetra
0 0 .492 r
.60322 .50104 .60878 .52099 .61973 .54042 .61431 .52772 Mtetra
0 0 .451 r
.61431 .52772 .61973 .54042 .63072 .55506 .62547 .54885 Mtetra
.526 .687 .941 r
.62547 .54885 .63072 .55506 .64124 .55214 .63611 .54846 Mtetra
.931 .829 .721 r
.63611 .54846 .64124 .55214 .65123 .53372 .64611 .52899 Mtetra
.928 .802 .7 r
.64611 .52899 .65123 .53372 .66108 .51322 .65597 .50742 Mtetra
.899 .789 .73 r
.65597 .50742 .66108 .51322 .67099 .49582 .66591 .48962 Mtetra
.8 .78 .834 r
.66591 .48962 .67099 .49582 .68124 .48678 .67622 .48091 Mtetra
.532 .702 .948 r
.67622 .48091 .68124 .48678 .69188 .48541 .68692 .4803 Mtetra
.149 .519 .916 r
.68692 .4803 .69188 .48541 .70283 .48872 .69792 .48416 Mtetra
0 .419 .848 r
.69792 .48416 .70283 .48872 .71396 .49378 .70908 .48932 Mtetra
.329 .662 .973 r
.70908 .48932 .71396 .49378 .725 .49585 .72011 .4907 Mtetra
.61 .769 .956 r
.72011 .4907 .725 .49585 .73591 .4946 .73098 .4883 Mtetra
.722 .766 .887 r
.73098 .4883 .73591 .4946 .74667 .49022 .7417 .48298 Mtetra
.757 .749 .845 r
.7417 .48298 .74667 .49022 .75731 .48372 .75234 .4759 Mtetra
.756 .733 .832 r
.75234 .4759 .75731 .48372 .76792 .47647 .76297 .46856 Mtetra
.747 .729 .836 r
.76297 .46856 .76792 .47647 .77854 .46926 .77365 .46165 Mtetra
.719 .728 .858 r
.77365 .46165 .77854 .46926 .78928 .46318 .78445 .45609 Mtetra
.688 .732 .884 r
.78445 .45609 .78928 .46318 .80013 .45824 .79538 .45176 Mtetra
.647 .737 .915 r
.79538 .45176 .80013 .45824 .81113 .4546 .80646 .44865 Mtetra
.611 .742 .939 r
.80646 .44865 .81113 .4546 .82225 .45187 .81765 .44634 Mtetra
.59 .751 .954 r
.81765 .44634 .82225 .45187 .83347 .44965 .82892 .44437 Mtetra
.577 .756 .963 r
.82892 .44437 .83347 .44965 .84477 .44774 .84027 .44254 Mtetra
.582 .762 .964 r
.84027 .44254 .84477 .44774 .85612 .44585 .85165 .44059 Mtetra
.588 .764 .962 r
.85165 .44059 .85612 .44585 .86753 .44392 .86308 .4385 Mtetra
.6 .763 .957 r
.86308 .4385 .86753 .44392 .87898 .44184 .87454 .4362 Mtetra
.61 .759 .95 r
.87454 .4362 .87898 .44184 .89047 .43963 .88604 .43374 Mtetra
.618 .753 .943 r
.88604 .43374 .89047 .43963 .902 .43732 .89757 .43115 Mtetra
.624 .746 .935 r
.89757 .43115 .902 .43732 .91357 .43489 .90915 .42846 Mtetra
.676 .756 .911 r
.29453 .60833 .3005 .61354 .30981 .60996 .30385 .60499 Mtetra
.679 .766 .917 r
.30385 .60499 .30981 .60996 .31916 .60629 .3132 .60157 Mtetra
.684 .778 .922 r
.3132 .60157 .31916 .60629 .32854 .60249 .32259 .59802 Mtetra
.691 .789 .925 r
.32259 .59802 .32854 .60249 .33796 .59854 .33202 .59428 Mtetra
.7 .8 .927 r
.33202 .59428 .33796 .59854 .34741 .59438 .34149 .5903 Mtetra
.708 .809 .928 r
.34149 .5903 .34741 .59438 .3569 .5901 .35099 .5861 Mtetra
.718 .815 .925 r
.35099 .5861 .3569 .5901 .36642 .58568 .36054 .58164 Mtetra
.719 .813 .924 r
.36054 .58164 .36642 .58568 .37595 .58141 .37011 .57713 Mtetra
.715 .804 .92 r
.37011 .57713 .37595 .58141 .3855 .57746 .37971 .57271 Mtetra
.692 .783 .921 r
.37971 .57271 .3855 .57746 .39505 .57428 .3893 .56888 Mtetra
.652 .75 .922 r
.3893 .56888 .39505 .57428 .40458 .57228 .39889 .56605 Mtetra
.6 .704 .916 r
.39889 .56605 .40458 .57228 .41412 .57148 .40847 .56445 Mtetra
.531 .649 .91 r
.40847 .56445 .41412 .57148 .42366 .572 .41804 .56434 Mtetra
.488 .61 .899 r
.41804 .56434 .42366 .572 .43325 .57294 .42764 .56519 Mtetra
.456 .592 .899 r
.42764 .56519 .43325 .57294 .4429 .57366 .43728 .56659 Mtetra
.504 .638 .914 r
.43728 .56659 .4429 .57366 .45264 .57267 .447 .56694 Mtetra
.61 .729 .93 r
.447 .56694 .45264 .57267 .46248 .56882 .45683 .56499 Mtetra
.766 .837 .906 r
.45683 .56499 .46248 .56882 .47241 .56129 .46677 .55891 Mtetra
.874 .876 .835 r
.46677 .55891 .47241 .56129 .48239 .55003 .47679 .54802 Mtetra
.878 .891 .838 r
.47679 .54802 .48239 .55003 .49235 .54001 .4868 .53711 Mtetra
.818 .876 .888 r
.4868 .53711 .49235 .54001 .50227 .53437 .49678 .52925 Mtetra
.498 .712 .966 r
.49678 .52925 .50227 .53437 .51219 .53671 .50673 .52896 Mtetra
0 .198 .725 r
.50673 .52896 .51219 .53671 .52216 .54806 .5167 .53786 Mtetra
0 0 .555 r
.5167 .53786 .52216 .54806 .53227 .56319 .52679 .55211 Mtetra
0 .043 .612 r
.52679 .55211 .53227 .56319 .54251 .5763 .53702 .56601 Mtetra
.716 .656 .79 r
.53702 .56601 .54251 .5763 .55274 .57052 .54725 .5596 Mtetra
.883 .701 .65 r
.54725 .5596 .55274 .57052 .56274 .54331 .55727 .52957 Mtetra
.881 .68 .627 r
.55727 .52957 .56274 .54331 .57255 .51048 .56709 .49289 Mtetra
.842 .645 .636 r
.56709 .49289 .57255 .51048 .58231 .48271 .57681 .46147 Mtetra
.615 .497 .695 r
.57681 .46147 .58231 .48271 .59245 .47954 .58693 .45826 Mtetra
0 0 .533 r
.58693 .45826 .59245 .47954 .60322 .50104 .59772 .48335 Mtetra
0 0 .342 r
.59772 .48335 .60322 .50104 .61431 .52772 .60885 .51383 Mtetra
0 0 .402 r
.60885 .51383 .61431 .52772 .62547 .54885 .62005 .53774 Mtetra
.549 .566 .824 r
.62005 .53774 .62547 .54885 .63611 .54846 .63071 .53793 Mtetra
.856 .705 .694 r
.63071 .53793 .63611 .54846 .64611 .52899 .64073 .51761 Mtetra
.851 .694 .688 r
.64073 .51761 .64611 .52899 .65597 .50742 .65065 .49688 Mtetra
.824 .697 .724 r
.65065 .49688 .65597 .50742 .66591 .48962 .66073 .48151 Mtetra
.728 .71 .834 r
.66073 .48151 .66591 .48962 .67622 .48091 .67118 .47544 Mtetra
.367 .637 .959 r
.67118 .47544 .67622 .48091 .68692 .4803 .68202 .47704 Mtetra
0 .386 .78 r
.68202 .47704 .68692 .4803 .69792 .48416 .69309 .48177 Mtetra
0 .332 .693 r
.69309 .48177 .69792 .48416 .70908 .48932 .70425 .48651 Mtetra
.344 .747 .982 r
.70425 .48651 .70908 .48932 .72011 .4907 .71523 .48636 Mtetra
.691 .832 .951 r
.71523 .48636 .72011 .4907 .73098 .4883 .72601 .482 Mtetra
.759 .777 .868 r
.72601 .482 .73098 .4883 .7417 .48298 .73668 .47525 Mtetra
.767 .74 .828 r
.73668 .47525 .7417 .48298 .75234 .4759 .74729 .46741 Mtetra
.748 .716 .822 r
.74729 .46741 .75234 .4759 .76297 .46856 .75795 .46013 Mtetra
.729 .711 .833 r
.75795 .46013 .76297 .46856 .77365 .46165 .7687 .45381 Mtetra
.696 .714 .862 r
.7687 .45381 .77365 .46165 .78445 .45609 .7796 .44904 Mtetra
.661 .724 .896 r
.7796 .44904 .78445 .45609 .79538 .45176 .79063 .44552 Mtetra
.62 .736 .93 r
.79063 .44552 .79538 .45176 .80646 .44865 .80179 .44304 Mtetra
.585 .746 .954 r
.80179 .44304 .80646 .44865 .81765 .44634 .81305 .44118 Mtetra
.571 .759 .967 r
.81305 .44118 .81765 .44634 .82892 .44437 .82438 .4394 Mtetra
.568 .767 .972 r
.82438 .4394 .82892 .44437 .84027 .44254 .83576 .43759 Mtetra
.581 .775 .971 r
.83576 .43759 .84027 .44254 .85165 .44059 .84717 .43551 Mtetra
.595 .776 .967 r
.84717 .43551 .85165 .44059 .86308 .4385 .85861 .43319 Mtetra
.61 .774 .959 r
.85861 .43319 .86308 .4385 .87454 .4362 .87008 .43062 Mtetra
.621 .769 .95 r
.87008 .43062 .87454 .4362 .88604 .43374 .88158 .42786 Mtetra
.629 .761 .942 r
.88158 .42786 .88604 .43374 .89757 .43115 .89312 .42496 Mtetra
.635 .752 .933 r
.89312 .42496 .89757 .43115 .90915 .42846 .90469 .42197 Mtetra
.666 .754 .916 r
.28853 .60308 .29453 .60833 .30385 .60499 .29785 .59998 Mtetra
.668 .764 .922 r
.29785 .59998 .30385 .60499 .3132 .60157 .3072 .59681 Mtetra
.673 .775 .927 r
.3072 .59681 .3132 .60157 .32259 .59802 .3166 .59352 Mtetra
.679 .787 .931 r
.3166 .59352 .32259 .59802 .33202 .59428 .32603 .59005 Mtetra
.689 .8 .934 r
.32603 .59005 .33202 .59428 .34149 .5903 .33551 .58633 Mtetra
.699 .813 .936 r
.33551 .58633 .34149 .5903 .35099 .5861 .34503 .58233 Mtetra
.713 .824 .934 r
.34503 .58233 .35099 .5861 .36054 .58164 .3546 .57797 Mtetra
.721 .83 .933 r
.3546 .57797 .36054 .58164 .37011 .57713 .36421 .57339 Mtetra
.727 .829 .928 r
.36421 .57339 .37011 .57713 .37971 .57271 .37384 .56864 Mtetra
.715 .815 .927 r
.37384 .56864 .37971 .57271 .3893 .56888 .38349 .56418 Mtetra
.69 .787 .925 r
.38349 .56418 .3893 .56888 .39889 .56605 .39313 .56038 Mtetra
.646 .74 .918 r
.39313 .56038 .39889 .56605 .40847 .56445 .40277 .55766 Mtetra
.583 .681 .907 r
.40277 .55766 .40847 .56445 .41804 .56434 .4124 .55645 Mtetra
.522 .62 .89 r
.4124 .55645 .41804 .56434 .42764 .56519 .42202 .55669 Mtetra
.452 .569 .882 r
.42202 .55669 .42764 .56519 .43728 .56659 .43166 .55841 Mtetra
.447 .576 .89 r
.43166 .55841 .43728 .56659 .447 .56694 .44136 .56009 Mtetra
.491 .642 .923 r
.44136 .56009 .447 .56694 .45683 .56499 .45114 .56055 Mtetra
.677 .801 .942 r
.45114 .56055 .45683 .56499 .46677 .55891 .46107 .55693 Mtetra
.849 .903 .873 r
.46107 .55693 .46677 .55891 .47679 .54802 .47111 .54779 Mtetra
.89 .949 .839 r
.47111 .54779 .47679 .54802 .4868 .53711 .48118 .53665 Mtetra
.883 .947 .848 r
.48118 .53665 .4868 .53711 .49678 .52925 .49123 .52594 Mtetra
.728 .86 .944 r
.49123 .52594 .49678 .52925 .50673 .52896 .50124 .52095 Mtetra
.346 .529 .892 r
.50124 .52095 .50673 .52896 .5167 .53786 .51123 .52415 Mtetra
.111 .249 .728 r
.51123 .52415 .5167 .53786 .52679 .55211 .52129 .53488 Mtetra
.094 .191 .675 r
.52129 .53488 .52679 .55211 .53702 .56601 .53148 .54887 Mtetra
.629 .534 .728 r
.53148 .54887 .53702 .56601 .54725 .5596 .54173 .5454 Mtetra
.841 .664 .662 r
.54173 .5454 .54725 .5596 .55727 .52957 .55183 .52015 Mtetra
.904 .717 .639 r
.55183 .52015 .55727 .52957 .56709 .49289 .56175 .48711 Mtetra
.93 .759 .649 r
.56175 .48711 .56709 .49289 .57681 .46147 .57157 .4572 Mtetra
.652 .809 .959 r
.57157 .4572 .57681 .46147 .58693 .45826 .58172 .45398 Mtetra
.879 .446 .07 r
.58172 .45398 .58693 .45826 .59772 .48335 .59246 .47751 Mtetra
.884 .464 .055 r
.59246 .47751 .59772 .48335 .60885 .51383 .60348 .50429 Mtetra
0 0 .371 r
.60348 .50429 .60885 .51383 .62005 .53774 .61452 .52333 Mtetra
.625 .559 .761 r
.61452 .52333 .62005 .53774 .63071 .53793 .62509 .5205 Mtetra
.797 .626 .669 r
.62509 .5205 .63071 .53793 .64073 .51761 .63512 .50003 Mtetra
.776 .614 .679 r
.63512 .50003 .64073 .51761 .65065 .49688 .64519 .4828 Mtetra
.733 .619 .732 r
.64519 .4828 .65065 .49688 .66073 .48151 .65551 .47315 Mtetra
.59 .649 .876 r
.65551 .47315 .66073 .48151 .67118 .47544 .66619 .47179 Mtetra
0 .425 .824 r
.66619 .47179 .67118 .47544 .68202 .47704 .67719 .47626 Mtetra
.415 0 0 r
.67719 .47626 .68202 .47704 .69309 .48177 .6883 .4812 Mtetra
.254 0 0 r
.6883 .4812 .69309 .48177 .70425 .48651 .69941 .48412 Mtetra
.542 .865 .995 r
.69941 .48412 .70425 .48651 .71523 .48636 .71028 .48141 Mtetra
.773 .828 .894 r
.71028 .48141 .71523 .48636 .72601 .482 .72095 .47452 Mtetra
.775 .749 .829 r
.72095 .47452 .72601 .482 .73668 .47525 .73155 .46637 Mtetra
.761 .712 .806 r
.73155 .46637 .73668 .47525 .74729 .46741 .74217 .45816 Mtetra
.73 .693 .815 r
.74217 .45816 .74729 .46741 .75795 .46013 .7529 .45145 Mtetra
.702 .695 .841 r
.7529 .45145 .75795 .46013 .7687 .45381 .76375 .44623 Mtetra
.665 .71 .881 r
.76375 .44623 .7687 .45381 .7796 .44904 .77476 .44256 Mtetra
.624 .73 .923 r
.77476 .44256 .7796 .44904 .79063 .44552 .7859 .44001 Mtetra
.583 .75 .957 r
.7859 .44001 .79063 .44552 .80179 .44304 .79714 .43813 Mtetra
.553 .763 .975 r
.79714 .43813 .80179 .44304 .81305 .44118 .80847 .43656 Mtetra
.554 .778 .982 r
.80847 .43656 .81305 .44118 .82438 .4394 .81984 .43482 Mtetra
.565 .785 .982 r
.81984 .43482 .82438 .4394 .83576 .43759 .83124 .43287 Mtetra
.588 .789 .976 r
.83124 .43287 .83576 .43759 .84717 .43551 .84267 .43053 Mtetra
.607 .788 .967 r
.84267 .43053 .84717 .43551 .85861 .43319 .85411 .4279 Mtetra
.623 .782 .957 r
.85411 .4279 .85861 .43319 .87008 .43062 .86559 .42501 Mtetra
.634 .774 .948 r
.86559 .42501 .87008 .43062 .88158 .42786 .87709 .42193 Mtetra
.641 .766 .938 r
.87709 .42193 .88158 .42786 .89312 .42496 .88863 .41872 Mtetra
.645 .756 .93 r
.88863 .41872 .89312 .42496 .90469 .42197 .90021 .41544 Mtetra
.657 .752 .92 r
.28248 .59781 .28853 .60308 .29785 .59998 .29181 .5949 Mtetra
.658 .76 .925 r
.29181 .5949 .29785 .59998 .3072 .59681 .30117 .59195 Mtetra
.661 .77 .93 r
.30117 .59195 .3072 .59681 .3166 .59352 .31057 .58892 Mtetra
.666 .782 .935 r
.31057 .58892 .3166 .59352 .32603 .59005 .32001 .58574 Mtetra
.673 .796 .94 r
.32001 .58574 .32603 .59005 .33551 .58633 .32949 .58236 Mtetra
.684 .812 .944 r
.32949 .58236 .33551 .58633 .34503 .58233 .33902 .57869 Mtetra
.699 .829 .945 r
.33902 .57869 .34503 .58233 .3546 .57797 .3486 .57463 Mtetra
.713 .845 .945 r
.3486 .57463 .3546 .57797 .36421 .57339 .35822 .57021 Mtetra
.729 .854 .94 r
.35822 .57021 .36421 .57339 .37384 .56864 .36789 .56537 Mtetra
.732 .851 .937 r
.36789 .56537 .37384 .56864 .38349 .56418 .37759 .56045 Mtetra
.727 .832 .93 r
.37759 .56045 .38349 .56418 .39313 .56038 .3873 .55564 Mtetra
.699 .789 .92 r
.3873 .55564 .39313 .56038 .40277 .55766 .39702 .55155 Mtetra
.652 .728 .905 r
.39702 .55155 .40277 .55766 .4124 .55645 .40671 .54867 Mtetra
.581 .651 .884 r
.40671 .54867 .4124 .55645 .42202 .55669 .41639 .54762 Mtetra
.484 .571 .867 r
.41639 .54762 .42202 .55669 .43166 .55841 .42604 .54889 Mtetra
.424 .528 .86 r
.42604 .54889 .43166 .55841 .44136 .56009 .43572 .55146 Mtetra
.373 .525 .88 r
.43572 .55146 .44136 .56009 .45114 .56055 .44546 .55447 Mtetra
.514 .682 .942 r
.44546 .55447 .45114 .56055 .46107 .55693 .45533 .55426 Mtetra
.75 .887 .941 r
.45533 .55426 .46107 .55693 .47111 .54779 .46535 .54863 Mtetra
.855 .987 .849 r
.46535 .54863 .47111 .54779 .48118 .53665 .47546 .53858 Mtetra
.91 .98 .777 r
.47546 .53858 .48118 .53665 .49123 .52594 .48561 .5252 Mtetra
.889 .936 .841 r
.48561 .5252 .49123 .52594 .50124 .52095 .49571 .51408 Mtetra
.726 .733 .856 r
.49571 .51408 .50124 .52095 .51123 .52415 .50576 .50859 Mtetra
.441 .435 .756 r
.50576 .50859 .51123 .52415 .52129 .53488 .51581 .51297 Mtetra
.264 .265 .673 r
.51581 .51297 .52129 .53488 .53148 .54887 .52595 .52576 Mtetra
.51 .422 .692 r
.52595 .52576 .53148 .54887 .54173 .5454 .53619 .529 Mtetra
.736 .599 .705 r
.53619 .529 .54173 .5454 .55183 .52015 .54641 .51744 Mtetra
.938 .834 .716 r
.54641 .51744 .55183 .52015 .56175 .48711 .55654 .49731 Mtetra
.712 .818 .36 r
.55654 .49731 .56175 .48711 .57157 .4572 .56658 .47564 Mtetra
.453 .131 .329 r
.56658 .47564 .57157 .4572 .58172 .45398 .57683 .47241 Mtetra
.703 .369 .408 r
.57683 .47241 .58172 .45398 .59246 .47751 .58747 .48769 Mtetra
.735 .353 .329 r
.58747 .48769 .59246 .47751 .60348 .50429 .59823 .50148 Mtetra
0 .283 .664 r
.59823 .50148 .60348 .50429 .61452 .52333 .60893 .50671 Mtetra
.715 .588 .713 r
.60893 .50671 .61452 .52333 .62509 .5205 .6193 .49705 Mtetra
.753 .575 .654 r
.6193 .49705 .62509 .5205 .63512 .50003 .62935 .47772 Mtetra
.696 .544 .677 r
.62935 .47772 .63512 .50003 .64519 .4828 .63965 .46684 Mtetra
.582 .519 .749 r
.63965 .46684 .64519 .4828 .65551 .47315 .65031 .46593 Mtetra
.206 .475 .89 r
.65031 .46593 .65551 .47315 .66619 .47179 .66126 .47076 Mtetra
.547 0 0 r
.66126 .47076 .66619 .47179 .67719 .47626 .67241 .47791 Mtetra
.476 0 0 r
.67241 .47791 .67719 .47626 .6883 .4812 .68352 .4817 Mtetra
0 0 0 r
.68352 .4817 .6883 .4812 .69941 .48412 .69448 .481 Mtetra
.756 .899 .941 r
.69448 .481 .69941 .48412 .71028 .48141 .70519 .47477 Mtetra
.81 .78 .825 r
.70519 .47477 .71028 .48141 .72095 .47452 .71574 .46522 Mtetra
.771 .707 .792 r
.71574 .46522 .72095 .47452 .73155 .46637 .72632 .45611 Mtetra
.74 .678 .791 r
.72632 .45611 .73155 .46637 .74217 .45816 .73698 .44831 Mtetra
.698 .669 .818 r
.73698 .44831 .74217 .45816 .7529 .45145 .74782 .44288 Mtetra
.658 .681 .86 r
.74782 .44288 .7529 .45145 .76375 .44623 .75883 .43933 Mtetra
.615 .712 .914 r
.75883 .43933 .76375 .44623 .77476 .44256 .76997 .43703 Mtetra
.565 .742 .96 r
.76997 .43703 .77476 .44256 .7859 .44001 .78122 .43548 Mtetra
.532 .772 .985 r
.78122 .43548 .7859 .44001 .79714 .43813 .79253 .43405 Mtetra
.521 .788 .993 r
.79253 .43405 .79714 .43813 .80847 .43656 .8039 .43253 Mtetra
.546 .802 .993 r
.8039 .43253 .80847 .43656 .81984 .43482 .81529 .43059 Mtetra
.574 .806 .987 r
.81529 .43059 .81984 .43482 .83124 .43287 .8267 .42827 Mtetra
.604 .804 .976 r
.8267 .42827 .83124 .43287 .84267 .43053 .83813 .42554 Mtetra
.625 .796 .964 r
.83813 .42554 .84267 .43053 .85411 .4279 .84958 .42252 Mtetra
.638 .786 .953 r
.84958 .42252 .85411 .4279 .86559 .42501 .86105 .41928 Mtetra
.647 .777 .942 r
.86105 .41928 .86559 .42501 .87709 .42193 .87256 .41589 Mtetra
.652 .767 .934 r
.87256 .41589 .87709 .42193 .88863 .41872 .8841 .4124 Mtetra
.654 .759 .927 r
.8841 .4124 .88863 .41872 .90021 .41544 .89569 .40886 Mtetra
.652 .75 .922 r
.27639 .59249 .28248 .59781 .29181 .5949 .28573 .58969 Mtetra
.651 .755 .925 r
.28573 .58969 .29181 .5949 .30117 .59195 .2951 .58688 Mtetra
.652 .761 .929 r
.2951 .58688 .30117 .59195 .31057 .58892 .30451 .58403 Mtetra
.655 .769 .933 r
.30451 .58403 .31057 .58892 .32001 .58574 .31396 .58109 Mtetra
.658 .78 .939 r
.31396 .58109 .32001 .58574 .32949 .58236 .32344 .57804 Mtetra
.666 .796 .944 r
.32344 .57804 .32949 .58236 .33902 .57869 .33297 .57478 Mtetra
.677 .816 .95 r
.33297 .57478 .33902 .57869 .3486 .57463 .34255 .57122 Mtetra
.692 .84 .954 r
.34255 .57122 .3486 .57463 .35822 .57021 .35218 .56725 Mtetra
.713 .862 .953 r
.35218 .56725 .35822 .57021 .36789 .56537 .36186 .56274 Mtetra
.729 .878 .95 r
.36186 .56274 .36789 .56537 .37759 .56045 .37159 .55778 Mtetra
.747 .879 .94 r
.37159 .55778 .37759 .56045 .3873 .55564 .38137 .55238 Mtetra
.742 .855 .932 r
.38137 .55238 .3873 .55564 .39702 .55155 .39116 .54712 Mtetra
.721 .807 .918 r
.39116 .54712 .39702 .55155 .40671 .54867 .40094 .54242 Mtetra
.656 .727 .901 r
.40094 .54242 .40671 .54867 .41639 .54762 .4107 .5394 Mtetra
.557 .629 .879 r
.4107 .5394 .41639 .54762 .42604 .54889 .42042 .53893 Mtetra
.462 .539 .85 r
.42042 .53893 .42604 .54889 .43572 .55146 .43011 .54088 Mtetra
.354 .465 .835 r
.43011 .54088 .43572 .55146 .44546 .55447 .43982 .54508 Mtetra
.396 .519 .864 r
.43982 .54508 .44546 .55447 .45533 .55426 .44963 .54803 Mtetra
.542 .691 .936 r
.44963 .54803 .45533 .55426 .46535 .54863 .45958 .54737 Mtetra
.767 .944 .938 r
.45958 .54737 .46535 .54863 .47546 .53858 .46968 .54089 Mtetra
.896 .988 .773 r
.46968 .54089 .47546 .53858 .48561 .5252 .47988 .52781 Mtetra
.927 .973 .74 r
.47988 .52781 .48561 .5252 .49571 .51408 .49009 .51255 Mtetra
.915 .891 .793 r
.49009 .51255 .49571 .51408 .50576 .50859 .50024 .49868 Mtetra
.665 .641 .816 r
.50024 .49868 .50576 .50859 .51581 .51297 .51033 .49484 Mtetra
.351 .352 .721 r
.51033 .49484 .51581 .51297 .52595 .52576 .52043 .50288 Mtetra
.384 .34 .685 r
.52043 .50288 .52595 .52576 .53619 .529 .53064 .51185 Mtetra
.434 .416 .74 r
.53064 .51185 .53619 .529 .54641 .51744 .54095 .51696 Mtetra
.344 .817 .902 r
.54095 .51696 .54641 .51744 .55654 .49731 .55129 .51484 Mtetra
.305 0 .257 r
.55129 .51484 .55654 .49731 .56658 .47564 .5616 .50649 Mtetra
.495 .213 .414 r
.5616 .50649 .56658 .47564 .57683 .47241 .572 .50328 Mtetra
.553 .263 .429 r
.572 .50328 .57683 .47241 .58747 .48769 .58252 .50522 Mtetra
.419 .092 .302 r
.58252 .50522 .58747 .48769 .59823 .50148 .59299 .50091 Mtetra
.892 .96 .834 r
.59299 .50091 .59823 .50148 .60893 .50671 .60332 .48933 Mtetra
.764 .609 .686 r
.60332 .48933 .60893 .50671 .6193 .49705 .61353 .47383 Mtetra
.723 .557 .665 r
.61353 .47383 .6193 .49705 .62935 .47772 .62372 .45923 Mtetra
.61 .514 .721 r
.62372 .45923 .62935 .47772 .63965 .46684 .63429 .4566 Mtetra
.176 .366 .813 r
.63429 .4566 .63965 .46684 .65031 .46593 .64527 .46413 Mtetra
.606 .041 0 r
.64527 .46413 .65031 .46593 .66126 .47076 .65642 .47312 Mtetra
.629 .1 0 r
.65642 .47312 .66126 .47076 .67241 .47791 .6676 .47994 Mtetra
.222 0 0 r
.6676 .47994 .67241 .47791 .68352 .4817 .67858 .48006 Mtetra
.71 .947 .956 r
.67858 .48006 .68352 .4817 .69448 .481 .68932 .47425 Mtetra
.807 .776 .824 r
.68932 .47425 .69448 .481 .70519 .47477 .6999 .46474 Mtetra
.787 .7 .768 r
.6999 .46474 .70519 .47477 .71574 .46522 .7104 .45393 Mtetra
.742 .662 .772 r
.7104 .45393 .71574 .46522 .72632 .45611 .72103 .44539 Mtetra
.705 .656 .799 r
.72103 .44539 .72632 .45611 .73698 .44831 .73183 .43933 Mtetra
.654 .669 .853 r
.73183 .43933 .73698 .44831 .74782 .44288 .74283 .43588 Mtetra
.591 .699 .918 r
.74283 .43588 .74782 .44288 .75883 .43933 .75399 .43416 Mtetra
.533 .744 .973 r
.75399 .43416 .75883 .43933 .76997 .43703 .76525 .43303 Mtetra
.48 .772 .995 r
.76525 .43303 .76997 .43703 .78122 .43548 .77658 .43204 Mtetra
.484 .801 1 r
.77658 .43204 .78122 .43548 .79253 .43405 .78794 .43061 Mtetra
.517 .817 .999 r
.78794 .43061 .79253 .43405 .8039 .43253 .79932 .42872 Mtetra
.568 .823 .993 r
.79932 .42872 .8039 .43253 .81529 .43059 .8107 .42626 Mtetra
.606 .817 .981 r
.8107 .42626 .81529 .43059 .8267 .42827 .8221 .42338 Mtetra
.631 .804 .966 r
.8221 .42338 .8267 .42827 .83813 .42554 .83352 .42019 Mtetra
.645 .791 .952 r
.83352 .42019 .83813 .42554 .84958 .42252 .84497 .41677 Mtetra
.652 .779 .941 r
.84497 .41677 .84958 .42252 .86105 .41928 .85645 .41323 Mtetra
.657 .77 .933 r
.85645 .41323 .86105 .41928 .87256 .41589 .86797 .4096 Mtetra
.659 .763 .927 r
.86797 .4096 .87256 .41589 .8841 .4124 .87953 .40593 Mtetra
.659 .757 .923 r
.87953 .40593 .8841 .4124 .89569 .40886 .89113 .40224 Mtetra
.652 .75 .922 r
.27027 .58715 .27639 .59249 .28573 .58969 .27962 .58433 Mtetra
.651 .75 .923 r
.27962 .58433 .28573 .58969 .2951 .58688 .28901 .58152 Mtetra
.65 .751 .923 r
.28901 .58152 .2951 .58688 .30451 .58403 .29844 .57873 Mtetra
.649 .754 .926 r
.29844 .57873 .30451 .58403 .31396 .58109 .30789 .57593 Mtetra
.647 .759 .931 r
.30789 .57593 .31396 .58109 .32344 .57804 .31738 .57316 Mtetra
.648 .771 .938 r
.31738 .57316 .32344 .57804 .33297 .57478 .32691 .57032 Mtetra
.65 .789 .948 r
.32691 .57032 .33297 .57478 .34255 .57122 .33648 .56737 Mtetra
.66 .817 .959 r
.33648 .56737 .34255 .57122 .35218 .56725 .3461 .56411 Mtetra
.676 .851 .966 r
.3461 .56411 .35218 .56725 .36186 .56274 .35577 .56037 Mtetra
.699 .887 .967 r
.35577 .56037 .36186 .56274 .37159 .55778 .36551 .55596 Mtetra
.734 .913 .955 r
.36551 .55596 .37159 .55778 .38137 .55238 .37531 .55066 Mtetra
.758 .918 .944 r
.37531 .55066 .38137 .55238 .39116 .54712 .38516 .54478 Mtetra
.777 .894 .927 r
.38516 .54478 .39116 .54712 .40094 .54242 .39505 .53847 Mtetra
.745 .83 .917 r
.39505 .53847 .40094 .54242 .4107 .5394 .40492 .53306 Mtetra
.674 .731 .893 r
.40492 .53306 .4107 .5394 .42042 .53893 .41475 .52952 Mtetra
.565 .605 .851 r
.41475 .52952 .42042 .53893 .43011 .54088 .42452 .52898 Mtetra
.432 .483 .812 r
.42452 .52898 .43011 .54088 .43982 .54508 .43424 .53217 Mtetra
.372 .431 .793 r
.43424 .53217 .43982 .54508 .44963 .54803 .444 .53705 Mtetra
.326 .442 .826 r
.444 .53705 .44963 .54803 .45958 .54737 .45384 .54191 Mtetra
.509 .709 .961 r
.45384 .54191 .45958 .54737 .46968 .54089 .46385 .54147 Mtetra
.808 .99 .879 r
.46385 .54147 .46968 .54089 .47988 .52781 .47405 .53287 Mtetra
.853 .97 .651 r
.47405 .53287 .47988 .52781 .49009 .51255 .48433 .51754 Mtetra
.937 .955 .644 r
.48433 .51754 .49009 .51255 .50024 .49868 .49462 .49802 Mtetra
.908 .931 .816 r
.49462 .49802 .50024 .49868 .51033 .49484 .5048 .4855 Mtetra
.567 .61 .855 r
.5048 .4855 .51033 .49484 .52043 .50288 .51492 .48486 Mtetra
.244 .284 .705 r
.51492 .48486 .52043 .50288 .53064 .51185 .5251 .4957 Mtetra
0 0 .539 r
.5251 .4957 .53064 .51185 .54095 .51696 .53543 .51541 Mtetra
.831 .36 .061 r
.53543 .51541 .54095 .51696 .55129 .51484 .54592 .53184 Mtetra
.629 .285 .369 r
.54592 .53184 .55129 .51484 .5616 .50649 .55649 .53932 Mtetra
.497 .217 .419 r
.55649 .53932 .5616 .50649 .572 .50328 .56704 .53612 Mtetra
.35 .093 .377 r
.56704 .53612 .572 .50328 .58252 .50522 .57745 .52222 Mtetra
0 0 0 r
.57745 .52222 .58252 .50522 .59299 .50091 .58767 .49927 Mtetra
.967 .836 .662 r
.58767 .49927 .59299 .50091 .60332 .48933 .59773 .47296 Mtetra
.787 .627 .684 r
.59773 .47296 .60332 .48933 .61353 .47383 .6079 .45551 Mtetra
.659 .544 .713 r
.6079 .45551 .61353 .47383 .62372 .45923 .61835 .4496 Mtetra
.23 .417 .84 r
.61835 .4496 .62372 .45923 .63429 .4566 .62921 .45571 Mtetra
.765 .253 0 r
.62921 .45571 .63429 .4566 .64527 .46413 .64042 .46893 Mtetra
.693 .226 .14 r
.64042 .46893 .64527 .46413 .65642 .47312 .65162 .47796 Mtetra
.482 0 0 r
.65162 .47796 .65642 .47312 .6676 .47994 .66265 .4802 Mtetra
.619 .958 .885 r
.66265 .4802 .6676 .47994 .67858 .48006 .6734 .47414 Mtetra
.846 .804 .809 r
.6734 .47414 .67858 .48006 .68932 .47425 .6839 .46264 Mtetra
.778 .673 .747 r
.6839 .46264 .68932 .47425 .6999 .46474 .6944 .4511 Mtetra
.739 .631 .739 r
.6944 .4511 .6999 .46474 .7104 .45393 .70497 .44126 Mtetra
.69 .62 .772 r
.70497 .44126 .7104 .45393 .72103 .44539 .71576 .43524 Mtetra
.636 .636 .833 r
.71576 .43524 .72103 .44539 .73183 .43933 .72677 .43227 Mtetra
.561 .684 .922 r
.72677 .43227 .73183 .43933 .74283 .43588 .73796 .43124 Mtetra
.444 .725 .985 r
.73796 .43124 .74283 .43588 .75399 .43416 .74927 .43114 Mtetra
.383 .766 .99 r
.74927 .43114 .75399 .43416 .76525 .43303 .76061 .43061 Mtetra
.388 .794 .982 r
.76061 .43061 .76525 .43303 .77658 .43204 .77197 .42948 Mtetra
.478 .836 .994 r
.77197 .42948 .77658 .43204 .78794 .43061 .78333 .42744 Mtetra
.561 .85 .997 r
.78333 .42744 .78794 .43061 .79932 .42872 .79468 .42471 Mtetra
.617 .836 .984 r
.79468 .42471 .79932 .42872 .8107 .42626 .80604 .42147 Mtetra
.646 .814 .964 r
.80604 .42147 .8107 .42626 .8221 .42338 .81741 .4179 Mtetra
.657 .791 .946 r
.81741 .4179 .8221 .42338 .83352 .42019 .82883 .41423 Mtetra
.661 .775 .934 r
.82883 .41423 .83352 .42019 .84497 .41677 .84028 .41048 Mtetra
.661 .764 .926 r
.84028 .41048 .84497 .41677 .85645 .41323 .85177 .40675 Mtetra
.661 .757 .922 r
.85177 .40675 .85645 .41323 .86797 .4096 .86332 .40301 Mtetra
.66 .754 .92 r
.86332 .40301 .86797 .4096 .87953 .40593 .87491 .39928 Mtetra
.659 .753 .919 r
.87491 .39928 .87953 .40593 .89113 .40224 .88655 .39556 Mtetra
.656 .751 .92 r
.2641 .58177 .27027 .58715 .27962 .58433 .27348 .57883 Mtetra
.656 .748 .918 r
.27348 .57883 .27962 .58433 .28901 .58152 .2829 .5759 Mtetra
.654 .743 .916 r
.2829 .5759 .28901 .58152 .29844 .57873 .29235 .573 Mtetra
.651 .74 .915 r
.29235 .573 .29844 .57873 .30789 .57593 .30182 .57017 Mtetra
.645 .738 .916 r
.30182 .57017 .30789 .57593 .31738 .57316 .31133 .56745 Mtetra
.641 .739 .92 r
.31133 .56745 .31738 .57316 .32691 .57032 .32086 .56483 Mtetra
.634 .746 .929 r
.32086 .56483 .32691 .57032 .33648 .56737 .33042 .56233 Mtetra
.634 .764 .941 r
.33042 .56233 .33648 .56737 .3461 .56411 .34003 .55975 Mtetra
.637 .793 .957 r
.34003 .55975 .3461 .56411 .35577 .56037 .34968 .55698 Mtetra
.656 .838 .97 r
.34968 .55698 .35577 .56037 .36551 .55596 .35939 .55362 Mtetra
.688 .889 .971 r
.35939 .55362 .36551 .55596 .37531 .55066 .36918 .54936 Mtetra
.723 .933 .958 r
.36918 .54936 .37531 .55066 .38516 .54478 .37905 .54402 Mtetra
.772 .953 .932 r
.37905 .54402 .38516 .54478 .39505 .53847 .38899 .5374 Mtetra
.79 .943 .925 r
.38899 .5374 .39505 .53847 .40492 .53306 .39895 .53043 Mtetra
.786 .886 .917 r
.39895 .53043 .40492 .53306 .41475 .52952 .40892 .52378 Mtetra
.701 .76 .898 r
.40892 .52378 .41475 .52952 .42452 .52898 .41883 .51946 Mtetra
.565 .603 .851 r
.41883 .51946 .42452 .52898 .43424 .53217 .42866 .51891 Mtetra
.44 .466 .79 r
.42866 .51891 .43424 .53217 .444 .53705 .43844 .52233 Mtetra
.307 .363 .758 r
.43844 .52233 .444 .53705 .45384 .54191 .44821 .52942 Mtetra
.361 .433 .801 r
.44821 .52942 .45384 .54191 .46385 .54147 .45812 .53434 Mtetra
.559 .671 .913 r
.45812 .53434 .46385 .54147 .47405 .53287 .46822 .53351 Mtetra
.823 .991 .869 r
.46822 .53351 .47405 .53287 .48433 .51754 .47848 .52438 Mtetra
.818 .934 .563 r
.47848 .52438 .48433 .51754 .49462 .49802 .48883 .5071 Mtetra
.615 .807 .389 r
.48883 .5071 .49462 .49802 .5048 .4855 .49913 .49062 Mtetra
.56 .863 .558 r
.49913 .49062 .5048 .4855 .51492 .48486 .50935 .48039 Mtetra
.041 .487 .885 r
.50935 .48039 .51492 .48486 .5251 .4957 .51954 .48408 Mtetra
0 0 .454 r
.51954 .48408 .5251 .4957 .53543 .51541 .52984 .50196 Mtetra
0 0 .478 r
.52984 .50196 .53543 .51541 .54592 .53184 .54032 .52131 Mtetra
0 .066 .629 r
.54032 .52131 .54592 .53184 .55649 .53932 .55093 .53453 Mtetra
.646 .796 .955 r
.55093 .53453 .55649 .53932 .56704 .53612 .5615 .5313 Mtetra
.915 .803 .721 r
.5615 .5313 .56704 .53612 .57745 .52222 .57188 .5116 Mtetra
.88 .71 .667 r
.57188 .5116 .57745 .52222 .58767 .49927 .58209 .48568 Mtetra
.849 .675 .666 r
.58209 .48568 .58767 .49927 .59773 .47296 .59222 .46115 Mtetra
.76 .658 .749 r
.59222 .46115 .59773 .47296 .6079 .45551 .6026 .45085 Mtetra
.083 .505 .901 r
.6026 .45085 .6079 .45551 .61835 .4496 .61335 .45458 Mtetra
.713 .258 .168 r
.61335 .45458 .61835 .4496 .62921 .45571 .62437 .46466 Mtetra
.704 .297 .273 r
.62437 .46466 .62921 .45571 .64042 .46893 .63556 .4756 Mtetra
.525 .064 .101 r
.63556 .4756 .64042 .46893 .65162 .47796 .64658 .47832 Mtetra
.586 .946 .88 r
.64658 .47832 .65162 .47796 .66265 .4802 .65734 .47261 Mtetra
.825 .758 .789 r
.65734 .47261 .66265 .4802 .6734 .47414 .66787 .46103 Mtetra
.788 .659 .721 r
.66787 .46103 .6734 .47414 .6839 .46264 .67829 .44721 Mtetra
.728 .608 .723 r
.67829 .44721 .6839 .46264 .6944 .4511 .68886 .43711 Mtetra
.682 .599 .757 r
.68886 .43711 .6944 .4511 .70497 .44126 .69965 .43104 Mtetra
.615 .625 .838 r
.69965 .43104 .70497 .44126 .71576 .43524 .71068 .42883 Mtetra
.484 .671 .947 r
.71068 .42883 .71576 .43524 .72677 .43227 .72192 .42903 Mtetra
.298 .708 .975 r
.72192 .42903 .72677 .43227 .73796 .43124 .73324 .42956 Mtetra
.179 .688 .9 r
.73324 .42956 .73796 .43124 .74927 .43114 .74461 .42975 Mtetra
.29 .77 .924 r
.74461 .42975 .74927 .43114 .76061 .43061 .75596 .42861 Mtetra
.452 .845 .979 r
.75596 .42861 .76061 .43061 .77197 .42948 .76728 .42638 Mtetra
.587 .864 .995 r
.76728 .42638 .77197 .42948 .78333 .42744 .77859 .4232 Mtetra
.65 .839 .973 r
.77859 .4232 .78333 .42744 .79468 .42471 .7899 .41941 Mtetra
.669 .802 .947 r
.7899 .41941 .79468 .42471 .80604 .42147 .80123 .41543 Mtetra
.674 .776 .927 r
.80123 .41543 .80604 .42147 .81741 .4179 .8126 .41135 Mtetra
.669 .757 .916 r
.8126 .41135 .81741 .4179 .82883 .41423 .82402 .4074 Mtetra
.665 .747 .911 r
.82402 .4074 .82883 .41423 .84028 .41048 .83549 .40354 Mtetra
.661 .743 .911 r
.83549 .40354 .84028 .41048 .85177 .40675 .84702 .3998 Mtetra
.658 .742 .912 r
.84702 .3998 .85177 .40675 .86332 .40301 .85861 .39612 Mtetra
.656 .744 .914 r
.85861 .39612 .86332 .40301 .87491 .39928 .87024 .39248 Mtetra
.656 .748 .918 r
.87024 .39248 .87491 .39928 .88655 .39556 .88193 .38884 Mtetra
.663 .753 .917 r
.25789 .57635 .2641 .58177 .27348 .57883 .26731 .57322 Mtetra
.664 .747 .912 r
.26731 .57322 .27348 .57883 .2829 .5759 .27676 .57006 Mtetra
.663 .74 .907 r
.27676 .57006 .2829 .5759 .29235 .573 .28624 .56692 Mtetra
.659 .731 .903 r
.28624 .56692 .29235 .573 .30182 .57017 .29575 .56387 Mtetra
.653 .723 .9 r
.29575 .56387 .30182 .57017 .31133 .56745 .30529 .56095 Mtetra
.645 .714 .898 r
.30529 .56095 .31133 .56745 .32086 .56483 .31484 .55824 Mtetra
.632 .708 .902 r
.31484 .55824 .32086 .56483 .33042 .56233 .32441 .55584 Mtetra
.62 .709 .909 r
.32441 .55584 .33042 .56233 .34003 .55975 .33401 .55369 Mtetra
.605 .719 .925 r
.33401 .55369 .34003 .55975 .34968 .55698 .34363 .55182 Mtetra
.603 .753 .949 r
.34363 .55182 .34968 .55698 .35939 .55362 .3533 .54981 Mtetra
.606 .81 .978 r
.3533 .54981 .35939 .55362 .36918 .54936 .36303 .54738 Mtetra
.629 .893 .987 r
.36303 .54738 .36918 .54936 .37905 .54402 .37285 .54384 Mtetra
.673 .958 .945 r
.37285 .54384 .37905 .54402 .38899 .5374 .38277 .53859 Mtetra
.717 .986 .882 r
.38277 .53859 .38899 .5374 .39895 .53043 .39279 .53159 Mtetra
.812 .994 .866 r
.39279 .53159 .39895 .53043 .40892 .52378 .40289 .52276 Mtetra
.833 .941 .896 r
.40289 .52276 .40892 .52378 .41883 .51946 .41297 .51434 Mtetra
.763 .794 .878 r
.41297 .51434 .41883 .51946 .42866 .51891 .423 .50793 Mtetra
.604 .594 .814 r
.423 .50793 .42866 .51891 .43844 .52233 .43292 .50623 Mtetra
.43 .423 .751 r
.43292 .50623 .43844 .52233 .44821 .52942 .44273 .51075 Mtetra
.362 .355 .717 r
.44273 .51075 .44821 .52942 .45812 .53434 .45255 .51823 Mtetra
.297 .341 .739 r
.45255 .51823 .45812 .53434 .46822 .53351 .46247 .52623 Mtetra
.361 .572 .92 r
.46247 .52623 .46822 .53351 .47848 .52438 .47258 .52859 Mtetra
0 0 0 r
.47258 .52859 .47848 .52438 .48883 .5071 .48287 .52222 Mtetra
0 0 .065 r
.48287 .52222 .48883 .5071 .49913 .49062 .49325 .50871 Mtetra
0 0 .08 r
.49325 .50871 .49913 .49062 .50935 .48039 .50364 .4908 Mtetra
0 0 0 r
.50364 .4908 .50935 .48039 .51954 .48408 .51395 .4792 Mtetra
.59 .77 .965 r
.51395 .4792 .51954 .48408 .52984 .50196 .52424 .47716 Mtetra
.506 .412 .682 r
.52424 .47716 .52984 .50196 .54032 .52131 .5346 .48055 Mtetra
.509 .369 .626 r
.5346 .48055 .54032 .52131 .55093 .53453 .54505 .48574 Mtetra
.581 .409 .614 r
.54505 .48574 .55093 .53453 .5615 .5313 .55551 .48245 Mtetra
.633 .447 .613 r
.55551 .48245 .5615 .5313 .57188 .5116 .56591 .47068 Mtetra
.635 .457 .625 r
.56591 .47068 .57188 .5116 .58209 .48568 .57632 .46068 Mtetra
.62 .486 .677 r
.57632 .46068 .58209 .48568 .59222 .46115 .58683 .45612 Mtetra
0 .412 .847 r
.58683 .45612 .59222 .46115 .6026 .45085 .59759 .46118 Mtetra
.704 .311 .302 r
.59759 .46118 .6026 .45085 .61335 .45458 .6086 .47266 Mtetra
.617 .273 .365 r
.6086 .47266 .61335 .45458 .62437 .46466 .61963 .47974 Mtetra
.495 .137 .289 r
.61963 .47974 .62437 .46466 .63556 .4756 .63054 .47961 Mtetra
.48 .833 .565 r
.63054 .47961 .63556 .4756 .64658 .47832 .6412 .47063 Mtetra
.856 .76 .755 r
.6412 .47063 .64658 .47832 .65734 .47261 .65164 .45589 Mtetra
.761 .615 .697 r
.65164 .45589 .65734 .47261 .66787 .46103 .66206 .44164 Mtetra
.715 .572 .693 r
.66206 .44164 .66787 .46103 .67829 .44721 .6726 .43038 Mtetra
.649 .554 .733 r
.6726 .43038 .67829 .44721 .68886 .43711 .68343 .42544 Mtetra
.553 .566 .821 r
.68343 .42544 .68886 .43711 .69965 .43104 .69454 .42532 Mtetra
.337 .621 .955 r
.69454 .42532 .69965 .43104 .71068 .42883 .70584 .42728 Mtetra
0 .489 .761 r
.70584 .42728 .71068 .42883 .72192 .42903 .71725 .42968 Mtetra
.127 0 0 r
.71725 .42968 .72192 .42903 .73324 .42956 .72862 .4302 Mtetra
0 0 0 r
.72862 .4302 .73324 .42956 .74461 .42975 .73994 .42894 Mtetra
.42 .859 .921 r
.73994 .42894 .74461 .42975 .75596 .42861 .75121 .42591 Mtetra
.634 .898 .985 r
.75121 .42591 .75596 .42861 .76728 .42638 .76244 .42173 Mtetra
.691 .836 .953 r
.76244 .42173 .76728 .42638 .77859 .4232 .77367 .41712 Mtetra
.698 .783 .917 r
.77367 .41712 .77859 .4232 .7899 .41941 .78494 .41236 Mtetra
.686 .747 .897 r
.78494 .41236 .7899 .41941 .80123 .41543 .79626 .40787 Mtetra
.677 .728 .889 r
.79626 .40787 .80123 .41543 .8126 .41135 .80765 .40364 Mtetra
.666 .72 .889 r
.80765 .40364 .8126 .41135 .82402 .4074 .8191 .39973 Mtetra
.658 .719 .893 r
.8191 .39973 .82402 .4074 .83549 .40354 .83062 .39603 Mtetra
.654 .723 .899 r
.83062 .39603 .83549 .40354 .84702 .3998 .84221 .39248 Mtetra
.65 .728 .906 r
.84221 .39248 .84702 .3998 .85861 .39612 .85385 .389 Mtetra
.649 .735 .912 r
.85385 .389 .85861 .39612 .87024 .39248 .86554 .38555 Mtetra
.649 .742 .917 r
.86554 .38555 .87024 .39248 .88193 .38884 .87727 .38207 Mtetra
.669 .754 .915 r
.25164 .57089 .25789 .57635 .26731 .57322 .26109 .56761 Mtetra
.671 .75 .91 r
.26109 .56761 .26731 .57322 .27676 .57006 .27058 .56426 Mtetra
.671 .744 .905 r
.27058 .56426 .27676 .57006 .28624 .56692 .28009 .56088 Mtetra
.67 .737 .9 r
.28009 .56088 .28624 .56692 .29575 .56387 .28964 .55752 Mtetra
.667 .727 .894 r
.28964 .55752 .29575 .56387 .30529 .56095 .29922 .55421 Mtetra
.659 .713 .888 r
.29922 .55421 .30529 .56095 .31484 .55824 .30882 .5511 Mtetra
.646 .697 .883 r
.30882 .5511 .31484 .55824 .32441 .55584 .31843 .54831 Mtetra
.629 .68 .88 r
.31843 .54831 .32441 .55584 .33401 .55369 .32805 .54598 Mtetra
.604 .666 .883 r
.32805 .54598 .33401 .55369 .34363 .55182 .33767 .54427 Mtetra
.585 .664 .893 r
.33767 .54427 .34363 .55182 .3533 .54981 .34732 .54298 Mtetra
.56 .679 .918 r
.34732 .54298 .3533 .54981 .36303 .54738 .35699 .54207 Mtetra
.568 .738 .956 r
.35699 .54207 .36303 .54738 .37285 .54384 .36673 .54065 Mtetra
.596 .837 .99 r
.36673 .54065 .37285 .54384 .38277 .53859 .37657 .53807 Mtetra
.65 .945 .957 r
.37657 .53807 .38277 .53859 .39279 .53159 .38654 .53331 Mtetra
.729 .99 .854 r
.38654 .53331 .39279 .53159 .40289 .52276 .39665 .52556 Mtetra
.764 .993 .792 r
.39665 .52556 .40289 .52276 .41297 .51434 .40683 .51604 Mtetra
.848 .996 .83 r
.40683 .51604 .41297 .51434 .423 .50793 .41704 .50562 Mtetra
.813 .901 .903 r
.41704 .50562 .423 .50793 .43292 .50623 .42716 .49793 Mtetra
.635 .667 .864 r
.42716 .49793 .43292 .50623 .44273 .51075 .43716 .49532 Mtetra
.465 .453 .761 r
.43716 .49532 .44273 .51075 .45255 .51823 .44706 .49855 Mtetra
.323 .322 .703 r
.44706 .49855 .45255 .51823 .46247 .52623 .45692 .50755 Mtetra
.313 .325 .712 r
.45692 .50755 .46247 .52623 .47258 .52859 .46689 .5164 Mtetra
.356 .44 .81 r
.46689 .5164 .47258 .52859 .48287 .52222 .47704 .52121 Mtetra
.588 .92 .968 r
.47704 .52121 .48287 .52222 .49325 .50871 .48737 .51723 Mtetra
0 0 0 r
.48737 .51723 .49325 .50871 .50364 .4908 .49781 .50332 Mtetra
.49781 .50332 .50364 .4908 .51395 .4792 .50825 .48578 Mtetra
.818 .933 .559 r
.50825 .48578 .51395 .4792 .52424 .47716 .51864 .46833 Mtetra
.816 .719 .759 r
.51864 .46833 .52424 .47716 .5346 .48055 .52898 .45579 Mtetra
.639 .498 .675 r
.52898 .45579 .5346 .48055 .54505 .48574 .53933 .44957 Mtetra
.59 .434 .638 r
.53933 .44957 .54505 .48574 .55551 .48245 .54972 .44624 Mtetra
.563 .415 .638 r
.54972 .44624 .55551 .48245 .56591 .47068 .56019 .4458 Mtetra
.46 .381 .681 r
.56019 .4458 .56591 .47068 .57632 .46068 .5708 .45172 Mtetra
0 .149 .691 r
.5708 .45172 .57632 .46068 .58683 .45612 .5816 .46261 Mtetra
.72 .289 .224 r
.5816 .46261 .58683 .45612 .59759 .46118 .59253 .47365 Mtetra
.636 .255 .304 r
.59253 .47365 .59759 .46118 .6086 .47266 .60351 .48108 Mtetra
.329 0 .057 r
.60351 .48108 .6086 .47266 .61963 .47974 .61434 .47848 Mtetra
.887 .95 .843 r
.61434 .47848 .61963 .47974 .63054 .47961 .62494 .46699 Mtetra
.808 .673 .714 r
.62494 .46699 .63054 .47961 .6412 .47063 .63539 .45136 Mtetra
.756 .596 .679 r
.63539 .45136 .6412 .47063 .65164 .45589 .6458 .43554 Mtetra
.697 .556 .692 r
.6458 .43554 .65164 .45589 .66206 .44164 .6564 .42555 Mtetra
.637 .554 .744 r
.6564 .42555 .66206 .44164 .6726 .43038 .66725 .4215 Mtetra
.481 .59 .886 r
.66725 .4215 .6726 .43038 .68343 .42544 .6784 .42263 Mtetra
0 .428 .786 r
.6784 .42263 .68343 .42544 .69454 .42532 .68976 .42658 Mtetra
.392 0 0 r
.68976 .42658 .69454 .42532 .70584 .42728 .70116 .42963 Mtetra
.323 0 0 r
.70116 .42963 .70584 .42728 .71725 .42968 .71255 .43088 Mtetra
0 0 0 r
.71255 .43088 .71725 .42968 .72862 .4302 .72384 .42908 Mtetra
.541 .911 .952 r
.72384 .42908 .72862 .4302 .73994 .42894 .73503 .42502 Mtetra
.712 .871 .956 r
.73503 .42502 .73994 .42894 .75121 .42591 .74618 .41976 Mtetra
.731 .791 .9 r
.74618 .41976 .75121 .42591 .76244 .42173 .75733 .41397 Mtetra
.71 .734 .87 r
.75733 .41397 .76244 .42173 .77367 .41712 .76854 .40855 Mtetra
.693 .707 .858 r
.76854 .40855 .77367 .41712 .78494 .41236 .77981 .40356 Mtetra
.675 .694 .86 r
.77981 .40356 .78494 .41236 .79626 .40787 .79117 .39922 Mtetra
.662 .693 .868 r
.79117 .39922 .79626 .40787 .80765 .40364 .80262 .39534 Mtetra
.652 .699 .88 r
.80262 .39534 .80765 .40364 .8191 .39973 .81414 .3918 Mtetra
.646 .707 .892 r
.81414 .3918 .8191 .39973 .83062 .39603 .82572 .38847 Mtetra
.644 .718 .902 r
.82572 .38847 .83062 .39603 .84221 .39248 .83736 .38518 Mtetra
.642 .727 .91 r
.83736 .38518 .84221 .39248 .85385 .389 .84906 .38191 Mtetra
.642 .735 .916 r
.84906 .38191 .85385 .389 .86554 .38555 .8608 .37862 Mtetra
.644 .742 .92 r
.8608 .37862 .86554 .38555 .87727 .38207 .87259 .37524 Mtetra
.669 .755 .914 r
.24535 .5654 .25164 .57089 .26109 .56761 .25482 .56209 Mtetra
.673 .755 .912 r
.25482 .56209 .26109 .56761 .27058 .56426 .26433 .55866 Mtetra
.677 .754 .909 r
.26433 .55866 .27058 .56426 .28009 .56088 .27388 .55513 Mtetra
.68 .75 .904 r
.27388 .55513 .28009 .56088 .28964 .55752 .28347 .5515 Mtetra
.683 .742 .896 r
.28347 .5515 .28964 .55752 .29922 .55421 .2931 .54773 Mtetra
.68 .728 .886 r
.2931 .54773 .29922 .55421 .30882 .5511 .30275 .544 Mtetra
.674 .708 .874 r
.30275 .544 .30882 .5511 .31843 .54831 .31243 .5404 Mtetra
.656 .681 .861 r
.31243 .5404 .31843 .54831 .32805 .54598 .32211 .53723 Mtetra
.631 .651 .852 r
.32211 .53723 .32805 .54598 .33767 .54427 .33179 .53477 Mtetra
.599 .621 .845 r
.33179 .53477 .33767 .54427 .34732 .54298 .34145 .53322 Mtetra
.555 .595 .849 r
.34145 .53322 .34732 .54298 .35699 .54207 .3511 .53285 Mtetra
.525 .594 .866 r
.3511 .53285 .35699 .54207 .36673 .54065 .36077 .5331 Mtetra
.487 .625 .912 r
.36077 .5331 .36673 .54065 .37657 .53807 .37048 .53364 Mtetra
.495 .749 .986 r
.37048 .53364 .37657 .53807 .38654 .53331 .38031 .53288 Mtetra
.5 .895 .945 r
.38031 .53288 .38654 .53331 .39665 .52556 .39028 .52962 Mtetra
.406 .814 .608 r
.39028 .52962 .39665 .52556 .40683 .51604 .40042 .52293 Mtetra
0 0 0 r
.40042 .52293 .40683 .51604 .41704 .50562 .41071 .51219 Mtetra
.636 .884 .544 r
.41071 .51219 .41704 .50562 .42716 .49793 .42105 .49985 Mtetra
.883 .989 .802 r
.42105 .49985 .42716 .49793 .43716 .49532 .43136 .48781 Mtetra
.751 .727 .83 r
.43136 .48781 .43716 .49532 .44706 .49855 .44152 .48088 Mtetra
.54 .477 .734 r
.44152 .48088 .44706 .49855 .45692 .50755 .45153 .48168 Mtetra
.439 .361 .671 r
.45153 .48168 .45692 .50755 .46689 .5164 .46149 .4885 Mtetra
.363 .3 .652 r
.46149 .4885 .46689 .5164 .47704 .52121 .47147 .49957 Mtetra
.368 .339 .694 r
.47147 .49957 .47704 .52121 .48737 .51723 .48162 .508 Mtetra
.466 .571 .877 r
.48162 .508 .48737 .51723 .49781 .50332 .49195 .50944 Mtetra
0 0 0 r
.49195 .50944 .49781 .50332 .50825 .48578 .50242 .49972 Mtetra
.50242 .49972 .50825 .48578 .51864 .46833 .51293 .4796 Mtetra
.632 .776 .32 r
.51293 .4796 .51864 .46833 .52898 .45579 .52337 .45897 Mtetra
.906 .98 .709 r
.52337 .45897 .52898 .45579 .53933 .44957 .53376 .44343 Mtetra
.658 .749 .917 r
.53376 .44343 .53933 .44957 .54972 .44624 .54418 .44007 Mtetra
0 .151 .662 r
.54418 .44007 .54972 .44624 .56019 .4458 .55475 .44893 Mtetra
.783 .331 .173 r
.55475 .44893 .56019 .4458 .5708 .45172 .5655 .46295 Mtetra
.722 .339 .324 r
.5655 .46295 .5708 .45172 .5816 .46261 .5764 .47651 Mtetra
.558 .186 .292 r
.5764 .47651 .5816 .46261 .59253 .47365 .58725 .47966 Mtetra
0 0 0 r
.58725 .47966 .59253 .47365 .60351 .48108 .59794 .47155 Mtetra
.836 .722 .738 r
.59794 .47155 .60351 .48108 .61434 .47848 .60846 .45635 Mtetra
.753 .581 .663 r
.60846 .45635 .61434 .47848 .62494 .46699 .61887 .43843 Mtetra
.692 .521 .651 r
.61887 .43843 .62494 .46699 .63539 .45136 .62936 .42478 Mtetra
.646 .498 .667 r
.62936 .42478 .63539 .45136 .6458 .43554 .64004 .41723 Mtetra
.552 .484 .733 r
.64004 .41723 .6458 .43554 .6564 .42555 .65104 .41752 Mtetra
.184 .443 .872 r
.65104 .41752 .6564 .42555 .66725 .4215 .66232 .42304 Mtetra
.563 0 0 r
.66232 .42304 .66725 .4215 .6784 .42263 .67373 .42889 Mtetra
.563 .09 .09 r
.67373 .42889 .6784 .42263 .68976 .42658 .68517 .43315 Mtetra
.41 0 .017 r
.68517 .43315 .68976 .42658 .70116 .42963 .69649 .43328 Mtetra
.031 0 0 r
.69649 .43328 .70116 .42963 .71255 .43088 .70768 .42989 Mtetra
.67 .961 .938 r
.70768 .42989 .71255 .43088 .72384 .42908 .71876 .42391 Mtetra
.779 .836 .896 r
.71876 .42391 .72384 .42908 .73503 .42502 .72979 .4166 Mtetra
.743 .728 .838 r
.72979 .4166 .73503 .42502 .74618 .41976 .74085 .40956 Mtetra
.714 .679 .814 r
.74085 .40956 .74618 .41976 .75733 .41397 .75198 .40315 Mtetra
.684 .654 .814 r
.75198 .40315 .75733 .41397 .76854 .40855 .76322 .39795 Mtetra
.664 .649 .826 r
.76322 .39795 .76854 .40855 .77981 .40356 .77457 .39368 Mtetra
.648 .657 .846 r
.77457 .39368 .77981 .40356 .79117 .39922 .78602 .39016 Mtetra
.636 .672 .867 r
.78602 .39016 .79117 .39922 .80262 .39534 .79756 .38708 Mtetra
.632 .692 .888 r
.79756 .38708 .80262 .39534 .81414 .3918 .80916 .38414 Mtetra
.63 .71 .904 r
.80916 .38414 .81414 .3918 .82572 .38847 .82082 .38123 Mtetra
.634 .726 .914 r
.82082 .38123 .82572 .38847 .83736 .38518 .83252 .37818 Mtetra
.636 .736 .92 r
.83252 .37818 .83736 .38518 .84906 .38191 .84426 .37502 Mtetra
.639 .742 .923 r
.84426 .37502 .84906 .38191 .8608 .37862 .85604 .37175 Mtetra
.643 .745 .923 r
.85604 .37175 .8608 .37862 .87259 .37524 .86786 .36837 Mtetra
.662 .753 .918 r
.23902 .55988 .24535 .5654 .25482 .56209 .2485 .55672 Mtetra
.666 .76 .92 r
.2485 .55672 .25482 .56209 .26433 .55866 .25801 .55345 Mtetra
.672 .768 .923 r
.25801 .55345 .26433 .55866 .27388 .55513 .26757 .55003 Mtetra
.68 .774 .922 r
.26757 .55003 .27388 .55513 .28347 .5515 .27718 .5464 Mtetra
.69 .777 .918 r
.27718 .5464 .28347 .5515 .2931 .54773 .28684 .54248 Mtetra
.697 .774 .911 r
.28684 .54248 .2931 .54773 .30275 .544 .29655 .53836 Mtetra
.703 .762 .898 r
.29655 .53836 .30275 .544 .31243 .5404 .30629 .53403 Mtetra
.695 .737 .884 r
.30629 .53403 .31243 .5404 .32211 .53723 .31606 .52982 Mtetra
.679 .703 .866 r
.31606 .52982 .32211 .53723 .33179 .53477 .32583 .52597 Mtetra
.646 .658 .847 r
.32583 .52597 .33179 .53477 .34145 .53322 .33559 .52299 Mtetra
.601 .608 .83 r
.33559 .52299 .34145 .53322 .3511 .53285 .34531 .52134 Mtetra
.555 .561 .815 r
.34531 .52134 .3511 .53285 .36077 .5331 .355 .52111 Mtetra
.498 .523 .813 r
.355 .52111 .36077 .5331 .37048 .53364 .36467 .52251 Mtetra
.472 .526 .832 r
.36467 .52251 .37048 .53364 .38031 .53288 .37438 .52431 Mtetra
.458 .582 .89 r
.37438 .52431 .38031 .53288 .39028 .52962 .38418 .52562 Mtetra
.526 .783 .991 r
.38418 .52562 .39028 .52962 .40042 .52293 .39414 .52423 Mtetra
.591 .948 .863 r
.39414 .52423 .40042 .52293 .41071 .51219 .40431 .51853 Mtetra
0 0 0 r
.40431 .51853 .41071 .51219 .42105 .49985 .41465 .50857 Mtetra
.41465 .50857 .42105 .49985 .43136 .48781 .42509 .49469 Mtetra
.643 .879 .526 r
.42509 .49469 .43136 .48781 .44152 .48088 .43549 .48164 Mtetra
.825 .991 .866 r
.43549 .48164 .44152 .48088 .45153 .48168 .44578 .4724 Mtetra
.639 .649 .844 r
.44578 .4724 .45153 .48168 .46149 .4885 .45593 .46953 Mtetra
.451 .411 .723 r
.45593 .46953 .46149 .4885 .47147 .49957 .46599 .47402 Mtetra
.41 .343 .671 r
.46599 .47402 .47147 .49957 .48162 .508 .47609 .48208 Mtetra
.403 .337 .669 r
.47609 .48208 .48162 .508 .49195 .50944 .48629 .49062 Mtetra
.514 .455 .728 r
.48629 .49062 .49195 .50944 .50242 .49972 .49666 .49261 Mtetra
.744 .745 .853 r
.49666 .49261 .50242 .49972 .51293 .4796 .50714 .48614 Mtetra
0 0 0 r
.50714 .48614 .51293 .4796 .52337 .45897 .51766 .47605 Mtetra
.206 0 .191 r
.51766 .47605 .52337 .45897 .53376 .44343 .52817 .46576 Mtetra
.456 .142 .343 r
.52817 .46576 .53376 .44343 .54418 .44007 .53871 .46241 Mtetra
.565 .241 .379 r
.53871 .46241 .54418 .44007 .55475 .44893 .54934 .46601 Mtetra
.564 .214 .333 r
.54934 .46601 .55475 .44893 .5655 .46295 .56005 .46943 Mtetra
.393 0 .006 r
.56005 .46943 .5655 .46295 .5764 .47651 .5708 .46923 Mtetra
.786 .757 .827 r
.5708 .46923 .5764 .47651 .58725 .47966 .58146 .46053 Mtetra
.753 .596 .682 r
.58146 .46053 .58725 .47966 .59794 .47155 .592 .44517 Mtetra
.711 .539 .655 r
.592 .44517 .59794 .47155 .60846 .45635 .60251 .43027 Mtetra
.683 .523 .663 r
.60251 .43027 .60846 .45635 .61887 .43843 .61308 .41894 Mtetra
.623 .518 .714 r
.61308 .41894 .61887 .43843 .62936 .42478 .62387 .41506 Mtetra
.42 .537 .869 r
.62387 .41506 .62936 .42478 .64004 .41723 .63491 .41765 Mtetra
.565 0 0 r
.63491 .41765 .64004 .41723 .65104 .41752 .64619 .42414 Mtetra
.645 .189 .156 r
.64619 .42414 .65104 .41752 .66232 .42304 .65762 .43151 Mtetra
.548 .11 .16 r
.65762 .43151 .66232 .42304 .67373 .42889 .66898 .43492 Mtetra
.34 0 0 r
.66898 .43492 .67373 .42889 .68517 .43315 .68024 .43399 Mtetra
.48 .897 .819 r
.68024 .43399 .68517 .43315 .69649 .43328 .69133 .42864 Mtetra
.803 .857 .89 r
.69133 .42864 .69649 .43328 .70768 .42989 .7023 .4205 Mtetra
.763 .713 .805 r
.7023 .4205 .70768 .42989 .71876 .42391 .71325 .41184 Mtetra
.731 .654 .773 r
.71325 .41184 .71876 .42391 .72979 .4166 .72423 .40358 Mtetra
.696 .625 .773 r
.72423 .40358 .72979 .4166 .74085 .40956 .73534 .39698 Mtetra
.672 .619 .788 r
.73534 .39698 .74085 .40956 .75198 .40315 .74657 .39184 Mtetra
.648 .629 .817 r
.74657 .39184 .75198 .40315 .76322 .39795 .75794 .38807 Mtetra
.629 .649 .851 r
.75794 .38807 .76322 .39795 .77457 .39368 .76942 .38519 Mtetra
.617 .679 .886 r
.76942 .38519 .77457 .39368 .78602 .39016 .78098 .38269 Mtetra
.609 .707 .914 r
.78098 .38269 .78602 .39016 .79756 .38708 .79261 .38033 Mtetra
.613 .733 .931 r
.79261 .38033 .79756 .38708 .80916 .38414 .80427 .37774 Mtetra
.619 .75 .94 r
.80427 .37774 .80916 .38414 .82082 .38123 .81598 .37495 Mtetra
.63 .76 .94 r
.81598 .37495 .82082 .38123 .83252 .37818 .82771 .37185 Mtetra
.639 .762 .938 r
.82771 .37185 .83252 .37818 .84426 .37502 .83947 .36853 Mtetra
.645 .76 .933 r
.83947 .36853 .84426 .37502 .85604 .37175 .85127 .36504 Mtetra
.65 .755 .927 r
.85127 .36504 .85604 .37175 .86786 .36837 .8631 .36144 Mtetra
.648 .749 .924 r
.23264 .55431 .23902 .55988 .2485 .55672 .24211 .55147 Mtetra
.648 .762 .932 r
.24211 .55147 .2485 .55672 .25801 .55345 .25162 .54858 Mtetra
.653 .778 .94 r
.25162 .54858 .25801 .55345 .26757 .55003 .26117 .54553 Mtetra
.663 .795 .945 r
.26117 .54553 .26757 .55003 .27718 .5464 .27078 .54223 Mtetra
.677 .812 .947 r
.27078 .54223 .27718 .5464 .28684 .54248 .28045 .53857 Mtetra
.695 .825 .945 r
.28045 .53857 .28684 .54248 .29655 .53836 .29018 .53447 Mtetra
.717 .83 .935 r
.29018 .53447 .29655 .53836 .30629 .53403 .29997 .52981 Mtetra
.731 .82 .92 r
.29997 .52981 .30629 .53403 .31606 .52982 .30982 .52476 Mtetra
.737 .79 .895 r
.30982 .52476 .31606 .52982 .32583 .52597 .31971 .51936 Mtetra
.719 .738 .867 r
.31971 .51936 .32583 .52597 .33559 .52299 .32961 .51422 Mtetra
.686 .674 .833 r
.32961 .51422 .33559 .52299 .34531 .52134 .3395 .50978 Mtetra
.633 .6 .798 r
.3395 .50978 .34531 .52134 .355 .52111 .34933 .5069 Mtetra
.569 .529 .771 r
.34933 .5069 .355 .52111 .36467 .52251 .35908 .5063 Mtetra
.511 .473 .751 r
.35908 .5063 .36467 .52251 .37438 .52431 .36878 .50793 Mtetra
.44 .429 .75 r
.36878 .50793 .37438 .52431 .38418 .52562 .37845 .51188 Mtetra
.399 .439 .786 r
.37845 .51188 .38418 .52562 .39414 .52423 .38818 .51608 Mtetra
.337 .534 .899 r
.38818 .51608 .39414 .52423 .40431 .51853 .39804 .51897 Mtetra
.086 .645 .726 r
.39804 .51897 .40431 .51853 .41465 .50857 .40812 .51801 Mtetra
.085 0 0 r
.40812 .51801 .41465 .50857 .42509 .49469 .41842 .51138 Mtetra
.088 0 .117 r
.41842 .51138 .42509 .49469 .43549 .48164 .4289 .49937 Mtetra
0 0 .049 r
.4289 .49937 .43549 .48164 .44578 .4724 .43949 .48274 Mtetra
0 0 0 r
.43949 .48274 .44578 .4724 .45593 .46953 .45001 .4668 Mtetra
.882 .874 .823 r
.45001 .4668 .45593 .46953 .46599 .47402 .46042 .45486 Mtetra
.643 .529 .71 r
.46042 .45486 .46599 .47402 .47609 .48208 .47069 .4498 Mtetra
.514 .389 .647 r
.47069 .4498 .47609 .48208 .48629 .49062 .48088 .45311 Mtetra
.422 .312 .624 r
.48088 .45311 .48629 .49062 .49666 .49261 .49108 .46399 Mtetra
.25 .221 .629 r
.49108 .46399 .49666 .49261 .50714 .48614 .50137 .48014 Mtetra
.68 .191 0 r
.50137 .48014 .50714 .48614 .51766 .47605 .51182 .49429 Mtetra
.623 .277 .365 r
.51182 .49429 .51766 .47605 .52817 .46576 .52244 .50193 Mtetra
.491 .21 .415 r
.52244 .50193 .52817 .46576 .53871 .46241 .53314 .49859 Mtetra
.348 .09 .374 r
.53314 .49859 .53871 .46241 .54934 .46601 .54382 .48424 Mtetra
0 0 .036 r
.54382 .48424 .54934 .46601 .56005 .46943 .55441 .46331 Mtetra
.917 .778 .693 r
.55441 .46331 .56005 .46943 .5708 .46923 .5649 .4403 Mtetra
.719 .537 .643 r
.5649 .4403 .5708 .46923 .58146 .46053 .57538 .42254 Mtetra
.64 .464 .63 r
.57538 .42254 .58146 .46053 .592 .44517 .58596 .41238 Mtetra
.574 .431 .648 r
.58596 .41238 .592 .44517 .60251 .43027 .59672 .41065 Mtetra
.441 .404 .722 r
.59672 .41065 .60251 .43027 .61308 .41894 .60771 .4159 Mtetra
.558 0 0 r
.60771 .4159 .61308 .41894 .62387 .41506 .61893 .42525 Mtetra
.68 .275 .27 r
.61893 .42525 .62387 .41506 .63491 .41765 .63029 .43533 Mtetra
.59 .237 .339 r
.63029 .43533 .63491 .41765 .64619 .42414 .64163 .44077 Mtetra
.495 .142 .296 r
.64163 .44077 .64619 .42414 .65762 .43151 .65285 .44073 Mtetra
.188 0 .012 r
.65285 .44073 .65762 .43151 .66898 .43492 .6639 .43492 Mtetra
.813 .996 .857 r
.6639 .43492 .66898 .43492 .68024 .43399 .6748 .42514 Mtetra
.806 .737 .787 r
.6748 .42514 .68024 .43399 .69133 .42864 .68562 .414 Mtetra
.745 .629 .731 r
.68562 .414 .69133 .42864 .7023 .4205 .69646 .40309 Mtetra
.696 .579 .72 r
.69646 .40309 .7023 .4205 .71325 .41184 .70742 .39453 Mtetra
.665 .563 .729 r
.70742 .39453 .71325 .41184 .72423 .40358 .71852 .38826 Mtetra
.635 .565 .759 r
.71852 .38826 .72423 .40358 .73534 .39698 .72981 .38435 Mtetra
.609 .587 .803 r
.72981 .38435 .73534 .39698 .74657 .39184 .74124 .38203 Mtetra
.588 .631 .862 r
.74124 .38203 .74657 .39184 .75794 .38807 .75279 .38044 Mtetra
.567 .682 .917 r
.75279 .38044 .75794 .38807 .76942 .38519 .76441 .37913 Mtetra
.564 .737 .957 r
.76441 .37913 .76942 .38519 .78098 .38269 .77608 .37746 Mtetra
.568 .773 .975 r
.77608 .37746 .78098 .38269 .79261 .38033 .78777 .37539 Mtetra
.593 .797 .978 r
.78777 .37539 .79261 .38033 .80427 .37774 .79947 .37273 Mtetra
.616 .805 .972 r
.79947 .37273 .80427 .37774 .81598 .37495 .81119 .36962 Mtetra
.637 .802 .962 r
.81119 .36962 .81598 .37495 .82771 .37185 .82292 .36613 Mtetra
.651 .793 .95 r
.82292 .36613 .82771 .37185 .83947 .36853 .83468 .36237 Mtetra
.66 .78 .938 r
.83468 .36237 .83947 .36853 .85127 .36504 .84647 .35845 Mtetra
.662 .766 .927 r
.84647 .35845 .85127 .36504 .8631 .36144 .85831 .35446 Mtetra
.633 .746 .929 r
.22623 .54871 .23264 .55431 .24211 .55147 .23569 .54616 Mtetra
.63 .756 .938 r
.23569 .54616 .24211 .55147 .25162 .54858 .24518 .54364 Mtetra
.63 .771 .948 r
.24518 .54364 .25162 .54858 .26117 .54553 .25472 .54105 Mtetra
.634 .791 .957 r
.25472 .54105 .26117 .54553 .27078 .54223 .26431 .53828 Mtetra
.642 .815 .966 r
.26431 .53828 .27078 .54223 .28045 .53857 .27396 .53526 Mtetra
.658 .845 .972 r
.27396 .53526 .28045 .53857 .29018 .53447 .28367 .53178 Mtetra
.683 .875 .971 r
.28367 .53178 .29018 .53447 .29997 .52981 .29346 .52766 Mtetra
.712 .9 .963 r
.29346 .52766 .29997 .52981 .30982 .52476 .30333 .52281 Mtetra
.749 .91 .947 r
.30333 .52281 .30982 .52476 .31971 .51936 .31328 .51707 Mtetra
.771 .898 .932 r
.31328 .51707 .31971 .51936 .32961 .51422 .32328 .51081 Mtetra
.779 .856 .908 r
.32328 .51081 .32961 .51422 .3395 .50978 .33332 .50422 Mtetra
.747 .778 .879 r
.33332 .50422 .3395 .50978 .34933 .5069 .34333 .4983 Mtetra
.687 .681 .839 r
.34333 .4983 .34933 .5069 .35908 .5063 .3533 .49385 Mtetra
.608 .575 .791 r
.3533 .49385 .35908 .5063 .36878 .50793 .36317 .4918 Mtetra
.522 .481 .752 r
.36317 .4918 .36878 .50793 .37845 .51188 .37294 .49298 Mtetra
.465 .42 .723 r
.37294 .49298 .37845 .51188 .38818 .51608 .38266 .49669 Mtetra
.408 .381 .717 r
.38266 .49669 .38818 .51608 .39804 .51897 .39238 .50246 Mtetra
.402 .406 .749 r
.39238 .50246 .39804 .51897 .40812 .51801 .40222 .50749 Mtetra
.441 .528 .851 r
.40222 .50749 .40812 .51801 .41842 .51138 .41225 .50969 Mtetra
.571 .894 .986 r
.41225 .50969 .41842 .51138 .4289 .49937 .42251 .5064 Mtetra
0 0 0 r
.42251 .5064 .4289 .49937 .43949 .48274 .433 .49629 Mtetra
.433 .49629 .43949 .48274 .45001 .4668 .44359 .4823 Mtetra
.44359 .4823 .45001 .4668 .46042 .45486 .45418 .46671 Mtetra
.45418 .46671 .46042 .45486 .47069 .4498 .46468 .45416 Mtetra
.46468 .45416 .47069 .4498 .48088 .45311 .47507 .44751 Mtetra
.332 .628 .959 r
.47507 .44751 .48088 .45311 .49108 .46399 .48537 .44912 Mtetra
.199 .299 .743 r
.48537 .44912 .49108 .46399 .50137 .48014 .49568 .45833 Mtetra
.326 .311 .689 r
.49568 .45833 .50137 .48014 .51182 .49429 .50611 .46814 Mtetra
.453 .372 .675 r
.50611 .46814 .51182 .49429 .52244 .50193 .51668 .47423 Mtetra
.598 .462 .667 r
.51668 .47423 .52244 .50193 .53314 .49859 .52733 .47084 Mtetra
.689 .522 .655 r
.52733 .47084 .53314 .49859 .54382 .48424 .53799 .45797 Mtetra
.723 .548 .653 r
.53799 .45797 .54382 .48424 .55441 .46331 .54861 .44131 Mtetra
.741 .575 .668 r
.54861 .44131 .55441 .46331 .5649 .4403 .55918 .42522 Mtetra
.711 .603 .734 r
.55918 .42522 .5649 .4403 .57538 .42254 .56982 .41673 Mtetra
.479 .697 .964 r
.56982 .41673 .57538 .42254 .58596 .41238 .58061 .41658 Mtetra
.605 .104 .035 r
.58061 .41658 .58596 .41238 .59672 .41065 .59158 .4224 Mtetra
.657 .264 .289 r
.59158 .4224 .59672 .41065 .60771 .4159 .60274 .43133 Mtetra
.621 .254 .325 r
.60274 .43133 .60771 .4159 .61893 .42525 .61398 .43868 Mtetra
.557 .174 .272 r
.61398 .43868 .61893 .42525 .63029 .43533 .62522 .44213 Mtetra
.212 0 0 r
.62522 .44213 .63029 .43533 .64163 .44077 .63631 .43865 Mtetra
.831 .945 .897 r
.63631 .43865 .64163 .44077 .65285 .44073 .64724 .42957 Mtetra
.79 .691 .755 r
.64724 .42957 .65285 .44073 .6639 .43492 .65805 .41756 Mtetra
.744 .605 .703 r
.65805 .41756 .6639 .43492 .6748 .42514 .66881 .40477 Mtetra
.704 .563 .693 r
.66881 .40477 .6748 .42514 .68562 .414 .67966 .39406 Mtetra
.677 .55 .703 r
.67966 .39406 .68562 .414 .69646 .40309 .69063 .38593 Mtetra
.644 .552 .736 r
.69063 .38593 .69646 .40309 .70742 .39453 .7018 .3811 Mtetra
.608 .574 .791 r
.7018 .3811 .70742 .39453 .71852 .38826 .71315 .37874 Mtetra
.561 .625 .872 r
.71315 .37874 .71852 .38826 .72981 .38435 .72464 .3779 Mtetra
.489 .685 .954 r
.72464 .3779 .72981 .38435 .74124 .38203 .73626 .37777 Mtetra
.432 .748 .994 r
.73626 .37777 .74124 .38203 .75279 .38044 .74792 .37729 Mtetra
.409 .784 .993 r
.74792 .37729 .75279 .38044 .76441 .37913 .75961 .37629 Mtetra
.464 .826 .995 r
.75961 .37629 .76441 .37913 .77608 .37746 .7713 .37437 Mtetra
.533 .85 .998 r
.7713 .37437 .77608 .37746 .78777 .37539 .78299 .37169 Mtetra
.598 .854 .992 r
.78299 .37169 .78777 .37539 .79947 .37273 .79468 .36835 Mtetra
.639 .842 .978 r
.79468 .36835 .79947 .37273 .81119 .36962 .80638 .36452 Mtetra
.66 .821 .961 r
.80638 .36452 .81119 .36962 .82292 .36613 .8181 .36043 Mtetra
.671 .803 .945 r
.8181 .36043 .82292 .36613 .83468 .36237 .82985 .35614 Mtetra
.675 .786 .932 r
.82985 .35614 .83468 .36237 .84647 .35845 .84164 .35177 Mtetra
.674 .77 .923 r
.84164 .35177 .84647 .35845 .85831 .35446 .85348 .34743 Mtetra
.625 .743 .932 r
.21976 .54307 .22623 .54871 .23569 .54616 .22923 .54067 Mtetra
.618 .748 .939 r
.22923 .54067 .23569 .54616 .24518 .54364 .23872 .53838 Mtetra
.612 .755 .946 r
.23872 .53838 .24518 .54364 .25472 .54105 .24825 .53615 Mtetra
.607 .768 .957 r
.24825 .53615 .25472 .54105 .26431 .53828 .25782 .53393 Mtetra
.598 .788 .972 r
.25782 .53393 .26431 .53828 .27396 .53526 .26743 .53171 Mtetra
.596 .822 .986 r
.26743 .53171 .27396 .53526 .28367 .53178 .27709 .52926 Mtetra
.594 .863 .994 r
.27709 .52926 .28367 .53178 .29346 .52766 .28682 .52641 Mtetra
.598 .909 .981 r
.28682 .52641 .29346 .52766 .30333 .52281 .29664 .52283 Mtetra
.615 .944 .943 r
.29664 .52283 .30333 .52281 .31328 .51707 .30656 .5182 Mtetra
.64 .965 .893 r
.30656 .5182 .31328 .51707 .32328 .51081 .31658 .51238 Mtetra
.715 .987 .873 r
.31658 .51238 .32328 .51081 .33332 .50422 .3267 .50515 Mtetra
.789 .989 .888 r
.3267 .50515 .33332 .50422 .34333 .4983 .33689 .49705 Mtetra
.836 .929 .892 r
.33689 .49705 .34333 .4983 .3533 .49385 .34712 .48842 Mtetra
.788 .789 .853 r
.34712 .48842 .3533 .49385 .36317 .4918 .3573 .48065 Mtetra
.698 .638 .786 r
.3573 .48065 .36317 .4918 .37294 .49298 .3674 .47485 Mtetra
.606 .514 .723 r
.3674 .47485 .37294 .49298 .38266 .49669 .37738 .47223 Mtetra
.527 .425 .682 r
.37738 .47223 .38266 .49669 .39238 .50246 .38723 .4738 Mtetra
.474 .372 .658 r
.38723 .4738 .39238 .50246 .40222 .50749 .39701 .47886 Mtetra
.419 .334 .654 r
.39701 .47886 .40222 .50749 .41225 .50969 .40677 .48688 Mtetra
.361 .326 .684 r
.40677 .48688 .41225 .50969 .42251 .5064 .41662 .49541 Mtetra
.154 .348 .804 r
.41662 .49541 .42251 .5064 .433 .49629 .42663 .5024 Mtetra
.499 .025 .059 r
.42663 .5024 .433 .49629 .44359 .4823 .43686 .50463 Mtetra
.424 .107 .322 r
.43686 .50463 .44359 .4823 .45418 .46671 .44733 .50016 Mtetra
.378 .104 .366 r
.44733 .50016 .45418 .46671 .46468 .45416 .45795 .48959 Mtetra
.297 .041 .346 r
.45795 .48959 .46468 .45416 .47507 .44751 .46867 .47343 Mtetra
.053 0 .202 r
.46867 .47343 .47507 .44751 .48537 .44912 .4794 .45304 Mtetra
.968 .935 .655 r
.4794 .45304 .48537 .44912 .49568 .45833 .49008 .43078 Mtetra
.734 .55 .644 r
.49008 .43078 .49568 .45833 .50611 .46814 .50066 .41159 Mtetra
.627 .433 .6 r
.50066 .41159 .50611 .46814 .51668 .47423 .51115 .39853 Mtetra
.565 .376 .583 r
.51115 .39853 .51668 .47423 .52733 .47084 .52161 .39506 Mtetra
.516 .339 .579 r
.52161 .39506 .52733 .47084 .53799 .45797 .53213 .40121 Mtetra
.456 .309 .591 r
.53213 .40121 .53799 .45797 .54861 .44131 .54279 .41355 Mtetra
.26 .234 .639 r
.54279 .41355 .54861 .44131 .55918 .42522 .55362 .42902 Mtetra
.769 .315 .17 r
.55362 .42902 .55918 .42522 .56982 .41673 .5646 .44269 Mtetra
.621 .299 .404 r
.5646 .44269 .56982 .41673 .58061 .41658 .57567 .45214 Mtetra
.558 .264 .425 r
.57567 .45214 .58061 .41658 .59158 .4224 .58676 .45599 Mtetra
.496 .206 .403 r
.58676 .45599 .59158 .4224 .60274 .43133 .59781 .45368 Mtetra
.332 .03 .293 r
.59781 .45368 .60274 .43133 .61398 .43868 .60874 .44457 Mtetra
.636 .868 .504 r
.60874 .44457 .61398 .43868 .62522 .44213 .61953 .43059 Mtetra
.821 .696 .726 r
.61953 .43059 .62522 .44213 .63631 .43865 .63024 .415 Mtetra
.726 .56 .665 r
.63024 .415 .63631 .43865 .64724 .42957 .64093 .3999 Mtetra
.676 .507 .65 r
.64093 .3999 .64724 .42957 .65805 .41756 .6517 .38779 Mtetra
.645 .487 .655 r
.6517 .38779 .65805 .41756 .66881 .40477 .66261 .37921 Mtetra
.611 .48 .678 r
.66261 .37921 .66881 .40477 .67966 .39406 .67373 .37491 Mtetra
.573 .494 .727 r
.67373 .37491 .67966 .39406 .69063 .38593 .68505 .37388 Mtetra
.51 .544 .826 r
.68505 .37388 .69063 .38593 .7018 .3811 .69655 .37488 Mtetra
.347 .618 .952 r
.69655 .37488 .7018 .3811 .71315 .37874 .70817 .37678 Mtetra
.067 .602 .858 r
.70817 .37678 .71315 .37874 .72464 .3779 .71985 .37815 Mtetra
.076 0 0 r
.71985 .37815 .72464 .3779 .73626 .37777 .73156 .37864 Mtetra
0 0 0 r
.73156 .37864 .73626 .37777 .74792 .37729 .74325 .37767 Mtetra
.186 .718 .76 r
.74325 .37767 .74792 .37729 .75961 .37629 .75491 .37549 Mtetra
.419 .86 .914 r
.75491 .37549 .75961 .37629 .7713 .37437 .76655 .37221 Mtetra
.579 .905 .98 r
.76655 .37221 .7713 .37437 .78299 .37169 .77818 .36817 Mtetra
.654 .883 .982 r
.77818 .36817 .78299 .37169 .79468 .36835 .78983 .3637 Mtetra
.682 .848 .962 r
.78983 .3637 .79468 .36835 .80638 .36452 .80149 .35898 Mtetra
.687 .815 .944 r
.80149 .35898 .80638 .36452 .8181 .36043 .8132 .35427 Mtetra
.687 .793 .93 r
.8132 .35427 .8181 .36043 .82985 .35614 .82495 .34955 Mtetra
.685 .778 .922 r
.82495 .34955 .82985 .35614 .84164 .35177 .83675 .34489 Mtetra
.68 .767 .917 r
.83675 .34489 .84164 .35177 .85348 .34743 .84861 .34035 Mtetra
.634 .746 .929 r
.21326 .53739 .21976 .54307 .22923 .54067 .22276 .53478 Mtetra
.628 .738 .926 r
.22276 .53478 .22923 .54067 .23872 .53838 .23229 .5323 Mtetra
.621 .73 .924 r
.23229 .5323 .23872 .53838 .24825 .53615 .24184 .52999 Mtetra
.612 .724 .926 r
.24184 .52999 .24825 .53615 .25782 .53393 .25141 .52787 Mtetra
.596 .724 .933 r
.25141 .52787 .25782 .53393 .26743 .53171 .26101 .52602 Mtetra
.586 .734 .946 r
.26101 .52602 .26743 .53171 .27709 .52926 .27064 .52429 Mtetra
.571 .758 .966 r
.27064 .52429 .27709 .52926 .28682 .52641 .2803 .52261 Mtetra
.567 .805 .989 r
.2803 .52261 .28682 .52641 .29664 .52283 .29004 .5206 Mtetra
.558 .865 .996 r
.29004 .5206 .29664 .52283 .30656 .5182 .29986 .51798 Mtetra
.54 .914 .945 r
.29986 .51798 .30656 .5182 .31658 .51238 .30978 .51425 Mtetra
.521 .916 .826 r
.30978 .51425 .31658 .51238 .3267 .50515 .31984 .50896 Mtetra
.497 .879 .687 r
.31984 .50896 .3267 .50515 .33689 .49705 .33002 .50201 Mtetra
.557 .889 .635 r
.33002 .50201 .33689 .49705 .34712 .48842 .34032 .4932 Mtetra
.645 .934 .673 r
.34032 .4932 .34712 .48842 .3573 .48065 .35067 .48346 Mtetra
.792 .998 .803 r
.35067 .48346 .3573 .48065 .3674 .47485 .36104 .47344 Mtetra
.832 .93 .896 r
.36104 .47344 .3674 .47485 .37738 .47223 .37133 .46492 Mtetra
.725 .729 .854 r
.37133 .46492 .37738 .47223 .38723 .4738 .3815 .45925 Mtetra
.597 .544 .766 r
.3815 .45925 .38723 .4738 .39701 .47886 .39154 .45738 Mtetra
.499 .424 .703 r
.39154 .45738 .39701 .47886 .40677 .48688 .40146 .46004 Mtetra
.443 .358 .666 r
.40146 .46004 .40677 .48688 .41662 .49541 .41132 .46632 Mtetra
.402 .322 .651 r
.41132 .46632 .41662 .49541 .42663 .5024 .4212 .47523 Mtetra
.415 .339 .663 r
.4212 .47523 .42663 .5024 .43686 .50463 .43123 .48299 Mtetra
.469 .406 .704 r
.43123 .48299 .43686 .50463 .44733 .50016 .44146 .48704 Mtetra
.588 .563 .793 r
.44146 .48704 .44733 .50016 .45795 .48959 .4519 .48558 Mtetra
.806 .855 .886 r
.4519 .48558 .45795 .48959 .46867 .47343 .46252 .47753 Mtetra
.857 .984 .7 r
.46252 .47753 .46867 .47343 .4794 .45304 .47325 .46302 Mtetra
.68 .833 .405 r
.47325 .46302 .4794 .45304 .49008 .43078 .484 .44398 Mtetra
0 0 0 r
.484 .44398 .49008 .43078 .50066 .41159 .49468 .42653 Mtetra
.028 0 .065 r
.49468 .42653 .50066 .41159 .51115 .39853 .50528 .41422 Mtetra
.398 .043 .242 r
.50528 .41422 .51115 .39853 .52161 .39506 .51584 .41074 Mtetra
.593 .23 .322 r
.51584 .41074 .52161 .39506 .53213 .40121 .52644 .41613 Mtetra
.667 .3 .341 r
.52644 .41613 .53213 .40121 .54279 .41355 .53716 .4267 Mtetra
.694 .316 .328 r
.53716 .4267 .54279 .41355 .55362 .42902 .54803 .43893 Mtetra
.644 .232 .247 r
.54803 .43893 .55362 .42902 .5646 .44269 .559 .44665 Mtetra
.389 0 0 r
.559 .44665 .5646 .44269 .57567 .45214 .56999 .44789 Mtetra
.723 .853 .944 r
.56999 .44789 .57567 .45214 .58676 .45599 .58095 .44247 Mtetra
.755 .645 .74 r
.58095 .44247 .58676 .45599 .59781 .45368 .59183 .43146 Mtetra
.731 .569 .672 r
.59183 .43146 .59781 .45368 .60874 .44457 .6026 .41665 Mtetra
.712 .536 .65 r
.6026 .41665 .60874 .44457 .61953 .43059 .61331 .40064 Mtetra
.684 .512 .647 r
.61331 .40064 .61953 .43059 .63024 .415 .62406 .38727 Mtetra
.662 .504 .66 r
.62406 .38727 .63024 .415 .64093 .3999 .63491 .37755 Mtetra
.629 .507 .695 r
.63491 .37755 .64093 .3999 .6517 .38779 .64594 .37244 Mtetra
.579 .533 .768 r
.64594 .37244 .6517 .38779 .66261 .37921 .65716 .3712 Mtetra
.419 .594 .916 r
.65716 .3712 .66261 .37921 .67373 .37491 .66858 .3729 Mtetra
0 .438 .745 r
.66858 .3729 .67373 .37491 .68505 .37388 .68015 .37616 Mtetra
.42 0 0 r
.68015 .37616 .68505 .37388 .69655 .37488 .69181 .37916 Mtetra
.432 0 0 r
.69181 .37916 .69655 .37488 .70817 .37678 .70351 .38122 Mtetra
.333 0 0 r
.70351 .38122 .70817 .37678 .71985 .37815 .71518 .38137 Mtetra
.147 0 0 r
.71518 .38137 .71985 .37815 .73156 .37864 .72682 .37982 Mtetra
.199 .719 .697 r
.72682 .37982 .73156 .37864 .74325 .37767 .73842 .37665 Mtetra
.528 .911 .938 r
.73842 .37665 .74325 .37767 .75491 .37549 .74999 .37234 Mtetra
.671 .903 .977 r
.74999 .37234 .75491 .37549 .76655 .37221 .76156 .36738 Mtetra
.708 .848 .949 r
.76156 .36738 .76655 .37221 .77818 .36817 .77313 .36206 Mtetra
.707 .801 .923 r
.77313 .36206 .77818 .36817 .78983 .3637 .78475 .3568 Mtetra
.701 .772 .907 r
.78475 .3568 .78983 .3637 .80149 .35898 .79642 .35165 Mtetra
.69 .755 .901 r
.79642 .35165 .80149 .35898 .8132 .35427 .80815 .34677 Mtetra
.683 .748 .901 r
.80815 .34677 .8132 .35427 .82495 .34955 .81994 .3421 Mtetra
.678 .748 .904 r
.81994 .3421 .82495 .34955 .83675 .34489 .83179 .33759 Mtetra
.673 .752 .91 r
.83179 .33759 .83675 .34489 .84861 .34035 .8437 .33321 Mtetra
.656 .752 .92 r
.20671 .53168 .21326 .53739 .22276 .53478 .21628 .52855 Mtetra
.653 .734 .909 r
.21628 .52855 .22276 .53478 .23229 .5323 .22587 .52551 Mtetra
.644 .714 .898 r
.22587 .52551 .23229 .5323 .24184 .52999 .23548 .52267 Mtetra
.632 .695 .89 r
.23548 .52267 .24184 .52999 .25141 .52787 .2451 .52013 Mtetra
.613 .677 .887 r
.2451 .52013 .25141 .52787 .26101 .52602 .25473 .51805 Mtetra
.594 .664 .887 r
.25473 .51805 .26101 .52602 .27064 .52429 .26436 .51643 Mtetra
.568 .657 .897 r
.26436 .51643 .27064 .52429 .2803 .52261 .27399 .51537 Mtetra
.545 .668 .918 r
.27399 .51537 .2803 .52261 .29004 .5206 .28365 .51464 Mtetra
.51 .7 .955 r
.28365 .51464 .29004 .5206 .29986 .51798 .29334 .51412 Mtetra
.466 .768 .996 r
.29334 .51412 .29986 .51798 .30978 .51425 .3031 .51329 Mtetra
.342 .805 .931 r
.3031 .51329 .30978 .51425 .31984 .50896 .31296 .51171 Mtetra
0 0 0 r
.31296 .51171 .31984 .50896 .33002 .50201 .32296 .50872 Mtetra
.011 0 0 r
.32296 .50872 .33002 .50201 .34032 .4932 .33311 .50373 Mtetra
.059 0 0 r
.33311 .50373 .34032 .4932 .35067 .48346 .34341 .49647 Mtetra
.014 0 0 r
.34341 .49647 .35067 .48346 .36104 .47344 .35385 .48666 Mtetra
0 0 0 r
.35385 .48666 .36104 .47344 .37133 .46492 .36438 .47514 Mtetra
.36438 .47514 .37133 .46492 .3815 .45925 .37494 .46256 Mtetra
.841 .997 .767 r
.37494 .46256 .3815 .45925 .39154 .45738 .38546 .45052 Mtetra
.811 .758 .803 r
.38546 .45052 .39154 .45738 .40146 .46004 .3959 .44027 Mtetra
.671 .543 .7 r
.3959 .44027 .40146 .46004 .41132 .46632 .40623 .43279 Mtetra
.592 .439 .642 r
.40623 .43279 .41132 .46632 .4212 .47523 .41645 .42901 Mtetra
.544 .382 .612 r
.41645 .42901 .4212 .47523 .43123 .48299 .42658 .42956 Mtetra
.507 .347 .598 r
.42658 .42956 .43123 .48299 .44146 .48704 .43664 .43471 Mtetra
.475 .325 .597 r
.43664 .43471 .44146 .48704 .4519 .48558 .44671 .44331 Mtetra
.423 .302 .61 r
.44671 .44331 .4519 .48558 .46252 .47753 .45685 .45467 Mtetra
.192 .214 .655 r
.45685 .45467 .46252 .47753 .47325 .46302 .46707 .46862 Mtetra
.776 .355 .251 r
.46707 .46862 .47325 .46302 .484 .44398 .47743 .48369 Mtetra
.62 .325 .448 r
.47743 .48369 .484 .44398 .49468 .42653 .48797 .49621 Mtetra
.565 .301 .475 r
.48797 .49621 .49468 .42653 .50528 .41422 .49871 .50315 Mtetra
.518 .27 .479 r
.49871 .50315 .50528 .41422 .51584 .41074 .50961 .49974 Mtetra
.47 .231 .469 r
.50961 .49974 .51584 .41074 .52644 .41613 .52056 .48594 Mtetra
.41 .173 .441 r
.52056 .48594 .52644 .41613 .53716 .4267 .53147 .4665 Mtetra
.243 .007 .343 r
.53147 .4665 .53716 .4267 .54803 .43893 .54231 .44444 Mtetra
.912 .947 .597 r
.54231 .44444 .54803 .43893 .559 .44665 .55308 .42343 Mtetra
.752 .577 .659 r
.55308 .42343 .559 .44665 .56999 .44789 .5638 .40499 Mtetra
.663 .472 .617 r
.5638 .40499 .56999 .44789 .58095 .44247 .57451 .38928 Mtetra
.625 .434 .603 r
.57451 .38928 .58095 .44247 .59183 .43146 .58525 .37703 Mtetra
.597 .412 .602 r
.58525 .37703 .59183 .43146 .6026 .41665 .59607 .36942 Mtetra
.574 .404 .613 r
.59607 .36942 .6026 .41665 .61331 .40064 .60702 .36619 Mtetra
.545 .407 .644 r
.60702 .36619 .61331 .40064 .62406 .38727 .61812 .36673 Mtetra
.483 .427 .718 r
.61812 .36673 .62406 .38727 .63491 .37755 .6294 .37011 Mtetra
.147 .45 .881 r
.6294 .37011 .63491 .37755 .64594 .37244 .64083 .37533 Mtetra
.574 .034 0 r
.64083 .37533 .64594 .37244 .65716 .3712 .65239 .38115 Mtetra
.575 .149 .196 r
.65239 .38115 .65716 .3712 .66858 .3729 .66402 .3859 Mtetra
.541 .147 .244 r
.66402 .3859 .66858 .3729 .68015 .37616 .67568 .38893 Mtetra
.479 .085 .216 r
.67568 .38893 .68015 .37616 .69181 .37916 .6873 .38936 Mtetra
.381 0 .115 r
.6873 .38936 .69181 .37916 .70351 .38122 .69887 .38746 Mtetra
.156 0 0 r
.69887 .38746 .70351 .38122 .71518 .38137 .71038 .38349 Mtetra
.319 .783 .658 r
.71038 .38349 .71518 .38137 .72682 .37982 .72185 .37806 Mtetra
.695 .954 .952 r
.72185 .37806 .72682 .37982 .73842 .37665 .7333 .37185 Mtetra
.752 .859 .929 r
.7333 .37185 .73842 .37665 .74999 .37234 .74476 .3653 Mtetra
.735 .778 .887 r
.74476 .3653 .74999 .37234 .76156 .36738 .75626 .35896 Mtetra
.717 .733 .863 r
.75626 .35896 .76156 .36738 .77313 .36206 .76782 .35295 Mtetra
.697 .708 .856 r
.76782 .35295 .77313 .36206 .78475 .3568 .77945 .34751 Mtetra
.684 .699 .858 r
.77945 .34751 .78475 .3568 .79642 .35165 .79116 .34255 Mtetra
.672 .699 .867 r
.79116 .34255 .79642 .35165 .80815 .34677 .80296 .33805 Mtetra
.664 .706 .879 r
.80296 .33805 .80815 .34677 .81994 .3421 .81483 .33388 Mtetra
.658 .719 .893 r
.81483 .33388 .81994 .3421 .83179 .33759 .82677 .3299 Mtetra
.655 .735 .908 r
.82677 .3299 .83179 .33759 .8437 .33321 .83876 .32602 Mtetra
.677 .756 .911 r
.20012 .52592 .20671 .53168 .21628 .52855 .20975 .52225 Mtetra
.676 .739 .898 r
.20975 .52225 .21628 .52855 .22587 .52551 .21942 .51857 Mtetra
.67 .718 .885 r
.21942 .51857 .22587 .52551 .23548 .52267 .22911 .515 Mtetra
.659 .695 .872 r
.22911 .515 .23548 .52267 .2451 .52013 .23882 .51167 Mtetra
.644 .67 .86 r
.23882 .51167 .2451 .52013 .25473 .51805 .24852 .50871 Mtetra
.624 .642 .848 r
.24852 .50871 .25473 .51805 .26436 .51643 .25822 .50629 Mtetra
.598 .614 .838 r
.25822 .50629 .26436 .51643 .27399 .51537 .26791 .50458 Mtetra
.573 .589 .831 r
.26791 .50458 .27399 .51537 .28365 .51464 .27758 .50361 Mtetra
.542 .57 .832 r
.27758 .50361 .28365 .51464 .29334 .51412 .28725 .50347 Mtetra
.519 .567 .844 r
.28725 .50347 .29334 .51412 .3031 .51329 .29693 .50384 Mtetra
.492 .583 .874 r
.29693 .50384 .3031 .51329 .31296 .51171 .30665 .50454 Mtetra
.476 .645 .931 r
.30665 .50454 .31296 .51171 .32296 .50872 .31646 .50486 Mtetra
.439 .759 .996 r
.31646 .50486 .32296 .50872 .33311 .50373 .32638 .50424 Mtetra
.289 .789 .828 r
.32638 .50424 .33311 .50373 .34341 .49647 .33645 .50185 Mtetra
0 0 0 r
.33645 .50185 .34341 .49647 .35385 .48666 .3467 .49694 Mtetra
.02 0 0 r
.3467 .49694 .35385 .48666 .36438 .47514 .35712 .48931 Mtetra
.024 0 .016 r
.35712 .48931 .36438 .47514 .37494 .46256 .36769 .47875 Mtetra
.015 0 .052 r
.36769 .47875 .37494 .46256 .38546 .45052 .37833 .46641 Mtetra
0 0 .019 r
.37833 .46641 .38546 .45052 .3959 .44027 .389 .45311 Mtetra
0 0 0 r
.389 .45311 .3959 .44027 .40623 .43279 .39963 .44022 Mtetra
.39963 .44022 .40623 .43279 .41645 .42901 .41018 .429 Mtetra
.767 .981 .911 r
.41018 .429 .41645 .42901 .42658 .42956 .4206 .42152 Mtetra
.625 .683 .885 r
.4206 .42152 .42658 .42956 .43664 .43471 .43089 .41898 Mtetra
.495 .475 .764 r
.43089 .41898 .43664 .43471 .44671 .44331 .44111 .42085 Mtetra
.418 .367 .694 r
.44111 .42085 .44671 .44331 .45685 .45467 .4513 .42701 Mtetra
.35 .294 .653 r
.4513 .42701 .45685 .45467 .46707 .46862 .46151 .43774 Mtetra
.313 .256 .631 r
.46151 .43774 .46707 .46862 .47743 .48369 .4718 .4515 Mtetra
.366 .288 .636 r
.4718 .4515 .47743 .48369 .48797 .49621 .48227 .46331 Mtetra
.463 .354 .645 r
.48227 .46331 .48797 .49621 .49871 .50315 .49294 .46973 Mtetra
.588 .439 .647 r
.49294 .46973 .49871 .50315 .50961 .49974 .50377 .46627 Mtetra
.673 .497 .639 r
.50377 .46627 .50961 .49974 .52056 .48594 .51468 .45289 Mtetra
.71 .522 .633 r
.51468 .45289 .52056 .48594 .53147 .4665 .52557 .43406 Mtetra
.724 .533 .632 r
.52557 .43406 .53147 .4665 .54231 .44444 .53638 .41323 Mtetra
.711 .526 .638 r
.53638 .41323 .54231 .44444 .55308 .42343 .54715 .39538 Mtetra
.691 .522 .653 r
.54715 .39538 .55308 .42343 .5638 .40499 .55791 .3821 Mtetra
.673 .53 .682 r
.55791 .3821 .5638 .40499 .57451 .38928 .5687 .37312 Mtetra
.642 .559 .746 r
.5687 .37312 .57451 .38928 .58525 .37703 .57958 .3686 Mtetra
.489 .618 .905 r
.57958 .3686 .58525 .37703 .59607 .36942 .5906 .36907 Mtetra
.392 0 0 r
.5906 .36907 .59607 .36942 .60702 .36619 .60178 .37336 Mtetra
.607 .148 .138 r
.60178 .37336 .60702 .36619 .61812 .36673 .61311 .37939 Mtetra
.608 .212 .267 r
.61311 .37939 .61812 .36673 .6294 .37011 .62456 .38585 Mtetra
.587 .214 .302 r
.62456 .38585 .6294 .37011 .64083 .37533 .6361 .39139 Mtetra
.556 .186 .294 r
.6361 .39139 .64083 .37533 .65239 .38115 .64768 .39512 Mtetra
.491 .107 .24 r
.64768 .39512 .65239 .38115 .66402 .3859 .65924 .39588 Mtetra
.368 0 .099 r
.65924 .39588 .66402 .3859 .67568 .38893 .67075 .39385 Mtetra
.014 0 0 r
.67075 .39385 .67568 .38893 .6873 .38936 .68219 .38924 Mtetra
.63 .961 .894 r
.68219 .38924 .6873 .38936 .69887 .38746 .69358 .38279 Mtetra
.779 .866 .913 r
.69358 .38279 .69887 .38746 .71038 .38349 .70493 .37535 Mtetra
.761 .753 .845 r
.70493 .37535 .71038 .38349 .72185 .37806 .71629 .36751 Mtetra
.731 .689 .81 r
.71629 .36751 .72185 .37806 .7333 .37185 .72768 .35999 Mtetra
.711 .657 .795 r
.72768 .35999 .7333 .37185 .74476 .3653 .73913 .35299 Mtetra
.691 .641 .795 r
.73913 .35299 .74476 .3653 .75626 .35896 .75067 .34684 Mtetra
.677 .638 .804 r
.75067 .34684 .75626 .35896 .76782 .35295 .76229 .34144 Mtetra
.664 .643 .819 r
.76229 .34144 .76782 .35295 .77945 .34751 .77401 .33678 Mtetra
.654 .654 .838 r
.77401 .33678 .77945 .34751 .79116 .34255 .78582 .33268 Mtetra
.646 .67 .859 r
.78582 .33268 .79116 .34255 .80296 .33805 .79771 .32896 Mtetra
.64 .687 .878 r
.79771 .32896 .80296 .33805 .81483 .33388 .80967 .32549 Mtetra
.637 .706 .896 r
.80967 .32549 .81483 .33388 .82677 .3299 .8217 .32214 Mtetra
.636 .725 .912 r
.8217 .32214 .82677 .3299 .83876 .32602 .83378 .31877 Mtetra
.691 .759 .904 r
.19348 .52013 .20012 .52592 .20975 .52225 .20317 .51606 Mtetra
.693 .747 .893 r
.20317 .51606 .20975 .52225 .21942 .51857 .21291 .51186 Mtetra
.692 .732 .881 r
.21291 .51186 .21942 .51857 .22911 .515 .22268 .5076 Mtetra
.688 .712 .867 r
.22268 .5076 .22911 .515 .23882 .51167 .23247 .50338 Mtetra
.68 .687 .85 r
.23247 .50338 .23882 .51167 .24852 .50871 .2423 .49922 Mtetra
.665 .655 .831 r
.2423 .49922 .24852 .50871 .25822 .50629 .25212 .49538 Mtetra
.644 .62 .811 r
.25212 .49538 .25822 .50629 .26791 .50458 .26194 .49206 Mtetra
.618 .582 .791 r
.26194 .49206 .26791 .50458 .27758 .50361 .27173 .4895 Mtetra
.588 .545 .773 r
.27173 .4895 .27758 .50361 .28725 .50347 .28149 .48797 Mtetra
.559 .512 .759 r
.28149 .48797 .28725 .50347 .29693 .50384 .29122 .4875 Mtetra
.527 .485 .752 r
.29122 .4875 .29693 .50384 .30665 .50454 .30092 .48824 Mtetra
.5 .47 .755 r
.30092 .48824 .30665 .50454 .31646 .50486 .31062 .48991 Mtetra
.468 .467 .774 r
.31062 .48991 .31646 .50486 .32638 .50424 .32034 .49233 Mtetra
.432 .497 .827 r
.32034 .49233 .32638 .50424 .33645 .50185 .33013 .49485 Mtetra
.333 .583 .934 r
.33013 .49485 .33645 .50185 .3467 .49694 .34001 .49693 Mtetra
.099 0 0 r
.34001 .49693 .3467 .49694 .35712 .48931 .35004 .49765 Mtetra
.353 0 .036 r
.35004 .49765 .35712 .48931 .36769 .47875 .36024 .49626 Mtetra
.394 .046 .251 r
.36024 .49626 .36769 .47875 .37833 .46641 .37059 .49258 Mtetra
.398 .092 .327 r
.37059 .49258 .37833 .46641 .389 .45311 .3811 .48633 Mtetra
.394 .111 .36 r
.3811 .48633 .389 .45311 .39963 .44022 .39172 .47774 Mtetra
.382 .109 .371 r
.39172 .47774 .39963 .44022 .41018 .429 .40242 .46694 Mtetra
.357 .09 .364 r
.40242 .46694 .41018 .429 .4206 .42152 .41319 .45435 Mtetra
.295 .025 .324 r
.41319 .45435 .4206 .42152 .43089 .41898 .42398 .44026 Mtetra
.063 0 .15 r
.42398 .44026 .43089 .41898 .44111 .42085 .43479 .42467 Mtetra
.918 .976 .705 r
.43479 .42467 .44111 .42085 .4513 .42701 .44559 .40796 Mtetra
.766 .603 .676 r
.44559 .40796 .4513 .42701 .46151 .43774 .45634 .39097 Mtetra
.658 .464 .61 r
.45634 .39097 .46151 .43774 .4718 .4515 .46704 .37469 Mtetra
.609 .406 .581 r
.46704 .37469 .4718 .4515 .48227 .46331 .47767 .36053 Mtetra
.58 .375 .567 r
.47767 .36053 .48227 .46331 .49294 .46973 .48822 .35006 Mtetra
.553 .35 .56 r
.48822 .35006 .49294 .46973 .50377 .46627 .49871 .34648 Mtetra
.53 .333 .558 r
.49871 .34648 .50377 .46627 .51468 .45289 .5092 .34979 Mtetra
.514 .325 .562 r
.5092 .34979 .51468 .45289 .52557 .43406 .51978 .35683 Mtetra
.493 .319 .573 r
.51978 .35683 .52557 .43406 .53638 .41323 .53047 .36603 Mtetra
.453 .316 .604 r
.53047 .36603 .53638 .41323 .54715 .39538 .5413 .376 Mtetra
.284 .307 .709 r
.5413 .376 .54715 .39538 .55791 .3821 .55225 .38573 Mtetra
.675 .178 .059 r
.55225 .38573 .55791 .3821 .5687 .37312 .56333 .39438 Mtetra
.602 .259 .361 r
.56333 .39438 .5687 .37312 .57958 .3686 .57452 .40156 Mtetra
.571 .265 .411 r
.57452 .40156 .57958 .3686 .5906 .36907 .58579 .40724 Mtetra
.552 .258 .421 r
.58579 .40724 .5906 .36907 .60178 .37336 .59714 .41113 Mtetra
.533 .24 .416 r
.59714 .41113 .60178 .37336 .61311 .37939 .60852 .41281 Mtetra
.506 .209 .395 r
.60852 .41281 .61311 .37939 .62456 .38585 .61992 .41211 Mtetra
.458 .147 .35 r
.61992 .41211 .62456 .38585 .6361 .39139 .6313 .4088 Mtetra
.354 .011 .238 r
.6313 .4088 .6361 .39139 .64768 .39512 .64265 .40313 Mtetra
0 0 0 r
.64265 .40313 .64768 .39512 .65924 .39588 .65394 .39529 Mtetra
.799 .99 .882 r
.65394 .39529 .65924 .39588 .67075 .39385 .66518 .38604 Mtetra
.799 .77 .826 r
.66518 .38604 .67075 .39385 .68219 .38924 .67641 .37631 Mtetra
.744 .656 .762 r
.67641 .37631 .68219 .38924 .69358 .38279 .68765 .36666 Mtetra
.708 .602 .735 r
.68765 .36666 .69358 .38279 .70493 .37535 .69894 .35777 Mtetra
.686 .577 .727 r
.69894 .35777 .70493 .37535 .71629 .36751 .71029 .34981 Mtetra
.668 .566 .731 r
.71029 .34981 .71629 .36751 .72768 .35999 .72173 .34309 Mtetra
.655 .566 .743 r
.72173 .34309 .72768 .35999 .73913 .35299 .73327 .33747 Mtetra
.643 .574 .762 r
.73327 .33747 .73913 .35299 .75067 .34684 .74493 .33291 Mtetra
.633 .589 .787 r
.74493 .33291 .75067 .34684 .76229 .34144 .75668 .32913 Mtetra
.626 .611 .815 r
.75668 .32913 .76229 .34144 .77401 .33678 .76853 .32588 Mtetra
.621 .635 .844 r
.76853 .32588 .77401 .33678 .78582 .33268 .78045 .32298 Mtetra
.62 .663 .87 r
.78045 .32298 .78582 .33268 .79771 .32896 .79245 .32014 Mtetra
.618 .686 .891 r
.79245 .32014 .79771 .32896 .80967 .32549 .8045 .31733 Mtetra
.618 .706 .907 r
.8045 .31733 .80967 .32549 .8217 .32214 .81661 .31447 Mtetra
.622 .723 .919 r
.81661 .31447 .8217 .32214 .83378 .31877 .82876 .31146 Mtetra
.69 .759 .904 r
.18679 .51429 .19348 .52013 .20317 .51606 .1965 .51024 Mtetra
.696 .761 .902 r
.1965 .51024 .20317 .51606 .21291 .51186 .20627 .50599 Mtetra
.702 .762 .898 r
.20627 .50599 .21291 .51186 .22268 .5076 .21608 .50155 Mtetra
.707 .757 .891 r
.21608 .50155 .22268 .5076 .23247 .50338 .22593 .4969 Mtetra
.712 .746 .878 r
.22593 .4969 .23247 .50338 .2423 .49922 .23584 .49199 Mtetra
.709 .724 .862 r
.23584 .49199 .2423 .49922 .25212 .49538 .24578 .48701 Mtetra
.699 .693 .841 r
.24578 .48701 .25212 .49538 .26194 .49206 .25574 .48207 Mtetra
.679 .653 .817 r
.25574 .48207 .26194 .49206 .27173 .4895 .26569 .47752 Mtetra
.652 .607 .791 r
.26569 .47752 .27173 .4895 .28149 .48797 .27563 .47362 Mtetra
.621 .56 .765 r
.27563 .47362 .28149 .48797 .29122 .4875 .28553 .47066 Mtetra
.587 .515 .741 r
.28553 .47066 .29122 .4875 .30092 .48824 .29538 .46896 Mtetra
.556 .476 .72 r
.29538 .46896 .30092 .48824 .31062 .48991 .30519 .4686 Mtetra
.525 .442 .705 r
.30519 .4686 .31062 .48991 .32034 .49233 .31496 .46972 Mtetra
.5 .418 .695 r
.31496 .46972 .32034 .49233 .33013 .49485 .32472 .47209 Mtetra
.476 .402 .694 r
.32472 .47209 .33013 .49485 .34001 .49693 .33448 .47556 Mtetra
.463 .403 .705 r
.33448 .47556 .34001 .49693 .35004 .49765 .34431 .47934 Mtetra
.455 .424 .735 r
.34431 .47934 .35004 .49765 .36024 .49626 .35424 .48281 Mtetra
.457 .487 .802 r
.35424 .48281 .36024 .49626 .37059 .49258 .36431 .48514 Mtetra
.465 .638 .931 r
.36431 .48514 .37059 .49258 .3811 .48633 .37453 .48562 Mtetra
.296 .784 .898 r
.37453 .48562 .3811 .48633 .39172 .47774 .38491 .48402 Mtetra
.074 0 0 r
.38491 .48402 .39172 .47774 .40242 .46694 .39543 .47991 Mtetra
.166 0 .06 r
.39543 .47991 .40242 .46694 .41319 .45435 .40611 .47259 Mtetra
.159 0 .15 r
.40611 .47259 .41319 .45435 .42398 .44026 .41692 .46175 Mtetra
.132 0 .178 r
.41692 .46175 .42398 .44026 .43479 .42467 .42781 .448 Mtetra
.09 0 .179 r
.42781 .448 .43479 .42467 .44559 .40796 .43874 .43169 Mtetra
.002 0 .146 r
.43874 .43169 .44559 .40796 .45634 .39097 .4497 .41247 Mtetra
0 0 .068 r
.4497 .41247 .45634 .39097 .46704 .37469 .46063 .39164 Mtetra
0 0 0 r
.46063 .39164 .46704 .37469 .47767 .36053 .47145 .37282 Mtetra
.47145 .37282 .47767 .36053 .48822 .35006 .48215 .35899 Mtetra
.254 0 .004 r
.48215 .35899 .48822 .35006 .49871 .34648 .49272 .35539 Mtetra
.627 .201 .214 r
.49272 .35539 .49871 .34648 .5092 .34979 .50325 .36205 Mtetra
.691 .304 .31 r
.50325 .36205 .5092 .34979 .51978 .35683 .51388 .37374 Mtetra
.689 .329 .359 r
.51388 .37374 .51978 .35683 .53047 .36603 .52466 .38752 Mtetra
.656 .313 .38 r
.52466 .38752 .53047 .36603 .5413 .376 .53559 .39973 Mtetra
.62 .285 .382 r
.53559 .39973 .5413 .376 .55225 .38573 .54665 .40907 Mtetra
.593 .257 .37 r
.54665 .40907 .55225 .38573 .56333 .39438 .55782 .41586 Mtetra
.557 .215 .345 r
.55782 .41586 .56333 .39438 .57452 .40156 .56907 .41974 Mtetra
.494 .139 .293 r
.56907 .41974 .57452 .40156 .58579 .40724 .58036 .42007 Mtetra
.372 0 .164 r
.58036 .42007 .58579 .40724 .59714 .41113 .59165 .41714 Mtetra
0 0 0 r
.59165 .41714 .59714 .41113 .60852 .41281 .60293 .41167 Mtetra
.756 .973 .924 r
.60293 .41167 .60852 .41281 .61992 .41211 .61418 .40406 Mtetra
.792 .759 .823 r
.61418 .40406 .61992 .41211 .6313 .4088 .62539 .39454 Mtetra
.747 .639 .741 r
.62539 .39454 .6313 .4088 .64265 .40313 .63657 .38383 Mtetra
.714 .578 .702 r
.63657 .38383 .64265 .40313 .65394 .39529 .64773 .37277 Mtetra
.693 .547 .684 r
.64773 .37277 .65394 .39529 .66518 .38604 .6589 .36202 Mtetra
.674 .528 .679 r
.6589 .36202 .66518 .38604 .67641 .37631 .67012 .35236 Mtetra
.661 .521 .682 r
.67012 .35236 .67641 .37631 .68765 .36666 .6814 .34397 Mtetra
.648 .519 .693 r
.6814 .34397 .68765 .36666 .69894 .35777 .69277 .3371 Mtetra
.637 .525 .71 r
.69277 .3371 .69894 .35777 .71029 .34981 .70425 .3316 Mtetra
.626 .538 .735 r
.70425 .3316 .71029 .34981 .72173 .34309 .71585 .32739 Mtetra
.616 .557 .765 r
.71585 .32739 .72173 .34309 .73327 .33747 .72755 .32416 Mtetra
.607 .584 .802 r
.72755 .32416 .73327 .33747 .74493 .33291 .73935 .3216 Mtetra
.599 .616 .84 r
.73935 .3216 .74493 .33291 .75668 .32913 .75124 .31944 Mtetra
.596 .651 .875 r
.75124 .31944 .75668 .32913 .76853 .32588 .7632 .31733 Mtetra
.595 .682 .902 r
.7632 .31733 .76853 .32588 .78045 .32298 .77522 .31516 Mtetra
.601 .708 .919 r
.77522 .31516 .78045 .32298 .79245 .32014 .78727 .31271 Mtetra
.607 .725 .928 r
.78727 .31271 .79245 .32014 .8045 .31733 .79937 .31004 Mtetra
.614 .733 .931 r
.79937 .31004 .8045 .31733 .81661 .31447 .81152 .30717 Mtetra
.621 .737 .93 r
.81152 .30717 .81661 .31447 .82876 .31146 .82371 .3041 Mtetra
.676 .756 .911 r
.18006 .50842 .18679 .51429 .1965 .51024 .18976 .50472 Mtetra
.682 .77 .918 r
.18976 .50472 .1965 .51024 .20627 .50599 .1995 .50085 Mtetra
.692 .786 .922 r
.1995 .50085 .20627 .50599 .21608 .50155 .20931 .49672 Mtetra
.706 .8 .923 r
.20931 .49672 .21608 .50155 .22593 .4969 .21918 .49221 Mtetra
.724 .808 .917 r
.21918 .49221 .22593 .4969 .23584 .49199 .22912 .48718 Mtetra
.738 .806 .906 r
.22912 .48718 .23584 .49199 .24578 .48701 .23913 .4817 Mtetra
.748 .791 .887 r
.23913 .4817 .24578 .48701 .25574 .48207 .2492 .47572 Mtetra
.745 .759 .864 r
.2492 .47572 .25574 .48207 .26569 .47752 .25931 .46952 Mtetra
.732 .714 .834 r
.25931 .46952 .26569 .47752 .27563 .47362 .26945 .46326 Mtetra
.706 .658 .8 r
.26945 .46326 .27563 .47362 .28553 .47066 .27958 .4573 Mtetra
.674 .6 .765 r
.27958 .4573 .28553 .47066 .29538 .46896 .28969 .45196 Mtetra
.639 .544 .731 r
.28969 .45196 .29538 .46896 .30519 .4686 .29976 .44753 Mtetra
.605 .495 .701 r
.29976 .44753 .30519 .4686 .31496 .46972 .30978 .44432 Mtetra
.576 .453 .676 r
.30978 .44432 .31496 .46972 .32472 .47209 .31976 .4425 Mtetra
.55 .42 .656 r
.31976 .4425 .32472 .47209 .33448 .47556 .32968 .44228 Mtetra
.529 .395 .642 r
.32968 .44228 .33448 .47556 .34431 .47934 .33958 .44355 Mtetra
.512 .376 .633 r
.33958 .44355 .34431 .47934 .35424 .48281 .34947 .44625 Mtetra
.503 .369 .63 r
.34947 .44625 .35424 .48281 .36431 .48514 .35939 .44966 Mtetra
.499 .368 .634 r
.35939 .44966 .36431 .48514 .37453 .48562 .36939 .45335 Mtetra
.488 .371 .645 r
.36939 .45335 .37453 .48562 .38491 .48402 .37945 .45743 Mtetra
.471 .381 .672 r
.37945 .45743 .38491 .48402 .39543 .47991 .3896 .46174 Mtetra
.445 .422 .739 r
.3896 .46174 .39543 .47991 .40611 .47259 .39985 .46552 Mtetra
.255 .543 .924 r
.39985 .46552 .40611 .47259 .41692 .46175 .41021 .46851 Mtetra
.531 .063 .088 r
.41021 .46851 .41692 .46175 .42781 .448 .42065 .47176 Mtetra
.55 .221 .363 r
.42065 .47176 .42781 .448 .43874 .43169 .43117 .47512 Mtetra
.524 .24 .426 r
.43117 .47512 .43874 .43169 .4497 .41247 .44184 .47593 Mtetra
.508 .245 .451 r
.44184 .47593 .4497 .41247 .46063 .39164 .45266 .47356 Mtetra
.506 .253 .465 r
.45266 .47356 .46063 .39164 .47145 .37282 .46355 .46942 Mtetra
.507 .259 .474 r
.46355 .46942 .47145 .37282 .48215 .35899 .4745 .46452 Mtetra
.515 .268 .479 r
.4745 .46452 .48215 .35899 .49272 .35539 .48546 .46099 Mtetra
.52 .272 .48 r
.48546 .46099 .49272 .35539 .50325 .36205 .49646 .45884 Mtetra
.516 .266 .475 r
.49646 .45884 .50325 .36205 .51388 .37374 .50752 .45593 Mtetra
.504 .251 .465 r
.50752 .45593 .51388 .37374 .52466 .38752 .51862 .45124 Mtetra
.473 .216 .443 r
.51862 .45124 .52466 .38752 .53559 .39973 .52976 .44334 Mtetra
.413 .146 .396 r
.52976 .44334 .53559 .39973 .54665 .40907 .54091 .43285 Mtetra
.293 0 .271 r
.54091 .43285 .54665 .40907 .55782 .41586 .55205 .42243 Mtetra
0 0 0 r
.55205 .42243 .55782 .41586 .56907 .41974 .56319 .41227 Mtetra
.82 .775 .81 r
.56319 .41227 .56907 .41974 .58036 .42007 .57432 .40127 Mtetra
.722 .586 .702 r
.57432 .40127 .58036 .42007 .59165 .41714 .58544 .38971 Mtetra
.677 .516 .661 r
.58544 .38971 .59165 .41714 .60293 .41167 .59655 .37836 Mtetra
.654 .483 .641 r
.59655 .37836 .60293 .41167 .61418 .40406 .60766 .36737 Mtetra
.642 .468 .632 r
.60766 .36737 .61418 .40406 .62539 .39454 .61877 .35665 Mtetra
.634 .46 .63 r
.61877 .35665 .62539 .39454 .63657 .38383 .6299 .34663 Mtetra
.624 .455 .632 r
.6299 .34663 .63657 .38383 .64773 .37277 .64109 .33805 Mtetra
.616 .455 .64 r
.64109 .33805 .64773 .37277 .6589 .36202 .65235 .33099 Mtetra
.608 .459 .654 r
.65235 .33099 .6589 .36202 .67012 .35236 .66371 .32555 Mtetra
.6 .47 .674 r
.66371 .32555 .67012 .35236 .6814 .34397 .67517 .32154 Mtetra
.591 .486 .703 r
.67517 .32154 .6814 .34397 .69277 .3371 .68674 .31879 Mtetra
.582 .511 .74 r
.68674 .31879 .69277 .3371 .70425 .3316 .69841 .31698 Mtetra
.571 .545 .787 r
.69841 .31698 .70425 .3316 .71585 .32739 .71019 .31581 Mtetra
.558 .589 .841 r
.71019 .31581 .71585 .32739 .72755 .32416 .72206 .31496 Mtetra
.549 .641 .893 r
.72206 .31496 .72755 .32416 .73935 .3216 .734 .31406 Mtetra
.543 .689 .934 r
.734 .31406 .73935 .3216 .75124 .31944 .746 .31294 Mtetra
.552 .73 .958 r
.746 .31294 .75124 .31944 .7632 .31733 .75803 .3113 Mtetra
.567 .757 .967 r
.75803 .3113 .7632 .31733 .77522 .31516 .77009 .30919 Mtetra
.592 .771 .965 r
.77009 .30919 .77522 .31516 .78727 .31271 .78217 .30655 Mtetra
.612 .773 .958 r
.78217 .30655 .78727 .31271 .79937 .31004 .79428 .3035 Mtetra
.626 .767 .947 r
.79428 .3035 .79937 .31004 .81152 .30717 .80642 .30018 Mtetra
.635 .756 .935 r
.80642 .30018 .81152 .30717 .82371 .3041 .81861 .29669 Mtetra
.66 .752 .919 r
.17328 .5025 .18006 .50842 .18976 .50472 .18296 .49919 Mtetra
.661 .767 .928 r
.18296 .49919 .18976 .50472 .1995 .50085 .19268 .49581 Mtetra
.668 .787 .937 r
.19268 .49581 .1995 .50085 .20931 .49672 .20245 .49225 Mtetra
.68 .811 .945 r
.20245 .49225 .20931 .49672 .21918 .49221 .21229 .48837 Mtetra
.696 .838 .951 r
.21229 .48837 .21918 .49221 .22912 .48718 .2222 .48404 Mtetra
.716 .867 .953 r
.2222 .48404 .22912 .48718 .23913 .4817 .23218 .47917 Mtetra
.74 .892 .948 r
.23218 .47917 .23913 .4817 .2492 .47572 .24226 .47361 Mtetra
.76 .908 .941 r
.24226 .47361 .2492 .47572 .25931 .46952 .2524 .46746 Mtetra
.78 .91 .929 r
.2524 .46746 .25931 .46952 .26945 .46326 .26261 .46072 Mtetra
.79 .893 .917 r
.26261 .46072 .26945 .46326 .27958 .4573 .27287 .45366 Mtetra
.789 .854 .899 r
.27287 .45366 .27958 .4573 .28969 .45196 .28315 .44648 Mtetra
.77 .793 .871 r
.28315 .44648 .28969 .45196 .29976 .44753 .29342 .4395 Mtetra
.737 .718 .834 r
.29342 .4395 .29976 .44753 .30978 .44432 .30369 .433 Mtetra
.694 .64 .791 r
.30369 .433 .30978 .44432 .31976 .4425 .31391 .42728 Mtetra
.65 .568 .749 r
.31391 .42728 .31976 .4425 .32968 .44228 .3241 .42264 Mtetra
.609 .507 .713 r
.3241 .42264 .32968 .44228 .33958 .44355 .33424 .41938 Mtetra
.573 .458 .684 r
.33424 .41938 .33958 .44355 .34947 .44625 .34432 .41776 Mtetra
.551 .425 .662 r
.34432 .41776 .34947 .44625 .35939 .44966 .35439 .41737 Mtetra
.536 .402 .646 r
.35439 .41737 .35939 .44966 .36939 .45335 .36446 .41805 Mtetra
.52 .384 .635 r
.36446 .41805 .36939 .45335 .37945 .45743 .37454 .41999 Mtetra
.506 .368 .628 r
.37454 .41999 .37945 .45743 .3896 .46174 .38464 .42322 Mtetra
.494 .358 .625 r
.38464 .42322 .3896 .46174 .39985 .46552 .39478 .42745 Mtetra
.481 .35 .625 r
.39478 .42745 .39985 .46552 .41021 .46851 .40497 .4327 Mtetra
.445 .331 .63 r
.40497 .4327 .41021 .46851 .42065 .47176 .41519 .44008 Mtetra
.393 .308 .64 r
.41519 .44008 .42065 .47176 .43117 .47512 .42546 .44953 Mtetra
.349 .306 .669 r
.42546 .44953 .43117 .47512 .44184 .47593 .43585 .45897 Mtetra
.269 .328 .739 r
.43585 .45897 .44184 .47593 .45266 .47356 .4464 .4671 Mtetra
0 .359 .821 r
.4464 .4671 .45266 .47356 .46355 .46942 .45712 .47294 Mtetra
.428 0 0 r
.45712 .47294 .46355 .46942 .4745 .46452 .46801 .47523 Mtetra
.296 0 .063 r
.46801 .47523 .4745 .46452 .48546 .46099 .47906 .47169 Mtetra
0 0 0 r
.47906 .47169 .48546 .46099 .49646 .45884 .49022 .46231 Mtetra
.806 .987 .724 r
.49022 .46231 .49646 .45884 .50752 .45593 .50141 .44934 Mtetra
.873 .792 .767 r
.50141 .44934 .50752 .45593 .51862 .45124 .51258 .43403 Mtetra
.779 .627 .691 r
.51258 .43403 .51862 .45124 .52976 .44334 .52373 .41736 Mtetra
.726 .553 .656 r
.52373 .41736 .52976 .44334 .54091 .43285 .53483 .40063 Mtetra
.686 .508 .64 r
.53483 .40063 .54091 .43285 .55205 .42243 .5459 .38595 Mtetra
.657 .478 .631 r
.5459 .38595 .55205 .42243 .56319 .41227 .55695 .37338 Mtetra
.643 .464 .626 r
.55695 .37338 .56319 .41227 .57432 .40127 .56801 .36182 Mtetra
.635 .457 .625 r
.56801 .36182 .57432 .40127 .58544 .38971 .57907 .35126 Mtetra
.627 .454 .628 r
.57907 .35126 .58544 .38971 .59655 .37836 .59016 .34198 Mtetra
.621 .454 .634 r
.59016 .34198 .59655 .37836 .60766 .36737 .60128 .33396 Mtetra
.617 .458 .644 r
.60128 .33396 .60766 .36737 .61877 .35665 .61244 .32703 Mtetra
.613 .467 .659 r
.61244 .32703 .61877 .35665 .6299 .34663 .62367 .32134 Mtetra
.603 .477 .682 r
.62367 .32134 .6299 .34663 .64109 .33805 .63499 .31732 Mtetra
.592 .496 .715 r
.63499 .31732 .64109 .33805 .65235 .33099 .64642 .31471 Mtetra
.577 .527 .763 r
.64642 .31471 .65235 .33099 .66371 .32555 .65794 .31322 Mtetra
.554 .572 .826 r
.65794 .31322 .66371 .32555 .67517 .32154 .66957 .31254 Mtetra
.517 .628 .9 r
.66957 .31254 .67517 .32154 .68674 .31879 .68129 .31236 Mtetra
.459 .685 .963 r
.68129 .31236 .68674 .31879 .69841 .31698 .6931 .3124 Mtetra
.395 .726 .99 r
.6931 .3124 .69841 .31698 .71019 .31581 .70498 .31232 Mtetra
.357 .75 .986 r
.70498 .31232 .71019 .31581 .72206 .31496 .71692 .31192 Mtetra
.378 .779 .985 r
.71692 .31192 .72206 .31496 .734 .31406 .7289 .31092 Mtetra
.434 .807 .993 r
.7289 .31092 .734 .31406 .746 .31294 .74091 .30931 Mtetra
.511 .828 1 r
.74091 .30931 .746 .31294 .75803 .3113 .75294 .30699 Mtetra
.57 .829 .994 r
.75294 .30699 .75803 .3113 .77009 .30919 .76499 .30411 Mtetra
.612 .816 .979 r
.76499 .30411 .77009 .30919 .78217 .30655 .77706 .30075 Mtetra
.636 .799 .961 r
.77706 .30075 .78217 .30655 .79428 .3035 .78916 .29706 Mtetra
.648 .781 .945 r
.78916 .29706 .79428 .3035 .80642 .30018 .80129 .29317 Mtetra
.652 .764 .932 r
.80129 .29317 .80642 .30018 .81861 .29669 .81347 .28921 Mtetra
.642 .748 .926 r
.16646 .49655 .17328 .5025 .18296 .49919 .17611 .49363 Mtetra
.636 .761 .938 r
.17611 .49363 .18296 .49919 .19268 .49581 .1858 .49079 Mtetra
.632 .78 .952 r
.1858 .49079 .19268 .49581 .20245 .49225 .19552 .48794 Mtetra
.629 .808 .969 r
.19552 .48794 .20245 .49225 .21229 .48837 .20529 .48502 Mtetra
.62 .844 .985 r
.20529 .48502 .21229 .48837 .2222 .48404 .21511 .48197 Mtetra
.608 .888 .99 r
.21511 .48197 .2222 .48404 .23218 .47917 .225 .47856 Mtetra
.584 .922 .964 r
.225 .47856 .23218 .47917 .24226 .47361 .23497 .47462 Mtetra
.535 .924 .889 r
.23497 .47462 .24226 .47361 .2524 .46746 .24503 .47001 Mtetra
.484 .894 .783 r
.24503 .47001 .2524 .46746 .26261 .46072 .25519 .46456 Mtetra
.436 .849 .68 r
.25519 .46456 .26261 .46072 .27287 .45366 .26543 .45836 Mtetra
.428 .828 .621 r
.26543 .45836 .27287 .45366 .28315 .44648 .27576 .45141 Mtetra
.458 .842 .619 r
.27576 .45141 .28315 .44648 .29342 .4395 .28614 .4439 Mtetra
.543 .898 .681 r
.28614 .4439 .29342 .4395 .30369 .433 .29656 .43599 Mtetra
.673 .971 .796 r
.29656 .43599 .30369 .433 .31391 .42728 .307 .42786 Mtetra
.788 .986 .896 r
.307 .42786 .31391 .42728 .3241 .42264 .31746 .41972 Mtetra
.806 .886 .903 r
.31746 .41972 .3241 .42264 .33424 .41938 .3279 .41198 Mtetra
.753 .741 .842 r
.3279 .41198 .33424 .41938 .34432 .41776 .33831 .40494 Mtetra
.694 .62 .769 r
.33831 .40494 .34432 .41776 .35439 .41737 .3487 .39859 Mtetra
.649 .538 .715 r
.3487 .39859 .35439 .41737 .36446 .41805 .35907 .39297 Mtetra
.618 .483 .676 r
.35907 .39297 .36446 .41805 .37454 .41999 .36944 .38803 Mtetra
.595 .444 .647 r
.36944 .38803 .37454 .41999 .38464 .42322 .37981 .38379 Mtetra
.575 .413 .625 r
.37981 .38379 .38464 .42322 .39478 .42745 .39016 .38057 Mtetra
.558 .389 .609 r
.39016 .38057 .39478 .42745 .40497 .4327 .40051 .37866 Mtetra
.54 .368 .596 r
.40051 .37866 .40497 .4327 .41519 .44008 .41084 .37865 Mtetra
.524 .349 .586 r
.41084 .37865 .41519 .44008 .42546 .44953 .42117 .38087 Mtetra
.507 .332 .578 r
.42117 .38087 .42546 .44953 .43585 .45897 .43149 .38579 Mtetra
.496 .321 .573 r
.43149 .38579 .43585 .45897 .4464 .4671 .44186 .39279 Mtetra
.497 .321 .572 r
.44186 .39279 .4464 .4671 .45712 .47294 .45234 .3997 Mtetra
.513 .334 .575 r
.45234 .3997 .45712 .47294 .46801 .47523 .46298 .40406 Mtetra
.559 .37 .581 r
.46298 .40406 .46801 .47523 .47906 .47169 .47384 .40044 Mtetra
.599 .4 .583 r
.47384 .40044 .47906 .47169 .49022 .46231 .48485 .38881 Mtetra
.609 .406 .581 r
.48485 .38881 .49022 .46231 .50141 .44934 .49587 .3746 Mtetra
.608 .404 .58 r
.49587 .3746 .50141 .44934 .51258 .43403 .50686 .36025 Mtetra
.6 .398 .58 r
.50686 .36025 .51258 .43403 .52373 .41736 .51782 .34797 Mtetra
.59 .394 .583 r
.51782 .34797 .52373 .41736 .53483 .40063 .52876 .33838 Mtetra
.584 .394 .59 r
.52876 .33838 .53483 .40063 .5459 .38595 .53972 .33103 Mtetra
.578 .395 .598 r
.53972 .33103 .5459 .38595 .55695 .37338 .55072 .32559 Mtetra
.574 .401 .609 r
.55072 .32559 .55695 .37338 .56801 .36182 .56176 .32147 Mtetra
.572 .411 .625 r
.56176 .32147 .56801 .36182 .57907 .35126 .57286 .31838 Mtetra
.571 .428 .648 r
.57286 .31838 .57907 .35126 .59016 .34198 .58402 .31602 Mtetra
.569 .452 .68 r
.58402 .31602 .59016 .34198 .60128 .33396 .59526 .31433 Mtetra
.562 .486 .727 r
.59526 .31433 .60128 .33396 .61244 .32703 .60657 .31342 Mtetra
.542 .542 .804 r
.60657 .31342 .61244 .32703 .62367 .32134 .61798 .3132 Mtetra
.469 .629 .922 r
.61798 .3132 .62367 .32134 .63499 .31732 .62948 .31372 Mtetra
.241 .674 .959 r
.62948 .31372 .63499 .31732 .64642 .31471 .64107 .31466 Mtetra
.092 0 0 r
.64107 .31466 .64642 .31471 .65794 .31322 .65275 .3156 Mtetra
.256 0 0 r
.65275 .3156 .65794 .31322 .66957 .31254 .6645 .31633 Mtetra
.298 0 0 r
.6645 .31633 .66957 .31254 .68129 .31236 .67632 .31666 Mtetra
.283 0 0 r
.67632 .31666 .68129 .31236 .6931 .3124 .68819 .31643 Mtetra
.22 0 0 r
.68819 .31643 .6931 .3124 .70498 .31232 .70009 .31543 Mtetra
.105 0 0 r
.70009 .31543 .70498 .31232 .71692 .31192 .71202 .31365 Mtetra
0 0 0 r
.71202 .31365 .71692 .31192 .7289 .31092 .72396 .31101 Mtetra
.321 .809 .827 r
.72396 .31101 .7289 .31092 .74091 .30931 .73591 .30768 Mtetra
.514 .896 .959 r
.73591 .30768 .74091 .30931 .75294 .30699 .74789 .30378 Mtetra
.615 .891 .989 r
.74789 .30378 .75294 .30699 .76499 .30411 .75988 .29952 Mtetra
.653 .854 .977 r
.75988 .29952 .76499 .30411 .77706 .30075 .77192 .29511 Mtetra
.667 .819 .957 r
.77192 .29511 .77706 .30075 .78916 .29706 .78399 .29061 Mtetra
.67 .792 .939 r
.78399 .29061 .78916 .29706 .80129 .29317 .79612 .28611 Mtetra
.668 .771 .927 r
.79612 .28611 .80129 .29317 .81347 .28921 .8083 .28168 Mtetra
.616 .741 .935 r
.15958 .49055 .16646 .49655 .17611 .49363 .1692 .48815 Mtetra
.6 .756 .953 r
.1692 .48815 .17611 .49363 .1858 .49079 .17884 .48597 Mtetra
.577 .774 .973 r
.17884 .48597 .1858 .49079 .19552 .48794 .18849 .48399 Mtetra
.54 .797 .992 r
.18849 .48399 .19552 .48794 .20529 .48502 .19817 .48222 Mtetra
.466 .814 .998 r
.19817 .48222 .20529 .48502 .21511 .48197 .20787 .48073 Mtetra
.353 .806 .944 r
.20787 .48073 .21511 .48197 .225 .47856 .21761 .47923 Mtetra
.184 .717 .774 r
.21761 .47923 .225 .47856 .23497 .47462 .22742 .47755 Mtetra
0 0 0 r
.22742 .47755 .23497 .47462 .24503 .47001 .23732 .47541 Mtetra
.091 0 0 r
.23732 .47541 .24503 .47001 .25519 .46456 .24732 .47251 Mtetra
.158 0 0 r
.24732 .47251 .25519 .46456 .26543 .45836 .25744 .46877 Mtetra
.187 0 0 r
.25744 .46877 .26543 .45836 .27576 .45141 .26767 .46401 Mtetra
.204 0 .05 r
.26767 .46401 .27576 .45141 .28614 .4439 .278 .45832 Mtetra
.209 0 .092 r
.278 .45832 .28614 .4439 .29656 .43599 .28842 .45174 Mtetra
.205 0 .115 r
.28842 .45174 .29656 .43599 .307 .42786 .29891 .44433 Mtetra
.191 0 .12 r
.29891 .44433 .307 .42786 .31746 .41972 .30947 .43619 Mtetra
.173 0 .112 r
.30947 .43619 .31746 .41972 .3279 .41198 .32006 .42762 Mtetra
.143 0 .084 r
.32006 .42762 .3279 .41198 .33831 .40494 .33068 .41885 Mtetra
.096 0 .028 r
.33068 .41885 .33831 .40494 .3487 .39859 .34129 .41021 Mtetra
.023 0 0 r
.34129 .41021 .3487 .39859 .35907 .39297 .35189 .40192 Mtetra
0 0 0 r
.35189 .40192 .35907 .39297 .36944 .38803 .36251 .39355 Mtetra
.449 .816 .557 r
.36251 .39355 .36944 .38803 .37981 .38379 .37314 .385 Mtetra
.755 .993 .87 r
.37314 .385 .37981 .38379 .39016 .38057 .38377 .37671 Mtetra
.801 .863 .895 r
.38377 .37671 .39016 .38057 .40051 .37866 .39439 .36887 Mtetra
.743 .692 .803 r
.39439 .36887 .40051 .37866 .41084 .37865 .40502 .36115 Mtetra
.677 .565 .722 r
.40502 .36115 .41084 .37865 .42117 .38087 .41564 .35399 Mtetra
.601 .465 .669 r
.41564 .35399 .42117 .38087 .43149 .38579 .42619 .34992 Mtetra
.548 .402 .634 r
.42619 .34992 .43149 .38579 .44186 .39279 .43667 .34939 Mtetra
.526 .372 .614 r
.43667 .34939 .44186 .39279 .45234 .3997 .44717 .35081 Mtetra
.527 .364 .604 r
.44717 .35081 .45234 .3997 .46298 .40406 .45774 .35226 Mtetra
.567 .39 .601 r
.45774 .35226 .46298 .40406 .47384 .40044 .46848 .34858 Mtetra
.603 .416 .602 r
.46848 .34858 .47384 .40044 .48485 .38881 .47934 .33973 Mtetra
.606 .421 .606 r
.47934 .33973 .48485 .38881 .49587 .3746 .4902 .33091 Mtetra
.599 .424 .616 r
.4902 .33091 .49587 .3746 .50686 .36025 .50106 .32403 Mtetra
.577 .422 .635 r
.50106 .32403 .50686 .36025 .51782 .34797 .51193 .3207 Mtetra
.546 .429 .671 r
.51193 .3207 .51782 .34797 .52876 .33838 .52283 .32049 Mtetra
.533 .482 .745 r
.52283 .32049 .52876 .33838 .53972 .33103 .53381 .32086 Mtetra
.497 .584 .872 r
.53381 .32086 .53972 .33103 .55072 .32559 .54487 .32136 Mtetra
.279 .672 .971 r
.54487 .32136 .55072 .32559 .56176 .32147 .556 .32233 Mtetra
.207 0 0 r
.556 .32233 .56176 .32147 .57286 .31838 .56721 .32358 Mtetra
.394 0 0 r
.56721 .32358 .57286 .31838 .58402 .31602 .57851 .32467 Mtetra
.45 0 .079 r
.57851 .32467 .58402 .31602 .59526 .31433 .58988 .32569 Mtetra
.483 .064 .168 r
.58988 .32569 .59526 .31433 .60657 .31342 .60134 .32708 Mtetra
.497 .101 .219 r
.60134 .32708 .60657 .31342 .61798 .3132 .6129 .32862 Mtetra
.498 .117 .247 r
.6129 .32862 .61798 .3132 .62948 .31372 .62453 .32997 Mtetra
.491 .116 .255 r
.62453 .32997 .62948 .31372 .64107 .31466 .63624 .3309 Mtetra
.475 .101 .249 r
.63624 .3309 .64107 .31466 .65275 .3156 .648 .33109 Mtetra
.452 .074 .229 r
.648 .33109 .65275 .3156 .6645 .31633 .6598 .33044 Mtetra
.419 .031 .194 r
.6598 .33044 .6645 .31633 .67632 .31666 .67164 .32888 Mtetra
.37 0 .136 r
.67164 .32888 .67632 .31666 .68819 .31643 .68349 .32636 Mtetra
.289 0 .041 r
.68349 .32636 .68819 .31643 .70009 .31543 .69535 .32279 Mtetra
.16 0 0 r
.69535 .32279 .70009 .31543 .71202 .31365 .70722 .31834 Mtetra
0 0 0 r
.70722 .31834 .71202 .31365 .72396 .31101 .71908 .3131 Mtetra
.335 .794 .667 r
.71908 .3131 .72396 .31101 .73591 .30768 .73095 .30736 Mtetra
.569 .938 .89 r
.73095 .30736 .73591 .30768 .74789 .30378 .74284 .30144 Mtetra
.676 .941 .963 r
.74284 .30144 .74789 .30378 .75988 .29952 .75477 .29549 Mtetra
.7 .893 .967 r
.75477 .29549 .75988 .29952 .77192 .29511 .76676 .28983 Mtetra
.702 .847 .952 r
.76676 .28983 .77192 .29511 .78399 .29061 .77881 .28437 Mtetra
.696 .811 .936 r
.77881 .28437 .78399 .29061 .79612 .28611 .79091 .27912 Mtetra
.688 .783 .923 r
.79091 .27912 .79612 .28611 .8083 .28168 .80308 .27409 Mtetra
.588 .732 .943 r
.15266 .48451 .15958 .49055 .1692 .48815 .16224 .48262 Mtetra
.564 .744 .961 r
.16224 .48262 .1692 .48815 .17884 .48597 .17183 .48101 Mtetra
.528 .754 .979 r
.17183 .48101 .17884 .48597 .18849 .48399 .18143 .47974 Mtetra
.469 .76 .994 r
.18143 .47974 .18849 .48399 .19817 .48222 .19104 .47888 Mtetra
.36 .746 .987 r
.19104 .47888 .19817 .48222 .20787 .48073 .20065 .47859 Mtetra
.217 .705 .926 r
.20065 .47859 .20787 .48073 .21761 .47923 .21027 .47861 Mtetra
.028 .598 .762 r
.21027 .47861 .21761 .47923 .22742 .47755 .21994 .47884 Mtetra
.136 0 0 r
.21994 .47884 .22742 .47755 .23732 .47541 .22967 .47895 Mtetra
.24 0 0 r
.22967 .47895 .23732 .47541 .24732 .47251 .2395 .47864 Mtetra
.298 0 0 r
.2395 .47864 .24732 .47251 .25744 .46877 .24944 .47769 Mtetra
.32 0 .015 r
.24944 .47769 .25744 .46877 .26767 .46401 .25951 .47586 Mtetra
.336 0 .105 r
.25951 .47586 .26767 .46401 .278 .45832 .26969 .47315 Mtetra
.344 0 .167 r
.26969 .47315 .278 .45832 .28842 .45174 .27998 .46951 Mtetra
.348 0 .213 r
.27998 .46951 .28842 .45174 .29891 .44433 .29038 .46494 Mtetra
.35 .012 .245 r
.29038 .46494 .29891 .44433 .30947 .43619 .30087 .4594 Mtetra
.35 .027 .268 r
.30087 .4594 .30947 .43619 .32006 .42762 .31145 .45295 Mtetra
.349 .035 .284 r
.31145 .45295 .32006 .42762 .33068 .41885 .32211 .4457 Mtetra
.357 .048 .298 r
.32211 .4457 .33068 .41885 .34129 .41021 .33279 .43822 Mtetra
.367 .062 .309 r
.33279 .43822 .34129 .41021 .35189 .40192 .34348 .43081 Mtetra
.36 .058 .312 r
.34348 .43081 .35189 .40192 .36251 .39355 .35423 .4227 Mtetra
.341 .044 .306 r
.35423 .4227 .36251 .39355 .37314 .385 .36504 .41358 Mtetra
.322 .025 .296 r
.36504 .41358 .37314 .385 .38377 .37671 .37589 .40374 Mtetra
.289 0 .274 r
.37589 .40374 .38377 .37671 .39439 .36887 .38677 .39306 Mtetra
.187 0 .212 r
.38677 .39306 .39439 .36887 .40502 .36115 .39774 .38006 Mtetra
0 0 .063 r
.39774 .38006 .40502 .36115 .41564 .35399 .40877 .36504 Mtetra
0 0 0 r
.40877 .36504 .41564 .35399 .42619 .34992 .4197 .35176 Mtetra
.794 .999 .824 r
.4197 .35176 .42619 .34992 .43667 .34939 .43052 .34172 Mtetra
.744 .744 .852 r
.43052 .34172 .43667 .34939 .44717 .35081 .44125 .33497 Mtetra
.629 .556 .753 r
.44125 .33497 .44717 .35081 .45774 .35226 .45193 .33107 Mtetra
.608 .5 .705 r
.45193 .33107 .45774 .35226 .46848 .34858 .46265 .32735 Mtetra
.605 .498 .705 r
.46265 .32735 .46848 .34858 .47934 .33973 .47341 .32379 Mtetra
.556 .515 .765 r
.47341 .32379 .47934 .33973 .4902 .33091 .48417 .3231 Mtetra
.317 .554 .92 r
.48417 .3231 .4902 .33091 .50106 .32403 .49497 .32573 Mtetra
.569 .012 0 r
.49497 .32573 .50106 .32403 .51193 .3207 .50584 .33164 Mtetra
.631 .216 .238 r
.50584 .33164 .51193 .3207 .52283 .32049 .51681 .33933 Mtetra
.579 .218 .321 r
.51681 .33933 .52283 .32049 .53381 .32086 .5279 .34503 Mtetra
.542 .206 .348 r
.5279 .34503 .53381 .32086 .54487 .32136 .5391 .34841 Mtetra
.531 .206 .361 r
.5391 .34841 .54487 .32136 .556 .32233 .55039 .35096 Mtetra
.522 .202 .366 r
.55039 .35096 .556 .32233 .56721 .32358 .56176 .3528 Mtetra
.51 .192 .365 r
.56176 .3528 .56721 .32358 .57851 .32467 .5732 .35363 Mtetra
.501 .183 .361 r
.5732 .35363 .57851 .32467 .58988 .32569 .58471 .35376 Mtetra
.5 .18 .355 r
.58471 .35376 .58988 .32569 .60134 .32708 .5963 .35397 Mtetra
.496 .172 .347 r
.5963 .35397 .60134 .32708 .6129 .32862 .60796 .35397 Mtetra
.481 .153 .333 r
.60796 .35397 .6129 .32862 .62453 .32997 .61967 .35315 Mtetra
.461 .126 .312 r
.61967 .35315 .62453 .32997 .63624 .3309 .63142 .3514 Mtetra
.431 .087 .279 r
.63142 .3514 .63624 .3309 .648 .33109 .64321 .34868 Mtetra
.39 .033 .233 r
.64321 .34868 .648 .33109 .6598 .33044 .65501 .34498 Mtetra
.33 0 .164 r
.65501 .34498 .6598 .33044 .67164 .32888 .66682 .34032 Mtetra
.238 0 .059 r
.66682 .34032 .67164 .32888 .68349 .32636 .67863 .33475 Mtetra
.084 0 0 r
.67863 .33475 .68349 .32636 .69535 .32279 .69043 .32825 Mtetra
0 0 0 r
.69043 .32825 .69535 .32279 .70722 .31834 .70223 .32108 Mtetra
.429 .835 .643 r
.70223 .32108 .70722 .31834 .71908 .3131 .71402 .31346 Mtetra
.642 .967 .846 r
.71402 .31346 .71908 .3131 .73095 .30736 .72583 .30569 Mtetra
.732 .972 .929 r
.72583 .30569 .73095 .30736 .74284 .30144 .73768 .29813 Mtetra
.754 .931 .946 r
.73768 .29813 .74284 .30144 .75477 .29549 .74957 .29089 Mtetra
.743 .884 .944 r
.74957 .29089 .75477 .29549 .76676 .28983 .76154 .28421 Mtetra
.73 .845 .935 r
.76154 .28421 .76676 .28983 .77881 .28437 .77357 .27796 Mtetra
.717 .814 .925 r
.77357 .27796 .77881 .28437 .79091 .27912 .78566 .27206 Mtetra
.706 .789 .916 r
.78566 .27206 .79091 .27912 .80308 .27409 .79782 .26643 Mtetra
.57 .727 .948 r
.14569 .47843 .15266 .48451 .16224 .48262 .15526 .47682 Mtetra
.556 .733 .958 r
.15526 .47682 .16224 .48262 .17183 .48101 .16485 .47536 Mtetra
.54 .734 .964 r
.16485 .47536 .17183 .48101 .18143 .47974 .17446 .47409 Mtetra
.523 .728 .967 r
.17446 .47409 .18143 .47974 .19104 .47888 .1841 .47306 Mtetra
.504 .715 .966 r
.1841 .47306 .19104 .47888 .20065 .47859 .19376 .47234 Mtetra
.496 .697 .958 r
.19376 .47234 .20065 .47859 .21027 .47861 .20346 .47184 Mtetra
.493 .677 .947 r
.20346 .47184 .21027 .47861 .21994 .47884 .21318 .47153 Mtetra
.5 .662 .934 r
.21318 .47153 .21994 .47884 .22967 .47895 .22296 .47126 Mtetra
.511 .655 .924 r
.22296 .47126 .22967 .47895 .2395 .47864 .2328 .4709 Mtetra
.525 .66 .921 r
.2328 .4709 .2395 .47864 .24944 .47769 .24272 .47032 Mtetra
.542 .679 .928 r
.24272 .47032 .24944 .47769 .25951 .47586 .25273 .46934 Mtetra
.554 .714 .947 r
.25273 .46934 .25951 .47586 .26969 .47315 .26283 .46796 Mtetra
.559 .765 .975 r
.26283 .46796 .26969 .47315 .27998 .46951 .273 .46615 Mtetra
.55 .833 .998 r
.273 .46615 .27998 .46951 .29038 .46494 .28327 .46378 Mtetra
.497 .881 .968 r
.28327 .46378 .29038 .46494 .30087 .4594 .29363 .46078 Mtetra
.364 .833 .805 r
.29363 .46078 .30087 .4594 .31145 .45295 .30409 .45704 Mtetra
0 0 0 r
.30409 .45704 .31145 .45295 .32211 .4457 .31463 .45253 Mtetra
.036 0 0 r
.31463 .45253 .32211 .4457 .33279 .43822 .3252 .44798 Mtetra
.201 0 0 r
.3252 .44798 .33279 .43822 .34348 .43081 .3358 .44374 Mtetra
.259 0 .084 r
.3358 .44374 .34348 .43081 .35423 .4227 .34646 .43888 Mtetra
.282 0 .156 r
.34646 .43888 .35423 .4227 .36504 .41358 .35722 .43301 Mtetra
.311 0 .213 r
.35722 .43301 .36504 .41358 .37589 .40374 .36802 .42653 Mtetra
.324 0 .253 r
.36802 .42653 .37589 .40374 .38677 .39306 .37889 .41913 Mtetra
.272 0 .257 r
.37889 .41913 .38677 .39306 .39774 .38006 .38993 .40831 Mtetra
.207 0 .246 r
.38993 .40831 .39774 .38006 .40877 .36504 .40109 .39383 Mtetra
.209 0 .252 r
.40109 .39383 .40877 .36504 .4197 .35176 .41224 .37908 Mtetra
.229 0 .252 r
.41224 .37908 .4197 .35176 .43052 .34172 .42331 .36577 Mtetra
.259 0 .242 r
.42331 .36577 .43052 .34172 .44125 .33497 .43429 .35516 Mtetra
.309 0 .228 r
.43429 .35516 .44125 .33497 .45193 .33107 .44517 .34801 Mtetra
.373 .012 .217 r
.44517 .34801 .45193 .33107 .46265 .32735 .45599 .34428 Mtetra
.465 .097 .256 r
.45599 .34428 .46265 .32735 .47341 .32379 .4668 .34396 Mtetra
.539 .187 .319 r
.4668 .34396 .47341 .32379 .48417 .3231 .47762 .34713 Mtetra
.575 .237 .358 r
.47762 .34713 .48417 .3231 .49497 .32573 .48851 .35305 Mtetra
.587 .258 .379 r
.48851 .35305 .49497 .32573 .50584 .33164 .49949 .36045 Mtetra
.582 .257 .383 r
.49949 .36045 .50584 .33164 .51681 .33933 .5106 .36761 Mtetra
.541 .217 .368 r
.5106 .36761 .51681 .33933 .5279 .34503 .52183 .37111 Mtetra
.494 .167 .341 r
.52183 .37111 .5279 .34503 .5391 .34841 .53315 .37117 Mtetra
.472 .134 .311 r
.53315 .37117 .5391 .34841 .55039 .35096 .54454 .37031 Mtetra
.448 .094 .271 r
.54454 .37031 .55039 .35096 .56176 .3528 .55599 .36884 Mtetra
.403 .03 .212 r
.55599 .36884 .56176 .3528 .5732 .35363 .5675 .36634 Mtetra
.346 0 .128 r
.5675 .36634 .5732 .35363 .58471 .35376 .57905 .36322 Mtetra
.296 0 .016 r
.57905 .36322 .58471 .35376 .5963 .35397 .59066 .36041 Mtetra
.196 0 0 r
.59066 .36041 .5963 .35397 .60796 .35397 .60233 .35757 Mtetra
0 0 0 r
.60233 .35757 .60796 .35397 .61967 .35315 .61403 .35394 Mtetra
.378 .841 .805 r
.61403 .35394 .61967 .35315 .63142 .3514 .62576 .34954 Mtetra
.621 .93 .968 r
.62576 .34954 .63142 .3514 .64321 .34868 .63751 .34449 Mtetra
.707 .88 .962 r
.63751 .34449 .64321 .34868 .65501 .34498 .64928 .33886 Mtetra
.727 .817 .921 r
.64928 .33886 .65501 .34498 .66682 .34032 .66107 .33277 Mtetra
.732 .774 .887 r
.66107 .33277 .66682 .34032 .67863 .33475 .67288 .32626 Mtetra
.735 .75 .864 r
.67288 .32626 .67863 .33475 .69043 .32825 .68469 .31933 Mtetra
.737 .741 .854 r
.68469 .31933 .69043 .32825 .70223 .32108 .69652 .31214 Mtetra
.739 .742 .854 r
.69652 .31214 .70223 .32108 .71402 .31346 .70837 .30486 Mtetra
.742 .752 .861 r
.70837 .30486 .71402 .31346 .72583 .30569 .72025 .2976 Mtetra
.741 .767 .874 r
.72025 .2976 .72583 .30569 .73768 .29813 .73217 .29053 Mtetra
.739 .781 .887 r
.73217 .29053 .73768 .29813 .74957 .29089 .74414 .28367 Mtetra
.733 .792 .9 r
.74414 .28367 .74957 .29089 .76154 .28421 .75616 .27713 Mtetra
.727 .795 .906 r
.75616 .27713 .76154 .28421 .77357 .27796 .76823 .27082 Mtetra
.72 .793 .909 r
.76823 .27082 .77357 .27796 .78566 .27206 .78035 .2647 Mtetra
.715 .785 .907 r
.78035 .2647 .78566 .27206 .79782 .26643 .79252 .25872 Mtetra
.576 .729 .946 r
.13868 .4723 .14569 .47843 .15526 .47682 .14827 .47057 Mtetra
.583 .727 .942 r
.14827 .47057 .15526 .47682 .16485 .47536 .15791 .46872 Mtetra
.593 .718 .931 r
.15791 .46872 .16485 .47536 .17446 .47409 .16762 .46674 Mtetra
.604 .699 .911 r
.16762 .46674 .17446 .47409 .1841 .47306 .17739 .46459 Mtetra
.615 .672 .881 r
.17739 .46459 .1841 .47306 .19376 .47234 .18723 .4622 Mtetra
.617 .633 .844 r
.18723 .4622 .19376 .47234 .20346 .47184 .19712 .45971 Mtetra
.612 .593 .808 r
.19712 .45971 .20346 .47184 .21318 .47153 .20706 .45719 Mtetra
.602 .557 .775 r
.20706 .45719 .21318 .47153 .22296 .47126 .21703 .4548 Mtetra
.591 .526 .75 r
.21703 .4548 .22296 .47126 .2328 .4709 .22701 .4527 Mtetra
.581 .504 .733 r
.22701 .4527 .2328 .4709 .24272 .47032 .23702 .45084 Mtetra
.574 .489 .722 r
.23702 .45084 .24272 .47032 .25273 .46934 .24706 .44925 Mtetra
.568 .481 .717 r
.24706 .44925 .25273 .46934 .26283 .46796 .25712 .4479 Mtetra
.563 .479 .718 r
.25712 .4479 .26283 .46796 .273 .46615 .26722 .44677 Mtetra
.562 .484 .725 r
.26722 .44677 .273 .46615 .28327 .46378 .27738 .4457 Mtetra
.565 .497 .738 r
.27738 .4457 .28327 .46378 .29363 .46078 .28758 .44459 Mtetra
.572 .521 .76 r
.28758 .44459 .29363 .46078 .30409 .45704 .29786 .44325 Mtetra
.583 .558 .792 r
.29786 .44325 .30409 .45704 .31463 .45253 .30822 .44158 Mtetra
.569 .602 .847 r
.30822 .44158 .31463 .45253 .3252 .44798 .3186 .44033 Mtetra
.515 .666 .93 r
.3186 .44033 .3252 .44798 .3358 .44374 .32899 .43979 Mtetra
.413 .758 .995 r
.32899 .43979 .3358 .44374 .34646 .43888 .33946 .43914 Mtetra
.116 .668 .758 r
.33946 .43914 .34646 .43888 .35722 .43301 .35 .43808 Mtetra
.274 0 0 r
.35 .43808 .35722 .43301 .36802 .42653 .36058 .43742 Mtetra
.411 0 .116 r
.36058 .43742 .36802 .42653 .37889 .41913 .37122 .43689 Mtetra
.377 .017 .22 r
.37122 .43689 .37889 .41913 .38993 .40831 .38206 .43327 Mtetra
.335 .018 .271 r
.38206 .43327 .38993 .40831 .40109 .39383 .3931 .42556 Mtetra
.338 .046 .313 r
.3931 .42556 .40109 .39383 .41224 .37908 .40425 .41548 Mtetra
.348 .067 .337 r
.40425 .41548 .41224 .37908 .42331 .36577 .41544 .40424 Mtetra
.372 .091 .353 r
.41544 .40424 .42331 .36577 .43429 .35516 .42661 .39374 Mtetra
.405 .121 .365 r
.42661 .39374 .43429 .35516 .44517 .34801 .4377 .38552 Mtetra
.461 .167 .379 r
.4377 .38552 .44517 .34801 .45599 .34428 .44871 .3818 Mtetra
.512 .212 .394 r
.44871 .3818 .45599 .34428 .4668 .34396 .45967 .38258 Mtetra
.535 .234 .403 r
.45967 .38258 .4668 .34396 .47762 .34713 .47066 .38566 Mtetra
.542 .239 .404 r
.47066 .38566 .47762 .34713 .48851 .35305 .48174 .38952 Mtetra
.531 .225 .394 r
.48174 .38952 .48851 .35305 .49949 .36045 .49293 .39223 Mtetra
.502 .19 .369 r
.49293 .39223 .49949 .36045 .5106 .36761 .50422 .39258 Mtetra
.425 .099 .307 r
.50422 .39258 .5106 .36761 .52183 .37111 .5156 .38879 Mtetra
.287 0 .184 r
.5156 .38879 .52183 .37111 .53315 .37117 .52703 .38188 Mtetra
.122 0 0 r
.52703 .38188 .53315 .37117 .54454 .37031 .53849 .37509 Mtetra
0 0 0 r
.53849 .37509 .54454 .37031 .55599 .36884 .54997 .36869 Mtetra
.665 .97 .907 r
.54997 .36869 .55599 .36884 .5675 .36634 .56148 .36186 Mtetra
.76 .873 .93 r
.56148 .36186 .5675 .36634 .57905 .36322 .57301 .3549 Mtetra
.721 .743 .87 r
.57301 .3549 .57905 .36322 .59066 .36041 .58458 .34867 Mtetra
.687 .656 .814 r
.58458 .34867 .59066 .36041 .60233 .35757 .5962 .34285 Mtetra
.674 .605 .771 r
.5962 .34285 .60233 .35757 .61403 .35394 .60784 .33668 Mtetra
.664 .572 .742 r
.60784 .33668 .61403 .35394 .62576 .34954 .61951 .33027 Mtetra
.654 .55 .724 r
.61951 .33027 .62576 .34954 .63751 .34449 .6312 .3238 Mtetra
.647 .535 .713 r
.6312 .3238 .63751 .34449 .64928 .33886 .64293 .31739 Mtetra
.64 .526 .708 r
.64293 .31739 .64928 .33886 .66107 .33277 .6547 .3112 Mtetra
.637 .523 .708 r
.6547 .3112 .66107 .33277 .67288 .32626 .66652 .30524 Mtetra
.635 .526 .713 r
.66652 .30524 .67288 .32626 .68469 .31933 .67838 .29955 Mtetra
.636 .536 .724 r
.67838 .29955 .68469 .31933 .69652 .31214 .6903 .2941 Mtetra
.638 .553 .742 r
.6903 .2941 .69652 .31214 .70837 .30486 .70227 .28895 Mtetra
.645 .579 .766 r
.70227 .28895 .70837 .30486 .72025 .2976 .7143 .28392 Mtetra
.657 .615 .796 r
.7143 .28392 .72025 .2976 .73217 .29053 .72637 .27885 Mtetra
.67 .656 .828 r
.72637 .27885 .73217 .29053 .74414 .28367 .73847 .27367 Mtetra
.686 .7 .857 r
.73847 .27367 .74414 .28367 .75616 .27713 .75061 .26824 Mtetra
.697 .733 .879 r
.75061 .26824 .75616 .27713 .76823 .27082 .76277 .26262 Mtetra
.705 .756 .892 r
.76277 .26262 .76823 .27082 .78035 .2647 .77496 .25685 Mtetra
.709 .77 .899 r
.77496 .25685 .78035 .2647 .79252 .25872 .78718 .25095 Mtetra
.627 .744 .931 r
.13161 .46613 .13868 .4723 .14827 .47057 .14133 .46343 Mtetra
.645 .719 .902 r
.14133 .46343 .14827 .47057 .15791 .46872 .15113 .46032 Mtetra
.657 .688 .867 r
.15113 .46032 .15791 .46872 .16762 .46674 .16102 .45677 Mtetra
.663 .655 .831 r
.16102 .45677 .16762 .46674 .17739 .46459 .171 .45273 Mtetra
.668 .623 .795 r
.171 .45273 .17739 .46459 .18723 .4622 .18108 .44806 Mtetra
.659 .587 .764 r
.18108 .44806 .18723 .4622 .19712 .45971 .19121 .44318 Mtetra
.645 .555 .738 r
.19121 .44318 .19712 .45971 .20706 .45719 .20136 .43836 Mtetra
.627 .526 .719 r
.20136 .43836 .20706 .45719 .21703 .4548 .2115 .43402 Mtetra
.606 .499 .706 r
.2115 .43402 .21703 .4548 .22701 .4527 .22158 .43056 Mtetra
.589 .48 .697 r
.22158 .43056 .22701 .4527 .23702 .45084 .23164 .42788 Mtetra
.573 .465 .693 r
.23164 .42788 .23702 .45084 .24706 .44925 .24166 .42604 Mtetra
.561 .456 .692 r
.24166 .42604 .24706 .44925 .25712 .4479 .25168 .42481 Mtetra
.552 .452 .694 r
.25168 .42481 .25712 .4479 .26722 .44677 .26172 .42407 Mtetra
.545 .45 .697 r
.26172 .42407 .26722 .44677 .27738 .4457 .27178 .42368 Mtetra
.541 .452 .703 r
.27178 .42368 .27738 .4457 .28758 .44459 .28189 .42353 Mtetra
.539 .458 .712 r
.28189 .42353 .28758 .44459 .29786 .44325 .29205 .42345 Mtetra
.54 .468 .724 r
.29205 .42345 .29786 .44325 .30822 .44158 .30228 .42334 Mtetra
.529 .476 .741 r
.30228 .42334 .30822 .44158 .3186 .44033 .31254 .42363 Mtetra
.51 .481 .761 r
.31254 .42363 .3186 .44033 .32899 .43979 .32283 .42451 Mtetra
.502 .495 .781 r
.32283 .42451 .32899 .43979 .33946 .43914 .33319 .42549 Mtetra
.491 .514 .808 r
.33319 .42549 .33946 .43914 .35 .43808 .34361 .42656 Mtetra
.389 .499 .85 r
.34361 .42656 .35 .43808 .36058 .43742 .35401 .42934 Mtetra
.129 .444 .879 r
.35401 .42934 .36058 .43742 .37122 .43689 .36441 .43394 Mtetra
0 .456 .78 r
.36441 .43394 .37122 .43689 .38206 .43327 .37498 .43694 Mtetra
.248 0 0 r
.37498 .43694 .38206 .43327 .3931 .42556 .38578 .43678 Mtetra
.281 0 .047 r
.38578 .43678 .3931 .42556 .40425 .41548 .39677 .43323 Mtetra
.279 0 .171 r
.39677 .43323 .40425 .41548 .41544 .40424 .40792 .4266 Mtetra
.307 0 .236 r
.40792 .4266 .41544 .40424 .42661 .39374 .41913 .41885 Mtetra
.347 .028 .275 r
.41913 .41885 .42661 .39374 .4377 .38552 .43035 .41158 Mtetra
.426 .102 .312 r
.43035 .41158 .4377 .38552 .44871 .3818 .44149 .40785 Mtetra
.487 .157 .333 r
.44149 .40785 .44871 .3818 .45967 .38258 .4526 .40768 Mtetra
.493 .159 .329 r
.4526 .40768 .45967 .38258 .47066 .38566 .46377 .40802 Mtetra
.467 .124 .299 r
.46377 .40802 .47066 .38566 .48174 .38952 .47504 .40723 Mtetra
.371 .008 .213 r
.47504 .40723 .48174 .38952 .49293 .39223 .48641 .40335 Mtetra
.096 0 0 r
.48641 .40335 .49293 .39223 .50422 .39258 .49785 .39604 Mtetra
.67 .953 .712 r
.49785 .39604 .50422 .39258 .5156 .38879 .50934 .38553 Mtetra
.878 .902 .843 r
.50934 .38553 .5156 .38879 .52703 .38188 .52082 .37336 Mtetra
.799 .757 .814 r
.52082 .37336 .52703 .38188 .53849 .37509 .5323 .36301 Mtetra
.737 .67 .786 r
.5323 .36301 .53849 .37509 .54997 .36869 .54379 .35438 Mtetra
.717 .631 .76 r
.54379 .35438 .54997 .36869 .56148 .36186 .55529 .34582 Mtetra
.703 .605 .744 r
.55529 .34582 .56148 .36186 .57301 .3549 .56681 .33735 Mtetra
.685 .58 .733 r
.56681 .33735 .57301 .3549 .58458 .34867 .57836 .32947 Mtetra
.669 .558 .72 r
.57836 .32947 .58458 .34867 .5962 .34285 .58993 .32197 Mtetra
.662 .542 .708 r
.58993 .32197 .5962 .34285 .60784 .33668 .60152 .31444 Mtetra
.654 .529 .698 r
.60152 .31444 .60784 .33668 .61951 .33027 .61314 .30696 Mtetra
.647 .518 .692 r
.61314 .30696 .61951 .33027 .6312 .3238 .62479 .29971 Mtetra
.639 .509 .688 r
.62479 .29971 .6312 .3238 .64293 .31739 .63648 .29282 Mtetra
.631 .502 .687 r
.63648 .29282 .64293 .31739 .6547 .3112 .64821 .2864 Mtetra
.622 .495 .687 r
.64821 .2864 .6547 .3112 .66652 .30524 .66001 .28062 Mtetra
.612 .49 .69 r
.66001 .28062 .66652 .30524 .67838 .29955 .67188 .27569 Mtetra
.602 .488 .696 r
.67188 .27569 .67838 .29955 .6903 .2941 .68384 .27157 Mtetra
.591 .49 .708 r
.68384 .27157 .6903 .2941 .70227 .28895 .6959 .26836 Mtetra
.587 .502 .725 r
.6959 .26836 .70227 .28895 .7143 .28392 .70805 .26564 Mtetra
.591 .524 .748 r
.70805 .26564 .7143 .28392 .72637 .27885 .72027 .26299 Mtetra
.6 .556 .777 r
.72027 .26299 .72637 .27885 .73847 .27367 .73254 .26013 Mtetra
.622 .601 .809 r
.73254 .26013 .73847 .27367 .75061 .26824 .74482 .2566 Mtetra
.641 .646 .839 r
.74482 .2566 .75061 .26824 .76277 .26262 .75713 .25256 Mtetra
.659 .69 .867 r
.75713 .25256 .76277 .26262 .77496 .25685 .76946 .24805 Mtetra
.676 .731 .891 r
.76946 .24805 .77496 .25685 .78718 .25095 .7818 .24311 Mtetra
.685 .758 .907 r
.12449 .45992 .13161 .46613 .14133 .46343 .1344 .45579 Mtetra
.697 .72 .867 r
.1344 .45579 .14133 .46343 .15113 .46032 .1444 .45103 Mtetra
.701 .682 .829 r
.1444 .45103 .15113 .46032 .16102 .45677 .15451 .44565 Mtetra
.7 .648 .795 r
.15451 .44565 .16102 .45677 .171 .45273 .16472 .43964 Mtetra
.7 .62 .764 r
.16472 .43964 .171 .45273 .18108 .44806 .17503 .43285 Mtetra
.687 .59 .742 r
.17503 .43285 .18108 .44806 .19121 .44318 .18536 .42594 Mtetra
.67 .563 .725 r
.18536 .42594 .19121 .44318 .20136 .43836 .19568 .41938 Mtetra
.648 .537 .714 r
.19568 .41938 .20136 .43836 .2115 .43402 .20594 .41367 Mtetra
.62 .51 .707 r
.20594 .41367 .2115 .43402 .22158 .43056 .21608 .40939 Mtetra
.598 .492 .704 r
.21608 .40939 .22158 .43056 .23164 .42788 .22616 .40624 Mtetra
.578 .476 .702 r
.22616 .40624 .23164 .42788 .24166 .42604 .23617 .40417 Mtetra
.564 .466 .702 r
.23617 .40417 .24166 .42604 .25168 .42481 .24617 .4028 Mtetra
.556 .46 .701 r
.24617 .4028 .25168 .42481 .26172 .42407 .2562 .40184 Mtetra
.548 .454 .7 r
.2562 .40184 .26172 .42407 .27178 .42368 .26624 .40127 Mtetra
.541 .449 .7 r
.26624 .40127 .27178 .42368 .28189 .42353 .27632 .40102 Mtetra
.538 .446 .7 r
.27632 .40102 .28189 .42353 .29205 .42345 .28644 .40096 Mtetra
.536 .446 .7 r
.28644 .40096 .29205 .42345 .30228 .42334 .29662 .40099 Mtetra
.536 .447 .702 r
.29662 .40099 .30228 .42334 .31254 .42363 .30687 .40102 Mtetra
.536 .446 .7 r
.30687 .40102 .31254 .42363 .32283 .42451 .31718 .40103 Mtetra
.536 .442 .695 r
.31718 .40103 .32283 .42451 .33319 .42549 .32756 .40103 Mtetra
.53 .432 .688 r
.32756 .40103 .33319 .42549 .34361 .42656 .33798 .40137 Mtetra
.473 .391 .683 r
.33798 .40137 .34361 .42656 .35401 .42934 .34831 .4046 Mtetra
.386 .336 .68 r
.34831 .4046 .35401 .42934 .36441 .43394 .35854 .41136 Mtetra
.358 .333 .695 r
.35854 .41136 .36441 .43394 .37498 .43694 .36888 .41849 Mtetra
.361 .374 .739 r
.36888 .41849 .37498 .43694 .38578 .43678 .37939 .4242 Mtetra
.425 .501 .834 r
.37939 .4242 .38578 .43678 .39677 .43323 .39014 .42657 Mtetra
.551 .725 .955 r
.39014 .42657 .39677 .43323 .40792 .4266 .40113 .42499 Mtetra
.572 .908 .976 r
.40113 .42499 .40792 .4266 .41913 .41885 .41227 .42097 Mtetra
.405 .85 .756 r
.41227 .42097 .41913 .41885 .43035 .41158 .42349 .41572 Mtetra
0 0 0 r
.42349 .41572 .43035 .41158 .44149 .40785 .4347 .41198 Mtetra
.09 0 0 r
.4347 .41198 .44149 .40785 .4526 .40768 .44592 .40975 Mtetra
0 0 0 r
.44592 .40975 .4526 .40768 .46377 .40802 .45722 .40628 Mtetra
.689 .943 .961 r
.45722 .40628 .46377 .40802 .47504 .40723 .46862 .40037 Mtetra
.809 .797 .841 r
.46862 .40037 .47504 .40723 .48641 .40335 .4801 .39046 Mtetra
.789 .678 .742 r
.4801 .39046 .48641 .40335 .49785 .39604 .49163 .37716 Mtetra
.754 .606 .694 r
.49163 .37716 .49785 .39604 .50934 .38553 .50314 .36239 Mtetra
.724 .565 .674 r
.50314 .36239 .50934 .38553 .52082 .37336 .51462 .34795 Mtetra
.679 .527 .672 r
.51462 .34795 .52082 .37336 .5323 .36301 .52608 .33707 Mtetra
.646 .504 .675 r
.52608 .33707 .5323 .36301 .54379 .35438 .53754 .32908 Mtetra
.644 .506 .679 r
.53754 .32908 .54379 .35438 .55529 .34582 .54903 .32144 Mtetra
.648 .512 .684 r
.54903 .32144 .55529 .34582 .56681 .33735 .56054 .31377 Mtetra
.652 .519 .689 r
.56054 .31377 .56681 .33735 .57836 .32947 .57206 .30606 Mtetra
.652 .52 .69 r
.57206 .30606 .57836 .32947 .58993 .32197 .58361 .29835 Mtetra
.65 .518 .689 r
.58361 .29835 .58993 .32197 .60152 .31444 .59518 .29071 Mtetra
.648 .516 .689 r
.59518 .29071 .60152 .31444 .61314 .30696 .60678 .28325 Mtetra
.644 .514 .69 r
.60678 .28325 .61314 .30696 .62479 .29971 .61841 .2761 Mtetra
.639 .511 .691 r
.61841 .2761 .62479 .29971 .63648 .29282 .63008 .26936 Mtetra
.634 .509 .693 r
.63008 .26936 .63648 .29282 .64821 .2864 .64179 .26301 Mtetra
.624 .504 .696 r
.64179 .26301 .64821 .2864 .66001 .28062 .65357 .25738 Mtetra
.609 .496 .699 r
.65357 .25738 .66001 .28062 .67188 .27569 .66544 .25286 Mtetra
.592 .488 .704 r
.66544 .25286 .67188 .27569 .68384 .27157 .67741 .2495 Mtetra
.57 .48 .713 r
.67741 .2495 .68384 .27157 .6959 .26836 .68952 .24763 Mtetra
.555 .481 .727 r
.68952 .24763 .6959 .26836 .70805 .26564 .70176 .24664 Mtetra
.548 .492 .745 r
.70176 .24664 .70805 .26564 .72027 .26299 .71409 .24602 Mtetra
.55 .515 .769 r
.71409 .24602 .72027 .26299 .73254 .26013 .7265 .24529 Mtetra
.569 .554 .798 r
.7265 .24529 .73254 .26013 .74482 .2566 .73893 .24375 Mtetra
.587 .596 .829 r
.73893 .24375 .74482 .2566 .75713 .25256 .75139 .24156 Mtetra
.607 .644 .861 r
.75139 .24156 .75713 .25256 .76946 .24805 .76388 .23871 Mtetra
.629 .696 .894 r
.76388 .23871 .76946 .24805 .7818 .24311 .77637 .23521 Mtetra
.725 .765 .884 r
.11732 .45366 .12449 .45992 .1344 .45579 .12741 .4482 Mtetra
.73 .729 .85 r
.12741 .4482 .1344 .45579 .1444 .45103 .13759 .44213 Mtetra
.73 .7 .822 r
.13759 .44213 .1444 .45103 .15451 .44565 .14786 .43555 Mtetra
.728 .676 .8 r
.14786 .43555 .15451 .44565 .16472 .43964 .15819 .42849 Mtetra
.728 .659 .782 r
.15819 .42849 .16472 .43964 .17503 .43285 .1686 .42091 Mtetra
.719 .645 .774 r
.1686 .42091 .17503 .43285 .18536 .42594 .17901 .41345 Mtetra
.705 .631 .772 r
.17901 .41345 .18536 .42594 .19568 .41938 .18937 .40662 Mtetra
.686 .62 .776 r
.18937 .40662 .19568 .41938 .20594 .41367 .19965 .40069 Mtetra
.658 .604 .783 r
.19965 .40069 .20594 .41367 .21608 .40939 .20983 .39611 Mtetra
.637 .59 .785 r
.20983 .39611 .21608 .40939 .22616 .40624 .21995 .39237 Mtetra
.62 .574 .78 r
.21995 .39237 .22616 .40624 .23617 .40417 .23006 .38922 Mtetra
.608 .554 .768 r
.23006 .38922 .23617 .40417 .24617 .4028 .24018 .3864 Mtetra
.602 .535 .751 r
.24018 .3864 .24617 .4028 .2562 .40184 .25034 .38365 Mtetra
.59 .51 .733 r
.25034 .38365 .2562 .40184 .26624 .40127 .26052 .38126 Mtetra
.576 .488 .717 r
.26052 .38126 .26624 .40127 .27632 .40102 .2707 .37934 Mtetra
.57 .472 .704 r
.2707 .37934 .27632 .40102 .28644 .40096 .28092 .37761 Mtetra
.567 .461 .692 r
.28092 .37761 .28644 .40096 .29662 .40099 .29119 .37588 Mtetra
.576 .457 .681 r
.29119 .37588 .29662 .40099 .30687 .40102 .30156 .37349 Mtetra
.586 .453 .667 r
.30156 .37349 .30687 .40102 .31718 .40103 .31205 .37012 Mtetra
.586 .441 .651 r
.31205 .37012 .31718 .40103 .32756 .40103 .3226 .36628 Mtetra
.577 .424 .637 r
.3226 .36628 .32756 .40103 .33798 .40137 .33319 .36266 Mtetra
.536 .386 .624 r
.33319 .36266 .33798 .40137 .34831 .4046 .34362 .36238 Mtetra
.484 .342 .611 r
.34362 .36238 .34831 .4046 .35854 .41136 .35389 .36654 Mtetra
.465 .324 .603 r
.35389 .36654 .35854 .41136 .36888 .41849 .36415 .37256 Mtetra
.464 .321 .601 r
.36415 .37256 .36888 .41849 .37939 .4242 .37451 .37884 Mtetra
.491 .342 .606 r
.37451 .37884 .37939 .4242 .39014 .42657 .38508 .38276 Mtetra
.527 .371 .613 r
.38508 .38276 .39014 .42657 .40113 .42499 .39589 .38321 Mtetra
.554 .394 .619 r
.39589 .38321 .40113 .42499 .41227 .42097 .40686 .38112 Mtetra
.574 .412 .625 r
.40686 .38112 .41227 .42097 .42349 .41572 .41796 .37719 Mtetra
.574 .415 .629 r
.41796 .37719 .42349 .41572 .4347 .41198 .42909 .37339 Mtetra
.572 .414 .629 r
.42909 .37339 .4347 .41198 .44592 .40975 .44026 .36973 Mtetra
.588 .423 .625 r
.44026 .36973 .44592 .40975 .45722 .40628 .45153 .3642 Mtetra
.607 .432 .619 r
.45153 .3642 .45722 .40628 .46862 .40037 .46288 .35612 Mtetra
.629 .444 .613 r
.46288 .35612 .46862 .40037 .4801 .39046 .4743 .34454 Mtetra
.641 .45 .609 r
.4743 .34454 .4801 .39046 .49163 .37716 .48574 .33054 Mtetra
.638 .447 .607 r
.48574 .33054 .49163 .37716 .50314 .36239 .49716 .31677 Mtetra
.628 .441 .61 r
.49716 .31677 .50314 .36239 .51462 .34795 .50854 .30485 Mtetra
.599 .424 .616 r
.50854 .30485 .51462 .34795 .52608 .33707 .51991 .29741 Mtetra
.574 .413 .625 r
.51991 .29741 .52608 .33707 .53754 .32908 .5313 .29334 Mtetra
.577 .424 .637 r
.5313 .29334 .53754 .32908 .54903 .32144 .54274 .2895 Mtetra
.588 .442 .651 r
.54274 .2895 .54903 .32144 .56054 .31377 .55423 .28518 Mtetra
.606 .466 .665 r
.55423 .28518 .56054 .31377 .57206 .30606 .56575 .27985 Mtetra
.621 .486 .677 r
.56575 .27985 .57206 .30606 .58361 .29835 .57729 .27385 Mtetra
.626 .498 .687 r
.57729 .27385 .58361 .29835 .59518 .29071 .58887 .26783 Mtetra
.629 .509 .698 r
.58887 .26783 .59518 .29071 .60678 .28325 .60049 .262 Mtetra
.628 .519 .711 r
.60049 .262 .60678 .28325 .61841 .2761 .61216 .25665 Mtetra
.629 .533 .727 r
.61216 .25665 .61841 .2761 .63008 .26936 .62388 .25167 Mtetra
.635 .553 .745 r
.62388 .25167 .63008 .26936 .64179 .26301 .63565 .24674 Mtetra
.634 .568 .763 r
.63565 .24674 .64179 .26301 .65357 .25738 .64747 .24215 Mtetra
.626 .577 .779 r
.64747 .24215 .65357 .25738 .66544 .25286 .65937 .23817 Mtetra
.608 .575 .791 r
.65937 .23817 .66544 .25286 .67741 .2495 .67136 .23506 Mtetra
.574 .56 .801 r
.67136 .23506 .67741 .2495 .68952 .24763 .68348 .23333 Mtetra
.548 .549 .807 r
.68348 .23333 .68952 .24763 .70176 .24664 .69573 .23256 Mtetra
.528 .542 .813 r
.69573 .23256 .70176 .24664 .71409 .24602 .7081 .23244 Mtetra
.522 .547 .823 r
.7081 .23244 .71409 .24602 .7265 .24529 .72057 .23247 Mtetra
.537 .569 .835 r
.72057 .23247 .7265 .24529 .73893 .24375 .73309 .23195 Mtetra
.549 .597 .854 r
.73309 .23195 .73893 .24375 .75139 .24156 .74565 .23095 Mtetra
.563 .632 .878 r
.74565 .23095 .75139 .24156 .76388 .23871 .75826 .22941 Mtetra
.58 .676 .905 r
.75826 .22941 .76388 .23871 .77637 .23521 .7709 .22725 Mtetra
.748 .767 .868 r
.1101 .44736 .11732 .45366 .12741 .4482 .12033 .44095 Mtetra
.748 .742 .847 r
.12033 .44095 .12741 .4482 .13759 .44213 .13062 .43417 Mtetra
.746 .725 .832 r
.13062 .43417 .13759 .44213 .14786 .43555 .14096 .42714 Mtetra
.744 .715 .825 r
.14096 .42714 .14786 .43555 .15819 .42849 .15132 .42001 Mtetra
.744 .714 .824 r
.15132 .42001 .15819 .42849 .1686 .42091 .16171 .41284 Mtetra
.741 .724 .836 r
.16171 .41284 .1686 .42091 .17901 .41345 .17207 .40607 Mtetra
.729 .739 .86 r
.17207 .40607 .17901 .41345 .18937 .40662 .18236 .40011 Mtetra
.716 .762 .889 r
.18236 .40011 .18937 .40662 .19965 .40069 .1926 .39485 Mtetra
.693 .78 .918 r
.1926 .39485 .19965 .40069 .20983 .39611 .20279 .39039 Mtetra
.686 .783 .924 r
.20279 .39039 .20983 .39611 .21995 .39237 .21299 .3861 Mtetra
.695 .768 .908 r
.21299 .3861 .21995 .39237 .23006 .38922 .22326 .3815 Mtetra
.695 .726 .874 r
.22326 .3815 .23006 .38922 .24018 .3864 .23358 .37667 Mtetra
.69 .677 .832 r
.23358 .37667 .24018 .3864 .25034 .38365 .24396 .37152 Mtetra
.667 .624 .797 r
.24396 .37152 .25034 .38365 .26052 .38126 .25434 .36668 Mtetra
.638 .576 .769 r
.25434 .36668 .26052 .38126 .2707 .37934 .2647 .36256 Mtetra
.625 .545 .744 r
.2647 .36256 .2707 .37934 .28092 .37761 .27508 .3586 Mtetra
.62 .522 .722 r
.27508 .3586 .28092 .37761 .29119 .37588 .28551 .35448 Mtetra
.633 .514 .7 r
.28551 .35448 .29119 .37588 .30156 .37349 .29608 .34898 Mtetra
.647 .506 .677 r
.29608 .34898 .30156 .37349 .31205 .37012 .30681 .34149 Mtetra
.644 .488 .656 r
.30681 .34149 .31205 .37012 .3226 .36628 .31763 .33295 Mtetra
.632 .465 .639 r
.31763 .33295 .3226 .36628 .33319 .36266 .32847 .32426 Mtetra
.59 .424 .625 r
.32847 .32426 .33319 .36266 .34362 .36238 .33912 .3188 Mtetra
.539 .378 .611 r
.33912 .3188 .34362 .36238 .35389 .36654 .34955 .31798 Mtetra
.511 .35 .598 r
.34955 .31798 .35389 .36654 .36415 .37256 .35989 .31991 Mtetra
.498 .335 .59 r
.35989 .31991 .36415 .37256 .37451 .37884 .37024 .32342 Mtetra
.508 .339 .587 r
.37024 .32342 .37451 .37884 .38508 .38276 .38073 .32587 Mtetra
.527 .352 .587 r
.38073 .32587 .38508 .38276 .39589 .38321 .39139 .32607 Mtetra
.541 .363 .588 r
.39139 .32607 .39589 .38321 .40686 .38112 .4022 .32439 Mtetra
.554 .373 .59 r
.4022 .32439 .40686 .38112 .41796 .37719 .41313 .32104 Mtetra
.558 .376 .591 r
.41313 .32104 .41796 .37719 .42909 .37339 .42413 .31717 Mtetra
.562 .379 .591 r
.42413 .31717 .42909 .37339 .44026 .36973 .43518 .31278 Mtetra
.573 .386 .591 r
.43518 .31278 .44026 .36973 .45153 .3642 .44632 .30671 Mtetra
.584 .395 .59 r
.44632 .30671 .45153 .3642 .46288 .35612 .45752 .29874 Mtetra
.599 .405 .591 r
.45752 .29874 .46288 .35612 .4743 .34454 .46879 .28849 Mtetra
.607 .412 .592 r
.46879 .28849 .4743 .34454 .48574 .33054 .48007 .27716 Mtetra
.6 .41 .596 r
.48007 .27716 .48574 .33054 .49716 .31677 .49133 .26739 Mtetra
.586 .404 .602 r
.49133 .26739 .49716 .31677 .50854 .30485 .50257 .2604 Mtetra
.552 .388 .612 r
.50257 .2604 .50854 .30485 .51991 .29741 .51382 .25809 Mtetra
.521 .376 .624 r
.51382 .25809 .51991 .29741 .5313 .29334 .52512 .25906 Mtetra
.522 .39 .642 r
.52512 .25906 .5313 .29334 .54274 .2895 .53651 .25989 Mtetra
.536 .416 .663 r
.53651 .25989 .54274 .2895 .55423 .28518 .54798 .25967 Mtetra
.57 .456 .685 r
.54798 .25967 .55423 .28518 .56575 .27985 .5595 .25743 Mtetra
.597 .492 .705 r
.5595 .25743 .56575 .27985 .57729 .27385 .57106 .25379 Mtetra
.606 .515 .724 r
.57106 .25379 .57729 .27385 .58887 .26783 .58267 .24997 Mtetra
.61 .536 .747 r
.58267 .24997 .58887 .26783 .60049 .262 .59434 .24633 Mtetra
.601 .556 .776 r
.59434 .24633 .60049 .262 .61216 .25665 .60608 .24342 Mtetra
.598 .591 .815 r
.60608 .24342 .61216 .25665 .62388 .25167 .61788 .24083 Mtetra
.612 .645 .859 r
.61788 .24083 .62388 .25167 .63565 .24674 .62974 .23792 Mtetra
.621 .7 .901 r
.62974 .23792 .63565 .24674 .64747 .24215 .64165 .23475 Mtetra
.629 .748 .933 r
.64165 .23475 .64747 .24215 .65937 .23817 .65361 .23128 Mtetra
.619 .762 .947 r
.65361 .23128 .65937 .23817 .67136 .23506 .66563 .22798 Mtetra
.582 .741 .951 r
.66563 .22798 .67136 .23506 .68348 .23333 .67775 .22552 Mtetra
.555 .704 .939 r
.67775 .22552 .68348 .23333 .69573 .23256 .68998 .22378 Mtetra
.526 .66 .921 r
.68998 .22378 .69573 .23256 .7081 .23244 .70233 .22288 Mtetra
.515 .633 .905 r
.70233 .22288 .7081 .23244 .72057 .23247 .71479 .22241 Mtetra
.52 .623 .894 r
.71479 .22241 .72057 .23247 .73309 .23195 .72733 .22191 Mtetra
.523 .626 .895 r
.72733 .22191 .73309 .23195 .74565 .23095 .73995 .22131 Mtetra
.529 .641 .904 r
.73995 .22131 .74565 .23095 .75826 .22941 .75264 .22046 Mtetra
.539 .667 .92 r
.75264 .22046 .75826 .22941 .7709 .22725 .76539 .21923 Mtetra
.749 .767 .868 r
.10283 .44102 .1101 .44736 .12033 .44095 .11309 .43456 Mtetra
.749 .767 .867 r
.11309 .43456 .12033 .44095 .13062 .43417 .12337 .42807 Mtetra
.749 .776 .875 r
.12337 .42807 .13062 .43417 .14096 .42714 .13366 .4217 Mtetra
.746 .797 .894 r
.13366 .4217 .14096 .42714 .15132 .42001 .14393 .41562 Mtetra
.736 .833 .924 r
.14393 .41562 .15132 .42001 .16171 .41284 .15417 .41003 Mtetra
.709 .887 .962 r
.15417 .41003 .16171 .41284 .17207 .40607 .16437 .40501 Mtetra
.619 .924 .974 r
.16437 .40501 .17207 .40607 .18236 .40011 .17452 .40075 Mtetra
.487 .9 .899 r
.17452 .40075 .18236 .40011 .1926 .39485 .18467 .39679 Mtetra
.368 .834 .786 r
.18467 .39679 .1926 .39485 .20279 .39039 .19485 .39285 Mtetra
.388 .842 .762 r
.19485 .39285 .20279 .39039 .21299 .3861 .20513 .38832 Mtetra
.533 .922 .825 r
.20513 .38832 .21299 .3861 .22326 .3815 .21555 .38265 Mtetra
.661 .97 .899 r
.21555 .38265 .22326 .3815 .23358 .37667 .22606 .3763 Mtetra
.746 .965 .934 r
.22606 .3763 .23358 .37667 .24396 .37152 .23663 .36946 Mtetra
.755 .922 .945 r
.23663 .36946 .24396 .37152 .25434 .36668 .2472 .36303 Mtetra
.724 .868 .949 r
.2472 .36303 .25434 .36668 .2647 .36256 .25769 .35761 Mtetra
.717 .823 .931 r
.25769 .35761 .2647 .36256 .27508 .3586 .2682 .3524 Mtetra
.721 .783 .901 r
.2682 .3524 .27508 .3586 .28551 .35448 .27877 .34691 Mtetra
.756 .751 .848 r
.27877 .34691 .28551 .35448 .29608 .34898 .2895 .33959 Mtetra
.782 .716 .79 r
.2895 .33959 .29608 .34898 .30681 .34149 .30043 .32958 Mtetra
.777 .675 .751 r
.30043 .32958 .30681 .34149 .31763 .33295 .31148 .318 Mtetra
.757 .632 .722 r
.31148 .318 .31763 .33295 .32847 .32426 .32255 .30579 Mtetra
.702 .574 .709 r
.32255 .30579 .32847 .32426 .33912 .3188 .33345 .29623 Mtetra
.626 .502 .693 r
.33345 .29623 .33912 .3188 .34955 .31798 .3441 .29085 Mtetra
.57 .444 .669 r
.3441 .29085 .34955 .31798 .35989 .31991 .35463 .28846 Mtetra
.534 .403 .648 r
.35463 .28846 .35989 .31991 .37024 .32342 .36509 .28827 Mtetra
.533 .391 .634 r
.36509 .28827 .37024 .32342 .38073 .32587 .37562 .28806 Mtetra
.545 .394 .626 r
.37562 .28806 .38073 .32587 .39139 .32607 .38627 .28678 Mtetra
.556 .398 .622 r
.38627 .28678 .39139 .32607 .4022 .32439 .39702 .28444 Mtetra
.566 .404 .621 r
.39702 .28444 .4022 .32439 .41313 .32104 .40786 .28102 Mtetra
.571 .408 .621 r
.40786 .28102 .41313 .32104 .42413 .31717 .41877 .27709 Mtetra
.576 .411 .621 r
.41877 .27709 .42413 .31717 .43518 .31278 .42974 .27266 Mtetra
.586 .418 .621 r
.42974 .27266 .43518 .31278 .44632 .30671 .44078 .26714 Mtetra
.596 .427 .622 r
.44078 .26714 .44632 .30671 .45752 .29874 .45187 .26057 Mtetra
.609 .438 .626 r
.45187 .26057 .45752 .29874 .46879 .28849 .46302 .25289 Mtetra
.614 .448 .633 r
.46302 .25289 .46879 .28849 .48007 .27716 .47418 .24518 Mtetra
.599 .448 .647 r
.47418 .24518 .48007 .27716 .49133 .26739 .48534 .23969 Mtetra
.569 .443 .669 r
.48534 .23969 .49133 .26739 .50257 .2604 .4965 .23721 Mtetra
.497 .421 .701 r
.4965 .23721 .50257 .2604 .51382 .25809 .50769 .23897 Mtetra
.412 .401 .737 r
.50769 .23897 .51382 .25809 .52512 .25906 .51897 .24344 Mtetra
.4 .437 .783 r
.51897 .24344 .52512 .25906 .53651 .25989 .53036 .24729 Mtetra
.428 .506 .836 r
.53036 .24729 .53651 .25989 .54798 .25967 .54184 .24956 Mtetra
.52 .613 .886 r
.54184 .24956 .54798 .25967 .5595 .25743 .5534 .24912 Mtetra
.588 .697 .918 r
.5534 .24912 .5595 .25743 .57106 .25379 .565 .24681 Mtetra
.592 .743 .948 r
.565 .24681 .57106 .25379 .58267 .24997 .57667 .24422 Mtetra
.565 .776 .978 r
.57667 .24422 .58267 .24997 .59434 .24633 .5884 .24185 Mtetra
.46 .777 .998 r
.5884 .24185 .59434 .24633 .60608 .24342 .60022 .24052 Mtetra
.338 .768 .971 r
.60022 .24052 .60608 .24342 .61788 .24083 .61213 .23961 Mtetra
.253 .755 .89 r
.61213 .23961 .61788 .24083 .62974 .23792 .62409 .23821 Mtetra
.184 .718 .773 r
.62409 .23821 .62974 .23792 .64165 .23475 .63611 .23612 Mtetra
.199 .72 .699 r
.63611 .23612 .64165 .23475 .65361 .23128 .64814 .23284 Mtetra
.235 .742 .695 r
.64814 .23284 .65361 .23128 .66563 .22798 .66021 .22896 Mtetra
.284 .781 .754 r
.66021 .22896 .66563 .22798 .67775 .22552 .67233 .2251 Mtetra
.377 .841 .874 r
.67233 .2251 .67775 .22552 .68998 .22378 .68453 .22154 Mtetra
.442 .848 .969 r
.68453 .22154 .68998 .22378 .70233 .22288 .69683 .21878 Mtetra
.492 .814 1 r
.69683 .21878 .70233 .22288 .71479 .22241 .70923 .21661 Mtetra
.512 .76 .986 r
.70923 .21661 .71479 .22241 .72733 .22191 .72174 .21495 Mtetra
.518 .721 .965 r
.72174 .21495 .72733 .22191 .73995 .22131 .73435 .21359 Mtetra
.522 .698 .95 r
.73435 .21359 .73995 .22131 .75264 .22046 .74705 .21238 Mtetra
.528 .69 .942 r
.74705 .21238 .75264 .22046 .76539 .21923 .75983 .21113 Mtetra
.733 .766 .879 r
.09551 .43462 .10283 .44102 .11309 .43456 .10571 .42879 Mtetra
.727 .785 .898 r
.10571 .42879 .11309 .43456 .12337 .42807 .1159 .42329 Mtetra
.715 .817 .929 r
.1159 .42329 .12337 .42807 .13366 .4217 .12604 .4183 Mtetra
.681 .862 .968 r
.12604 .4183 .13366 .4217 .14393 .41562 .13614 .41397 Mtetra
.573 .894 .986 r
.13614 .41397 .14393 .41562 .15417 .41003 .14616 .41059 Mtetra
.349 .825 .86 r
.14616 .41059 .15417 .41003 .16437 .40501 .15614 .40784 Mtetra
0 0 0 r
.15614 .40784 .16437 .40501 .17452 .40075 .16611 .40567 Mtetra
.079 0 0 r
.16611 .40567 .17452 .40075 .18467 .39679 .17614 .40329 Mtetra
.088 0 0 r
.17614 .40329 .18467 .39679 .19485 .39285 .18631 .40006 Mtetra
.009 0 0 r
.18631 .40006 .19485 .39285 .20513 .38832 .19665 .39556 Mtetra
0 0 0 r
.19665 .39556 .20513 .38832 .21555 .38265 .20721 .3892 Mtetra
.20721 .3892 .21555 .38265 .22606 .3763 .21788 .38192 Mtetra
.434 .824 .598 r
.21788 .38192 .22606 .3763 .23663 .36946 .2286 .37423 Mtetra
.442 .842 .645 r
.2286 .37423 .23663 .36946 .2472 .36303 .23928 .36716 Mtetra
.346 .792 .636 r
.23928 .36716 .2472 .36303 .25769 .35761 .24987 .36148 Mtetra
.328 .783 .641 r
.24987 .36148 .25769 .35761 .2682 .3524 .26045 .35613 Mtetra
.366 .81 .665 r
.26045 .35613 .2682 .3524 .27877 .34691 .27108 .35051 Mtetra
.576 .928 .748 r
.27108 .35051 .27877 .34691 .2895 .33959 .2819 .34283 Mtetra
.787 .997 .794 r
.2819 .34283 .2895 .33959 .30043 .32958 .29296 .33207 Mtetra
.875 .993 .8 r
.29296 .33207 .30043 .32958 .31148 .318 .30416 .31928 Mtetra
.911 .967 .801 r
.30416 .31928 .31148 .318 .32255 .30579 .31543 .3053 Mtetra
.891 .947 .839 r
.31543 .3053 .32255 .30579 .33345 .29623 .32655 .29311 Mtetra
.826 .894 .89 r
.32655 .29311 .33345 .29623 .3441 .29085 .33746 .2842 Mtetra
.737 .778 .886 r
.33746 .2842 .3441 .29085 .35463 .28846 .34823 .278 Mtetra
.648 .654 .842 r
.34823 .278 .35463 .28846 .36509 .28827 .35889 .27415 Mtetra
.614 .574 .786 r
.35889 .27415 .36509 .28827 .37562 .28806 .36956 .27101 Mtetra
.606 .535 .748 r
.36956 .27101 .37562 .28806 .38627 .28678 .38028 .26777 Mtetra
.604 .516 .728 r
.38028 .26777 .38627 .28678 .39702 .28444 .39107 .2643 Mtetra
.607 .509 .717 r
.39107 .2643 .39702 .28444 .40786 .28102 .40191 .26046 Mtetra
.608 .507 .713 r
.40191 .26046 .40786 .28102 .41877 .27709 .4128 .2565 Mtetra
.61 .508 .713 r
.4128 .2565 .41877 .27709 .42974 .27266 .42374 .2524 Mtetra
.617 .515 .715 r
.42374 .2524 .42974 .27266 .44078 .26714 .43473 .24794 Mtetra
.625 .528 .724 r
.43473 .24794 .44078 .26714 .45187 .26057 .44577 .24325 Mtetra
.635 .551 .743 r
.44577 .24325 .45187 .26057 .46302 .25289 .45685 .23846 Mtetra
.633 .584 .781 r
.45685 .23846 .46302 .25289 .47418 .24518 .46796 .23437 Mtetra
.574 .619 .859 r
.46796 .23437 .47418 .24518 .48534 .23969 .47907 .23265 Mtetra
.381 .633 .954 r
.47907 .23265 .48534 .23969 .4965 .23721 .49022 .23369 Mtetra
0 .38 .752 r
.49022 .23369 .4965 .23721 .50769 .23897 .50143 .23806 Mtetra
.484 0 0 r
.50143 .23806 .50769 .23897 .51897 .24344 .51274 .24428 Mtetra
.474 0 0 r
.51274 .24428 .51897 .24344 .53036 .24729 .52417 .24931 Mtetra
.386 0 0 r
.52417 .24931 .53036 .24729 .54184 .24956 .53571 .25231 Mtetra
.189 0 0 r
.53571 .25231 .54184 .24956 .5534 .24912 .54733 .25219 Mtetra
.027 0 0 r
.54733 .25219 .5534 .24912 .565 .24681 .55901 .24997 Mtetra
.01 0 0 r
.55901 .24997 .565 .24681 .57667 .24422 .57075 .24747 Mtetra
.049 0 0 r
.57075 .24747 .57667 .24422 .5884 .24185 .58256 .24533 Mtetra
.182 0 0 r
.58256 .24533 .5884 .24185 .60022 .24052 .59446 .24462 Mtetra
.257 0 0 r
.59446 .24462 .60022 .24052 .61213 .23961 .60646 .24455 Mtetra
.264 0 0 r
.60646 .24455 .61213 .23961 .62409 .23821 .61854 .24407 Mtetra
.241 0 0 r
.61854 .24407 .62409 .23821 .63611 .23612 .63066 .24264 Mtetra
.153 0 0 r
.63066 .24264 .63611 .23612 .64814 .23284 .64278 .2393 Mtetra
.068 0 0 r
.64278 .2393 .64814 .23284 .66021 .22896 .65491 .23465 Mtetra
0 0 0 r
.65491 .23465 .66021 .22896 .67233 .2251 .66705 .22911 Mtetra
.66705 .22911 .67233 .2251 .68453 .22154 .67922 .22334 Mtetra
.315 .79 .697 r
.67922 .22334 .68453 .22154 .69683 .21878 .69146 .21817 Mtetra
.465 .888 .897 r
.69146 .21817 .69683 .21878 .70923 .21661 .70379 .21364 Mtetra
.532 .875 .989 r
.70379 .21364 .70923 .21661 .72174 .21495 .71624 .2101 Mtetra
.553 .819 .995 r
.71624 .2101 .72174 .21495 .73435 .21359 .7288 .20726 Mtetra
.554 .765 .976 r
.7288 .20726 .73435 .21359 .74705 .21238 .74146 .20494 Mtetra
.551 .725 .955 r
.74146 .20494 .74705 .21238 .75983 .21113 .75422 .20298 Mtetra
.701 .761 .898 r
.08813 .42819 .09551 .43462 .10571 .42879 .09822 .42343 Mtetra
.679 .793 .935 r
.09822 .42343 .10571 .42879 .1159 .42329 .10825 .41934 Mtetra
.63 .834 .979 r
.10825 .41934 .1159 .42329 .12604 .4183 .11821 .41604 Mtetra
.506 .854 .994 r
.11821 .41604 .12604 .4183 .13614 .41397 .1281 .41366 Mtetra
.202 .727 .841 r
.1281 .41366 .13614 .41397 .14616 .41059 .13789 .41252 Mtetra
.086 0 0 r
.13789 .41252 .14616 .41059 .15614 .40784 .14766 .41197 Mtetra
.249 0 0 r
.14766 .41197 .15614 .40784 .16611 .40567 .15746 .41172 Mtetra
.267 0 0 r
.15746 .41172 .16611 .40567 .17614 .40329 .16738 .41081 Mtetra
.199 0 0 r
.16738 .41081 .17614 .40329 .18631 .40006 .17753 .40835 Mtetra
.094 0 0 r
.17753 .40835 .18631 .40006 .19665 .39556 .18791 .40419 Mtetra
0 0 0 r
.18791 .40419 .19665 .39556 .20721 .3892 .19853 .39788 Mtetra
.19853 .39788 .20721 .3892 .21788 .38192 .20927 .3907 Mtetra
.20927 .3907 .21788 .38192 .2286 .37423 .22003 .38348 Mtetra
.22003 .38348 .2286 .37423 .23928 .36716 .23071 .37727 Mtetra
.166 0 0 r
.23071 .37727 .23928 .36716 .24987 .36148 .24126 .37294 Mtetra
.247 0 .013 r
.24126 .37294 .24987 .36148 .26045 .35613 .25178 .36925 Mtetra
.28 0 .071 r
.25178 .36925 .26045 .35613 .27108 .35051 .26235 .36548 Mtetra
.224 0 .077 r
.26235 .36548 .27108 .35051 .2819 .34283 .27313 .3597 Mtetra
.12 0 .056 r
.27313 .3597 .2819 .34283 .29296 .33207 .28417 .35072 Mtetra
.059 0 .053 r
.28417 .35072 .29296 .33207 .30416 .31928 .2954 .33933 Mtetra
.022 0 .056 r
.2954 .33933 .30416 .31928 .31543 .3053 .30674 .32615 Mtetra
.081 0 .097 r
.30674 .32615 .31543 .3053 .32655 .29311 .31802 .31375 Mtetra
.164 0 .135 r
.31802 .31375 .32655 .29311 .33746 .2842 .32914 .30347 Mtetra
.219 0 .146 r
.32914 .30347 .33746 .2842 .34823 .278 .34014 .29526 Mtetra
.263 0 .141 r
.34014 .29526 .34823 .278 .35889 .27415 .35104 .28911 Mtetra
.262 0 .104 r
.35104 .28911 .35889 .27415 .36956 .27101 .36192 .28392 Mtetra
.242 0 .054 r
.36192 .28392 .36956 .27101 .38028 .26777 .37281 .27919 Mtetra
.223 0 .008 r
.37281 .27919 .38028 .26777 .39107 .2643 .38372 .27478 Mtetra
.208 0 0 r
.38372 .27478 .39107 .2643 .40191 .26046 .39467 .27056 Mtetra
.212 0 0 r
.39467 .27056 .40191 .26046 .4128 .2565 .40565 .26657 Mtetra
.227 0 0 r
.40565 .26657 .4128 .2565 .42374 .2524 .41666 .26284 Mtetra
.248 0 0 r
.41666 .26284 .42374 .2524 .43473 .24794 .42772 .25929 Mtetra
.285 0 .04 r
.42772 .25929 .43473 .24794 .44577 .24325 .43881 .25606 Mtetra
.332 0 .098 r
.43881 .25606 .44577 .24325 .45685 .23846 .44994 .2533 Mtetra
.39 0 .165 r
.44994 .2533 .45685 .23846 .46796 .23437 .46111 .25151 Mtetra
.46 .079 .229 r
.46111 .25151 .46796 .23437 .47907 .23265 .47231 .2518 Mtetra
.509 .138 .271 r
.47231 .2518 .47907 .23265 .49022 .23369 .48356 .2542 Mtetra
.546 .18 .297 r
.48356 .2542 .49022 .23369 .50143 .23806 .49488 .25878 Mtetra
.558 .191 .301 r
.49488 .25878 .50143 .23806 .51274 .24428 .5063 .26417 Mtetra
.529 .159 .282 r
.5063 .26417 .51274 .24428 .52417 .24931 .51786 .26776 Mtetra
.482 .105 .248 r
.51786 .26776 .52417 .24931 .53571 .25231 .52951 .26893 Mtetra
.397 .014 .191 r
.52951 .26893 .53571 .25231 .54733 .25219 .54124 .26685 Mtetra
.314 0 .125 r
.54124 .26685 .54733 .25219 .55901 .24997 .55301 .26272 Mtetra
.28 0 .071 r
.55301 .26272 .55901 .24997 .57075 .24747 .56484 .2585 Mtetra
.273 0 .024 r
.56484 .2585 .57075 .24747 .58256 .24533 .57672 .25493 Mtetra
.327 0 .006 r
.57672 .25493 .58256 .24533 .59446 .24462 .58871 .25331 Mtetra
.355 0 0 r
.58871 .25331 .59446 .24462 .60646 .24455 .60079 .25273 Mtetra
.343 0 0 r
.60079 .25273 .60646 .24455 .61854 .24407 .61295 .2521 Mtetra
.299 0 0 r
.61295 .2521 .61854 .24407 .63066 .24264 .62516 .2506 Mtetra
.184 0 0 r
.62516 .2506 .63066 .24264 .64278 .2393 .63737 .24687 Mtetra
.067 0 0 r
.63737 .24687 .64278 .2393 .65491 .23465 .64956 .24138 Mtetra
0 0 0 r
.64956 .24138 .65491 .23465 .66705 .22911 .66173 .23428 Mtetra
.66173 .23428 .66705 .22911 .67922 .22334 .6739 .22647 Mtetra
.383 .805 .616 r
.6739 .22647 .67922 .22334 .69146 .21817 .6861 .21896 Mtetra
.533 .92 .812 r
.6861 .21896 .69146 .21817 .70379 .21364 .69837 .21206 Mtetra
.6 .938 .946 r
.69837 .21206 .70379 .21364 .71624 .2101 .71076 .20643 Mtetra
.622 .892 .988 r
.71076 .20643 .71624 .2101 .7288 .20726 .72325 .20176 Mtetra
.616 .825 .981 r
.72325 .20176 .7288 .20726 .74146 .20494 .73585 .19791 Mtetra
.6 .765 .958 r
.73585 .19791 .74146 .20494 .75422 .20298 .74857 .19475 Mtetra
.654 .751 .921 r
.0807 .4217 .08813 .42819 .09822 .42343 .09064 .41822 Mtetra
.602 .782 .966 r
.09064 .41822 .09822 .42343 .10825 .41934 .10049 .41563 Mtetra
.495 .802 .999 r
.10049 .41563 .10825 .41934 .11821 .41604 .11027 .41401 Mtetra
.27 .744 .938 r
.11027 .41401 .11821 .41604 .1281 .41366 .11996 .41344 Mtetra
.093 0 0 r
.11996 .41344 .1281 .41366 .13789 .41252 .12955 .41421 Mtetra
.28 0 0 r
.12955 .41421 .13789 .41252 .14766 .41197 .13915 .41544 Mtetra
.346 0 0 r
.13915 .41544 .14766 .41197 .15746 .41172 .14882 .4166 Mtetra
.304 0 0 r
.14882 .4166 .15746 .41172 .16738 .41081 .15868 .41669 Mtetra
.164 0 0 r
.15868 .41669 .16738 .41081 .17753 .40835 .16884 .4147 Mtetra
.003 0 0 r
.16884 .4147 .17753 .40835 .18791 .40419 .17925 .41078 Mtetra
0 0 0 r
.17925 .41078 .18791 .40419 .19853 .39788 .18992 .40466 Mtetra
.18992 .40466 .19853 .39788 .20927 .3907 .20069 .39794 Mtetra
.20069 .39794 .20927 .3907 .22003 .38348 .21142 .39169 Mtetra
.045 0 0 r
.21142 .39169 .22003 .38348 .23071 .37727 .22205 .38695 Mtetra
.277 0 0 r
.22205 .38695 .23071 .37727 .24126 .37294 .23248 .38464 Mtetra
.37 0 .088 r
.23248 .38464 .24126 .37294 .25178 .36925 .24287 .38343 Mtetra
.407 .004 .158 r
.24287 .38343 .25178 .36925 .26235 .36548 .25329 .38254 Mtetra
.375 0 .184 r
.25329 .38254 .26235 .36548 .27313 .3597 .26391 .37996 Mtetra
.312 0 .191 r
.26391 .37996 .27313 .3597 .28417 .35072 .27481 .37438 Mtetra
.272 0 .206 r
.27481 .37438 .28417 .35072 .2954 .33933 .28594 .36621 Mtetra
.246 0 .22 r
.28594 .36621 .2954 .33933 .30674 .32615 .29725 .35574 Mtetra
.27 0 .249 r
.29725 .35574 .30674 .32615 .31802 .31375 .30857 .345 Mtetra
.306 .002 .274 r
.30857 .345 .31802 .31375 .32914 .30347 .31984 .33514 Mtetra
.335 .029 .289 r
.31984 .33514 .32914 .30347 .34014 .29526 .33104 .32647 Mtetra
.361 .051 .297 r
.33104 .32647 .34014 .29526 .35104 .28911 .34216 .31923 Mtetra
.373 .058 .297 r
.34216 .31923 .35104 .28911 .36192 .28392 .35326 .31287 Mtetra
.381 .062 .294 r
.35326 .31287 .36192 .28392 .37281 .27919 .36435 .30718 Mtetra
.388 .065 .291 r
.36435 .30718 .37281 .27919 .38372 .27478 .37544 .30209 Mtetra
.396 .07 .29 r
.37544 .30209 .38372 .27478 .39467 .27056 .38655 .29755 Mtetra
.406 .077 .292 r
.38655 .29755 .39467 .27056 .40565 .26657 .39768 .29357 Mtetra
.417 .087 .296 r
.39768 .29357 .40565 .26657 .41666 .26284 .40883 .29014 Mtetra
.428 .098 .302 r
.40883 .29014 .41666 .26284 .42772 .25929 .42001 .28726 Mtetra
.441 .112 .311 r
.42001 .28726 .42772 .25929 .43881 .25606 .43123 .28499 Mtetra
.455 .127 .321 r
.43123 .28499 .43881 .25606 .44994 .2533 .44249 .28341 Mtetra
.47 .145 .332 r
.44249 .28341 .44994 .2533 .46111 .25151 .45379 .28272 Mtetra
.492 .167 .343 r
.45379 .28272 .46111 .25151 .47231 .2518 .46514 .28348 Mtetra
.507 .182 .35 r
.46514 .28348 .47231 .2518 .48356 .2542 .47656 .28546 Mtetra
.518 .19 .35 r
.47656 .28546 .48356 .2542 .49488 .25878 .48805 .28835 Mtetra
.515 .181 .34 r
.48805 .28835 .49488 .25878 .5063 .26417 .49965 .291 Mtetra
.48 .141 .314 r
.49965 .291 .5063 .26417 .51786 .26776 .51136 .29132 Mtetra
.426 .08 .272 r
.51136 .29132 .51786 .26776 .52951 .26893 .52316 .28902 Mtetra
.336 0 .206 r
.52316 .28902 .52951 .26893 .54124 .26685 .53501 .28365 Mtetra
.243 0 .127 r
.53501 .28365 .54124 .26685 .55301 .26272 .54689 .27656 Mtetra
.196 0 .054 r
.54689 .27656 .55301 .26272 .56484 .2585 .55881 .26977 Mtetra
.179 0 0 r
.55881 .26977 .56484 .2585 .57672 .25493 .57077 .2641 Mtetra
.242 0 0 r
.57077 .2641 .57672 .25493 .58871 .25331 .58282 .26093 Mtetra
.278 0 0 r
.58282 .26093 .58871 .25331 .60079 .25273 .59497 .25931 Mtetra
.274 0 0 r
.59497 .25931 .60079 .25273 .61295 .2521 .6072 .25818 Mtetra
.222 0 0 r
.6072 .25818 .61295 .2521 .62516 .2506 .61949 .25643 Mtetra
.067 0 0 r
.61949 .25643 .62516 .2506 .63737 .24687 .63178 .25242 Mtetra
0 0 0 r
.63178 .25242 .63737 .24687 .64956 .24138 .64405 .2464 Mtetra
.64405 .2464 .64956 .24138 .66173 .23428 .65627 .23822 Mtetra
.448 .825 .582 r
.65627 .23822 .66173 .23428 .6739 .22647 .66846 .2289 Mtetra
.573 .916 .704 r
.66846 .2289 .6739 .22647 .6861 .21896 .68065 .21949 Mtetra
.674 .975 .828 r
.68065 .21949 .6861 .21896 .69837 .21206 .69289 .21054 Mtetra
.701 .973 .925 r
.69289 .21054 .69837 .21206 .71076 .20643 .70523 .20298 Mtetra
.704 .928 .965 r
.70523 .20298 .71076 .20643 .72325 .20176 .71767 .1965 Mtetra
.685 .862 .966 r
.71767 .1965 .72325 .20176 .73585 .19791 .73021 .19101 Mtetra
.656 .795 .949 r
.73021 .19101 .73585 .19791 .74857 .19475 .74288 .18646 Mtetra
.597 .735 .941 r
.07322 .41517 .0807 .4217 .09064 .41822 .08301 .41287 Mtetra
.515 .75 .981 r
.08301 .41287 .09064 .41822 .10049 .41563 .09271 .41158 Mtetra
.373 .738 .99 r
.09271 .41158 .10049 .41563 .11027 .41401 .10234 .41125 Mtetra
.153 .653 .91 r
.10234 .41125 .11027 .41401 .11996 .41344 .1119 .41188 Mtetra
0 .459 .696 r
.1119 .41188 .11996 .41344 .12955 .41421 .12138 .4137 Mtetra
.231 0 0 r
.12138 .4137 .12955 .41421 .13915 .41544 .13092 .41567 Mtetra
.21 0 0 r
.13092 .41567 .13915 .41544 .14882 .4166 .14059 .41708 Mtetra
.033 0 0 r
.14059 .41708 .14882 .4166 .15868 .41669 .1505 .41702 Mtetra
.332 .814 .864 r
.1505 .41702 .15868 .41669 .16884 .4147 .16076 .41444 Mtetra
.594 .934 .95 r
.16076 .41444 .16884 .4147 .17925 .41078 .17129 .40979 Mtetra
.748 .951 .943 r
.17129 .40979 .17925 .41078 .18992 .40466 .18208 .40305 Mtetra
.768 .936 .938 r
.18208 .40305 .18992 .40466 .20069 .39794 .19292 .39599 Mtetra
.73 .926 .956 r
.19292 .39599 .20069 .39794 .21142 .39169 .20369 .38991 Mtetra
.604 .907 .983 r
.20369 .38991 .21142 .39169 .22205 .38695 .21428 .38586 Mtetra
.236 .743 .889 r
.21428 .38586 .22205 .38695 .23248 .38464 .22463 .38484 Mtetra
.112 0 0 r
.22463 .38484 .23248 .38464 .24287 .38343 .23488 .38558 Mtetra
.334 0 0 r
.23488 .38558 .24287 .38343 .25329 .38254 .24512 .38736 Mtetra
.348 0 0 r
.24512 .38736 .25329 .38254 .26391 .37996 .25551 .38819 Mtetra
.287 0 0 r
.25551 .38819 .26391 .37996 .27481 .37438 .26616 .38669 Mtetra
.253 0 .026 r
.26616 .38669 .27481 .37438 .28594 .36621 .27706 .38284 Mtetra
.229 0 .098 r
.27706 .38284 .28594 .36621 .29725 .35574 .28817 .37653 Mtetra
.26 0 .169 r
.28817 .37653 .29725 .35574 .30857 .345 .29939 .36921 Mtetra
.296 0 .219 r
.29939 .36921 .30857 .345 .31984 .33514 .31065 .36169 Mtetra
.325 0 .25 r
.31065 .36169 .31984 .33514 .33104 .32647 .3219 .35443 Mtetra
.35 .027 .27 r
.3219 .35443 .33104 .32647 .34216 .31923 .33315 .34778 Mtetra
.364 .042 .28 r
.33315 .34778 .34216 .31923 .35326 .31287 .34439 .3416 Mtetra
.376 .053 .286 r
.34439 .3416 .35326 .31287 .36435 .30718 .35563 .3359 Mtetra
.387 .064 .29 r
.35563 .3359 .36435 .30718 .37544 .30209 .36689 .33075 Mtetra
.398 .073 .294 r
.36689 .33075 .37544 .30209 .38655 .29755 .37815 .32617 Mtetra
.409 .083 .298 r
.37815 .32617 .38655 .29755 .39768 .29357 .38943 .32219 Mtetra
.42 .093 .302 r
.38943 .32219 .39768 .29357 .40883 .29014 .40073 .31879 Mtetra
.431 .102 .306 r
.40073 .31879 .40883 .29014 .42001 .28726 .41207 .31598 Mtetra
.44 .111 .31 r
.41207 .31598 .42001 .28726 .43123 .28499 .42344 .31372 Mtetra
.448 .118 .312 r
.42344 .31372 .43123 .28499 .44249 .28341 .43486 .31195 Mtetra
.456 .124 .314 r
.43486 .31195 .44249 .28341 .45379 .28272 .44634 .31066 Mtetra
.464 .129 .313 r
.44634 .31066 .45379 .28272 .46514 .28348 .45787 .31 Mtetra
.466 .125 .304 r
.45787 .31 .46514 .28348 .47656 .28546 .46947 .30961 Mtetra
.457 .108 .284 r
.46947 .30961 .47656 .28546 .48805 .28835 .48115 .30902 Mtetra
.425 .061 .241 r
.48115 .30902 .48805 .28835 .49965 .291 .49291 .30742 Mtetra
.328 0 .148 r
.49291 .30742 .49965 .291 .51136 .29132 .50477 .30334 Mtetra
.147 0 0 r
.50477 .30334 .51136 .29132 .52316 .28902 .51668 .29683 Mtetra
0 0 0 r
.51668 .29683 .52316 .28902 .53501 .28365 .52862 .28795 Mtetra
.529 .875 .625 r
.52862 .28795 .53501 .28365 .54689 .27656 .54057 .27808 Mtetra
.659 .969 .81 r
.54057 .27808 .54689 .27656 .55881 .26977 .55254 .26925 Mtetra
.664 .968 .913 r
.55254 .26925 .55881 .26977 .57077 .2641 .56456 .2622 Mtetra
.521 .893 .968 r
.56456 .2622 .57077 .2641 .58282 .26093 .57665 .25827 Mtetra
.391 .809 .973 r
.57665 .25827 .58282 .26093 .59497 .25931 .58884 .25642 Mtetra
.312 .758 .962 r
.58884 .25642 .59497 .25931 .6072 .25818 .60113 .25559 Mtetra
.319 .77 .956 r
.60113 .25559 .6072 .25818 .61949 .25643 .6135 .25444 Mtetra
.465 .867 .963 r
.6135 .25444 .61949 .25643 .63178 .25242 .62587 .25113 Mtetra
.581 .933 .941 r
.62587 .25113 .63178 .25242 .64405 .2464 .63823 .24567 Mtetra
.703 .98 .9 r
.63823 .24567 .64405 .2464 .65627 .23822 .65053 .23758 Mtetra
.765 .993 .875 r
.65053 .23758 .65627 .23822 .66846 .2289 .66278 .22795 Mtetra
.794 .994 .873 r
.66278 .22795 .66846 .2289 .68065 .21949 .67502 .21772 Mtetra
.808 .984 .89 r
.67502 .21772 .68065 .21949 .69289 .21054 .68727 .20762 Mtetra
.787 .959 .923 r
.68727 .20762 .69289 .21054 .70523 .20298 .6996 .19874 Mtetra
.766 .918 .939 r
.6996 .19874 .70523 .20298 .71767 .1965 .71201 .19086 Mtetra
.737 .866 .941 r
.71201 .19086 .71767 .1965 .73021 .19101 .72451 .18396 Mtetra
.702 .809 .932 r
.72451 .18396 .73021 .19101 .74288 .18646 .73713 .1781 Mtetra
.547 .719 .952 r
.06568 .40859 .07322 .41517 .08301 .41287 .07537 .40711 Mtetra
.457 .714 .978 r
.07537 .40711 .08301 .41287 .09271 .41158 .08498 .40662 Mtetra
.337 .689 .98 r
.08498 .40662 .09271 .41158 .10234 .41125 .09453 .40699 Mtetra
.194 .635 .946 r
.09453 .40699 .10234 .41125 .1119 .41188 .10404 .40813 Mtetra
.025 .54 .866 r
.10404 .40813 .1119 .41188 .12138 .4137 .11351 .41017 Mtetra
.034 .553 .867 r
.11351 .41017 .12138 .4137 .13092 .41567 .12307 .41203 Mtetra
.184 .65 .937 r
.12307 .41203 .13092 .41567 .14059 .41708 .13282 .41292 Mtetra
.426 .763 .996 r
.13282 .41292 .14059 .41708 .1505 .41702 .14285 .41206 Mtetra
.643 .811 .964 r
.14285 .41206 .1505 .41702 .16076 .41444 .15324 .40848 Mtetra
.723 .794 .908 r
.15324 .40848 .16076 .41444 .17129 .40979 .16391 .40287 Mtetra
.762 .772 .861 r
.16391 .40287 .17129 .40979 .18208 .40305 .1748 .39541 Mtetra
.756 .753 .85 r
.1748 .39541 .18208 .40305 .19292 .39599 .18571 .38795 Mtetra
.721 .737 .864 r
.18571 .38795 .19292 .39599 .20369 .38991 .1965 .3819 Mtetra
.647 .718 .9 r
.1965 .3819 .20369 .38991 .21428 .38586 .20707 .37828 Mtetra
.466 .662 .947 r
.20707 .37828 .21428 .38586 .22463 .38484 .21735 .37814 Mtetra
.232 .571 .94 r
.21735 .37814 .22463 .38484 .23488 .38558 .22748 .38034 Mtetra
0 .42 .826 r
.22748 .38034 .23488 .38558 .24512 .38736 .23754 .38428 Mtetra
0 .351 .685 r
.23754 .38428 .24512 .38736 .25551 .38819 .2477 .38807 Mtetra
.263 0 0 r
.2477 .38807 .25551 .38819 .26616 .38669 .25808 .39037 Mtetra
.268 0 0 r
.25808 .39037 .26616 .38669 .27706 .38284 .2687 .39072 Mtetra
.242 0 0 r
.2687 .39072 .27706 .38284 .28817 .37653 .27957 .38874 Mtetra
.267 0 .027 r
.27957 .38874 .28817 .37653 .29939 .36921 .2906 .38526 Mtetra
.29 0 .115 r
.2906 .38526 .29939 .36921 .31065 .36169 .30176 .38076 Mtetra
.311 0 .169 r
.30176 .38076 .31065 .36169 .3219 .35443 .31299 .37569 Mtetra
.328 0 .202 r
.31299 .37569 .3219 .35443 .33315 .34778 .32428 .37043 Mtetra
.34 0 .221 r
.32428 .37043 .33315 .34778 .34439 .3416 .3356 .3651 Mtetra
.35 .006 .233 r
.3356 .3651 .34439 .3416 .35563 .3359 .34696 .3599 Mtetra
.362 .019 .242 r
.34696 .3599 .35563 .3359 .36689 .33075 .35834 .355 Mtetra
.374 .031 .25 r
.35834 .355 .36689 .33075 .37815 .32617 .36974 .35053 Mtetra
.386 .043 .255 r
.36974 .35053 .37815 .32617 .38943 .32219 .38116 .34654 Mtetra
.397 .052 .26 r
.38116 .34654 .38943 .32219 .40073 .31879 .39261 .34303 Mtetra
.406 .06 .262 r
.39261 .34303 .40073 .31879 .41207 .31598 .40409 .33995 Mtetra
.411 .063 .262 r
.40409 .33995 .41207 .31598 .42344 .31372 .41562 .33719 Mtetra
.412 .062 .258 r
.41562 .33719 .42344 .31372 .43486 .31195 .42721 .33455 Mtetra
.406 .052 .249 r
.42721 .33455 .43486 .31195 .44634 .31066 .43886 .33185 Mtetra
.395 .034 .231 r
.43886 .33185 .44634 .31066 .45787 .31 .45057 .32895 Mtetra
.365 0 .194 r
.45057 .32895 .45787 .31 .46947 .30961 .46235 .32549 Mtetra
.301 0 .122 r
.46235 .32549 .46947 .30961 .48115 .30902 .4742 .32099 Mtetra
.16 0 0 r
.4742 .32099 .48115 .30902 .49291 .30742 .48613 .31497 Mtetra
0 0 0 r
.48613 .31497 .49291 .30742 .50477 .30334 .49811 .30655 Mtetra
.654 .951 .725 r
.49811 .30655 .50477 .30334 .51668 .29683 .51012 .29614 Mtetra
.86 .983 .851 r
.51012 .29614 .51668 .29683 .52862 .28795 .52213 .28418 Mtetra
.871 .91 .854 r
.52213 .28418 .52862 .28795 .54057 .27808 .53414 .27204 Mtetra
.826 .848 .864 r
.53414 .27204 .54057 .27808 .55254 .26925 .54615 .26165 Mtetra
.764 .795 .878 r
.54615 .26165 .55254 .26925 .56456 .2622 .5582 .25365 Mtetra
.659 .736 .907 r
.5582 .25365 .56456 .2622 .57665 .25827 .57031 .2492 Mtetra
.564 .681 .918 r
.57031 .2492 .57665 .25827 .58884 .25642 .58253 .24725 Mtetra
.498 .646 .923 r
.58253 .24725 .58884 .25642 .60113 .25559 .59486 .24676 Mtetra
.492 .655 .932 r
.59486 .24676 .60113 .25559 .6135 .25444 .60727 .24629 Mtetra
.574 .717 .939 r
.60727 .24629 .6135 .25444 .62587 .25113 .6197 .24391 Mtetra
.656 .782 .941 r
.6197 .24391 .62587 .25113 .63823 .24567 .63214 .23942 Mtetra
.751 .844 .921 r
.63214 .23942 .63823 .24567 .65053 .23758 .64452 .23211 Mtetra
.803 .88 .902 r
.64452 .23211 .65053 .23758 .66278 .22795 .65685 .22297 Mtetra
.829 .899 .89 r
.65685 .22297 .66278 .22795 .67502 .21772 .66916 .21279 Mtetra
.833 .902 .887 r
.66916 .21279 .67502 .21772 .68727 .20762 .68146 .20241 Mtetra
.812 .893 .902 r
.68146 .20241 .68727 .20762 .6996 .19874 .69382 .19293 Mtetra
.789 .873 .909 r
.69382 .19293 .6996 .19874 .71201 .19086 .70624 .18425 Mtetra
.762 .843 .913 r
.70624 .18425 .71201 .19086 .72451 .18396 .71874 .17646 Mtetra
.729 .806 .912 r
.71874 .17646 .72451 .18396 .73713 .1781 .73134 .16968 Mtetra
.549 .719 .952 r
.05808 .40196 .06568 .40859 .07537 .40711 .06779 .40045 Mtetra
.489 .696 .96 r
.06779 .40045 .07537 .40711 .08498 .40662 .07743 .3998 Mtetra
.434 .668 .96 r
.07743 .3998 .08498 .40662 .09453 .40699 .08703 .39987 Mtetra
.391 .638 .954 r
.08703 .39987 .09453 .40699 .10404 .40813 .09661 .40054 Mtetra
.349 .601 .942 r
.09661 .40054 .10404 .40813 .11351 .41017 .10617 .40185 Mtetra
.398 .602 .929 r
.10617 .40185 .11351 .41017 .12307 .41203 .11584 .40284 Mtetra
.487 .619 .907 r
.11584 .40284 .12307 .41203 .13282 .41292 .12572 .40276 Mtetra
.574 .633 .872 r
.12572 .40276 .13282 .41292 .14285 .41206 .13585 .40103 Mtetra
.654 .648 .831 r
.13585 .40103 .14285 .41206 .15324 .40848 .14633 .39685 Mtetra
.69 .651 .807 r
.14633 .39685 .15324 .40848 .16391 .40287 .15703 .391 Mtetra
.715 .657 .791 r
.15703 .391 .16391 .40287 .1748 .39541 .16791 .38378 Mtetra
.711 .66 .798 r
.16791 .38378 .1748 .39541 .18571 .38795 .17878 .37689 Mtetra
.68 .659 .823 r
.17878 .37689 .18571 .38795 .1965 .3819 .1895 .37165 Mtetra
.609 .649 .864 r
.1895 .37165 .1965 .3819 .20707 .37828 .19998 .36895 Mtetra
.436 .594 .909 r
.19998 .36895 .20707 .37828 .21735 .37814 .21018 .36972 Mtetra
.21 .499 .905 r
.21018 .36972 .21735 .37814 .22748 .38034 .22022 .37296 Mtetra
0 .36 .823 r
.22022 .37296 .22748 .38034 .23754 .38428 .23016 .37813 Mtetra
0 .312 .763 r
.23016 .37813 .23754 .38428 .2477 .38807 .24018 .38356 Mtetra
0 .354 .747 r
.24018 .38356 .2477 .38807 .25808 .39037 .2504 .38798 Mtetra
0 .426 .715 r
.2504 .38798 .25808 .39037 .2687 .39072 .26085 .39077 Mtetra
.077 0 0 r
.26085 .39077 .2687 .39072 .27957 .38874 .27156 .39137 Mtetra
.067 0 0 r
.27156 .39137 .27957 .38874 .2906 .38526 .28247 .39026 Mtetra
.068 0 0 r
.28247 .39026 .2906 .38526 .30176 .38076 .29356 .38767 Mtetra
.082 0 0 r
.29356 .38767 .30176 .38076 .31299 .37569 .30477 .38405 Mtetra
.099 0 0 r
.30477 .38405 .31299 .37569 .32428 .37043 .31608 .37975 Mtetra
.114 0 0 r
.31608 .37975 .32428 .37043 .3356 .3651 .32745 .37507 Mtetra
.133 0 0 r
.32745 .37507 .3356 .3651 .34696 .3599 .33888 .37027 Mtetra
.157 0 0 r
.33888 .37027 .34696 .3599 .35834 .355 .35033 .3656 Mtetra
.183 0 0 r
.35033 .3656 .35834 .355 .36974 .35053 .36182 .36123 Mtetra
.208 0 0 r
.36182 .36123 .36974 .35053 .38116 .34654 .37334 .35722 Mtetra
.229 0 0 r
.37334 .35722 .38116 .34654 .39261 .34303 .38488 .35359 Mtetra
.242 0 0 r
.38488 .35359 .39261 .34303 .40409 .33995 .39647 .35025 Mtetra
.243 0 0 r
.39647 .35025 .40409 .33995 .41562 .33719 .40811 .34704 Mtetra
.227 0 0 r
.40811 .34704 .41562 .33719 .42721 .33455 .41981 .34372 Mtetra
.186 0 0 r
.41981 .34372 .42721 .33455 .43886 .33185 .43157 .34001 Mtetra
.108 0 0 r
.43157 .34001 .43886 .33185 .45057 .32895 .44341 .33561 Mtetra
0 0 0 r
.44341 .33561 .45057 .32895 .46235 .32549 .45532 .33018 Mtetra
.45532 .33018 .46235 .32549 .4742 .32099 .4673 .32323 Mtetra
.624 .954 .787 r
.4673 .32323 .4742 .32099 .48613 .31497 .47934 .31453 Mtetra
.831 .989 .867 r
.47934 .31453 .48613 .31497 .49811 .30655 .49142 .30358 Mtetra
.881 .927 .849 r
.49142 .30358 .49811 .30655 .51012 .29614 .50351 .29094 Mtetra
.88 .866 .82 r
.50351 .29094 .51012 .29614 .52213 .28418 .51559 .27726 Mtetra
.861 .823 .809 r
.51559 .27726 .52213 .28418 .53414 .27204 .52765 .26379 Mtetra
.822 .79 .822 r
.52765 .26379 .53414 .27204 .54615 .26165 .5397 .25227 Mtetra
.769 .753 .838 r
.5397 .25227 .54615 .26165 .5582 .25365 .55177 .24328 Mtetra
.681 .7 .861 r
.55177 .24328 .5582 .25365 .57031 .2492 .5639 .23782 Mtetra
.6 .642 .864 r
.5639 .23782 .57031 .2492 .58253 .24725 .57612 .23496 Mtetra
.543 .594 .855 r
.57612 .23496 .58253 .24725 .59486 .24676 .58845 .23382 Mtetra
.532 .576 .845 r
.58845 .23382 .59486 .24676 .60727 .24629 .60086 .23302 Mtetra
.577 .595 .834 r
.60086 .23302 .60727 .24629 .6197 .24391 .61331 .23081 Mtetra
.626 .624 .829 r
.61331 .23081 .6197 .24391 .63214 .23942 .62579 .22688 Mtetra
.689 .665 .821 r
.62579 .22688 .63214 .23942 .64452 .23211 .63822 .2204 Mtetra
.731 .699 .82 r
.63822 .2204 .64452 .23211 .65685 .22297 .65063 .21219 Mtetra
.762 .73 .824 r
.65063 .21219 .65685 .22297 .66916 .21279 .66301 .20285 Mtetra
.777 .754 .833 r
.66301 .20285 .66916 .21279 .68146 .20241 .67539 .19316 Mtetra
.771 .77 .851 r
.67539 .19316 .68146 .20241 .69382 .19293 .68782 .18412 Mtetra
.762 .779 .867 r
.68782 .18412 .69382 .19293 .70624 .18425 .7003 .17568 Mtetra
.747 .782 .881 r
.7003 .17568 .70624 .18425 .71874 .17646 .71286 .16798 Mtetra
.724 .778 .895 r
.71286 .16798 .71874 .17646 .73134 .16968 .7255 .16118 Mtetra
.585 .731 .944 r
.05043 .39529 .05808 .40196 .06779 .40045 .06025 .39313 Mtetra
.549 .699 .938 r
.06025 .39313 .06779 .40045 .07743 .3998 .07001 .39168 Mtetra
.524 .664 .925 r
.07001 .39168 .07743 .3998 .08703 .39987 .07975 .39077 Mtetra
.508 .63 .905 r
.07975 .39077 .08703 .39987 .09661 .40054 .08948 .39029 Mtetra
.495 .593 .882 r
.08948 .39029 .09661 .40054 .10617 .40185 .09922 .39024 Mtetra
.52 .574 .85 r
.09922 .39024 .10617 .40185 .11584 .40284 .10907 .38984 Mtetra
.561 .568 .818 r
.10907 .38984 .11584 .40284 .12572 .40276 .11909 .38846 Mtetra
.601 .568 .79 r
.11909 .38846 .12572 .40276 .13585 .40103 .12934 .38573 Mtetra
.642 .577 .766 r
.12934 .38573 .13585 .40103 .14633 .39685 .13987 .38107 Mtetra
.663 .582 .754 r
.13987 .38107 .14633 .39685 .15703 .391 .15057 .37522 Mtetra
.677 .59 .75 r
.15057 .37522 .15703 .391 .16791 .38378 .1614 .36854 Mtetra
.67 .593 .76 r
.1614 .36854 .16791 .38378 .17878 .37689 .17218 .36244 Mtetra
.64 .588 .78 r
.17218 .36244 .17878 .37689 .1895 .37165 .18281 .35805 Mtetra
.58 .571 .808 r
.18281 .35805 .1895 .37165 .19998 .36895 .19322 .35605 Mtetra
.457 .519 .834 r
.19322 .35605 .19998 .36895 .21018 .36972 .20337 .35718 Mtetra
.327 .454 .837 r
.20337 .35718 .21018 .36972 .22022 .37296 .21337 .36061 Mtetra
.197 .381 .82 r
.21337 .36061 .22022 .37296 .23016 .37813 .22329 .36587 Mtetra
.165 .364 .815 r
.22329 .36587 .23016 .37813 .24018 .38356 .23328 .37154 Mtetra
.208 .399 .831 r
.23328 .37154 .24018 .38356 .2504 .38798 .24343 .37654 Mtetra
.287 .462 .859 r
.24343 .37654 .2504 .38798 .26085 .39077 .2538 .38021 Mtetra
.393 .545 .888 r
.2538 .38021 .26085 .39077 .27156 .39137 .26442 .38195 Mtetra
.474 .619 .913 r
.26442 .38195 .27156 .39137 .28247 .39026 .27525 .38202 Mtetra
.547 .688 .932 r
.27525 .38202 .28247 .39026 .29356 .38767 .28628 .38048 Mtetra
.598 .742 .945 r
.28628 .38048 .29356 .38767 .30477 .38405 .29746 .37774 Mtetra
.634 .783 .953 r
.29746 .37774 .30477 .38405 .31608 .37975 .30875 .37412 Mtetra
.654 .812 .959 r
.30875 .37412 .31608 .37975 .32745 .37507 .32013 .36993 Mtetra
.662 .832 .965 r
.32013 .36993 .32745 .37507 .33888 .37027 .33157 .36549 Mtetra
.658 .844 .972 r
.33157 .36549 .33888 .37027 .35033 .3656 .34305 .36104 Mtetra
.646 .85 .978 r
.34305 .36104 .35033 .3656 .36182 .36123 .35457 .35676 Mtetra
.631 .849 .983 r
.35457 .35676 .36182 .36123 .37334 .35722 .36613 .35272 Mtetra
.616 .845 .986 r
.36613 .35272 .37334 .35722 .38488 .35359 .37772 .34894 Mtetra
.608 .838 .987 r
.37772 .34894 .38488 .35359 .39647 .35025 .38936 .34532 Mtetra
.611 .831 .984 r
.38936 .34532 .39647 .35025 .40811 .34704 .40105 .34169 Mtetra
.629 .823 .975 r
.40105 .34169 .40811 .34704 .41981 .34372 .41281 .33781 Mtetra
.658 .814 .958 r
.41281 .33781 .41981 .34372 .43157 .34001 .42464 .33336 Mtetra
.694 .801 .932 r
.42464 .33336 .43157 .34001 .44341 .33561 .43654 .32801 Mtetra
.728 .783 .896 r
.43654 .32801 .44341 .33561 .45532 .33018 .44851 .32144 Mtetra
.758 .761 .856 r
.44851 .32144 .45532 .33018 .4673 .32323 .46055 .31323 Mtetra
.777 .739 .818 r
.46055 .31323 .4673 .32323 .47934 .31453 .47264 .3033 Mtetra
.794 .721 .783 r
.47264 .3033 .47934 .31453 .49142 .30358 .48477 .2914 Mtetra
.801 .708 .762 r
.48477 .2914 .49142 .30358 .50351 .29094 .4969 .2781 Mtetra
.803 .699 .75 r
.4969 .2781 .50351 .29094 .51559 .27726 .50902 .26409 Mtetra
.796 .693 .751 r
.50902 .26409 .51559 .27726 .52765 .26379 .52111 .25046 Mtetra
.773 .682 .763 r
.52111 .25046 .52765 .26379 .5397 .25227 .53319 .23868 Mtetra
.737 .664 .778 r
.53319 .23868 .5397 .25227 .55177 .24328 .54528 .22923 Mtetra
.675 .629 .796 r
.54528 .22923 .55177 .24328 .5639 .23782 .55742 .22298 Mtetra
.616 .588 .799 r
.55742 .22298 .5639 .23782 .57612 .23496 .56963 .21918 Mtetra
.57 .55 .793 r
.56963 .21918 .57612 .23496 .58845 .23382 .58193 .21714 Mtetra
.553 .53 .783 r
.58193 .21714 .58845 .23382 .60086 .23302 .59433 .2157 Mtetra
.573 .534 .773 r
.59433 .2157 .60086 .23302 .61331 .23081 .60678 .21341 Mtetra
.6 .549 .769 r
.60678 .21341 .61331 .23081 .62579 .22688 .61926 .20989 Mtetra
.643 .578 .767 r
.61926 .20989 .62579 .22688 .63822 .2204 .63174 .20437 Mtetra
.674 .606 .772 r
.63174 .20437 .63822 .2204 .65063 .21219 .64421 .19743 Mtetra
.702 .638 .782 r
.64421 .19743 .65063 .21219 .66301 .20285 .65667 .18947 Mtetra
.72 .667 .798 r
.65667 .18947 .66301 .20285 .67539 .19316 .66915 .18113 Mtetra
.723 .693 .821 r
.66915 .18113 .67539 .19316 .68782 .18412 .68167 .17322 Mtetra
.723 .717 .844 r
.68167 .17322 .68782 .18412 .7003 .17568 .69424 .16573 Mtetra
.717 .737 .867 r
.69424 .16573 .7003 .17568 .71286 .16798 .70689 .15881 Mtetra
.702 .752 .891 r
.70689 .15881 .71286 .16798 .7255 .16118 .71961 .15261 Mtetra
.639 .747 .927 r
.04273 .38856 .05043 .39529 .06025 .39313 .05272 .38529 Mtetra
.617 .708 .91 r
.05272 .38529 .06025 .39313 .07001 .39168 .06268 .38254 Mtetra
.6 .667 .886 r
.06268 .38254 .07001 .39168 .07975 .39077 .07263 .38018 Mtetra
.588 .627 .858 r
.07263 .38018 .07975 .39077 .08948 .39029 .08258 .37809 Mtetra
.577 .59 .829 r
.08258 .37809 .08948 .39029 .09922 .39024 .09255 .37626 Mtetra
.584 .564 .797 r
.09255 .37626 .09922 .39024 .10907 .38984 .10262 .37412 Mtetra
.6 .549 .769 r
.10262 .37412 .10907 .38984 .11909 .38846 .11283 .37121 Mtetra
.617 .542 .747 r
.11283 .37121 .11909 .38846 .12934 .38573 .12321 .36729 Mtetra
.639 .543 .73 r
.12321 .36729 .12934 .38573 .13987 .38107 .1338 .36199 Mtetra
.648 .543 .722 r
.1338 .36199 .13987 .38107 .15057 .37522 .14452 .35593 Mtetra
.654 .545 .719 r
.14452 .35593 .15057 .37522 .1614 .36854 .15531 .34942 Mtetra
.645 .541 .723 r
.15531 .34942 .1614 .36854 .17218 .36244 .16606 .34354 Mtetra
.619 .528 .73 r
.16606 .34354 .17218 .36244 .18281 .35805 .17667 .33917 Mtetra
.577 .504 .736 r
.17667 .33917 .18281 .35805 .19322 .35605 .1871 .33681 Mtetra
.513 .462 .738 r
.1871 .33681 .19322 .35605 .20337 .35718 .19732 .33699 Mtetra
.459 .42 .728 r
.19732 .33699 .20337 .35718 .21337 .36061 .20742 .33909 Mtetra
.417 .382 .713 r
.20742 .33909 .21337 .36061 .22329 .36587 .21745 .34275 Mtetra
.412 .367 .698 r
.21745 .34275 .22329 .36587 .23328 .37154 .22752 .34689 Mtetra
.43 .368 .687 r
.22752 .34689 .23328 .37154 .24343 .37654 .23773 .35066 Mtetra
.458 .38 .681 r
.23773 .35066 .24343 .37654 .2538 .38021 .24811 .3535 Mtetra
.492 .398 .678 r
.24811 .3535 .2538 .38021 .26442 .38195 .25871 .35488 Mtetra
.519 .415 .677 r
.25871 .35488 .26442 .38195 .27525 .38202 .2695 .3549 Mtetra
.544 .432 .677 r
.2695 .3549 .27525 .38202 .28628 .38048 .28046 .35354 Mtetra
.562 .445 .678 r
.28046 .35354 .28628 .38048 .29746 .37774 .29157 .3511 Mtetra
.576 .456 .679 r
.29157 .3511 .29746 .37774 .30875 .37412 .3028 .34779 Mtetra
.585 .464 .681 r
.3028 .34779 .30875 .37412 .32013 .36993 .31412 .34393 Mtetra
.591 .47 .683 r
.31412 .34393 .32013 .36993 .33157 .36549 .32551 .33976 Mtetra
.593 .473 .685 r
.32551 .33976 .33157 .36549 .34305 .36104 .33694 .3355 Mtetra
.592 .474 .687 r
.33694 .3355 .34305 .36104 .35457 .35676 .34843 .33128 Mtetra
.59 .473 .688 r
.34843 .33128 .35457 .35676 .36613 .35272 .35995 .3272 Mtetra
.588 .472 .688 r
.35995 .3272 .36613 .35272 .37772 .34894 .37152 .32325 Mtetra
.587 .47 .687 r
.37152 .32325 .37772 .34894 .38936 .34532 .38313 .31935 Mtetra
.587 .469 .686 r
.38313 .31935 .38936 .34532 .40105 .34169 .3948 .31535 Mtetra
.591 .47 .683 r
.3948 .31535 .40105 .34169 .41281 .33781 .40653 .31104 Mtetra
.598 .472 .68 r
.40653 .31104 .41281 .33781 .42464 .33336 .41833 .30617 Mtetra
.608 .477 .677 r
.41833 .30617 .42464 .33336 .43654 .32801 .43021 .30042 Mtetra
.621 .484 .673 r
.43021 .30042 .43654 .32801 .44851 .32144 .44215 .29357 Mtetra
.637 .493 .67 r
.44215 .29357 .44851 .32144 .46055 .31323 .45416 .28532 Mtetra
.653 .503 .667 r
.45416 .28532 .46055 .31323 .47264 .3033 .46621 .27565 Mtetra
.67 .515 .666 r
.46621 .27565 .47264 .3033 .48477 .2914 .4783 .2645 Mtetra
.683 .526 .667 r
.4783 .2645 .48477 .2914 .4969 .2781 .4904 .25236 Mtetra
.693 .537 .671 r
.4904 .25236 .4969 .2781 .50902 .26409 .50249 .23982 Mtetra
.696 .547 .68 r
.50249 .23982 .50902 .26409 .52111 .25046 .51457 .22774 Mtetra
.687 .55 .694 r
.51457 .22774 .52111 .25046 .53319 .23868 .52665 .21724 Mtetra
.669 .548 .709 r
.52665 .21724 .53319 .23868 .54528 .22923 .53873 .20868 Mtetra
.634 .535 .725 r
.53873 .20868 .54528 .22923 .55742 .22298 .55086 .20272 Mtetra
.599 .517 .734 r
.55086 .20272 .55742 .22298 .56963 .21918 .56306 .19881 Mtetra
.569 .499 .737 r
.56306 .19881 .56963 .21918 .58193 .21714 .57534 .19646 Mtetra
.555 .488 .735 r
.57534 .19646 .58193 .21714 .59433 .2157 .58771 .19475 Mtetra
.563 .491 .733 r
.58771 .19475 .59433 .2157 .60678 .21341 .60014 .1926 Mtetra
.579 .502 .733 r
.60014 .1926 .60678 .21341 .61926 .20989 .61263 .18965 Mtetra
.607 .525 .736 r
.61263 .18965 .61926 .20989 .63174 .20437 .62513 .18527 Mtetra
.63 .549 .744 r
.62513 .18527 .63174 .20437 .64421 .19743 .63766 .17985 Mtetra
.652 .577 .758 r
.63766 .17985 .64421 .19743 .65667 .18947 .6502 .17362 Mtetra
.668 .607 .778 r
.6502 .17362 .65667 .18947 .66915 .18113 .66277 .16705 Mtetra
.674 .636 .804 r
.66277 .16705 .66915 .18113 .68167 .17322 .6754 .16074 Mtetra
.678 .666 .832 r
.6754 .16074 .68167 .17322 .69424 .16573 .68808 .15471 Mtetra
.676 .697 .861 r
.68808 .15471 .69424 .16573 .70689 .15881 .70084 .14908 Mtetra
.667 .725 .892 r
.70084 .14908 .70689 .15881 .71961 .15261 .71368 .14397 Mtetra
.689 .759 .905 r
.03496 .38178 .04273 .38856 .05272 .38529 .04517 .37719 Mtetra
.672 .718 .883 r
.04517 .37719 .05272 .38529 .06268 .38254 .05536 .37292 Mtetra
.657 .677 .857 r
.05536 .37292 .06268 .38254 .07263 .38018 .06556 .36891 Mtetra
.643 .637 .829 r
.06556 .36891 .07263 .38018 .08258 .37809 .07576 .36506 Mtetra
.631 .602 .802 r
.07576 .36506 .08258 .37809 .09255 .37626 .08599 .36135 Mtetra
.627 .573 .774 r
.08599 .36135 .09255 .37626 .10262 .37412 .09628 .35744 Mtetra
.63 .554 .751 r
.09628 .35744 .10262 .37412 .11283 .37121 .10668 .35302 Mtetra
.635 .543 .733 r
.10668 .35302 .11283 .37121 .12321 .36729 .11719 .34798 Mtetra
.644 .539 .72 r
.11719 .34798 .12321 .36729 .1338 .36199 .12784 .34212 Mtetra
.647 .537 .714 r
.12784 .34212 .1338 .36199 .14452 .35593 .13856 .33585 Mtetra
.649 .536 .713 r
.13856 .33585 .14452 .35593 .15531 .34942 .14934 .32943 Mtetra
.64 .532 .715 r
.14934 .32943 .15531 .34942 .16606 .34354 .16007 .32355 Mtetra
.621 .52 .719 r
.16007 .32355 .16606 .34354 .17667 .33917 .1707 .31881 Mtetra
.592 .5 .719 r
.1707 .31881 .17667 .33917 .1871 .33681 .18121 .31551 Mtetra
.552 .469 .715 r
.18121 .31551 .1871 .33681 .19732 .33699 .19157 .31402 Mtetra
.52 .436 .701 r
.19157 .31402 .19732 .33699 .20742 .33909 .20185 .31391 Mtetra
.495 .406 .684 r
.20185 .31391 .20742 .33909 .21745 .34275 .21209 .31496 Mtetra
.488 .388 .667 r
.21209 .31496 .21745 .34275 .22752 .34689 .22235 .31645 Mtetra
.493 .379 .653 r
.22235 .31645 .22752 .34689 .23773 .35066 .23271 .31781 Mtetra
.503 .378 .642 r
.23271 .31781 .23773 .35066 .24811 .3535 .2432 .31863 Mtetra
.517 .382 .635 r
.2432 .31863 .24811 .3535 .25871 .35488 .25384 .31854 Mtetra
.53 .386 .63 r
.25384 .31854 .25871 .35488 .2695 .3549 .26462 .31755 Mtetra
.541 .392 .628 r
.26462 .31755 .2695 .3549 .28046 .35354 .27555 .31561 Mtetra
.55 .397 .626 r
.27555 .31561 .28046 .35354 .29157 .3511 .2866 .31289 Mtetra
.557 .402 .626 r
.2866 .31289 .29157 .3511 .3028 .34779 .29775 .30953 Mtetra
.562 .405 .626 r
.29775 .30953 .3028 .34779 .31412 .34393 .30898 .30573 Mtetra
.565 .407 .626 r
.30898 .30573 .31412 .34393 .32551 .33976 .32028 .30167 Mtetra
.566 .409 .627 r
.32028 .30167 .32551 .33976 .33694 .3355 .33163 .29749 Mtetra
.567 .409 .627 r
.33163 .29749 .33694 .3355 .34843 .33128 .34304 .2933 Mtetra
.566 .409 .628 r
.34304 .2933 .34843 .33128 .35995 .3272 .35448 .28916 Mtetra
.565 .408 .628 r
.35448 .28916 .35995 .3272 .37152 .32325 .36597 .28507 Mtetra
.565 .408 .627 r
.36597 .28507 .37152 .32325 .38313 .31935 .37751 .28096 Mtetra
.566 .408 .627 r
.37751 .28096 .38313 .31935 .3948 .31535 .38911 .27674 Mtetra
.568 .41 .626 r
.38911 .27674 .3948 .31535 .40653 .31104 .40077 .27225 Mtetra
.573 .412 .626 r
.40077 .27225 .40653 .31104 .41833 .30617 .41249 .26732 Mtetra
.579 .417 .626 r
.41249 .26732 .41833 .30617 .43021 .30042 .42428 .26173 Mtetra
.587 .423 .626 r
.42428 .26173 .43021 .30042 .44215 .29357 .43613 .25535 Mtetra
.598 .432 .627 r
.43613 .25535 .44215 .29357 .45416 .28532 .44804 .248 Mtetra
.609 .441 .63 r
.44804 .248 .45416 .28532 .46621 .27565 .45999 .23973 Mtetra
.621 .453 .634 r
.45999 .23973 .46621 .27565 .4783 .2645 .47199 .23051 Mtetra
.632 .466 .64 r
.47199 .23051 .4783 .2645 .4904 .25236 .48401 .22073 Mtetra
.641 .48 .649 r
.48401 .22073 .4904 .25236 .50249 .23982 .49603 .2108 Mtetra
.646 .493 .661 r
.49603 .2108 .50249 .23982 .51457 .22774 .50807 .2013 Mtetra
.642 .502 .676 r
.50807 .2013 .51457 .22774 .52665 .21724 .52011 .19296 Mtetra
.633 .508 .693 r
.52011 .19296 .52665 .21724 .53873 .20868 .53218 .18603 Mtetra
.611 .505 .709 r
.53218 .18603 .53873 .20868 .55086 .20272 .5443 .18094 Mtetra
.588 .498 .72 r
.5443 .18094 .55086 .20272 .56306 .19881 .55648 .17733 Mtetra
.567 .488 .726 r
.55648 .17733 .56306 .19881 .57534 .19646 .56873 .17488 Mtetra
.556 .481 .726 r
.56873 .17488 .57534 .19646 .58771 .19475 .58107 .173 Mtetra
.558 .482 .725 r
.58107 .173 .58771 .19475 .60014 .1926 .59349 .17096 Mtetra
.566 .488 .726 r
.59349 .17096 .60014 .1926 .61263 .18965 .60597 .16851 Mtetra
.583 .503 .73 r
.60597 .16851 .61263 .18965 .62513 .18527 .61849 .1652 Mtetra
.598 .522 .739 r
.61849 .1652 .62513 .18527 .63766 .17985 .63106 .16126 Mtetra
.613 .545 .754 r
.63106 .16126 .63766 .17985 .6502 .17362 .64368 .15679 Mtetra
.625 .572 .775 r
.64368 .15679 .6502 .17362 .66277 .16705 .65634 .15209 Mtetra
.629 .601 .802 r
.65634 .15209 .66277 .16705 .6754 .16074 .66906 .14754 Mtetra
.632 .632 .832 r
.66906 .14754 .6754 .16074 .68808 .15471 .68186 .14316 Mtetra
.631 .665 .865 r
.68186 .14316 .68808 .15471 .70084 .14908 .69473 .13904 Mtetra
.622 .699 .899 r
.69473 .13904 .70084 .14908 .71368 .14397 .70769 .13525 Mtetra
.728 .765 .882 r
.02714 .37496 .03496 .38178 .04517 .37719 .03757 .36904 Mtetra
.714 .728 .862 r
.03757 .36904 .04517 .37719 .05536 .37292 .048 .3633 Mtetra
.699 .691 .839 r
.048 .3633 .05536 .37292 .06556 .36891 .05843 .35771 Mtetra
.685 .656 .815 r
.05843 .35771 .06556 .36891 .07576 .36506 .06888 .35223 Mtetra
.672 .624 .793 r
.06888 .35223 .07576 .36506 .08599 .36135 .07934 .34683 Mtetra
.662 .596 .771 r
.07934 .34683 .08599 .36135 .09628 .35744 .08984 .34137 Mtetra
.657 .576 .752 r
.08984 .34137 .09628 .35744 .10668 .35302 .1004 .33571 Mtetra
.654 .562 .738 r
.1004 .33571 .10668 .35302 .11719 .34798 .11102 .32981 Mtetra
.655 .555 .729 r
.11102 .32981 .11719 .34798 .12784 .34212 .1217 .32359 Mtetra
.655 .552 .726 r
.1217 .32359 .12784 .34212 .13856 .33585 .13243 .31726 Mtetra
.654 .551 .726 r
.13243 .31726 .13856 .33585 .14934 .32943 .14318 .31096 Mtetra
.648 .549 .728 r
.14318 .31096 .14934 .32943 .16007 .32355 .15391 .30501 Mtetra
.637 .542 .73 r
.15391 .30501 .16007 .32355 .1707 .31881 .16459 .29971 Mtetra
.619 .527 .728 r
.16459 .29971 .1707 .31881 .18121 .31551 .17522 .29521 Mtetra
.596 .503 .72 r
.17522 .29521 .18121 .31551 .19157 .31402 .18578 .29166 Mtetra
.575 .476 .704 r
.18578 .29166 .19157 .31402 .20185 .31391 .1963 .28889 Mtetra
.558 .448 .685 r
.1963 .28889 .20185 .31391 .21209 .31496 .20681 .28676 Mtetra
.548 .426 .665 r
.20681 .28676 .21209 .31496 .22235 .31645 .21734 .28494 Mtetra
.543 .409 .648 r
.21734 .28494 .22235 .31645 .23271 .31781 .22793 .28315 Mtetra
.543 .399 .635 r
.22793 .28315 .23271 .31781 .2432 .31863 .23859 .28117 Mtetra
.545 .392 .625 r
.23859 .28117 .2432 .31863 .25384 .31854 .24935 .27883 Mtetra
.547 .389 .618 r
.24935 .27883 .25384 .31854 .26462 .31755 .26019 .27609 Mtetra
.55 .387 .613 r
.26019 .27609 .26462 .31755 .27555 .31561 .27112 .27293 Mtetra
.553 .387 .61 r
.27112 .27293 .27555 .31561 .2866 .31289 .28214 .26941 Mtetra
.555 .387 .609 r
.28214 .26941 .2866 .31289 .29775 .30953 .29322 .26557 Mtetra
.556 .387 .608 r
.29322 .26557 .29775 .30953 .30898 .30573 .30437 .26153 Mtetra
.557 .388 .607 r
.30437 .26153 .30898 .30573 .32028 .30167 .31557 .25736 Mtetra
.558 .388 .607 r
.31557 .25736 .32028 .30167 .33163 .29749 .32682 .25314 Mtetra
.32682 .25314 .33163 .29749 .34304 .2933 .33812 .2489 Mtetra
.557 .388 .607 r
.33812 .2489 .34304 .2933 .35448 .28916 .34947 .2447 Mtetra
.557 .387 .607 r
.34947 .2447 .35448 .28916 .36597 .28507 .36086 .24053 Mtetra
.556 .387 .607 r
.36086 .24053 .36597 .28507 .37751 .28096 .3723 .23634 Mtetra
.557 .387 .607 r
.3723 .23634 .37751 .28096 .38911 .27674 .38379 .23211 Mtetra
.558 .388 .607 r
.38379 .23211 .38911 .27674 .40077 .27225 .39533 .22774 Mtetra
.56 .39 .608 r
.39533 .22774 .40077 .27225 .41249 .26732 .40694 .22315 Mtetra
.563 .393 .609 r
.40694 .22315 .41249 .26732 .42428 .26173 .4186 .21826 Mtetra
.568 .398 .611 r
.4186 .21826 .42428 .26173 .43613 .25535 .43031 .213 Mtetra
.573 .404 .614 r
.43031 .213 .43613 .25535 .44804 .248 .44208 .2073 Mtetra
.58 .412 .619 r
.44208 .2073 .44804 .248 .45999 .23973 .45391 .2012 Mtetra
.587 .422 .625 r
.45391 .2012 .45999 .23973 .47199 .23051 .46577 .19471 Mtetra
.595 .435 .635 r
.46577 .19471 .47199 .23051 .48401 .22073 .47768 .18803 Mtetra
.602 .449 .647 r
.47768 .18803 .48401 .22073 .49603 .2108 .48962 .18138 Mtetra
.607 .465 .662 r
.48962 .18138 .49603 .2108 .50807 .2013 .50159 .17502 Mtetra
.608 .48 .681 r
.50159 .17502 .50807 .2013 .52011 .19296 .51359 .16932 Mtetra
.604 .494 .701 r
.51359 .16932 .52011 .19296 .53218 .18603 .52564 .1644 Mtetra
.594 .502 .72 r
.52564 .1644 .53218 .18603 .5443 .18094 .53774 .16046 Mtetra
.582 .505 .733 r
.53774 .16046 .5443 .18094 .55648 .17733 .54991 .15733 Mtetra
.569 .502 .741 r
.54991 .15733 .55648 .17733 .56873 .17488 .56215 .15487 Mtetra
.561 .498 .742 r
.56215 .15487 .56873 .17488 .58107 .173 .57447 .15278 Mtetra
.56 .496 .74 r
.57447 .15278 .58107 .173 .59349 .17096 .58687 .15071 Mtetra
.562 .497 .741 r
.58687 .15071 .59349 .17096 .60597 .16851 .59934 .14854 Mtetra
.569 .505 .743 r
.59934 .14854 .60597 .16851 .61849 .1652 .61187 .14604 Mtetra
.575 .517 .753 r
.61187 .14604 .61849 .1652 .63106 .16126 .62448 .14331 Mtetra
.583 .535 .767 r
.62448 .14331 .63106 .16126 .64368 .15679 .63715 .14036 Mtetra
.588 .557 .788 r
.63715 .14036 .64368 .15679 .65634 .15209 .64989 .13734 Mtetra
.589 .583 .814 r
.64989 .13734 .65634 .15209 .66906 .14754 .6627 .13441 Mtetra
.588 .612 .843 r
.6627 .13441 .66906 .14754 .68186 .14316 .6756 .1316 Mtetra
.584 .643 .875 r
.6756 .1316 .68186 .14316 .69473 .13904 .68858 .12894 Mtetra
.574 .675 .908 r
.68858 .12894 .69473 .13904 .70769 .13525 .70165 .12647 Mtetra
.754 .768 .864 r
.01926 .36808 .02714 .37496 .03757 .36904 .02989 .36107 Mtetra
.742 .739 .849 r
.02989 .36107 .03757 .36904 .048 .3633 .04051 .35415 Mtetra
.73 .711 .832 r
.04051 .35415 .048 .3633 .05843 .35771 .05115 .34733 Mtetra
.718 .683 .816 r
.05115 .34733 .05843 .35771 .06888 .35223 .06179 .34061 Mtetra
.706 .658 .8 r
.06179 .34061 .06888 .35223 .07934 .34683 .07243 .33399 Mtetra
.694 .634 .785 r
.07243 .33399 .07934 .34683 .08984 .34137 .08309 .32746 Mtetra
.685 .616 .773 r
.08309 .32746 .08984 .34137 .1004 .33571 .09376 .32103 Mtetra
.678 .603 .765 r
.09376 .32103 .1004 .33571 .11102 .32981 .10443 .3147 Mtetra
.673 .596 .761 r
.10443 .3147 .11102 .32981 .1217 .32359 .11512 .30846 Mtetra
.671 .595 .762 r
.11512 .30846 .1217 .32359 .13243 .31726 .12583 .30232 Mtetra
.67 .597 .765 r
.12583 .30232 .13243 .31726 .14318 .31096 .13654 .29627 Mtetra
.67 .6 .769 r
.13654 .29627 .14318 .31096 .15391 .30501 .14728 .29032 Mtetra
.668 .6 .77 r
.14728 .29032 .15391 .30501 .16459 .29971 .15803 .28446 Mtetra
.662 .59 .764 r
.15803 .28446 .16459 .29971 .17522 .29521 .16879 .2787 Mtetra
.653 .572 .751 r
.16879 .2787 .17522 .29521 .18578 .29166 .17958 .27303 Mtetra
.64 .544 .73 r
.17958 .27303 .18578 .29166 .1963 .28889 .19039 .26746 Mtetra
.626 .514 .706 r
.19039 .26746 .1963 .28889 .20681 .28676 .20122 .26198 Mtetra
.611 .484 .683 r
.20122 .26198 .20681 .28676 .21734 .28494 .21208 .25659 Mtetra
.599 .459 .662 r
.21208 .25659 .21734 .28494 .22793 .28315 .22295 .2513 Mtetra
.589 .439 .646 r
.22295 .2513 .22793 .28315 .23859 .28117 .23386 .2461 Mtetra
.581 .423 .633 r
.23386 .2461 .23859 .28117 .24935 .27883 .24479 .24099 Mtetra
.574 .412 .623 r
.24479 .24099 .24935 .27883 .26019 .27609 .25575 .23598 Mtetra
.57 .403 .616 r
.25575 .23598 .26019 .27609 .27112 .27293 .26674 .23106 Mtetra
.566 .397 .612 r
.26674 .23106 .27112 .27293 .28214 .26941 .27776 .22623 Mtetra
.563 .392 .608 r
.27776 .22623 .28214 .26941 .29322 .26557 .28882 .2215 Mtetra
.561 .389 .606 r
.28882 .2215 .29322 .26557 .30437 .26153 .29991 .21686 Mtetra
.559 .387 .604 r
.29991 .21686 .30437 .26153 .31557 .25736 .31103 .21232 Mtetra
.558 .385 .604 r
.31103 .21232 .31557 .25736 .32682 .25314 .32219 .20787 Mtetra
.556 .384 .603 r
.32219 .20787 .32682 .25314 .33812 .2489 .33339 .20351 Mtetra
.555 .383 .603 r
.33339 .20351 .33812 .2489 .34947 .2447 .34463 .19924 Mtetra
.554 .382 .603 r
.34463 .19924 .34947 .2447 .36086 .24053 .35591 .19507 Mtetra
.553 .382 .603 r
.35591 .19507 .36086 .24053 .3723 .23634 .36724 .19099 Mtetra
.552 .381 .603 r
.36724 .19099 .3723 .23634 .38379 .23211 .37861 .18701 Mtetra
.551 .381 .604 r
.37861 .18701 .38379 .23211 .39533 .22774 .39002 .18312 Mtetra
.551 .382 .605 r
.39002 .18312 .39533 .22774 .40694 .22315 .40148 .17933 Mtetra
.551 .383 .608 r
.40148 .17933 .40694 .22315 .4186 .21826 .41299 .17563 Mtetra
.551 .386 .611 r
.41299 .17563 .4186 .21826 .43031 .213 .42456 .17202 Mtetra
.552 .39 .616 r
.42456 .17202 .43031 .213 .44208 .2073 .43617 .16851 Mtetra
.553 .397 .623 r
.43617 .16851 .44208 .2073 .45391 .2012 .44784 .1651 Mtetra
.555 .406 .633 r
.44784 .1651 .45391 .2012 .46577 .19471 .45957 .16178 Mtetra
.558 .418 .647 r
.45957 .16178 .46577 .19471 .47768 .18803 .47135 .15856 Mtetra
.562 .435 .664 r
.47135 .15856 .47768 .18803 .48962 .18138 .48319 .15544 Mtetra
.567 .456 .686 r
.48319 .15544 .48962 .18138 .50159 .17502 .4951 .15241 Mtetra
.572 .481 .713 r
.4951 .15241 .50159 .17502 .51359 .16932 .50706 .14948 Mtetra
.576 .507 .74 r
.50706 .14948 .51359 .16932 .52564 .1644 .5191 .14665 Mtetra
.579 .531 .765 r
.5191 .14665 .52564 .1644 .53774 .16046 .5312 .14391 Mtetra
.579 .546 .782 r
.5312 .14391 .53774 .16046 .54991 .15733 .54337 .14128 Mtetra
.577 .552 .79 r
.54337 .14128 .54991 .15733 .56215 .15487 .55561 .13874 Mtetra
.574 .55 .79 r
.55561 .13874 .56215 .15487 .57447 .15278 .56792 .13631 Mtetra
.571 .545 .786 r
.56792 .13631 .57447 .15278 .58687 .15071 .58031 .13397 Mtetra
.568 .54 .784 r
.58031 .13397 .58687 .15071 .59934 .14854 .59278 .13174 Mtetra
.565 .538 .784 r
.59278 .13174 .59934 .14854 .61187 .14604 .60532 .12961 Mtetra
.562 .542 .79 r
.60532 .12961 .61187 .14604 .62448 .14331 .61795 .12758 Mtetra
.56 .552 .802 r
.61795 .12758 .62448 .14331 .63715 .14036 .63066 .12565 Mtetra
.557 .567 .819 r
.63066 .12565 .63715 .14036 .64989 .13734 .64346 .12383 Mtetra
.554 .587 .842 r
.64346 .12383 .64989 .13734 .6627 .13441 .65635 .12212 Mtetra
.548 .609 .866 r
.65635 .12212 .6627 .13441 .6756 .1316 .66932 .12051 Mtetra
.54 .633 .892 r
.66932 .12051 .6756 .1316 .68858 .12894 .6824 .119 Mtetra
.528 .658 .919 r
.6824 .119 .68858 .12894 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Nooooo`;oRZ;T1?n7Z>/00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo057ooooo001Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool07Oooool3o`0000;ooooo00?o0000ooooooooool0Dooo
ool2ohfFe`GoS9_M1On:X^@3ohNXj`03o`000?n7Z>_ooooo01Gooooo00?o0000ooooooooool0D?oo
ool0063ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00007?ooool2o`0005?ooooo0_n?
SLd4ohjAd@GoSIKG1On<Vmd5ohZRi0;oQjS[00?o0000oi:/j?ooool05?ooool00ol0003oooooo`00
001Aooooo`00H?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
6_ooool3o`0004gooooo0_n@RLP4ohn:bPGoShg=1?n>TM44ohfFe`KoS9_M0_n:X^@2oiFTg`;oTZcX
00?o0000oi:/j?nB[>P05_ooool00ol0003oooooooooo`1?ooooo`00H?ooool01Ol0003ooooooooo
oooooooo000000_ooooo00CogMgMoeEEEOoooooo00006?ooool2o`0004cooooo0_nAR/P5oi29b0Co
Sh[:1?n?SLd4ohjAd@GoSIKG0on<Vmd2oiJLe`GoUJCO00?oTZcXo`000?nB[>P00_nB[>PFooooo`03
o`000?oooooooooo04kooooo001Pooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOo
c<c<o`00000Eooooo`?o00000_ooool00ol0003oooooooooo`15ooooo`;oTX_91OnAR/P4oi29b0Co
Sh[:1?n?SLd5ohjAd@;oSIKG0_nFUM05oiJLe`KoUJCO00Co0000oi:/j?nO/^KoWk;V5_ooool00ol0
003oooooooooo`1>ooooo`00H?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4
A?l000004oooool2o`0004Kooooo00?oThg:oi:<b_nBS<X00_nBS<X5oi:;b@CoTH[81?n@RLP4ohn:
bPGoShg=0_n>TM42oiJ>b@GoUYG@1OnFW=L4oiFTg`03oj6ZgOl0003oWk;V00?oWk;V5_ooool00ol0
003oooooooooo`1=ooooo`00H?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`00
0?ooool03oooool3o`0004Cooooo0_nDRlP4oi>=bPCoTXc:1?nBRlT4oi6:b0GoT8W81?n?R/X2ohn=
c@;oUHS41OnFS/T4oiJEd0GoUYcG00?oUJCOoj6ZgOnQZ]d00_nQZ]d00ol0003oWk;VoinbiP03oinb
iQKooooo00?o0000ooooooooool0C?ooool008;ooooo0_l00013ooooo`;oU8O31OnDRlP4oi>=bP?o
TXc:1?nBRlT5oi6:b0CoT8W80_n?R/X2oi>4`0GoUHS41?nFS/T5oiJEd0;oUYcG0_nQXM@5oj6Zg@03
o`000?nO/^KoWk;V00;oWk;V00?oZ[WTooooooooool05?ooool00ol0003oooooooooo`1<ooooo`00
Ooooool3o`0000;ooooo00?o0000ooooooooool0??ooool2oi>1_@GoU8O31?nDRlP4oi>=bP?oTXc:
1OnBRlT2oi6:b0;oSgnm1?nAPKh5oi>4`0CoUHS41?nFS/T4oiJEd003oj6IcOnQXMCoXJ7D00?oXJ7D
1?nQZ]d00ol0003oXJ[MoinbiP04ojZii1Cooooo0ol0001=ooooo`00O?ooool3o`00043ooooo0_nB
NkH5oi>1_@CoU8O31?nDRlP5oi>=bP?oTXc:0_nBRlT2ohmn_@CoSgnm1OnAPKh4oi>4`0CoUHS41OnF
S/T00onFUM3oXIW=oj6Ic@02oj6Ic@GoXJ7D0onQZ]d00ol0003o[K;LojZii004ojZii1Oooooo00?o
0000ooooooooool0B_ooool007[ooooo0_l0000oooooo`;oTGB_1OnBNkH4oi>1_@CoU8O31OnDRlP2
oi>=bP;oTH2m0on?Okd4ohmn_@GoSgnm1?nAPKh4oi>4`0GoUHS40_nFS/T2oinBaPGoXIW=1?nQXM@0
0on]Z]Co[K;Lojfbg002ojfbg003o`000?n]/]coZ[WT00;oZ[WT0_nc`>@Fooooo`03o`000?oooooo
oooo04[ooooo001gooooo`?o0000?_ooool00on?KjWoTGB_oi5d[`02oi5d[`GoTW^f1?nCPKd5oiB7
``;oU8_80_nDPK/4oi60_@CoSgnm1?n?O[d4ohmo_@CoTH6n1OnCQ<02oiF8a0;oW8_11OnOT/H5oj6I
c@03oj6Qe?n]Z]Co[J[D00;o[J[D0on]/]`00ol0003o[K;LojZii005ok?0i1Kooooo00?o0000oooo
ooooool0BOooool007Gooooo0_l00002ooooo`03o`000?oooooooooo03Sooooo0_n>JjD4ohm_Z@Co
TGB_1?nBNkH5oi>1_@;oU8O30_nHP;P4oiB1^`GoTH2m0on?Okd4ohmn_@CoSgnm1OnAPKh3oi>4`003
oiV5_OnLRl7oW8_100?oW8_11?nOT/H4oj6Ic@03ojbRcOn]Z]Co[J[D00?o[J[D0on]/]`00ol0003o
]kcMok?0i004ok?0i003okW7iOoooooooooo01Gooooo00?o0000ooooooooool0B?ooool007;ooooo
0ol00005ooooo`03o`000?oooooooooo03?ooooo0_n>Ij84ohi[Y@CoSfnY1?nAM:l5oi9k]P?oTh6m
00?oVWjcoiR0^?nHP;P00_nHP;P5oiB1^`CoTH2m1?n?Okd3ohmn_@GoSgnm1?nAPKh00onCQ<3oVHFm
oiV5_@02oiV5_@CoW8_11OnOT/H00onQVLgo[:;=ojbRc@02ojbRc@Go[J[D00?o[K;LokNlgOl00000
0_ng_=d3ok?0i0?o^LOU5_ooool00ol0003oooooooooo`18ooooo`00L?ooool2o`0003_ooooo00?o
SFFOohiWX_n>Ij800_n>Ij85ohi[Y@?oSfnY1?nAM:l5oi9k]P04oi>1_OnJO[?oVWjcoiYn/`GoV82h
1?nDPK/4oi60_@CoSgnm1?n?O[d4ohmo_@;oTH6n0_nEP;X5oiV5_@CoW8_11?nOT/H00on[VlOo[:;=
ojbRc@03ojbRc@Co[J[D00Co^KOHokNlgOng_=go00000ong_=d00onc`>Co^LOUokW7i@03okW7iAKo
oooo00?o0000ooooooooool0Aoooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool5o`00023ooooo0ol0000iooooo`;oSF>M0on=IIl5ohiWXPCoSV^U1?n?KjT4oi5d[`?o
TW^f00?oVgZ^oiYn/onJO[<00onJO[<4oiR0^0CoU86k1OnAP;d4ohmo_@?oSgjm0_n?Okd2oi1l^@Go
UH2j1?nIQKd5oib;`@03oinBa_n[VlOoZi_700;oZi_71On/X/d00on]Z]Co^KOHokVgf002okVgf004
okNlgOl0003o]kcMokNlg@;o_lSQ1?nianD00onjc^Woooooooooo`0Cooooo`?o0000B?ooool003So
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A401kooooo0_l00003ooooo`03o`000?oooooooooo03;ooooo0_n=HY`4oheSW@?oSFFO1On>Ij84
ohi[Y@CoSfnY1?nAM:l01?nBNkKoVgZ^oi]j[_nKNZh5oiYn/`CoV82h1OnDPK/4oi60_@;oSgnm1On>
NkT5oi1l^@CoUH2j1OnIQKd3oib;`@03ojJC`_n[VlOoZi_700?oZi_71?n/X/d00oni/M;o^KOHokVg
f004okVgf003o`000?nob>7o_lSQ00?o_lSQ00?o^LOUok[>jOnjc^T00_njc^TFooooo`03o`000?oo
oooooooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@
4?oooooooooo02Wooooo000hooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Q
onk^kP0Looooo`?o0000=oooool00on=HY_oSF:LoheRW002oheRW0CoSF>M1?n=IIl4ohiWXPCoSV^U
1?n?KjT3oi5d[`03oi]gZOnKNZkoVgZ^00?oVgZ^1?nJO[<5oiR0^0CoU86k0_nAP;d2oi5l^@SoSW^i
1?n@O;T5oiF0^PCoVHFm00?oW8_1ojJC`_nVTl800_nVTl84oj^Ka`?o[:;=0oni/M84okVgf003ol?7
gOl0003o_lSQ00?o_lSQ00?o`mOYok[>jOnjc^T01?njc^TFooooo`03o`000?oooooooooo00Gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Zooooo`00
>?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h06?ooool3o`0003Ko
oooo0_n=HIX3oheRV`CoSF:L1?n=Hid4oheUW`CoSVNR1?n>JjD5ohm_Z@03oi5d[onKMjWoVgNY00Go
VgZ^1OnJO[<4oiR0^0;oU86k0_nFOkP4oi5l^@SoSW^i1On@O;T4oiF0^P?oVHFm00?oXHbnojJC`_nV
Tl801?nVTl84oj^Ka`03ojbRcOni/M;o^K7B00;o^K7B0oni]mP2ol?7g@04o`000?nob>7o_lSQoko8
h@?o`mOY1?njc^T2ok??kQKooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000[ooooo`00>?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMg
ofIVI_ooool05Oooool3o`0003Gooooo1On=HIX3oheRV`GoSF:L0on=Hid4oheUW`CoSVNR1On>JjD3
ohm_Z@03oiYbYOnKMjWoVgNY00;oVgNY1?nKNZh5oiYn/`;oV82h0_nLPKD5oiIo^0CoTGbi2?n>NkT4
oi1l^@GoUH2j00CoVHFmoj6<__nQS;koXHbn1OnVTl83oj^Ka`03okRZc?ni/M;o^K7B00Co^K7B00Oo
^KOHol?7gOo3amgo`lOMo`000?o3amgo_lSQ00Go`mOY00?o^/kYok??k_nccnh00onccnhEooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgooooo
o`0002cooooo000hooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0A
ooooo`?o00000oooool00ol0003oooooooooo`0`ooooo`OoSF6J1?n=HY/4oheRW0?oSF>M1?n=IIl5
ohiWXPCoSV^U00CoSfnYoiYbYOnJLZGoVW:U1?nKMjT5oi]j[P?oVWjc00?oXX:aoib1]OnLPKD00_nL
PKD5oiIo^0CoTGbi2?n>NkT5oi1l^@;oUH2j0_nKQ[`4oj6<_PKoYY?200CoZi_7okRZc?nhZ/co^:[<
1?ni/M82olG5f@?o`lOM00?o0000olWOj?o9gnP01?o3enT2okcMl0Co/lo^00?oYl_booooooooool0
5?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgo
EEEEooooool0000/ooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_ooooooV9RHoa0@400Aooooo`;o0000=oooool9oheQVPCoSF:K1?n=HY`4oheSW@?oSFFO1On>Ij83
ohi[Y@03oiQ_X_nJLZGoVW:U00?oVW:U0onKMjT5oi]j[P04oiYn/onRP[7oXX:aoj:2/@GoW86e1?nF
OkP4oi5l^@WoSW^i0_n@O;T2oiB0^`GoVhJl1?nQS;h4ojJC`P03ok>Sb?nhZ/co^:[<00;o^:[<0oni
/M84olG5f@03ol?7gOo9gnSo000000?obMoX00?o`mOYokcMl?nlgO000onlgO000onccnkoYl_bojO;
lP02ojO;lQKooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oMgMgolc<c?l00000;?ooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`03_ooool3o`0003Gooooo3On=HIX4oheRV`CoSF:L1?n=Hid4oheUW`Co
SVNR00CoSV^UoiQ_X_nHKj;oV6nR1OnJLZD3oi]gZ@CoVgZ^00?oY82]oj:2/OnRP[400onRP[44oib1
]@GoUWnh1?nAO;T6ohik^@;oT7fk1?nDP;/5oi^6_0CoXHbn0onVTl83ok>Sb0Co^:[<00?o^K7BolG5
fOo5aMT00_o5aMT2oloTiP04olWOj?l0003obMoXolWOj0;oa>_`1?nlgO02ojoLm`GoYl_b5?ooool2
o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002cooooo001I
ooooo`?o0000=?ooool@oheQVPCoSF:K1?n=HY`4oheSW@CoSFFO0on>Ij800onFK9ooV6nRoiQ_XP03
oiQ_XPCoVW:U1?nKMjT2oi]j[P;oY82]1OnRP[44oib1]@GoUWnh1?nAO;T2ohik^@;oSWbl1?n@OK/5
oiB0^`CoVhJl1OnQS;h00onVTl;o/j?8ok>Sb002ok>Sb0Co^:[<00Coa/7EolG5fOo5aMWoaLGI1?o?
i>H00ol0003oa>_`olC[l003olC[l003okcMl?n_g?Oo[mcg00?o[mcg0_nWbo82oiW3mA?ooooo00Co
0000oooooooooooo00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?oo
ool0:oooool005Kooooo0ol00003ooooo`03o`000?oooooooooo02kooooo00?oSV:JoheQV_n=HIX0
4?n=HIX4oheRV`CoSF:L1?n=Hid4oheUW`04ohiWX_nFK9ooUVbOoiI/W`GoV6nR1?nJLZD4oi]gZ@03
oi]j[_nTP:goY82]00;oY82]1?nRP[45oib1]@?oUWnh00?oVHBkoi5o_?nAOk`00_nAOk`4ohil_0Go
T7fk1?nDP;/5oi^6_0?oXHbn00?o[9_5ok>Sb?ncXlP00oncXlP3okRZc0?oa/7E00?oaLGIoloTi_o?
i>H00_o?i>H00oo9mNco0000olC[l003olC[l0?o]>gg0_n_g?L2oigCn`GoVL?e5_ooool00ol0003o
ooooooooo`10ooooo`00E?ooool2o`0003Gooooo0on>HYXCoheQVP?oSF:K1?n=HY`4oheSW@?oSFFO
00?oU6VNoiI/WonFK9l00_nFK9l5oiQ_XPCoVW:U1?nKMjT5ojB0[@GoXX:a1?nLPKD01?nFOkSoVHBk
oiV4^onIQ;/5oi5o_0CoSWbl1?n@OK/4oiB0^`GoVhJl00?oXHbnojbKaOn/VlD00_n/VlD5ok>Sb003
okRZc?o6`MGoa/7E00;oa/7E00CoeNKSoloTi_o?i>KocnCV0_o9mN`00ol0003obOG/olC[l004okC]
m`03oioTo?nMdo_oWM?k00?oWM?k1?nI`oDFooooo`03o`000?oooooooooo043ooooo001Aooooo`?o
0000=?ooool6ohiRVQ?oSF6J0on=HY/5oheRW0?oSF>M00CoSFFOoiAYW_nDJIkoU6VN1OnFK9l4oiQ_
XPGoVW:U0_nKMjT00onUOZWoY82]ojB0[@03ojB0[@GoXX:a0_nLPKD2oj:8^@GoVHBk1?nAOk`4ohil
_0CoT7fk1OnDP;/3oi^6_003ojBCa?n/VlGo[9_500?o[9_51?ncXlP00oo3^];oa/7EolK1e@02olK1
e@?oeNKS00GocnCVolWek?o9mNcobOG/o`000003ok?ik003okC]monOi?coWnCl00;oWnCl0_nMdo/2
ohg3n@GoSKWd5_ooool00ol0003oooooooooo`0oooooo`00C_ooool5o`0003;ooooo2On>HYXCoheQ
VPCoSF:K1?n=HY`2oheSW@03oi9WWOnDJIkoU6VN00;oU6VN1OnFK9l4oiQ_XPGoVW:U00CoVgNYojEn
ZOnUOZWoYGjY1?nTP:d4oj:2/@03oj^<]OnRR;WoXXRi00?oXXRi1?nIQ;/4oi5o_0CoSWbl1On@OK/4
oiB0^`03oi^6_?nTTlCoY9?400;oY9?41?n/VlD3ok>Sb0?o`k[B0_o6`MD3omGVh`?oc__S00?obOG/
ok?ik?l000000_ncnN`2oiW`lP;oWnCl0on=dOh4ohg3n@GoSKWd5_ooool00ol0003oooooooooo`0n
ooooo`00C?ooool2o`0000Gooooo00?o0000ooooooooool0;_ooool:ohiRVQ?oSF6J1?n=HY/4oheR
W003oheSWOnBIigoTVNM00GoU6VN1?nFK9l5oiQ_XP?oVW:U00?oY7ZVojEnZOnUOZT00_nUOZT5ojB0
[@;oXX:a0_n[S;D5oj:8^@CoVHBk1OnAOk`4ohil_0CoT7fk0_nDP;/2oiV<a0GoY9?41On/VlD00onc
XlSo`k[Bol>jdP02ol>jdP04olK1eOoEi^?oeNKSomGVh`?oc__S0on/nM<00ol0003oVO3boiW`lP04
ohSOo@CoSM7n1?n=`oT2ohfim0;oQk3a5_ooool00ol0003oooooooooo`0nooooo`00BOooool3o`00
03Gooooo0_n?HiX;ohiRVQ?oSF6J1?n=HY/3oheRW004oi5UW?nBIigoTVNMoi9WW@GoU6VN1?nFK9l5
oiQ_XP;oVW:U0_nTNZH4ojEnZ@GoY82]00?oXX:aoj^<]On[S;D00_n[S;D4oj:8^@GoVHBk1?nAOk`4
ohil_0;oT7fk0_nBR<D5oiV<a0CoY9?41?n/VlD00onk/]7o`k[Bol>jdP03ol>jdP;oe>KS00CoeNKS
olkkhoo>nn?oc__S0on/nM<01?n8jlooMn?Uo`000?mghnD2ohSOo@;oPl;l1On4^?L4ohFbl`CoQk3a
5?ooool3o`0003oooooo000Rooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08?ooool2o`0003Gooooo
00?oSf>KohmSV_n?HiX00_n?HiX;ohiRVQ?oSF6J1?n=HY/01?n=HYcoTFFLoi5UW?nAII`4oi9WW@Co
U6VN1?nFK9l5oiQ_XP03oiYbYOnTNZKoY7ZV00;oY7ZV0onUOZT5ojB0[@GoZhbe1OnRR;T4oiV4^`;o
TGnl0_nAS</4ohf7b0GoTXS51?nIS<@5ojBCa003ojbKaOnk/]7o^k;A00;o^k;A0oo3^]83omCVh`;o
bokO00?oc__Sojcidon/nM<00_m@b[82ogOSi@03o`000?mmd?ooOM3o00CoPl;l1On4^?L4ohFbl`Co
Qk3a5Oooool00ol0003oooooooooo`0mooooo`008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01go
oooo0ol00002ooooo`03o`000?oooooooooo037ooooo0_n?Hi/4ohmSVPcoSV:J4_n=HIX2oheRV`;o
T6BK1?nAII`4oi9WW@CoU6VN1OnFK9l3oiQ_XP03oj5gXonTNZKoY7ZV00?oY7ZV0onUOZT4ojB0[@03
ojn</On[S;GoZhbe00?oZhbe1OnRR;T2oiV4^`;oWIK<1OnAS</4ohf7b0CoTXS51?nIS<@4ojBCa003
ok2Zd_nk/]7o^k;A00Co^k;A00Co`k[BomCVhooDi^?oe>KS0_o;o]l2oi;Z]0;oD<Zb1?mafOP01?l0
003oOM3oogg@oommd?l4oh?2o0;oQ;Sg0_n5X>D4ohNTi`GoRJ[[5Oooool00ol0003oooooooooo`0l
ooooo`008_ooool01Ol@413ooooooooooooooooo410@01_ooooo0_l0000fooooo`;oT6BK0on?Hi/4
ohmSVPcoSV:J4On=HIX00on?Hi_oT6BKoi1TV`02oi1TV`GoTFFL0onBIid4oiAYWPGoUVbO0_nHKj82
oj5gX`GoY7ZV1?nUOZT2ojB0[@?o[hba1On[S;D3oj:8^@03ojbQbonMU/coWIK<00?oWIK<1?nAS</4
ohf7b0CoTXS51OnIS<@00onTTlCo/:[Bok2ZdP02ok2ZdPCo^k;A00CocN7VomCVhooDi^?oe>KS0_o;
o]l00onBj[CoH=OOof3Gg`02ohjdl0CoQZS[00Co0000oh>Rion3X^OoPj;W1?n5Wn@5ohFPi@CoQjCW
1On9Z^/Eooooo`03o`000?oooooooooo03_ooooo000Rooooo`05o`000?ooooooooooooooool00000
6?ooool3o`0003Gooooo00?oT6FLoi1TVon@I9/00_n@I9/4ohmSV`?oSf>J3?n>HYX@oheQVP;oSf>K
1?n@I9/5oi5UW0?oTVNM1?nDJIh5oiI/W`03oiQ_X_nQMj?oXGNS00;oXGNS1?nTNZH4ojEnZ@03ojB0
[On_S;7o[hba00;o[hba1On[S;D00onRR;Wo[:7;ojbQb`02ojbQb`CoWIK<1?nAS</4ohf7b0GoTXS5
0_nIS<@2oj2Oe0Go/:[B0onk/]43olgQiP03omCVhoo;o]oobokO00?oU;gc1?n>]?03ohJXj`03o`00
0?n3X^OoPj;W00;oPj;W1?n5Wn@4ohFPi@GoQjCW0_n9Z^/2oiB]iaGooooo00?o0000ooooooooool0
>oooool002;ooooo00Go0000ooooooooooooooooo`00000Fooooo`?o0000=_ooool2oi1UW0CoT6BK
1?n?Hi/3ohmSVPcoSV:J3On=HIX2ohiSV`?oSf>K1On@I9/4oi5UW0?oTVNM1OnDJIh3oiI/W`03oiic
X_nQMj?oXGNS00?oXGNS1?nTNZH4ojEnZ@Go[hba1?n[S;D00onlZLOo[:7;ojbQb`03ojbQb`CoWIK<
1OnAS</4ohf7b0;oTXS50_nCV=D5oj2Oe0Go/:[B00?o^k;AolgQi_o=hNH00_o=hNH00oo3o]ooL]>D
oiBml`04oiBml`CoS[C`0_n6Z>/00ol0003oQZS[oh>Ri`03oh>Ri`CoQIoT1?n5X>D2ohNTi`;oT:7P
1OnD[NLEooooo`03o`000?oooooooooo03[ooooo000Rooooo`05oa0@4?ooooooooooooooool@4100
4oooool3o`0000;ooooo00?o0000ooooooooool0<Oooool2oi5WW@?oT6FL1?n@I9/4ohmSV`?oSf>J
3?n>HYX9oheQVPKoSV>K1?n?Hi/4oi1TV`CoTFFL0onBIid5oiAYWP;oUVbO0_nNLj85oj5gX`GoY7ZV
0_nUOZT2ok:<[PGo[hba0_n[S;D3okbYa`Co[:7;1OnMU/`2oi6<b`;oRiSJ1?n8TmP5oi>He@CoX9oD
1?n`Z]82ol3Hj`?ocN7V00Co`okOog;CU?nN`o;oW/?b0_nD_O<2oi:?c@CoS8c>0_n7R]000ol0003o
Qh[@ohF<dP03ohF<dPCoRI7E1?n<V=X5oi2Qh0CoU:gW5_ooool00ol0003oooooooooo`0iooooo`00
8_ooool01OmgMgOoV9RHoooooonHV9SoMgMg013ooooo0ol0000fooooo`03oi9YWonAIigoTFNM00;o
TFNM1?n@II`3oi1TV`CoSf>K1?n?HiX;ohiRVPKoSF6J2On>Hi/4ohmSV`CoT6BK1?nAII`3oi9WW@Go
U6VN00CoUVbOoiicX_nNLj;oWW>R1OnQMj<5ojAjYP04ojEnZOnbS:ko/Xb^ok:<[PGo[hba00?oZhbe
okbYaonlZLL00_nlZLL5ojbQb`;oWIK<0_nIY=d5oh^HfPCoR9?H1?nCV=D5oj2Oe003ok2Zd_o0f>_o
`=S[00?o`=S[00CocN7Vol?ngonN`o;oW/?b0_nKTlX5oi:?c@CoS8c>00CoQh[@o`000?n7R]3oQh[@
1?n5S=84ohVAe@CoS9SJ1On@XN02oiB]i`;oXK;T5?ooool2o`0003_ooooo000Rooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03_ooool2o`0003Sooooo0_nBJIl4oi5WW@CoT6FL0on@I9/4ohmSV`CoSf>J
2on>HYX5oheQVP[oSV>K1?n?Hi/4oi1TV`CoTFFL1?nBIid3oiAYWP03oi]`XOnNLj;oWW>R00?oWW>R
1?nQMj<5ojAjYPGo/Xb^1?n_S;46okbYa`;o[:7;0_n^/m`5oiVTg@CoRiSJ1?n8TmP4oi>He@CoX9oD
0_nWb?04ol3Hj`03ok?ji_nQ_nkoX9?700GoVi?:1?nBSld4ohb<cP04ohN:d?l0003oQh[@ohN:d0Co
QHcB1?n9TMD5ohbHfP;oT:7P0_nKY=`5oj6bi1Gooooo00?o0000ooooooooool0>?ooool003;ooooo
1Ol0000eooooo`;oU6bR0onBJIl4oi5WW@CoT6FL0on@I9/4ohmSV`CoSf>J2on>HYX2oheQVPgoSV>K
1?n?Hi/4oi1TV`CoTFFL1?nBIid2oiAYWP;oVg2Q1OnNLj85oj5gX`?oY7ZV00?o/HV[ok:<[_nbS:h0
0onbS:h4ojn</@03olF^`onlZLOo_:W700;o_:W700?oa<3Fojjcg?n^/m`00on^/m`4oiVTg@CoRiSJ
1On8TmP4oi>He@03oj2Oe?nWb?3oYlS`00?oYlS`00?o`=S[ok?ji_ncn^H01?nPTlL4oi^CbPCoTXo=
1?n<S<h2o`0000?oQh[@1?n5S=84ohVAe@;oS9SJ0_nFV=@5oi^Tg0?oXK;T00?o[K_Tooooooooool0
5?ooool00ol0003oooooooooo`0gooooo`00<?ooool2o`0003Oooooo00?oUW2UoiA/X_nDK:800_nD
K:84oi9YW`?oTFNM1?n@II`4oi1TV`?oSf>K1?n?HiX9ohiRVQ7oSV>K1?n?Hi/4oi1TV`GoTFFL0onB
Iid01?nDJIkoVg2Qoi]`XOnKL:45oiicXPGoXGNS0_nTNZH3ok69Z`Co/Xb^0on_S;42olF^``?o_:W7
0oo4`=H5ojjcg0CoVJCM1?n;V=X2ohRCf0;oOJO^1OnB]o04ojO8l0;oU>k`0onRTL<3oj2Ca`GoVi?:
1?nBSld3o`000003ohb<c_l0003oQh[@00;oS7fn1?n<Pl@4oi6=c0GoUYSD1?nKY=`00onQ/^Co[K_T
ojfki002ojfki1Gooooo00?o0000ooooooooool0=oooool002gooooo0ol0000hooooo`;oUW2U1?nD
K:84oi9YW`?oTFNM1?n@II`4oi1TV`CoSf>K0on?HiX6ohiRVQCoSV>K1?n?Hi/4oi1TV`GoTFFL0_nB
Iid00onIKZ3oVg2Qoi]`X@03oi]`X@CoWW>R1OnQMj<00onTNZKo/HV[ok69Z`02ok69Z`Go/Xb^00?o
[hbaolF^`oo5[/<00_o5[/<00onlZLOoa<3FolC0eP02olC0ePCo[[?L00?oZ;cXoi2^jon@[^/00_n@
[^/5ognUk0CoOJO^1OnB]o000onWb?3oU>k`oiC^l005oj:A``CoX9?70_nKTlX2oiMl]004oi5j]_l0
003o0000o`0000CoSW^j00?oS7fno`000?n<OKh00_n<OKh4ohb3a0?oTHg<1OnFV=@2oi^Tg0;oZ;3M
1_n]^n@Eooooo`03o`000?oooooooooo03Kooooo000/ooooo`;o0000>?ooool01?nIMJWoUW2UoiI`
YOnFL:D4oiA/XPCoTVVO1?nAIid3oi1UW0CoT6BK1?n?Hi/3ohmSVPGoSV:J5_n>Hi/3ohmSV`GoT6BK
1?nAII`00onBIigoVFjPoiU^X005oi]`X@CoWW>R1OnQMj<5ok69Z`Go/Xb^1Oo5[/<6olC0eP03ojjc
g?nX_>SoZ;cX00;oZ;cX1?n@[^/5ognUk0CoOJO^0_nB]o03ogOMmP?oXXfn1?nRTL<3oj2Ca`03oi]n
/_nGO;CoUgbd00?o00001?nAN[H4ohik^P04oham__l0003oS7fnoham_PCoS8?41?nASL`3oiJHe003
ojBUe_nX/=goZ;3M00?oZ;3M1?n]^n@2okG5iQGooooo00?o0000ooooooooool0=Oooool002cooooo
0ol0000fooooo`;oVGFY1?nFL:D3oiA/XPCoTVVO1?nAIid3oi1UW0CoT6BK1?n?Hi/3ohmSVP;oSV:J
6On>Hi/4ohmSV`CoT6BK0onAII`01?nFK:3oVFjPoiU^X?nIKZ05oi]`X@GoWW>R0onQMj<00on^QZ[o
/HV[ok69Z`03ok69Z`Co/Xb^0_o;/L04olF^``03om;:d_o4`=Koa<3F00;oa<3F0_o3bn05ojRlj0Co
T:k[0_moYN`4odo2mPCoDLGd00?oMmgfoj68^_nRSKh00onRSKh5oj:A``03oj2CaonKO[;o000000;o
00000onGO;@4oi5j]PCoSW^j0_n<OKh00ol0003oS7fnohb3a003ohb3a0CoTHg<00?oUYSDojBUe_nT
YMH00_nTYMH5ojR`g@03ojfki?neaNKo]LGV00?o]LGV5?ooool00ol0003oooooooooo`0eooooo`00
;?ooool01?l0003oooooo`000?l0000booooo`;oW7^^1?nIMJT3oiI`Y@?oU6bR1?nBJIl4oi5WW@Co
T6FL0on@I9/4ohmSV`;oSf>J7?n>Hi/4ohmSV`CoT6BK00CoTFFLoiI/X?nFK:3oUVbP1?nIKZ04oi]`
X@GoWW>R0_nQMj<3ojj6ZPGo/HV[0_nbS:h3ol^a`0?oaJk30ooBb]800oo4`=Ko`l_Pol?;h003ol?;
h0;oZ;cX1?n5i?L4ofC?n@;oCl;f0_nIS/H00onPQ;KoXHRjoj68^P03oj68^PCoXXfn1?nRTL<3o`00
00;oVgjb1?nGO;@4oi5j]PCoSW^j0_n<OKh00ol0003oS7fnoham_P04ohb3a0;oTHg<00?oWiW?ojBU
e_nTYMH00onTYMH4ojR`g@;o]<7T1?neaNH00ongb>Soooooooooo`0Aooooo`03o`000?oooooo0000
00Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<01Wooooo000/ooooo`;o00000_ooool00ol0003oooooooooo`0/ooooo`03oj23]?nLNjko
W7^^00;oW7^^1?nIMJT3oiI`Y@CoU6bR0onBJIl4oi5WW@CoT6FL0on@I9/3ohmSVaooSV>K1?n?Hi/3
oi1TV`03oiAZX?nFK:3oUVbP00;oUVbP1?nIKZ04oi]`X@GoWW>R00?oXGNSojj6Z_n^QZX00_n^QZX5
ok69Z`03ok:<[_o;/L3obk7000?obk7000?oaJk3om;:d_oBb]800_oBb]85ol?;h0?oZOOY0_n5i?L3
oi^3^@CoW8Vo00?oXH:boj24]_nPQ;H00_nPQ;H4oj68^PGoXXfn0ol000000onOPK;oVgjboi]n/P02
oi]n/PCoUgbd1OnAN[H4ohik^P;oS7fn00Co0000oham__n<PlCoS8?40_nIS/H4oinIc`GoY:GF00?o
Z;3MokC1i?nd`N@00ond`N@00oneaNKo]lSXokO8j002okO8j1Gooooo00?o0000ooooooooool01Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B406Oooool002_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Zooooo`;oX8>d
1?nLNjh4oiUeZ@?oUW2U1?nDK:83oi9YW`CoTFNM1?n@II`3oi1TV`03ohmSVon>Hi_oSV>K01ooSV>K
1?n?Hi/01?n@I9_oU6ZPoiAZX?nDJZ04oiI/X0CoVFjP1?nKL:45oiicXPGo[XJZ1OnaRJ/6ol^a`0Go
d/[B00CodmWMol?;h?o3bn3o`l_P0onYmnT2oiQm]0GoVh>i00CoW8Vooj62/_nQP[;oXH:b1?nPQ;H5
oj68^P;oXXfn0_l00005oin1/P?oVgjb1OnGO;@4oi5j]PCoSW^j0_n<OKh00onGQ[oo0000oiV>aP03
oiV>aPGoWiW?0_nTYMH3ok:kh@Co]<7T00?o^<_XokO8j?ngb>P00ongb>PEooooo`03o`000?oooooo
oooo00Gooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000
6Oooool002_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Wooooo`03oj>;^_nP
PkCoX8>d00;oX8>d0onLNjh4oiUeZ@?oUW2U1?nDK:84oi9YW`?oTFNM1?n@II`2oi1TVb?oSV>K0on?
Hi/00onBJJ3oU6ZPoiAZX002oiAZX0CoUVbP1?nIKZ05oi]`X@?oWW>R00?oZh>Zojj6Z_n^QZX00on^
QZX4ok69Z`;ocK:o1?o;/L02omcBc`?od/[B0ooCfMd01?o3bn3oZOOYojWgjOnAM:l4oiQm]0?oVh>i
00?oX7n_oj62/_nQP[800onQP[83oj24]PCoXHRj0ol00002oj:2/@GoWh6b0onKO[85oiMl]0;oTGZf
0_nGOKD4oiJ0^@?oUhJo00?o0000oiN6_onIS/H00onIS/H3oinIc`03ojncfonb^n7o/[_Q00Co/[_Q
00?o]<7TokS;j?nhbnP00_nhbnP3okO8j0;o]<WZ5Oooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q01Wooooo000[ooooo`?o
00001Oooool00ol0003oooooooooo`0Tooooo`?oXh^j1?nPPk@4oiak[P?oVGFY1?nFL:D3oiA/XPCo
TVVO0onAIid2oi1UW0;oSF>L9On>Hi/01?n?Hi_oTVVPoi9YX?nBJJ05oiAZX0?oUVbP1?nIKZ05oi]`
X@;oWW>R0on[PjX5ojj6ZP;o/HV[0oo=/[l3ol^a`0Cog=;?00Cod/[Bom?IgOoCfMgodmWM0_nXn<l3
oi5d[`CoV7fd00CoVh>ioj1o[onPOjooX7n_1OnQP[84oj24]P?o000000?oXh:`oj:2/OnRP[400onR
P[44oin1/PCoVgjb0onGO;@00onJO;;oUgfeoiMm]@02oiMm]@GoUX2i0onGQ[l00ol0003oVHk6oiV>
aP02oiV>aP03oinIcon_/m_o[k?K00;o[k?K1?nb^n42ok[;i`Co^<_X00?o]lSXokC9j_ndbNX00ond
bNXEooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`06Oooool002_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Qooooo`03ojNB`?nSRk[oXh^j00?oXh^j0onPPk@4oiak[PCoVGFY0onFL:D3oiA/XPCoTVVO
0_nAIid00on<HicoSF>LoheSW002oheSW2CoSV>K00?oTFRPoi9YX?nBJJ000_nBJJ05oiAZX0CoUVbP
0onIKZ05oi]`X@03oiicX_n[Pj[oZh>Z00;oZh>Z1On^QZX00onaRJ_ocK:oolfb_`03olfb_`03ol^a
`?oLd/oog=;?00;og=;?0ooNj=X00ooCfMgoZ?S?ojShc`05oi5d[`;oV7fd00?oWWb]oj1o[onPOjl0
0onPOjl4oj62/P05oj24]_l0003o0000o`000?nQR;X00onSP[05oj:2/@GoWh6b0onKO[801?nGO;Co
VWbboiYl/_nJO;85oiMm]@CoUX2i1?nGQ[l01?l0003oVHk6oiV>a_n[Ym<6ojncf`03ok:khOnjbnOo
^/_W00?o^/_W0_nhbnP2okO@k0Co]<WZ00?o/<S/ooooooooool04oooool00ol0003oooooooooo`03
ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Kooooo`00:oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01oooooo0onWT/04oj>;^P?oX8>d1?nLNjh4
oiUeZ@?oUW2U0onDK:82oi9YW`;oS6>N0on<Hi`4oheSW23oSV>K0_n@J:03oi5XX0GoTVVP1?nDJZ04
oiI/X0CoVFjP0onKL:400onWP:[oZh>Zoj^3ZP03oj^3ZPGo[XJZ1_o=/[l01?oQgM7og=;?omcBcooL
d/l4omkXfP03ohOOWon9JZWoRFZY00GoTGB_00?oV7fdoiil[OnNO:d01OnPOjl2oj62/P?o00000_nP
Q;H00onTPk3oXh:`oj>2/003oj>2/0CoXX:a1OnOPK82oi]n/P03oiam/?nJO;;oVWbb00?oVWbb1?nG
OKD4oiJ0^@GoUhJo00Co0000oj^Wdon[Ym?oZjOC1?n_/m/2ok_:iPCo^/_W00?o^]S_okO@k?ngd>`0
0ongd>`00ondbN[o/<S/ok38k002ok38k1?ooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool00ooMgMgo410@oiRHV00Kooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01cooooo00?oZIO3ojNB`?nWT/000_nWT/04oj>;^PCoX8>d0onLNjh4oiUeZ@;o
UW2U00CoRfJRoh]TWon;I9ooRfBO1?n<Hih3ohaSW0CoSF>L7On>Hi/5oi1XX0?oTFRP1OnBJJ04oiAZ
X0CoUVbP1?nIKZ02oi]`X@;oYh2Z1On[PjX5ojj6ZP03olfe`oo=/[oocK:o00?ocK:o0_oQgM400ooL
d/oog^SJomkXfP02omkXfPGoRFZY0onAM:l00onKMj[oWWb]oiil[@02oiil[@?oX7n_0ol00003oj62
/P03oj24]_nTPk3oY8>`00GoXh:`1OnRP[43oin1/P04oimn[onLOK3oW7f`oiam/0GoVWbb1?nGOKD5
oiJ0^@;oUhJo0_nXWL/00ol0003oZjOCoj^Wd`02oj^Wd`03ojncfonkb^Ko^l[V00?o^l[V00?o^/_W
ok[Hkonjf>l00_njf>l2okO@k0?o//o_1On`b>`Eooooo`09o`000?ooooooooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@6Oooool0013ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`?o00002_ooool00ol0
003oooooooooo`0Iooooo`CoZIO30onWT/05oj>;^P?oX8>d0onLNjh2oiUeZ@;oRfRU0on;IZ83oh]T
W`CoS6>N1?n<Hi`3oheSW1_oSV>K1on@J:04oi5XX0CoTVVP1?nDJZ04oiI/X0CoVFjP00?oVg2QojN0
Z_nWP:X00_nWP:X4oj^3ZPCo[XJZ0_o=]L<4olfb_`?ohMgA00Cog?_IomkXf_oNj=[og^SJ0_n5Hj@4
ohUZZ@04oi5d[onKMj[oVgNZoi]gZPCoWWb]0ol00002oj1o[`?oXH:b00?oYHB`ojB3/?nTPk000_nT
Pk04oj>2/0GoXX:a00CoWh6boimn[onOOZooWgj_1?nLOK04oiYl/PGoUgfe0onFP;T00onUU<CoZ9g;
ojRMb`03ojRMb`04o`000?n[Ym?oZjOCokg7h`Go^l[V00?o_^;aok[Hkonjf>l00_njf>l2ok?Hl`Go
//o_0_n`b>`2oj_5kAGooooo00?o0000ooooooooool0;oooool000Sooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Fooooo`03oj^IaOnYUl?oZIO300?oZIO31?nWT/04oj>;^P;oX8>d00CoSW:_oha]Z_n<
KJ[oS6fZ1?n;J:D3oh]VXP?oRfBO1?n<Hih4ohaSW0?oSF>L6On>Hi/9oi1XX0CoTFRP1?nBJJ04oiAZ
X0CoUVbP0onIKZ000onSOZ_oYh2ZojN0ZP03ojN0ZPGoZh>Z0_n^QZX3olfe``?ocK:o0ooQgM43omck
f@04omkXf_n5HjCoQF>TohESY0;oRFZY0_nFLJH5oi]gZP03oiil[Ol0003o000000GoX7n_00CoXH:b
ojF4/?nUQ;3oYHB`1?nTPk05oj>2/0?oXX:a00?oXH2_oimn[onOOZl00onOOZl3oiam/0CoVWbb1OnG
OKD00onFP;WoYIC4ojFDa002ojFDa0CoZ9g;00?oZjOCo`000?nman<00_nman<3ok_:iP?o_^;a00?o
^]S_ok?Hloncf?<00oncf?<2ok;?k`;oZl[`1On[aNdEooooo`03o`000?oooooooooo02kooooo000@
ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00006ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool04_ooool00on[VLCoZiW5oj^Ia@02oj^Ia@CoZIO3
1?nWT/02oj>;^P;oTgVd0on>LZl3oha]ZPCoRfRU0on;IZ84oh]TW`?oS6>N1?n<Hi`3oheSW1GoSV>K
3On@J:04oi5XX0CoTVVP1?nDJZ04oiI/X004oiU^X?nSOZ_oXgj[oj=nZ`GoYh2Z1On[PjX00on^QZ[o
cKG3olfe``03olfe``04olfb_ooQgM7ohMgAon7Md@?og?_I0_n5H9l2ohESY003oi=/XonFLJKoUW6V
00;oUW6V0onKMjX3o`0000;oWWb]1?nPOjl00onVQ;3oYHB`ojF4/003ojF4/0?oY8>`1OnSP[001?nR
P[7oXH2_oj60[onQP:l5oimn[`?oW7f`1OnJO;83oiMm]@03oj>=_OnUU<CoYIC400?oYIC41?nXWL/0
0onman?o0000okg7h`03okg7h`04ok_:i_nnh_7o_^;aokkRl@;o/nCg1?ncf?<00onZdOCoZl[`oj_:
l003oj_:l0;oZlG]0onV`nhEooooo`03o`000?oooooooooo02gooooo000@ooooo`05o`000?oooooo
ooooooooool000002oooool01?oMgMgoEEEEooooool00006ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool04?ooool3oj^Ia0?oZiW51OnYUl<2ojNB`003oiR0^?nCNKCoTgVd00;oTgVd
1?n>LZl3oha]ZP?oRfRU0on;IZ84oh]TW`?oS6>N1?n<Hi`4oheSW17oSV>K00?oTFRPoi1XX?n@J:00
3On@J:04oi5XX0CoTVVP1OnDJZ03oiI/X0GoXgj[1?nWP:X4oj^3ZP03ol^hb?o=]L?ocKG300CocKG3
0_oQkMT00ooQgM7og?_Iomckf@03ohEPW`04oi9YWonCK:?oTfbSoi=/X`CoUW6V0ol00002oi]gZPCo
WWb]0_nPOjl2ojJ4/0GoYHB`1?nTPk04oj>2/0GoXH2_1?nOOZl4oiam/0CoVWbb00?oUgfeoj>=_OnS
SKd00_nSSKd4ojFDa0?oZ9g;0_nma=l01?nman?o0000okg7honman<3ol7^lP03okkRlOnci?Oo/nCg
00;o/nCg00?o/mScoj[Am?nZdO@00_nZdO@3oj_:l0;oYLOa1OnV`nhDooooo`03o`000?oooooooooo
02gooooo000@ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000006oooo
o`;o00003oooool2o`0000kooooo00?oZiS3oj^Ia?n[VL@00_n[VL@4oj^Ia@;oZIO30_nNQ[X3oiR0
^0CoTgVd1?n>LZl3oha]ZP?oRfRU0on;IZ84oh]TW`CoS6>N0on<Hi`4oheSW0ooSV>K0onAJ:0@oi1X
X0?oTFRP1OnBJJ04oiAZX0;oUVbP00?oWW^/oj=nZonSOZ/00onSOZ/5ojN0ZP;oZh>Z0oo;^<P4olfe
``?ohNgI00CoYo>ioheSW?n=HicoQF2O0onBJIl4oi=/X`?o000000?oUW6Voi]gZ_nKMjX00_nKMjX4
oiil[@03oj1o[onVQ;3oYXB`00;oYXB`1?nUQ;04ojB3/0CoXh:`1OnQP:l4oimn[`CoW7f`0_nJO;82
oj:9^@GoXhfm1OnUU<@00onXWL_o_LCOokg4g`02okg4g`03okg7hol0003o`Nkb00;o`Nkb0_n]l?H2
ok?Tm`?oYm[j1OnZdO@00on[b_3oYLOaojG7l@02ojG7l@;oY/?^0_nR`NlEooooo`03o`000?oooooo
oooo02cooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000006
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02Oooool4oj^H``?oZiW40on[VLD0
0onSR[[oWXJjoij6^P03oij6^P?oV82h0onCNK@4ohib[`?oS6fZ1?n;J:D3oh]VXP?oRfBO1?n<Hih3
ohaSW0CoSF>L3On>Hi/00on@J:3oTFRPoi5XX002oi5XX13oT6RP0onAJ:05oi9YX0CoU6ZP00CoUVbP
oiik[?nNNjcoWW^/1?nSOZ/5ojN0ZP03oj^3Z_o;^<SobkS800;obkS80oo=]L<3on7]f@04oiIWV_n=
HicoSF>LoiU/W@CoTVVO00CoTfbSo`000?l0003o00001?nFLJH5oi]gZP;oWWb]00?oYXF`ojJ4/?nV
Q;000onVQ;04ojF4/0CoY8>`1OnSP[04oj60[`GoWgj_0_nLOK000onRQ[KoXXVioj:9^@03oj:9^@Co
Xhfm1?nUU<@00onm`=co_LCOokg4g`02okg4g`?o^oS]00Co0000ojg`m_n]l?Ko[O3f0_nMi?d5ojOJ
nP;oZ]7d0_nRc?H4ojG7l@03oj34l_nR`NooX/7_00?oX/7_4oooool2o`0002kooooo000@ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01_ooool6oj^H``CoZiW400CoZiW5oj>:^_nSR[[oXhZj1?nNQ[X3
oiR0^0CoTgVd0on>LZl3oha]ZPCoRfRU0on;IZ83oh]TW`CoS6>N0on<Hi`4oheSW0WoSV>K1On@J:05
oi5XX0ooT6RP1?nAJ:04oi9YX0;oU6ZP0_nKNZd4oiik[0CoXgj[1OnWP:X6ol^hb004olfe`ooQkMWo
hNgIon7]f@;oUVNJ00?oSF>LoiU/WOnIK9d00_nBJIl3o`0000?oTfbS1?nFLJH5oi]gZP03oiil[OnV
QK3oYXF`00GoYXB`1OnUQ;02ojB3/003ojF4/OnSP[3oXh:`00?oXh:`1?nQP:l5oimn[`03oiam/?nR
Q[KoXXJf00GoXXVi1OnSSKd00onUU<Co_L3Lokg0g002okg0g003okg4gonkn>go^oS]00;o^oS]00?o
TO3So`000?n]l?H01OnMi?d2ojOJnP;oW=3j1OnRc?H00onUao7oX<Cboj34lP02oj34lPCoX/7_5Ooo
ool00ol0003oooooooooo`0[ooooo`00:Oooool2o`0001Cooooo00?o0000ooooooooool01?ooool7
oj^H``?oZiW400?oYHbjoj>:^_nSR[X00_nSR[X4oij6^P?oV82h1?nCNK@3ohib[`?oS6fZ1?n;J:D3
oh]VXP?oRfBO1?n<Hih4ohaSW0?oSF>L1_n>Hi/00on?Ij3oT6RPoi1XX005oi1XX0GoTFRP3on@J:04
oi5XX0?oTVVP00?oVGR^oi]j[OnKNZd00_nKNZd4oiik[0CoXgj[1?nWP:X2olJmd@CobkS80ooDoMd0
1?oQkMWoUVNJoiIWV_nFIiX2oiU/W@?o00000onBJIl3oi=/X`CoUW6V1?nKMjX00onVQ;3oYXF`ojJ5
/002ojJ5/0CoYXB`1OnUQ;001?nTPk3oYHBaojF4/OnUQ;44oj>2/0GoXH2_0onOOZl00onSQKGoXXJf
oj:6]P02oj:6]PCoXXVi1?nSSKd00onm_M[o_L3Lokg0g003okg0g0;oY?OH00Oo^oS]oi7`honAl>?o
TO3Soh?UmOl0003oPnGe00;oWNCm0onAe?h4oic@nP;oX/cf0onLaOD5oj34lP;oX/7_0_nN_>hEoooo
o`03o`000?oooooooooo02[ooooo000Yooooo`03o`000?oooooooooo01Cooooo00Go0000oooooooo
ooooooooojbH`P09oj^H``04oj^Ia?nUS;[oYHbjojF<^P?oXhZj1OnNQ[X3oiR0^0?oTgVd1?n>LZl3
oha]ZP?oRfRU0on;IZ84oh]TW`?oS6>N1?n<Hi`3oheSW0?oSV>K00CoSVJPohmWX?n?Ij3oSfNP2?n@
J:04oi5XX0ooT6RP1?nAJ:001?nBJJ3oVGR^oiUh[_nIN:h5oi]j[@?oWW^/1OnSOZ/2ojN0ZP?oa[gA
0oo;^<P3omCmg@05oiUXV?nFIi[oUVNJoiIWV_nPL9`00_l00002oiU/W@CoTVVO0onCK:<5oiIaYP;o
VgNZ0_nVQ;04ojJ5/0GoYXB`0onUQ;000onWQk;oYHBaojF4/@02ojF4/@CoXh:`1OnQP:l01?nOOZoo
XhFeoj>5]OnSQKD4oj:6]PGoXXVi00?oXhfmokfmf_nm_MX00_nm_MX3okg0g0;oY?OH00?oEL^Zoe;?
dom_c_h00_m_c_h2oh;Co`03o`000?n2doooP]?o00;oTMCn0_nA`OL5oiO5m`CoW<Ge0_nPa?82oifk
kPGoW[c^5?ooool00ol0003oooooooooo`0Zooooo`00:Oooool00ol0003oooooooooo`0Eooooo`03
o`000?n/V<;o[9S200;o[9S21on[V<<00onWSKWoYHbjojF<^P02ojF<^PCoXhZj1?nNQ[X3oiR0^0?o
TgVd1?n>LZl3oha]ZP?oRfRU0on;IZ84oh]TW`?oS6>N1?n<Hi`3oheSW004ohiSVon>IZ3oSVJPohiV
X0?oSfNP2?n@J:04oi5XX0ooT6RP0_nAJ:02oiMh[PGoVGR^1?nKNZd3oiik[0GoXgj[00?oYh2ZolJm
dOo6_M400oo6_M400oo;^<Soe?gMomCmg@03oiUXV004oiIWV_l0003o0000o`0000CoVFbM1?nBJIl4
oi=/X`CoUW6V00?oVgNZojJ4/?nVQ;000_nVQ;03ojJ5/0GoYXB`00CoYHB`ojN7/_nWQk;oYhNb1?nU
Q;45oj>2/0?oXH2_00?oXhJeoj>5]OnSQKD00onSQKD3oj:6]PCoXXVi00?o_;gJokfmf_nm_MX01?nm
_MX00onm`=coY?OHof37o003of37o0CoKlkn0_n2dol00ol0003oSK[eoi71m`04oi71m`;oUlGg0_nI
]N/4oi^ik@GoWK_^0_nN_>h3oinijaCooooo00?o0000ooooooooool0:Oooool002Wooooo00?o0000
ooooooooool05?ooool00on]V/?o[9S2ojbH`P03ojbH`PGoZiS31?nWSKT3ojF<^PCoXhZj0_nNQ[X2
oiMo^0?oSGRg0on5Kk<4ogiW[`?oO6>Z0on;J:D3oh]VXPCoRfBO0on<Hih2ohaSW0;oRVBP0on<IJ04
ohiVX0CoSfNP1on@J:04oi5XX0koT6RP00?oUWR_oiMh[_nGN:h00_nGN:h5oiUh[PCoVgZ]1?nNNj`3
oj=nZ`03ol;2foo6_M7oa[gA00?oa[gA0_nOm<T00onKJIOoVFRHoiUXV003o`0000?oX72L1?nIK9d4
oi9YW`CoTfbS0onFLJH00onUPjooYXB`ojJ4/003ojJ4/0CoYXF`0onVQ;000onYR[GoYhNbojN7/P03
ojN7/P?oYHBa1OnSP[001?nQP:ooXhJeoj>6]OnSQ[D5oj>5]@CoXXJf0_nRRKT3okbmfPCo_KgJ00?o
KMFTohjFeon>U]L01On<Y>@4oh^`k`04ohfjmOl0003oSK[eohfjm@;oTL7g0_nH[^H5oiVej`CoVkW]
0_nM^nh3oijdj0GoWkW[5?ooool00ol0003oooooooooo`0Xooooo`00:Oooool3o`0001?ooooo0on]
V/<4ojbH`P?oZiS31_nWSKT4ojF<^P;oXhZj00?oWXFhoiMo^?nGOkP00_nGOkP3oheh]`?oQFnc1?mn
Ijl3ogaSZP?oOV6W0on0H:@4ohAQXP?oQf:Q1?n:I:03ohaUX0CoSVJP1?n?Ij07oi1XX0CoTFRP3On@
J:02oiIh[`GoUgR^1?nIN:h4oi]j[@CoWW^/00?oXgj[ol;2foo2`]/00_o2`]/3olJmd@;oWoC900Co
VfVGo`000?l0003o00000_nIJ9P4oj1`W0CoVFbM1?nBJIl4oi=/X`04oiIaY_nUPjooYH>_ojF3[`Go
YXB`1?nVQK001?nVQ;3oZHZeojV:]OnYR[D5ojN7/PCoYHBa0onSP[000onUR;KoXhJeoj>6]@03oj>6
]@CoXhFe1?nRQ[H00onRRKWo_;gJokbmfP03okbmfP03okfmf_nBRlWoTX_900CoSYKG1On<Y>@4oh^`
k`03ohfjmOl0003oV:KO00GoV:kV1OnI]N/2oi^ik@03oij_i?nN]>SoW[CX00CoW[CX0_nO^N/2oj:i
jA?ooooo0_l0000Zooooo`00:Oooool00ol0003oooooooooo`0Aooooo`03ojnMaOn]V/?o[I[300;o
[I[31On/V<800on[V<?oYhfiojN=^@05ojN=^@CoYHbj00?oXhZjoij5^?nNQKP01OnGOkP3oheh]`?o
QFnc0omnIjl3ogaSZP?oOV6W0on0H:@4ohAQXP?oQf:Q1?n:I:03ohaUX0CoSVJP1?n?Ij07oi1XX0Go
TFRP2On@J:06oiIh[`CoUgR^1?nIN:h5oi]j[@;oWW^/0_njb>D5ol;2f`03olJmdOnOm<Wo000000;o
000000GoVfVGoiUXV?nIJ9SoVFRHoj=bV`04oj1`W0CoVFbM1OnBJIl3oi=/X`GoYH>_1?nVQ;04ojJ5
/0GoZHZe1?nWQk84ojF4/@04oj>2/?nUR;KoYHRfojF8]PGoXhJe1OnSQKD2oj:6]P;o_;oM1?nl_MX0
1?nDP[goTX_9oi:;bOnBRlT5ohjFe`;oS:CT0_nKULd4oiVMe`;oV:KO00?o0000oiRVgonH[^H01?nH
[^H2oiVej`;oWZWN1?nN[n@4oijdj003oj>diOnR^NWoX[WY00?oX[WY5?ooool00ol0003ooooooooo
o`0Wooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001Ooo
ool00ol0003oooooooooo`0Aooooo`?o[ig50on]V/<4ojbH`P03ojN>^_nWSKWoYhfi00OoYhfi0_nU
S;X00onSR;OoWXFhoij5^002oij5^0CoUgnh0on=N;L3ohE_/`?oOVN_0omlHjX4ogiQY`;oP62T1?n4
HJ83ohMRX@CoRVBP1?n<IJ03ohiVX0CoSfNP1on@J:05oi5XX0GoT6RP0_nFN;08oiIh[`CoUgR^1?nI
N:h5oi]j[@03oiik[?njb>Go^/SU00;o^/SU0oo2`]/3o`0000CoVfVG0_nIJ9P2oj=bV`CoX72L1?nI
K9d5oi9YW`;oTfbS00?oY86]ojF3[onUPjl00onUPjl5ojJ4/0;oYXF`00?oZhjhojV:]OnYR[D00onY
R[D5ojN7/P;oYHBa00?oYhbiojF8]_nUR;H00onUR;H4oj>6]@GoXhFe00?oXXJfokbogOnl_md00_nl
_md01?nl_M[oU8:moiB2_OnDP[d4oi:;b@;oSYKG0_nMS/<4oi^Ec@GoVIgG00CoV:KOo`000?nHY]oo
V:KO0_nH[^H2oijRf0GoWZWN1?nN[n@00onN]>SoXkCUoj>di@02oj>di@CoX[WY5Oooool00ol0003o
ooooooooo`0Vooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003oooooooooo`0?ooooo`03ok6Rb?n_WLGo[ig5
00;o[ig51?n]V/<00on/V<;oYhjjojN>^P02ojN>^PSoYhfi00CoYHbjoj>8]onSR;OoXhRg0onNQKP4
oiMo^0?oSGRg0on5Kk<4ogiW[`;oO6>Z1?mnHJL3oh1PY0?oQ66R1?n7HZ43ohYTX0CoS6FP1?n>IZ03
ohmWX0SoT6RP1?nAJ:02oi1XX003oiMi/?nFN;3oUWR`00;oUWR`2?nFN:l4oiMh[PGoVGR^0onKNZd0
0onacNko^/SUok[8i@03ok[8i@?o00000onIIiL4oi]YU`03oiUXV?nSLY_oXg:K00;oXg:K1?nPL9`4
oiU/W@CoTVVO00CoTfbSojB1[OnTPJgoY86]1?nUPjl5ojJ4/004ojJ5/?n[S[SoZhjhoj^>^0CoZHZe
1OnWQk800onUQ;7oYhbiojN<^@05ojF8]PGoXhJe0onSQKD00onka^?o_;oMokbog@02okbog@03oiMl
/onDP[goU8:m00?oU8:m0_nBRlT00onPRKcoWHk3oif>``03oif>``CoViG=1?nIWML2oiRVg`03o`00
0?nPW=3oWZ;H00CoWZ;H1?nNZMh2oij_i0?oXjoP1?nS]>D2oj:ij@?oYkcX5?ooool00ol0003ooooo
ooooo`0Vooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Kooooo0_l0000>ooooo`Co/J;80on_WLD3ojfJ``03ojN?_?nWS[[oYhjj00?oYhjj
1onWSKT00onVRKKoXhRgoj>8]`02oj>8]`?oWXFh1OnGOkP3oheh]`;oQFnc1?mnIjl3ogaSZP?oOV6W
0on0H:@3ohAQXPCoQf:Q0on:I:04ohaUX0CoSVJP0on?Ij08oi1XX0?oTFRP00CoUgV_oiMi/?nGNK3o
UgV`1OnFN;07oiIh[`GoUgR^1?nIN:h00onKNZgo/Lg^ok7=kP02ok7=kP;o^/SU0_l00002oiEUU`Go
VFNG0onKJIL5oj=bV`CoX72L1?nIK9d3oi9YW`03ojF1[?nTPJgoY86]00;oY86]1OnUPjl3ojJ4/003
ojnD^on[S[SoZhjh00;oZhjh1OnYR[D3ojN7/P03ojVB_OnWS;WoYhbi00;oYhbi1?nUR;H5oj>6]@03
oj>5]Onka^?o^lKS00;o^lKS00?o_;oMoiMl/onGO;<00_nGO;<3oiB2_@03oj>6]OnPRKcoX8Vl00;o
X8Vl1?nMS/<4oi^Ec@;oVIgG0_nRU/T3oj2Ld003o`000?nPW=3oWZ;H00?oWZ;H0_nNZMh2ojF[f`Ko
XjoP0_nS]>D2ojRhi0GoYkcX5?ooool00ol0003oooooooooo`0Uooooo`003_ooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`0;ooooo`03
okBXc?naX/So/J;800?o/J;81?n_WLD01?n]V/?oYhnlojN?_?nWSk`4ojN>^PGoYhfi1?nVRKH3oj>8
]`CoWXFh1?nGOkP3oheh]`?oQFnc0omnIjl3ogaSZP?oOV6W0on0H:@3ohAQXPCoQf:Q1?n:I:03ohaU
X0CoSVJP1?n?Ij07oi1XX004oi5XX?nGNJooUgV_oiMi[`CoUgV`1?nFN;07oiIh[`GoUgR^0_nIN:h3
ojS@m@?o/Lg^0ol00004oiEUU`GoVFNG0onKJIL5oj=bV`CoX72L1?nIK9d01?nBJIooYH6/ojF1[?nU
PJ`4ojB1[@GoYH>_00?oYXB`ojnD^on_U;/00_n_U;/3oj^>^0GoZHZe00?oYhNbojVB_OnYT[d00_nY
T[d3ojN<^@GoYHRf0onSQ[D2ok[Aj`?o^lKS00?oVGR/oiMl/onGO;<00onGO;<00onDP[goXhJeoj>6
]@02oj>6]@?oX8Vl1OnMS/<2oi^Ec@03ojBB`onRU/WoXYK900?oXYK90onPW=001Ol0003oX9c@oijR
f?nNX]SoYjOF00GoYJ_K1?nS[n000onY]>7oZ;STojRhi003ojRhi0;oYkcX0_n/`>PEooooo`03o`00
0?oooooooooo02Cooooo000>ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIV
ooooo`04ooooo`03o`000?oooooooooo00[ooooo0ondZ<`4ok6Rb0?o[ig500?oZ9?0ojN?_?nWSk`0
0_nWSk`5ojN>^P;oYhfi00?oYHVfojJ9]_nVRKH00onVRKH4oj>8]`?oWXFh0_nGOkP2oi>1_0?oPgJl
0omeJkX3ogiW[`?oO6>Z0omnHJL3oh1PY0CoQ66R0on7HZ44ohYTX0?oS6FP1?n>IZ04ohmWX0GoT6RP
1onGNJl3oiMi/0CoUWR`2?nFN:l3oiMh[P;oXM;i1?nXd?D3o`0000CoTV:G0onEIIL5oiUWU`;oVfVG
00?oY7>Koj=bVonSLY/00onSLY/4oj1`W0CoVFbM1OnUPJ`3ojB1[@CoYH>_00?o/iZnojnD^on_U;/0
0on_U;/4oj^>^0?oZHZe00?o[9[5ojVB_OnYT[d00onYT[d3ojN<^@GoYHRf00?oXhJeok[AjonjdN/0
0onjdN/01?nka^?oVGR/oiUh[?nIN:`3oiMl/`03ojF4/OnSQ[GoXhJe00?oXhJe0onPRK`4oif>``03
ojN@__nTT/?oY9;300;oY9;31?nRU/T3oj2Ld003o`000?nYY=7oYjOF00?oYjOF1OnUZm/00onS[n3o
ZKCQojVdh@02ojVdh@?oZ;ST00?o[KoWojc0j?n/`>P00on/`>PCooooo`;o00002?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`02Oooool0
00kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00?ooooo0_l00009
ooooo`03okN^d?ndZ<co]:S<00;o]:S<1OnaX/P01?n_WLGoZ9?0ojRC`?nXTl03ojN?_0GoYhjj00Co
YhfiojF9]_nURKKoYHVf1?nVRKH4oj>8]`;oWXFh00?oWXNjoi>1_?nCPK`00onCPK`2oh=f_0?oMF^j
0omZHKH3ogaSZPCoOV6W0_n0H:@4ohAQXP?oQf:Q1?n:I:03ohaUX0CoSVJP1?n?Ij02oi1XX003oiMh
[_nGNJooUgV_00OoUgV_0onGNK04oiIh/0SoUWR_00?oUgR^oj7BnOnQd_T00onQd_T3o`0000?oSf6G
1?nBHYL4oiEUU`CoVFNG00?oVfVGojAcVonTLi/01OnSLY/4oj1`W0?oVFbM00?o[HJ/ojF1[?nUPJ`0
0onUPJ`4ojB1[@;oYH>_0oncV[h4ojnD^`CoZhjh00?oZHZeojbJaOn/V/D00_n/V/D4ojVB_@CoYhbi
0onUR;H2okCQmPCo^]7[00?oVgFWoiUh[?nIN:`00_nIN:`01?nGO;?oYHBaojF4/OnUQ;45oj>6]@Co
X8Vl00?oWHk3ojN@__nWT;h00_nWT;h3ojBB``GoXYK900CoX9c@ojVTdOnYY=7o00001OnWYmH2ojF[
f`?o[;;M1?nY]>400onX^>Co[KoWojfoi`02ojfoi`?o[<3X0_n^a>XDooooo`03o`000?oooooooooo
00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonH
V9So8B4Q00Wooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo0_l00008ooooo`Co]jk@1?ndZ<`2ok6Rb0;oZIS51?nXTl04ojN?_0?oYhjj
00?oY8VhojF9]_nURKH00_nURKH5ojJ9]P;oXhRg00?oYHZioij7^_nNQkX00_nNQkX4oi>1_0?oPgJl
0_meJkX3ofYQ]P?oJEfb1?mnHJL3oh1PY0?oQ66R0on7HZ44ohYTX0CoS6FP0on>IZ03ohmWX004oiEf
[_nGN:koUgR^oiMh[PWoUgV_0onGNK05oiIh/0KoUWR_1?nLe?/3o`0000;oSV2G1?n?HIL4oi9RU`Co
UFFG1?nIIiL01?nKJIOoY7>KojAcVonTLi/4oj=bV`CoX72L0_nIK9d3ojf6[0CoYH6/1?nTPJd00onU
Pjoo/iZnok>J_P02ok>J_PGo[iBk0_n[S[P00on_Ym3o[9[5ojbJa@03ojbJa@GoZI:m0onWS;T00onU
R;Ko]>7fokCQmP03okCQmP04ok[AjonKMJOoVgFWoi]eY`CoVGR/1OnUQ;45oj>6]@;oX8Vl00?oZi2k
ojN@__nWT;h00onWT;h4ojBB``;oXYK90_n]Xld4ojVTd@05o`000?nWYmKoYjOFojNWe_n_/]/01_n/
/]d2ojVdh@;o[[oV1On]_nL00on/`>So[/CZojk4jP02ojk4jQCooooo00?o0000ooooooooool01?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000009ooooo`00
3_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`03o`000?oooooooooo00Kooooo1Ong[]03okBXc003ojbObonYV<GoZIS500?oZIS50onXTl04ojN?
_003ojN>^_nTRKSoY8Vh00;oY8Vh0onURKH5ojJ9]P04oj>8]onUR[WoYHZiojF:^@?oWXNj1?nCPK`3
oh=f_0?oMF^j0_mZHKH3ofUM/P?oKUj_00CoOV6Woh1PY?n0H:CoP62T0on4HJ84ohMRX@?oRVBP1?n<
IJ03ohiVX004ohmWX?nEMZkoUGJ^oiEf[PCoUgR^2?nGNJl4oiMi/0CoUWR`0_nFN:l4oi_Fo004oicD
nol0003o0000o`0000;oSEnG1?n>H9L3ohmQU`CoTV:G1?nEIIL3oiUWU`03oj5aW?nTLi_oY7>K00;o
Y7>K1?nSLY/4oj1`W003oiU/WOn]QZco[HJ/00;o[HJ/1?nUPJ`4ojB1[@Go/iZn1On_U;/01?n[S[So
[jO@ojnWd?n_Ym04ojbJa@GoZI:m0_nWS;T3oik^m`;o]>7f0_nMM:<5oi]eY`;oVGR/00?oZHF^ojF4
/OnUQ;400onUQ;45oj>6]@04oj29_?n[T;_oZi2koj^@^`CoYi2n0onTT/<00on`Y<_o[J?=ojfSc@03
ojfSc@CoZJCA00?o0000ojnbfon_/]/00_n_/]/4ojbbg@03ok31i_n^_nKo[[oV00?o[[oV0_n]_nL2
ojo7k0Co[/CZ00?o[<G/ooooooooool04_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Wooooo000Wooooo`03o`000?oo
oooooooo00Gooooo0_nj]]@5okN^d004okBXc?n/Wl_o[9o;ojbOb`CoZIS51?nXTl02ojN?_003oj:;
^onTRKSoY8Vh00?oY8Vh1?nURKH3ojJ9]P03ojN;^?nUR[WoYHZi00;oYHZi0onNQkX5oi>1_0;oPgJl
0omeJkX3ofYQ]P;oJEfb1?m^GZl3ogEQ[P?oQ66R1?n7HZ43ohYTX0CoS6FP0_n>IZ000onCM:goUGJ^
oiEf[P03oiEf[P?oUgR^2OnGNJl3oiMi/0;oUWR`1?nMf?`2oi_Fo0?o000000?oRUbFoheOUon=GiL0
0_n=GiL4ohiPU`?oSf6G1?nBHYL4oiEUU`;oVFNG0_nQLI`4ojAcV`GoXg:K0onPL9`5ojf6[0GoYH6/
0_nTPJd2okNQ`PGo/iZn0on_U;/00onh_]ko[jO@ojnWd002ojnWd0Go[9[50onYT[d3of3GcP;oW^kg
0_nOM:43oiedX`GoVgFW00CoVGR/ojV5[_nYQJkoZHF^1?nUQ;44oj>6]@03ojnC^_n[T;_oZi2k00;o
Zi2k1OnWT;h01?nTT/?o/:C;ok2Tbon`Y</5ojfSc@;oZJCA00?o/[GKo`000?n_/]/01?n_/]/00on/
/]go/<7Vok31iP02ok31iP?o[[oV00?o[l_^ojo7k?n_an`00on_an`00on^a>[o[<G/ojc5k002ojc5
k1Cooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<
o`000?l0003o0000olc<c009ooooo`009oooool2o`0000Gooooo1?nj]]@3okN^d003ojnWd?n/Wl_o
[9o;00?o[9o;0onYV<D3ojRC`003oj6=`?nRRk_oXX^k00;oXX^k1?nTRKP4ojF9]P04ojJ9]_nWRkSo
Yh^hojN;^0CoYHZi1?nNQkX4oi>1_0?oPgJl0_meJkX3ofYQ]P?oJEfb0om^GZl3ogEQ[P?oOFF]1?n7
HZ42ohYTX003oh]^[On?LJgoSg6]00;oSg6]0onCM:d5oiEf[P?oUgR^2OnGNJl2oiMi/0?oXMWk0onM
f?`01?n6FYKo0000o`000?n6FYH4ohYLUP?oSEnG1?n>H9L3ohmQU`CoTV:G1?nEIIL01?nIIiOoXG6L
oj5aW?nQLI`4ojAcV`GoXg:K0onPL9`5ojf6[0GoYH6/00CoY86]okNQ`_ngXL;o]j721OncV[h00on_
U;_o^;kNokRngP02okRngP?o[jO@1On/V/D00onYT[goW7NXoj9eX@02oj9eX@GoWgBQ1?nMM:<3oi]e
Y`03ojb7[OnYQJkoZHF^00;oZHF^1OnUQ;42oj>6]@;o[i>j1?n[T;/4ojN@_P03okJXbon`Y<_o/:C;
00;o/:C;1?n]Xld00ong^mco/[GKok:ef`02ok:ef`03o`000?n_/]_o[k;K00;o/lGX1On``NH00on^
_nKo[l_^ojo;kP02ojo;kP;o[lO/0on/bNh4ojc5k1Gooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4009ooooo`009oooool0
0ol0003oooooooooo`02ooooo`03okfmfOnj]]Co^[KD00Co^[KD00Co]jk@ojnWd?n_Ym3o[jO@1?n/
Wl/4ojVHa@04ojRC`?nQSL3oXHg0oj6=`0?oXX^k1OnTRKP2ojF9]P03ojF;^?nWRkSoYh^h00;oYh^h
1OnUR[T3oij7^P;oTh6l0_nDT/h3ogB4e@?oMF^j0_mZHKH3ofUM/P?oKUj_0omeHJh3ogeU[@CoQ6Z]
0on;KZd4ohma[@CoTgB]1?nEMZh3oiMh[PSoUgV_0_nUfOX5oj7In`?o00000on6FYH4ohYLUP?oSEnG
1?n>H9L4ohmQU`?oTV:G0onEIIL00onKKYkoXG6Loj5aW003oj5aW0?oY7>K1OnSLY/2oj1`W0;o^I2/
1On]QZ`3ojF1[003okb[bOngXL;o]j7200;o]j721?ncV[h2ol;OkPCo^;kN1?n_Ym02ojbJa@?oWGFT
1OnRMJ44oimdX@CoWGBS0_nKMJL2ojb7[@CoZHF^1OnUQ;401?nSQ[Go[i>jojnC^_n_TkX5oj^@^`04
ojN@__nfZ<_o]ZS;okJXb`Go/:C;00?o[J?=okNkg?ng^m`00_ng^m`3ok:ef`03okC=k?l0003o/lGX
00?o/lGX0_n``NH3ojo@l@?o[l_^0_n[cO45ojc9kP;o[<G/0_nYa>dBooooo`?o00001?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000009ooooo`009oooool0
1?l0003oooooooooooooool3okfmf@Co^[KD00?o/[3FojnWd?n_Ym000_n_Ym05ojbOb`;oZIS500?o
X9;6oj6=`?nQSL000_nQSL03oj:;^`GoY8Vh00CoYHVfojF;^?nURkSoYH^h1?nWRkP4ojF:^@;oWXNj
00?oXiK7oiBBc_nDT/h00onDT/h2ogB4e@?oDgCF0omZHKH2ofUM/P?oKUj_1?meHJh2ogeU[@CoQ6Z]
1?n;KZd4ohma[@?oTgB]1?nEMZh4oiMh[PGoUgV_1OnUfOX01?nQfO_o0000o`000?l00003oh9FUP?o
QUZF1?n:G9H3oheOU`CoSV2G1?n?HIL3oi9RU`;oUFFG0_nKKYh5oj5aW0?oY7>K1OnSLY/01?nPL9co
^I2/okV@[?niT:`5ojf6[003ojF1[?nlZlWo_:_900;o_:_91?ngXL800oncV[ko`]o^ol;OkP03ol;O
kPCo^;kN0_n_Ym03oiidXP?oWGFT1OnRMJ44oimdX@CoWGBS00?oVgFWojb7[On/Qjd00_n/Qjd3ojV5
[PCoYHBa00?o]IZlojnC^_n_TkX00on_TkX3oj^@^`03ok^`confZ<_o]ZS;00?o]ZS;0on`Y</00onl
an?o]k_LokNkg003okNkg005ok:efondcNco]<g/okC=k?l000000oncaNP2ojkImPGo[m3a00?o[l_^
oj_=lOn[cO400_n[cO42ojc9kP;oZ<O`1OnYa>dDooooo`09o`000?ooooooooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@09ooooo`009_ooool3o`0000;o
`LCM1?nm_MT00onj]]Co/[3Fok:`eP02ok:`ePCo[jO@0_n/Wl/2oj6Jc@CoX9;60onQSL04oj:;^`?o
Y8Vh00?oXh^jojF;^?nURkP00_nURkP4ojN;^0?oYHZi00?oZiO2oj>FaonSU/L00_nSU/L4oiBBcP?o
M8CE0_mCM=H3oc9Qd@;oJEfb1?m^GZl3ogEQ[P?oOFF]1?n4JZd3oh]^[@CoSg6]0onCM:d4oiEf[PCo
UgR^0_nGNJl4ojSHn0;oYMWj0ol00003ogmEU`?oPUJF0on6FYH4ohYLUPCoSEnG0on>H9L4ohmQU`?o
TV:G00CoUFFGoi]^W_nKKYkoVfjN1OnQLI`3ojAcV`GoXg:K1?niT:`5ojf6[0Go_:_90ongXL83oj[h
j0;o`]o^0onRM9l3oj1dX0GoWWBR0_nMMJ@2ojAgX@CoXWFQ1?nOM:44oiedX`Go[8N]1?nYQJh2ojF4
/@?o]IZl1?n_TkX2oj^@^`?o^k3?1?nfZ</00on`Y<_o_<OSokc7h`02okc7h`?o]k_L0_nefO84okC=
k003o`000?ncaNSo[]Wf00?o[]Wf0_n_d?43ojSBmP;oZlga0_nVbo<5ojS7l0;oZLC]0_nV`NdEoooo
o`03o`000?oooooooooo01kooooo000Vooooo`03o`000?o1a=go`LCM00?o`LCM0_nm_MT2okJjg0Go
/[3F0_n_Ym000onTXmCoXI[=oj6Jc@03oj6Jc@?oX9;61?nQSL03oj:;^`03ojB9^?nSRk[oXh^j00;o
Xh^j0onURkP4ojN;^003ojF:^On[Ul;oZiO200;oZiO20onSU/L5oiBBcP;oM8CE0omCM=H2oc9Qd@;o
:Ug@00CoJEfbofiN[om^GZooKUj_0omeHJh3ogeU[@CoQ6Z]0on;KZd4ohma[@?oTgB]1OnEMZh2oiMh
[P?oZMCg0onXf?P3o`0000?oPUVI0omoEIL3oh9FUP?oQUZF1?n:G9H4oheOU`?oSV2G1?n?HIL2oi9R
U`03oiI/WonKKYkoVfjN00?oVfjN1?nQLI`4ojAcV`CoXg:K1?niT:`4ojf6[0;oc<7@1OnlZlT01Ong
XL;oZ_SXoj[hj?nZn>SoTVJK00GoXWBO0onPM:05oiidXP04oieeY?nTMj7oY7NQojAgX@CoXWFQ1OnO
M:43oiedX`Go[8N]1?nYQJh00onUQ;7o]IZlokFJ_002okFJ_0Co[i>j00?oZi2kok^`conk/<l00_nk
/<l3okJXb`;o`=_]1Onlan<00ong^mco]MWbokGIlP02okGIlP;o]<g/0_nWh_/00ol0003o[]WfojkI
mP03oj?GnP?oZ=;f0_nScOH4ojK;l`;oZ<O`0onU`^h4ojK1kACooooo00?o0000ooooooooool07_oo
ool001_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooo`LCM00;o`LCM0_nj
`n44okJjg0?o/[3F00?oZ:gKojBSe?nTXm@00_nTXm@4oj6Jc@?oX9;61?nQSL02oj:;^`03oif:_onS
Rk[oXh^j00?oXh^j1?nURkP2ojN;^003ojfG_on[Ul;oZiO200?oZiO21?nSU/L2oiBBcP;oVjKM0om_
V>P2oe=deP?o<V7A0_lZGM03ofiN[`?oMF6^0ommIJd4ohAZ[@?oRfj]1?n?LJd4oi=d[@CoUGJ^00?o
UgR^ojWDmonYe?L00_nYe?L3o`0000;oNeNL0omgDYX01?n2FIWoOeFGogmEUomoEIL3oh9FUPCoQUZF
0on:G9H4oheOU`?oSV2G1?n?HIL00onBHYOoUVbOoiI/W`05oi]^WPCoXG6L1?nTLi/3oj=bV`;o`I^a
1?niT:`2ojf6[0?oc<7@1?nlZlT00ol0003oTfFIoi=UV@02oi9VV`03ojAfX?nRM9ooXWBO00?oXWBO
1?nPM:03oiidXP03ojMkY?nTMj7oY7NQ00;oY7NQ1?nRMJ45oimdX@;oWGBS0_naS:l4ojb7[@CoZHF^
1OneV[`3ojnC^P03ol;0f?nk/<oo^k3?00Co^k3?00?o]ZS;ol3KkOo0fnd00_o0fnd2okc7h`?oZnOj
0_nefO84oiCWnP;oYn;k00?oVM[mo`000?nIf_d01?nSeoX00onXd_KoXlgfoj?=mP02oj?=mP;oY/_c
0_nS`o05ojG2kP;oY/7]0_nT_^`Dooooo`03o`000?oooooooooo01gooooo000Kooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool01?l0003oooooooooooo1a=d4ok[3h@Co][[L00Co/[3FojR]fonX
[M_oZ:gK0onTXm@4oj6Jc@CoX9;60_nQSL000onIS<CoWHZooif:_`02oif:_`CoXh^j1?nURkP01?nW
RkSo[INoojfG_on]Ukl4oj^G`P?oXiK70_n^Z=84oi^Vg@?oKiSX0_leOnL2oc9Qd@;o:Ug@0_leI]@0
1?m^GZooMF6^ogEQ[_meHJh3ogeU[@CoQ6Z]0on;KZd5ohma[@?oTgB]0_nEMZh4ojO?m@?o00000on9
HYl2og]GW0CoMe:J0_mfDYT01?moEIOoPUJFoh9FU_n2EYH4ohIJUP?oRUbF1?n=GiL3ohiPU`;oSf6G
0_nBJJ43oiI/W`GoVfjN1?nQLI`4ojAcV`;oXg:K0oo1Vk44okV@[003ojf6[?o<`M3oc<7@00?oc<7@
00?o_:_9oiETUonCIIT00onCIIT01?nBIY_oY7JPojAfX?nTMZ04oj9dW`CoX7BP0_nNM:82ojMkY0Co
Y7NQ1?nRMJ45oimdX@04oiedXonaS:oo/Hb_ok6<[`Go[8N]0_nYQJh2okjW``Go]IZl00Co[i>jol;0
f?o2`=So`/3H1?nk/<l00onam??o`=_]ol3Kk@02ol3Kk@?oQnW`0_n[ioX3of_Lj@;oU>Oj0on8fOl2
oiWJo@03o`000?nGc?[oWLkh00CoWLkh0_nScOH2oj72l0GoXl?`0_nU`^h2oj>mk0GoY;k/4oooool2
o`0001kooooo000Kooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0000;ooooo1Onj`n42
okJjg003ojbgh_nX[M_oZ:gK00;oZ:gK1?nTXm@4oj6Jc@;oX9;600?oUI3<oiV<a?nIS<@00_nIS<@3
oif:_`GoXh^j0_nURkP00onYU<7o[INoojfG_`03ojfG_`CoZiO200?oXiK7ojjXd_n^Z=800_n^Z=84
oi^Vg@?oKiSX0_leOnL2o`1LdP;o:Ug@0_leI]@4ogEQ[P?oOFF]1?n4JZd3oh]^[@CoSg6]0_nCM:d2
oj;8l`;oYloe0ol00002oi=/X`CoRF:O0_mkEi`4ogMBVP?oMU:I0on2EYH4ohIJUP?oRUbF1?n=GiL2
ohiPU`03oi9ZXOnBJJ7oTVVQ00;oTVVQ1?nFK9l4oi]^WPCoXG6L1?nTLi/00onSLY_o`I^aol6K/@02
ol6K/@Co^I2/00?oh>KGolc1d?o<`M000_o<`M03oiETU`CoTfFI1?nTMZ04oj9dW`CoX7BP00CoWWBR
ojMkY?nWNjCoYg^T1OnTMj44oj9eX@?oWgBQ00?o]Y>cok6<[onaS:l00_naS:l5ojb7[@04ojV5[_nn
Yl?o_ZO3okjW``Co]IZl00?oamgYol;0f?o2`=P00oo2`=P00onk/<oo/OCcok7dl`02ok7dl`04ol3K
kOn7jO3oQnW`ohOYl0?o;kO20_m[g>T3ogKCoP;oR=Wo0onAaOT2oiO<nP04o`000?nGc?[oWLkhoig>
n0?oW[o`1?nQ`_02oj?3l0?oX[c[1?nS_N`2ojBnk0;oY;g[4_ooool00ol0003oooooo`00000Noooo
o`006oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool2ok[3
h@?o/<;W0on/]n84ojR]f`;oY:?D00?oUZ3Koi>Ge?nCUm@00_nCUm@4oiF@c0?oVHc40onMR[l5oj>;
^P04ojF;^?nYU<7oZIC1ojVD`@Co[INo0on[Ul800onfZ<co[ZSBojjXdP04ojjXdP;oVjKM00?oYKOV
ogNYl_mgZO800_mgZO82oc^Bl0?o05cB0oleI]@2odUff`04ogEQ[_mmIJgoOFF]ogeU[@CoQ6Z]0on;
KZd2ohma[@?oVKga0onRb?<2o`0000;oUW2V0onCK:<4ohURW`?oNeNL0omgDYX3ogIBV@;oOENK00?o
PUJFohIJU_n6FYH00_n6FYH3ohYLUP;oSEnG0_nBJIl3oi9ZX@CoTVVQ1?nFK9l4oi]^WPGoXG6L0onT
Li/5ol6K/@Co^I2/0_oPi]L00oo<`M3oUfBEoiETU`03oiETU`?oTfFI00?oZ7ZQojAfX?nTMZ000_nT
MZ04oj9dW`CoX7BP1OnWNj@4ojAgX@CoXWFQ0_nOM:42okJC/`Co/Hb_1?n/Qjd00oo<aM?o_ZO3okjW
``02okjW``?o]IZl0oo7gNT3ol;0f0?oDLRX0_nam?<2ogf_m0CoK[on1?mXb?h2ogKCoP;oT;cd1OnA
aOT2oiO<nP03o`000?nL^nkoW[o`00CoW[o`0_nQ`_02oj:ij@GoX[c[0_nS_N`00onT_>[oY;g[ojBm
j`03ojBmjaCooooo00?o0000ooooooooool06oooool001_ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00?ooooo1On``^L3ojbghP;oZ:gK0_nIZ^83oiJPf`CoTiOD0onE
T<`3oiV<a0CoWHZo0onSRkX00onTTlCoZIC1ojVD`@02ojVD`@Go[INo00CoZiO2okJXc?nfZ<co]ZS<
1?n^Z=800onh_=goYKOVojFgiP02ojFgiPCoMjWb0olkT_000ol0Jm?o05cBocEVe002ocEVe0;oBGKK
0omTRn<4ogVNj@CoS;3^1?nI_O43o`000003oiIcZ_nFL:KoUW2V00;oUW2V0onCK:<3ohURW`?oNeNL
0omgDYX3ogIBV@?oOENK1?n6FYH2ohYLUP03oheTW_nBJIooTVVO00;oTVVO0onBJZ45oi9YX@?oUVbO
1?nKKYh5oj5aW0?oY7>K00?obJfmol6K/Oo1Vk400oo1Vk42okV@[0?oh>KG0_nGI9D4oiETU`;oTfFI
0_nXNZ44ojAfX0GoXWBO0onPM:05ojMkY0CoY7NQ1?nRMJ400onOM:7o]Y>cokJC/`02okJC/`Co/Hb_
0_n/Qjd3olc5d`Co_ZO300?o]IZlolOMjOo7gNT00oo7gNT00oo2`=SoSioOohnOg`03ohnOg`;oOJod
00?oViK=oiJQg?nFXM`00onFXM`4oi6^jPCoT;cd0_nAaOT2oi^dj@;oW;_^00?o0000oibkk_nL^nh0
0_nN_o02oj6ei`GoX[WY0_nR_>/2ojBjj0CoY;cZ0onT_N/00onV_N[oooooooooo`0Cooooo`03o`00
0?oooooooooo01[ooooo000Kooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003ooooo
ooooo`05ooooo`?o/<;W00CoXko]oifej?nM]NSoWKGX1OnIZ^83oiJPf`?oTiOD0onET<`4oiV<a0?o
WHZo00?oXh^jojBCa?nTTl@00_nTTl@3ojVD`@Co[INo00?o]jS:okJXc?nfZ<`00onfZ<`00on^Z=;o
^;cMokRlg@02okRlg@CoYKOV0_mgZO83ocbnh`03ok6igolkT_3o06_C00;o06_C00Co05V_ocEVe?m9
M]_oBGKK0omTRn<4ogVNj@CoS;3^0ol000001?nCM:koUW>ZoiIcZ_nFLjX4oiI`YP?oTfbS0on9HYl3
og]GW0?oMe:J0omfDYT3ogeGV`CoQUjL0on=I9h4oi9YW`CoTVZQ1?nBJJ43oiI/W`CoVfjN1OnQLI`2
ojAcV`;obJfm1Oo1Vk401?niT:coh>KGon3VeooPi]L4oiMTU@?oUFBG00?oTfFIojQjXOnXNZ400_nX
NZ43ojAfX0GoXWBO0_nPM:000on]Q:WoYg^TojMkY003ojMkY0CoY7NQ1?nRMJ45okJC/`Co/Hb_00?o
[8N]olc5doo<aM<00_o<aM<3okjW``?oXOKT0_o7gNT4oi^BbP;oSioO0_nRT<84oi^Fc@GoUZ7L0_nA
[^X00onQY]WoWJgRoif]hP03oif]hPCoVkCY0_nL^nh00ol0003oXK7Soj6ei`04oj6ei`;oX[WY0_nT
]nH5ojBjj0CoY;cZ00CoY;g[ojJmj_nV_N[oY[gZ5?ooool00ol0003oooooooooo`0Jooooo`006ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00007ooooo`04ok32ionS_ngoXko]oj>ok@?o
WKGX1OnIZ^83oiJPf`?oTiOD0onET<`2oiV<a004ohnAdOnITL[oVI7:oiVAbPGoY9?41?nYU<400on]
Ukoo]jS:okNXbP02okNXbPCo]ZS<1_nh_=d2ojFgiP?oV^Sk0onaa>P2ok6ig`03oi^=a?nJR<3oVXS0
00?oVXS000?oUh:ko`1]]omTRn<00_mTRn<4ogVNj@?o000000CoTGJaoi=d[_nCM:koTgB^0onFLjX4
oiI`YP?oTfbS0on9HYl3og]GW0?oMe:J0omfDYT3ogeGV`CoQUjL0on=I9h5oi9YW`?oTVZQ1?nBJJ43
oiI/W`GoVfjN1?nQLI`01?nTLi_obJfmolV]_Oo9[Kd4ol6K/@?oZo>f00?oh>KGoiMTUOnGI9D00onG
I9D3oiETU`GoZ7ZQ0onTMZ05oj9dW`04oj1dX?n]Q:Wo[HBYojf4Z@CoYg^T1OnTMj42oj9eX@;o_j>m
1?nfTk<4ok6<[`03olcmhOo<aM?oc<GC00?oc<GC00?o_ZO3oj7fi?nQm^@01?nTSK`3oi^BbP03ojZ@
^_nRT<;oXY3200;oXY321?nKU/d4oiJQg003ojFQdOnQY]WoXJKI00;oXJKI1OnM[N82oi^dj@06oj:/
gOnQ/N?oXK7Soj6ahol0003oXK7S0onQ]NL00onU]>CoY;OVojBgiP03ojBgiPCoY;[X0_nT_>X2ojJl
j@GoY[gZ5?ooool00ol0003oooooooooo`0Iooooo`006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo00?o0000ooooooooool01oooool4oj>ok@?oWKGX0_nIZ^82ohJYk0?oPZ7W0omnUn43ohFB
f@CoSi7A0onITLX4ojBCa0?oZIC100?o/:K>okNXb_ngZ<X00ongZ<X3okJXc0;o`L3I1?nh_=d3ok[]
m003oi[Xnon_b>co[lS/00;o/LCX00?oWY;7oi^=a?nKSL@00_nKSL@4oiZ8`0?oUh:k0onCO;L3o`00
00CoTGJa0onCM:h3oiIcZPCoUW2V0onCK:<3ohURW`?oNeNL0omgDYX4ogIBV@;oOENK1?n6GY`4oheT
WPCoTVVO0onBJZ44oi9YX@?oUVbO1OnKKYh3oj5aW003olo<eoo9[KgobJfm00?obJfm0_o1Vk42oj_c
]P?oVFFD1OnGI9D3oiETU`GoZ7ZQ0onTMZ05oj9dW`Co[HBY1?nWNj@5ojAgX@04oj9eXOnoXkgo_j>m
oknS_@Go]Y>c0_naS:l3olcmh@;oc<GC00?oW7Z]oi9n^_n]S;<00_n]S;<5ojB=_004oi^Bb_nZT;[o
ZY2jojZ@^PCoXY321?nKU/d00onFXMcoYJ7AojFQd@02ojFQd@CoXJKI0_nM[N82ojFXf0CoXZcM0onQ
/N<00ol0003oXKGWojFdi003ojFdi0CoY;OV0_nT^^P3ojJji`CoY[cY0_nV_NX2ojNojaCooooo00?o
0000ooooooooool06Oooool002Gooooo00?o0000ooooooooool02?ooool2oj>ok@?oUK_a0on</_03
ohJYk0?oPZ7W0omnUn43ohFBf@?oSi7A0onITLX5ojBCa004ojVD`On`Y/ko/:K>ok2VcPGo]jS:00?o
]ZS<ol70fOo1`=T00_o1`=T00onh_=go^^gdok[]m002ok[]m004ok77jon_b>co[lS/oj>Gb0CoWY;7
0onKSL@4oiZ8`0?oUh:k0ol000001?nCO;OoTGRdoi5h]?nAN;@3oi5f/@CoTgB^0onFLjX3oiI`YP?o
TfbS1?n9HYl2og]GW0CoMe:J0omfDYT3ogeGV`?oQUjL1?n=I9h4oi9YW`?oTVZQ1?nBJJ43oiI/W`Go
VfjN0_nQLI`3olo<e`CobJfm00Co`I^aoi]WU?nKIiCoVfND0onIII@5oiMTU@;oUFBG00?o[h:SojQj
XOnXNZ400onXNZ44ojAfX0?oXWBO00?o^9Jcojf4ZOn]Q:T00_n]Q:T5ojMkY0?oY7NQ00?ob/;BoknS
_OnoXkd00_noXkd5okJC/`03ok6<[oo<oN7oc?gQ00GoW7Z]1?n]S;<4ojB=_003ok:D^?nZT;[oZY2j
00;oZY2j1?nRT<82oi^Fc@;o[9k91OnUXM42oj6Vf@;oZJKC1OnUZ=P4oj:/g@;oXK7S00?o0000ojJb
hOnU]>@01?nU]>@2ojBgiP;oYkWV1OnV^^L2ojJlj@;oYkkY1?nW_n/Booooo`03o`000?oooooo0000
01[ooooo000Uooooo`03o`000?oooooooooo00[ooooo1?nE^o43ohbbl0?oQZW/0on2XNL2ogjGh@?o
QI;I0on?TM44oiVAbP;oY9?40_nWYM@4ok2VcPCo]jS:0_o3aM`3ol70f@?oa>o`00Co]l?Sok77jona
an_oZ9[81?nSUlP3oijBa`?oVhg41?nJR<03o`000004oiN2^onCO;OoTgbgoi=l]`?oTGRd0onAM[44
oi=d[P?oUW>Z0onFL:H3oi=/X`CoRF:O0_mkEi`4ogMBVP?oMU:I0ommEi/3ohINW0CoSFBN1?nBJIl3
oi9ZX@CoTVVQ1?nFK9l4oi]^WP03oj5aW?o?c=OoclcG00;oclcG0oo9[Kd5oi]WU0?oVFFD1OnGI9D0
1?nEI9Oo[h:Sojn2Xon_PZ<4ojQjX@CoY7JP0_nRM9l3okRF/`?o[HBY1OnWNj@2ojAgX@;ob/;B1Ono
Xkd3okJC/`04ojf1Y_nUO:OoYGbWojElY`CoW7Z]00?o]92aojf</on]S;<00_n]S;<3ojB=_0;o/YBh
1?nZT;X3oj:@`P03ok:OaOn/W/Wo[9k900?o[9k90onUXM400on_Ym3oZJKCojVVd`03ojVVd`CoYJSH
0_nR[=d2ojVagP?oY[;Q00Co0000ojJbhOnU]>CoYKCT0_nX^>@5ojNiiP;oY[[W0_nX_NT5ojNnj@;o
Yko[0_nX`>/Dooooo`03o`000?oooooooooo01Oooooo000Uooooo`;o00003?ooool2oiFkl@;oS;Sc
0omm/_D3ofn[m@;oI:?d0omIVO43ohFBf@?oSi7A0_nITLX00onBX]ooYjGDojNUe003ojNUe0Co/:K>
00?o]jS:ol?5g?o3aM`00oo3aM`01_o1`=Woa>o`olC_l?o4ko3o]l?SojnNaPCoZ9[80onSUlP4oijB
a`?oVhg400CoVXS0o`000?l0003oVXS00onGP[/2oi=l]`03ohYb/on9L[?oRG:c00_oRG:c0on9LK43
ohM^/0CoRF:O0omkEi`3ogMBVP?oMU:I0ommEi/3ohINW0CoSFBN1?nBJIl3oi9ZX@GoTVVQ0onFK9l3
oi]^WP;o/?7f1Oo?c=L00oo9[KgoVfNDoi]WU004oi]WU0CoVFFD1?nGI9D4ojn2X`CoZ7ZQ1?nTMZ00
0onRM9oo^9JcokRF/`02okRF/`?o[HBY1OnWNj@00onTMj7ob/;Bol[2dP02ol[2dPCo_j>m00Co]Y>c
ojf1Y_n]PJKo[H6V1?nUO:L2oiaj[@?o]92a1?n]S;<01?nTSKco/YBhok:D^?nbU;P5ojZ@^P04oj:@
`_nbWlGo/Yo5ok:Oa@Go[9k900CoYJ7AojnWd?n_Ym3o[jO@1OnYY]<2ojFXf003ojbag?nY/MkoZK7N
00?oZK7N0_nV/^400onZ^>?o0000ojZhh`04ojRhi0;oYkWV0_nY_^T5ojRmj@;oYkkY0_nX`N/5ojS0
ja?ooooo00?o0000ooooooooool05oooool002Cooooo00?o0000ooooooooool03Oooool4ohbhl`?o
OK;e0om_ZoD2ofBSm0?oFIWa0_mUV^d3ogbNj0CoTZ;O1?nWYM@3ok2VcP?o^L_X0oo3aM`3okocl@03
olC_l?n_W/Ko[ik600;o[ik60onXV/P4oj>Gb0;oWY;700?oTgVcoi1g/ol000000_l00003ohie/`?o
S7Bc0on:L[<=ohUb/`?oRG6a0on7K[03ogUT[P04ohURWomkEicoNeNLog]GW0?oMe:J0omfDYT3ogeG
V`CoQUjL0on=I9h4oi9YW`CoTVZQ1?nBJJ43oiI/W`03oi]^W_n`lOKo/?7f00?o/?7f0_o?c=L00onI
IYGoVfNDoi]WU006oi]WU0CoVFFD1?nGI9D4ojn2X`GoZ7ZQ0onTMZ05okRF/`Co[HBY0onWNj@00oo1
nNcob/;Bol[2dP03ol[2dP?o_j>m00?oZH6Xojf1Y_n]PJH00_n]PJH4ojElY`03oiaj[OndT;7o]92a
00;o]92a1?n]S;<5ok:D^0?oZY2j00?o^jO5ok:OaOnbWlD00_nbWlD4ojbNb@03okJ]d?n_Ym3o[jO@
00;o[jO@1?nYY]<00ona]=_o[;7Lojbag002ojbag0?oZK7N00?o[K[SojZhhonZ^><00_nZ^><01?l0
003oZ[SSojRhi?nX^>@2ojZoj@CoZKkY0_nX_NT3ojW1k0CoZ<7[0_nX`>/2ojS1k1Cooooo00?o0000
ooooooooool05_ooool002Cooooo00?o0000ooooooooool03_ooool5ohbhl`?oM;Kj0omF/?X01?la
X_;oFIWaoeVIlOmIVO42ofFJk@?oO9kX1?nBX]l4ojNUe003ok2Vc_nibnSo^L_X00?o^L_X00Go`lGL
okoclOnolo7o_o?aokBQa@05ojnNaPCoZ9[80_nSUlP00onIOKCoTgVco`000002o`0000;oT7Nc1?n>
MK<3ohad/`CoRW:c3On9L[<3ohUa/@;oQfj`1?miI:h2of9F[P04og]GW?mgDY[oMe:JogMBVP?oMU:I
0ommEi/4ohINW0?oSFBN1OnBJIl3oi9ZX@CoTVVQ0_nFK9l3o`0000;o/?7f0_n?GY@3oiUVU@SoVfND
1?nIII@3oiMTU@03okV=Yon_PZ?o[h:S00;o[h:S1OnXNZ42ojAfX0;odLK?1?nhU[<4ojf4Z@;oYg^T
0oo1nN`4ol[2dP03oknS_OnYPJSoZH6X00;o^HnZ0on]PJH4ojElY`Go]92a1?n]S;<00onnXK_o/YBh
ok:D^002ok:D^0;oZY2j0onkYlD4ok:Oa@04ojbNbOnf[M3o]Zg@okJ]d0Go[jO@00?oZJKCok6dfona
]=/00_na]=/4ojbag004ojVag_n]^^?o[K[Sojfjh`?oZ[SS00?o0000oj_1j_nZ_nT01?nZ_nT2ojVn
j@;oZL?]1OnY`N`2ojS1j`;oZ<?]1?nX`N`Dooooo`03o`000?oooooooooo01Gooooo000Tooooo`?o
00003oooool5ohbhl`?oM;Kj0omF/?X3oc6RlP?o1X[M0omlW^P4oi:Rg`;oYjGD0_nTcoH4okW;j0?o
V>oc00Co_o?aokBQaOndXLGo]:751On_W/H2ojRJb003oij2]?nIOKCo000000;o00000onCNK<3oi1g
/`?oSWFc0on<M;<4ohYb/`goRG:c0on9LK43ohM^/0?oNFB^0omREZh3ogMBVP?oMU:I0ommEi/4ohIN
W0?oSFBN1OnBJIl3oi9ZX@;oTVVQ1?moDY83oh=ET`CoSejD1?nIIYD7oi]WU0CoVFFD0_nGI9D3okV=
Y`?o[h:S1OnXNZ401?nTMZ3odLK?om76cooAa/l4okRF/`Co[HBY00?oYg^Tol7ik?o1nN`00oo1nN`2
ol[2dP03ojn3YOnYPJSoZH6X00?o^HnZ1?n]PJH3ojElY`03okjJ/ondT;7o]92a00?o]92a0_n]S;<2
okjQ^`Co/YBh00?oZY2jok^WaOnkYlD00_nkYlD3ok:Oa@03okjje_nf[M3o]Zg@00?o]Zg@0on_Ym00
0one^mko/KCKok6df`03ok6df`;o[;7L0_n__nD5ojfjh`05ojZhhon[`N[oZl7Zo`000?n[`NX00onZ
_nT00onYa^ooZL?]ojW3k@03ojW3k@;oZL7/0_nXaNh5ojS3k@;oZ<7/0_nW`^dBooooo`;o00002Ooo
ool4o`000003oa0@4?oooooooooo00Oooooo000Tooooo`03o`000?oooooooooo013ooooo0_n<^?<3
oiRll0CoPkok0omO_?d2obNWj0?oAKk`00CoPM[noc/00?l_Y^oo;jK_0om]`oh4ojC?mP03okW;j?nH
ko?oV>oc00;oV>oc00?o_KWFokBQaOndXLD00_ndXLD4ojnNaP03ojF9]_nNP[Co000000;o00000onI
OK@3oi=i/`?oT7Nc1?n>MK<3ohad/`?oRW:c3On9L[<3ohUa/@?oQfj`1?miI:h2of9F[P;oFeFa00?o
Me:JogIBVOmfDYT00_mfDYT2ogeGV`CoQUjL1?n=I9h4oi9YW`;oTVZQ1?mnDY83ogmBTP?oPeFC1?n?
GY@4oiUVU@OoVfND1?nIII@2oiMTU@?o^HfW1?n_PZ<3ojQjX@;o00000ooAa/l5okRF/`;o[HBY00?o
V6VJoi9WW?nfRJH00onfRJH4ojn3Y@03ojV1Z?niSj[o^HnZ00;o^HnZ1?n]PJH2ojElY`;o_YZc1Ond
T;401?n]S;?o_Z6kokjQ^onnXK/4ok:D^0Ko^jO500Co/Yo5okjje_nn^]Ko_[[F1?nf[M000on_Ym3o
]K_NokFkgP02okFkgP?o/KCK0_nbb>X4ojnoi@;o[K[S0_n/a^d4oj_1jP03o`000?nZ_nWoZLK_00?o
ZLK_0_nY`nd2ojK7l0GoZ<G^0_nX`nd2ojK4k`GoYl;]4oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Wooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo1Ol00006ooooo`03o`000?oooooooooo01;ooooo1?nH_?02oh>on`CoV/Sg0_mncOl3oj7EnP;o
PM[n0on^g?L3ofg3oP;oY<of0onn]]83okfieP;o^:G61?ndXLD00on_W/KoYHVfo`000002o`0000?o
WX:d0onIOK@3oi=i/`?oT7Nc1?n>MK<3ohad/`?oRW:c3On9L[<3ohUa/@?oQfj`1?miI:h2of9F[P?o
FeFa1?mfDYT3ogeGV`?oQUjL1?n=I9h3oi9YW`03ohIIU_n1E9?oPEBC00CoOU:B0omoDY83oh=ET`Co
SejD1?nIIYD8oi]WU0?oVFFD00?oUfBEokV=YoniSJL00_niSJL4ojn2X`;oZ7ZQ00Co/8FWol2CZ?o0
TjSo00000ooAa/l4okRF/`03ojf4ZOnHJI[oV6VJ00Go]XVV1?n_PjD5okV?ZPCo[H6V00CoYGbWokjJ
/onnV[?o_YZc1?ndT;400oo>_<Wo_Z6kokjQ^`03okjQ^`;o/YBh0_o3]/h4ok^Wa@03olOFiOnn^]Ko
_[[F00?o_[[F0_nf[M02ok_:iPGo]K_N00?o/KCKok;8j_nbb>X00_nbb>X2ojnoi@;oZlgb1?n/a^d2
oj_1jP03ojS:l_l0003oZ<[b00?oZLK_0_nUb_<4ojK7l0;oZ<G^0_nUa_45ojK4k`;oYl;]0_nU`NhD
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool000Wooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o
0000ooooooooool04oooool2oiRll0;oYl3[1?nJb?L2ojg;k`?oXMGj1?ngdNd00on^g?Oo_/cTokk<
i002okk<i0Ko_[KB00Co_KWFokRUa_nhYLKo^:G60ondXLD3o`0000;oYHVf1?nNP[@3oiUm]0CoTgVc
0on@Mk<3ohie/`?oS7Bc1?n:L[<=ohUb/`?oRG6a0_n7K[04ogUT[P?oHUJ^0_mKEK42oeaO_@;oMU:I
0ommEi/3ohINW0CoSFBN00CoTVVOoi;XnOn6FIKoQUVF0_n1E9<4ogiBTP?oOe:B0on3EI<4ohmNU0Co
VFJE2?nKIi@3oiUUU0Go^HfW1?n_PZ<00onXNZ7o/8FWol2CZ002ol2CZ0?oZGRM00?oWfnJokRF/onh
U[<00_nOKiX3oiQYVPGo]XVV1?n_PjD5okV?ZPCo[H6V1OnnV[<2okB@/@?oc[c91?nnXK/01?nbU;So
`kK>ol>fc_o3]/h3ok^Wa@?oamKU0onn^]H00onfg_Co^l[Vok_:iP03ok_:iP;o]K_N0_n`e_<4ok;8
jP03ojKFnOn[cO;oZlgb00?oZlgb0_n/a^d2ojG@mP?oZ<[b00?o0000ojS:l_nYa^l01?nUb_<2ojK7
l0;oXlWc1?nUa_42ojK4k`;oY<C`1OnU`NhCooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02Oooool000Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^
00Kooooo00?o0000ooooooooool05Oooool4ojO0j`03oi[8mon]bnoo[L__00?o[L__00?oXMGjokOA
kOngdNd00_ngdNd2oko6g`?o_/cT0_nn]m<4okjfdP03okZXb?nhYLKo^:G600?o^:G60_l00002oj^@
^@CoYHVf0onNP[@4oiUm]0?oTgVc0on@Mk<3ohie/`?oS7Bc1?n:L[<=ohUb/`?oRG6a0on7K[04ogUT
[P;oHUJ^0omKEK43oeaO_@?oOENK0on6GY`2oheTWP?oT^Si0on6FIH3oh5DT`?oOU:B0omoDY84oh=E
T`?oSejD1?nIIYD8oi]WU0?oVFFD1OniSJL4ojn2X`03okJ6Xon`QJOo`9>X00;o`9>X0onYN9d5oim_
VP;oV6VJ0_nkTJ`5okJ9YP;o[h>U0_oB/[T5okV?ZP?o[H6V00?ob[31okjJ/onnV[<00_nnV[<00ond
T;7oc[c9oljlb@02oljlb@?o_Z6k00?ocM_Sol>fc_o3]/h00oo3]/h00onkYlGoamKUolOFi@02olOF
i@03okjje_nfg_Co]]kd00;o]]kd0_nkb^H3oj;Uo0Co/=Kc00?o//SZojKFnOnVe_T00_nVe_T2oj_=
lP?oWMKk1?nUd?H2ojS:lP03oj7=mol0003oXLgg00;oYL[c0_nOboH5oj?9l`;oYLKa0_nRa_84ojC4
l0;oYL7^0onR`>hCooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool000Wo
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0ol0000Foooo
o`;oYl3[1?nc`^D2ojg;k`?o^/SU00?o]m7]oko6gonoa]l00onoa]l00onnc>Co_[OCokjgd`02okjg
d`03okjfd_njZ<So^ZS800;o^ZS800Co^:G6o`000?l0003o00001?n[T;T4ojF9]PCoWX:d0onIOK@2
oi=i/`04oi9g/On?M;7oSgBaohmd/@?oSG>a0on;Lk84ohYc/`?oRGFf0on:MkT3ohMi_@CoPW_20on0
O/L3ogf3cPCoNFB^0_mREZh3oe]E/@?oG5nm0om/P=D2ohINW0CoSKWd00?oT^SiohYNV?n6FIH00_n6
FIH3oh5DT`?oOU:B0omoDY84oh=ET`?oSejD1?nIIYD8oi]WU0;oVFFD0_o7X;05okV=Y`?o[h:S00?o
]XJSol2CZ?o0TjP00_o0TjP3ojUhW@GoWfnJ00CoV6VJok^A[?nkTJco^i6/1OnfRJH01?n_PjGod[:i
om:b^OoB/[T5okV?ZP;o[H6V0_o:/<44okjJ/`Koc[c900Co_Z6kolgKhoo=fn?ocM_S0oo3]/h3oj_f
l0;oamKU0on:jO<2okKNm0?oJm_[1?nRiO`2ok3Fl`?oU]gn0_nVe_T3ohoIo`;oWMKk0_nAd_h4oi_A
n`;oXLgg00?oV/gio`000?nOboH01?nOboH2oj?9l`;oWlSd1OnRa_82ojC4l0;oXL;a1OnR`>hAoooo
o`?o00001oooool00ol0003oooooooooo`09ooooo`002Oooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`0Hooooo`?o/l;U0_nka>43ok[8
i@?o_lCM0onoa]l2okjie0?o_[OC00Co^Zg<okZXb?njZ<So^ZS80ol00002okRUaP;o[iNm0on[T;T4
ojF9]PCoWX:d0_nIOK@01?nFN[;oTWNaoi9g/OnBMk43ohmd/@?oSG>a0on;Lk84ohYc/`CoRGFf0on:
MkT3ohMi_@CoPW_20on0O/L2ogf3cPCoHgoI0_lQLN400omREZkoFeFaoe]E/@04oeaO_@?oK83E1?n=
^O@3ohYNV0?oQUVF0on1E9<3ogiBTP?oOe:B1?n3EI<3ohmNU0CoVFJE2?nKIi@01?nIIICoaj2`olNP
/?o7X;05okV=Y`;o[h:S0_nfQZ<4ol2CZ0?oZGRM1OnOKiX01?nHJI[o^i6/ok^A[?nkTJ`5okJ9YP04
ojn3YOoB/[Wod[:iom:b^@Go^HnZ00Co[H6VolZ``Oo:/<7ob[310onnV[<2om3nf`Coc[c900?oN^GA
olgKhoo=fn<00oo=fn<00oo3]/koZoK`oj_fl003o`0000;oR^Wc0ol00002of_Kj`?oB/G/0_mcf?X4
of?;n`?oN]Kn0_n?fOl3ohCAo`CoTM;n0_nKdO/2oi;>o0;oV/gi00Co0000oi[=nOnOboKoWl_f0onK
bOL4oio8m0;oX/Kb0_nNa?<5oj72l@;oX/3^0_nO_^l>ooooo`Co000000?oooooo`000?ooool01_oo
ool00ol0003oooooooooo`09ooooo`002Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03ok?2iOnka>7o^lCQ00;o^lCQ00?o
^/SUoko4gOnoa=d00onoa=d00onoa]oo_[WDokjie002okjie003okjgdonj[Lco^Zg<00?o00000onj
Z<P01?nhYLKo[iNmojnG_On_Ukd4oj^@^@?oYHVf0_nNP[@2oi]o]0?oUWZb1?nBMk43ohmd/@?oSG>a
0on;Lk83ohYc/`CoRGFf0on:MkT3ohMi_@CoPW_20on0O/L3ogf3cPCoHgoI0_lQLN43oe]E/@?oG5nm
1?m/P=D00on=^OCoNeVOog]IW`03ohYNV0?oQUVF0on1E9<3ogiBTP?oOe:B1?n3EI<3ohmNU0CoVFJE
2?nKIi@01?nIIICoaj2`olNP/?o7X;05okV=Y`03ojn2XonfQZ?o]XJS00;ojO:H0oo0TjP4ojUhW@Co
WfnJ1?nkTJ`5okJ9YPGod[:i0oniSjX00ooDlNGob[31olZ``@03olZ``@03okjJ/oo@o]_od?kK00;o
d?kK00?oc[c9og[UdOmjiM400_mjiM42olgKh`CoWIoF0_mkZo82oj:Re@CoSjo/1?ma^O`4of;4o@;o
Hl_k0omjaOh4og_=o`;oQ=7o0_n5bOh4oh_=oPCoT/kl0_nJcOT00ol0003oU/WioiK9n@04oi_9m`;o
WlSd0_nLa_D4oik4l`;oXL;a0_nN`?45oinnk`[ooooo0ol00005ooooo`03o`000?oooooooooo00?o
oooo00?oEEEEofIVI_l000002oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001Oooool2o`0001_ooooo0onka>42oko4gPCo_lCM00?o_kgHokji
e?nn^M@00onn^M@3o`000003okZ]c?njZ<So^ZS800;o^ZS800?o/ik3ojnG_On_Ukd00_n_Ukd4oj^@
^@;oYHVf00?oX8Jhoi]o]?nKOk@00_nKOk@3oiIj/PCoTWNa0on?M;43ohec/@?oRg>b1?n:Lk<3ohUe
]P?oRWNi0on7NKd4oh9k`P?oP7k71?mmPlh4of=of@?o8G7Q00?o07C7oeaO_OmLGkd00_mLGkd2ofb0
e@CoNeVO0_maE:401?n:GYSoQUVFohIIU_n6FIH3oh5DT`?oOU:B1?moDY83oh=ET`CoSejD0onIIYD8
oi]WU0Coaj2`1?niSJL00oniR:7o]XJSokJ6X`03onWbV0?o`9>X1?nYN9d3oim_VP03ol6U_OnkTJco
^i6/00;o^i6/1?nfRJH2oj;NP@Cod[:i00?o^HnZomCaiOoDlND00_oDlND3olZ``@;oXhfn0_ngT[45
ojJ=^`04ohf@d_n^VL7o[YW1ojjI`@?oWIoF00?o/9k5oj:ReOnRX]D00onRX]D4ohn_k0;oLKWl0_nG
/^/4ohRnn@;oN/Gn0_n@_OD5ohS5o0CoQLWn0_n;cOh2ohg7n`CoT<Sk0_nFbOT00ol0003oU<KhoiS6
m`04oiS6m`CoW<Ke0_nNa?<2oic2l`CoW/3a0_nO_^l2oifmk`Kooooo1?l00008ooooo`03o`000?oo
oooooooo017ooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Gooooo00?o0000ooooooooool06oooool00onka>7o_lCNoko4gP02oko4gP03oko4
gOno_MSo_kgH00;o_kgH00Go_[WDo`000?l0003o0000okZcdP04okZ]c003okZXb?ncW/?o/ik300;o
/ik31?n_Ukd2oj^@^@04ojF>_?nPQ[SoX8Jhoj26^0CoVgnd1?nFN[83oi9g/@?oSgBa0on=Lk43oh]c
/PCoRW>c1?n9MKH3ohYg^@?oQgVm1?n2Nl83oh1na`;oOH?>1?n=K:T3ohUVY@?oQF:R0on1GZ03ogiK
W`?oNeVO0omaE:43ohIIUP?oPEBC0omnDY84ogmBTP?oPeFC1?n?GY@3oiUVU@SoVfND00?ogl[4olNP
/?o7X;000_o7X;02okV=Y`;o^HRQ0_nfQZ<00om2>j?o_I>[onWbV004ol2CZ0?oZGRM0_nOKiX3ol6U
_@Co^i6/0_nfRJH2ojj5Z@04oj;NPOoB/[Wod[:iom:b^@?oYGnZ0ooDlND01?o:/<7o/Xjaok:>/OnS
SKh4okNB/@?oYXfk00?o^Y^iojjI`On^VL400on^VL401?nMWmKo/9k5ok2NaOn`W/D4oj:Re@;oSjo/
0_nWZmX5oiNbj`;oR;ki0_nM]^T4oi2mm@;oR<Gl0onE_o@4ohg3n@CoSLOk0_n@b?/2oi74n004oiC6
n?l0003oU<KhoiC6n0;oV<Kg0_nF`oH5oiW3m0CoW<;c0_nN`?42oi^nl@CoWKg_0_ooool3o`0000co
oooo00?o0000ooooooooool04Oooool002;ooooo00?o0000ooooooooool07Oooool6oko4gP05oknm
f?l0003o0000o`000?nn^M@00onj/m83okZ]c003ok>UboncW/?o/ik300?o/ik31?n_Ukd01?n[T;Wo
YHjlojF>_?nUS[`3oj26^0CoVgnd0onFN[83oi9g/@CoSgBa0on=Lk43oh]c/P?oRW>c1?n9MKH2ohYg
^@03oiF>b_nAV]SoTI[H00;oTI[H1On3Z^h01?mY`_koTWF_oi9e[onBMJl3ohe/Z@?oRFJU0on5HZ83
oh5NX0?oOU^O0omkFIl3og5DX@03ofA>Xon6FIKoQUVF00?oPEBC0omnDY84ogmBTP?oPeFC1?n?GY@3
oiUVU@OoVfND0_oOb/@4olNP/006okV=YoniR:7o^HRQokV8XOnfQZ?oM4nG0onmTj/01?oYlYSo`9>X
ol2CZ?o0TjP3ojUhW@03oim_V_o1YKgo`JFm00;o`JFm1?nkTJ`01?nfRJKo[XFYojj5ZOn^QJT2ok65
YP03om:b^OnaQJKoYGnZ00;oYGnZ0_o1V:d4ok:>/@Go]i:a0_nVSK/2okZK^@Co[YW100?o_J6mok2N
aOn`W/D00_n`W/D3oj:Re@;o]:O<1?nWZmX2oiNbj`;oZ:kL1OnM]^T2oi2mm@;oWk[/1OnE_o@2ohg3
n@;oUKkd1?nB`_L4oi74n004oiC6n?l0003oU<?foiC3mPCoU/?f0_nI`o@2oiO1m0CoVL3b1OnK__42
oifmk`;oV[c_00?o0000ooooooooool03_ooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0
003oooooooooo`0Nooooo`Co_lCN0_l00002oknmf0;o^[[I1?nj/m801?nj[Lco/jG;ok>UboncYL/5
ok>N``;o[iNm00?oZ9K3ojF>_?nUS[`00_nUS[`3oj26^0CoVgnd0onFN[84oi9g/@?oSgBa0on=Lk43
oh]c/P;oRW>c00?oT7nloi:5`_nBQL800_nBQL84oiF>bPCoTI[H0_n3Z^h3ohMUY0?oPf2R0on=K:T3
ohUVY@?oQF:R0on1GZ03ogiKW`?oNeVO0omaE:42ofA>X`04ohIIU_n1E9?oPEBCoh5DT`?oOU:B1?mo
DY83oh=ET`CoSejD1?nIIYD5oi]WU0?ogl[40oo7X;000oneQJ;o^HRQokV8X@02okV8X@;oM4nG1?nm
Tj/3ol2CZ0;oZGRM00?o^M[aol6U_Oo1YKd00oo1YKd4ok^A[0?o[XFY00?o`9BYok65Y_naQJH00ona
QJH01?nUOj[o`IR]ol6H[Oo1V:d4ok:>/@Go]i:a00?oYXfkokZK^OnjVkT00_njVkT2ojjI`@?o_J6m
1?n`W/D00onRX]Go]:O<okBWc002okBWc0;oYj_J0_nbZm44ojR^g0;oWKKY0_nZ]N45oinjk0;oUKod
0_nN_>h5oiFnm0;oT/;g0_nG`?@4oi?1mP04oiC3m_l0003oU<?foiC3mP;oU/?f0_nE`?D4oiO1m0Co
VL3b0_nK__42oiVml@GoV[c_4?ooool00ol0003oooooooooo`0@ooooo`008_ooool2o`00023ooooo
0ol000000onoa=ko^L?RokZjf@04okZjf@;o^[?B00?o/jkDok>UboncYL/00_ncYL/4ok>N``03oj^O
bonXU/?oZ9K300;oZ9K30onUS[`3oj26^0CoVgnd0onFN[84oi9g/@;oSgBa00CoTG^goi1j]on@N[Oo
T7Zg0on?NkT4oi1o_0CoTXG20onES/X3oi6Jf0?oS6^W0on7IJ@3oh=PXP?oP5jQ0on9IZD4ohERXP;o
PEjP0omnFil3og]IW`CoLEBQ0_mTCZ<3oh5DT`CoOU:B0omoDY83oh=ET`CoSejD1?nIIYD4oi]WU0Go
gl[400?oaj2`okF5X_neQJ801?niR:400omdCiOo^HbWokV<Y`03okfCZ`;oj/Na0_nhRJ@3okWJl@Go
`JFm0_nkTJ`3ojj5Z@;o`9BY1OnaQJH01?nUOj[o`IR]ol6H[Oo1V:d3ok:>/@;o`Yfb1?ngT[45okZK
^@03ojjI`OnmXKgo_J6m00;o_J6m0on`W/D00onmZLGo]:O<okBWc003okBWc0Go/Z_A0_nX[]`2ok>a
e`CoZ[GQ0_nO^^`2ojVii@GoW[c^0_nE__@2oibml0GoUl3d0_nC`OH2oiJom003oiG0mOl0003oUL3e
00GoUL3e0_nG`O@2oiJnl`CoUkkb1?nI_O42oiZlk`;oV;_`4?ooool00ol0003oooooooooo`0@oooo
o`008_ooool00ol0003oooooooooo`0Looooo`?o000000?ooooooko4g_ni`n800oni`n83okZjf@03
ok:hgOnc[]Co/jkD00;o/jkD1?ncYL/00oncW/?oZio;oj^Ob`02oj^Ob`?oZ9K31?nUS[`3oj26^0?o
Vgnd0_nFN[800onDPK_oTWfhoi9m^002oi9m^0?oTG^g1?n@N[L3ohmk^@?oT7nl1?nBQL84oiF>bP03
oi6Jf?nCLjgoS6^W00;oS6^W0on7IJ@3oh=PXP?oP5jQ0omoGZ84ohERXP;oPEjP0omnFil4og]IW`?o
LEBQ0_mTCZ<00omICZ_oPEBCoh5DT`04ogiBTP?oOe:B0on3EI<4ohmNU0CoVFJE0onKIi@00oo>o;Wo
gl[4omo:a002omo:a0Co]HFR0oniR:42ogA?U`;o^HbW0onmTj/2on[7/@?o^8VT0_nif_45ol6U_@03
ok^A[?nfRJOo]XVW00;o[XFY0oo0U:T4ok65YPGo`IR]00Co/Xjaol:M/_o2WK;o`Yfb1?ngT[400oo9
Z;So^Y^iokZK^@02okZK^@Ko_J6m00Co/9k5okfYaOnmZLGo_JW50ondYl`2okf]bPCo/Z_A1Onc/ML2
ojZeh@;o/[KL1?nY^ND2oijlkP?oYKcZ1?nL_O02oiO0m0;oVkka1OnF_o@01?l0003oUL3eoiJolonF
_o<3oiFnm0GoU[kc0_nG__82oiJllP?oUk_a1OnH^o0?ooooo`03o`000?oooooooooo013ooooo000R
ooooo`03o`000?oooooooooo01Wooooo0ol00006ooooo`Co^L?R00Co^[[Iok:hgOnb^=go/[SM1?nc
[]@2ok>Ub`03ojVWe?n[Wl_oZio;00?oZio;0onXU/<4ojF>_0?oX8Jh0_nKOk@00onGQ[ooU86koiB1
^`02oiB1^`?oTWfh1?nANkL3oi1j]`?oSg^i0on@Ok`5oi:5`P;oUHk:0onCLjd3oha[Y`?oQfFT0on3
H:83oh1NX@?oOejR0omlGZD01?n5HZ;oPEjPoh5NX?n1GZ02ogiKW`CoNeVO0omaE:42ofA>X`;oFDj[
00?oPEBCogiBT_mnDY800_mnDY83ogmBTP?oPeFC1?n?GY@4oiUVU@?oVfND0_o>o;T00ooOb/CoQeF>
okF5XP04okF5XP?o^HRQ00CoM4nGokV<YoniS:Oo^HbW0_nmTj/3on[7/@Go^8VT00CoXgJQol6U_Oo1
YKgo`9R^1?nfRJL00on^QJWo`9BYol2DZ@02ol2DZ@Co/HFV1Oo1V:d01?nbS[7o`Yfbol:M/_o2WK83
okNB/@;obJRh1?njVkT00oo7[;oo_J6mokfQ_@03okfQ_@Go_JW500Co]:O<okf]b_nm[L[o_Jg:0onb
Zm42okZad0?o/k7G00?o^[KEok:fg?nb]]`00onb]]`2ojVii@;o/;_R0onU_>X2ojZmi`CoXKg]1?nK
__42oiJom0;oV;kb00?oU[oco`000?nF_o<00_nF_o<3oiFnm0;oU[kc0_nE_O85oiJllP?oUk_a0_nH
^o02oiNjl0oooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool05_ooool3
o`0000[ooooo0_ni`n82ojo2j0Co/[SM0_nc[]@00onX/=goZJODojVWe002ojVWe0CoZio;1?nXU/<2
ojF>_004oibGc_nJS/KoVXk6oiZ>aPCoUhJo0onDPK/3oi9m^0CoTG^g0on@N[L3ohmk^@CoT7nl0_nB
QL82oegEcP;oVWjc1?nCLjd2oha[Y`?oQfFT1?n3H:82oh1NX@?oOejR1?mlGZD2ogQQ[004oh5NX?mn
FiooOU^OogiKW`?oNeVO0omaE:43ofA>X`;oFDj[1?mnDY83ogmBTPCoPeFC0on?GY@4oiUVU@;oVfND
0_o>o;T3ohMESPKo]HFR00?o^HRQohAFU?mdCiL01?niS:L01?nmTj_oj/Naon[7/OoZak45okR9Y004
oj=fXOo0V:ko`9R^ol2H[PCo]XVW1Oo0U:T3ok65YP;ocZbf1?o1V:d5ol:M/P04okNB/Oo9Z;SobJRh
olVX^0?o^Y^i0_o7[;l4okfQ_@03olVca?nmZLGo_JW500;o_JW500?oaKC:okf]b_nm[LX00onm[LX0
0onbZm7o^[7@okZad002okZad004ok>aeonj]]Go^[KEokZfe@?o/[KL0_nh^]/4ok2khP03ojFlj_nZ
_NOoZ[gW00;oZ[gW0_nQ_Nd2ojFnj`CoW[k_1?nH__801?nF_o?o0000oiNml_nG_O85oiFml`?oUKgb
0_nF_?82oiBklPCoUK[a1?nG^_0>ooooo`03o`000?oooooooooo013ooooo000Rooooo`;o00005?oo
ool3o`0000kooooo1?n_`^P2ok:hg@03ojFhi_nX/=goZ;3M00;oZ;3M1?nYYm@4oj^Ob`;oZ9K300?o
WJ;HoibGc_nLUlh00_nLUlh3oiZ>aP?oUhJo0onDPK/4oi9m^0?oTG^g1?n@N[L3ohmk^@;oT7nl0omo
hOL01?nSRk_oVWjcoiYn/onJO[<4oi=c[@?oS6^W0on7IJ@3oh=PXP?oP5jQ0omoGZ83ogaNY@?oN66/
0omnFil3og]IW`?oLEBQ0omTCZ<2oeU>Z`;oA5>m0_mnDY83ogmBTPCoPeFC0on?GY@4oiUVU@04oi]W
U?n=FHooSEV?oheIS`;oQeF>0_n/Oj<5okF5XP03okV8XOn4EYCo^HbW00Co^HbW00Co_I>[on[7/OoZ
ak7oj/Na1?nhRJ@00oo9`M?o`9R^ol2H[P02ol2H[PCo]XVW1Oo0U:T2ok65YP?ocZbf1?o1V:d00ooK
`/7o`Yfbol:M/P02ol:M/P03okNB/Oo9Z;SobJRh00;obJRh00Co^Y^iolN/_oo7[;ooajbo0onmXKd3
olVca0;o_JW50oo5]<X3okf]bP03ol:fc_nj/M3o^[7@00;o^[7@00?o_kOBokZfeOnj]]D00onj]]D0
0onb]]co^;[KokRjf`02okRjf`;o/;_R0_nd_N03ojZmi`03ojjniOnU_^_oYKk[00?oYKk[0_nN_^l2
oj6nkP?oV[g`0_nG_O800ol0003oUkgboiNmlP02oiFml`;oUKcb2?nD^o84oiFjl@;oUk[`0_nE^O0=
ooooo`03o`000?oooooooooo013ooooo000Qooooo`;o00004_ooool3o`0001;ooooo0_n_`^P00onP
_^koYKSVojFhiP02ojFhiPCoZ;3M1?nYYm@2oj^Ob`03oif/hOnMX]SoWJ;H00;oWJ;H0onLUlh3oiZ>
aP?oUhJo1?nDPK/3oi9m^0CoTG^g0on@N[L2ohmk^@?oS=Go00?oOn7goj>;^onSRk/00_nSRk/3oiYn
/`?oTg>]0on<JjL3ohMUY0?oPf2R0on0GZ43ogmNXP?oO5jU0omhHJ`3og5/_@?oNeVO1?maE:42ofA>
X`?oFDj[0om4Dkd3ogmBTPCoPeFC0on?GY@3oiUVU@;oU5nA0on=FHl01?n7EHko[7nSojaoXon/Oj<5
okF5XP03okV8XOn`QJOo^HbW00Co^HbW00?o0009on[7/OoZak400_oZak42okR9Y0;obL7C1?o0V:h3
okJ9Y`;oe[Rl1?o0U:T00onaQJKocZbfolj/]P02olj/]P?o`IR]0_oK`/44ol:M/PGobJRh1Oo7[;l0
0onmXKgobK?4olVca002olVca003okfYaOo5]<[oaKC:00;oaKC:00?o_Jg:ol:fc_o2]/h00_o2]/h2
okZad0?o_kOB0onj]]D00ono^]Ko^;[KokRjf`02okRjf`03ok^lf_nd_N3o];gP00?o];gP00CoZ[gW
ojjniOn^_^Go[[kU0_nU_^/2ojVnj@GoXKk^0onJ_O001?nG_O;o0000oiRllOnH_?45oiFllPKoU;_b
0_nD^_43oiBil@GoUKW`3?ooool00ol0003oooooooooo`0@ooooo`001oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`0?ooooo`;o00005_ooool3oj2nkPCoYKSV0_nX/=d2oiNgkPCoV[;Y0onM[>43oifRf0?oW9O>
0onJS/H4oiN6_`?oU86k0onBOKP4oi5k]`;oT7Zg0on?`oT2ohcEo`?o[9W30onSRk/3oiYn/`?oTg>]
0on<JjL3ohMUY0?oPf2R0on0GZ43ogmNXP?oO5jU1?mhHJ`3og5/_@;o@H_/1?maE:42ofA>X`?oFDj[
1?m4Dkd00ol0Fm;oOe:Boh=ET`03oh=ET`?oSejD0_nIIYD3ogIJY@;oSEV?00?oUW2UojaoXon/Oj<0
0_n/Oj<5okF5XP?o/8FW1?niS:L00on@JZ?o0009on[7/@02on[7/@04okR9Y?o9`M?obL7ColW1d`Go
`9R^00Co]XVWomJh_?oF^;coe[Rl1?o0U:T6olj/]P04ol6H[OoK`/7ofl;1om_2`@?o`Yfb0_oC`/T4
olVX^003omS=coo7[;ooajbo00;oajbo1Oo9/l@5olFdbPGo`[K>00?o^[7@okngd_no]m800_no]m80
0onj]]Go_k[FoknjeP02oknjeP03okRjfonk_=[o^kcJ00;o^kcJ0_nd_N02okRng`?o[[kU0_na_^@4
ojVnj@;oXKk^0_nS_N`5oibmk`03o`000?nH_?7oV;ca00;oUKcb0_nF^_49oiBjl@?oU;Wa0_nE^O02
oiBhl0gooooo00?o0000ooooooooool03oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo0ol0000I
ooooo`?oX;k^0_nU^>H3oiFjl@?oUkO^1?nJ/^T3oif/h@?oWJ;H0onLUlh3oiZ>aP?oUhJo0_nDPK/0
0on6Z>_oRZg]ohZ]k@03ohZ]k@CoSKKb0_n?`oT3okBXc0;o[9W300CoUX>mohii^?n>NKSoSWVh0on6
LK@3ogm[/@?oS6^W0on7IJ@3oh=PXP?oP5jQ0omoGZ84ogaNY@?oN66/1?maK;d01Om1RncoLE^ZofIB
Y_mVDZKoLEBQ00?oI4jS0_mICZ/5odAC_@03o`1Kd_n3EI?oPeFC00;oPeFC0on?GY@00onIIYGoMUZU
ogIJY@02ogIJY@?oUW2U1?n/Oj<5okF5XP?o/8FW0oniS:L00onGKj?oT6ZSoi1ZX`02oi1ZX`03ogEQ
[_nRM9oobL7C00?obL7C1?o0V:h01?nfRJOoe[RlomJh_?oF^;`4ol2DZ@03on?ceoo>[;KocZbf00?o
cZbf00?o`IR]om_2`OoK`/400_oK`/401?o2WK;odl;9om?2bOoC`/T3olVX^0;of<g?0oo7[;l2olk6
dP?obK?40_o?am<3olFdbP;oa[oD0oo2]/h2olBmd`?o_kOB0_o1^m@3oknjeP;o`KgF0onk_=X00onn
_][o^;kOokRng`03okRng`03ojjniOna_^Co/KkT00;o/KkT0_nY_^T2ojbni`CoXkg/0_nL_Nl2oijl
k@04oiVkkol0003oVK__oiVkk`CoU[[a1_nD^_46oi>hl0CoU;S`3?ooool00ol0003oooooooooo`0?
ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00005ooooo`;o00002_ooool3
o`0001gooooo0onC^_85oiFjl@?oUkO^0_nJ/^T2ohFjm`?oPKOg0omn/_D3ogj]lP?oOjW_0on2Yn`3
ohJXj`GoRZg]0_n=]_82ok^fe@04ojJKb_nNSl?oWXo3oij?``CoUX>m0_n>NKP3ohIa]0?oOf^a0omi
I[43ohMUY0CoPf2R0_n0GZ43ogmNXPCoO5jU0omhHJ`3og5/_@03ogm//omaFj[oLE^Z00?oIU:V0on;
HI`3oeU>Z`;oA5>m00?oNE>Hofa=W?m/CI`00_m/CI`01?la=ZOoPeFCohmNU?n?GY@3oee9XP?oMUZU
0onFL:D4ojaoX`Co]HFR1?n`QJL3okV<Y`05oiM_Xon@JZ?oT6ZSoi1ZXonRLY`00onRM9l3olW1d`?o
`9R^00?o0000omJh_?oF^;`00ooF^;`2ol2DZ@;oho?G1?o>[;H00omjeI3ofl;1om_2`@02om_2`@03
oiKbhOoC`/Wodl;900?odl;900?obJRhomS=cooHcLl00_oHcLl00oo7[;ooc/KBolk6dP02olk6dP03
olVca?o?am?oclOC00;oclOC00?oaKC:olJoe?o6_m@00_o6_m@00oo2]/koa;gColBmd`02olBmd`03
okngd_o1^mCo`K_D00;o`K_D00?o_k[Fol6me_o1_MH00_o1_MH01?nk_=[o_[kJokjnf_nn_]X3okRn
g`03okZogOna_^Co/KkT00;o/KkT00?o];kRojbnion/_^L00on/_^L2oj>mk0;oY[gZ1?nN_>d01?l0
003oVK__oiVkkonI^nl2oiJjl@;oUkW_1?nD^O08oi>hl0;oU;S`0_nC]o0;ooooo`03o`000?oooooo
oooo00oooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0
0006ooooo`03o`000?oooooooooo00Kooooo0ol0000Qooooo`?oTk[b0_nE^_43ohjkm@CoR[_f0on5
^_L3oh6gm`?oO[;e0omn[O83ognYk`?oPZO/0on6Z>/2ohZ]k@Co_/;M00Co^kKEojJKb_nVVl[oYY_:
0onNSl<3oiJ3_@?oSWVh0on6LK@2ogm[/@?oNFJa0omfIk@4oh=PXP?oP5jQ0omoGZ83ogaNY@CoN66/
00?oLFbmogm//omoK;<00_maFjX3ofIBYP;oJUJY00CoRf6Loh5HVOn1F9WoPERI1?miDiP3ofa=W003
oc4fYoo>f^;oJ5N[00;oD46Q0_mMBJ83ogIJY@CoUW2U1?n/Oj<2okF5XPGo/8FW0_niS:L2oiM_X`;o
T6ZS0_nRLY`4oj9dW`;oWWb]00Go`9R^omV/Z_oI[:[ofJbZo`000004omJh_003ol2DZOoSlmOoho?G
00;oho?G00KocZbfok:;[OnbRjgo/X^]oiB4_ooK`/44oiKbh@?odl;900?oW_GRomS=cooHcLl00_oH
cLl2okGbm0?oc/KB0_o1i_03olo7d`03olGCi?o6_mCoa[oD00;oa[oD00?o`/KNolBmdoo4_M<00_o4
_M<00oo1_mSo`K_Dol6ke002ol6ke003ol:ne_o1_MKo`KgF00;o`KgF00?o`[kFokjnf_nn_]X00onn
_]X01Onh_]oo^[oMokZogOnj_mgo/KkT00Co];kR0_n/_^L2ojjmi@GoY[gZ0_nN_>d2oj6kj`03o`00
0?nK^^koVk[^00GoUkW_0_nD^O02oiFhk`coTkO`2_ooool00ol0003oooooooooo`0?ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003o
ooooooooo`03ooooo`?o00009_ooool4oi6jlP?oS[_e0_n:^oH2ohO1nPCoN<;n0omL__`2ocNdk@;o
F/ka0onKhod3okOMl`03okgTl_nob^?o_l[S00;o_l[S0_nn`]d2ojfWd@CoYY_:0onNSl<3oiJ3_@?o
SWVh0on6LK@3ogm[/@;oNFJa0omfIk@3ogA/_004oh=PX_n0GZ7oP5jQoh1NX@?oOejR0omlGZD3ogQQ
[004ogUOZ?m[EJOoOfbcogm//`?oLE^Z0_mVDZH3ofYFZ@?oPERI1?miDiP2ofa=W0;oc][R0omXEj/0
0om@@J7oGDVRoee9XP03ogIJY@CoUW2U1?n/Oj<2okF5XP03oiUfZ_n`QJOo/8FW00?o/8FW00Co^HbW
oiM_XonGKj?oT6ZS0onRLY`5oj9dW`04oiil[OoI[:[ofJbZomV/ZP;ommJY00CobJ2_omJh_?oF^;co
bJ2_1OniSZX5ok:;[@03oiB4_onkW[_o^ijk00;o^ijk00?odl;9okZeeOnj]MD00_nj]MD00ooHcLoo
]O;dokGbm003okGbm003olk6d_o1i_3o`NK`00;o`NK`00GoclOColGCi?o5dnCoaM?TolJoe004ol;6
gP03olBmdoo1_mSo`KoH00;o`KoH0_o1^m@3ol:neP;o`KgF0oo2_]H3okjnfP04oknnfOnj_mgo^[oM
okZog@;o_;kL0ond_^82okJng`Co[[gU0_nV_NX2ojRli`GoXK_[00?o0000oi^jk_nK^^h00_nG^Nl2
oiRhkPGoUKS_2OnC]o02oi>gk`[ooooo00?o0000ooooooooool03oooool000Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Gooooo00Co0000oooooooooooooooo0ol0
000Zooooo`;oTK[b0_nF^o44oi2nmP?oQl7j0_mh`_h3oh[<o@;oMm3o1?nNf?`01?nKhogo]mgcokOM
longgO<2okc>i`?o_l[S00?o/[7GojfWdOn]Ym400_n]Ym44ojJKbP?oWXo31?nFPkd2ohii^0?oQW6d
0omoJk43ogUV/@?oMVNd0omdK;`3ogAlc@?oOejR0omlGZD01?mhHJcoQVb^ogUOZ?miGjP2of]EY`04
ogm//omaFj[oLE^Zog5KZP?oIU:V0_mZEZT2ogQW]003oh5HVOmiDiSoNE>H00;oNE>H00?oK4fLolkJ
h_o>f^800_mcJKT2ofQGZ`03ofMFZomMBJ;oGDVR00?oMUZU1?nFL:D4ojaoX`03okF5X_nIMZ[oVGJZ
00Go/8FW00?o^HbWoiM_XonDJ9d01OnRLY`4oj9dW`04oiil[OoI[:[ofJbZomV/ZP;ommJY0oo9X:l2
ol>K[`Co^HjZ1OnbRjd5ok^N^`Co^[GE00?oc<OEohRcl_n8/o800on8/o801?lVQ>[o06;7ol7Vl?o1
i_02oh[MoP?oaM?T0_n`e?<3ol;6gP03okS4hoo1_mSo`KoH00?o`KoH00?o`K_Dol:ne_o2_]H00_o2
_]H00oo1_MKo`[kFol:neP02ol:neP03okjnf_no_]Wo_kkI00;o_kkI00?o^[oMokbng?nl_]`00_nl
_]`00ond_^;o][kOokJng`02okJng`;o[[gU0_n`_><4ojRli`;oXK_[0_nS^NT00onM^Nco0000oifi
k002oifik0?oV;S^0_nE^>l2oiJfkPCoU;K^1?nC]^l4oi>gk`Wooooo00?o0000ooooooooool03ooo
ool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Gooooo1?l0
000^ooooo`CoU[_a0_n@__H2oiW1l`CoTlKi0_n:c?d4oj7>n0;oW]Sl0onbe_<00onggO?o_<kWokc>
i`02okc>i`04oko:honb/MOo/[7Gok:ae`Co[JOA1?nVVlX3oij?``?oUX>m0on>NKP3ohIa]0;oOf^a
0omiI[43ogIW]0CoM6bl0_mdO<d5ogNSkP03od_8iOn6K:koQVb^00?oNEnX0_m[EJL3og5KZP?oIU:V
0_mZEZT3ogQW]0;oNE>H0_nFT</3olkJhP;oLfVi0_mXEj/00omWEZ_oGDVRoee9XP04ogIJY@?oUW2U
1?n/Oj<3oiUfZPGo/8FW0onDJ9d5oj9bW0CoXWBO1?oI[:X3ooOFZ@04olVP[oo3Vjoo`i^_ol>K[`?o
^HjZ0_o0TjL4ok:;[@03olJM[OnkW[_o^ijk00;o^ijk00?od[:iokZeeOnj]MD00oo<amD2ohRclP;o
U;G^0om=SN/01Ol0JmWoR]gnoh[Mo_n:gOkoaM?T00Co/=Cc00Co`/KNokS4honha>?o^<CS0oo1_mP2
okjofP?o`[kF0_o1_MH3ol:neP;o`kkE0ono_]T2ol6ne`?o_;kL00?o_[kJokJngonf_]l00_nf_]l0
0onh_Mgo/;cSok2lh`03ok2lh`;oZ;cW0_nZ^nD4oj>ij@04o`000?nM^NcoW[OZoijgjP?oVKK/1OnF
]^h4oiBfkP;oTkK_0_nD]^h3oi>fk`Wooooo00?o0000ooooooooool03oooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Cooooo0_l0000aooooo`;oU[_a0_nM
_Nl4oiW1l`;oTlKi0onQao<2oj7>n0Co[/oa0_nbe_<3okW>jP;o_<kW0_ne^M`4ok:ae`?o[JOA0_nV
VlX2oiJ;a@?oSh?20on6O<03ogmh`@?oQW6d0omoJk42ogUV/@?oMVNd1?mdK;`3ogAlc@?oMj?^00Co
Vh>iohI/[_n6K:koQVb^0omiGjP2of]EY`;oG5>_00CoLE^ZofIBY_mVDZKoIU:V0omZEZT2ogQW]0Go
UY3;00Coc][Rog1LZomcJKWoLfVi0omXEj/00omWEZ_oGDVRoee9XP03ogIJY@?oUW2U1?n/Oj<3oiUf
ZPCo/8FW00CoPUjPoiAXWOnDJ9goU6RM1OnRLY`4oj9dW`03on6eZ_oI[:[ofJbZ00CommJY1?o3Vjl3
okV>ZP;o`9>W0onbRjd2olJM[@?o^ijk0_oB/[T00onj]MGoc<OEolc7e@02olc7e@03om;CfOnD]Nko
U;G^00;oU;G^0om=SN/01OlXMnCo06_IoeBYnOmDZOWoF;ok00;o/=Cc0_nLa?@4okS4h`03ol6of?nn
_m[o_[oJ00;o_[oJ00?o`[kFol6me_o1_MH00_o1_MH00oo2_]Ko`kkEol>ne@02ol>ne@03oknnfOo1
_]Oo`KkG00;o`KkG00Go_;kLokjnf_nn_][o_[kJokJng`04okRmg@?o/;cS00?o/[cQojZkiOnZ^nD0
0onZ^nD2oj>ij@03ojFhionN]n[o000000?oW[OZ0onI]^`2oiJfkP;oV;G/1?nE]Nd5oiBfkP?oTkK_
2?ooool00ol0003oooooooooo`0?ooooo`008_ooool00ol0003oooooooooo`0_ooooo`CoWKg_0_nI
`O<2oj;2l0?oXLOc0on[bNl3ojk?l@;o]<c/0onic^X00onf_^3o]KWLokFig003okFig0;o/[7G00Co
Y9k?oijDb_nNU<[oWYC:1?nFRlD3ohn3`PCoQWc00_moN<43ogMgaP?oKWoC0omiI[43ogIW]0?oM6bl
1?mdO<d01?mgXnkoVh>ioi^3^OnKPkT2ohI/[P?oNEnX0_m[EJL3oeaC[`?oIU:V0omZEZT3ogQW]0Co
UY3;0_m`G:/00omLC:KoLfViofQGZ`02ofQGZ`;oIeJ[00CoGDVRogIJYOmfFZGoMUZU1?nFL:D2ojao
X`03og=O[?nIMZ[oVGJZ00;oVGJZ0_n`QJL2oh9NX0?oU6RM1OnRLY`3oj9dW`;ohKFZ0_oI[:X3ooOF
Z@03onCeeOo3Vjoo`i^_00?o`i^_00Co^HjZol2CYoo0TjOo`9>W0onbRjd2olJM[@;o^ijk0ooB/[T0
1?oVbK[oc<OEolc7eOo<amD3om;Cf@;oU;G^00GoT;3/oef<i_mMS>KoGHcVodf=j`02obQgi0;oE:Wi
1OnLa?@2okS4h`;o/KkS0onn_mX2okbkf@?o`KgF00?o`KcEol>neOo3_]D00_o3_]D00oo4_M?o`KkG
ol6ne`02ol6ne`04ol:me_nn_][o_[kJokjnfP;o_kgH1?nh_Md00on`_>?o/[cQok:lh@02ok:lh@;o
Z[_U0_n/^^<4ojFhi`04oijgj_l0003oX;KXoj2fj0CoVkGZ1?nH]N`4oiFek@;oU;K^0_nE]Nd3oiBf
kPWooooo00?o0000ooooooooool03_ooool002?ooooo00?o0000ooooooooool0;oooool2oifmk`;o
Y;o]1?nR`_000onQao?oZlW_oj_9k`03oj_9k`03ojk?lOndc>co]<c/00;o]<c/00Co^LkZokJnh?nf
_^3o][kP0one^M`00onZYmCoY9k?ojBNc`02ojBNc`?oWYC:1?nFRlD3ohn3`P?oQWc00omoN<43ogMg
aP?oKWoC0_mEUNl3ogIW]0CoM6bl0_mdO<d2ohEk`0?oMf^i0_n6K:h3ogUOZ0?oJeFW0_mLDjl2obMI
c@04ofIBY_mZEZWoJUJYofYFZ@?oN6Nd0onFT</3og1LZ`;oG4bV00?oLfViofQGZomXEj/00omWEZ/3
ogIJY@CoUW2U00Co[7nSoi6Lf_nAW=[oLen/0onIMZX01?n`QJOoPFV^oh9NX?n2GZ04oiAXW@CoXW:L
0onRM9l2on6eZP;ofJbZ0_ogeZT2onCee@Go`i^_00?o^HjZol2CYoo0TjL00_o0TjL00onbRjgoaYf]
olJM[@02olJM[@04ok^N^ooB/[Wod[:iom:b^@;oi/Vj00Goc<OEom;CfOoBdmWod]?IolcGh@04oi2`
k0?oGHcV0_m6ON83oejLl@;oW<Cd0_nA]Nl5ok6nh`03okjof_nl^mWo_;_I00;o_;_I00Go`KgFol6l
eOo1_=Go`KcEol>ne@04olBmd`03ol6neoo2_MKo`[gF00;o`[gF00?o_[kJoknmf?no_MP00_no_MP2
okRmg@;o^[gL0onb_>42okBkg`Co[;[S0_nU^>L2ojJgi@04o`000?nP]^SoX;KXoj2fj0CoVkGZ0_nH
]N`2oiVdj`?oUkC/1OnE]Nd3oiBfkPSooooo00?o0000ooooooooool03_ooool002Cooooo00?o0000
ooooooooool0;oooool4ojBok@;oX/;`1?nYa>d2oj_9k`?o/LW/0_ndc>`2okC1i0Co][kP00Co]KWL
ojZWe?nZYmCoZZOD0onTW/l3oijDbPCoUX_50on?Pl83ohIl`0?oOgS10omgMlH4ofiod`;oEIG_1?n_
[]H3oi^CbP?oQG_00omgJkT2ofQQ]`03ohI/[_miGjSoNEnX00?oJeFW0omLDjl2obMIc@04ofIBY_mZ
EZWoJUJYofYFZ@?oN6Nd00?oUY3;ohYj^om`G:/00_m`G:/3oea<YP;oJ5N[0omWEZ/2oh=d^P03ogIJ
YOnFL:GoUW2U00;oUW2U00Co[7nSoeUJ^?nAW=[o?TRd0_nIMZX3oh5Y[P?oPUjP0onDJ9d4oj9bW0?o
XWBO0ooQ]JX2ooOFZ@Coi?GE0oo3Vjl00ongU[Ko`9>Wol2CY`03ol2CY`03ok:;[Oo6WJgoaYf]00;o
aYf]0ooB/[T3onK9^P;ol=jm00Cod]?IolcGhOo<en7oc=OQ1?n@/>`3oef<iP;oAWgR0omNW?44oi6e
k`;o/KkS0_n]]^04okbkf@03ok^heoo1_=Go`KcE00;o`KcE1Oo4_M<5ol:mePGo_kgH1Onj_M`00onb
_>7o];_OokBkg`02okBkg`;o[;[S00?o[KWRojJgiOnV]nD00onV]nD00ol0003oX;KXoj2fj002oi^e
jP;oWKCY1OnI]>/3oiNdk0;oUKG]0_nG]Nd4oiJfkPOooooo00?o0000ooooooooool03_ooool002Go
oooo0_l0000`ooooo`;oY;o]0onX`>/2ojW4k@?o[/G[0onabN`2ok?3i@Co]<7T0_nf_^000on^[mWo
ZZODojZWe002ojZWe0CoY9k?0onNU<X3oiJ;a@?oSh?21?n6O<03ogmh`@?oMgO60_m^Om<01?m9bM?o
_lOQoko7hOnoan43ojn^eP?oVi?:0on5Nl03ogM[^@?oJ66g0omiGjP2of]EY`?oG5>_0olWFLd3ofYF
Z@;oN6Nd00CoMg?2oe9B/omBD[?oRWZk0om`G:/2oea<YP;oGUJa00?oJ5N[ofMFZomWEZ/00on3M;X2
oiI`Y@?oZZC@0_mIF[P3oci8]0?oPFV^0on2GZ03oiAXW@CoXW:L0_nRM9l4on6eZP?oVgV/0_lM8i`0
0ooTmMGo`i^_ol>K[`02okNF]PGo`9>W1Oo6WJd00ooI/K3od[:ionK9^P03onK9^P;ol=jm00?okn[5
olcGhOo<en400_nmdNT3ohFUj@?oHXOQ0om6ON82of^Ej004oejLlOnA]NooTKG_oi2Yi`Go[KKP00?o
_;_Iok^heonk^=L00_nk^=L2ol6le@;o`[[C0oo4_M<2olFldP?o`[gF0_o3_M@3oknmf0;o`KgG0onj
_M`00onk_=_o];_OokBkg`02okBkg`03okFkg_n]^N;o[KWR00;o[KWR0_nV]nD2ojRgi004oj:fi_l0
003oX[KVoj:fiPCoWKCY0_nI]>/2oi^dj@CoVKC[1?nG]Nd4oiJfkPKooooo00?o0000ooooooooool0
3_ooool002Oooooo00?o0000ooooooooool0;_ooool3ojS0j`?o[L7Y1?n^aN/00onabNco/l?Uok?3
i@02ok?3i@;o]<7T00?o/;KMojj_fOn^[mT00_n^[mT4ojZWe0;oY9k?00CoVIgFoi:Fe?nBU]CoTYKD
0on:TM@3ohBAf0CoOIGO1?miYNh3og32oP;oam_X1?noan43ojn^eP?oVi?:0on5Nl02ogM[^@?oJ66g
0omVIkl3of]EY`?oG5>_00Co9eW=om3Vioo@i^Ood>KW0_nRZ]d3ogMc`P;oDU:c0om`G:/2oea<YP?o
GUJa0omWEZ/2oh=d^P;oj^C;0onZY=02oeUJ^0;oHUN_00Co?TRdo`00ROn1JJkoPFV^0on2GZ03oiAX
W@GoXW:L00?oXWBOon6eZ_oQ]JX00_oQ]JX3oi]i[0;o7B>L00?o04RYol>K[ongU[H00_ngU[H5ol2C
Y`CoaYf]0_oI/K001?oB/[Woi/VjonK9^_oVbKX3oo3N_@03onoZaOoVl=?o_M7Y00?o_M7Y0on5YNT2
of:7h@?oEgkM00?oAWgRof^Ej?m[UNP01?n@ZNL3ojffh003ojbag?nk^=Oo^kSG00?o^kSG00?o`KcE
ol:jdoo2^]<00_o2^]<00oo4_M?oaKcBolFldP02olFldP03ol:me_o3_MCo`kgD00;o`kgD00Go_kgH
ol6meoo1_MOo`KgGokZmg004ok^lf`03okBkgone^mko]K_N00;o]K_N0_n]^N800on_^N7oZ;OTojRg
i003ojRgi004oj:fi_l0003oX[KVoj:fiP;oWKCY0_nO]>L4oi^dj@CoVKC[0_nG]Nd00onI]NcoV;O]
oiRgk@02oiRgk@Kooooo00?o0000ooooooooool03_ooool002Sooooo00?o0000ooooooooool0;_oo
ool00onX`>_o[L7Yojg1j@03ojg1j@;o[/G[0_nb`^H3ok?3i@03ok6khOn`]]go/;KM00;o/;KM1?n^
[mT2ojZWe003oinTfOnIWMKoVIgF00;oVIgF0onBU]@3ohZAe0?oQ97H1?mmUMl4ogVUkP03og32o_o7
fnSoam_X00;oam_X0_noan401?nRVLcoTHO5oi67aOnAQlD3oh9i`0;oL6fo00CoQG_0ogM[^OmgJkWo
Mf^i0_mXHKL3ofIW_`?oL8OI0_mLDjl00onBi?coVYS@oiZHd002oiZHd0?oKVc00_mgLl82oe9B/`03
oe1C]_m`G:_oL5b[00?oG4bV0_mNE[43ogNBh003oh=d^_mgT^3oj^C;00;oj^C;0onZY=001OmIF[So
HUN_of9G[omREjoo?TRd00;oPFV^0on2GZ03oiAXW@GoXW:L00GoXWBOon6eZ_oQ]J[ohKFZom2NY002
oi]i[004oi]i[OlM8ico7B>Lo`00O@Go]iJf0oo0TjL2olbPZ`;oaYf]0ooI/K000oo]cK?oi/VjonK9
^P03oo3N_@;okn[50_oVl=<2okgAj@04ojJmj_mhUn?oN9OSogRGh`;oHh;L00CoHXOQoeMngOmGO]go
EgkM0omeTN44oi2Yi`04ojffh?n//Mco[;7Lojbag0?o^kSG0_nk]]D3ol:jd`03ol>jd_o5_=;oaKcB
00;oaKcB00?oa[cAol>me?o3_M@00_o3_M@01?o5_M?o`KgGol6meoo1_ML2ol:ne`?o^kcK0_nl_MX4
okFkgP04ojfih_n_^N7o[kWQojnih@?oZ;OT00?oZKOSoj>eiOl000000_nS]ND5oindi`;oVkCY00?o
WKCXoi^dj_nK]>X00_nK]>X4oiVek0CoV;O]1Oooool00ol0003oooooooooo`0>ooooo`00:Oooool0
0ol0003oooooooooo`0_ooooo`;o[L7Y0on``^L4ok;2iP04ok?3iOna^n7o/K_Qok6kh@Co/;KM0_n^
[mT00onTZmcoWjCIoinTf@02oinTf@?oVIgF0onBU]@4ohZAe0?oQ97H1?mmUMl2ogVUkP?oaNG^0_o7
fnP00on_[=GoXYW<oj:Ic002oj:Ic0?oTHO50on2NL02og1]_`?oMf^i0omXHKL3ofIW_`CoL8OI0_o3
bn03oiZHd0?oKVc000?oG5ZgogMc`_mBD[<00_mBD[<00om@DkKoL5b[oea<YP02oea<YP?oGUJa0omg
T^02on[Tb`;o^K_K0om`Kl42oeUJ^0?oHUN_00?o001joh5Y[_n2GZ000_n2GZ03oiAXW@GoXW:L1?oQ
]JX01Oo@WZCoVgV]oi]i[OnKNJgo@cnV00;o7B>L00?o04RYokNF]_ngU[H00_ngU[H2ol2CY`?oc:2[
0_o6WJd3omVa/0;okLfc00?oi/Vjoo3N_Oo`g[d00_o_j/D3onK`d`CoY[gZ0omhUn<3of>2g0?oEgkM
0omeTN43oi:Sh0Go[;7L00?o^kSGok^feOnk]]D00_nk]]D01Oo2^]?o`k[Bol>jd_o3^];oaKcB00Co
a[cA00?o`kgDolFmdoo5_M<00_o5_M<00oo1_MOo`[kGol:ne`02ol:ne`03ok^lfonl_M[o_;gJ00;o
_;gJ0_ne^mh00onf^mgo[kWQojnih@03ojnih@06ojRgi?nY]n?oZKOSojVghonS]NGo00000_nS]ND2
oindi`;oXKCV1?nM]>P4oi^djP;oVKG/0_nK]^/4oiZhk@Cooooo00?o0000ooooooooool03_ooool0
02[ooooo0_l0000aooooo`Co/<;W0_nb`^H2ok6oi0Co/K_Q0_n`]]d2ojRag`?oY:_L1?nOY=T3oiVM
eP?oTYKD0_n:TM@2oh:cm0?oMlCn0on:jO401OnSmnCoaNG^olGUk_o5iNko^;cM00Co[jcE0onRVL`3
oi67a@?oPWW00_m`KKl3ofI`b@?oJ66g0omVIkl3og27f@?o`l_P1?nJV=02ofi/`0;oG5Zg00?oMg?2
oe9B/omBD[<00_m@DkH3oea<YPCoGUJa00?oMi;Pongi_Oni^m/00oni^m/3og1_`@;oFEZh0omREjl0
0om_J[go001joh5Y[P02oh9NX0?oU6RM1OnRLY`3on6eZP;od9jT1?nKNJd00om3?jKo7B>Lo`00GP04
okNF]P;o`9>W0oo<X:/01?o6WJgofK6`omVa/?oI/K03ong=/`04ooSV/Oo`g[gokn[5onoZa@?oi_3C
0_oDi>84ojJmjP?oN9OS0_mSP]`3of5ofPCoMI7Q0onBXn02ojbag0;o[JkH1?nk]]D00onl]]?o`k[B
ol>jdP02ol>jdPGoa[cA00CoakgAolFmdoo5_M?oaKgC0_o6_m<3ol:ne`03ol>oeonl_M[o_;gJ00;o
_;gJ00?o_KkKokJkgOnf^md00_nf^md2ojnih@;o[kWP1OnY]n<00onS]NGo0000ojFei005oj6diP;o
WKCX0_nO]>L3oifdj@GoVkK[0_nJ^>d2oifik0?ooooo00?o0000ooooooooool03_ooool002cooooo
00?o0000ooooooooool0;oooool4ok32i`Co/KoT0_na^n42oj^ghPCoZ;7O0onTZm`2oinTf@03oiRY
honAZ>GoTJSU00;oTJSU1?n;Zn/3oh:cm004ogO4o_n:jO7oR^Waoj?gi0?o_nSb00CoaNG^okRlgOnh
_=go^;cM0on_[=D3oj:Ic0?oTHO50on2NL03og1]_`;oIW390omFR>H4ofIW_`03og27fOoEl>GoeO3U
00?o`l_P0onJV=02ofi/`0?oG5Zg0_mBD[<2oe1C]P;oFg3?0_mLC:H2oeiF/@04oiK[mooJn:KokOVm
on?_e`Co^K_K0_m`Kl400om3@jcoFEZhof9G[`02of9G[`03ofmZ_Ol007[oPFV^00;oPUjP0onDJ9d5
oj9bW005on[=^?oQ]J[od9jTom2NY?o;WJP01?nKNJd00om3?jKo7B>Lo`00O@04okNF]P03ol2CYoo<
X:_oc:2[00;oc:2[1?oI/K03ong=/`03ooSV/Oodlk7om?>a00;ojoZh00?oi_3ComCTh_oDi>800_nm
cnP3oi6YiP?oKX_N0_mSOmT00omSP]coHGoJof5ofP04ogbAg0?oUZ7L1On][]P00onk]]Go_;KCokbf
d`02okbfd`;o`k[B0_o4^]43olJld@?oakgA00?oaKgColJodoo6_m<00_o6_m<01Oo2_]Oo`koGol>o
eoo3_mOo_;gJ00Co_KkK0_nf^md2okJlgPCo[kWP0_nY]n<2ojZghP;oYKGT00Co0000ojFei?nQ]>Ko
XKCV0_nR]>D5oindi`?oWKCY0_nK]^/2oifgjPGoWKW/0oooool00ol0003oooooooooo`0=ooooo`00
;Oooool00ol0003oooooooooo`0_ooooo`Co/<;W0_na_n@2ojfmi@CoZkOR0_nX/Ml00onQ/N?oW:gS
oib]h`02oib]h`?oV:WS1?nAZ>D2oh^[j`?oTLkm0_n>gOh00onMlO7o_nSbokoXlP02okoXlP;o_<[U
1?nh_=d3ojn/e@?oXYW<0onAQlD3oh9i`0;oL6fo0omVL<T3oeJ8iP03oiObg?o3o/[oeO3U00;oeO3U
00Co/l;Uoi2JfOn@V]WoT9[I0om`MlX3ofi/`0;oG5Zg0_m<Ekd00omBD[?oD5>foe1C]P03oe]`c`04
oeiF/OnFjoOof_RVongi_@?ohnoG0oni^m/3og1_`@03od=3[?mIF[SoHUN_00;oHUN_00CoKfZmo`00
N_n2GZ3oPUjP1?nDJ9d3oj9bW0;oj/fh00?ohKFZom2NY?o@WZ@00_o;WJP3oi]i[@;o@cnV00Go001m
o`00G_ngU[Ko]iJfoin?`P05olbPZ`03om^d/OoI/K3ofK6`00?okLfc0_ohi[42ooCc/@04on_j^?oV
nM3oi_W@omCThPCo_LoX0onAZNH3ofj;gP?oHgoI0_mQOmX4ogbAg0?oUZ7L0on][]P00on_[]Ko_;KC
okbfd`03okbfd`03ol>jd_o4^]7oa;[A00;oa;[A00Goa[cAolNmdOo7_M7oakgAolW0dP04olJod`04
olO1eOo3_mOo`koGol>oe`;o`l7H0onm_]/00onm_mco][cNokJlgP03okJlgP;o[kWP0_n`^N04ojZg
hP04ojFei?l0003oY[GSojJeh`CoX[CU0_nO]>L2oj6diPCoWkGX1?nM]nX2oifik0;oWk[[0oooool0
0ol0003oooooooooo`0=ooooo`00;_ooool00ol0003oooooooooo`0_ooooo`;o/<;W0_n]`NT4ojfm
i@;oZkOR0_nT]^D3oj6ah`CoW:gS0onHZN<2oi6Xi@?oT/;g0_nAc_d2oiWXn`Co]^Kf00?o_nSbokc:
iOnlb^D00_nlb^D2okRlg@04ojFXf?nIVmCoVI_DoiVKe0?oSXo@0omoQM03ogR6e0?oL6fo0omVL<T0
0omFR>KoIm2Kok[mfP02olong@04olWRj_nc`^Go/l;Uok?2i@?oT9[I0_m`MlX2odiL`P04ofi/`?mL
F[OoG5ZgoeaJ]`;oC5Nm0_m@DkH3oe]`c`03o`000?oJn:KokOVm00?ohnoG0_njg?42oeR7i0?oL6o1
0_m3@j`3of9G[`;oKfZm0on2GZ03oiAXW@;oXW:L0ooZcKP00ooQ[j?od9jTol^MZ002ol^MZ0CoVgV]
00?o@cnVo`00OOl006H01?nOSl83olbPZ`;ofkBa0_oI/K03ong=/`04ooSV/Oodlk7om?>aon_j^0;o
i_W@0ooIk>42okg?j004ojNfhon3V=ooPiSOoh>Hg`?oJH?I00?oKX_Nof=ofOmSOmT00omWPMT3ogbA
g0CoUZ7L00Co[JkHojn^e_n_[]Ko[jkF0onl]]<2okjgdP?oa;[A00Coa[cAolNmdOo7_M7oakgA0oo9
`=82olJod`?oal7E00?o`koGol?1f?o3`MP00_o3`MP01?nm_]_o_KoLokfog?nm_m`3okJlgP03okJm
gon`^N3o/;WP00?o/;WP0onZ]n82ojJeh`03o`000?nV]N?oY[GS00;oX[CU0_nS]>@4oj6diPCoWkGX
0_nM]nX00onP]nWoWk[[oinjj`03oinjj`;ooooo00?o0000ooooooooool03Oooool002oooooo00?o
0000ooooooooool0;oooool4ojg1j@;o[KgU0_nW^nP4ojBfi@?oXK7S0_nL[N<2oiRikPCoU[_b0_nB
`_L3oiSLoP04oiWXnonfi_Ko]^KfokKVmP?o^m7[0_nlb^D2ojfcg@CoYJSH0onIVm@3ohj?d0?oOhG@
0omhQ]@4ogFDh`03ohK8oOnjoM[o^_gJ00;ocokM0oo9h^X3ok?2i@;oT9[I0om`MlX2odiL`P?oG5Zg
0om<Ekd2oebBj`04oe]`cooBoMkof_RVonGla@;oj?[60_oRl]T3ok[Ll@04oeR7i?lL?k[o73njog1_
`@;o@d>/0on2K;400om_J[go_9Vdo`00NP02oh9NX0?oU6RM0_nRLY`3on[=^003on6_Xoo@WZCobifX
00;obifX1?nKNJd2od<oYP03o`00OOl005koWho200;oWho20oo<X:/3om^d/@03omVa/?o]cK?okLfc
00;on>Ja00Com?>aon_j^?oVnM3oi_W@0ooIk>400oo5dN?oYkKSojNfh`02ojNfh`?oPiSO0omYPmT2
of=me`03of=ofOmWPMWoIh7I00?oPI;J1?nJXMX5ojn^eP03okbfdonn]m;o_[OB00;o_[OB00Goa;[A
olJldOo6_=7oa[cAolNmd@04olW0dP03olJodoo7`MGoal7E00;oal7E1?o3`MP00oo3a=[o_KoLokfo
g002okfog003okJlg_nf_Moo][gO00;o][gO0_n`^N02ojnih@CoZ[OR0_nV]N<00ol0003oYkGSoj>d
i004oj>di0?oXKCV0_nO]NP2oj6fi`CoX;OY0_nO^^/2oj:kj`;ooooo00?o0000ooooooooool03Ooo
ool0033ooooo0_l0000`ooooo`;o[L7Y0_nW`>/4ojNkj0;oY;KU0_nN^^`3oibik@CoV;W^0_nF^o83
oiSBo0;oV=cn0_n^goP2okODk`?o^m7[00?o/KcRojfcgOn]/md00on]/md4ojFXf0?oVI_D0on>Sm02
ogn5d0CoN8KD0_meU><00omoiO7o^_gJok[mfP02olong@?obN;Z00Co[;_Toi2JfOn@V]WoT9[I0om^
Nll2og1gbP;oCUc20_mLK/d00omLF[OoC5NmodaG_@02odaG_@03oebBjooBoMkod_gN00;oiOc500Go
j?[6on;bfOoRl]Woh_;Iom7Ph`02ognfm`06o`0b^OmHQnCo73njoa`o^_m`Kl7o@d>/0on2K;43okbI
]003o`0@XOn2GZ3oU6RM00;oU6RM00CoXW:Lon[=^?oZcKSoj/fh0_oQ[j<4ol^MZ0;oVgV]0_nOQKP0
1?mFF;So@cnVo`0FWOl006H3oin?`P;oc:2[1?oK];401?o^e;SokLfcong=/oohi[42ooCc/@;oh_bj
00?oho[BomW/hOo5dN<00oo5dN<3ojNfh`CoPiSO0_mYPmT3of=me`?oIh7I0on1T]X4oiZQfP?o[jkF
00?o/[3Fokjgd_nn]m800_nn]m800oo0^M?oa[cAolJld@02olJld@04olS0doo9`=;obL3BolW0dP;o
b/?C0oo7`MD2olS4e`03ol?1f?o3a=[o`lCJ00;o`lCJ0_nm_m`2okc1gP?o][gO0_ne_^04ojnih@;o
Z[OR0_n[]n801?nW]N?o0000ojNehonW]N<2oj>di0;oYKCT0onS]ND5oj6fi`;oX;OY0_nS^>P4oj:k
j`03ooooool0003ooooo00kooooo000booooo`03o`000?oooooooooo02kooooo1?nW`>/2ojNkj0;o
X;c]1?nN^^`3oibik@;oV;W^0onIbOP2oiSBo0?oZ=Sh00?o[]ohokODkonge>l00_nge>l01?nkdN_o
/KcRok6lh_na_>84ojfcg@;oYJSH0_nIW]P3ohjHf@?oQYSM0omlWnT2ogR6e0;oO[ol0_nVlO@2okOl
h@;ob_7/0_nne>X3ojbki0?oT9[I0_m^Nll2oem^b`?oCUc20omLK/d2odaG_@;oSj_Y0_o>oN400ooU
o<Goj?[6on;bf@02on;bf@?odN3S0_mo]_L01?l0<[Wo73njoa`o^_lL?kX2od=3[0?oPVba0onlVK@0
0ooGZJWoU6RMoiAXW@03ojG;m004on[=^?oQ[j?ohJnSon6_X`CobifX1?nOQKP2oeIH^003o`0FWOl0
07goWho200?oWho200?oc:2[om^d/OoK];400_oK];42onkD^004ong=/oohi[7oj?NVom[fXP;oh_bj
00?oho[BomWUg_o5dN<00_o5dN<01?nb^]ooV:CNoiRTg_nHY=h4og^>fP;oIgoG00?oJH?Iof=meomS
OML00om/PmT01?mWPMWoPI;Joh6Bf_n1T]X3oiZQfP03ojn^e_nb/=Ko/[3F00;o/[3F0_nn]m83ol2i
d`;oa[cA0oo8`=<00oo9`=;ob/?Col[3d`02ol[3d`04olO1eOo8a=Oob<CGolS4e`Go`lCJ00?o`lKM
okc1g_nl`Mh00_nl`Mh00onf_Moo]KkPokFnh002okFnh0;o[kWQ00?o[k[Roj^gh_n[]n800on[]n80
0onW]N?o0000ojNeh`05ojFdi0?oXkGU0_nQ]^L2ojBgiPGoXkSX0_nR^n/00onU_>[oooooo`00000?
ooooo`00<oooool00ol0003oooooooooo`0^ooooo`;oYl3[0_nR_^d4oj2lk@;oW[[/0_nL`O84oi_4
m0;oVLWh0onTd?L2ojSHn0?o/M?a0_nge>l2ok?3i@Co/KcR0_n]/md00onQY][oVIkHoiVNf003oiVN
f0?oSYSI0on6V=d4ogbOj@03ogjoo?nVlOCoY_7d00;o]ocQ0_o:lN`4okkDjP?o[;_T0_n@V]T3ofik
c`;oGfk;0_m>G<83oea^c@?oSj_Y0_o>oN401OoUo<Gof_cIon?be_oSl]Koh_;I00?odN3S00Go_lgU
od^Gl_m;Uo;oBiObo`0b^@02oa`o^P;o@d>/0on2K;42okbI]0CoejVY0_nUbo@01OoQ[Z3ohJnSon6_
XooQ[j?oh;F[00CobifX00Coc:Reoin5^?nOQKSoWhFh0omFF;P00ol05Ygo001coin?`P02oin?`P04
olbPZooK];7ofkBaom^d/@?ok]Bh00?om_2donSgY_oXmjH00_oRo;X01OoSn];ofNGNomWUg_oIiMko
aM7S00?o/[[O0onHY=h3og^>fP?oIgoG0omSOML3ofb3f@?oQYGK1?nNY=X4ok:`eP03okjgd_o0^M?o
`;WC00;o`;WC00?oa[cAolS0doo8`=<00_o8`=<4ol[3d`04ol_8eoo8a=Oob<CGolS4e`;ob<SJ0oo3
a=X3ol?6g@;o_<7N00?o^l?PokFnh?ne_^000_ne_^000ond_^;o[k[RojnjhP02ojnjhP;oZkOR0_nZ
]n82ojNeh`04o`000?nW]N?oYKCTojFdi0;oY[GS1?nU]ND4ojBgiP;oXkSX0_nU^NL4ojFljP03o`00
0?oooooooooo00gooooo000dooooo`03o`000?oooooooooo02kooooo1?nR_^d2oj2lk@;oW[o`1?nL
`O82oi_4m0?oX/[d0_nTd?L3ojg?lP;o/M?a0_nba^T4ok?3i@;o/KcR0_nW[]`3oj6VfPCoVIkH0on>
V=T4ohJHg@;oO9oY0_nHe_d2ojcel@;oaO?^0_o6i>d2okkDjP;oYk[V0on>XN43ogJ9f@;oKW_?0_mO
K//3oe=ad`?oG6k=00CoSj_YolkmhOo>oN7oa?7`0_oJo=T01?oSl]Koh>CFon3Te_oAh><4oko=i@?o
BiOb0_lL?kX00olH<:co@d>/oh9//@02oh9//@;o_9Vd0ooGZJT2on:cYP;ohJjP0ooQ[j<2on2eZ`;o
bifX0_o<Z;D4oin5^0;oEURh0_l05Yd3ohb@dPCofkBa0oo^e;P01Oofl;Coj?NVon;l^_oRo;[oho[B
00?ofNGN00?obLoNok:jgonb^]l00onb^]l3oiRTgP?oNhkJ0_mWOmL3ofEoe`04of=meom/PmWoK8?I
ofb3f@?oQYGK1?nNY=X2ok:`eP;o]K?G0oo0^M<2ol>ne@?ob<3C0_o9a=D00oo:`m?oblSGol_8e`02
ol_8e`03olS4eoo8b=[ob<SJ00;ob<SJ00Go`lCJol?6gOo3a]go`lKMol79h@04ok_3h003okFnh?nd
_^;o];kR00;o];kR0_n_^^82ojjjh`CoZ[OR0_nW]N<00ol0003oY[GSojJeh`03ojJeh`CoYKGU0_nT
]nH00onV^>KoYKWWojFii`03ojFii`;oYKcZ00?oooooo`000?ooool03_ooool003Gooooo0_l0000_
ooooo`;oX[k]0onO_^h3oijol0;oW<7b0onQaO82oj;:m0;oZL_a0on]co82ok36j`Co//KY0_nc`nD2
ojbeg`CoYjkL0onQY]X2oiVNf003oiFYi?n?[N_oSjg[00;oSjg[1OnA_?@01?nHe_go[?GaolGck_o5
lnh3olKTk@;o^<k[1?nW^^H3ohjQh@;oMXWI0omJMmD2oem^b`?oDg7C0on2]OH2olCal0;of_cI00Co
ho;Fon3Te_oPi=Koh>CF0_oGd]@2oko=i@?o]kkO0_m8T^l2oa`o^P03oaP`[?m3@jcoPVba00;oPVba
00Co_9VdomNYZOoGZJWoejVY0ooR/jH3on6_X`?oh;F[00CobifXolbX]Oo<Z;Goc:Re1?nOQKP3oeIH
^003o`0FWOl007?oS93B00;oS93B0_oK];43onkD^003ooK`]?oXmjKof_JR00;oeOoD0_oKl>001?oI
iMkobLoNolW?g_o9cmh2ok:jg`;oYJ_K0on>VMX3ogN9f0?oIgoG0omUOmL3og27fPCoQYGK0_nNY=X0
0onRZ=_o]K?GokFce`03okFce`03ol2idoo3_]Go`kkE00;o`kkE00Gob<3ColW4eOo9a=GobLCEol_:
f@03ol_8e`;oblcJ0oo8b=X2olO<gP03ol?6gOo1bN7o`LWQ00;o`LWQ0_nk`n02okW4h`?o];kR00?o
/[oTojjjhon^^^<00on^^^<2ojZghP05ojVghonW]^?oYkKSo`000?nW]^<01?nV]N<2ojFei@;oY[KT
1?nV^>H2ojFii`Kooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000ooooooooool0;_oo
ool2oinnkP;oX[k]1?nQ`O02oj75lP;oYlO`1?nYbo400on]co;o/<K[ok36j`02ok36j`;o//KY0_n^
^^84ojbeg`;oYjkL00?oXJkQoiZZh_nJZ^800_nJZ^83oiFYi0CoSjg[0_nA_?@2oj7To0;o^Nke0oo2
jo400oo6i>go^<k[okS>j`02okS>j`?oYk[V0on>XN43ogJ9f@;oFWOE0omUQ=d3oe=ad`03oh:em_o4
lO3oa?7`00;of_cI00Coho;Fon3Te_oPi=Koh>CF0ooGd]@01?o?`loo]kkOokNngong_]l2okRff0;o
Jj3`00?o73njoaP`[?lH<:`00_n2K;400onQR;[oejVYomNYZ@02omNYZ@?oh[>V0ooQ[j<3on2eZ`03
ol^MZ?o<Z;Goc:Re00;oc:Re0onOQKP3oeIH^003oaY3__l05Ygo001c00?oS93B00CofkBaonkD^?o^
e;Som_2d0_oXmjH2omGoe0;ofo3P0_oBg>42olW?gP;o^[cK1?nUZm/3ohjIfP;oMhWH0omWP=P01?mW
OmOoIGoGofEoeomUOmL2og27fPCoRYWL1?nRZ=/3okFce`03okRif_o3_]Go`kkE00;o`kkE00CoaLCI
olW4eOo9a=GobLCE0oo;b]T00oo;b=OoblcJol_<fP02ol_<fP03olS8f_o7c=koalcN00;oaM3R0oo1
bN400onnbnCo^LCSokW4h`03okW4h`04okBnh_nb_nCo/[oTok:oi0;o[[[S0_n/^^@4ojVgh`;oYkKS
00Co0000ojNfhonV]N?oY[GS0_nW]^<4ojJfi0;oY[SV2Oooool00ol0003oooooooooo`0<ooooo`00
>?ooool00ol0003oooooooooo`0^ooooo`CoX[k]0_nQ`O02ojG3kPCoYlO`0_nYbo43ojk6k0;o/<K[
0_n^_ND4ojjjhP;o[;GO00?oYK;Roj6^hOnQ[^400_nQ[^44oiZZhP?oUJWT0_n?[N/3oi_?nP03oj7T
o?nik_Go^Nke00?o`^_a0onmf^h2okS>j`04ojJjionDY^;oU:KRoiBVhP?oNi;M0om/Qm`3oeYge@?o
IHCM0on:/>l2okoSl0;ofNOO0_oOh=D01?oPi=Koem;DomOBe?oGd]@3olo3c`03okNngonh]]So^;KH
00;o^;KH00CoJj3`o`00S_lH<:co632/1?nQR;X2omNYZ@Coh[>V0ooQ[j<3on2eZ`Goc:Re0_nOQKP0
1onTV/_oK7_AofakdOm/Nm7oEURhoaY3__l01YP01On6[o000oo^e;Som_2doj3`]P02omGoe0;ofo3P
0ooBg>400oo5bMgo^[cKokZlf`02okZlf`?oYJ_K1?n>VMX2ogN9f0?oIh3H0omXPmX3og27fPCoRYWL
1?nRZ=/01One/mOo^;WJokRif_nh^M[o`kkE00CoaLCI00?obLCEol_:fOo;b]T00_o;b]T4ol_<fP;o
bm;O00?oalcNolG@h_o5d>800_o5d>801?o1bN7o_/_Tokk;i?nnbn@2okW4h`;o]/GV0onb_n@00on_
_nGo[;[Tojbji003ojbji0?oZKOS0onX]^<00ol0003oYkKSojNfh`03ojNfh`;oY[KT3?ooool00ol0
003oooooooooo`0<ooooo`00>Oooool00ol0003oooooooooo`0^ooooo`;oX[k]0_nU_n`4ojG3kP;o
YlO`0on/a>`2ojk6k0;o[[oW1?n^_ND2ojjjhP;oZ;KS0onU/^84oj6^h@;oVZ[R0_nJ^>`4oi[0lP;o
Vloj0_n`hoP2ok_Ym0;o_n7`0onmf^h2ok;9j`?oY[[W0onDY^83og^Bg@;oK8OL0omOQ^401OmJMmGo
IHCMofF4gOmUQ=goR[3_00;o_n?`0ooIiml2omoPe@;ofm;?00?oem;Dolo3coo?`ll00_o?`ll01Oo:
^L_o^;KHokRff?nh]]So^k;@00;oT:_X0olH<:`3oj68^P;oejVY0ooR/jH2on_2ZP03on6_XooP]J_o
h;F[00;oh;F[00?oi<RlolbX]Oo<Z;D00_o<Z;D4ojBJb`?oK7_A0_m=QNH00ol0DL_oQZo`ohJ_l002
ohoPo@03oiObe_nPl;Ko___W00;odO?W00CodNCUom;LhOoBg>7od]cQ0oo5bMd2okZlf`04ojnafOnM
X]WoWJ;IoifRf@CoRICI0omeRMT3ofN0f0;oJ8?J0omdS]h01?m`Qm[oRYWLohZIg?n:VM`2oj:Xf`;o
YJoO0onh^MX2ok_0gP?oaLCI0_o7bmd3ol_:f@;obm3M00?oblcJol_Bgoo;d]l00_o;d]l4olG@hP04
ol;CionnbnCo_/_Tokk;i0;o^/gX1?nfaNH01?nb_nCo[koUojnoiOn__nD3ojbji003ojZjiOnY]n?o
ZKOS00;oZKOS0onX]^<00ol0003oYkKSojNfh`0@ooooo`03o`000?oooooooooo00cooooo000joooo
o`;o0000;oooool4ojFok0;oYL?^0onZ`^/2ojc4k0;o[L7X1?n^_nL2ojjmi@;oZ[[T1?nX]^<3ojFb
hP;oXJkQ0_nN]NP4oiZhk0;oV/3b0onWe_P00on`hoSo^nWdok_Ym004okoQl003okgJk_nbbN_o//W[
00;o//W[0onV^^L3oiBVhP?oNi;M0_m/Qm`3oen6h@CoPjka00Co_n?`omWWgooIimoofNOO0_oOh=D3
om_Bc`04omG6boo?`loocl??olo3c`?ob[W;00Co^;KHok^bd?nk/]3o^k;@0_n@ZnP2oaP`[0?oXHRj
0_oGZJT3on:cYP;ojl:Z00CohJnSon2eZooP]J_oh;F[0_oTb;`3olbX]@;ocKg;0onTV//4ofakd@;o
CHGV0_l0DL/01?n?h?goUo;FokkkionnnnL2om7ci`?odNCU00God]cQolG9gOo5bMgoaLWMokZlf`04
ojnaf@?oWJ;I1?n9U=T2ogF9f@?oJHCJ0omXPmX3ogB>gPCoSZ3P1?nU[ml00onh^M[o^l3Nok_0gP02
ok_0gP03olG4fOo7bmgoal_M00;oal_M00?obl[Iol_@gOo;d=d00_o;f><3ol_Bg`;ob=OU00?oaM3R
ol;Cioo2dnL00_o2dnL00onnbnCo^/gXok[=j002ok[=j0;o]/GV00?o/LGXojnoiOn__nD00on__nD0
1?n/^^CoZ[[UojZjiOnZ^^D4ojVgh`;oZ;KS00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0<ooooo`00??ooool00ol0003oooooooooo`0]ooooo`;oYKo/0_nY`>/3oj[2j`;o[<7Y1?n]`NP2
ojjoi`;oZkcV1?nZ^^@2ojRfh`;oYKKU0onQ]NH4oijej0;oV[S/0onSbo@2ojOFn0;o/^?g0onjh?<2
okoQl0?o^]C^0_nbbN/2ojFmj`?oUJkX0_n5W^<3og>Ah@?oLY?S0omOQ^42oh>^l@?o[Lga00?ofNOO
omoPeOoOh=D01?oKd/l2omG6b`05olo3coo:^L_ob[W;olZiboo7/lL01?nk/]02ojV^f`03o`0;W?lH
<:coXHRj00?oXHRj1?oR/jH2on_2ZPCoh;F[0ooTb;`01?o<Z;GocKg;olfmboo=_L/4ojBJb`?oK7_A
0_m=QNH2ohS;oP;o[>gh0_o1ko401?oAlnOodNCUom7TiOoAi>D3olWBh@04olG9gOnj_=_o^[cKokZl
f`Co[k7I0onMX]T3ohVDf@?oMHWI0_mYQ=X3of^9gP04ofR3f_mdS]koM8kNogB>gPCoSZ3P0_nU[ml2
ojVgh`?o^l3N00?o_LWSolO;gOo7bmd00_o7bmd2olSChP03ol_@gOo;f>?obmSS00;obmSS00?obm;O
olSGiOo8enD00_o4g>/3ol;Ci`;o_=G/0_njcNP2okC=k0Co/LGX0_n__nD2ojbni`CoZ[[U0_nY]n<5
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03?ooool003gooooo00?o0000oooo
ooooool0;Oooool4ojW0j`03oj[2jon/`NWo[<7Y00;o[<7Y0_n]`NP2oj^ni`CoZkcV0_nZ^^@2ojNi
iPCoYKKU0onQ]NH2oijej0?oX/?`0_nSbo@3ojgIm`04ok;Smonjh??o^^3cok[Pl`?o^mW_0_nje>h2
ok39k0CoYKg[0onE[^P2ohFNh`?oLi7Q0ombTn<4ogfTk0;o[Lga0oo4e^L01?o;c]cofm;?om_BcooK
d/l3omG6b`?ob[W;0oo7/lL2ok^bd0;o_jo:0_nY[]/01Ol02ico632/oj68^_nQR;[o]jO:00?oh[>V
0oo[`ZX00oobf;Goh;F[on2eZ`04onC8_0GocKg;0_nTV//2ojNki`CoQZg_00?oR<_nojc]n?n/kOP0
0_o1ko43olOXk@05om7TiOo9d^7obM;QolWBhOo1a]h01?nj_=/2ojnaf@;oZ:cJ0onGX=X3ohJEf`?o
MHgM00?oMHWIofV4f_mYQ=X00om[RMh3ogRFh`CoTZWU1OnY]n<01Onk`=ko_LWSokg9honmbN?oal_M
00Cob=?R1?o;f><2olSNj@03olSGiOo4g>_oa=c[00;oa=c[00?o`]?WokcEk?nleN`00_nfe_44okC=
k0;o/LGX0on]a>/3ojbni`;oZ[[U2Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00cooooo000nooooo`03o`000?oooooooooo02gooooo0_nY`>/3oj_1j@;o[<7Y0_n[_nP4oj^ni`;o
ZkcV0_nX^nL4ojNiiP;oYKKU0_nT_N/4oj:nk@;oX/?`0onXdOD2ojgIm`?o]]cc00Co^^3cok_Ikonk
fNoo^mW_0_ngd>d4ok39k0;oYKg[00CoVKCZohNVj?n7Y^SoQjKX0omlW>H3og>Ah@?oLY?S0_mmY>`2
oibjkP?oa=KW0oo;c]`01?oKd/ooeLK;omG6booEa//2olnlb003olZiboo7/lOoak?700;oak?700?o
^k;@okn_b_no[lX00_no[lX01?nY[]_o00^Lo`0;W?nQR;X3okNWbP;oh[>V0_o[`ZX3oo;H]@04on2e
ZooTb;coi<RlonC8_0;og>SL0oo=_L/2ol;Jk0CoYk_W0_n6[Nl2oi[Io@;oZnGj00Co`NoaolOXkOo7
j>goanS]0_o4f>P00oo9d^7o`LKNol76gP02ol76gP;o^[cK0_nb]M/4ojR/fP?oUj3J0on6UM/3ogF=
g@?oJh_P0om[RMh3ogRFh`CoTZWU0_nY]n<2ojc1jP?o_LWS0_nnd^T3olSChP;oamcX00CobmSSolSN
jOo8g^Wob=kY0_o3i>l2olCLj`?o_Mo`00?o_=G/okKFlOnfe_400_nfe_42okC=k0;o[Lc`0_n]a>/@
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool003oooooo0_l0000_oooo
o`;oZl7Y0_n[`NX4oj^oj0;oZkkW0_nY_NP4ojRki`;oYkWV0_nU_>X4ojBmj`;oX[k]0onVbO82ojSA
m@?o/MOd0_nfg?<3ok[Jl003ok_Ikongd>go]m3]00;o]m3]0_n`bN`2ojJok0?oVKCZ0on7Y^P3ogbL
iP?oM9OV0on1XnT4oibjkP04olCFioo;c]coblkLol_>g0?oblGE00CoeLK;olnlb?o?_<Sockc81Oo7
/lL5okn_bP;o]JgA00?o00^LokNWb_ngYlX00ongYlX00ooR/jKojl:Zon_2ZP03oo;H]@;oio[:00?o
i<RlomcXg?oLj=`00_oLj=`00oo=_L_o`][/ol;Jk002ol;Jk0;oYk_W0_nNf_`01?nJfOgoZnGjoj_U
n_n[iOX3ok?Um`03olOXkOo4f>Soa=SX00;o_lcT0oo1a]h00oni_Mgo/[GKok:ef`03ok:ef`?oZ:cJ
0_nGX=X01OnDXMgoQIWOohFIgon5VMooQYGK00?oMHgM0om[Rn03ofjCi@;oNj7Z00?oN9KSoi:YiOnB
ZND00_nE]>d4ojc1jP03okg9honnd^Wo_];Y00;o_];Y00?ob=?RolOLj?o7g>P00oo3i>h00oo8g^Wo
`nC_ol?Tk`03ok[Wm0;o_Mo`0_ndh?D2okKFl@?o[MGe0_n]c?0Dooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool02oooool0047ooooo00?o0000ooooooooool0;Oooool4oj_1jP;oZkoX
0_nY_nT4ojVmj0;oZ;_W0_nV_NX4ojFljP;oY;g[0_nUaO03ojK9lP;o[M3c0onaeo@3okKHl@;o^][`
0onje>d2okO@k@?o/LS[0onV_n`3oiVdjP?oQjKX0omlW>H3ogBGiP?oPJ?Y0_nL^^h3ok30iP05ol_>
g?o;aMGoblGEol_5eOo7_<l01?o?_<P01?o;]/Goak?7olNcaoo7/lL2olJ`a0?o_jo:0_o2[/D2okF]
d@05o`0;W?ngYl[o]jO:okNWb_o0g>d00_o[`ZX4oo;H]@03onOjb_mafJgoLMV]00;og>SL0onKl?42
ol;Jk0?oTnGl0_nNf_`2oiSOoP?oVMkn0_nciOL2okOHl@03olCHj?noc>Co_lcT00;o_lcT00Co`LKN
okVmgOni_Mgo^KgM0onb]M/00on//]coXj[Loj>Zg002oj>Zg0?oU:7M0on5VMl3ogNDhP?oKYGW00Co
Jh_PofjCiOm^TnGoKY?U0_mkXNX5oiFdk@;o[<7Z0_n]c?02okkBj@?o_Mg`00CoamcXol?Tk_o3i>ko
`nC^0_nlj_<01?o3i>oo^^Odok[Wm?njio@2ojoXn@;o]>3e0onYg_X2ojgEmASooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0;ooooo`00@_ooool00ol0003oooooooooo`0]ooooo`;o
Zl7Z0_nY`>X4ojVoj@;oZKgX0_nW_^X4ojJmjP;oYKcZ0_nU`^h4ojG5l003ojK9l_n]d??o[M3c00;o
[M3c00Co/MOdokKHlOnff?7o]]Sa0onhe>h2ok[Dk@?o]lg[0_nab>/01?nZ`ncoWK[]oifjkOnM^^d3
ohn_k0?oOJ?[0omiW^T3ogbPj@CoTZkZ0on``>H01?nh_mooblGEol_5eOo;aMD3olNlc`;ockc80oo;
]/D00oo7/lOoa[34olJ`a002olJ`a003okn_b_o2[/Go`Zk500;o`Zk500?o]JgAok^[bOngYlX01?o0
g>d01Oo[`Z[ol]Reoo;H]Oobf;Goio[:00;oLMV]0_mcX>d3odVMm003oc>Pl_lZ[n;o:ZoR00;o:ZoR
0_meeo`2ogC@oP;oVMkn0onSdoT2okOHl@?o]/g/0_noc>@2okS2hPCo^KgM00Co/[GKojbbg?n//]co
[;;L1?nSZ]`3oiBQg@?oQIWO0omgU>83ofjEi`?oLIk]0omn[O82oiFdk@?oUl3d0_n]c?03ojcHm`;o
_Mg`0onii_D00oo3i>ko_>[cokcZl`02ok;]m`04ok[Wm?n_j?Wo[nSiojoXn@;oX^Kl0_nYg_XMoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool004?ooooo00?o0000oooooooo
ool0;Oooool4ojW0jP;oZKoY0_nW_n/4ojNnjP;oY[gZ0_nV`Nd4ojG2kP;oYLG`0onZbo42ojg@l`?o
/]Ca00Go]]SaokSDk_nhe>ko^=C^okS@k004okO=j`03ok;9jonZ`ncoZ/?/00;oZ/?/0onM^^d3ohn_
k0?oOJ?[0omiW^T3ogbPj@CoTZkZ00Go/<3VokRogonh_moo^;oOol_5e@04olNlc`03olnlb?o;]/Go
bkK500;obkK51Oo6/<@5ol:^a@Co^j_90_o0g>d3od;2^@04oo;H]OnLY]goZ:KDojRVe0?oTJ;Q0omk
Xn`3of^Xm@?oLKKk0_mdd?h3ohS7o0;oXm?i0_nVbO83okK=k003ok;4ionh`^;o^<;R00?o^<;R0_ni
_Md00onc^Mko[;;Lojbbg003ojbbg0;oXj[L00?oWjgQoi:VhonBY^<00_nBY^<3ohFQiP;oN9oZ00Co
MiCRofjEiom^UNOoKYGW0omaW^d4ogj]lP;oUl3d0_nFcO/3ojcHm`;oYn;k0_nii_D2ok3/n0;oY>kh
0_nbkOL2ojG/n@;oU^Wj0_nRi_`Pooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2oooool004Cooooo00?o0000ooooooooool0;Oooool2ojW0jP;oYl3[1?nW_n/2ojNnjP;oY/3/1?nV
`Nd2ojG2kP?oZ<O`0_nZbo43ojo?l@;o/]Ca0onfd^l01Onhe>ko^=3/okS@k?nhd>co]lg[00Co//W[
0_nZ`n`2ojFok0?oU[K^0on7[>d3ogNRk@?oMj3/0on3Y^/3oibcj0?o^;oO0_ni^MT3olNlc`;oa;K<
0oo;]/D2olRba0?oa[340_o6[/83ol:^a@;oa:g30_nkZlT3okj[aP;o/JS?00?o]jS;ojRVe?nXY]@0
0onXY]@3oi6Rh@?oNj?/0om[Z?D4og6fn`;oR<Ol00?oTkodojK9l_nVbO800onVbO801?nfcNco//CW
ok;4ionba>L2okS2hP;o/kgQ1?nc^Mh2ojbbg0;oZ;?Q1?nO[N44oi:Vh`?oQJ7V0_mhWnX4og2Rk`?o
Ljge1?mo^oX4oiK=n`03ojcHmonWh__oYn;k00?oW^Sk00?o/>chojC^n?nTk_P00_nFk?L01?nUk?Wo
U^WjoiKYn_nFjOXTooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool004Go
oooo0_l0000_ooooo`?oYl3[0_nW_n/3ojJok0?oY/3/0_nV`Nd3ojO4kP;oZ<O`0on/bo02ojo?l@?o
/]3_0_nfd^l2okO@k0;o^=3/0onfc>/2ok;9j`;o[/G[1?nU_n`3oiJfkP?oQjc]0omgX^d3ogNPk0?o
PjK[0onL/nP00onh_moo^KWIokVif@02okVif@03olNlcoo4]/coa;K<00;oa;K<00?obkK5olRba?o8
//@00_o8//@00oo6/<CoaZk2olJ^`P02olJ^`P05ol:^aOo4[L?oa:g3olB]`onkZlT01?nnZlH01?na
Z<oo]jS;okNXbongZ</3ojRVe003ojjVd?nNXmWoWZ?I00;oWZ?I0on@Y>83ohBWj`CoQ[;b0onC_o@2
ojK9lP?oYl3[0_nba>L2ojnni@Co/kgQ0_nc^Mh2ojjih@CoZ;?Q0onO[N42oi:Vh`;oTZkY0on6Znd3
og^[lPCoL:;_0omc[OD2ognknP?oO/Sn0_nCf?h2oh_OoP;oW^Sk0_nBjOP2ohGVl`;oU^cg00?oQnOd
ooooooooool09oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo0017oooo
o`03o`000?oooooooooo02gooooo1_nV_n`2ojK1k0CoY/;]0_nWa>h3oj[8k`;o[<_`0on`c>l2ok;@
k`;o]Lo]0_ngd>`3okO=j`;o]/c[0_ncbNX4ojk5j`;oYKo/0_nO_>d3ohnck`?oPJ[^0omcXNd2ogRQ
k0?oQjOY1?nQ/N@3okVif@03okRde_o4]/coa;K<00?oa;K<1Oo8//@5olJ^`PCoa:g31OnnZlH5okNX
b`04ojRVe?n^Y]3o[ZK@ojjVd0CoWZ?I0on@Y>83ohBWj`;oQ[;b0_nC/>/4oi^ik@;oYl3[0_nX_>P4
ojnni@;o/kgQ0_n__>@4ojjih@;oZ;?Q0_nU]^D3oifbiPCoTZkY0on6Znd4og^[lP?oLk3g0ome^_`2
ogk8oP?oN];o0_n;goh01?n2hOWoNN7cogWQlomihO<2ohGVl`03og_Sl?oooooooooo02[ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`00B?ooool00ol0003oooooooooo`0]
ooooo`CoY[o/1?nV`N`2ojK2k@;oZLG^0onZb>l2ojg9kP?o/<c_00Co/lc]okG?kOnecngo]Lo]0_nf
cN/3okO=j`;o]/_Y1?ncbNX2ojk5j`?oZ/?/0onO_>d3ohnck`?oPJ[^0omcXNd2ogRQk0?oQjOY1?nQ
/N@01?ni^MWo^;CFokRde_nh]=H3olBfc0;o`K;;0oo8//@2olJ`a0GoaZk20_o4[L<2olF]`P?o_Z_6
0_o1[<D3okNXb`03okZZb_n^Y]3o[ZK@00?o[ZK@0_nNXmT00onVYmOoVjKNoi^VgP02oi^VgP?oTZWU
1?nC/>/2oi^ik@;oWkKY1?nX_>P2ojnni@03ojfni_n__>Co[kcT00?o[kcT0_n^^N400on[^nGoYKKU
ojFfi@03ojFfi@?oWK;V0_nB[^T2oi:gl0?oR;Od1?mm^OT3ogFno@CoM<Oo0_mjd_l01?mff?_oM=_g
ogCKmomdfoL2ogWQl`03ogCOkooooooooooo02kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0;ooooo`00BOooool00ol0003oooooooooo`0]ooooo`CoY[o/0_nV`N`2ojS2k0CoZLG^
00?oZ/S_ojg9k_n]bNh00_n]bNh01On`c>oo/lc]ok?<kOncc>go]Lo]00Co]/g[00?o]lg[okK;jOnf
bnT00_nfbnT2ok?9jP?o/<KZ0_nZ`n`2ojK0k0?oVk[^0on:/Nl3ogbWk`?oL9o^0_mgX>`3ohNWj@;o
XK7T0_nQ[n44okRdeP03olBfc?o1//_o`K;;00;o`K;;00?ob;;4olJ`a?o6/<@00_o6/<@4olJ^`P03
olB]`oo5[L;oaJg200;oaJg200?o_Z_6ol6/aOo1[<D00_o1[<D01?ngZ<_o^Z[:okZZb_njZ/X3ojjV
d003ok:Zd?nVYmOoYZOG00;oYZOG1?nKY]h3oi:Yi@;oTk3[00?oVk3VoinfjOnO]^T00onO]^T3ojRl
j0Co[KkV0_n__>@2ojbmiPCoZk_U0_nU]^D2oj>lj`CoW;[]1?nB]o03ohRgm0;oOKWi0_n1aOd4ogS:
o`;oM=7n00CoMmSloggNn_mmg_[oOMkj0_mfg_@dooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool004[ooooo0_l0000^ooooo`;oY[o/0_nX`>/4ojS2k0;oZLG^0on/a^d2ojg9
kP;o/<W/0_ncc>d3okC;j`;o]/g[1OnfbnT3okC8j@;o/<KZ0_n^a>X4ojK0k0?oVk[^0on:/Nl3ogbW
k`?oL9o^0_mgX>`3ohRVj0CoXJoQ0_nh]=H2okB`e0?o`K;;00?o_[3;olJ`a?o6/<@00_o6/<@00oo5
/<GoaZk2olJ^`P02olJ^`PGoaJg21Oo1[<D5okZZbP04ojjVd?nbZ]3o/Z[@ok:Zd0?oYZOG0_nKY]h2
oj:Zg0?oVj_R1?nK/>H2oinfj@;oX[SX1?nX_>P2ojfniP;oZkkX1?n/_NH2oj^ki@;oZ;oZ1?nS_>/2
oibjk@;oW<7a1?nD`?D3oh_2n@;oPLGm0on8col2ogkDo`;oQm_n0_mmg_Xiooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02_ooool004cooooo00?o0000ooooooooool0;?ooool4ojS0
j`;oZ<;/0on[`n`2ojc6k@;o[lO/0_n`bN`3ok?9j`;o]<_[0_nfb^T3okK;j@;o]/WY0ondb>T2ok?7
j@Co[/CZ0_nV`>`01?nS_^coUkO^oiNgk_nG]nh3ohJ]k`?oN:C^0om]W>d3ogBMj`?oR:KX0_nQ[n40
0onOZmoo];3DokB`e003okB`e004ol6bbonn/<_o_[3;okj`b`;oa[340oo5/<D2olJ^`P;oak330oo5
[L82olJ_``?o`Jc50_o2[/H3okZZbP03okb^c?nbZ]3o/Z[@00;o/Z[@0_nVYmL2oj^[e`CoXZ[L0onK
Zn82oi^`iP;oX;CV1?nR^>P2ojRlj0;oYkgY1?n[_^P2ojbmiP;oZL7[1?nX_nX2oj>lj`;oX/;_1?nL
`O42oiC0m@;oV<Sh1?n@bo`2ohS?o`;oT=Oo0_n7fohlooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02_ooool004gooooo00?o0000ooooooooool0;?ooool2ojS0j`?oZ/7Z0_n[`n`0
1?n]a>[o[lO/ojo7k?n_an`2ok76jP?o/lW[0_ndb>T4okK:j@03okK;jOnfbNWo]/WY00;o]/WY00?o
]<SYok?7jOncanT00_ncanT2ojk4jP;o[<;Z0onS_^`3oiNgkP?oQZg_0omhY>h3offLk@;oM9g[0on6
XnL4oin[g`?o];3D00?o/ZkEokj`bonn/</00_nn/</00oo6/<CoaK35olF`a@02olF`a@03olJ^`_o7
/<?oak3300;oak3300?oaJg2olJ_`oo6[l<00_o6[l<01Oo1[<Go`Zk6ol:^a_o2[/Ko^Z[:00Co_:k<
0_nbZ]02okF_dPCoZj_G0_nRZ]`2ojN`g`?oXK7S1?nP]>H2oj:hj0;oY;_Y1?nW_NT2oj^nj0;oZL;/
1?nY`N/2ojRojP;oY/?^1?nR`^l2oic1l@;oW/Od0_nHb?P3oig>n@;oUm;l@oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00[ooooo001>ooooo`03o`000?oooooooooo02gooooo0_nZ
`NX2ojg1j@?o[LCZ00?o[lO/ok76j_naa^X00_naa^X00oncbN_o]<SYokC8j@02okC8j@;o]/[Y0onf
bNP2okK9j@?o]/SX0_ncanT2ok;5j0Co[<;Z00?oXkk/oj2kk?nP^n`01?nC]>h2oh6Zk`?oLj7^0_mY
VN`3ogBMj`?oQZ?W1?nOZml01?nd/=Co/ZkEok:^eOnb[]D2okj`b`03okf`cOo5/<GoaK3500?oaK35
1Oo7/<<5olJ_``?o`Zk600?oa;?:okb^c?nl[/`00onl[/`5okF_dP;oZj_G0_n_/]/4ojN`g`?oXK7S
0_nP]>H2oj>hj0CoY;_Y0_nW_NT00onW`NcoZL;/ojW2k003ojW2k0;oZL7[0_nXa>h2ojK3kP;oYLOa
1?nRa_82oik7m0?oXLcf0_nMc_U7ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2_ooool004oooooo0_l0000^ooooo`Co[L7Y00Co[LCZok34jOn`a>Wo/<CY0_naa^X3ok?6j0;o]<SY
0onfanP2okK9j0?o]lOW0_nfb>P2okG6i`Co//GX0_n/`^X2oj[0jP?oX;_/0_nC]>h2ohnak@;oOJK^
0omcXNh2ofVIk0?oL9[Z0_n3XNH4oibYg`Co/ZkE00Co_[3;okf`cOnm/<go_K3=0oo5/<D2olFba`?o
ak330_o7//H3olJ_``;oak?600Co`Zk6olBcb_o4/l[oa;?:0onl[/`2okjcd0?o]JoB00?o^;KHojnb
fon_/]/00on_/]/2ojN`g`03ojZgh_nU]^GoYKKU00;oYKKU1?nS^>P2ojBkj@;oYL3/0onW`N`2ojW2
k0?oZ<G_0_nXa>h2ojK7l@CoYLOa0_nRa_82oj?:m0;oXLcfC?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00[ooooo001Aooooo`03o`000?oooooooooo02cooooo0_n]`NT2ojo2i`;o
/<CY0_nba>L3ok?6j0;o]LKW0onfanP2okO7iP?o]lOW0_nganH4okG6i`;o//GX0_n``nP2oj[0jP;o
YkgY0onM^>`4ohnak@;oOJK^0om_WNd2ofFFj`?oL9[Z0_n3XNH4oibYg`;o/ZkE00?o[jkGokf`cOnm
/<d00onm/<d00oo5/<GoaK;7olFba`02olFba`03olN``oo7//Koak;600;oak;600CoaZo3olNca_o7
/lKoak?61Oo4/lX00onl[/co_[?@okjcd002okjcd004okF_d_nh]]So^;KHokRff0?o[k;K00?o/KWP
ojZgh_nZ]n800_nZ]n82ojFfi@;oYkkZ1?nU_^/2ojG0k0;oY/C_1?nWaNl2ojS5k`03ojO8lOnVao7o
Y/Oa00?oY/Oa0_nUao42ojG:l`;oXl[dCoooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00[ooooo001Booooo`03o`000?oooooooooo02_ooooo0on_`^L2ok72iPCo//CW00?o/lKXokG6
ionea^L00_nea^L00onfanSo]lOVokO7iP02okO7iP03okO7ionganKo]lOV00;o]lOV0_nea^L2okC5
i`;o/<?X0_n_`NL4ojNmj@?oWKS/0_n?/Nd2ohb^k@;oNJC]0om_WNd2ofFFj`;oK9OY0omnW^L2oibY
g`03oiRXhOn_[]Oo[jkG00;o[jkG0onm/<d2ok^bd0?oaK;70_o5]L/3olNbaP04olNgb_o7/lKoak?6
olNcaP;ob;W;0oo4/lX2olBic`?o_[?@00?o_kcFokRff?nh]]P00_nh]]P00on_/]_o/KWPok6ih002
ok6ih0;oZ[OR0_n/_nP4ojNnjP;oYKk[0_nV`nh4ojK4k`;oYlG_0_nVb?43ojO8l@;oY/Oa1OnUb_=C
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool005?ooooo00?o0000oooo
ooooool0:oooool00on_`^Oo/L;Vok72iP02ok72iP;o//CW0onda>H2okG6i`?o]/KV0_nganH3okO6
iP;o]lOV00Co]lGUokC5iondaNOo]<GW0_nc`nH4ojo1i`;oYkgY0_nU^nT4oiZej`?oS:k]0_miY>d3
of^Kk0;oH9C[0_m/UnT3ogjNi`?oV:SQ1?n_[]L00onm/<go^k;@ok^bd002ok^bd003olFbaoo5]L_o
aKG;00;oaKG;00Goak;6olNgb_o7]l[oakO:olNcaP04olRib`03olBcb_o4^Looa;W?00;oa;W?00Co
_[?@oknle_no_=Ko_kcF0_nh]]P2okVngP?o/KWP0_na`^L4ojboj0;oYkkZ00?oZ<?]ojK3k_nV`nh0
0onV`nh2ojK4k`;oY/Oa0_nVb?46ojK:l`;oYL[cEoooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Wooooo001Dooooo`;o0000;Oooool2ok72iP?o/l;U0_nda>H2okK4i@?o]/KV0_ng
aND3okO6iPGo]lGU00?o]<GWok?3i_nc`nH00_nc`nH2ojo1i`;o[KoW1?nU^nT2oiZej`04oiNbj_n9
ZncoRJ_/ohV[k0?oMZ;]0om[Vn`2of2Dj`;oIYKZ0omnW^L3oiRXh@;o[jkG0_n//=X3ok^bd003okZf
eOo5]L_oaKG;00;oaKG;00?oa;[AolNgb_o7]lX00_o7]lX01?o8_M3ob;W;olRiboo8^L/2olRodP?o
a;W?00CoaL;Goknle_no_=Ko_kcF0_noa=h4okVngP03ok6ih?na`^Oo/L;W00;o/L;W0_n/_nP00on/
aNgoZ<?]ojS3k@02ojS3k@;oY/?^1OnVao42ojG:l`KoY/[cF_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Wooooo001Fooooo`03o`000?oooooooooo02_ooooo0onc`^D2okC3i@Co
]/CU00?o]/KVokO5iOngaND00_ngaND00onga^Ko]lGUokO5i@03okO5i@?o]/CU0_nc`nH2ok;1i@Co
[KoW0_nU^nT00onS^>SoUk;ZoiNbjP02oiNbjP?oRJ_/0_mfX^d3ofNIk@?oG9?/0_mVU^X3ogVNj@?o
TjST1?n//=X01?nk/]3o^[KEokZfeOnj]]D2olFeb`?oa;[A0_o7]lX3olRmd003olRiboo8_m;ob;oB
00;ob;oB00Goa;W?olG2eoo5`]OoaL;GoknleP04oko4gP;o^KkN0onhb>H2ok72i`03ok39kOn/aNgo
[<G]00;o[<G]0_nX`nd3ojO8l@;oY/Oa0onVb_<3ojG:l`;oY/[cG_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Wooooo001Gooooo`03o`000?oooooooooo02_ooooo00?o/l;UokC3
iOnd`nD00_nd`nD2okK4i@?o]lCT0_ngaND2okS5i0;o]lGU0onga>@2okK4i@;o]/?T1?nb`ND2ojfo
i`?oZkcV0_nS^>P2oiNbjP;oUK3Z0on7Z^`2ogBQk@?oIiW]0_mLTn`3of6Fk0?oNIkY0onCZ>@2ojb`
fP03ojVch?nj]]Go^[KE00;o^[KE00?oaKG;olBjdOo4^]400_o4^]400oo7]l[ob;g@olRmd002olRm
d005olS6f?o8_m;ob;oBolRod_o8bM/00oo5`]L2olC<h0?o_lCN0_nmcnL3okS8iP03okG?kOn`bNgo
/<W]00;o/<W]0_n/aNd3oj[;l@;oYlSa0_nVbo<2ojK:lfKooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`09ooooo`00F?ooool00ol0003oooooooooo`0/ooooo`;o]<?U0_nf`n@3okO4
i0;o^<CT0onhaN@01?nha>?o]lCTokO4i?nga>@2okO3h`Co]/?T0_nb`ND3ok6oi0;oZkcV00CoZK[U
oj6fionQ]^OoXKKW1?nE/>X3ohNZk0;oM:7]0omUV^d2oeVDk@;oHIK/0omcWn`3ohj[j@CoZK?P0_nj
]]D2okVkg0?oa;[A0_o4`]P3olRmd0?ob<KH00Gob;oBolS9foo8bM_ob<WKolG2e`04olC<h003oko4
g_nmcnOo_LoW00;o_LoW00Co^<SVokG?kOnecngo]Lo]0_n`bNd3ojg?lP;oZ/_a0_nWc_@2ojK;lf[o
oooo00Go0000ooooooooooooooooo`00000;ooooo`00FOooool00ol0003oooooooooo`0/ooooo`Co
]/?T00?o]lCTokS4i?nha>@00_nha>@01OnhaNCo^<CSokS4honha>?o]lCT00Co]l?S0_nf`n@3okC1
h`;o/KoT00?o[kgTojVjiOnY^^D00_nY^^D3oj6fi`;oUK3Z0_nD[nT3ohJYk0;oM:;^0omUV^d2oeVD
k@;oG9O_0omcWn`3ohj[j@;oZK?P0_nV^NH4okVkg003olBjdOo4`]Soa<;H00;oa<;H00Gob;g@olS6
f?o8a]Sob<KHolKAhP03olS9f`?oa]CT0_o4c>03ol7GjP;o_LoW0_nienl2okG?k@?o[mGd0_n]co82
ojSBmP;oYlkdKOooool01Ol0003ooooooooooooooooo000000_ooooo001Jooooo`;o0000;Oooool2
okK3i0?o]l?S0_nha>@7okS4h`;o]l?S0_ng`^<3okC1h`03ok>ohon__NCo[kgT00;o[kgT0_nY^^D2
ojRhi@?oWkCW1?nD[nT3ohJYk0;oM:;^0omTVnl2oeNGl0;oG9O_0om]XO03ohV_k`CoY[WV0_ni^m`2
okO4i0?oa<;H0oo3bn401Oo8a]Soa]7RolKAh_o6dN;ob<WK00?oa]CT0_o1gnh2ol7GjP?o^]ob0_ni
enl3ok3LmP;o[mGd0_nXf?P2ojSBmW7ooooo00Co0000oooooooooooo00002oooool005cooooo00?o
0000ooooooooool0:oooool3okO3h`04okS3honha>?o^<CSokS4h`;o^L?R0onha><2okS3hPCo]l;S
00Co]<7Sok>ohonc_n?o/koS0_n__N@2ojjkh`CoZ;SU0onO]>L2oiB_j@;oTjoY0_n6Z^`3ogFTk`?o
I9__0_mGUo02oeRKlP?oKJ7`0on9[nl2ojJiiP;oX/3_1?nga>@01Oo4`]So`l_Qol?;hOo3bn7o_mO[
00?oa]7R0oo3g>`00oo6e>Co`Mo^ol7OkP03okOWmP;o^]ob0on_i?T2ok3LmP;oY]kk0_nXf?Qeoooo
o`03o`000?oooooo000000_ooooo001Mooooo`03o`000?oooooooooo02_ooooo00Go]l?SokS3honh
`n?o^<?SokS4h`04okW3hP03okS4honh`n;o^<?R00;o^<?R0_ng`^<2okK1hP;o/koS0_nb_N84ojjk
h`;oZ;SU0_nV]^@4oijciP?oTjoY0_n6Z^`3ogFTk`;oIYoa0omGW?83oeRKlP;oIZGd0on3]OD4oj;0
k`;o]lCT0_nccNd00oo3bn7o_mO[okoGj`02okoGj`04olKAh_o3g>co`mc/ol?Lk0;o^^Kd00Co`Mo^
okOWm_ngioKo]nOf0onXj_X2ojoTn@;oXNGl0_nVg_]hooooo`04o`000?ooooooooooo`0000[ooooo
001Nooooo`03o`000?oooooooooo02_ooooo0_nh`n<3okS3hPGo^L?R0_nh`n82okO2hP?o]/7R00?o
]KoRok:mh_nb_N800_nb_N82ojjkh`;o[;WS1?nV]^@2oijciP04oijbi_nD[nWoU:oYoiB_j@?oR:c]
0omhYo02ofVUl`?oEicb0_mFX?D3of:[n0?oPkGe0_nR`>l2oic8m`;o/lg]0on]f?H2okoGj`?o^N7d
00?o`mc/ok[Vm?nji_@00on]k?T01?ngioKoZ>[jojSZn_nXj_X2oiOXn`;oXNGlO?ooool00ol0003o
ooooo`00000:ooooo`00Goooool2o`0002cooooo1Onh`n83okW3hP;o^<?R1?ng`^801?nf`N;o]KoR
okFoh_ne_n82ok:mhP;o/KcR1?n/^N<2ojJfi003ojFei?nN/^KoW[;V00;oW[;V0onD[nT3ohR/k@?o
N:O`0omYYO<2oeZSmP;oEZOh0omRZoP3ogbkn`;oW<Sg0onCdOd2ojgHmP?oXn3l0_nihO@01?n]jOWo
WN_ioig[nOnMjoT2ojg/n@;oW>ci00?oR^Ofooooooooool0POooool2o`0000[ooooo001Qooooo`03
o`000?oooooooooo02[ooooo1Onh`n800oni`n;o^<?RokS3hP02okS3hP;o]l;R0_ng`N82okFohP;o
/kkR1?na_>82ojbih`03oj^hhonU]NCoYKGT00;oYKGT1?nN/^H3oiJ`j@?oRjk]0omm[?83og2/mP;o
HJci0omFYoP3oefbn`?oM<;n0_nCdOd3ohWGo`;oXn3l00CoU^ClohOTn?n7i?SoQnCh0_nMjoT00on<
j?GoO^CaogkTl@25ooooo`?o00002_ooool006;ooooo00?o0000ooooooooool0:oooool7okS3hP04
okS2h_ng`N;o]l7RokO1hP;o]L3R1?nc_^82ok6lhP;o[k[R0on[^><4ojFei0CoW[;V0onF/>T3oh^^
k@?oOJcb0om`[?H3of6/n@?oF[3k0omM^O`3ofg7o`;oRMOo00CoOM[mogGKn?mefoSoMM_h0_n7i?P0
0omlh_?oMN3_ogGPk`24ooooo`Co00003Oooool006?ooooo00?o0000ooooooooool0:oooool3okS3
hP03okS3honh`^;o^<;R00;o^<;R00?o]l7RokG0h_ne`>800_ne`>82ok>nhP;o/[gR1?n_^^800on[
^>?oZ[OSojZgh`04ojFei0;oW[;V0_nO/nH3oiRbj@?oT;;^0on4/_83ogVcn0?oJkGk0omR^_d2of32
o@?oJ<[m0_mYdOX2ofoGn@;oL]cd0_mdg_:3ooooo`Co00004Oooool006Cooooo0_l0000/ooooo`04
okS3h_nh`n?o^<?SokS3h`;o^<;R0ong`^82okG0hP;o];oR1?nb_N82ojnjhP;o[[WR0onZ]n<2ojFe
i0;oYKCT1?nO/nH3oiRbj@03oi2bk_nE]NgoUKG]00CoSKOb0on4^oP3ogRoo@;oK/Co0ommc_l2ogCC
oP;oQ=_n0_mjgOV3ooooo`?o00005Oooool006Kooooo00?o0000ooooooooool0:oooool00onh`n?o
]l?SokO3h`03okO2hP;o]L7S1?nd_n82ok:mhP;o/;cR0_n^^N82ojbihPCoZKOS0onU]>@2oinciP03
oj6di_nL]>WoW;CY00;oW;CY0onE]Nd2ohfglP;oU[ca1?n?`OP3ohO7o@;oOLko00?oS]Kooooooooo
ool0Poooool4o`0001Sooooo001Wooooo`03o`000?oooooooooo02[ooooo1?ng`n<00ong`^;o]L7S
okG1h`02okG1h`;o];oR00Co/[kSok2lh_n`_>;o/;cR0_n_^n84ojbihP;oZKOS00CoZ;KSojFei?nU
]NCoYKGT1?nQ]>H2oibdj@;oWkKX1?nK^>`3oiJll@;oSl7h0_nKa_H2oiK>nhCooooo1?l0000Loooo
o`00J?ooool00ol0003oooooooooo`0Zooooo`;o]l?S0onf`n@2okG1h`;o/l3S0onb_^<00on`_>;o
[k_RojnkhP02ojnkhP;o[;WR0_n[^>83ojRfh`?oYKGT0_nQ]>H2oj>ei@CoWkKX0_nK^>`00onR^n_o
Wko`oinol002oinol0;oVlKfPoooool4o`00023ooooo001Yooooo`;o0000;?ooool2okK3i0;o]<?U
1?nc`><01?nb_^?o/;gSok2mhon`_N<2ojnkhP;o[K[S1?n[^>83ojRfh`CoY[GS0onS]ND2oinfj003
ojBhionR^n_oX[_[00;oX[_[0_nO_o22ooooo`Co00009?ooool006_ooooo00?o0000ooooooooool0
:_ooool4okC3i@;o/l3S0_nb`>@2ok2mh`;o[[cT1?n]^^<2oj^hhP03ojZghonX]^?oZ;KS00;oZ;KS
0_nV]N<2ojNfh`CoYKKU0_nT^>L2oj:kjh;ooooo0ol0000Xooooo`00K?ooool00ol0003ooooooooo
o`0Zooooo`;o]<?U0_nb`^H2ok;0i0;o[koU1?n^_>@2ojfjh`03oj^ii?nZ]n?oZ[OS00;oZ[OS1?nX
]^<4ojNfh`;oYKKUPoooool4o`0002_ooooo001]ooooo`03o`000?oooooooooo02_ooooo00?o//;V
ok32ion``^L01?n__nD2ojjli0;o[;cU0on[^N@2ojZgh`;oZKOS1?nX]^<2ojNfhh;ooooo1?l0000_
ooooo`00K_ooool00ol0003oooooooooo`0Zooooo`Co/<;W0_n__nD2ojfniPCo[;cU00?oZkWTojVi
i?nY^N@01?nY]n<2ojRfhh7ooooo1?l0000cooooo`00Koooool2o`0002_ooooo0_n``^L2ojg1j0Co
[KkV0_n/_>D2ojZkiP?oZKWT0_nY]n>0ooooo`Co0000=oooool0077ooooo00?o0000ooooooooool0
:_ooool3ojg1j0;o[KkV0_n[_^P2ojZkiX;ooooo1?l0000kooooo`00L_ooool00ol0003ooooooooo
o`0Zooooo`?oZl7Z0_n[_^R2ooooo`?o0000?oooool007?ooooo00?o0000ooooooooool0:_ooool0
0on[`N[oooooooooo`1oooooo`Co0000@_ooool007Cooooo0_l0000Zooooo`03o`000?oooooooooo
07_ooooo1?l00016ooooo`00M_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07So
oooo1?l0001:ooooo`00Moooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07Cooooo
1?l0001>ooooo`00N?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo077ooooo0ol0
001Booooo`00NOooool2o`0002Cooooo00?o0000ooooooooool0KOooool4o`0005Gooooo001koooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0JOooool4o`0005Wooooo001looooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0IOooool4o`0005gooooo001mooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0HOooool4o`00067ooooo001nooooo`;o00007ooo
ool00ol0003oooooooooo`1Mooooo`Co0000IOooool0083ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`1Jooooo`?o0000JOooool0087ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`1Fooooo`Co0000K?ooool008;ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`1Booooo`Co0000L?ooool008?ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`1>ooooo`Co0000M?ooool008Cooooo0_l0000Iooooo`03o`000?oooooooooo04[ooooo1?l0
001hooooo`00Q_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Kooooo1?l0001l
ooooo`00Qoooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04?ooooo0ol00020oooo
o`00R?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03oooooo1?l00023ooooo`00
ROooool2o`0001Cooooo00?o0000ooooooooool0>oooool4o`0008Oooooo002;ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0=oooool4o`0008_ooooo002<ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0<oooool4o`0008oooooo002=ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0<?ooool3o`0009?ooooo002>ooooo`;o00003oooool00ol0003o
ooooooooo`0/ooooo`Co0000U_ooool0093ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Xooooo`Co0000V_ooool0097ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Tooooo`Co0000W_ooool009;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Q
ooooo`Co0000X_ooool009?ooooo0_l00009ooooo`03o`000?oooooooooo01gooooo1?l0002Voooo
o`00UOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo0ol0002Zooooo`00
U_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo1?l0002]ooooo`00Uooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo1?l0002aooooo`00V?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0002eooooo`00VOooool2o`00
00?ooooo00?o0000ooooooooool02_ooool4o`000;Wooooo002Kooooo`04o`000?ooooooooooo`00
00Wooooo0ol0002mooooo`00W?ooool00ol0003oooooo`000005ooooo`Co0000`?ooool009gooooo
0_l000000ooooooo0000o`000002o`000<Cooooo002Nooooo`;o0000b?ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00:[ooooo00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`Go00001Oooool00ol0
003ok^k^ooooo`05ooooo`;o8B4Q1?ooool5o`0009?ooooo002Zooooo`05oa0@4?nj^[[ok^k^ogMg
Mol@41000_ooool6o`000006oooooonHV9So8B4Qonk^k_ooooooA4A41Oooool00omEEEGoZJVYoooo
o`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A409?ooooo002Zooooo`03o`000?oo
oooooooo00cooooo00?oV9RHob4Q8Oo^k^h01_ooool00onYZJWoEEEEooooo`0<ooooo`03oiRHV?lQ
8B7ok^k^09Cooooo002Zooooo`03o`000?oooooooooo00Cooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^00Kooooo00?o8B4Qooooooooool03?ooool00onHV9So8B4Qonk^kP2Cooooo`00Z_ooool00ol0
003oooooooooo`0>ooooo`03ogMgMomVIVKooooo00Gooooo00?oEEEEolc<c?ooool03Oooool00omg
MgOoIVIVooooo`2Booooo`00Z?ooool00ol@413o0000o`000003o`0000kooooo00?o0000oooooooo
ool01?ooool00onYZJWoMgMgooooo`0>ooooo`03o`000?oooooooooo097ooooo002Zooooo`03o`00
0?oooooooooo00_ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05oa0@4?oooooooooooooo
oolb<S802oooool01Ol0003o^[ZjoooooonHV9So410@09?ooooo002Zooooo`03o`000?oooooooooo
00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`Go00002oooool01OnHV9So410@o`000?lQ
8B7oc<c<09?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -17 0 ]
[.5 .82364 17 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(28.) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.66 .752 .918 r
.39636 .6972 .40169 .70185 .41061 .69934 .40531 .69457 Mtetra
.659 .748 .916 r
.40531 .69457 .41061 .69934 .41957 .69681 .41428 .69197 Mtetra
.656 .745 .915 r
.41428 .69197 .41957 .69681 .42855 .69428 .42328 .68943 Mtetra
.653 .744 .917 r
.42328 .68943 .42855 .69428 .43756 .69174 .43231 .68695 Mtetra
.647 .746 .921 r
.43231 .68695 .43756 .69174 .4466 .68919 .44136 .68458 Mtetra
.642 .753 .929 r
.44136 .68458 .4466 .68919 .45567 .68663 .45045 .6823 Mtetra
.634 .763 .941 r
.45045 .6823 .45567 .68663 .46478 .68407 .45956 .68012 Mtetra
.625 .779 .955 r
.45956 .68012 .46478 .68407 .47391 .68149 .46871 .678 Mtetra
.613 .798 .97 r
.46871 .678 .47391 .68149 .48307 .67891 .47789 .67592 Mtetra
.601 .82 .984 r
.47789 .67592 .48307 .67891 .49227 .67632 .48711 .67382 Mtetra
.588 .841 .993 r
.48711 .67382 .49227 .67632 .50149 .67371 .49635 .67163 Mtetra
.579 .859 .996 r
.49635 .67163 .50149 .67371 .51075 .6711 .50564 .6693 Mtetra
.579 .872 .994 r
.50564 .6693 .51075 .6711 .52004 .66849 .51495 .66677 Mtetra
.591 .881 .992 r
.51495 .66677 .52004 .66849 .52936 .66586 .5243 .66403 Mtetra
.616 .883 .99 r
.5243 .66403 .52936 .66586 .53871 .66322 .53368 .66104 Mtetra
.643 .875 .984 r
.53368 .66104 .53871 .66322 .54809 .66058 .54309 .65786 Mtetra
.667 .854 .971 r
.54309 .65786 .54809 .66058 .55751 .65792 .55253 .65451 Mtetra
.681 .824 .952 r
.55253 .65451 .55751 .65792 .56695 .65526 .56199 .65107 Mtetra
.686 .791 .93 r
.56199 .65107 .56695 .65526 .57643 .65259 .57148 .6476 Mtetra
.685 .758 .907 r
.57148 .6476 .57643 .65259 .58595 .6499 .58101 .64415 Mtetra
.681 .73 .887 r
.58101 .64415 .58595 .6499 .59549 .64721 .59056 .64077 Mtetra
.677 .707 .87 r
.59056 .64077 .59549 .64721 .60507 .64451 .60014 .63744 Mtetra
.673 .687 .855 r
.60014 .63744 .60507 .64451 .61468 .6418 .60975 .63415 Mtetra
.67 .671 .842 r
.60975 .63415 .61468 .6418 .62432 .63908 .6194 .63086 Mtetra
.668 .657 .83 r
.6194 .63086 .62432 .63908 .634 .63636 .62907 .62756 Mtetra
.665 .644 .819 r
.62907 .62756 .634 .63636 .64371 .63362 .63878 .62428 Mtetra
.662 .632 .81 r
.63878 .62428 .64371 .63362 .65345 .63087 .64851 .62102 Mtetra
.657 .621 .802 r
.64851 .62102 .65345 .63087 .66323 .62811 .65829 .61787 Mtetra
.652 .612 .797 r
.65829 .61787 .66323 .62811 .67304 .62535 .6681 .61488 Mtetra
.646 .606 .795 r
.6681 .61488 .67304 .62535 .68289 .62257 .67795 .61208 Mtetra
.642 .604 .796 r
.67795 .61208 .68289 .62257 .69277 .61979 .68785 .60948 Mtetra
.638 .606 .801 r
.68785 .60948 .69277 .61979 .70269 .61699 .69779 .60703 Mtetra
.636 .611 .808 r
.69779 .60703 .70269 .61699 .71264 .61418 .70778 .60469 Mtetra
.636 .62 .817 r
.70778 .60469 .71264 .61418 .72262 .61137 .71781 .60239 Mtetra
.637 .632 .828 r
.71781 .60239 .72262 .61137 .73264 .60854 .72787 .60009 Mtetra
.638 .644 .84 r
.72787 .60009 .73264 .60854 .7427 .60571 .73798 .59779 Mtetra
.638 .658 .853 r
.73798 .59779 .7427 .60571 .75279 .60286 .74812 .59549 Mtetra
.637 .673 .868 r
.74812 .59549 .75279 .60286 .76291 .60001 .75831 .59324 Mtetra
.634 .69 .885 r
.75831 .59324 .76291 .60001 .77308 .59714 .76854 .59104 Mtetra
.629 .711 .906 r
.76854 .59104 .77308 .59714 .78328 .59427 .77882 .5889 Mtetra
.623 .738 .929 r
.77882 .5889 .78328 .59427 .79351 .59138 .78914 .5868 Mtetra
.614 .768 .954 r
.78914 .5868 .79351 .59138 .80378 .58849 .7995 .58466 Mtetra
.602 .801 .976 r
.7995 .58466 .80378 .58849 .81409 .58558 .8099 .58244 Mtetra
.591 .832 .99 r
.8099 .58244 .81409 .58558 .82443 .58267 .82033 .58004 Mtetra
.581 .856 .995 r
.82033 .58004 .82443 .58267 .83482 .57974 .83077 .57744 Mtetra
.58 .872 .994 r
.83077 .57744 .83482 .57974 .84523 .5768 .84124 .57459 Mtetra
.59 .881 .992 r
.84124 .57459 .84523 .5768 .85569 .57385 .85172 .57152 Mtetra
.609 .883 .991 r
.85172 .57152 .85569 .57385 .86618 .57089 .86223 .56824 Mtetra
.631 .876 .987 r
.86223 .56824 .86618 .57089 .87672 .56792 .87275 .56481 Mtetra
.65 .86 .98 r
.87275 .56481 .87672 .56792 .88729 .56494 .8833 .5613 Mtetra
.662 .839 .968 r
.8833 .5613 .88729 .56494 .89789 .56195 .89388 .55775 Mtetra
.667 .814 .954 r
.89388 .55775 .89789 .56195 .90854 .55895 .90451 .55423 Mtetra
.668 .792 .941 r
.90451 .55423 .90854 .55895 .91923 .55594 .91517 .55078 Mtetra
.666 .773 .93 r
.91517 .55078 .91923 .55594 .92995 .55292 .92589 .54743 Mtetra
.663 .759 .922 r
.92589 .54743 .92995 .55292 .94071 .54988 .93666 .54417 Mtetra
.659 .75 .917 r
.93666 .54417 .94071 .54988 .95152 .54684 .94748 .54102 Mtetra
.656 .745 .915 r
.94748 .54102 .95152 .54684 .96236 .54378 .95835 .53794 Mtetra
.654 .744 .916 r
.95835 .53794 .96236 .54378 .97324 .54071 .96927 .53491 Mtetra
.652 .746 .918 r
.96927 .53491 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.665 .754 .916 r
.391 .69252 .39636 .6972 .40531 .69457 .39997 .68977 Mtetra
.662 .748 .914 r
.39997 .68977 .40531 .69457 .41428 .69197 .40896 .68708 Mtetra
.657 .744 .914 r
.40896 .68708 .41428 .69197 .42328 .68943 .41798 .68451 Mtetra
.65 .742 .917 r
.41798 .68451 .42328 .68943 .43231 .68695 .42702 .68209 Mtetra
.639 .742 .923 r
.42702 .68209 .43231 .68695 .44136 .68458 .4361 .67989 Mtetra
.628 .747 .933 r
.4361 .67989 .44136 .68458 .45045 .6823 .44519 .67788 Mtetra
.613 .755 .946 r
.44519 .67788 .45045 .6823 .45956 .68012 .45432 .67609 Mtetra
.598 .768 .961 r
.45432 .67609 .45956 .68012 .46871 .678 .46348 .67444 Mtetra
.58 .785 .977 r
.46348 .67444 .46871 .678 .47789 .67592 .47267 .67287 Mtetra
.565 .806 .99 r
.47267 .67287 .47789 .67592 .48711 .67382 .48191 .67125 Mtetra
.554 .828 .997 r
.48191 .67125 .48711 .67382 .49635 .67163 .49118 .66948 Mtetra
.555 .849 .998 r
.49118 .66948 .49635 .67163 .50564 .6693 .50048 .66743 Mtetra
.573 .868 .995 r
.50048 .66743 .50564 .6693 .51495 .66677 .50983 .66499 Mtetra
.604 .882 .991 r
.50983 .66499 .51495 .66677 .5243 .66403 .51921 .66212 Mtetra
.645 .887 .984 r
.51921 .66212 .5243 .66403 .53368 .66104 .52861 .65876 Mtetra
.68 .878 .973 r
.52861 .65876 .53368 .66104 .54309 .65786 .53805 .65502 Mtetra
.705 .856 .955 r
.53805 .65502 .54309 .65786 .55253 .65451 .54751 .65095 Mtetra
.715 .825 .933 r
.54751 .65095 .55253 .65451 .56199 .65107 .55699 .64673 Mtetra
.715 .792 .912 r
.55699 .64673 .56199 .65107 .57148 .6476 .5665 .64248 Mtetra
.709 .761 .892 r
.5665 .64248 .57148 .6476 .58101 .64415 .57604 .6383 Mtetra
.701 .733 .876 r
.57604 .6383 .58101 .64415 .59056 .64077 .5856 .63429 Mtetra
.693 .712 .863 r
.5856 .63429 .59056 .64077 .60014 .63744 .59519 .63039 Mtetra
.687 .694 .851 r
.59519 .63039 .60014 .63744 .60975 .63415 .60481 .6266 Mtetra
.684 .68 .84 r
.60481 .6266 .60975 .63415 .6194 .63086 .61445 .62282 Mtetra
.681 .668 .83 r
.61445 .62282 .6194 .63086 .62907 .62756 .62413 .61903 Mtetra
.678 .656 .821 r
.62413 .61903 .62907 .62756 .63878 .62428 .63383 .61524 Mtetra
.674 .644 .812 r
.63383 .61524 .63878 .62428 .64851 .62102 .64357 .61151 Mtetra
.667 .632 .806 r
.64357 .61151 .64851 .62102 .65829 .61787 .65334 .608 Mtetra
.658 .622 .802 r
.65334 .608 .65829 .61787 .6681 .61488 .66315 .60478 Mtetra
.648 .614 .802 r
.66315 .60478 .6681 .61488 .67795 .61208 .67301 .60196 Mtetra
.638 .609 .804 r
.67301 .60196 .67795 .61208 .68785 .60948 .68293 .59953 Mtetra
.631 .609 .81 r
.68293 .59953 .68785 .60948 .69779 .60703 .6929 .59741 Mtetra
.625 .613 .818 r
.6929 .59741 .69779 .60703 .70778 .60469 .70292 .5955 Mtetra
.624 .621 .828 r
.70292 .5955 .70778 .60469 .71781 .60239 .71298 .59366 Mtetra
.624 .632 .838 r
.71298 .59366 .71781 .60239 .72787 .60009 .72309 .59182 Mtetra
.624 .643 .849 r
.72309 .59182 .72787 .60009 .73798 .59779 .73324 .58998 Mtetra
.623 .655 .861 r
.73324 .58998 .73798 .59779 .74812 .59549 .74343 .58815 Mtetra
.618 .666 .875 r
.74343 .58815 .74812 .59549 .75831 .59324 .75368 .58642 Mtetra
.611 .68 .891 r
.75368 .58642 .75831 .59324 .76854 .59104 .76397 .58483 Mtetra
.6 .697 .911 r
.76397 .58483 .76854 .59104 .77882 .5889 .77433 .5834 Mtetra
.588 .719 .934 r
.77433 .5834 .77882 .5889 .78914 .5868 .78473 .58205 Mtetra
.575 .747 .959 r
.78473 .58205 .78914 .5868 .7995 .58466 .79518 .58069 Mtetra
.563 .779 .98 r
.79518 .58069 .7995 .58466 .8099 .58244 .80567 .57916 Mtetra
.558 .813 .993 r
.80567 .57916 .8099 .58244 .82033 .58004 .81618 .57731 Mtetra
.559 .842 .997 r
.81618 .57731 .82033 .58004 .83077 .57744 .82669 .57506 Mtetra
.576 .867 .995 r
.82669 .57506 .83077 .57744 .84124 .57459 .83721 .57231 Mtetra
.6 .882 .992 r
.83721 .57231 .84124 .57459 .85172 .57152 .84772 .56912 Mtetra
.632 .889 .987 r
.84772 .56912 .85172 .57152 .86223 .56824 .85823 .56552 Mtetra
.659 .883 .98 r
.85823 .56552 .86223 .56824 .87275 .56481 .86874 .56162 Mtetra
.678 .867 .97 r
.86874 .56162 .87275 .56481 .8833 .5613 .87927 .55756 Mtetra
.688 .844 .958 r
.87927 .55756 .8833 .5613 .89388 .55775 .88983 .55345 Mtetra
.689 .819 .945 r
.88983 .55345 .89388 .55775 .90451 .55423 .90044 .54942 Mtetra
.685 .796 .933 r
.90044 .54942 .90451 .55423 .91517 .55078 .91109 .54553 Mtetra
.678 .775 .924 r
.91109 .54553 .91517 .55078 .92589 .54743 .9218 .54185 Mtetra
.67 .76 .918 r
.9218 .54185 .92589 .54743 .93666 .54417 .93257 .53838 Mtetra
.662 .749 .915 r
.93257 .53838 .93666 .54417 .94748 .54102 .94341 .53513 Mtetra
.656 .744 .914 r
.94341 .53513 .94748 .54102 .95835 .53794 .95431 .53204 Mtetra
.651 .742 .916 r
.95431 .53204 .95835 .53794 .96927 .53491 .96527 .52906 Mtetra
.648 .744 .919 r
.96527 .52906 .96927 .53491 .98024 .53192 .97628 .52616 Mtetra
.67 .755 .914 r
.38561 .68781 .391 .69252 .39997 .68977 .3946 .68492 Mtetra
.665 .749 .912 r
.3946 .68492 .39997 .68977 .40896 .68708 .40361 .68213 Mtetra
.658 .743 .913 r
.40361 .68213 .40896 .68708 .41798 .68451 .41265 .67951 Mtetra
.647 .74 .916 r
.41265 .67951 .41798 .68451 .42702 .68209 .42171 .67713 Mtetra
.632 .737 .924 r
.42171 .67713 .42702 .68209 .4361 .67989 .4308 .67508 Mtetra
.615 .739 .935 r
.4308 .67508 .4361 .67989 .44519 .67788 .43991 .67334 Mtetra
.592 .744 .949 r
.43991 .67334 .44519 .67788 .45432 .67609 .44904 .67192 Mtetra
.57 .754 .965 r
.44904 .67192 .45432 .67609 .46348 .67444 .45821 .67072 Mtetra
.545 .768 .98 r
.45821 .67072 .46348 .67444 .47267 .67287 .46742 .66966 Mtetra
.528 .787 .992 r
.46742 .66966 .47267 .67287 .48191 .67125 .47667 .66854 Mtetra
.522 .81 .998 r
.47667 .66854 .48191 .67125 .49118 .66948 .48596 .66719 Mtetra
.535 .836 .999 r
.48596 .66719 .49118 .66948 .50048 .66743 .49529 .66542 Mtetra
.572 .862 .996 r
.49529 .66542 .50048 .66743 .50983 .66499 .50466 .66306 Mtetra
.621 .881 .989 r
.50466 .66306 .50983 .66499 .51921 .66212 .51407 .66004 Mtetra
.675 .887 .976 r
.51407 .66004 .51921 .66212 .52861 .65876 .52351 .65628 Mtetra
.713 .874 .957 r
.52351 .65628 .52861 .65876 .53805 .65502 .53297 .65195 Mtetra
.736 .85 .934 r
.53297 .65195 .53805 .65502 .54751 .65095 .54246 .64714 Mtetra
.742 .818 .912 r
.54246 .64714 .54751 .65095 .55699 .64673 .55196 .64214 Mtetra
.737 .787 .892 r
.55196 .64214 .55699 .64673 .5665 .64248 .56149 .63714 Mtetra
.727 .758 .877 r
.56149 .63714 .5665 .64248 .57604 .6383 .57104 .63231 Mtetra
.714 .733 .866 r
.57104 .63231 .57604 .6383 .5856 .63429 .58061 .62778 Mtetra
.704 .716 .858 r
.58061 .62778 .5856 .63429 .59519 .63039 .59021 .62348 Mtetra
.696 .702 .851 r
.59021 .62348 .59519 .63039 .60481 .6266 .59984 .61936 Mtetra
.694 .693 .844 r
.59984 .61936 .60481 .6266 .61445 .62282 .6095 .61525 Mtetra
.693 .684 .837 r
.6095 .61525 .61445 .62282 .62413 .61903 .61918 .61109 Mtetra
.691 .675 .83 r
.61918 .61109 .62413 .61903 .63383 .61524 .62889 .60689 Mtetra
.688 .665 .822 r
.62889 .60689 .63383 .61524 .64357 .61151 .63863 .60273 Mtetra
.678 .652 .817 r
.63863 .60273 .64357 .61151 .65334 .608 .6484 .59887 Mtetra
.666 .64 .815 r
.6484 .59887 .65334 .608 .66315 .60478 .65822 .59543 Mtetra
.65 .63 .816 r
.65822 .59543 .66315 .60478 .67301 .60196 .66809 .59259 Mtetra
.635 .622 .821 r
.66809 .59259 .67301 .60196 .68293 .59953 .67803 .59034 Mtetra
.623 .621 .828 r
.67803 .59034 .68293 .59953 .6929 .59741 .68803 .58852 Mtetra
.614 .624 .837 r
.68803 .58852 .6929 .59741 .70292 .5955 .69808 .587 Mtetra
.612 .632 .847 r
.69808 .587 .70292 .5955 .71298 .59366 .70818 .58553 Mtetra
.612 .642 .856 r
.70818 .58553 .71298 .59366 .72309 .59182 .71832 .58403 Mtetra
.613 .652 .864 r
.71832 .58403 .72309 .59182 .73324 .58998 .7285 .58247 Mtetra
.611 .659 .873 r
.7285 .58247 .73324 .58998 .74343 .58815 .73873 .58093 Mtetra
.603 .665 .883 r
.73873 .58093 .74343 .58815 .75368 .58642 .74902 .57959 Mtetra
.591 .672 .896 r
.74902 .57959 .75368 .58642 .76397 .58483 .75937 .57847 Mtetra
.573 .681 .913 r
.75937 .57847 .76397 .58483 .77433 .5834 .76979 .57767 Mtetra
.554 .696 .935 r
.76979 .57767 .77433 .5834 .78473 .58205 .78028 .57705 Mtetra
.536 .72 .958 r
.78028 .57705 .78473 .58205 .79518 .58069 .79081 .57645 Mtetra
.524 .751 .979 r
.79081 .57645 .79518 .58069 .80567 .57916 .80139 .57564 Mtetra
.526 .789 .993 r
.80139 .57564 .80567 .57916 .81618 .57731 .81198 .57436 Mtetra
.54 .825 .998 r
.81198 .57436 .81618 .57731 .82669 .57506 .82256 .57249 Mtetra
.574 .859 .996 r
.82256 .57249 .82669 .57506 .83721 .57231 .83313 .56987 Mtetra
.613 .88 .99 r
.83313 .56987 .83721 .57231 .84772 .56912 .84367 .56657 Mtetra
.655 .89 .982 r
.84367 .56657 .84772 .56912 .85823 .56552 .85418 .56264 Mtetra
.687 .885 .971 r
.85418 .56264 .85823 .56552 .86874 .56162 .86469 .55827 Mtetra
.705 .868 .959 r
.86469 .55827 .86874 .56162 .87927 .55756 .8752 .55367 Mtetra
.712 .845 .946 r
.8752 .55367 .87927 .55756 .88983 .55345 .88574 .54899 Mtetra
.708 .819 .934 r
.88574 .54899 .88983 .55345 .90044 .54942 .89632 .54445 Mtetra
.701 .796 .924 r
.89632 .54445 .90044 .54942 .91109 .54553 .90696 .54013 Mtetra
.688 .775 .917 r
.90696 .54013 .91109 .54553 .9218 .54185 .91767 .53615 Mtetra
.677 .759 .913 r
.91767 .53615 .9218 .54185 .93257 .53838 .92845 .53248 Mtetra
.665 .747 .912 r
.92845 .53248 .93257 .53838 .94341 .53513 .93931 .52914 Mtetra
.655 .741 .913 r
.93931 .52914 .94341 .53513 .95431 .53204 .95025 .52606 Mtetra
.648 .739 .916 r
.95025 .52606 .95431 .53204 .96527 .52906 .96124 .52316 Mtetra
.643 .741 .92 r
.96124 .52316 .96527 .52906 .97628 .52616 .9723 .52037 Mtetra
.676 .756 .911 r
.38018 .68308 .38561 .68781 .3946 .68492 .3892 .68001 Mtetra
.67 .749 .91 r
.3892 .68001 .3946 .68492 .40361 .68213 .39823 .6771 Mtetra
.66 .742 .911 r
.39823 .6771 .40361 .68213 .41265 .67951 .40729 .67441 Mtetra
.646 .737 .915 r
.40729 .67441 .41265 .67951 .42171 .67713 .41637 .67205 Mtetra
.625 .732 .923 r
.41637 .67205 .42171 .67713 .4308 .67508 .42547 .67013 Mtetra
.603 .73 .935 r
.42547 .67013 .4308 .67508 .43991 .67334 .43459 .66862 Mtetra
.572 .731 .95 r
.43459 .66862 .43991 .67334 .44904 .67192 .44374 .66756 Mtetra
.543 .737 .965 r
.44374 .66756 .44904 .67192 .45821 .67072 .45292 .66679 Mtetra
.511 .746 .98 r
.45292 .66679 .45821 .67072 .46742 .66966 .46213 .66623 Mtetra
.493 .764 .991 r
.46213 .66623 .46742 .66966 .47667 .66854 .47139 .6656 Mtetra
.493 .789 .998 r
.47139 .6656 .47667 .66854 .48596 .66719 .4807 .66468 Mtetra
.52 .821 1 r
.4807 .66468 .48596 .66719 .49529 .66542 .49006 .66319 Mtetra
.577 .854 .996 r
.49006 .66319 .49529 .66542 .50466 .66306 .49946 .66089 Mtetra
.641 .875 .985 r
.49946 .66089 .50466 .66306 .51407 .66004 .50889 .65769 Mtetra
.703 .88 .963 r
.50889 .65769 .51407 .66004 .52351 .65628 .51836 .6535 Mtetra
.741 .864 .937 r
.51836 .6535 .52351 .65628 .53297 .65195 .52786 .64854 Mtetra
.761 .838 .91 r
.52786 .64854 .53297 .65195 .54246 .64714 .53737 .64296 Mtetra
.762 .806 .888 r
.53737 .64296 .54246 .64714 .55196 .64214 .54689 .63718 Mtetra
.753 .776 .872 r
.54689 .63718 .55196 .64214 .56149 .63714 .55644 .63148 Mtetra
.738 .751 .862 r
.55644 .63148 .56149 .63714 .57104 .63231 .566 .62612 Mtetra
.721 .73 .858 r
.566 .62612 .57104 .63231 .58061 .62778 .5756 .62127 Mtetra
.708 .718 .857 r
.5756 .62127 .58061 .62778 .59021 .62348 .58522 .6168 Mtetra
.699 .711 .857 r
.58522 .6168 .59021 .62348 .59984 .61936 .59487 .61262 Mtetra
.699 .709 .856 r
.59487 .61262 .59984 .61936 .6095 .61525 .60454 .60842 Mtetra
.702 .708 .853 r
.60454 .60842 .6095 .61525 .61918 .61109 .61424 .60409 Mtetra
.705 .705 .848 r
.61424 .60409 .61918 .61109 .62889 .60689 .62396 .5996 Mtetra
.704 .698 .842 r
.62396 .5996 .62889 .60689 .63863 .60273 .6337 .59508 Mtetra
.693 .685 .838 r
.6337 .59508 .63863 .60273 .6484 .59887 .64348 .59088 Mtetra
.677 .671 .837 r
.64348 .59088 .6484 .59887 .65822 .59543 .65331 .58722 Mtetra
.654 .657 .84 r
.65331 .58722 .65822 .59543 .66809 .59259 .6632 .58436 Mtetra
.631 .647 .847 r
.6632 .58436 .66809 .59259 .67803 .59034 .67316 .58228 Mtetra
.612 .643 .857 r
.67316 .58228 .67803 .59034 .68803 .58852 .68318 .58076 Mtetra
.6 .646 .868 r
.68318 .58076 .68803 .58852 .69808 .587 .69327 .57957 Mtetra
.6 .656 .877 r
.69327 .57957 .69808 .587 .70818 .58553 .7034 .57835 Mtetra
.603 .666 .883 r
.7034 .57835 .70818 .58553 .71832 .58403 .71357 .57698 Mtetra
.608 .672 .886 r
.71357 .57698 .71832 .58403 .7285 .58247 .72377 .57547 Mtetra
.607 .674 .888 r
.72377 .57547 .7285 .58247 .73873 .58093 .73402 .57396 Mtetra
.595 .67 .892 r
.73402 .57396 .73873 .58093 .74902 .57959 .74434 .57274 Mtetra
.578 .667 .899 r
.74434 .57274 .74902 .57959 .75937 .57847 .75473 .57191 Mtetra
.551 .665 .912 r
.75473 .57191 .75937 .57847 .76979 .57767 .7652 .57161 Mtetra
.523 .671 .93 r
.7652 .57161 .76979 .57767 .78028 .57705 .77576 .57167 Mtetra
.5 .688 .951 r
.77576 .57167 .78028 .57705 .79081 .57645 .78639 .57183 Mtetra
.486 .716 .972 r
.78639 .57183 .79081 .57645 .80139 .57564 .79705 .57178 Mtetra
.496 .759 .989 r
.79705 .57178 .80139 .57564 .81198 .57436 .80772 .57111 Mtetra
.523 .803 .997 r
.80772 .57111 .81198 .57436 .82256 .57249 .81838 .56965 Mtetra
.575 .847 .996 r
.81838 .56965 .82256 .57249 .83313 .56987 .82899 .56717 Mtetra
.628 .874 .988 r
.82899 .56717 .83313 .56987 .84367 .56657 .83956 .56377 Mtetra
.678 .887 .975 r
.83956 .56377 .84367 .56657 .85418 .56264 .85009 .55952 Mtetra
.712 .882 .96 r
.85009 .55952 .85418 .56264 .86469 .55827 .86059 .55469 Mtetra
.729 .864 .945 r
.86059 .55469 .86469 .55827 .8752 .55367 .87108 .54954 Mtetra
.733 .842 .931 r
.87108 .54954 .8752 .55367 .88574 .54899 .8816 .5443 Mtetra
.725 .816 .921 r
.8816 .5443 .88574 .54899 .89632 .54445 .89216 .53927 Mtetra
.714 .793 .913 r
.89216 .53927 .89632 .54445 .90696 .54013 .90279 .53454 Mtetra
.697 .772 .909 r
.90279 .53454 .90696 .54013 .91767 .53615 .91349 .53027 Mtetra
.682 .756 .908 r
.91349 .53027 .91767 .53615 .92845 .53248 .92429 .52643 Mtetra
.666 .744 .909 r
.92429 .52643 .92845 .53248 .93931 .52914 .93517 .52305 Mtetra
.653 .738 .912 r
.93517 .52305 .93931 .52914 .95025 .52606 .94614 .52 Mtetra
.644 .736 .916 r
.94614 .52 .95025 .52606 .96124 .52316 .95719 .51719 Mtetra
.637 .737 .921 r
.95719 .51719 .96124 .52316 .9723 .52037 .96829 .51454 Mtetra
.683 .757 .908 r
.37472 .67831 .38018 .68308 .3892 .68001 .38376 .67505 Mtetra
.676 .749 .906 r
.38376 .67505 .3892 .68001 .39823 .6771 .39282 .67198 Mtetra
.664 .741 .907 r
.39282 .67198 .39823 .6771 .40729 .67441 .4019 .66919 Mtetra
.647 .733 .912 r
.4019 .66919 .40729 .67441 .41637 .67205 .411 .66681 Mtetra
.621 .725 .921 r
.411 .66681 .41637 .67205 .42547 .67013 .42011 .66498 Mtetra
.593 .721 .933 r
.42011 .66498 .42547 .67013 .43459 .66862 .42924 .66367 Mtetra
.554 .716 .948 r
.42924 .66367 .43459 .66862 .44374 .66756 .4384 .66294 Mtetra
.519 .717 .963 r
.4384 .66294 .44374 .66756 .45292 .66679 .44759 .66259 Mtetra
.48 .722 .977 r
.44759 .66259 .45292 .66679 .46213 .66623 .45681 .66252 Mtetra
.461 .738 .988 r
.45681 .66252 .46213 .66623 .47139 .6656 .46609 .66237 Mtetra
.467 .765 .995 r
.46609 .66237 .47139 .6656 .4807 .66468 .47541 .66186 Mtetra
.509 .803 .999 r
.47541 .66186 .4807 .66468 .49006 .66319 .48479 .66065 Mtetra
.585 .843 .994 r
.48479 .66065 .49006 .66319 .49946 .66089 .49421 .6584 Mtetra
.662 .866 .977 r
.49421 .6584 .49946 .66089 .50889 .65769 .50368 .655 Mtetra
.729 .867 .946 r
.50368 .655 .50889 .65769 .51836 .6535 .51318 .65032 Mtetra
.764 .847 .914 r
.51318 .65032 .51836 .6535 .52786 .64854 .5227 .64467 Mtetra
.78 .82 .884 r
.5227 .64467 .52786 .64854 .53737 .64296 .53224 .63828 Mtetra
.776 .789 .864 r
.53224 .63828 .53737 .64296 .54689 .63718 .54179 .63172 Mtetra
.762 .762 .852 r
.54179 .63172 .54689 .63718 .55644 .63148 .55136 .6254 Mtetra
.743 .739 .849 r
.55136 .6254 .55644 .63148 .566 .62612 .56094 .61968 Mtetra
.72 .723 .853 r
.56094 .61968 .566 .62612 .5756 .62127 .57055 .61477 Mtetra
.704 .718 .86 r
.57055 .61477 .5756 .62127 .58522 .6168 .5802 .61046 Mtetra
.692 .72 .87 r
.5802 .61046 .58522 .6168 .59487 .61262 .58987 .60658 Mtetra
.695 .731 .878 r
.58987 .60658 .59487 .61262 .60454 .60842 .59958 .60264 Mtetra
.706 .743 .881 r
.59958 .60264 .60454 .60842 .61424 .60409 .6093 .59839 Mtetra
.716 .75 .879 r
.6093 .59839 .61424 .60409 .62396 .5996 .61904 .5938 Mtetra
.722 .748 .873 r
.61904 .5938 .62396 .5996 .6337 .59508 .6288 .58899 Mtetra
.711 .736 .871 r
.6288 .58899 .6337 .59508 .64348 .59088 .6386 .58448 Mtetra
.691 .721 .873 r
.6386 .58448 .64348 .59088 .65331 .58722 .64844 .5806 Mtetra
.658 .703 .88 r
.64844 .5806 .65331 .58722 .6632 .58436 .65835 .57772 Mtetra
.622 .689 .892 r
.65835 .57772 .6632 .58436 .67316 .58228 .66833 .57583 Mtetra
.594 .684 .904 r
.66833 .57583 .67316 .58228 .68318 .58076 .67839 .57457 Mtetra
.577 .687 .916 r
.67839 .57457 .68318 .58076 .69327 .57957 .68851 .57364 Mtetra
.584 .7 .922 r
.68851 .57364 .69327 .57957 .7034 .57835 .69866 .57248 Mtetra
.599 .71 .922 r
.69866 .57248 .7034 .57835 .71357 .57698 .70884 .57098 Mtetra
.613 .711 .915 r
.70884 .57098 .71357 .57698 .72377 .57547 .71906 .56918 Mtetra
.616 .703 .906 r
.71906 .56918 .72377 .57547 .73402 .57396 .72931 .56732 Mtetra
.6 .685 .901 r
.72931 .56732 .73402 .57396 .74434 .57274 .73963 .5659 Mtetra
.576 .668 .901 r
.73963 .5659 .74434 .57274 .75473 .57191 .75004 .56509 Mtetra
.537 .651 .908 r
.75004 .56509 .75473 .57191 .7652 .57161 .76056 .56512 Mtetra
.5 .645 .921 r
.76056 .56512 .7652 .57161 .77576 .57167 .77118 .56577 Mtetra
.468 .652 .94 r
.77118 .56577 .77576 .57167 .78639 .57183 .78189 .56669 Mtetra
.451 .676 .961 r
.78189 .56669 .78639 .57183 .79705 .57178 .79264 .56743 Mtetra
.468 .723 .98 r
.79264 .56743 .79705 .57178 .80772 .57111 .8034 .56743 Mtetra
.507 .775 .992 r
.8034 .56743 .80772 .57111 .81838 .56965 .81412 .56644 Mtetra
.576 .83 .993 r
.81412 .56644 .81838 .56965 .82899 .56717 .82479 .56414 Mtetra
.642 .864 .983 r
.82479 .56414 .82899 .56717 .83956 .56377 .83539 .56066 Mtetra
.699 .878 .965 r
.83539 .56066 .83956 .56377 .85009 .55952 .84593 .5561 Mtetra
.733 .873 .946 r
.84593 .5561 .85009 .55952 .86059 .55469 .85642 .55079 Mtetra
.749 .856 .929 r
.85642 .55079 .86059 .55469 .87108 .54954 .8669 .5451 Mtetra
.75 .834 .915 r
.8669 .5451 .87108 .54954 .8816 .5443 .8774 .53932 Mtetra
.739 .809 .907 r
.8774 .53932 .8816 .5443 .89216 .53927 .88794 .53382 Mtetra
.725 .787 .902 r
.88794 .53382 .89216 .53927 .90279 .53454 .89856 .52871 Mtetra
.704 .767 .901 r
.89856 .52871 .90279 .53454 .91349 .53027 .90927 .52419 Mtetra
.686 .751 .902 r
.90927 .52419 .91349 .53027 .92429 .52643 .92008 .52022 Mtetra
.666 .739 .905 r
.92008 .52022 .92429 .52643 .93517 .52305 .931 .51681 Mtetra
.65 .733 .91 r
.931 .51681 .93517 .52305 .94614 .52 .94201 .51383 Mtetra
.638 .731 .915 r
.94201 .51383 .94614 .52 .95719 .51719 .9531 .51115 Mtetra
.63 .733 .922 r
.9531 .51115 .95719 .51719 .96829 .51454 .96426 .50866 Mtetra
.691 .759 .904 r
.36922 .67351 .37472 .67831 .38376 .67505 .37829 .67004 Mtetra
.682 .749 .902 r
.37829 .67004 .38376 .67505 .39282 .67198 .38738 .66677 Mtetra
.669 .74 .903 r
.38738 .66677 .39282 .67198 .4019 .66919 .39648 .66385 Mtetra
.649 .73 .908 r
.39648 .66385 .4019 .66919 .411 .66681 .4056 .6614 Mtetra
.619 .72 .918 r
.4056 .6614 .411 .66681 .42011 .66498 .41473 .65961 Mtetra
.586 .711 .929 r
.41473 .65961 .42011 .66498 .42924 .66367 .42387 .65846 Mtetra
.54 .701 .944 r
.42387 .65846 .42924 .66367 .4384 .66294 .43303 .65801 Mtetra
.498 .697 .958 r
.43303 .65801 .4384 .66294 .44759 .66259 .44223 .65804 Mtetra
.453 .696 .971 r
.44223 .65804 .44759 .66259 .45681 .66252 .45146 .65843 Mtetra
.435 .71 .981 r
.45146 .65843 .45681 .66252 .46609 .66237 .46075 .65876 Mtetra
.446 .739 .99 r
.46075 .65876 .46609 .66237 .47541 .66186 .47008 .65867 Mtetra
.503 .783 .995 r
.47008 .65867 .47541 .66186 .48479 .66065 .47948 .65773 Mtetra
.595 .829 .988 r
.47948 .65773 .48479 .66065 .49421 .6584 .48893 .65551 Mtetra
.681 .852 .965 r
.48893 .65551 .49421 .6584 .50368 .655 .49843 .65189 Mtetra
.749 .85 .925 r
.49843 .65189 .50368 .655 .51318 .65032 .50796 .64668 Mtetra
.781 .829 .89 r
.50796 .64668 .51318 .65032 .5227 .64467 .51751 .64031 Mtetra
.793 .802 .859 r
.51751 .64031 .5227 .64467 .53224 .63828 .52708 .63307 Mtetra
.785 .773 .842 r
.52708 .63307 .53224 .63828 .54179 .63172 .53666 .62573 Mtetra
.767 .747 .835 r
.53666 .62573 .54179 .63172 .55136 .6254 .54624 .61888 Mtetra
.742 .727 .838 r
.54624 .61888 .55136 .6254 .56094 .61968 .55585 .61298 Mtetra
.711 .715 .851 r
.55585 .61298 .56094 .61968 .57055 .61477 .56548 .60833 Mtetra
.688 .716 .87 r
.56548 .60833 .57055 .61477 .5802 .61046 .57516 .60457 Mtetra
.669 .728 .894 r
.57516 .60457 .5802 .61046 .58987 .60658 .58487 .60143 Mtetra
.675 .758 .913 r
.58487 .60143 .58987 .60658 .59958 .60264 .59461 .59813 Mtetra
.696 .79 .923 r
.59461 .59813 .59958 .60264 .6093 .59839 .60437 .59427 Mtetra
.721 .813 .922 r
.60437 .59427 .6093 .59839 .61904 .5938 .61414 .58974 Mtetra
.739 .819 .914 r
.61414 .58974 .61904 .5938 .6288 .58899 .62393 .58465 Mtetra
.73 .807 .912 r
.62393 .58465 .6288 .58899 .6386 .58448 .63374 .5798 Mtetra
.705 .789 .916 r
.63374 .5798 .6386 .58448 .64844 .5806 .64359 .57565 Mtetra
.656 .764 .929 r
.64359 .57565 .64844 .5806 .65835 .57772 .65353 .57274 Mtetra
.596 .743 .947 r
.65353 .57274 .65835 .57772 .66833 .57583 .66355 .57109 Mtetra
.55 .736 .962 r
.66355 .57109 .66833 .57583 .67839 .57457 .67364 .57015 Mtetra
.525 .74 .973 r
.67364 .57015 .67839 .57457 .68851 .57364 .6838 .56945 Mtetra
.553 .764 .976 r
.6838 .56945 .68851 .57364 .69866 .57248 .69398 .5682 Mtetra
.595 .777 .967 r
.69398 .5682 .69866 .57248 .70884 .57098 .70416 .56627 Mtetra
.631 .772 .947 r
.70416 .56627 .70884 .57098 .71906 .56918 .71436 .56378 Mtetra
.643 .748 .925 r
.71436 .56378 .71906 .56918 .72931 .56732 .72459 .56113 Mtetra
.621 .71 .91 r
.72459 .56113 .72931 .56732 .73963 .5659 .7349 .55911 Mtetra
.587 .676 .901 r
.7349 .55911 .73963 .5659 .75004 .56509 .74531 .558 Mtetra
.533 .641 .902 r
.74531 .558 .75004 .56509 .76056 .56512 .75586 .55818 Mtetra
.482 .621 .911 r
.75586 .55818 .76056 .56512 .77118 .56577 .76654 .55933 Mtetra
.439 .617 .926 r
.76654 .55933 .77118 .56577 .78189 .56669 .77732 .561 Mtetra
.415 .635 .946 r
.77732 .561 .78189 .56669 .79264 .56743 .78816 .56258 Mtetra
.438 .685 .969 r
.78816 .56258 .79264 .56743 .8034 .56743 .799 .56329 Mtetra
.489 .745 .985 r
.799 .56329 .8034 .56743 .81412 .56644 .8098 .56281 Mtetra
.577 .81 .988 r
.8098 .56281 .81412 .56644 .82479 .56414 .82052 .5607 Mtetra
.654 .849 .975 r
.82052 .5607 .82479 .56414 .83539 .56066 .83115 .55715 Mtetra
.716 .865 .952 r
.83115 .55715 .83539 .56066 .84593 .5561 .8417 .55227 Mtetra
.751 .86 .929 r
.8417 .55227 .84593 .5561 .85642 .55079 .85219 .54649 Mtetra
.764 .843 .911 r
.85219 .54649 .85642 .55079 .8669 .5451 .86265 .54028 Mtetra
.763 .822 .899 r
.86265 .54028 .8669 .5451 .8774 .53932 .87313 .53398 Mtetra
.749 .799 .893 r
.87313 .53398 .8774 .53932 .88794 .53382 .88367 .52804 Mtetra
.732 .779 .89 r
.88367 .52804 .88794 .53382 .89856 .52871 .89428 .5226 Mtetra
.709 .76 .892 r
.89428 .5226 .89856 .52871 .90927 .52419 .905 .51788 Mtetra
.687 .745 .896 r
.905 .51788 .90927 .52419 .92008 .52022 .91583 .51382 Mtetra
.664 .734 .902 r
.91583 .51382 .92008 .52022 .931 .51681 .92678 .51044 Mtetra
.646 .728 .908 r
.92678 .51044 .931 .51681 .94201 .51383 .93783 .50756 Mtetra
.632 .726 .915 r
.93783 .50756 .94201 .51383 .9531 .51115 .94898 .50504 Mtetra
.622 .728 .923 r
.94898 .50504 .9531 .51115 .96426 .50866 .9602 .50275 Mtetra
.699 .761 .899 r
.36369 .66869 .36922 .67351 .37829 .67004 .37279 .66496 Mtetra
.69 .75 .897 r
.37279 .66496 .37829 .67004 .38738 .66677 .38191 .66146 Mtetra
.675 .739 .899 r
.38191 .66146 .38738 .66677 .39648 .66385 .39104 .65836 Mtetra
.653 .727 .904 r
.39104 .65836 .39648 .66385 .4056 .6614 .40017 .65581 Mtetra
.62 .714 .913 r
.40017 .65581 .4056 .6614 .41473 .65961 .40932 .65401 Mtetra
.583 .702 .924 r
.40932 .65401 .41473 .65961 .42387 .65846 .41847 .65295 Mtetra
.531 .686 .938 r
.41847 .65295 .42387 .65846 .43303 .65801 .42764 .65273 Mtetra
.484 .677 .95 r
.42764 .65273 .43303 .65801 .44223 .65804 .43685 .65309 Mtetra
.432 .669 .961 r
.43685 .65309 .44223 .65804 .45146 .65843 .44608 .6539 Mtetra
.414 .681 .972 r
.44608 .6539 .45146 .65843 .46075 .65876 .45538 .65468 Mtetra
.431 .71 .982 r
.45538 .65468 .46075 .65876 .47008 .65867 .46472 .655 Mtetra
.5 .76 .989 r
.46472 .655 .47008 .65867 .47948 .65773 .47414 .65434 Mtetra
.605 .81 .979 r
.47414 .65434 .47948 .65773 .48893 .65551 .48361 .65216 Mtetra
.696 .834 .949 r
.48361 .65216 .48893 .65551 .49843 .65189 .49314 .64829 Mtetra
.765 .831 .903 r
.49314 .64829 .49843 .65189 .50796 .64668 .5027 .64251 Mtetra
.793 .809 .865 r
.5027 .64251 .50796 .64668 .51751 .64031 .51229 .63536 Mtetra
.802 .783 .835 r
.51229 .63536 .51751 .64031 .52708 .63307 .52189 .62723 Mtetra
.79 .755 .821 r
.52189 .62723 .52708 .63307 .53666 .62573 .53149 .61913 Mtetra
.768 .732 .819 r
.53149 .61913 .53666 .62573 .54624 .61888 .5411 .61185 Mtetra
.736 .713 .83 r
.5411 .61185 .54624 .61888 .55585 .61298 .55072 .60599 Mtetra
.692 .702 .854 r
.55072 .60599 .55585 .61298 .56548 .60833 .56039 .60197 Mtetra
.654 .708 .888 r
.56039 .60197 .56548 .60833 .57516 .60457 .57009 .59925 Mtetra
.613 .732 .93 r
.57009 .59925 .57516 .60457 .58487 .60143 .57985 .59738 Mtetra
.611 .788 .966 r
.57985 .59738 .58487 .60143 .59461 .59813 .58964 .59521 Mtetra
.642 .851 .98 r
.58964 .59521 .59461 .59813 .60437 .59427 .59945 .59209 Mtetra
.692 .898 .971 r
.59945 .59209 .60437 .59427 .61414 .58974 .60926 .58778 Mtetra
.739 .916 .953 r
.60926 .58778 .61414 .58974 .62393 .58465 .61907 .58243 Mtetra
.738 .905 .952 r
.61907 .58243 .62393 .58465 .63374 .5798 .62891 .57717 Mtetra
.708 .883 .962 r
.62891 .57717 .63374 .5798 .64359 .57565 .63879 .57268 Mtetra
.626 .848 .984 r
.63879 .57268 .64359 .57565 .65353 .57274 .64875 .56976 Mtetra
.509 .805 .999 r
.64875 .56976 .65353 .57274 .66355 .57109 .65882 .56842 Mtetra
.415 .777 .995 r
.65882 .56842 .66355 .57109 .67364 .57015 .66896 .56785 Mtetra
.37 .771 .985 r
.66896 .56785 .67364 .57015 .6838 .56945 .67916 .56738 Mtetra
.457 .826 .993 r
.67916 .56738 .6838 .56945 .69398 .5682 .68935 .56587 Mtetra
.578 .866 .995 r
.68935 .56587 .69398 .5682 .70416 .56627 .69954 .56317 Mtetra
.666 .858 .973 r
.69954 .56317 .70416 .56627 .71436 .56378 .7097 .55951 Mtetra
.692 .812 .939 r
.7097 .55951 .71436 .56378 .72459 .56113 .71989 .55553 Mtetra
.661 .748 .915 r
.71989 .55553 .72459 .56113 .7349 .55911 .73015 .55242 Mtetra
.613 .692 .899 r
.73015 .55242 .7349 .55911 .74531 .558 .74054 .55063 Mtetra
.54 .637 .895 r
.74054 .55063 .74531 .558 .75586 .55818 .7511 .55071 Mtetra
.472 .599 .898 r
.7511 .55071 .75586 .55818 .76654 .55933 .76183 .55226 Mtetra
.414 .582 .909 r
.76183 .55226 .76654 .55933 .77732 .561 .77268 .55466 Mtetra
.383 .592 .927 r
.77268 .55466 .77732 .561 .78816 .56258 .78361 .55712 Mtetra
.41 .645 .953 r
.78361 .55712 .78816 .56258 .799 .56329 .79453 .55859 Mtetra
.473 .712 .974 r
.79453 .55859 .799 .56329 .8098 .56281 .80541 .55866 Mtetra
.578 .787 .978 r
.80541 .55866 .8098 .56281 .82052 .5607 .81618 .55677 Mtetra
.665 .831 .963 r
.81618 .55677 .82052 .5607 .83115 .55715 .82684 .55314 Mtetra
.73 .847 .936 r
.82684 .55314 .83115 .55715 .8417 .55227 .83739 .54794 Mtetra
.764 .842 .911 r
.83739 .54794 .8417 .55227 .85219 .54649 .84787 .5417 Mtetra
.774 .826 .893 r
.84787 .5417 .85219 .54649 .86265 .54028 .85833 .53498 Mtetra
.772 .807 .881 r
.85833 .53498 .86265 .54028 .87313 .53398 .86879 .5282 Mtetra
.755 .786 .878 r
.86879 .5282 .87313 .53398 .88367 .52804 .87932 .52189 Mtetra
.737 .768 .878 r
.87932 .52189 .88367 .52804 .89428 .5226 .88994 .51617 Mtetra
.711 .751 .883 r
.88994 .51617 .89428 .5226 .905 .51788 .90068 .51131 Mtetra
.687 .738 .89 r
.90068 .51131 .905 .51788 .91583 .51382 .91154 .50722 Mtetra
.661 .727 .898 r
.91154 .50722 .91583 .51382 .92678 .51044 .92252 .50391 Mtetra
.64 .721 .907 r
.92252 .50391 .92678 .51044 .93783 .50756 .93362 .50118 Mtetra
.624 .72 .915 r
.93362 .50118 .93783 .50756 .94898 .50504 .94482 .49886 Mtetra
.612 .722 .924 r
.94482 .49886 .94898 .50504 .9602 .50275 .9561 .4968 Mtetra
.708 .762 .895 r
.35813 .66383 .36369 .66869 .37279 .66496 .36726 .65983 Mtetra
.698 .751 .893 r
.36726 .65983 .37279 .66496 .38191 .66146 .37641 .65608 Mtetra
.682 .739 .894 r
.37641 .65608 .38191 .66146 .39104 .65836 .38556 .65276 Mtetra
.659 .726 .899 r
.38556 .65276 .39104 .65836 .40017 .65581 .39472 .65005 Mtetra
.624 .71 .908 r
.39472 .65005 .40017 .65581 .40932 .65401 .40388 .64817 Mtetra
.583 .694 .918 r
.40388 .64817 .40932 .65401 .41847 .65295 .41305 .64714 Mtetra
.527 .674 .931 r
.41305 .64714 .41847 .65295 .42764 .65273 .42223 .64706 Mtetra
.475 .658 .941 r
.42223 .64706 .42764 .65273 .43685 .65309 .43144 .64768 Mtetra
.419 .644 .95 r
.43144 .64768 .43685 .65309 .44608 .6539 .44068 .64886 Mtetra
.401 .652 .96 r
.44068 .64886 .44608 .6539 .45538 .65468 .44998 .65005 Mtetra
.42 .681 .971 r
.44998 .65005 .45538 .65468 .46472 .655 .45934 .65079 Mtetra
.498 .734 .978 r
.45934 .65079 .46472 .655 .47414 .65434 .46877 .65041 Mtetra
.611 .788 .966 r
.46877 .65041 .47414 .65434 .48361 .65216 .47826 .64829 Mtetra
.707 .814 .932 r
.47826 .64829 .48361 .65216 .49314 .64829 .48782 .64421 Mtetra
.776 .813 .882 r
.48782 .64421 .49314 .64829 .5027 .64251 .49742 .63787 Mtetra
.802 .793 .844 r
.49742 .63787 .5027 .64251 .51229 .63536 .50704 .62994 Mtetra
.81 .769 .815 r
.50704 .62994 .51229 .63536 .52189 .62723 .51666 .62089 Mtetra
.795 .743 .805 r
.51666 .62089 .52189 .62723 .53149 .61913 .52629 .61204 Mtetra
.768 .72 .808 r
.52629 .61204 .53149 .61913 .5411 .61185 .53592 .60441 Mtetra
.727 .701 .826 r
.53592 .60441 .5411 .61185 .55072 .60599 .54557 .59882 Mtetra
.662 .687 .863 r
.54557 .59882 .55072 .60599 .56039 .60197 .55526 .59579 Mtetra
.59 .692 .912 r
.55526 .59579 .56039 .60197 .57009 .59925 .56501 .59457 Mtetra
.487 .711 .969 r
.56501 .59457 .57009 .59925 .57985 .59738 .57481 .59451 Mtetra
.436 .776 .997 r
.57481 .59451 .57985 .59738 .58964 .59521 .58466 .59392 Mtetra
.462 .856 .975 r
.58466 .59392 .58964 .59521 .59945 .59209 .59453 .59182 Mtetra
.564 .927 .937 r
.59453 .59182 .59945 .59209 .60926 .58778 .60438 .5878 Mtetra
.685 .972 .92 r
.60438 .5878 .60926 .58778 .61907 .58243 .61423 .58203 Mtetra
.715 .969 .933 r
.61423 .58203 .61907 .58243 .62891 .57717 .62409 .57615 Mtetra
.689 .947 .959 r
.62409 .57615 .62891 .57717 .63879 .57268 .63399 .57113 Mtetra
.558 .889 .986 r
.63399 .57113 .63879 .57268 .64875 .56976 .64399 .5682 Mtetra
.335 .782 .958 r
.64399 .5682 .64875 .56976 .65882 .56842 .65411 .56735 Mtetra
.154 .682 .869 r
.65411 .56735 .65882 .56842 .66896 .56785 .66431 .56737 Mtetra
.08 .638 .792 r
.66431 .56737 .66896 .56785 .67916 .56738 .67456 .5673 Mtetra
.258 .768 .84 r
.67456 .5673 .67916 .56738 .68935 .56587 .68478 .56548 Mtetra
.523 .911 .931 r
.68478 .56548 .68935 .56587 .69954 .56317 .69495 .56171 Mtetra
.709 .942 .959 r
.69495 .56171 .69954 .56317 .7097 .55951 .70507 .55642 Mtetra
.76 .88 .933 r
.70507 .55642 .7097 .55951 .71989 .55553 .71519 .55056 Mtetra
.717 .792 .911 r
.71519 .55056 .71989 .55553 .73015 .55242 .72539 .54589 Mtetra
.651 .714 .894 r
.72539 .54589 .73015 .55242 .74054 .55063 .73574 .54305 Mtetra
.555 .639 .889 r
.73574 .54305 .74054 .55063 .7511 .55071 .74629 .54282 Mtetra
.463 .583 .889 r
.74629 .54282 .7511 .55071 .76183 .55226 .75705 .54469 Mtetra
.387 .552 .896 r
.75705 .54469 .76183 .55226 .77268 .55466 .76797 .54781 Mtetra
.344 .552 .911 r
.76797 .54781 .77268 .55466 .78361 .55712 .77899 .55117 Mtetra
.378 .607 .939 r
.77899 .55117 .78361 .55712 .79453 .55859 .78999 .55341 Mtetra
.454 .682 .963 r
.78999 .55341 .79453 .55859 .80541 .55866 .80094 .55402 Mtetra
.578 .766 .968 r
.80094 .55402 .80541 .55866 .81618 .55677 .81176 .55231 Mtetra
.674 .811 .949 r
.81176 .55231 .81618 .55677 .82684 .55314 .82245 .54858 Mtetra
.741 .827 .918 r
.82245 .54858 .82684 .55314 .83739 .54794 .83301 .54304 Mtetra
.773 .822 .891 r
.83301 .54304 .83739 .54794 .84787 .5417 .84348 .53634 Mtetra
.781 .807 .874 r
.84348 .53634 .84787 .5417 .85833 .53498 .85392 .52915 Mtetra
.776 .79 .865 r
.85392 .52915 .85833 .53498 .86879 .5282 .86438 .52195 Mtetra
.758 .772 .864 r
.86438 .52195 .86879 .5282 .87932 .52189 .87491 .51532 Mtetra
.738 .757 .868 r
.87491 .51532 .87932 .52189 .88994 .51617 .88554 .50941 Mtetra
.71 .741 .876 r
.88554 .50941 .88994 .51617 .90068 .51131 .8963 .50448 Mtetra
.684 .73 .885 r
.8963 .50448 .90068 .51131 .91154 .50722 .90719 .50043 Mtetra
.656 .72 .896 r
.90719 .50043 .91154 .50722 .92252 .50391 .91823 .49725 Mtetra
.633 .715 .906 r
.91823 .49725 .92252 .50391 .93362 .50118 .92938 .49471 Mtetra
.614 .714 .916 r
.92938 .49471 .93362 .50118 .94482 .49886 .94064 .49262 Mtetra
.601 .717 .926 r
.94064 .49262 .94482 .49886 .9561 .4968 .95198 .4908 Mtetra
.716 .763 .889 r
.35253 .65894 .35813 .66383 .36726 .65983 .3617 .65465 Mtetra
.706 .752 .887 r
.3617 .65465 .36726 .65983 .37641 .65608 .37088 .65061 Mtetra
.69 .739 .889 r
.37088 .65061 .37641 .65608 .38556 .65276 .38006 .64704 Mtetra
.666 .725 .893 r
.38006 .64704 .38556 .65276 .39472 .65005 .38924 .64412 Mtetra
.63 .708 .902 r
.38924 .64412 .39472 .65005 .40388 .64817 .39842 .6421 Mtetra
.587 .688 .911 r
.39842 .6421 .40388 .64817 .41305 .64714 .40761 .641 Mtetra
.529 .664 .922 r
.40761 .641 .41305 .64714 .42223 .64706 .4168 .64097 Mtetra
.474 .643 .931 r
.4168 .64097 .42223 .64706 .43144 .64768 .42601 .64175 Mtetra
.414 .622 .938 r
.42601 .64175 .43144 .64768 .44068 .64886 .43526 .64324 Mtetra
.395 .625 .945 r
.43526 .64324 .44068 .64886 .44998 .65005 .44456 .6448 Mtetra
.413 .651 .956 r
.44456 .6448 .44998 .65005 .45934 .65079 .45393 .64594 Mtetra
.495 .706 .964 r
.45393 .64594 .45934 .65079 .46877 .65041 .46337 .64587 Mtetra
.613 .763 .951 r
.46337 .64587 .46877 .65041 .47826 .64829 .47288 .64387 Mtetra
.712 .793 .915 r
.47288 .64387 .47826 .64829 .48782 .64421 .48246 .63963 Mtetra
.782 .795 .863 r
.48246 .63963 .48782 .64421 .49742 .63787 .4921 .63277 Mtetra
.809 .779 .825 r
.4921 .63277 .49742 .63787 .50704 .62994 .50175 .62407 Mtetra
.816 .758 .797 r
.50175 .62407 .50704 .62994 .51666 .62089 .51141 .61409 Mtetra
.8 .733 .791 r
.51141 .61409 .51666 .62089 .52629 .61204 .52107 .60452 Mtetra
.768 .711 .799 r
.52107 .60452 .52629 .61204 .53592 .60441 .53072 .59661 Mtetra
.713 .689 .826 r
.53072 .59661 .53592 .60441 .54557 .59882 .54039 .59149 Mtetra
.614 .665 .876 r
.54039 .59149 .54557 .59882 .55526 .59579 .55011 .58983 Mtetra
.47 .649 .937 r
.55011 .58983 .55526 .59579 .56501 .59457 .55989 .59062 Mtetra
.197 .594 .945 r
.55989 .59062 .56501 .59457 .57481 .59451 .56975 .59297 Mtetra
.01 .564 .82 r
.56975 .59297 .57481 .59451 .58466 .59392 .57966 .59445 Mtetra
0 0 0 r
.57966 .59445 .58466 .59392 .59453 .59182 .58959 .59364 Mtetra
.257 .75 .669 r
.58959 .59364 .59453 .59182 .60438 .5878 .59951 .58989 Mtetra
.538 .911 .745 r
.59951 .58989 .60438 .5878 .61423 .58203 .60938 .58342 Mtetra
.645 .966 .824 r
.60938 .58342 .61423 .58203 .62409 .57615 .61926 .57659 Mtetra
.646 .967 .892 r
.61926 .57659 .62409 .57615 .63399 .57113 .62919 .5708 Mtetra
.442 .872 .919 r
.62919 .5708 .63399 .57113 .64399 .5682 .63923 .56785 Mtetra
.064 .627 .773 r
.63923 .56785 .64399 .5682 .65411 .56735 .64941 .56775 Mtetra
.175 0 0 r
.64941 .56775 .65411 .56735 .66431 .56737 .65968 .5687 Mtetra
.237 0 0 r
.65968 .5687 .66431 .56737 .67456 .5673 .67001 .5693 Mtetra
.005 0 0 r
.67001 .5693 .67456 .5673 .68478 .56548 .68026 .56718 Mtetra
.398 .839 .719 r
.68026 .56718 .68478 .56548 .69495 .56171 .69042 .56208 Mtetra
.737 .99 .875 r
.69042 .56208 .69495 .56171 .70507 .55642 .70048 .55467 Mtetra
.833 .939 .896 r
.70048 .55467 .70507 .55642 .71519 .55056 .7105 .54635 Mtetra
.782 .836 .893 r
.7105 .54635 .71519 .55056 .72539 .54589 .72061 .5396 Mtetra
.698 .74 .884 r
.72061 .5396 .72539 .54589 .73574 .54305 .7309 .53532 Mtetra
.576 .646 .882 r
.7309 .53532 .73574 .54305 .74629 .54282 .74144 .53457 Mtetra
.458 .571 .881 r
.74144 .53457 .74629 .54282 .75705 .54469 .75222 .53666 Mtetra
.361 .523 .883 r
.75222 .53666 .75705 .54469 .76797 .54781 .76321 .54049 Mtetra
.305 .514 .894 r
.76321 .54049 .76797 .54781 .77899 .55117 .7743 .54476 Mtetra
.347 .572 .924 r
.7743 .54476 .77899 .55117 .78999 .55341 .78539 .54774 Mtetra
.438 .654 .951 r
.78539 .54774 .78999 .55341 .80094 .55402 .7964 .54885 Mtetra
.58 .745 .955 r
.7964 .54885 .80094 .55402 .81176 .55231 .80726 .54727 Mtetra
.682 .791 .932 r
.80726 .54727 .81176 .55231 .82245 .54858 .81797 .54338 Mtetra
.748 .805 .898 r
.81797 .54338 .82245 .54858 .83301 .54304 .82853 .53748 Mtetra
.778 .8 .871 r
.82853 .53748 .83301 .54304 .84348 .53634 .839 .53032 Mtetra
.783 .786 .855 r
.839 .53032 .84348 .53634 .85392 .52915 .84943 .52271 Mtetra
.777 .772 .848 r
.84943 .52271 .85392 .52915 .86438 .52195 .85989 .51515 Mtetra
.758 .756 .851 r
.85989 .51515 .86438 .52195 .87491 .51532 .87043 .50831 Mtetra
.736 .744 .858 r
.87043 .50831 .87491 .51532 .88554 .50941 .88108 .5023 Mtetra
.707 .731 .869 r
.88108 .5023 .88554 .50941 .8963 .50448 .89187 .4974 Mtetra
.679 .721 .881 r
.89187 .4974 .8963 .50448 .90719 .50043 .90281 .49346 Mtetra
.649 .712 .894 r
.90281 .49346 .90719 .50043 .91823 .49725 .91389 .49046 Mtetra
.624 .708 .906 r
.91389 .49046 .91823 .49725 .92938 .49471 .9251 .48814 Mtetra
.604 .707 .917 r
.9251 .48814 .92938 .49471 .94064 .49262 .93643 .48631 Mtetra
.589 .71 .927 r
.93643 .48631 .94064 .49262 .95198 .4908 .94784 .48476 Mtetra
.725 .765 .884 r
.34689 .65403 .35253 .65894 .3617 .65465 .3561 .64944 Mtetra
.715 .753 .883 r
.3561 .64944 .3617 .65465 .37088 .65061 .36531 .64511 Mtetra
.699 .741 .884 r
.36531 .64511 .37088 .65061 .38006 .64704 .37452 .64126 Mtetra
.674 .726 .889 r
.37452 .64126 .38006 .64704 .38924 .64412 .38373 .63808 Mtetra
.638 .708 .897 r
.38373 .63808 .38924 .64412 .39842 .6421 .39294 .63584 Mtetra
.595 .686 .905 r
.39294 .63584 .39842 .6421 .40761 .641 .40214 .63459 Mtetra
.536 .658 .915 r
.40214 .63459 .40761 .641 .4168 .64097 .41135 .6345 Mtetra
.479 .632 .92 r
.41135 .6345 .4168 .64097 .42601 .64175 .42057 .63533 Mtetra
.416 .604 .925 r
.42057 .63533 .42601 .64175 .43526 .64324 .42982 .63702 Mtetra
.395 .602 .93 r
.42982 .63702 .43526 .64324 .44456 .6448 .43912 .63887 Mtetra
.409 .622 .939 r
.43912 .63887 .44456 .6448 .45393 .64594 .44849 .64039 Mtetra
.491 .675 .947 r
.44849 .64039 .45393 .64594 .46337 .64587 .45794 .64067 Mtetra
.609 .735 .935 r
.45794 .64067 .46337 .64587 .47288 .64387 .46747 .63888 Mtetra
.711 .771 .9 r
.46747 .63888 .47288 .64387 .48246 .63963 .47708 .63459 Mtetra
.785 .78 .849 r
.47708 .63459 .48246 .63963 .4921 .63277 .48674 .62734 Mtetra
.814 .77 .812 r
.48674 .62734 .4921 .63277 .50175 .62407 .49644 .61798 Mtetra
.824 .753 .785 r
.49644 .61798 .50175 .62407 .51141 .61409 .50613 .60713 Mtetra
.806 .732 .782 r
.50613 .60713 .51141 .61409 .52107 .60452 .51582 .59687 Mtetra
.77 .71 .796 r
.51582 .59687 .52107 .60452 .53072 .59661 .52549 .58874 Mtetra
.699 .683 .832 r
.52549 .58874 .53072 .59661 .54039 .59149 .53518 .58421 Mtetra
.544 .637 .893 r
.53518 .58421 .54039 .59149 .55011 .58983 .54493 .58416 Mtetra
.257 .55 .928 r
.54493 .58416 .55011 .58983 .55989 .59062 .55475 .58732 Mtetra
0 .295 .706 r
.55475 .58732 .55989 .59062 .56975 .59297 .56466 .5925 Mtetra
.415 0 0 r
.56466 .5925 .56975 .59297 .57966 .59445 .57464 .59636 Mtetra
.291 0 0 r
.57464 .59636 .57966 .59445 .58959 .59364 .58463 .59694 Mtetra
0 0 0 r
.58463 .59694 .58959 .59364 .59951 .58989 .5946 .59323 Mtetra
.497 .86 .623 r
.5946 .59323 .59951 .58989 .60938 .58342 .6045 .58554 Mtetra
.688 .972 .772 r
.6045 .58554 .60938 .58342 .61926 .57659 .61439 .57721 Mtetra
.715 .986 .879 r
.61439 .57721 .61926 .57659 .62919 .5708 .62433 .57025 Mtetra
.467 .881 .938 r
.62433 .57025 .62919 .5708 .63923 .56785 .63441 .56728 Mtetra
0 .525 .717 r
.63441 .56728 .63923 .56785 .64941 .56775 .64467 .56832 Mtetra
.348 0 0 r
.64467 .56832 .64941 .56775 .65968 .5687 .65504 .57075 Mtetra
.397 0 0 r
.65504 .57075 .65968 .5687 .67001 .5693 .66546 .57256 Mtetra
.136 0 0 r
.66546 .57256 .67001 .5693 .68026 .56718 .67576 .57037 Mtetra
0 0 0 r
.67576 .57037 .68026 .56718 .69042 .56208 .6859 .56385 Mtetra
.77 .991 .772 r
.6859 .56385 .69042 .56208 .70048 .55467 .6959 .55399 Mtetra
.893 .961 .833 r
.6959 .55399 .70048 .55467 .7105 .54635 .70581 .54278 Mtetra
.842 .865 .86 r
.70581 .54278 .7105 .54635 .72061 .5396 .71582 .53358 Mtetra
.746 .765 .868 r
.71582 .53358 .72061 .5396 .7309 .53532 .72603 .52763 Mtetra
.599 .659 .88 r
.72603 .52763 .7309 .53532 .74144 .53457 .73655 .52623 Mtetra
.449 .565 .88 r
.73655 .52623 .74144 .53457 .75222 .53666 .74737 .52852 Mtetra
.324 .499 .877 r
.74737 .52852 .75222 .53666 .76321 .54049 .7584 .533 Mtetra
.254 .479 .882 r
.7584 .533 .76321 .54049 .7743 .54476 .76958 .53811 Mtetra
.312 .545 .914 r
.76958 .53811 .7743 .54476 .78539 .54774 .78073 .54173 Mtetra
.426 .635 .943 r
.78073 .54173 .78539 .54774 .7964 .54885 .7918 .5432 Mtetra
.586 .729 .942 r
.7918 .5432 .7964 .54885 .80726 .54727 .80268 .54163 Mtetra
.691 .771 .913 r
.80268 .54163 .80726 .54727 .81797 .54338 .8134 .53748 Mtetra
.753 .782 .877 r
.8134 .53748 .81797 .54338 .82853 .53748 .82396 .53119 Mtetra
.779 .777 .851 r
.82396 .53119 .82853 .53748 .839 .53032 .83442 .52359 Mtetra
.781 .765 .838 r
.83442 .52359 .839 .53032 .84943 .52271 .84486 .51563 Mtetra
.774 .754 .835 r
.84486 .51563 .84943 .52271 .85989 .51515 .85532 .50783 Mtetra
.754 .742 .841 r
.85532 .50783 .85989 .51515 .87043 .50831 .86589 .5009 Mtetra
.732 .732 .851 r
.86589 .5009 .87043 .50831 .88108 .5023 .87657 .49491 Mtetra
.702 .721 .865 r
.87657 .49491 .88108 .5023 .89187 .4974 .8874 .49013 Mtetra
.673 .714 .879 r
.8874 .49013 .89187 .4974 .90281 .49346 .89839 .48637 Mtetra
.641 .706 .894 r
.89839 .48637 .90281 .49346 .91389 .49046 .90953 .48359 Mtetra
.614 .702 .907 r
.90953 .48359 .91389 .49046 .9251 .48814 .9208 .48153 Mtetra
.592 .701 .919 r
.9208 .48153 .9251 .48814 .93643 .48631 .93218 .47997 Mtetra
.577 .704 .929 r
.93218 .47997 .93643 .48631 .94784 .48476 .94366 .47868 Mtetra
.732 .765 .88 r
.34122 .64908 .34689 .65403 .3561 .64944 .35046 .64422 Mtetra
.723 .755 .878 r
.35046 .64422 .3561 .64944 .36531 .64511 .35971 .6396 Mtetra
.707 .743 .88 r
.35971 .6396 .36531 .64511 .37452 .64126 .36895 .63545 Mtetra
.684 .729 .884 r
.36895 .63545 .37452 .64126 .38373 .63808 .3782 .63198 Mtetra
.649 .71 .892 r
.3782 .63198 .38373 .63808 .39294 .63584 .38743 .62945 Mtetra
.607 .687 .899 r
.38743 .62945 .39294 .63584 .40214 .63459 .39665 .62794 Mtetra
.549 .656 .907 r
.39665 .62794 .40214 .63459 .41135 .6345 .40588 .62766 Mtetra
.492 .626 .91 r
.40588 .62766 .41135 .6345 .42057 .63533 .41511 .6284 Mtetra
.428 .593 .912 r
.41511 .6284 .42057 .63533 .42982 .63702 .42437 .63015 Mtetra
.403 .583 .914 r
.42437 .63015 .42982 .63702 .43912 .63887 .43367 .6322 Mtetra
.409 .594 .92 r
.43367 .6322 .43912 .63887 .44849 .64039 .44304 .63407 Mtetra
.484 .644 .927 r
.44304 .63407 .44849 .64039 .45794 .64067 .4525 .63473 Mtetra
.598 .705 .918 r
.4525 .63473 .45794 .64067 .46747 .63888 .46204 .63327 Mtetra
.703 .749 .888 r
.46204 .63327 .46747 .63888 .47708 .63459 .47167 .62912 Mtetra
.783 .768 .839 r
.47167 .62912 .47708 .63459 .48674 .62734 .48136 .62169 Mtetra
.817 .765 .803 r
.48136 .62169 .48674 .62734 .49644 .61798 .49109 .61184 Mtetra
.831 .753 .777 r
.49109 .61184 .49644 .61798 .50613 .60713 .50082 .60024 Mtetra
.814 .735 .777 r
.50082 .60024 .50613 .60713 .51582 .59687 .51054 .58935 Mtetra
.775 .715 .796 r
.51054 .58935 .51582 .59687 .52549 .58874 .52024 .581 Mtetra
.683 .682 .843 r
.52024 .581 .52549 .58874 .53518 .58421 .52995 .57712 Mtetra
.439 .595 .909 r
.52995 .57712 .53518 .58421 .54493 .58416 .53971 .57883 Mtetra
0 .352 .817 r
.53971 .57883 .54493 .58416 .55475 .58732 .54957 .58462 Mtetra
.599 .039 0 r
.54957 .58462 .55475 .58732 .56466 .5925 .55953 .59297 Mtetra
.632 .083 0 r
.55953 .59297 .56466 .5925 .57464 .59636 .56957 .59943 Mtetra
.46 0 0 r
.56957 .59943 .57464 .59636 .58463 .59694 .57963 .60137 Mtetra
.036 0 0 r
.57963 .60137 .58463 .59694 .5946 .59323 .58964 .59728 Mtetra
.588 .889 .599 r
.58964 .59728 .5946 .59323 .6045 .58554 .59956 .5876 Mtetra
.816 .997 .776 r
.59956 .5876 .6045 .58554 .61439 .57721 .60945 .57702 Mtetra
.829 .98 .881 r
.60945 .57702 .61439 .57721 .62433 .57025 .61939 .56835 Mtetra
.577 .884 .991 r
.61939 .56835 .62433 .57025 .63441 .56728 .6295 .56537 Mtetra
0 .469 .774 r
.6295 .56537 .63441 .56728 .64467 .56832 .63985 .56809 Mtetra
.471 0 0 r
.63985 .56809 .64467 .56832 .65504 .57075 .65034 .57276 Mtetra
.52 0 0 r
.65034 .57276 .65504 .57075 .66546 .57256 .66088 .57654 Mtetra
.225 0 0 r
.66088 .57654 .66546 .57256 .67576 .57037 .67125 .57471 Mtetra
0 0 0 r
.67125 .57471 .67576 .57037 .6859 .56385 .68139 .5668 Mtetra
.803 .975 .682 r
.68139 .5668 .6859 .56385 .6959 .55399 .69132 .55428 Mtetra
.934 .958 .764 r
.69132 .55428 .6959 .55399 .70581 .54278 .70112 .53982 Mtetra
.89 .879 .818 r
.70112 .53982 .70581 .54278 .71582 .53358 .71103 .52792 Mtetra
.79 .787 .85 r
.71103 .52792 .71582 .53358 .72603 .52763 .72116 .52013 Mtetra
.623 .677 .88 r
.72116 .52013 .72603 .52763 .73655 .52623 .73165 .51803 Mtetra
.434 .562 .884 r
.73165 .51803 .73655 .52623 .74737 .52852 .74249 .5205 Mtetra
.278 .477 .874 r
.74249 .5205 .74737 .52852 .7584 .533 .75358 .52558 Mtetra
.196 .446 .871 r
.75358 .52558 .7584 .533 .76958 .53811 .76482 .53142 Mtetra
.279 .525 .909 r
.76482 .53142 .76958 .53811 .78073 .54173 .77603 .53549 Mtetra
.423 .626 .938 r
.77603 .53549 .78073 .54173 .7918 .5432 .78713 .53711 Mtetra
.598 .719 .929 r
.78713 .53711 .7918 .5432 .80268 .54163 .79803 .53536 Mtetra
.701 .754 .892 r
.79803 .53536 .80268 .54163 .8134 .53748 .80874 .53083 Mtetra
.756 .76 .856 r
.80874 .53083 .8134 .53748 .82396 .53119 .81929 .5241 Mtetra
.778 .754 .832 r
.81929 .5241 .82396 .53119 .83442 .52359 .82975 .51609 Mtetra
.777 .744 .823 r
.82975 .51609 .83442 .52359 .84486 .51563 .8402 .50788 Mtetra
.769 .736 .822 r
.8402 .50788 .84486 .51563 .85532 .50783 .85068 .49997 Mtetra
.747 .726 .832 r
.85068 .49997 .85532 .50783 .86589 .5009 .86128 .49309 Mtetra
.725 .72 .845 r
.86128 .49309 .86589 .5009 .87657 .49491 .872 .48726 Mtetra
.694 .712 .863 r
.872 .48726 .87657 .49491 .8874 .49013 .88289 .4827 Mtetra
.663 .707 .879 r
.88289 .4827 .8874 .49013 .89839 .48637 .89394 .47921 Mtetra
.631 .701 .896 r
.89394 .47921 .89839 .48637 .90953 .48359 .90513 .4767 Mtetra
.603 .697 .91 r
.90513 .4767 .90953 .48359 .9208 .48153 .91647 .4749 Mtetra
.58 .696 .921 r
.91647 .4749 .9208 .48153 .93218 .47997 .92791 .4736 Mtetra
.565 .699 .931 r
.92791 .4736 .93218 .47997 .94366 .47868 .93945 .47256 Mtetra
.737 .766 .876 r
.33552 .6441 .34122 .64908 .35046 .64422 .34479 .63901 Mtetra
.73 .758 .875 r
.34479 .63901 .35046 .64422 .35971 .6396 .35407 .63414 Mtetra
.715 .748 .877 r
.35407 .63414 .35971 .6396 .36895 .63545 .36335 .62971 Mtetra
.694 .735 .882 r
.36335 .62971 .36895 .63545 .3782 .63198 .37262 .62593 Mtetra
.662 .717 .889 r
.37262 .62593 .3782 .63198 .38743 .62945 .38188 .62305 Mtetra
.621 .693 .895 r
.38188 .62305 .38743 .62945 .39665 .62794 .39114 .6212 Mtetra
.566 .661 .901 r
.39114 .6212 .39665 .62794 .40588 .62766 .40038 .62059 Mtetra
.51 .627 .903 r
.40038 .62059 .40588 .62766 .41511 .6284 .40963 .62109 Mtetra
.444 .589 .902 r
.40963 .62109 .41511 .6284 .42437 .63015 .4189 .62273 Mtetra
.415 .571 .9 r
.4189 .62273 .42437 .63015 .43367 .6322 .42821 .62485 Mtetra
.412 .572 .902 r
.42821 .62485 .43367 .6322 .44304 .63407 .43758 .62698 Mtetra
.477 .614 .908 r
.43758 .62698 .44304 .63407 .4525 .63473 .44704 .62802 Mtetra
.582 .673 .902 r
.44704 .62802 .4525 .63473 .46204 .63327 .45659 .62702 Mtetra
.689 .725 .878 r
.45659 .62702 .46204 .63327 .47167 .62912 .46623 .62322 Mtetra
.776 .755 .834 r
.46623 .62322 .47167 .62912 .48136 .62169 .47595 .61591 Mtetra
.818 .762 .8 r
.47595 .61591 .48136 .62169 .49109 .61184 .48571 .6059 Mtetra
.839 .758 .774 r
.48571 .6059 .49109 .61184 .50082 .60024 .49548 .59379 Mtetra
.825 .747 .777 r
.49548 .59379 .50082 .60024 .51054 .58935 .50523 .5824 Mtetra
.785 .731 .802 r
.50523 .5824 .51054 .58935 .52024 .581 .51496 .57381 Mtetra
.67 .693 .863 r
.51496 .57381 .52024 .581 .52995 .57712 .52468 .57046 Mtetra
.297 .535 .912 r
.52468 .57046 .52995 .57712 .53971 .57883 .53446 .57379 Mtetra
0 .114 .607 r
.53446 .57379 .53971 .57883 .54957 .58462 .54434 .58209 Mtetra
.744 .223 0 r
.54434 .58209 .54957 .58462 .55953 .59297 .55435 .59357 Mtetra
.719 .207 .003 r
.55435 .59357 .55953 .59297 .56957 .59943 .56445 .60252 Mtetra
.519 0 0 r
.56445 .60252 .56957 .59943 .57963 .60137 .57456 .60552 Mtetra
0 0 0 r
.57456 .60552 .57963 .60137 .58964 .59728 .58461 .60047 Mtetra
.83 .985 .709 r
.58461 .60047 .58964 .59728 .59956 .5876 .59453 .58796 Mtetra
.926 .953 .785 r
.59453 .58796 .59956 .5876 .60945 .57702 .60441 .57429 Mtetra
.876 .877 .832 r
.60441 .57429 .60945 .57702 .61939 .56835 .61432 .56333 Mtetra
.654 .77 .935 r
.61432 .56333 .61939 .56835 .6295 .56537 .62447 .56033 Mtetra
.023 .431 .866 r
.62447 .56033 .6295 .56537 .63985 .56809 .6349 .56531 Mtetra
.497 0 0 r
.6349 .56531 .63985 .56809 .65034 .57276 .64552 .57304 Mtetra
.605 .042 0 r
.64552 .57304 .65034 .57276 .66088 .57654 .65621 .57965 Mtetra
.239 0 0 r
.65621 .57965 .66088 .57654 .67125 .57471 .66667 .57877 Mtetra
.471 .816 .53 r
.66667 .57877 .67125 .57471 .68139 .5668 .67683 .56975 Mtetra
.882 .976 .675 r
.67683 .56975 .68139 .5668 .69132 .55428 .6867 .55469 Mtetra
.96 .932 .718 r
.6867 .55469 .69132 .55428 .70112 .53982 .69639 .53702 Mtetra
.917 .873 .778 r
.69639 .53702 .70112 .53982 .71103 .52792 .70621 .52254 Mtetra
.824 .802 .83 r
.70621 .52254 .71103 .52792 .72116 .52013 .71628 .51307 Mtetra
.643 .699 .887 r
.71628 .51307 .72116 .52013 .73165 .51803 .72677 .51038 Mtetra
.405 .564 .898 r
.72677 .51038 .73165 .51803 .74249 .5205 .73763 .51305 Mtetra
.212 .456 .875 r
.73763 .51305 .74249 .5205 .75358 .52558 .74877 .5186 Mtetra
.126 .417 .863 r
.74877 .5186 .75358 .52558 .76482 .53142 .76005 .52492 Mtetra
.255 .519 .91 r
.76005 .52492 .76482 .53142 .77603 .53549 .77128 .52912 Mtetra
.436 .629 .936 r
.77128 .52912 .77603 .53549 .78713 .53711 .78239 .53057 Mtetra
.618 .712 .913 r
.78239 .53057 .78713 .53711 .79803 .53536 .79329 .52841 Mtetra
.712 .737 .871 r
.79329 .52841 .79803 .53536 .80874 .53083 .80399 .52337 Mtetra
.757 .738 .836 r
.80399 .52337 .80874 .53083 .81929 .5241 .81453 .5162 Mtetra
.774 .733 .815 r
.81453 .5162 .81929 .5241 .82975 .51609 .82499 .50788 Mtetra
.77 .725 .811 r
.82499 .50788 .82975 .51609 .8402 .50788 .83546 .49955 Mtetra
.761 .72 .814 r
.83546 .49955 .8402 .50788 .85068 .49997 .84597 .4917 Mtetra
.739 .714 .828 r
.84597 .4917 .85068 .49997 .86128 .49309 .85662 .48503 Mtetra
.715 .711 .844 r
.85662 .48503 .86128 .49309 .872 .48726 .86741 .4795 Mtetra
.684 .706 .865 r
.86741 .4795 .872 .48726 .88289 .4827 .87836 .47526 Mtetra
.653 .703 .883 r
.87836 .47526 .88289 .4827 .89394 .47921 .88947 .47209 Mtetra
.62 .699 .901 r
.88947 .47209 .89394 .47921 .90513 .4767 .90072 .46985 Mtetra
.591 .695 .915 r
.90072 .46985 .90513 .4767 .91647 .4749 .91212 .46831 Mtetra
.569 .694 .925 r
.91212 .46831 .91647 .4749 .92791 .4736 .92362 .46723 Mtetra
.554 .696 .934 r
.92362 .46723 .92791 .4736 .93945 .47256 .93521 .46639 Mtetra
.741 .767 .873 r
.32977 .63908 .33552 .6441 .34479 .63901 .33908 .63383 Mtetra
.735 .761 .874 r
.33908 .63383 .34479 .63901 .35407 .63414 .34839 .62877 Mtetra
.723 .753 .877 r
.34839 .62877 .35407 .63414 .36335 .62971 .3577 .6241 Mtetra
.703 .742 .882 r
.3577 .6241 .36335 .62971 .37262 .62593 .36701 .62002 Mtetra
.675 .726 .888 r
.36701 .62002 .37262 .62593 .38188 .62305 .3763 .61675 Mtetra
.638 .703 .893 r
.3763 .61675 .38188 .62305 .39114 .6212 .38559 .61446 Mtetra
.587 .671 .898 r
.38559 .61446 .39114 .6212 .40038 .62059 .39486 .61339 Mtetra
.533 .635 .897 r
.39486 .61339 .40038 .62059 .40963 .62109 .40414 .61347 Mtetra
.469 .592 .894 r
.40414 .61347 .40963 .62109 .4189 .62273 .41342 .61482 Mtetra
.435 .567 .888 r
.41342 .61482 .4189 .62273 .42821 .62485 .42274 .61682 Mtetra
.421 .557 .886 r
.42274 .61682 .42821 .62485 .43758 .62698 .43211 .61909 Mtetra
.471 .587 .888 r
.43211 .61909 .43758 .62698 .44704 .62802 .44156 .6205 Mtetra
.561 .64 .886 r
.44156 .6205 .44704 .62802 .45659 .62702 .45111 .62007 Mtetra
.666 .698 .87 r
.45111 .62007 .45659 .62702 .46623 .62322 .46076 .61689 Mtetra
.761 .741 .835 r
.46076 .61689 .46623 .62322 .47595 .61591 .4705 .61012 Mtetra
.815 .763 .804 r
.4705 .61012 .47595 .61591 .48571 .6059 .48029 .60036 Mtetra
.846 .769 .778 r
.48029 .60036 .48571 .6059 .49548 .59379 .4901 .58811 Mtetra
.839 .767 .782 r
.4901 .58811 .49548 .59379 .50523 .5824 .49988 .57641 Mtetra
.801 .759 .813 r
.49988 .57641 .50523 .5824 .51496 .57381 .50964 .56752 Mtetra
.662 .719 .891 r
.50964 .56752 .51496 .57381 .52468 .57046 .51939 .56447 Mtetra
.127 .462 .889 r
.51939 .56447 .52468 .57046 .53446 .57379 .52918 .569 Mtetra
.58 .065 0 r
.52918 .569 .53446 .57379 .54434 .58209 .53908 .57939 Mtetra
.807 .318 0 r
.53908 .57939 .54434 .58209 .55435 .59357 .54911 .59363 Mtetra
.765 .268 .037 r
.54911 .59363 .55435 .59357 .56445 .60252 .55925 .60466 Mtetra
.524 0 0 r
.55925 .60466 .56445 .60252 .57456 .60552 .56941 .60825 Mtetra
.492 .877 .688 r
.56941 .60825 .57456 .60552 .58461 .60047 .57949 .60148 Mtetra
.949 .94 .742 r
.57949 .60148 .58461 .60047 .59453 .58796 .58939 .58514 Mtetra
.927 .839 .738 r
.58939 .58514 .59453 .58796 .60441 .57429 .59923 .56748 Mtetra
.85 .753 .756 r
.59923 .56748 .60441 .57429 .61432 .56333 .60911 .55357 Mtetra
.648 .631 .819 r
.60911 .55357 .61432 .56333 .62447 .56033 .61926 .55055 Mtetra
.149 .349 .806 r
.61926 .55055 .62447 .56033 .6349 .56531 .62979 .55844 Mtetra
0 .041 .585 r
.62979 .55844 .6349 .56531 .64552 .57304 .64055 .57013 Mtetra
.637 .093 0 r
.64055 .57013 .64552 .57304 .65621 .57965 .6514 .58055 Mtetra
.208 0 0 r
.6514 .58055 .65621 .57965 .66667 .57877 .66198 .58138 Mtetra
.686 .957 .711 r
.66198 .58138 .66667 .57877 .67683 .56975 .67217 .57175 Mtetra
.944 .961 .695 r
.67217 .57175 .67683 .56975 .6867 .55469 .682 .55456 Mtetra
.971 .899 .692 r
.682 .55456 .6867 .55469 .69639 .53702 .69163 .53407 Mtetra
.93 .858 .749 r
.69163 .53407 .69639 .53702 .70621 .52254 .70138 .51742 Mtetra
.846 .812 .816 r
.70138 .51742 .70621 .52254 .71628 .51307 .71142 .50668 Mtetra
.654 .727 .903 r
.71142 .50668 .71628 .51307 .72677 .51038 .72191 .50365 Mtetra
.351 .567 .919 r
.72191 .50365 .72677 .51038 .73763 .51305 .73281 .50658 Mtetra
.117 .432 .873 r
.73281 .50658 .73763 .51305 .74877 .5186 .74397 .51241 Mtetra
.048 .396 .853 r
.74397 .51241 .74877 .5186 .76005 .52492 .75528 .51883 Mtetra
.248 .533 .92 r
.75528 .51883 .76005 .52492 .77128 .52912 .76651 .52273 Mtetra
.469 .648 .936 r
.76651 .52273 .77128 .52912 .78239 .53057 .7776 .52358 Mtetra
.644 .71 .895 r
.7776 .52358 .78239 .53057 .79329 .52841 .78846 .52074 Mtetra
.722 .721 .849 r
.78846 .52074 .79329 .52841 .80399 .52337 .79914 .51505 Mtetra
.756 .718 .817 r
.79914 .51505 .80399 .52337 .81453 .5162 .80968 .50746 Mtetra
.768 .713 .801 r
.80968 .50746 .81453 .5162 .82499 .50788 .82015 .49895 Mtetra
.761 .708 .802 r
.82015 .49895 .82499 .50788 .83546 .49955 .83064 .4907 Mtetra
.75 .706 .809 r
.83064 .4907 .83546 .49955 .84597 .4917 .84122 .48312 Mtetra
.728 .703 .827 r
.84122 .48312 .84597 .4917 .85662 .48503 .85193 .47683 Mtetra
.703 .703 .847 r
.85193 .47683 .85662 .48503 .86741 .4795 .86279 .47174 Mtetra
.672 .703 .87 r
.86279 .47174 .86741 .4795 .87836 .47526 .87381 .46791 Mtetra
.64 .701 .891 r
.87381 .46791 .87836 .47526 .88947 .47209 .88499 .4651 Mtetra
.608 .699 .908 r
.88499 .4651 .88947 .47209 .90072 .46985 .8963 .46314 Mtetra
.58 .696 .921 r
.8963 .46314 .90072 .46985 .91212 .46831 .90775 .46181 Mtetra
.559 .694 .93 r
.90775 .46181 .91212 .46831 .92362 .46723 .9193 .46089 Mtetra
.546 .694 .937 r
.9193 .46089 .92362 .46723 .93521 .46639 .93095 .46018 Mtetra
.742 .767 .873 r
.32399 .63404 .32977 .63908 .33908 .63383 .33332 .62872 Mtetra
.738 .765 .874 r
.33332 .62872 .33908 .63383 .34839 .62877 .34266 .62355 Mtetra
.728 .76 .878 r
.34266 .62355 .34839 .62877 .3577 .6241 .35201 .6187 Mtetra
.712 .752 .884 r
.35201 .6187 .3577 .6241 .36701 .62002 .36135 .61436 Mtetra
.689 .739 .89 r
.36135 .61436 .36701 .62002 .3763 .61675 .37068 .61071 Mtetra
.656 .718 .894 r
.37068 .61071 .3763 .61675 .38559 .61446 .38 .60795 Mtetra
.61 .688 .898 r
.38 .60795 .38559 .61446 .39486 .61339 .38931 .60631 Mtetra
.56 .651 .896 r
.38931 .60631 .39486 .61339 .40414 .61347 .39862 .60583 Mtetra
.497 .606 .892 r
.39862 .60583 .40414 .61347 .41342 .61482 .40792 .60668 Mtetra
.459 .573 .882 r
.40792 .60668 .41342 .61482 .42274 .61682 .41725 .60835 Mtetra
.435 .552 .875 r
.41725 .60835 .42274 .61682 .43211 .61909 .42663 .61056 Mtetra
.469 .568 .873 r
.42663 .61056 .43211 .61909 .44156 .6205 .43608 .6122 Mtetra
.54 .61 .872 r
.43608 .6122 .44156 .6205 .45111 .62007 .44563 .61236 Mtetra
.637 .668 .863 r
.44563 .61236 .45111 .62007 .46076 .61689 .45527 .61 Mtetra
.736 .722 .838 r
.45527 .61 .46076 .61689 .4705 .61012 .46502 .60419 Mtetra
.802 .759 .813 r
.46502 .60419 .4705 .61012 .48029 .60036 .47482 .5952 Mtetra
.847 .78 .786 r
.47482 .5952 .48029 .60036 .4901 .58811 .48467 .58332 Mtetra
.851 .792 .793 r
.48467 .58332 .4901 .58811 .49988 .57641 .49449 .57165 Mtetra
.822 .797 .829 r
.49449 .57165 .49988 .57641 .50964 .56752 .50428 .56247 Mtetra
.664 .766 .926 r
.50428 .56247 .50964 .56752 .51939 .56447 .51406 .55934 Mtetra
0 .406 .849 r
.51406 .55934 .51939 .56447 .52918 .569 .52386 .56429 Mtetra
.652 .14 0 r
.52386 .56429 .52918 .569 .53908 .57939 .53376 .5758 Mtetra
.824 .348 0 r
.53376 .5758 .53908 .57939 .54911 .59363 .54381 .59179 Mtetra
.774 .266 0 r
.54381 .59179 .54911 .59363 .55925 .60466 .55398 .60406 Mtetra
.37 0 0 r
.55398 .60406 .55925 .60466 .56941 .60825 .56417 .60766 Mtetra
.841 .965 .884 r
.56417 .60766 .56941 .60825 .57949 .60148 .57425 .59876 Mtetra
.937 .828 .712 r
.57425 .59876 .57949 .60148 .58939 .58514 .58414 .57832 Mtetra
.895 .75 .693 r
.58414 .57832 .58939 .58514 .59923 .56748 .59393 .55639 Mtetra
.825 .682 .706 r
.59393 .55639 .59923 .56748 .60911 .55357 .60376 .5393 Mtetra
.633 .559 .753 r
.60376 .5393 .60911 .55357 .61926 .55055 .61391 .53625 Mtetra
.178 .281 .733 r
.61391 .53625 .61926 .55055 .62979 .55844 .62452 .54727 Mtetra
0 .012 .587 r
.62452 .54727 .62979 .55844 .64055 .57013 .63541 .5632 Mtetra
0 0 .438 r
.63541 .5632 .64055 .57013 .6514 .58055 .6464 .57771 Mtetra
.002 .516 .858 r
.6464 .57771 .6514 .58055 .66198 .58138 .65709 .58065 Mtetra
.854 .97 .87 r
.65709 .58065 .66198 .58138 .67217 .57175 .66733 .57098 Mtetra
.958 .899 .723 r
.66733 .57098 .67217 .57175 .682 .55456 .67717 .5525 Mtetra
.96 .85 .688 r
.67717 .5525 .682 .55456 .69163 .53407 .68677 .5302 Mtetra
.925 .831 .734 r
.68677 .5302 .69163 .53407 .70138 .51742 .69652 .51237 Mtetra
.854 .816 .811 r
.69652 .51237 .70138 .51742 .71142 .50668 .70657 .50117 Mtetra
.649 .759 .93 r
.70657 .50117 .71142 .50668 .72191 .50365 .71709 .49818 Mtetra
.256 .564 .936 r
.71709 .49818 .72191 .50365 .73281 .50658 .72803 .50136 Mtetra
.003 .407 .854 r
.72803 .50136 .73281 .50658 .74397 .51241 .73921 .50712 Mtetra
0 .397 .848 r
.73921 .50712 .74397 .51241 .75528 .51883 .75051 .51312 Mtetra
.285 .574 .937 r
.75051 .51312 .75528 .51883 .76651 .52273 .7617 .51619 Mtetra
.526 .672 .93 r
.7617 .51619 .76651 .52273 .7776 .52358 .77274 .51601 Mtetra
.671 .705 .873 r
.77274 .51601 .7776 .52358 .78846 .52074 .78356 .51228 Mtetra
.73 .706 .828 r
.78356 .51228 .78846 .52074 .79914 .51505 .7942 .50594 Mtetra
.753 .7 .802 r
.7942 .50594 .79914 .51505 .80968 .50746 .80474 .49806 Mtetra
.76 .698 .793 r
.80474 .49806 .80968 .50746 .82015 .49895 .81524 .48956 Mtetra
.751 .695 .798 r
.81524 .48956 .82015 .49895 .83064 .4907 .82579 .48161 Mtetra
.739 .697 .811 r
.82579 .48161 .83064 .4907 .84122 .48312 .83643 .4745 Mtetra
.715 .699 .833 r
.83643 .4745 .84122 .48312 .85193 .47683 .84723 .46875 Mtetra
.69 .702 .856 r
.84723 .46875 .85193 .47683 .86279 .47174 .85817 .4642 Mtetra
.658 .704 .881 r
.85817 .4642 .86279 .47174 .87381 .46791 .86927 .46082 Mtetra
.626 .705 .902 r
.86927 .46082 .87381 .46791 .88499 .4651 .88051 .45837 Mtetra
.596 .704 .919 r
.88051 .45837 .88499 .4651 .8963 .46314 .89188 .45664 Mtetra
.57 .7 .93 r
.89188 .45664 .8963 .46314 .90775 .46181 .90338 .45545 Mtetra
.551 .697 .936 r
.90338 .45545 .90775 .46181 .9193 .46089 .91497 .45461 Mtetra
.542 .696 .94 r
.91497 .45461 .9193 .46089 .93095 .46018 .92665 .45393 Mtetra
.741 .766 .874 r
.31818 .62896 .32399 .63404 .33332 .62872 .32753 .62369 Mtetra
.738 .768 .877 r
.32753 .62369 .33332 .62872 .34266 .62355 .33689 .61851 Mtetra
.731 .768 .882 r
.33689 .61851 .34266 .62355 .35201 .6187 .34626 .61358 Mtetra
.719 .765 .889 r
.34626 .61358 .35201 .6187 .36135 .61436 .35563 .60906 Mtetra
.701 .755 .894 r
.35563 .60906 .36135 .61436 .37068 .61071 .365 .60507 Mtetra
.673 .738 .899 r
.365 .60507 .37068 .61071 .38 .60795 .37436 .60183 Mtetra
.635 .711 .902 r
.37436 .60183 .38 .60795 .38931 .60631 .38371 .59956 Mtetra
.589 .675 .899 r
.38371 .59956 .38931 .60631 .39862 .60583 .39305 .59839 Mtetra
.53 .629 .893 r
.39305 .59839 .39862 .60583 .40792 .60668 .40239 .59853 Mtetra
.49 .59 .881 r
.40239 .59853 .40792 .60668 .41725 .60835 .41175 .59962 Mtetra
.458 .558 .869 r
.41175 .59962 .41725 .60835 .42663 .61056 .42114 .60149 Mtetra
.475 .558 .861 r
.42114 .60149 .42663 .61056 .43608 .6122 .43059 .60316 Mtetra
.522 .583 .858 r
.43059 .60316 .43608 .6122 .44563 .61236 .44013 .60386 Mtetra
.603 .634 .855 r
.44013 .60386 .44563 .61236 .45527 .61 .44977 .60247 Mtetra
.698 .695 .844 r
.44977 .60247 .45527 .61 .46502 .60419 .4595 .59804 Mtetra
.778 .752 .829 r
.4595 .59804 .46502 .60419 .47482 .5952 .46932 .59042 Mtetra
.842 .794 .805 r
.46932 .59042 .47482 .5952 .48467 .58332 .47919 .57959 Mtetra
.861 .825 .812 r
.47919 .57959 .48467 .58332 .49449 .57165 .48905 .56839 Mtetra
.844 .849 .848 r
.48905 .56839 .49449 .57165 .50428 .56247 .49888 .55898 Mtetra
.679 .837 .959 r
.49888 .55898 .50428 .56247 .51406 .55934 .50868 .55527 Mtetra
0 .422 .835 r
.50868 .55527 .51406 .55934 .52386 .56429 .5185 .55952 Mtetra
.632 .119 0 r
.5185 .55952 .52386 .56429 .53376 .5758 .52841 .5707 Mtetra
.792 .318 0 r
.52841 .5707 .53376 .5758 .54381 .59179 .53845 .58687 Mtetra
.662 .156 0 r
.53845 .58687 .54381 .59179 .55398 .60406 .54862 .59915 Mtetra
.201 .562 .936 r
.54862 .59915 .55398 .60406 .56417 .60766 .55882 .6021 Mtetra
.839 .785 .8 r
.55882 .6021 .56417 .60766 .57425 .59876 .56891 .59091 Mtetra
.892 .734 .679 r
.56891 .59091 .57425 .59876 .58414 .57832 .57878 .56663 Mtetra
.863 .688 .663 r
.57878 .56663 .58414 .57832 .59393 .55639 .58853 .54071 Mtetra
.804 .636 .674 r
.58853 .54071 .59393 .55639 .60376 .5393 .59831 .52053 Mtetra
.621 .515 .712 r
.59831 .52053 .60376 .5393 .61391 .53625 .60844 .51744 Mtetra
.192 .24 .683 r
.60844 .51744 .61391 .53625 .62452 .54727 .6191 .5315 Mtetra
0 .011 .577 r
.6191 .5315 .62452 .54727 .63541 .5632 .63008 .55139 Mtetra
0 0 .526 r
.63008 .55139 .63541 .5632 .6464 .57771 .64118 .56971 Mtetra
.237 .462 .874 r
.64118 .56971 .6464 .57771 .65709 .58065 .65197 .5749 Mtetra
.81 .79 .834 r
.65197 .5749 .65709 .58065 .66733 .57098 .66227 .56585 Mtetra
.91 .799 .726 r
.66227 .56585 .66733 .57098 .67717 .5525 .67216 .54731 Mtetra
.927 .791 .69 r
.67216 .54731 .67717 .5525 .68677 .5302 .68181 .52479 Mtetra
.903 .797 .733 r
.68181 .52479 .68677 .5302 .69652 .51237 .69162 .50727 Mtetra
.844 .815 .822 r
.69162 .50727 .69652 .51237 .70657 .50117 .70175 .49674 Mtetra
.61 .792 .969 r
.70175 .49674 .70657 .50117 .71709 .49818 .71234 .4943 Mtetra
.091 .532 .908 r
.71234 .4943 .71709 .49818 .72803 .50136 .72331 .49768 Mtetra
0 .381 .799 r
.72331 .49768 .72803 .50136 .73921 .50712 .73448 .50291 Mtetra
0 .436 .854 r
.73448 .50291 .73921 .50712 .75051 .51312 .74573 .5078 Mtetra
.371 .642 .96 r
.74573 .5078 .75051 .51312 .7617 .51619 .75685 .50942 Mtetra
.595 .698 .915 r
.75685 .50942 .7617 .51619 .77274 .51601 .7678 .50778 Mtetra
.696 .698 .848 r
.7678 .50778 .77274 .51601 .78356 .51228 .77856 .50299 Mtetra
.734 .69 .809 r
.77856 .50299 .78356 .51228 .7942 .50594 .78918 .49606 Mtetra
.746 .684 .791 r
.78918 .49606 .7942 .50594 .80474 .49806 .79974 .48809 Mtetra
.749 .684 .788 r
.79974 .48809 .80474 .49806 .81524 .48956 .81029 .4799 Mtetra
.739 .686 .8 r
.81029 .4799 .81524 .48956 .82579 .48161 .82092 .47251 Mtetra
.726 .692 .818 r
.82092 .47251 .82579 .48161 .83643 .4745 .83165 .46608 Mtetra
.701 .699 .845 r
.83165 .46608 .83643 .4745 .84723 .46875 .84253 .46101 Mtetra
.674 .706 .871 r
.84253 .46101 .84723 .46875 .85817 .4642 .85357 .45708 Mtetra
.643 .712 .897 r
.85357 .45708 .85817 .4642 .86927 .46082 .86474 .45415 Mtetra
.611 .714 .918 r
.86474 .45415 .86927 .46082 .88051 .45837 .87605 .45201 Mtetra
.584 .713 .932 r
.87605 .45201 .88051 .45837 .89188 .45664 .88747 .45043 Mtetra
.562 .709 .94 r
.88747 .45043 .89188 .45664 .90338 .45545 .899 .44928 Mtetra
.548 .705 .943 r
.899 .44928 .90338 .45545 .91497 .45461 .91062 .4484 Mtetra
.543 .701 .943 r
.91062 .4484 .91497 .45461 .92665 .45393 .92232 .44763 Mtetra
.736 .766 .877 r
.31232 .62385 .31818 .62896 .32753 .62369 .32169 .61873 Mtetra
.736 .772 .882 r
.32169 .61873 .32753 .62369 .33689 .61851 .33107 .61366 Mtetra
.731 .776 .889 r
.33107 .61366 .33689 .61851 .34626 .61358 .34046 .60877 Mtetra
.723 .777 .895 r
.34046 .60877 .34626 .61358 .35563 .60906 .34986 .60415 Mtetra
.71 .773 .901 r
.34986 .60415 .35563 .60906 .365 .60507 .35926 .59992 Mtetra
.689 .76 .906 r
.35926 .59992 .365 .60507 .37436 .60183 .36866 .59627 Mtetra
.658 .739 .909 r
.36866 .59627 .37436 .60183 .38371 .59956 .37805 .59339 Mtetra
.618 .706 .908 r
.37805 .59339 .38371 .59956 .39305 .59839 .38744 .59148 Mtetra
.566 .662 .902 r
.38744 .59148 .39305 .59839 .40239 .59853 .39682 .59079 Mtetra
.525 .619 .888 r
.39682 .59079 .40239 .59853 .41175 .59962 .40621 .59109 Mtetra
.487 .579 .873 r
.40621 .59109 .41175 .59962 .42114 .60149 .41563 .59232 Mtetra
.489 .564 .858 r
.41563 .59232 .42114 .60149 .43059 .60316 .42509 .5937 Mtetra
.513 .57 .85 r
.42509 .5937 .43059 .60316 .44013 .60386 .43462 .59466 Mtetra
.571 .605 .847 r
.43462 .59466 .44013 .60386 .44977 .60247 .44425 .59415 Mtetra
.65 .66 .846 r
.44425 .59415 .44977 .60247 .4595 .59804 .45397 .59129 Mtetra
.736 .729 .844 r
.45397 .59129 .4595 .59804 .46932 .59042 .46378 .58548 Mtetra
.817 .792 .828 r
.46378 .58548 .46932 .59042 .47919 .57959 .47365 .57637 Mtetra
.854 .848 .837 r
.47365 .57637 .47919 .57959 .48905 .56839 .48354 .56627 Mtetra
.853 .893 .865 r
.48354 .56627 .48905 .56839 .49888 .55898 .49342 .55698 Mtetra
.701 .907 .968 r
.49342 .55698 .49888 .55898 .50868 .55527 .50326 .55236 Mtetra
.052 .552 .883 r
.50326 .55236 .50868 .55527 .5185 .55952 .51311 .55469 Mtetra
.485 0 0 r
.51311 .55469 .5185 .55952 .52841 .5707 .52302 .56373 Mtetra
.63 .172 0 r
.52302 .56373 .52841 .5707 .53845 .58687 .53305 .57796 Mtetra
0 .138 .684 r
.53305 .57796 .53845 .58687 .54862 .59915 .54319 .58874 Mtetra
.483 .539 .838 r
.54319 .58874 .54862 .59915 .55882 .6021 .55339 .59066 Mtetra
.783 .664 .732 r
.55339 .59066 .55882 .6021 .56891 .59091 .56348 .57823 Mtetra
.854 .678 .662 r
.56348 .57823 .56891 .59091 .57878 .56663 .57337 .55232 Mtetra
.85 .665 .652 r
.57337 .55232 .57878 .56663 .58853 .54071 .58312 .52447 Mtetra
.81 .636 .666 r
.58312 .52447 .58853 .54071 .59831 .52053 .59288 .50251 Mtetra
.623 .521 .718 r
.59288 .50251 .59831 .52053 .60844 .51744 .603 .49939 Mtetra
.096 .181 .664 r
.603 .49939 .60844 .51744 .6191 .5315 .61366 .51517 Mtetra
0 0 .538 r
.61366 .51517 .6191 .5315 .63008 .55139 .62466 .53693 Mtetra
0 0 .552 r
.62466 .53693 .63008 .55139 .64118 .56971 .63578 .55683 Mtetra
.344 .414 .79 r
.63578 .55683 .64118 .56971 .65197 .5749 .64661 .56322 Mtetra
.731 .644 .763 r
.64661 .56322 .65197 .5749 .66227 .56585 .65696 .55515 Mtetra
.834 .696 .712 r
.65696 .55515 .66227 .56585 .67216 .54731 .66695 .5381 Mtetra
.872 .724 .695 r
.66695 .5381 .67216 .54731 .68181 .52479 .67673 .51749 Mtetra
.863 .757 .744 r
.67673 .51749 .68181 .52479 .69162 .50727 .68669 .50209 Mtetra
.812 .813 .851 r
.68669 .50209 .69162 .50727 .70175 .49674 .69696 .49348 Mtetra
.512 .807 .999 r
.69696 .49348 .70175 .49674 .71234 .4943 .70763 .49193 Mtetra
0 .471 .805 r
.70763 .49193 .71234 .4943 .72331 .49768 .71862 .49515 Mtetra
0 .408 .766 r
.71862 .49515 .72331 .49768 .73448 .50291 .72975 .49922 Mtetra
.102 .55 .913 r
.72975 .49922 .73448 .50291 .74573 .5078 .74091 .50231 Mtetra
.504 .706 .961 r
.74091 .50231 .74573 .5078 .75685 .50942 .75192 .50203 Mtetra
.657 .706 .883 r
.75192 .50203 .75685 .50942 .7678 .50778 .76277 .49872 Mtetra
.712 .686 .824 r
.76277 .49872 .7678 .50778 .77856 .50299 .77349 .49299 Mtetra
.733 .677 .796 r
.77349 .49299 .77856 .50299 .78918 .49606 .78411 .48573 Mtetra
.738 .673 .788 r
.78411 .48573 .78918 .49606 .79974 .48809 .79471 .47801 Mtetra
.738 .678 .793 r
.79471 .47801 .79974 .48809 .81029 .4799 .80533 .47044 Mtetra
.726 .686 .811 r
.80533 .47044 .81029 .4799 .82092 .47251 .81606 .46382 Mtetra
.711 .697 .835 r
.81606 .46382 .82092 .47251 .83165 .46608 .82689 .45821 Mtetra
.685 .708 .865 r
.82689 .45821 .83165 .46608 .84253 .46101 .83788 .45386 Mtetra
.656 .718 .894 r
.83788 .45386 .84253 .46101 .85357 .45708 .84899 .45051 Mtetra
.626 .725 .918 r
.84899 .45051 .85357 .45708 .86474 .45415 .86024 .44797 Mtetra
.597 .727 .935 r
.86024 .44797 .86474 .45415 .87605 .45201 .8716 .44605 Mtetra
.575 .726 .945 r
.8716 .44605 .87605 .45201 .88747 .45043 .88306 .44452 Mtetra
.559 .721 .949 r
.88306 .44452 .88747 .45043 .899 .44928 .89462 .44329 Mtetra
.551 .715 .949 r
.89462 .44329 .899 .44928 .91062 .4484 .90625 .44226 Mtetra
.55 .709 .945 r
.90625 .44226 .91062 .4484 .92232 .44763 .91796 .44128 Mtetra
.729 .765 .882 r
.30643 .61871 .31232 .62385 .32169 .61873 .3158 .61384 Mtetra
.729 .775 .889 r
.3158 .61384 .32169 .61873 .33107 .61366 .32519 .60899 Mtetra
.728 .783 .897 r
.32519 .60899 .33107 .61366 .34046 .60877 .3346 .60425 Mtetra
.723 .789 .905 r
.3346 .60425 .34046 .60877 .34986 .60415 .34402 .59967 Mtetra
.715 .791 .911 r
.34402 .59967 .34986 .60415 .35926 .59992 .35345 .59533 Mtetra
.7 .785 .917 r
.35345 .59533 .35926 .59992 .36866 .59627 .36289 .59139 Mtetra
.677 .77 .921 r
.36289 .59139 .36866 .59627 .37805 .59339 .37233 .588 Mtetra
.645 .744 .921 r
.37233 .588 .37805 .59339 .38744 .59148 .38176 .5854 Mtetra
.601 .705 .916 r
.38176 .5854 .38744 .59148 .39682 .59079 .39119 .58381 Mtetra
.564 .661 .902 r
.39119 .58381 .39682 .59079 .40621 .59109 .40063 .58313 Mtetra
.528 .616 .883 r
.40063 .58313 .40621 .59109 .41563 .59232 .41008 .58339 Mtetra
.517 .585 .862 r
.41008 .58339 .41563 .59232 .42509 .5937 .41957 .58409 Mtetra
.52 .571 .846 r
.41957 .58409 .42509 .5937 .43462 .59466 .42911 .58488 Mtetra
.55 .582 .839 r
.42911 .58488 .43462 .59466 .44425 .59415 .43872 .58497 Mtetra
.599 .619 .843 r
.43872 .58497 .44425 .59415 .45397 .59129 .44842 .58367 Mtetra
.676 .689 .854 r
.44842 .58367 .45397 .59129 .46378 .58548 .45821 .57998 Mtetra
.768 .773 .857 r
.45821 .57998 .46378 .58548 .47365 .57637 .46808 .57326 Mtetra
.824 .86 .873 r
.46808 .57326 .47365 .57637 .48354 .56627 .47798 .56501 Mtetra
.843 .931 .887 r
.47798 .56501 .48354 .56627 .49342 .55698 .4879 .55639 Mtetra
.719 .96 .944 r
.4879 .55639 .49342 .55698 .50326 .55236 .49779 .55066 Mtetra
.339 .781 .962 r
.49779 .55066 .50326 .55236 .51311 .55469 .50767 .54983 Mtetra
0 .403 .84 r
.50767 .54983 .51311 .55469 .52302 .56373 .5176 .55468 Mtetra
0 .196 .726 r
.5176 .55468 .52302 .56373 .53305 .57796 .52761 .56445 Mtetra
.29 .367 .77 r
.52761 .56445 .53305 .57796 .54319 .58874 .53772 .57196 Mtetra
.553 .491 .74 r
.53772 .57196 .54319 .58874 .55339 .59066 .54789 .57265 Mtetra
.727 .583 .694 r
.54789 .57265 .55339 .59066 .56348 .57823 .558 .56085 Mtetra
.811 .631 .659 r
.558 .56085 .56348 .57823 .57337 .55232 .56793 .53696 Mtetra
.837 .653 .655 r
.56793 .53696 .57337 .55232 .58312 .52447 .57774 .51061 Mtetra
.827 .659 .674 r
.57774 .51061 .58312 .52447 .59288 .50251 .58754 .48908 Mtetra
.636 .57 .764 r
.58754 .48908 .59288 .50251 .603 .49939 .59766 .48593 Mtetra
0 .097 .644 r
.59766 .48593 .603 .49939 .61366 .51517 .60828 .50122 Mtetra
0 0 .518 r
.60828 .50122 .61366 .51517 .62466 .53693 .6192 .52141 Mtetra
0 .073 .62 r
.6192 .52141 .62466 .53693 .63578 .55683 .63022 .53923 Mtetra
.437 .414 .736 r
.63022 .53923 .63578 .55683 .64661 .56322 .641 .54492 Mtetra
.673 .552 .71 r
.641 .54492 .64661 .56322 .65696 .55515 .65139 .53803 Mtetra
.752 .604 .693 r
.65139 .53803 .65696 .55515 .66695 .5381 .66152 .52421 Mtetra
.796 .65 .7 r
.66152 .52421 .66695 .5381 .67673 .51749 .67152 .50807 Mtetra
.796 .704 .764 r
.67152 .50807 .67673 .51749 .68669 .50209 .68172 .49688 Mtetra
.734 .8 .904 r
.68172 .49688 .68669 .50209 .69696 .49348 .69219 .49145 Mtetra
.31 .757 .961 r
.69219 .49145 .69696 .49348 .70763 .49193 .70295 .49099 Mtetra
.172 0 0 r
.70295 .49099 .70763 .49193 .71862 .49515 .71394 .49349 Mtetra
0 .521 .796 r
.71394 .49349 .71862 .49515 .72975 .49922 .72499 .49564 Mtetra
.339 .708 .984 r
.72499 .49564 .72975 .49922 .74091 .50231 .73602 .49624 Mtetra
.625 .738 .928 r
.73602 .49624 .74091 .50231 .75192 .50203 .74691 .49374 Mtetra
.699 .7 .847 r
.74691 .49374 .75192 .50203 .76277 .49872 .75767 .48878 Mtetra
.718 .672 .804 r
.75767 .48878 .76277 .49872 .77349 .49299 .76835 .48238 Mtetra
.725 .664 .789 r
.76835 .48238 .77349 .49299 .78411 .48573 .779 .47524 Mtetra
.725 .666 .791 r
.779 .47524 .78411 .48573 .79471 .47801 .78968 .46818 Mtetra
.723 .677 .805 r
.78968 .46818 .79471 .47801 .80533 .47044 .80041 .46156 Mtetra
.711 .693 .831 r
.80041 .46156 .80533 .47044 .81606 .46382 .81124 .45591 Mtetra
.695 .711 .861 r
.81124 .45591 .81606 .46382 .82689 .45821 .82219 .45119 Mtetra
.667 .727 .894 r
.82219 .45119 .82689 .45821 .83788 .45386 .83327 .44752 Mtetra
.637 .738 .922 r
.83327 .44752 .83788 .45386 .84899 .45051 .84447 .44466 Mtetra
.608 .745 .942 r
.84447 .44466 .84899 .45051 .86024 .44797 .85577 .44238 Mtetra
.584 .746 .954 r
.85577 .44238 .86024 .44797 .8716 .44605 .86718 .44053 Mtetra
.57 .743 .958 r
.86718 .44053 .8716 .44605 .88306 .44452 .87866 .43892 Mtetra
.562 .737 .958 r
.87866 .43892 .88306 .44452 .89462 .44329 .89023 .43749 Mtetra
.559 .728 .953 r
.89023 .43749 .89462 .44329 .90625 .44226 .90187 .43617 Mtetra
.562 .719 .946 r
.90187 .43617 .90625 .44226 .91796 .44128 .91357 .43489 Mtetra
.719 .764 .888 r
.3005 .61354 .30643 .61871 .3158 .61384 .30988 .60897 Mtetra
.72 .776 .896 r
.30988 .60897 .3158 .61384 .32519 .60899 .31927 .60441 Mtetra
.72 .787 .905 r
.31927 .60441 .32519 .60899 .3346 .60425 .32869 .59989 Mtetra
.718 .796 .913 r
.32869 .59989 .3346 .60425 .34402 .59967 .33813 .59547 Mtetra
.714 .803 .92 r
.33813 .59547 .34402 .59967 .35345 .59533 .34758 .59116 Mtetra
.704 .803 .927 r
.34758 .59116 .35345 .59533 .36289 .59139 .35705 .58709 Mtetra
.689 .797 .932 r
.35705 .58709 .36289 .59139 .37233 .588 .36652 .58339 Mtetra
.665 .78 .934 r
.36652 .58339 .37233 .588 .38176 .5854 .376 .58024 Mtetra
.632 .751 .933 r
.376 .58024 .38176 .5854 .39119 .58381 .38548 .57785 Mtetra
.602 .712 .921 r
.38548 .57785 .39119 .58381 .40063 .58313 .39497 .57619 Mtetra
.572 .667 .903 r
.39497 .57619 .40063 .58313 .41008 .58339 .40448 .57531 Mtetra
.554 .626 .878 r
.40448 .57531 .41008 .58339 .41957 .58409 .41401 .57501 Mtetra
.543 .595 .856 r
.41401 .57501 .41957 .58409 .42911 .58488 .42357 .57513 Mtetra
.548 .582 .841 r
.42357 .57513 .42911 .58488 .43872 .58497 .43319 .57525 Mtetra
.562 .591 .84 r
.43319 .57525 .43872 .58497 .44842 .58367 .44287 .57499 Mtetra
.614 .639 .852 r
.44287 .57499 .44842 .58367 .45821 .57998 .45263 .5732 Mtetra
.692 .719 .87 r
.45263 .5732 .45821 .57998 .46808 .57326 .46247 .56909 Mtetra
.756 .822 .904 r
.46247 .56909 .46808 .57326 .47798 .56501 .47238 .5633 Mtetra
.798 .923 .92 r
.47238 .5633 .47798 .56501 .4879 .55639 .48231 .55627 Mtetra
.734 .974 .926 r
.48231 .55627 .4879 .55639 .49779 .55066 .49225 .54994 Mtetra
.623 .936 .962 r
.49225 .54994 .49779 .55066 .50767 .54983 .5022 .54562 Mtetra
.489 .747 .986 r
.5022 .54562 .50767 .54983 .5176 .55468 .51216 .54503 Mtetra
.401 .51 .854 r
.51216 .54503 .5176 .55468 .52761 .56445 .52216 .54828 Mtetra
.5 .464 .748 r
.52216 .54828 .52761 .56445 .53772 .57196 .53224 .55102 Mtetra
.579 .477 .702 r
.53224 .55102 .53772 .57196 .54789 .57265 .54238 .55035 Mtetra
.675 .531 .681 r
.54238 .55035 .54789 .57265 .558 .56085 .5525 .54175 Mtetra
.76 .595 .673 r
.5525 .54175 .558 .56085 .56793 .53696 .56253 .52491 Mtetra
.833 .677 .688 r
.56253 .52491 .56793 .53696 .57774 .51061 .57247 .5051 Mtetra
.894 .782 .731 r
.57247 .5051 .57774 .51061 .58754 .48908 .58239 .48754 Mtetra
.56 .895 .983 r
.58239 .48754 .58754 .48908 .59766 .48593 .59255 .48438 Mtetra
.733 .206 0 r
.59255 .48438 .59766 .48593 .60828 .50122 .60309 .49565 Mtetra
.631 .144 0 r
.60309 .49565 .60828 .50122 .6192 .52141 .61382 .50924 Mtetra
.09 .263 .747 r
.61382 .50924 .6192 .52141 .63022 .53923 .6246 .51989 Mtetra
.522 .454 .72 r
.6246 .51989 .63022 .53923 .641 .54492 .63524 .52229 Mtetra
.641 .509 .687 r
.63524 .52229 .641 .54492 .65139 .53803 .64567 .5167 Mtetra
.683 .541 .686 r
.64567 .5167 .65139 .53803 .66152 .52421 .65598 .50764 Mtetra
.714 .587 .712 r
.65598 .50764 .66152 .52421 .67152 .50807 .66627 .49805 Mtetra
.704 .66 .804 r
.66627 .49805 .67152 .50807 .68172 .49688 .67674 .49234 Mtetra
.579 .779 .974 r
.67674 .49234 .68172 .49688 .69219 .49145 .68742 .4904 Mtetra
.12 .66 .846 r
.68742 .4904 .69219 .49145 .70295 .49099 .69826 .49053 Mtetra
0 .541 .72 r
.69826 .49053 .70295 .49099 .71394 .49349 .70919 .49138 Mtetra
.308 .754 .962 r
.70919 .49138 .71394 .49349 .72499 .49564 .72013 .49097 Mtetra
.588 .781 .972 r
.72013 .49097 .72499 .49564 .73602 .49624 .73101 .48885 Mtetra
.692 .721 .872 r
.73101 .48885 .73602 .49624 .74691 .49374 .74179 .48436 Mtetra
.716 .683 .817 r
.74179 .48436 .74691 .49374 .75767 .48878 .7525 .47828 Mtetra
.715 .661 .796 r
.7525 .47828 .75767 .48878 .76835 .48238 .7632 .47179 Mtetra
.714 .66 .795 r
.7632 .47179 .76835 .48238 .779 .47524 .77392 .46529 Mtetra
.711 .671 .809 r
.77392 .46529 .779 .47524 .78968 .46818 .7847 .45923 Mtetra
.706 .69 .832 r
.7847 .45923 .78968 .46818 .80041 .46156 .79555 .45374 Mtetra
.694 .714 .864 r
.79555 .45374 .80041 .46156 .81124 .45591 .80649 .44905 Mtetra
.675 .736 .896 r
.80649 .44905 .81124 .45591 .82219 .45119 .81754 .44512 Mtetra
.646 .753 .927 r
.81754 .44512 .82219 .45119 .83327 .44752 .8287 .44197 Mtetra
.617 .762 .949 r
.8287 .44197 .83327 .44752 .84447 .44466 .83996 .43941 Mtetra
.595 .766 .961 r
.83996 .43941 .84447 .44466 .85577 .44238 .85132 .43721 Mtetra
.579 .763 .966 r
.85132 .43721 .85577 .44238 .86718 .44053 .86275 .43529 Mtetra
.573 .758 .966 r
.86275 .43529 .86718 .44053 .87866 .43892 .87425 .43348 Mtetra
.571 .75 .962 r
.87425 .43348 .87866 .43892 .89023 .43749 .88582 .43176 Mtetra
.573 .74 .955 r
.88582 .43176 .89023 .43749 .90187 .43617 .89745 .4301 Mtetra
.577 .729 .946 r
.89745 .4301 .90187 .43617 .91357 .43489 .90915 .42846 Mtetra
.709 .762 .894 r
.29453 .60833 .3005 .61354 .30988 .60897 .30391 .60408 Mtetra
.71 .775 .903 r
.30391 .60408 .30988 .60897 .31927 .60441 .31331 .59983 Mtetra
.71 .787 .912 r
.31331 .59983 .31927 .60441 .32869 .59989 .32273 .59561 Mtetra
.708 .799 .921 r
.32273 .59561 .32869 .59989 .33813 .59547 .33218 .59143 Mtetra
.706 .809 .929 r
.33218 .59143 .33813 .59547 .34758 .59116 .34165 .58729 Mtetra
.7 .817 .937 r
.34165 .58729 .34758 .59116 .35705 .58709 .35114 .5833 Mtetra
.69 .819 .944 r
.35114 .5833 .35705 .58709 .36652 .58339 .36064 .57951 Mtetra
.674 .814 .95 r
.36064 .57951 .36652 .58339 .376 .58024 .37016 .57607 Mtetra
.652 .797 .952 r
.37016 .57607 .376 .58024 .38548 .57785 .37969 .57311 Mtetra
.634 .77 .945 r
.37969 .57311 .38548 .57785 .39497 .57619 .38923 .5706 Mtetra
.617 .732 .929 r
.38923 .5706 .39497 .57619 .40448 .57531 .3988 .56856 Mtetra
.601 .686 .902 r
.3988 .56856 .40448 .57531 .41401 .57501 .40838 .56699 Mtetra
.586 .643 .874 r
.40838 .56699 .41401 .57501 .42357 .57513 .41799 .56591 Mtetra
.571 .606 .85 r
.41799 .56591 .42357 .57513 .43319 .57525 .42764 .56534 Mtetra
.555 .584 .838 r
.42764 .56534 .43319 .57525 .44287 .57499 .43731 .56525 Mtetra
.572 .596 .839 r
.43731 .56525 .44287 .57499 .45263 .5732 .44705 .56468 Mtetra
.608 .642 .859 r
.44705 .56468 .45263 .5732 .46247 .56909 .45687 .56302 Mtetra
.652 .731 .908 r
.45687 .56302 .46247 .56909 .47238 .5633 .46674 .56013 Mtetra
.701 .859 .957 r
.46674 .56013 .47238 .5633 .48231 .55627 .47668 .55579 Mtetra
.725 .964 .94 r
.47668 .55579 .48231 .55627 .49225 .54994 .48666 .54983 Mtetra
.781 .978 .91 r
.48666 .54983 .49225 .54994 .5022 .54562 .49667 .5425 Mtetra
.782 .871 .914 r
.49667 .5425 .5022 .54562 .51216 .54503 .50669 .53595 Mtetra
.692 .666 .819 r
.50669 .53595 .51216 .54503 .52216 .54828 .51672 .5312 Mtetra
.626 .531 .726 r
.51672 .5312 .52216 .54828 .53224 .55102 .52678 .52795 Mtetra
.597 .478 .687 r
.52678 .52795 .53224 .55102 .54238 .55035 .53687 .52581 Mtetra
.603 .475 .679 r
.53687 .52581 .54238 .55035 .5525 .54175 .54701 .52309 Mtetra
.637 .526 .712 r
.54701 .52309 .5525 .54175 .56253 .52491 .55717 .51883 Mtetra
.777 .769 .846 r
.55717 .51883 .56253 .52491 .57247 .5051 .56732 .51136 Mtetra
0 0 0 r
.56732 .51136 .57247 .5051 .58239 .48754 .57745 .50212 Mtetra
.428 .083 .277 r
.57745 .50212 .58239 .48754 .59255 .48438 .5877 .49895 Mtetra
.567 .214 .33 r
.5877 .49895 .59255 .48438 .60309 .49565 .59813 .50188 Mtetra
.475 .013 .075 r
.59813 .50188 .60309 .49565 .61382 .50924 .60858 .50304 Mtetra
.61 .721 .924 r
.60858 .50304 .61382 .50924 .6246 .51989 .61901 .50099 Mtetra
.626 .52 .714 r
.61901 .50099 .6246 .51989 .63524 .52229 .62944 .4974 Mtetra
.619 .486 .677 r
.62944 .4974 .63524 .52229 .64567 .5167 .63988 .49321 Mtetra
.608 .485 .686 r
.63988 .49321 .64567 .5167 .65598 .50764 .6504 .49014 Mtetra
.595 .512 .731 r
.6504 .49014 .65598 .50764 .66627 .49805 .66102 .4886 Mtetra
.536 .593 .859 r
.66102 .4886 .66627 .49805 .67674 .49234 .67178 .48889 Mtetra
.273 .676 .97 r
.67178 .48889 .67674 .49234 .68742 .4904 .68264 .48999 Mtetra
.089 .646 .787 r
.68264 .48999 .68742 .4904 .69826 .49053 .69349 .48969 Mtetra
.338 .809 .913 r
.69349 .48969 .69826 .49053 .70919 .49138 .70432 .48776 Mtetra
.637 .846 .98 r
.70432 .48776 .70919 .49138 .72013 .49097 .71511 .48435 Mtetra
.701 .749 .889 r
.71511 .48435 .72013 .49097 .73101 .48885 .72587 .47968 Mtetra
.712 .686 .823 r
.72587 .47968 .73101 .48885 .74179 .48436 .73659 .47387 Mtetra
.711 .66 .798 r
.73659 .47387 .74179 .48436 .7525 .47828 .7473 .46757 Mtetra
.7 .652 .798 r
.7473 .46757 .7525 .47828 .7632 .47179 .75807 .46175 Mtetra
.695 .662 .814 r
.75807 .46175 .7632 .47179 .77392 .46529 .7689 .45644 Mtetra
.691 .686 .841 r
.7689 .45644 .77392 .46529 .7847 .45923 .7798 .45163 Mtetra
.685 .717 .874 r
.7798 .45163 .7847 .45923 .79555 .45374 .79077 .4473 Mtetra
.673 .75 .909 r
.79077 .4473 .79555 .45374 .80649 .44905 .80182 .44346 Mtetra
.653 .775 .938 r
.80182 .44346 .80649 .44905 .81754 .44512 .81295 .44008 Mtetra
.625 .787 .96 r
.81295 .44008 .81754 .44512 .8287 .44197 .82418 .43719 Mtetra
.603 .79 .971 r
.82418 .43719 .8287 .44197 .83996 .43941 .83548 .43466 Mtetra
.589 .787 .974 r
.83548 .43466 .83996 .43941 .85132 .43721 .84686 .43236 Mtetra
.583 .78 .973 r
.84686 .43236 .85132 .43721 .86275 .43529 .85831 .4302 Mtetra
.584 .772 .969 r
.85831 .4302 .86275 .43529 .87425 .43348 .86981 .42809 Mtetra
.586 .761 .962 r
.86981 .42809 .87425 .43348 .88582 .43176 .88138 .42603 Mtetra
.589 .749 .953 r
.88138 .42603 .88582 .43176 .89745 .4301 .89301 .424 Mtetra
.593 .737 .944 r
.89301 .424 .89745 .4301 .90915 .42846 .90469 .42197 Mtetra
.699 .76 .9 r
.28853 .60308 .29453 .60833 .30391 .60408 .2979 .59911 Mtetra
.699 .771 .907 r
.2979 .59911 .30391 .60408 .31331 .59983 .30731 .59514 Mtetra
.699 .782 .916 r
.30731 .59514 .31331 .59983 .32273 .59561 .31674 .59119 Mtetra
.698 .793 .924 r
.31674 .59119 .32273 .59561 .33218 .59143 .32619 .58726 Mtetra
.696 .804 .932 r
.32619 .58726 .33218 .59143 .34165 .58729 .33568 .58336 Mtetra
.691 .814 .941 r
.33568 .58336 .34165 .58729 .35114 .5833 .34518 .57956 Mtetra
.683 .822 .949 r
.34518 .57956 .35114 .5833 .36064 .57951 .35471 .57589 Mtetra
.672 .825 .957 r
.35471 .57589 .36064 .57951 .37016 .57607 .36425 .57243 Mtetra
.658 .822 .963 r
.36425 .57243 .37016 .57607 .37969 .57311 .37381 .56923 Mtetra
.65 .811 .961 r
.37381 .56923 .37969 .57311 .38923 .5706 .3834 .56622 Mtetra
.647 .79 .95 r
.3834 .56622 .38923 .5706 .3988 .56856 .39302 .56333 Mtetra
.642 .756 .931 r
.39302 .56333 .3988 .56856 .40838 .56699 .40266 .56066 Mtetra
.635 .714 .905 r
.40266 .56066 .40838 .56699 .41799 .56591 .41234 .55824 Mtetra
.613 .666 .877 r
.41234 .55824 .41799 .56591 .42764 .56534 .42203 .55641 Mtetra
.585 .621 .855 r
.42203 .55641 .42764 .56534 .43731 .56525 .43174 .5554 Mtetra
.571 .595 .838 r
.43174 .5554 .43731 .56525 .44705 .56468 .44149 .55485 Mtetra
.562 .591 .84 r
.44149 .55485 .44705 .56468 .45687 .56302 .45128 .55452 Mtetra
.559 .622 .871 r
.45128 .55452 .45687 .56302 .46674 .56013 .46112 .55409 Mtetra
.565 .703 .934 r
.46112 .55409 .46674 .56013 .47668 .55579 .47103 .55302 Mtetra
.678 .875 .972 r
.47103 .55302 .47668 .55579 .48666 .54983 .48102 .54898 Mtetra
.821 .954 .903 r
.48102 .54898 .48666 .54983 .49667 .5425 .49108 .54091 Mtetra
.877 .912 .849 r
.49108 .54091 .49667 .5425 .50669 .53595 .50117 .53035 Mtetra
.844 .782 .792 r
.50117 .53035 .50669 .53595 .51672 .5312 .51125 .51869 Mtetra
.739 .633 .742 r
.51125 .51869 .51672 .5312 .52678 .52795 .52132 .50945 Mtetra
.641 .53 .712 r
.52132 .50945 .52678 .52795 .53687 .52581 .5314 .50489 Mtetra
.513 .435 .705 r
.5314 .50489 .53687 .52581 .54701 .52309 .54154 .50778 Mtetra
.247 .316 .737 r
.54154 .50778 .54701 .52309 .55717 .51883 .55181 .51721 Mtetra
.567 0 0 r
.55181 .51721 .55717 .51883 .56732 .51136 .56217 .52437 Mtetra
.537 .17 .292 r
.56217 .52437 .56732 .51136 .57745 .50212 .57255 .52598 Mtetra
.481 .182 .381 r
.57255 .52598 .57745 .50212 .5877 .49895 .58292 .52282 Mtetra
.396 .109 .354 r
.58292 .52282 .5877 .49895 .59813 .50188 .59323 .51487 Mtetra
0 0 .04 r
.59323 .51487 .59813 .50188 .60858 .50304 .60341 .50133 Mtetra
.934 .891 .764 r
.60341 .50133 .60858 .50304 .61901 .50099 .61351 .48547 Mtetra
.718 .597 .72 r
.61351 .48547 .61901 .50099 .62944 .4974 .62376 .47616 Mtetra
.594 .486 .701 r
.62376 .47616 .62944 .4974 .63988 .49321 .63426 .47435 Mtetra
.507 .448 .725 r
.63426 .47435 .63988 .49321 .6504 .49014 .64499 .47727 Mtetra
.377 .436 .795 r
.64499 .47727 .6504 .49014 .66102 .4886 .65589 .48268 Mtetra
.161 .496 .907 r
.65589 .48268 .66102 .4886 .67178 .48889 .66684 .487 Mtetra
.017 .562 .836 r
.66684 .487 .67178 .48889 .68264 .48999 .67777 .48881 Mtetra
.413 .843 .949 r
.67777 .48881 .68264 .48999 .69349 .48969 .68856 .48653 Mtetra
.722 .889 .956 r
.68856 .48653 .69349 .48969 .70432 .48776 .69925 .48121 Mtetra
.737 .763 .873 r
.69925 .48121 .70432 .48776 .71511 .48435 .70993 .47524 Mtetra
.718 .69 .822 r
.70993 .47524 .71511 .48435 .72587 .47968 .72063 .46915 Mtetra
.703 .656 .801 r
.72063 .46915 .72587 .47968 .73659 .47387 .73136 .46328 Mtetra
.693 .651 .804 r
.73136 .46328 .73659 .47387 .7473 .46757 .74215 .45787 Mtetra
.68 .663 .826 r
.74215 .45787 .7473 .46757 .75807 .46175 .75302 .45329 Mtetra
.671 .688 .858 r
.75302 .45329 .75807 .46175 .7689 .45644 .76398 .44932 Mtetra
.667 .726 .893 r
.76398 .44932 .7689 .45644 .7798 .45163 .77499 .44561 Mtetra
.659 .761 .925 r
.77499 .44561 .7798 .45163 .79077 .4473 .78607 .44211 Mtetra
.649 .79 .95 r
.78607 .44211 .79077 .4473 .80182 .44346 .79719 .43874 Mtetra
.634 .806 .965 r
.79719 .43874 .80182 .44346 .81295 .44008 .80838 .43557 Mtetra
.616 .808 .974 r
.80838 .43557 .81295 .44008 .82418 .43719 .81964 .43267 Mtetra
.604 .804 .977 r
.81964 .43267 .82418 .43719 .83548 .43466 .83097 .42998 Mtetra
.599 .796 .975 r
.83097 .42998 .83548 .43466 .84686 .43236 .84236 .42743 Mtetra
.597 .785 .97 r
.84236 .42743 .84686 .43236 .85831 .4302 .85382 .42498 Mtetra
.6 .775 .964 r
.85382 .42498 .85831 .4302 .86981 .42809 .86533 .42256 Mtetra
.602 .764 .956 r
.86533 .42256 .86981 .42809 .88138 .42603 .8769 .42017 Mtetra
.605 .752 .948 r
.8769 .42017 .88138 .42603 .89301 .424 .88852 .41781 Mtetra
.607 .741 .94 r
.88852 .41781 .89301 .424 .90469 .42197 .90021 .41544 Mtetra
.691 .759 .904 r
.28248 .59781 .28853 .60308 .2979 .59911 .29186 .59403 Mtetra
.691 .767 .91 r
.29186 .59403 .2979 .59911 .30731 .59514 .30128 .59026 Mtetra
.69 .775 .916 r
.30128 .59026 .30731 .59514 .31674 .59119 .31072 .5865 Mtetra
.689 .783 .923 r
.31072 .5865 .31674 .59119 .32619 .58726 .32018 .58279 Mtetra
.686 .791 .93 r
.32018 .58279 .32619 .58726 .33568 .58336 .32967 .57913 Mtetra
.68 .801 .939 r
.32967 .57913 .33568 .58336 .34518 .57956 .33919 .57557 Mtetra
.671 .81 .949 r
.33919 .57557 .34518 .57956 .35471 .57589 .34873 .57217 Mtetra
.661 .82 .96 r
.34873 .57217 .35471 .57589 .36425 .57243 .35829 .56892 Mtetra
.646 .827 .97 r
.35829 .56892 .36425 .57243 .37381 .56923 .36787 .56587 Mtetra
.642 .833 .974 r
.36787 .56587 .37381 .56923 .3834 .56622 .37749 .56283 Mtetra
.649 .834 .972 r
.37749 .56283 .3834 .56622 .39302 .56333 .38714 .55966 Mtetra
.662 .826 .962 r
.38714 .55966 .39302 .56333 .40266 .56066 .39684 .55632 Mtetra
.679 .802 .941 r
.39684 .55632 .40266 .56066 .41234 .55824 .40657 .55271 Mtetra
.673 .756 .913 r
.40657 .55271 .41234 .55824 .42203 .55641 .41634 .54927 Mtetra
.654 .698 .878 r
.41634 .54927 .42203 .55641 .43174 .5554 .42612 .5463 Mtetra
.619 .634 .844 r
.42612 .5463 .43174 .5554 .44149 .55485 .43591 .54428 Mtetra
.576 .584 .824 r
.43591 .54428 .44149 .55485 .45128 .55452 .44571 .5436 Mtetra
.521 .549 .825 r
.44571 .5436 .45128 .55452 .46112 .55409 .45553 .54451 Mtetra
.446 .54 .859 r
.45553 .54451 .46112 .55409 .47103 .55302 .46539 .54671 Mtetra
.538 .685 .934 r
.46539 .54671 .47103 .55302 .48102 .54898 .47535 .54616 Mtetra
.746 .883 .942 r
.47535 .54616 .48102 .54898 .49108 .54091 .48543 .54061 Mtetra
.887 .952 .843 r
.48543 .54061 .49108 .54091 .50117 .53035 .49557 .52957 Mtetra
.934 .897 .767 r
.49557 .52957 .50117 .53035 .51125 .51869 .50573 .5139 Mtetra
.878 .801 .771 r
.50573 .5139 .51125 .51869 .52132 .50945 .51585 .49974 Mtetra
.75 .678 .781 r
.51585 .49974 .52132 .50945 .5314 .50489 .52594 .49157 Mtetra
.334 .399 .781 r
.52594 .49157 .5314 .50489 .54154 .50778 .53608 .49782 Mtetra
.69 .294 0 r
.53608 .49782 .54154 .50778 .55181 .51721 .54642 .51854 Mtetra
.858 .439 .228 r
.54642 .51854 .55181 .51721 .56217 .52437 .55694 .53931 Mtetra
.7 .349 .379 r
.55694 .53931 .56217 .52437 .57255 .52598 .56754 .55232 Mtetra
.487 .193 .393 r
.56754 .55232 .57255 .52598 .58292 .52282 .57804 .54917 Mtetra
.165 0 .285 r
.57804 .54917 .58292 .52282 .59323 .51487 .58827 .52981 Mtetra
0 0 0 r
.58827 .52981 .59323 .51487 .60341 .50133 .59826 .50258 Mtetra
.986 .873 .634 r
.59826 .50258 .60341 .50133 .61351 .48547 .60814 .47534 Mtetra
.804 .695 .744 r
.60814 .47534 .61351 .48547 .62376 .47616 .61832 .46258 Mtetra
.51 .504 .785 r
.61832 .46258 .62376 .47616 .63426 .47435 .62893 .46436 Mtetra
.144 .35 .809 r
.62893 .46436 .63426 .47435 .64499 .47727 .63983 .47221 Mtetra
0 .104 .599 r
.63983 .47221 .64499 .47727 .65589 .48268 .65091 .48164 Mtetra
.389 0 0 r
.65091 .48164 .65589 .48268 .66684 .487 .66191 .48641 Mtetra
.172 .705 .838 r
.66191 .48641 .66684 .487 .67777 .48881 .67276 .48562 Mtetra
.745 .892 .945 r
.67276 .48562 .67777 .48881 .68856 .48653 .68342 .47974 Mtetra
.793 .77 .832 r
.68342 .47974 .68856 .48653 .69925 .48121 .69397 .47104 Mtetra
.734 .676 .794 r
.69397 .47104 .69925 .48121 .70993 .47524 .70459 .46365 Mtetra
.693 .635 .786 r
.70459 .46365 .70993 .47524 .72063 .46915 .71532 .45787 Mtetra
.668 .628 .8 r
.71532 .45787 .72063 .46915 .73136 .46328 .72616 .45345 Mtetra
.651 .648 .833 r
.72616 .45345 .73136 .46328 .74215 .45787 .73709 .45001 Mtetra
.642 .693 .882 r
.73709 .45001 .74215 .45787 .75302 .45329 .74811 .44704 Mtetra
.632 .742 .927 r
.74811 .44704 .75302 .45329 .76398 .44932 .75918 .44425 Mtetra
.634 .789 .957 r
.75918 .44425 .76398 .44932 .77499 .44561 .77028 .44119 Mtetra
.633 .818 .971 r
.77028 .44119 .77499 .44561 .78607 .44211 .78141 .43794 Mtetra
.635 .83 .976 r
.78141 .43794 .78607 .44211 .79719 .43874 .79258 .43456 Mtetra
.633 .83 .976 r
.79258 .43456 .79719 .43874 .80838 .43557 .80379 .43119 Mtetra
.625 .82 .975 r
.80379 .43119 .80838 .43557 .81964 .43267 .81506 .42802 Mtetra
.621 .807 .971 r
.81506 .42802 .81964 .43267 .83097 .42998 .8264 .42502 Mtetra
.617 .793 .966 r
.8264 .42502 .83097 .42998 .84236 .42743 .8378 .42217 Mtetra
.615 .78 .96 r
.8378 .42217 .84236 .42743 .85382 .42498 .84927 .41943 Mtetra
.616 .769 .954 r
.84927 .41943 .85382 .42498 .86533 .42256 .86079 .41674 Mtetra
.616 .76 .948 r
.86079 .41674 .86533 .42256 .8769 .42017 .87236 .4141 Mtetra
.617 .751 .942 r
.87236 .4141 .8769 .42017 .88852 .41781 .884 .41148 Mtetra
.618 .743 .936 r
.884 .41148 .88852 .41781 .90021 .41544 .89569 .40886 Mtetra
.686 .758 .906 r
.27639 .59249 .28248 .59781 .29186 .59403 .28579 .58884 Mtetra
.686 .763 .91 r
.28579 .58884 .29186 .59403 .30128 .59026 .29522 .58518 Mtetra
.686 .768 .914 r
.29522 .58518 .30128 .59026 .31072 .5865 .30467 .58153 Mtetra
.684 .772 .918 r
.30467 .58153 .31072 .5865 .32018 .58279 .31415 .57792 Mtetra
.681 .776 .923 r
.31415 .57792 .32018 .58279 .32967 .57913 .32366 .57438 Mtetra
.675 .78 .929 r
.32366 .57438 .32967 .57913 .33919 .57557 .33319 .57096 Mtetra
.665 .785 .938 r
.33319 .57096 .33919 .57557 .34873 .57217 .34274 .56775 Mtetra
.653 .79 .948 r
.34274 .56775 .34873 .57217 .35829 .56892 .35231 .56474 Mtetra
.636 .797 .96 r
.35231 .56474 .35829 .56892 .36787 .56587 .3619 .56201 Mtetra
.629 .81 .969 r
.3619 .56201 .36787 .56587 .37749 .56283 .37153 .55932 Mtetra
.628 .825 .976 r
.37153 .55932 .37749 .56283 .38714 .55966 .38119 .55652 Mtetra
.646 .846 .977 r
.38119 .55652 .38714 .55966 .39684 .55632 .39091 .55329 Mtetra
.683 .859 .966 r
.39091 .55329 .39684 .55632 .40657 .55271 .40069 .54934 Mtetra
.711 .85 .948 r
.40069 .54934 .40657 .55271 .41634 .54927 .41052 .54484 Mtetra
.729 .81 .915 r
.41052 .54484 .41634 .54927 .42612 .5463 .42039 .53987 Mtetra
.698 .735 .879 r
.42039 .53987 .42612 .5463 .43591 .54428 .43026 .53556 Mtetra
.644 .655 .846 r
.43026 .53556 .43591 .54428 .44571 .5436 .44013 .53274 Mtetra
.552 .567 .824 r
.44013 .53274 .44571 .5436 .45553 .54451 .44997 .53276 Mtetra
.427 .483 .815 r
.44997 .53276 .45553 .54451 .46539 .54671 .4598 .53607 Mtetra
.44 .513 .838 r
.4598 .53607 .46539 .54671 .47535 .54616 .46971 .53874 Mtetra
.548 .653 .904 r
.46971 .53874 .47535 .54616 .48543 .54061 .47974 .53825 Mtetra
.79 .905 .921 r
.47974 .53825 .48543 .54061 .49557 .52957 .48989 .53136 Mtetra
.917 .975 .771 r
.48989 .53136 .49557 .52957 .50573 .5139 .5001 .51743 Mtetra
.908 .979 .706 r
.5001 .51743 .50573 .5139 .51585 .49974 .5103 .50196 Mtetra
.869 .995 .776 r
.5103 .50196 .51585 .49974 .52594 .49157 .52045 .4898 Mtetra
.227 0 0 r
.52045 .4898 .52594 .49157 .53608 .49782 .53061 .49316 Mtetra
.856 .407 .017 r
.53061 .49316 .53608 .49782 .54642 .51854 .54093 .51346 Mtetra
.875 .44 .051 r
.54093 .51346 .54642 .51854 .55694 .53931 .55146 .53655 Mtetra
.827 .35 .005 r
.55146 .53655 .55694 .53931 .56754 .55232 .56212 .55349 Mtetra
.262 .767 .744 r
.56212 .55349 .56754 .55232 .57804 .54917 .57266 .55032 Mtetra
.978 .896 .67 r
.57266 .55032 .57804 .54917 .58827 .52981 .5829 .52699 Mtetra
.96 .806 .647 r
.5829 .52699 .58827 .52981 .59826 .50258 .59292 .4974 Mtetra
.935 .78 .664 r
.59292 .4974 .59826 .50258 .60814 .47534 .60287 .47052 Mtetra
.836 .825 .838 r
.60287 .47052 .60814 .47534 .61832 .46258 .61317 .46065 Mtetra
.412 0 0 r
.61317 .46065 .61832 .46258 .62893 .46436 .62394 .46641 Mtetra
.7 .192 .024 r
.62394 .46641 .62893 .46436 .63983 .47221 .63492 .47556 Mtetra
.663 .165 .053 r
.63492 .47556 .63983 .47221 .65091 .48164 .64597 .4832 Mtetra
.222 0 0 r
.64597 .4832 .65091 .48164 .66191 .48641 .65684 .48372 Mtetra
.744 .912 .95 r
.65684 .48372 .66191 .48641 .67276 .48562 .66751 .47774 Mtetra
.788 .741 .809 r
.66751 .47774 .67276 .48562 .68342 .47974 .67804 .46854 Mtetra
.762 .67 .762 r
.67804 .46854 .68342 .47974 .69397 .47104 .68855 .45866 Mtetra
.701 .627 .771 r
.68855 .45866 .69397 .47104 .70459 .46365 .69923 .45212 Mtetra
.649 .615 .802 r
.69923 .45212 .70459 .46365 .71532 .45787 .71009 .44847 Mtetra
.614 .64 .853 r
.71009 .44847 .71532 .45787 .72616 .45345 .72109 .44635 Mtetra
.58 .69 .917 r
.72109 .44635 .72616 .45345 .73709 .45001 .73219 .44492 Mtetra
.576 .766 .968 r
.73219 .44492 .73709 .45001 .74811 .44704 .7433 .44301 Mtetra
.583 .816 .988 r
.7433 .44301 .74811 .44704 .75918 .44425 .75444 .44052 Mtetra
.617 .843 .986 r
.75444 .44052 .75918 .44425 .77028 .44119 .76557 .4373 Mtetra
.644 .847 .978 r
.76557 .4373 .77028 .44119 .78141 .43794 .7767 .43363 Mtetra
.655 .833 .969 r
.7767 .43363 .78141 .43794 .79258 .43456 .78788 .42985 Mtetra
.657 .818 .961 r
.78788 .42985 .79258 .43456 .80379 .43119 .7991 .42611 Mtetra
.648 .8 .956 r
.7991 .42611 .80379 .43119 .81506 .42802 .81038 .42264 Mtetra
.64 .785 .951 r
.81038 .42264 .81506 .42802 .8264 .42502 .82174 .4194 Mtetra
.632 .774 .948 r
.82174 .4194 .8264 .42502 .8378 .42217 .83316 .41636 Mtetra
.627 .765 .945 r
.83316 .41636 .8378 .42217 .84927 .41943 .84464 .41345 Mtetra
.625 .758 .942 r
.84464 .41345 .84927 .41943 .86079 .41674 .85618 .41061 Mtetra
.624 .753 .939 r
.85618 .41061 .86079 .41674 .87236 .4141 .86778 .40781 Mtetra
.624 .748 .936 r
.86778 .40781 .87236 .4141 .884 .41148 .87943 .40503 Mtetra
.625 .743 .932 r
.87943 .40503 .884 .41148 .89569 .40886 .89113 .40224 Mtetra
.683 .757 .908 r
.27027 .58715 .27639 .59249 .28579 .58884 .27968 .58356 Mtetra
.684 .761 .909 r
.27968 .58356 .28579 .58884 .29522 .58518 .28912 .57992 Mtetra
.684 .762 .911 r
.28912 .57992 .29522 .58518 .30467 .58153 .2986 .57627 Mtetra
.683 .763 .912 r
.2986 .57627 .30467 .58153 .31415 .57792 .3081 .57265 Mtetra
.682 .763 .913 r
.3081 .57265 .31415 .57792 .32366 .57438 .31763 .56905 Mtetra
.676 .76 .914 r
.31763 .56905 .32366 .57438 .33319 .57096 .32718 .56559 Mtetra
.666 .757 .918 r
.32718 .56559 .33319 .57096 .34274 .56775 .33676 .56236 Mtetra
.652 .754 .924 r
.33676 .56236 .34274 .56775 .35231 .56474 .34634 .55947 Mtetra
.629 .752 .936 r
.34634 .55947 .35231 .56474 .3619 .56201 .35594 .55705 Mtetra
.609 .76 .951 r
.35594 .55705 .3619 .56201 .37153 .55932 .36556 .55494 Mtetra
.585 .777 .971 r
.36556 .55494 .37153 .55932 .38119 .55652 .37521 .55307 Mtetra
.588 .819 .987 r
.37521 .55307 .38119 .55652 .39091 .55329 .38491 .55081 Mtetra
.62 .87 .989 r
.38491 .55081 .39091 .55329 .40069 .54934 .39469 .54767 Mtetra
.683 .916 .973 r
.39469 .54767 .40069 .54934 .41052 .54484 .40456 .54318 Mtetra
.769 .924 .938 r
.40456 .54318 .41052 .54484 .42039 .53987 .4145 .53692 Mtetra
.788 .873 .91 r
.4145 .53692 .42039 .53987 .43026 .53556 .42448 .53016 Mtetra
.76 .782 .871 r
.42448 .53016 .43026 .53556 .44013 .53274 .43447 .5238 Mtetra
.656 .656 .838 r
.43447 .5238 .44013 .53274 .44997 .53276 .4444 .52049 Mtetra
.514 .523 .803 r
.4444 .52049 .44997 .53276 .4598 .53607 .45426 .52174 Mtetra
.424 .441 .773 r
.45426 .52174 .4598 .53607 .46971 .53874 .46414 .52599 Mtetra
.327 .408 .792 r
.46414 .52599 .46971 .53874 .47974 .53825 .47407 .53178 Mtetra
.407 .622 .94 r
.47407 .53178 .47974 .53825 .48989 .53136 .48414 .53321 Mtetra
.515 .91 .791 r
.48414 .53321 .48989 .53136 .5001 .51743 .49435 .52746 Mtetra
0 0 0 r
.49435 .52746 .5001 .51743 .5103 .50196 .50461 .51553 Mtetra
.50461 .51553 .5103 .50196 .52045 .4898 .51488 .50019 Mtetra
.188 0 .06 r
.51488 .50019 .52045 .4898 .53061 .49316 .5251 .49374 Mtetra
.564 0 0 r
.5251 .49374 .53061 .49316 .54093 .51346 .53538 .4992 Mtetra
.148 .27 .734 r
.53538 .4992 .54093 .51346 .55146 .53655 .54578 .50969 Mtetra
.394 .328 .665 r
.54578 .50969 .55146 .53655 .56212 .55349 .55631 .51976 Mtetra
.594 .443 .646 r
.55631 .51976 .56212 .55349 .57266 .55032 .56679 .51655 Mtetra
.694 .511 .635 r
.56679 .51655 .57266 .55032 .5829 .52699 .5771 .5 Mtetra
.722 .545 .65 r
.5771 .5 .5829 .52699 .59292 .4974 .58736 .48299 Mtetra
.756 .628 .718 r
.58736 .48299 .59292 .4974 .60287 .47052 .59768 .47099 Mtetra
.052 0 0 r
.59768 .47099 .60287 .47052 .61317 .46065 .60829 .47096 Mtetra
.671 .277 .291 r
.60829 .47096 .61317 .46065 .62394 .46641 .61922 .47993 Mtetra
.606 .236 .315 r
.61922 .47993 .62394 .46641 .63492 .47556 .63016 .48549 Mtetra
.445 .038 .173 r
.63016 .48549 .63492 .47556 .64597 .4832 .64097 .48481 Mtetra
.65 .963 .792 r
.64097 .48481 .64597 .4832 .65684 .48372 .65157 .47686 Mtetra
.844 .775 .785 r
.65157 .47686 .65684 .48372 .66751 .47774 .662 .46445 Mtetra
.754 .641 .735 r
.662 .46445 .66751 .47774 .67804 .46854 .67247 .45358 Mtetra
.703 .598 .737 r
.67247 .45358 .67804 .46854 .68855 .45866 .68309 .44574 Mtetra
.634 .586 .784 r
.68309 .44574 .68855 .45866 .69923 .45212 .69395 .44255 Mtetra
.544 .602 .862 r
.69395 .44255 .69923 .45212 .71009 .44847 .70504 .44248 Mtetra
.465 .676 .956 r
.70504 .44248 .71009 .44847 .72109 .44635 .71621 .44283 Mtetra
.386 .745 .992 r
.71621 .44283 .72109 .44635 .73219 .44492 .72742 .44268 Mtetra
.456 .835 .988 r
.72742 .44268 .73219 .44492 .7433 .44301 .73858 .44072 Mtetra
.57 .886 .99 r
.73858 .44072 .7433 .44301 .75444 .44052 .74969 .43736 Mtetra
.658 .883 .981 r
.74969 .43736 .75444 .44052 .76557 .4373 .76079 .4331 Mtetra
.694 .85 .958 r
.76079 .4331 .76557 .4373 .7767 .43363 .77189 .42842 Mtetra
.689 .808 .939 r
.77189 .42842 .7767 .43363 .78788 .42985 .78305 .424 Mtetra
.678 .781 .928 r
.78305 .424 .78788 .42985 .7991 .42611 .79428 .41988 Mtetra
.659 .761 .925 r
.79428 .41988 .7991 .42611 .81038 .42264 .80558 .41625 Mtetra
.646 .751 .926 r
.80558 .41625 .81038 .42264 .82174 .4194 .81697 .41297 Mtetra
.636 .746 .928 r
.81697 .41297 .82174 .4194 .83316 .41636 .82842 .40993 Mtetra
.63 .745 .93 r
.82842 .40993 .83316 .41636 .84464 .41345 .83994 .40704 Mtetra
.628 .745 .932 r
.83994 .40704 .84464 .41345 .85618 .41061 .85151 .40417 Mtetra
.627 .745 .932 r
.85151 .40417 .85618 .41061 .86778 .40781 .86314 .40133 Mtetra
.627 .744 .931 r
.86314 .40133 .86778 .40781 .87943 .40503 .87482 .39847 Mtetra
.628 .742 .93 r
.87482 .39847 .87943 .40503 .89113 .40224 .88655 .39556 Mtetra
.679 .757 .91 r
.2641 .58177 .27027 .58715 .27968 .58356 .27353 .57825 Mtetra
.682 .761 .911 r
.27353 .57825 .27968 .58356 .28912 .57992 .28299 .57466 Mtetra
.684 .763 .912 r
.28299 .57466 .28912 .57992 .2986 .57627 .29248 .57101 Mtetra
.685 .764 .912 r
.29248 .57101 .2986 .57627 .3081 .57265 .30201 .56732 Mtetra
.687 .763 .91 r
.30201 .56732 .3081 .57265 .31763 .56905 .31157 .56356 Mtetra
.683 .758 .908 r
.31157 .56356 .31763 .56905 .32718 .56559 .32116 .55989 Mtetra
.677 .749 .906 r
.32116 .55989 .32718 .56559 .33676 .56236 .33077 .55637 Mtetra
.661 .736 .905 r
.33077 .55637 .33676 .56236 .34634 .55947 .34038 .55324 Mtetra
.637 .721 .909 r
.34038 .55324 .34634 .55947 .35594 .55705 .35 .55071 Mtetra
.609 .709 .915 r
.35 .55071 .35594 .55705 .36556 .55494 .35963 .5488 Mtetra
.569 .703 .932 r
.35963 .5488 .36556 .55494 .37521 .55307 .36926 .54763 Mtetra
.555 .725 .953 r
.36926 .54763 .37521 .55307 .38491 .55081 .37894 .54653 Mtetra
.555 .774 .98 r
.37894 .54653 .38491 .55081 .39469 .54767 .38868 .54502 Mtetra
.613 .862 .99 r
.38868 .54502 .39469 .54767 .40456 .54318 .39852 .542 Mtetra
.717 .939 .958 r
.39852 .542 .40456 .54318 .4145 .53692 .40848 .53663 Mtetra
.787 .969 .917 r
.40848 .53663 .4145 .53692 .42448 .53016 .41852 .52934 Mtetra
.843 .946 .887 r
.41852 .52934 .42448 .53016 .43447 .5238 .42862 .52049 Mtetra
.802 .861 .893 r
.42862 .52049 .43447 .5238 .4444 .52049 .43868 .5131 Mtetra
.679 .705 .867 r
.43868 .5131 .4444 .52049 .45426 .52174 .44868 .50921 Mtetra
.505 .515 .801 r
.44868 .50921 .45426 .52174 .46414 .52599 .45859 .51073 Mtetra
.309 .358 .75 r
.45859 .51073 .46414 .52599 .47407 .53178 .46848 .51812 Mtetra
.266 .355 .769 r
.46848 .51812 .47407 .53178 .48414 .53321 .47846 .52556 Mtetra
.263 .502 .896 r
.47846 .52556 .48414 .53321 .49435 .52746 .48859 .52943 Mtetra
.287 .773 .696 r
.48859 .52943 .49435 .52746 .50461 .51553 .49885 .52547 Mtetra
0 0 0 r
.49885 .52547 .50461 .51553 .51488 .50019 .5092 .51286 Mtetra
.5092 .51286 .51488 .50019 .5251 .49374 .51952 .49857 Mtetra
.728 .941 .622 r
.51952 .49857 .5251 .49374 .53538 .4992 .52982 .48599 Mtetra
.717 .62 .748 r
.52982 .48599 .53538 .4992 .54578 .50969 .54012 .47804 Mtetra
.594 .447 .651 r
.54012 .47804 .54578 .50969 .55631 .51976 .55046 .47497 Mtetra
.584 .416 .62 r
.55046 .47497 .55631 .51976 .56679 .51655 .56085 .4717 Mtetra
.586 .417 .62 r
.56085 .4717 .56679 .51655 .5771 .5 .57127 .46821 Mtetra
.545 .413 .652 r
.57127 .46821 .5771 .5 .58736 .48299 .58181 .46964 Mtetra
.342 .41 .787 r
.58181 .46964 .58736 .48299 .59768 .47099 .59252 .47573 Mtetra
.671 .202 .129 r
.59252 .47573 .59768 .47099 .60829 .47096 .60337 .48358 Mtetra
.618 .24 .304 r
.60337 .48358 .60829 .47096 .61922 .47993 .6143 .48978 Mtetra
.372 0 .133 r
.6143 .48978 .61922 .47993 .63016 .48549 .62506 .48726 Mtetra
.784 .995 .782 r
.62506 .48726 .63016 .48549 .64097 .48481 .6356 .4768 Mtetra
.846 .749 .757 r
.6356 .4768 .64097 .48481 .65157 .47686 .646 .46269 Mtetra
.78 .644 .712 r
.646 .46269 .65157 .47686 .662 .46445 .65637 .44859 Mtetra
.701 .589 .728 r
.65637 .44859 .662 .46445 .67247 .45358 .66697 .44045 Mtetra
.621 .577 .784 r
.66697 .44045 .67247 .45358 .68309 .44574 .67784 .4378 Mtetra
.479 .614 .907 r
.67784 .4378 .68309 .44574 .69395 .44255 .68894 .43872 Mtetra
.156 .591 .933 r
.68894 .43872 .69395 .44255 .70504 .44248 .70019 .44117 Mtetra
.058 .609 .828 r
.70019 .44117 .70504 .44248 .71621 .44283 .71144 .44203 Mtetra
.224 .738 .869 r
.71144 .44203 .71621 .44283 .72742 .44268 .72264 .44093 Mtetra
.549 .897 .978 r
.72264 .44093 .72742 .44268 .73858 .44072 .73374 .43741 Mtetra
.701 .89 .966 r
.73374 .43741 .73858 .44072 .74969 .43736 .74478 .43233 Mtetra
.727 .827 .926 r
.74478 .43233 .74969 .43736 .76079 .4331 .75583 .42683 Mtetra
.721 .78 .899 r
.75583 .42683 .76079 .4331 .77189 .42842 .76691 .42138 Mtetra
.694 .747 .892 r
.76691 .42138 .77189 .42842 .78305 .424 .77808 .4167 Mtetra
.673 .731 .893 r
.77808 .4167 .78305 .424 .79428 .41988 .78934 .41265 Mtetra
.652 .725 .903 r
.78934 .41265 .79428 .41988 .80558 .41625 .8007 .40922 Mtetra
.637 .727 .913 r
.8007 .40922 .80558 .41625 .81697 .41297 .81214 .4062 Mtetra
.629 .733 .922 r
.81214 .4062 .81697 .41297 .82842 .40993 .82364 .40334 Mtetra
.625 .738 .928 r
.82364 .40334 .82842 .40993 .83994 .40704 .83521 .40056 Mtetra
.626 .744 .932 r
.83521 .40056 .83994 .40704 .85151 .40417 .84682 .39772 Mtetra
.627 .746 .932 r
.84682 .39772 .85151 .40417 .86314 .40133 .85847 .39483 Mtetra
.629 .746 .932 r
.85847 .39483 .86314 .40133 .87482 .39847 .87018 .39187 Mtetra
.632 .745 .929 r
.87018 .39187 .87482 .39847 .88655 .39556 .88193 .38884 Mtetra
.673 .755 .912 r
.25789 .57635 .2641 .58177 .27353 .57825 .26733 .57297 Mtetra
.677 .762 .915 r
.26733 .57297 .27353 .57825 .28299 .57466 .2768 .56949 Mtetra
.681 .767 .916 r
.2768 .56949 .28299 .57466 .29248 .57101 .28631 .5659 Mtetra
.686 .771 .916 r
.28631 .5659 .29248 .57101 .30201 .56732 .29587 .56216 Mtetra
.693 .772 .912 r
.29587 .56216 .30201 .56732 .31157 .56356 .30546 .55823 Mtetra
.695 .767 .907 r
.30546 .55823 .31157 .56356 .32116 .55989 .31509 .55422 Mtetra
.695 .756 .899 r
.31509 .55422 .32116 .55989 .33077 .55637 .32475 .55018 Mtetra
.683 .736 .891 r
.32475 .55018 .33077 .55637 .34038 .55324 .33442 .54643 Mtetra
.662 .712 .885 r
.33442 .54643 .34038 .55324 .35 .55071 .34409 .54321 Mtetra
.63 .681 .88 r
.34409 .54321 .35 .55071 .35963 .5488 .35376 .54086 Mtetra
.582 .651 .883 r
.35376 .54086 .35963 .5488 .36926 .54763 .3634 .53971 Mtetra
.542 .635 .892 r
.3634 .53971 .36926 .54763 .37894 .54653 .37305 .53942 Mtetra
.49 .638 .92 r
.37305 .53942 .37894 .54653 .38868 .54502 .38272 .53983 Mtetra
.491 .712 .969 r
.38272 .53983 .38868 .54502 .39852 .542 .39248 .53951 Mtetra
.53 .844 .999 r
.39248 .53951 .39852 .542 .40848 .53663 .40235 .5374 Mtetra
.589 .946 .895 r
.40235 .5374 .40848 .53663 .41852 .52934 .41237 .53227 Mtetra
.717 .981 .776 r
.41237 .53227 .41852 .52934 .42862 .52049 .42253 .52332 Mtetra
.813 .998 .782 r
.42253 .52332 .42862 .52049 .43868 .5131 .43274 .5126 Mtetra
.883 .943 .848 r
.43274 .5126 .43868 .5131 .44868 .50921 .44295 .50177 Mtetra
.722 .719 .847 r
.44295 .50177 .44868 .50921 .45859 .51073 .45303 .49624 Mtetra
.485 .477 .773 r
.45303 .49624 .45859 .51073 .46848 .51812 .46298 .4987 Mtetra
.36 .348 .71 r
.46298 .4987 .46848 .51812 .47846 .52556 .47292 .50662 Mtetra
.243 .276 .696 r
.47292 .50662 .47846 .52556 .48859 .52943 .48293 .51764 Mtetra
.274 .397 .806 r
.48293 .51764 .48859 .52943 .49885 .52547 .49311 .52384 Mtetra
.558 .892 .985 r
.49311 .52384 .49885 .52547 .5092 .51286 .50345 .52066 Mtetra
.662 .854 .458 r
.50345 .52066 .5092 .51286 .51952 .49857 .51386 .50497 Mtetra
.965 .919 .577 r
.51386 .50497 .51952 .49857 .52982 .48599 .52424 .47865 Mtetra
.904 .747 .676 r
.52424 .47865 .52982 .48599 .54012 .47804 .53452 .45354 Mtetra
.737 .561 .654 r
.53452 .45354 .54012 .47804 .55046 .47497 .54474 .43595 Mtetra
.588 .427 .63 r
.54474 .43595 .55046 .47497 .56085 .4717 .55505 .43262 Mtetra
.439 .322 .624 r
.55505 .43262 .56085 .4717 .57127 .46821 .56557 .4436 Mtetra
.143 .168 .627 r
.56557 .4436 .57127 .46821 .58181 .46964 .57634 .46218 Mtetra
.748 .306 0 r
.57634 .46218 .58181 .46964 .59252 .47573 .58732 .48204 Mtetra
.692 .252 .2 r
.58732 .48204 .59252 .47573 .60337 .48358 .59825 .49129 Mtetra
.269 0 .001 r
.59825 .49129 .60337 .48358 .6143 .48978 .60899 .48795 Mtetra
.905 .92 .818 r
.60899 .48795 .6143 .48978 .62506 .48726 .6195 .4751 Mtetra
.828 .683 .704 r
.6195 .4751 .62506 .48726 .6356 .4768 .62982 .45734 Mtetra
.745 .589 .681 r
.62982 .45734 .6356 .4768 .646 .46269 .64021 .44267 Mtetra
.689 .553 .695 r
.64021 .44267 .646 .46269 .65637 .44859 .65077 .43352 Mtetra
.581 .531 .764 r
.65077 .43352 .65637 .44859 .66697 .44045 .66168 .4325 Mtetra
.268 .496 .891 r
.66168 .4325 .66697 .44045 .67784 .4378 .67289 .43688 Mtetra
.343 0 0 r
.67289 .43688 .67784 .4378 .68894 .43872 .6842 .44118 Mtetra
.418 0 0 r
.6842 .44118 .68894 .43872 .70019 .44117 .6955 .44369 Mtetra
.118 0 0 r
.6955 .44369 .70019 .44117 .71144 .44203 .70668 .4423 Mtetra
.459 .888 .857 r
.70668 .4423 .71144 .44203 .72264 .44093 .71773 .43782 Mtetra
.752 .908 .946 r
.71773 .43782 .72264 .44093 .73374 .43741 .7287 .43148 Mtetra
.768 .804 .882 r
.7287 .43148 .73374 .43741 .74478 .43233 .73964 .42438 Mtetra
.733 .734 .851 r
.73964 .42438 .74478 .43233 .75583 .42683 .75066 .41798 Mtetra
.706 .702 .844 r
.75066 .41798 .75583 .42683 .76691 .42138 .76176 .41246 Mtetra
.673 .687 .855 r
.76176 .41246 .76691 .42138 .77808 .4167 .77299 .40819 Mtetra
.649 .688 .873 r
.77299 .40819 .77808 .4167 .78934 .41265 .78433 .4048 Mtetra
.631 .699 .894 r
.78433 .4048 .78934 .41265 .8007 .40922 .79577 .40198 Mtetra
.618 .713 .913 r
.79577 .40198 .8007 .40922 .81214 .4062 .80728 .39945 Mtetra
.616 .73 .927 r
.80728 .39945 .81214 .4062 .82364 .40334 .81884 .39689 Mtetra
.617 .741 .935 r
.81884 .39689 .82364 .40334 .83521 .40056 .83045 .39425 Mtetra
.624 .75 .938 r
.83045 .39425 .83521 .40056 .84682 .39772 .8421 .3914 Mtetra
.629 .754 .937 r
.8421 .3914 .84682 .39772 .85847 .39483 .85379 .38841 Mtetra
.634 .753 .934 r
.85379 .38841 .85847 .39483 .87018 .39187 .86551 .38529 Mtetra
.638 .75 .929 r
.86551 .38529 .87018 .39187 .88193 .38884 .87727 .38207 Mtetra
.663 .753 .917 r
.25164 .57089 .25789 .57635 .26733 .57297 .26108 .56774 Mtetra
.666 .763 .922 r
.26108 .56774 .26733 .57297 .2768 .56949 .27056 .56451 Mtetra
.672 .774 .927 r
.27056 .56451 .2768 .56949 .28631 .5659 .28008 .56112 Mtetra
.679 .784 .929 r
.28008 .56112 .28631 .5659 .29587 .56216 .28964 .55754 Mtetra
.691 .792 .928 r
.28964 .55754 .29587 .56216 .30546 .55823 .29926 .55365 Mtetra
.7 .797 .925 r
.29926 .55365 .30546 .55823 .31509 .55422 .30892 .54951 Mtetra
.711 .794 .916 r
.30892 .54951 .31509 .55422 .32475 .55018 .31863 .54507 Mtetra
.709 .78 .907 r
.31863 .54507 .32475 .55018 .33442 .54643 .32836 .54063 Mtetra
.7 .755 .895 r
.32836 .54063 .33442 .54643 .34409 .54321 .33811 .53637 Mtetra
.672 .716 .881 r
.33811 .53637 .34409 .54321 .35376 .54086 .34785 .53284 Mtetra
.628 .668 .869 r
.34785 .53284 .35376 .54086 .3634 .53971 .35756 .53049 Mtetra
.577 .617 .855 r
.35756 .53049 .3634 .53971 .37305 .53942 .36725 .52955 Mtetra
.508 .569 .852 r
.36725 .52955 .37305 .53942 .38272 .53983 .37691 .53034 Mtetra
.47 .56 .865 r
.37691 .53034 .38272 .53983 .39248 .53951 .3866 .53181 Mtetra
.438 .596 .91 r
.3866 .53181 .39248 .53951 .40235 .5374 .39635 .5332 Mtetra
.508 .765 .989 r
.39635 .5332 .40235 .5374 .41237 .53227 .40626 .53218 Mtetra
.645 .955 .94 r
.40626 .53218 .41237 .53227 .42253 .52332 .41634 .52707 Mtetra
.67 .954 .716 r
.41634 .52707 .42253 .52332 .43274 .5126 .42658 .51776 Mtetra
.784 .964 .655 r
.42658 .51776 .43274 .5126 .44295 .50177 .43691 .50459 Mtetra
.838 .998 .775 r
.43691 .50459 .44295 .50177 .45303 .49624 .44719 .49308 Mtetra
.779 .874 .918 r
.44719 .49308 .45303 .49624 .46298 .4987 .45735 .48651 Mtetra
.54 .542 .806 r
.45735 .48651 .46298 .4987 .47292 .50662 .46741 .48687 Mtetra
.373 .354 .709 r
.46741 .48687 .47292 .50662 .48293 .51764 .47742 .49447 Mtetra
.376 .333 .683 r
.47742 .49447 .48293 .51764 .49311 .52384 .48752 .50333 Mtetra
.436 .391 .71 r
.48752 .50333 .49311 .52384 .50345 .52066 .49777 .50901 Mtetra
.693 .631 .782 r
.49777 .50901 .50345 .52066 .51386 .50497 .50816 .50325 Mtetra
.94 .869 .741 r
.50816 .50325 .51386 .50497 .52424 .47865 .5186 .48511 Mtetra
.9 .94 .574 r
.5186 .48511 .52424 .47865 .53452 .45354 .52899 .46432 Mtetra
0 0 0 r
.52899 .46432 .53452 .45354 .54474 .43595 .53932 .44708 Mtetra
.356 0 .157 r
.53932 .44708 .54474 .43595 .55505 .43262 .5497 .44375 Mtetra
.69 .307 .316 r
.5497 .44375 .55505 .43262 .56557 .4436 .56028 .45435 Mtetra
.733 .351 .328 r
.56028 .45435 .56557 .4436 .57634 .46218 .57104 .46857 Mtetra
.73 .301 .23 r
.57104 .46857 .57634 .46218 .58732 .48204 .5819 .48019 Mtetra
.313 .769 .952 r
.5819 .48019 .58732 .48204 .59825 .49129 .59265 .47939 Mtetra
.783 .67 .739 r
.59265 .47939 .59825 .49129 .60899 .48795 .60318 .46703 Mtetra
.743 .581 .673 r
.60318 .46703 .60899 .48795 .6195 .4751 .61361 .45143 Mtetra
.719 .554 .665 r
.61361 .45143 .6195 .4751 .62982 .45734 .62403 .43706 Mtetra
.664 .537 .7 r
.62403 .43706 .62982 .45734 .64021 .44267 .63467 .43 Mtetra
.552 .548 .803 r
.63467 .43 .64021 .44267 .65077 .43352 .64559 .42998 Mtetra
0 .369 .771 r
.64559 .42998 .65077 .43352 .66168 .4325 .65678 .43499 Mtetra
.618 .086 0 r
.65678 .43499 .66168 .4325 .67289 .43688 .66814 .44174 Mtetra
.499 0 0 r
.66814 .44174 .67289 .43688 .6842 .44118 .67943 .44457 Mtetra
.179 0 0 r
.67943 .44457 .6842 .44118 .6955 .44369 .69059 .44312 Mtetra
.631 .955 .927 r
.69059 .44312 .6955 .44369 .70668 .4423 .70159 .43748 Mtetra
.802 .848 .885 r
.70159 .43748 .70668 .4423 .71773 .43782 .71246 .42934 Mtetra
.766 .731 .821 r
.71246 .42934 .71773 .43782 .7287 .43148 .72335 .42111 Mtetra
.735 .681 .799 r
.72335 .42111 .7287 .43148 .73964 .42438 .73429 .41357 Mtetra
.697 .657 .807 r
.73429 .41357 .73964 .42438 .75066 .41798 .74537 .40778 Mtetra
.668 .657 .829 r
.74537 .40778 .75066 .41798 .76176 .41246 .75658 .40346 Mtetra
.639 .671 .864 r
.75658 .40346 .76176 .41246 .77299 .40819 .76792 .40036 Mtetra
.613 .692 .9 r
.76792 .40036 .77299 .40819 .78433 .4048 .77937 .39801 Mtetra
.6 .721 .929 r
.77937 .39801 .78433 .4048 .79577 .40198 .79089 .39584 Mtetra
.593 .743 .948 r
.79089 .39584 .79577 .40198 .80728 .39945 .80247 .39368 Mtetra
.602 .762 .955 r
.80247 .39368 .80728 .39945 .81884 .39689 .81408 .39121 Mtetra
.612 .771 .956 r
.81408 .39121 .81884 .39689 .83045 .39425 .82572 .38848 Mtetra
.626 .774 .951 r
.82572 .38848 .83045 .39425 .8421 .3914 .83739 .38544 Mtetra
.637 .772 .945 r
.83739 .38544 .8421 .3914 .85379 .38841 .84908 .38217 Mtetra
.644 .766 .937 r
.84908 .38217 .85379 .38841 .86551 .38529 .86081 .37875 Mtetra
.648 .757 .929 r
.86081 .37875 .86551 .38529 .87727 .38207 .87259 .37524 Mtetra
.65 .75 .923 r
.24535 .5654 .25164 .57089 .26108 .56774 .25478 .56255 Mtetra
.65 .762 .931 r
.25478 .56255 .26108 .56774 .27056 .56451 .26425 .55966 Mtetra
.654 .776 .939 r
.26425 .55966 .27056 .56451 .28008 .56112 .27377 .55665 Mtetra
.661 .793 .945 r
.27377 .55665 .28008 .56112 .28964 .55754 .28333 .55342 Mtetra
.674 .811 .949 r
.28333 .55342 .28964 .55754 .29926 .55365 .29295 .54988 Mtetra
.69 .828 .949 r
.29295 .54988 .29926 .55365 .30892 .54951 .30262 .54593 Mtetra
.712 .84 .943 r
.30262 .54593 .30892 .54951 .31863 .54507 .31236 .54144 Mtetra
.728 .84 .934 r
.31236 .54144 .31863 .54507 .32836 .54063 .32215 .53652 Mtetra
.741 .823 .915 r
.32215 .53652 .32836 .54063 .33811 .53637 .33199 .53118 Mtetra
.731 .783 .895 r
.33199 .53118 .33811 .53637 .34785 .53284 .34185 .52601 Mtetra
.704 .727 .868 r
.34185 .52601 .34785 .53284 .35756 .53049 .35169 .5214 Mtetra
.65 .652 .839 r
.35169 .5214 .35756 .53049 .36725 .52955 .3615 .51826 Mtetra
.579 .576 .814 r
.3615 .51826 .36725 .52955 .37691 .53034 .37123 .51734 Mtetra
.51 .512 .794 r
.37123 .51734 .37691 .53034 .3866 .53181 .38092 .51865 Mtetra
.42 .458 .794 r
.38092 .51865 .3866 .53181 .39635 .5332 .39058 .52228 Mtetra
.382 .48 .835 r
.39058 .52228 .39635 .5332 .40626 .53218 .40031 .52586 Mtetra
.355 .607 .944 r
.40031 .52586 .40626 .53218 .41634 .52707 .41018 .52766 Mtetra
.323 .81 .831 r
.41018 .52766 .41634 .52707 .42658 .51776 .42027 .5249 Mtetra
0 0 0 r
.42027 .5249 .42658 .51776 .43691 .50459 .43057 .51584 Mtetra
.43057 .51584 .43691 .50459 .44719 .49308 .44098 .50226 Mtetra
.639 .83 .42 r
.44098 .50226 .44719 .49308 .45735 .48651 .45144 .48591 Mtetra
.909 .928 .814 r
.45144 .48591 .45735 .48651 .46741 .48687 .46178 .47306 Mtetra
.681 .595 .753 r
.46178 .47306 .46741 .48687 .47742 .49447 .47199 .46721 Mtetra
.528 .415 .668 r
.47199 .46721 .47742 .49447 .48752 .50333 .48212 .46929 Mtetra
.429 .326 .635 r
.48212 .46929 .48752 .50333 .49777 .50901 .49225 .47897 Mtetra
.372 .299 .645 r
.49225 .47897 .49777 .50901 .50816 .50325 .50248 .49062 Mtetra
.061 .245 .739 r
.50248 .49062 .50816 .50325 .5186 .48511 .51285 .50086 Mtetra
.601 .245 .338 r
.51285 .50086 .5186 .48511 .52899 .46432 .52335 .50636 Mtetra
.529 .255 .444 r
.52335 .50636 .52899 .46432 .53932 .44708 .53393 .50599 Mtetra
.516 .261 .466 r
.53393 .50599 .53932 .44708 .5497 .44375 .54455 .50269 Mtetra
.497 .245 .462 r
.54455 .50269 .5497 .44375 .56028 .45435 .55518 .49645 Mtetra
.413 .158 .415 r
.55518 .49645 .56028 .45435 .57104 .46857 .56576 .48431 Mtetra
0 0 .042 r
.56576 .48431 .57104 .46857 .5819 .48019 .57626 .46736 Mtetra
.825 .675 .697 r
.57626 .46736 .5819 .48019 .59265 .47939 .58667 .44894 Mtetra
.705 .524 .642 r
.58667 .44894 .59265 .47939 .60318 .46703 .59708 .43246 Mtetra
.638 .47 .639 r
.59708 .43246 .60318 .46703 .61361 .45143 .60763 .42362 Mtetra
.569 .443 .668 r
.60763 .42362 .61361 .45143 .62403 .43706 .61842 .4228 Mtetra
.35 .405 .778 r
.61842 .4228 .62403 .43706 .63467 .43 .6295 .42908 Mtetra
.667 .115 0 r
.6295 .42908 .63467 .43 .64559 .42998 .64081 .43897 Mtetra
.637 .215 .225 r
.64081 .43897 .64559 .42998 .65678 .43499 .65215 .44608 Mtetra
.537 .135 .227 r
.65215 .44608 .65678 .43499 .66814 .44174 .66341 .44861 Mtetra
.204 0 0 r
.66341 .44861 .66814 .44174 .67943 .44457 .67446 .44472 Mtetra
.76 .994 .868 r
.67446 .44472 .67943 .44457 .69059 .44312 .68532 .43616 Mtetra
.82 .782 .817 r
.68532 .43616 .69059 .44312 .70159 .43748 .69609 .42574 Mtetra
.766 .672 .759 r
.69609 .42574 .70159 .43748 .71246 .42934 .70686 .41525 Mtetra
.713 .618 .75 r
.70686 .41525 .71246 .42934 .72335 .42111 .71776 .40713 Mtetra
.677 .601 .763 r
.71776 .40713 .72335 .42111 .73429 .41357 .72882 .40128 Mtetra
.641 .606 .799 r
.72882 .40128 .73429 .41357 .74537 .40778 .74006 .39772 Mtetra
.606 .631 .85 r
.74006 .39772 .74537 .40778 .75658 .40346 .75145 .39568 Mtetra
.577 .678 .909 r
.75145 .39568 .75658 .40346 .76792 .40036 .76295 .39423 Mtetra
.549 .723 .954 r
.76295 .39423 .76792 .40036 .77937 .39801 .77452 .39295 Mtetra
.55 .768 .979 r
.77452 .39295 .77937 .39801 .79089 .39584 .78611 .39124 Mtetra
.562 .794 .986 r
.78611 .39124 .79089 .39584 .80247 .39368 .79773 .38909 Mtetra
.592 .808 .982 r
.79773 .38909 .80247 .39368 .81408 .39121 .80936 .38638 Mtetra
.618 .81 .974 r
.80936 .38638 .81408 .39121 .82572 .38848 .82101 .38324 Mtetra
.638 .802 .961 r
.82101 .38324 .82572 .38848 .83739 .38544 .83267 .37977 Mtetra
.651 .791 .949 r
.83267 .37977 .83739 .38544 .84908 .38217 .84436 .37607 Mtetra
.658 .778 .937 r
.84436 .37607 .84908 .38217 .86081 .37875 .85609 .37224 Mtetra
.66 .765 .927 r
.85609 .37224 .86081 .37875 .87259 .37524 .86786 .36837 Mtetra
.639 .747 .927 r
.23902 .55988 .24535 .5654 .25478 .56255 .24845 .55724 Mtetra
.636 .755 .934 r
.24845 .55724 .25478 .56255 .26425 .55966 .25792 .55464 Mtetra
.636 .767 .942 r
.25792 .55464 .26425 .55966 .27377 .55665 .26742 .55199 Mtetra
.639 .783 .95 r
.26742 .55199 .27377 .55665 .28333 .55342 .27698 .54922 Mtetra
.644 .803 .959 r
.27698 .54922 .28333 .55342 .29295 .54988 .28658 .54625 Mtetra
.658 .83 .966 r
.28658 .54625 .29295 .54988 .30262 .54593 .29624 .5429 Mtetra
.679 .859 .968 r
.29624 .5429 .30262 .54593 .31236 .54144 .30597 .53898 Mtetra
.705 .886 .964 r
.30597 .53898 .31236 .54144 .32215 .53652 .31577 .5344 Mtetra
.741 .902 .95 r
.31577 .5344 .32215 .53652 .33199 .53118 .32566 .52894 Mtetra
.763 .899 .937 r
.32566 .52894 .33199 .53118 .34185 .52601 .33559 .52295 Mtetra
.775 .868 .917 r
.33559 .52295 .34185 .52601 .35169 .5214 .34556 .51658 Mtetra
.747 .801 .896 r
.34556 .51658 .35169 .5214 .3615 .51826 .35552 .51088 Mtetra
.689 .71 .864 r
.35552 .51088 .3615 .51826 .37123 .51734 .36543 .50664 Mtetra
.605 .601 .821 r
.36543 .50664 .37123 .51734 .38092 .51865 .37525 .50486 Mtetra
.505 .499 .783 r
.37525 .50486 .38092 .51865 .39058 .52228 .38498 .50639 Mtetra
.442 .435 .755 r
.38498 .50639 .39058 .52228 .40031 .52586 .39469 .51024 Mtetra
.379 .4 .756 r
.39469 .51024 .40031 .52586 .41018 .52766 .40441 .51569 Mtetra
.402 .472 .817 r
.40441 .51569 .41018 .52766 .42027 .5249 .41429 .51927 Mtetra
.523 .716 .96 r
.41429 .51927 .42027 .5249 .43057 .51584 .42438 .51854 Mtetra
.576 .93 .76 r
.42438 .51854 .43057 .51584 .44098 .50226 .43469 .51143 Mtetra
0 0 0 r
.43469 .51143 .44098 .50226 .45144 .48591 .44518 .49731 Mtetra
.44518 .49731 .45144 .48591 .46178 .47306 .45568 .4813 Mtetra
.591 .82 .431 r
.45568 .4813 .46178 .47306 .47199 .46721 .46612 .46685 Mtetra
.795 .975 .908 r
.46612 .46685 .47199 .46721 .48212 .46929 .47643 .45901 Mtetra
.491 .557 .85 r
.47643 .45901 .48212 .46929 .49225 .47897 .48664 .46021 Mtetra
.297 .315 .71 r
.48664 .46021 .49225 .47897 .50248 .49062 .49685 .46955 Mtetra
.132 .185 .651 r
.49685 .46955 .50248 .49062 .51285 .50086 .50715 .48477 Mtetra
.054 .186 .684 r
.50715 .48477 .51285 .50086 .52335 .50636 .51761 .49796 Mtetra
.068 .362 .832 r
.51761 .49796 .52335 .50636 .53393 .50599 .52821 .50465 Mtetra
.531 .894 .973 r
.52821 .50465 .53393 .50599 .54455 .50269 .53887 .50134 Mtetra
.911 .923 .811 r
.53887 .50134 .54455 .50269 .55518 .49645 .5495 .48797 Mtetra
.877 .741 .708 r
.5495 .48797 .55518 .49645 .56576 .48431 .56004 .46805 Mtetra
.817 .645 .669 r
.56004 .46805 .56576 .48431 .57626 .46736 .57048 .44603 Mtetra
.745 .58 .67 r
.57048 .44603 .57626 .46736 .58667 .44894 .58094 .42986 Mtetra
.681 .554 .705 r
.58094 .42986 .58667 .44894 .59708 .43246 .59152 .42188 Mtetra
.498 .558 .848 r
.59152 .42188 .59708 .43246 .60763 .42362 .60233 .42302 Mtetra
.605 .035 0 r
.60233 .42302 .60763 .42362 .61842 .4228 .6134 .43087 Mtetra
.683 .257 .229 r
.6134 .43087 .61842 .4228 .6295 .42908 .62464 .44035 Mtetra
.638 .241 .274 r
.62464 .44035 .6295 .42908 .64081 .43897 .63594 .44795 Mtetra
.462 .031 .135 r
.63594 .44795 .64081 .43897 .65215 .44608 .6471 .44845 Mtetra
.385 .821 .67 r
.6471 .44845 .65215 .44608 .66341 .44861 .65806 .44245 Mtetra
.829 .804 .827 r
.65806 .44245 .66341 .44861 .67446 .44472 .66886 .43202 Mtetra
.778 .664 .737 r
.66886 .43202 .67446 .44472 .68532 .43616 .67955 .41966 Mtetra
.729 .602 .716 r
.67955 .41966 .68532 .43616 .69609 .42574 .69032 .4089 Mtetra
.698 .583 .723 r
.69032 .4089 .69609 .42574 .70686 .41525 .7012 .40051 Mtetra
.658 .583 .759 r
.7012 .40051 .70686 .41525 .71776 .40713 .7123 .3955 Mtetra
.616 .605 .817 r
.7123 .3955 .71776 .40713 .72882 .40128 .72358 .39302 Mtetra
.56 .655 .9 r
.72358 .39302 .72882 .40128 .74006 .39772 .73502 .39206 Mtetra
.48 .708 .97 r
.73502 .39206 .74006 .39772 .75145 .39568 .74657 .39179 Mtetra
.432 .762 .996 r
.74657 .39179 .75145 .39568 .76295 .39423 .75816 .39114 Mtetra
.427 .794 .995 r
.75816 .39114 .76295 .39423 .77452 .39295 .76978 .38995 Mtetra
.493 .832 .998 r
.76978 .38995 .77452 .39295 .78611 .39124 .78139 .38785 Mtetra
.559 .847 .998 r
.78139 .38785 .78611 .39124 .79773 .38909 .793 .38506 Mtetra
.614 .843 .987 r
.793 .38506 .79773 .38909 .80936 .38638 .80462 .38168 Mtetra
.646 .828 .97 r
.80462 .38168 .80936 .38638 .82101 .38324 .81625 .37789 Mtetra
.66 .808 .954 r
.81625 .37789 .82101 .38324 .83267 .37977 .8279 .37391 Mtetra
.668 .792 .94 r
.8279 .37391 .83267 .37977 .84436 .37607 .83959 .36978 Mtetra
.671 .778 .93 r
.83959 .36978 .84436 .37607 .85609 .37224 .85132 .36559 Mtetra
.67 .766 .922 r
.85132 .36559 .85609 .37224 .86786 .36837 .8631 .36144 Mtetra
.635 .746 .928 r
.23264 .55431 .23902 .55988 .24845 .55724 .24209 .55174 Mtetra
.63 .748 .932 r
.24209 .55174 .24845 .55724 .25792 .55464 .25156 .54927 Mtetra
.625 .752 .938 r
.25156 .54927 .25792 .55464 .26742 .55199 .26107 .54685 Mtetra
.621 .76 .945 r
.26107 .54685 .26742 .55199 .27698 .54922 .27061 .54448 Mtetra
.613 .775 .958 r
.27061 .54448 .27698 .54922 .28658 .54625 .28019 .54215 Mtetra
.613 .801 .972 r
.28019 .54215 .28658 .54625 .29624 .5429 .28981 .53966 Mtetra
.614 .838 .985 r
.28981 .53966 .29624 .5429 .30597 .53898 .2995 .53686 Mtetra
.627 .886 .988 r
.2995 .53686 .30597 .53898 .31577 .5344 .30926 .53342 Mtetra
.652 .931 .971 r
.30926 .53342 .31577 .5344 .32566 .52894 .31912 .52902 Mtetra
.682 .963 .938 r
.31912 .52902 .32566 .52894 .33559 .52295 .32907 .52349 Mtetra
.746 .982 .912 r
.32907 .52349 .33559 .52295 .34556 .51658 .33912 .5166 Mtetra
.796 .973 .909 r
.33912 .5166 .34556 .51658 .35552 .51088 .34922 .50894 Mtetra
.823 .908 .898 r
.34922 .50894 .35552 .51088 .36543 .50664 .35935 .50089 Mtetra
.767 .775 .86 r
.35935 .50089 .36543 .50664 .37525 .50486 .36943 .49403 Mtetra
.673 .631 .799 r
.36943 .49403 .37525 .50486 .38498 .50639 .37943 .48958 Mtetra
.573 .504 .74 r
.37943 .48958 .38498 .50639 .39469 .51024 .3893 .48881 Mtetra
.476 .408 .701 r
.3893 .48881 .39469 .51024 .40441 .51569 .39904 .49267 Mtetra
.417 .36 .687 r
.39904 .49267 .40441 .51569 .41429 .51927 .40877 .49936 Mtetra
.343 .334 .705 r
.40877 .49936 .41429 .51927 .42438 .51854 .41855 .5075 Mtetra
.265 .412 .824 r
.41855 .5075 .42438 .51854 .43469 .51143 .42851 .51303 Mtetra
.183 0 0 r
.42851 .51303 .43469 .51143 .44518 .49731 .4387 .51319 Mtetra
.295 0 .203 r
.4387 .51319 .44518 .49731 .45568 .4813 .44911 .50647 Mtetra
.233 0 .273 r
.44911 .50647 .45568 .4813 .46612 .46685 .45967 .49265 Mtetra
.173 0 .255 r
.45967 .49265 .46612 .46685 .47643 .45901 .47026 .47622 Mtetra
0 0 .062 r
.47026 .47622 .47643 .45901 .48664 .46021 .48079 .46008 Mtetra
.899 .956 .826 r
.48079 .46008 .48664 .46021 .49685 .46955 .49124 .44794 Mtetra
.655 .523 .691 r
.49124 .44794 .49685 .46955 .50715 .48477 .50164 .4412 Mtetra
.579 .413 .62 r
.50164 .4412 .50715 .48477 .51761 .49796 .51204 .43809 Mtetra
.558 .381 .597 r
.51204 .43809 .51761 .49796 .52821 .50465 .52249 .43705 Mtetra
.569 .384 .591 r
.52249 .43705 .52821 .50465 .53887 .50134 .53298 .43366 Mtetra
.581 .393 .591 r
.53298 .43366 .53887 .50134 .5495 .48797 .54349 .42789 Mtetra
.574 .392 .598 r
.54349 .42789 .5495 .48797 .56004 .46805 .55406 .4242 Mtetra
.554 .395 .62 r
.55406 .4242 .56004 .46805 .57048 .44603 .5647 .42416 Mtetra
.45 .393 .703 r
.5647 .42416 .57048 .44603 .58094 .42986 .57549 .42957 Mtetra
.681 .135 0 r
.57549 .42957 .58094 .42986 .59152 .42188 .58646 .43905 Mtetra
.65 .295 .358 r
.58646 .43905 .59152 .42188 .60233 .42302 .59757 .44888 Mtetra
.601 .282 .402 r
.59757 .44888 .60233 .42302 .6134 .43087 .60874 .45611 Mtetra
.516 .204 .376 r
.60874 .45611 .6134 .43087 .62464 .44035 .61982 .45616 Mtetra
.31 0 .218 r
.61982 .45616 .62464 .44035 .63594 .44795 .63074 .44923 Mtetra
.86 .997 .781 r
.63074 .44923 .63594 .44795 .6471 .44845 .64149 .43681 Mtetra
.816 .691 .727 r
.64149 .43681 .6471 .44845 .65806 .44245 .65211 .4217 Mtetra
.73 .575 .681 r
.65211 .4217 .65806 .44245 .66886 .43202 .66275 .40802 Mtetra
.687 .534 .673 r
.66275 .40802 .66886 .43202 .67955 .41966 .67351 .39721 Mtetra
.642 .514 .692 r
.67351 .39721 .67955 .41966 .69032 .4089 .68449 .39112 Mtetra
.6 .52 .736 r
.68449 .39112 .69032 .4089 .7012 .40051 .6957 .3888 Mtetra
.539 .563 .828 r
.6957 .3888 .7012 .40051 .7123 .3955 .7071 .38897 Mtetra
.4 .632 .948 r
.7071 .38897 .7123 .3955 .72358 .39302 .71865 .39038 Mtetra
.18 .661 .929 r
.71865 .39038 .72358 .39302 .73502 .39206 .73026 .39139 Mtetra
.049 .613 .782 r
.73026 .39139 .73502 .39206 .74657 .39179 .74189 .39163 Mtetra
.144 .688 .788 r
.74189 .39163 .74657 .39179 .75816 .39114 .7535 .39046 Mtetra
.322 .805 .887 r
.7535 .39046 .75816 .39114 .76978 .38995 .76509 .38813 Mtetra
.512 .884 .973 r
.76509 .38813 .76978 .38995 .78139 .38785 .77665 .3848 Mtetra
.62 .887 .989 r
.77665 .3848 .78139 .38785 .793 .38506 .78821 .3808 Mtetra
.664 .854 .972 r
.78821 .3808 .793 .38506 .80462 .38168 .79979 .37648 Mtetra
.68 .822 .951 r
.79979 .37648 .80462 .38168 .81625 .37789 .8114 .37198 Mtetra
.68 .795 .936 r
.8114 .37198 .81625 .37789 .8279 .37391 .82305 .36752 Mtetra
.679 .779 .926 r
.82305 .36752 .8279 .37391 .83959 .36978 .83475 .3631 Mtetra
.677 .768 .92 r
.83475 .3631 .83959 .36978 .85132 .36559 .8465 .35873 Mtetra
.673 .762 .917 r
.8465 .35873 .85132 .36559 .8631 .36144 .85831 .35446 Mtetra
.644 .748 .925 r
.22623 .54871 .23264 .55431 .24209 .55174 .23571 .54594 Mtetra
.64 .741 .922 r
.23571 .54594 .24209 .55174 .25156 .54927 .24522 .54326 Mtetra
.633 .733 .919 r
.24522 .54326 .25156 .54927 .26107 .54685 .25475 .54071 Mtetra
.625 .726 .92 r
.25475 .54071 .26107 .54685 .27061 .54448 .26431 .53835 Mtetra
.612 .724 .925 r
.26431 .53835 .27061 .54448 .28019 .54215 .27388 .53626 Mtetra
.602 .73 .934 r
.27388 .53626 .28019 .54215 .28981 .53966 .28349 .53432 Mtetra
.589 .747 .952 r
.28349 .53432 .28981 .53966 .2995 .53686 .29312 .5325 Mtetra
.589 .786 .974 r
.29312 .5325 .2995 .53686 .30926 .53342 .30282 .53042 Mtetra
.591 .844 .993 r
.30282 .53042 .30926 .53342 .31912 .52902 .3126 .52781 Mtetra
.6 .912 .98 r
.3126 .52781 .31912 .52902 .32907 .52349 .32247 .52414 Mtetra
.618 .954 .913 r
.32247 .52414 .32907 .52349 .33912 .5166 .33247 .51893 Mtetra
.627 .959 .818 r
.33247 .51893 .33912 .5166 .34922 .50894 .34258 .5121 Mtetra
.701 .977 .78 r
.34258 .5121 .34922 .50894 .35935 .50089 .3528 .50343 Mtetra
.775 .997 .816 r
.3528 .50343 .35935 .50089 .36943 .49403 .36306 .49411 Mtetra
.841 .97 .881 r
.36306 .49411 .36943 .49403 .37943 .48958 .37331 .48496 Mtetra
.776 .817 .885 r
.37331 .48496 .37943 .48958 .3893 .48881 .38346 .47815 Mtetra
.635 .619 .817 r
.38346 .47815 .3893 .48881 .39904 .49267 .39347 .47526 Mtetra
.517 .466 .739 r
.39347 .47526 .39904 .49267 .40877 .49936 .40336 .47678 Mtetra
.424 .368 .691 r
.40336 .47678 .40877 .49936 .41855 .5075 .41315 .48299 Mtetra
.392 .336 .675 r
.41315 .48299 .41855 .5075 .42851 .51303 .42298 .4911 Mtetra
.377 .342 .693 r
.42298 .4911 .42851 .51303 .4387 .51319 .43293 .49891 Mtetra
.443 .461 .783 r
.43293 .49891 .4387 .51319 .44911 .50647 .4431 .50222 Mtetra
.656 .822 .963 r
.4431 .50222 .44911 .50647 .45967 .49265 .45349 .49867 Mtetra
0 0 0 r
.45349 .49867 .45967 .49265 .47026 .47622 .46404 .48902 Mtetra
.46404 .48902 .47026 .47622 .48079 .46008 .47466 .47433 Mtetra
.47466 .47433 .48079 .46008 .49124 .44794 .48526 .45866 Mtetra
.48526 .45866 .49124 .44794 .50164 .4412 .49581 .4445 Mtetra
.726 .972 .725 r
.49581 .4445 .50164 .4412 .51204 .43809 .50631 .43409 Mtetra
.751 .854 .926 r
.50631 .43409 .51204 .43809 .52249 .43705 .51679 .42814 Mtetra
.653 .67 .854 r
.51679 .42814 .52249 .43705 .53298 .43366 .5273 .42471 Mtetra
.564 .631 .876 r
.5273 .42471 .53298 .43366 .54349 .42789 .53786 .42382 Mtetra
.006 .484 .869 r
.53786 .42382 .54349 .42789 .55406 .4242 .54851 .42742 Mtetra
.653 .149 .036 r
.54851 .42742 .55406 .4242 .5647 .42416 .55928 .43481 Mtetra
.664 .264 .278 r
.55928 .43481 .5647 .42416 .57549 .42957 .57019 .44376 Mtetra
.636 .262 .319 r
.57019 .44376 .57549 .42957 .58646 .43905 .58121 .45178 Mtetra
.547 .16 .258 r
.58121 .45178 .58646 .43905 .59757 .44888 .59225 .45473 Mtetra
.177 0 0 r
.59225 .45473 .59757 .44888 .60874 .45611 .60322 .45152 Mtetra
.842 .851 .851 r
.60322 .45152 .60874 .45611 .61982 .45616 .61405 .44134 Mtetra
.782 .643 .709 r
.61405 .44134 .61982 .45616 .63074 .44923 .62474 .42657 Mtetra
.731 .567 .669 r
.62474 .42657 .63074 .44923 .64149 .43681 .63538 .41144 Mtetra
.702 .538 .663 r
.63538 .41144 .64149 .43681 .65211 .4217 .64606 .39822 Mtetra
.665 .523 .681 r
.64606 .39822 .65211 .4217 .66275 .40802 .65691 .38976 Mtetra
.626 .531 .727 r
.65691 .38976 .66275 .40802 .67351 .39721 .66797 .38579 Mtetra
.54 .569 .833 r
.66797 .38579 .67351 .39721 .68449 .39112 .67926 .38584 Mtetra
.253 .598 .951 r
.67926 .38584 .68449 .39112 .6957 .3888 .69075 .3883 Mtetra
.22 0 0 r
.69075 .3883 .6957 .3888 .7071 .38897 .70234 .39096 Mtetra
.346 0 0 r
.70234 .39096 .7071 .38897 .71865 .39038 .71398 .39297 Mtetra
.242 0 0 r
.71398 .39297 .71865 .39038 .73026 .39139 .72559 .3931 Mtetra
.023 0 0 r
.72559 .3931 .73026 .39139 .74189 .39163 .73717 .39156 Mtetra
.338 .819 .848 r
.73717 .39156 .74189 .39163 .7535 .39046 .74869 .38843 Mtetra
.592 .912 .978 r
.74869 .38843 .7535 .39046 .76509 .38813 .76019 .3842 Mtetra
.682 .872 .97 r
.76019 .3842 .76509 .38813 .77665 .3848 .77169 .37941 Mtetra
.703 .821 .938 r
.77169 .37941 .77665 .3848 .78821 .3808 .7832 .37434 Mtetra
.698 .781 .916 r
.7832 .37434 .78821 .3808 .79979 .37648 .79477 .3694 Mtetra
.691 .759 .904 r
.79477 .3694 .79979 .37648 .8114 .37198 .80639 .3646 Mtetra
.681 .747 .901 r
.80639 .3646 .8114 .37198 .82305 .36752 .81807 .36007 Mtetra
.674 .743 .902 r
.81807 .36007 .82305 .36752 .83475 .3631 .82981 .35574 Mtetra
.67 .744 .907 r
.82981 .35574 .83475 .3631 .8465 .35873 .84162 .35154 Mtetra
.666 .749 .912 r
.84162 .35154 .8465 .35873 .85831 .35446 .85348 .34743 Mtetra
.661 .753 .918 r
.21976 .54307 .22623 .54871 .23571 .54594 .2293 .53987 Mtetra
.659 .738 .908 r
.2293 .53987 .23571 .54594 .24522 .54326 .23887 .53671 Mtetra
.653 .721 .899 r
.23887 .53671 .24522 .54326 .25475 .54071 .24846 .53368 Mtetra
.642 .704 .891 r
.24846 .53368 .25475 .54071 .26431 .53835 .25806 .53092 Mtetra
.627 .688 .887 r
.25806 .53092 .26431 .53835 .27388 .53626 .26767 .52853 Mtetra
.609 .673 .886 r
.26767 .52853 .27388 .53626 .28349 .53432 .27729 .52659 Mtetra
.584 .665 .894 r
.27729 .52659 .28349 .53432 .29312 .5325 .2869 .52521 Mtetra
.564 .671 .91 r
.2869 .52521 .29312 .5325 .30282 .53042 .29654 .52419 Mtetra
.534 .696 .943 r
.29654 .52419 .30282 .53042 .3126 .52781 .30621 .52346 Mtetra
.51 .763 .987 r
.30621 .52346 .3126 .52781 .32247 .52414 .31595 .5224 Mtetra
.449 .839 .983 r
.31595 .5224 .32247 .52414 .33247 .51893 .32579 .52054 Mtetra
.312 .799 .762 r
.32579 .52054 .33247 .51893 .34258 .5121 .33576 .51712 Mtetra
0 0 0 r
.33576 .51712 .34258 .5121 .3528 .50343 .34588 .51145 Mtetra
.34588 .51145 .3528 .50343 .36306 .49411 .35615 .50342 Mtetra
.35615 .50342 .36306 .49411 .37331 .48496 .36654 .49283 Mtetra
.36654 .49283 .37331 .48496 .38346 .47815 .37699 .48108 Mtetra
.853 .997 .782 r
.37699 .48108 .38346 .47815 .39347 .47526 .38742 .46922 Mtetra
.81 .776 .822 r
.38742 .46922 .39347 .47526 .40336 .47678 .39775 .45976 Mtetra
.654 .551 .726 r
.39775 .45976 .40336 .47678 .41315 .48299 .40792 .45447 Mtetra
.56 .431 .662 r
.40792 .45447 .41315 .48299 .42298 .4911 .41797 .45405 Mtetra
.496 .364 .63 r
.41797 .45405 .42298 .4911 .43293 .49891 .42791 .45893 Mtetra
.457 .33 .619 r
.42791 .45893 .43293 .49891 .4431 .50222 .43785 .46735 Mtetra
.411 .31 .629 r
.43785 .46735 .4431 .50222 .45349 .49867 .44785 .47772 Mtetra
.34 .327 .698 r
.44785 .47772 .45349 .49867 .46404 .48902 .45802 .48638 Mtetra
.318 0 0 r
.45802 .48638 .46404 .48902 .47466 .47433 .46836 .49124 Mtetra
.512 .16 .306 r
.46836 .49124 .47466 .47433 .48526 .45866 .47886 .49207 Mtetra
.486 .198 .401 r
.47886 .49207 .48526 .45866 .49581 .4445 .48946 .48903 Mtetra
.483 .214 .429 r
.48946 .48903 .49581 .4445 .50631 .43409 .50012 .48398 Mtetra
.485 .222 .44 r
.50012 .48398 .50631 .43409 .51679 .42814 .51081 .4784 Mtetra
.503 .238 .445 r
.51081 .4784 .51679 .42814 .5273 .42471 .52153 .47501 Mtetra
.52 .252 .449 r
.52153 .47501 .5273 .42471 .53786 .42382 .53229 .47379 Mtetra
.516 .248 .447 r
.53229 .47379 .53786 .42382 .54851 .42742 .54311 .47205 Mtetra
.495 .224 .433 r
.54311 .47205 .54851 .42742 .55928 .43481 .55397 .4683 Mtetra
.428 .148 .385 r
.55397 .4683 .55928 .43481 .57019 .44376 .56482 .46064 Mtetra
.148 0 .159 r
.56482 .46064 .57019 .44376 .58121 .45178 .57562 .44891 Mtetra
.921 .878 .776 r
.57562 .44891 .58121 .45178 .59225 .45473 .58633 .43329 Mtetra
.755 .586 .667 r
.58633 .43329 .59225 .45473 .60322 .45152 .59697 .41589 Mtetra
.681 .497 .631 r
.59697 .41589 .60322 .45152 .61405 .44134 .6076 .40043 Mtetra
.644 .462 .623 r
.6076 .40043 .61405 .44134 .62474 .42657 .6183 .38853 Mtetra
.61 .444 .632 r
.6183 .38853 .62474 .42657 .63538 .41144 .62917 .382 Mtetra
.573 .44 .662 r
.62917 .382 .63538 .41144 .64606 .39822 .64023 .38042 Mtetra
.492 .455 .744 r
.64023 .38042 .64606 .39822 .65691 .38976 .65152 .38311 Mtetra
.11 .452 .884 r
.65152 .38311 .65691 .38976 .66797 .38579 .663 .38827 Mtetra
.539 0 0 r
.663 .38827 .66797 .38579 .67926 .38584 .67459 .39335 Mtetra
.55 .091 .116 r
.67459 .39335 .67926 .38584 .69075 .3883 .68622 .39727 Mtetra
.48 .043 .129 r
.68622 .39727 .69075 .3883 .70234 .39096 .69782 .39859 Mtetra
.368 0 .027 r
.69782 .39859 .70234 .39096 .71398 .39297 .70936 .39749 Mtetra
.094 0 0 r
.70936 .39749 .71398 .39297 .72559 .3931 .72082 .39406 Mtetra
.414 .859 .785 r
.72082 .39406 .72559 .3931 .73717 .39156 .73223 .38901 Mtetra
.707 .931 .963 r
.73223 .38901 .73717 .39156 .74869 .38843 .74362 .38314 Mtetra
.743 .836 .922 r
.74362 .38314 .74869 .38843 .76019 .3842 .75501 .37691 Mtetra
.724 .763 .884 r
.75501 .37691 .76019 .3842 .77169 .37941 .76646 .37096 Mtetra
.707 .725 .864 r
.76646 .37096 .77169 .37941 .7832 .37434 .77796 .36538 Mtetra
.688 .705 .86 r
.77796 .36538 .7832 .37434 .79477 .3694 .78955 .36038 Mtetra
.675 .699 .864 r
.78955 .36038 .79477 .3694 .80639 .3646 .80122 .35583 Mtetra
.665 .701 .874 r
.80122 .35583 .80639 .3646 .81807 .36007 .81297 .35168 Mtetra
.657 .709 .886 r
.81297 .35168 .81807 .36007 .82981 .35574 .82479 .34779 Mtetra
.653 .721 .899 r
.82479 .34779 .82981 .35574 .84162 .35154 .83667 .34405 Mtetra
.651 .735 .911 r
.83667 .34405 .84162 .35154 .85348 .34743 .84861 .34035 Mtetra
.676 .756 .911 r
.21326 .53739 .21976 .54307 .2293 .53987 .22285 .53379 Mtetra
.677 .744 .901 r
.22285 .53379 .2293 .53987 .23887 .53671 .23248 .53014 Mtetra
.673 .728 .891 r
.23248 .53014 .23887 .53671 .24846 .53368 .24213 .52654 Mtetra
.665 .709 .88 r
.24213 .52654 .24846 .53368 .25806 .53092 .2518 .52311 Mtetra
.654 .688 .869 r
.2518 .52311 .25806 .53092 .26767 .52853 .26149 .51994 Mtetra
.636 .662 .858 r
.26149 .51994 .26767 .52853 .27729 .52659 .27117 .51723 Mtetra
.612 .634 .849 r
.27117 .51723 .27729 .52659 .2869 .52521 .28085 .51518 Mtetra
.587 .609 .841 r
.28085 .51518 .2869 .52521 .29654 .52419 .29051 .51387 Mtetra
.554 .588 .842 r
.29051 .51387 .29654 .52419 .30621 .52346 .30016 .51344 Mtetra
.53 .584 .853 r
.30016 .51344 .30621 .52346 .31595 .5224 .30983 .51354 Mtetra
.503 .6 .884 r
.30983 .51354 .31595 .5224 .32579 .52054 .31953 .51396 Mtetra
.497 .671 .942 r
.31953 .51396 .32579 .52054 .33576 .51712 .32933 .51386 Mtetra
.484 .8 1 r
.32933 .51386 .33576 .51712 .34588 .51145 .33925 .51252 Mtetra
.38 .844 .827 r
.33925 .51252 .34588 .51145 .35615 .50342 .34933 .509 Mtetra
0 0 0 r
.34933 .509 .35615 .50342 .36654 .49283 .35959 .50248 Mtetra
.35959 .50248 .36654 .49283 .37699 .48108 .37001 .49306 Mtetra
.37001 .49306 .37699 .48108 .38742 .46922 .38056 .48079 Mtetra
.38056 .48079 .38742 .46922 .39775 .45976 .39111 .46782 Mtetra
.39111 .46782 .39775 .45976 .40792 .45447 .40162 .45571 Mtetra
.798 .997 .861 r
.40162 .45571 .40792 .45447 .41797 .45405 .412 .44675 Mtetra
.686 .721 .877 r
.412 .44675 .41797 .45405 .42791 .45893 .42223 .44251 Mtetra
.532 .487 .751 r
.42223 .44251 .42791 .45893 .43785 .46735 .43236 .44327 Mtetra
.446 .375 .684 r
.43236 .44327 .43785 .46735 .44785 .47772 .44243 .44885 Mtetra
.434 .345 .656 r
.44243 .44885 .44785 .47772 .45802 .48638 .45255 .45618 Mtetra
.446 .349 .652 r
.45255 .45618 .45802 .48638 .46836 .49124 .46279 .4632 Mtetra
.488 .387 .666 r
.46279 .4632 .46836 .49124 .47886 .49207 .47318 .46739 Mtetra
.55 .443 .685 r
.47318 .46739 .47886 .49207 .48946 .48903 .48371 .46761 Mtetra
.602 .494 .703 r
.48371 .46761 .48946 .48903 .50012 .48398 .49433 .4647 Mtetra
.639 .53 .714 r
.49433 .4647 .50012 .48398 .51081 .4784 .505 .45975 Mtetra
.617 .522 .724 r
.505 .45975 .51081 .4784 .52153 .47501 .51571 .45632 Mtetra
.59 .506 .728 r
.51571 .45632 .52153 .47501 .53229 .47379 .52646 .4544 Mtetra
.623 .52 .717 r
.52646 .4544 .53229 .47379 .54311 .47205 .53725 .45044 Mtetra
.658 .528 .694 r
.53725 .45044 .54311 .47205 .55397 .4683 .54806 .44333 Mtetra
.686 .53 .669 r
.54806 .44333 .55397 .4683 .56482 .46064 .55885 .43221 Mtetra
.695 .524 .651 r
.55885 .43221 .56482 .46064 .57562 .44891 .56958 .4182 Mtetra
.689 .513 .644 r
.56958 .4182 .57562 .44891 .58633 .43329 .58029 .40383 Mtetra
.68 .511 .65 r
.58029 .40383 .58633 .43329 .59697 .41589 .591 .39122 Mtetra
.653 .51 .676 r
.591 .39122 .59697 .41589 .6076 .40043 .60181 .38344 Mtetra
.607 .531 .743 r
.60181 .38344 .6076 .40043 .6183 .38853 .61277 .38074 Mtetra
.387 .582 .919 r
.61277 .38074 .6183 .38853 .62917 .382 .62392 .38286 Mtetra
.513 0 0 r
.62392 .38286 .62917 .382 .64023 .38042 .63528 .3882 Mtetra
.613 .164 .162 r
.63528 .3882 .64023 .38042 .65152 .38311 .64677 .39445 Mtetra
.594 .187 .24 r
.64677 .39445 .65152 .38311 .663 .38827 .65835 .40002 Mtetra
.532 .128 .221 r
.65835 .40002 .663 .38827 .67459 .39335 .66992 .4027 Mtetra
.428 0 .114 r
.66992 .4027 .67459 .39335 .68622 .39727 .68143 .40242 Mtetra
.133 0 0 r
.68143 .40242 .68622 .39727 .69782 .39859 .69285 .39905 Mtetra
.523 .919 .85 r
.69285 .39905 .69782 .39859 .70936 .39749 .70419 .39344 Mtetra
.765 .885 .931 r
.70419 .39344 .70936 .39749 .72082 .39406 .71549 .38655 Mtetra
.76 .766 .858 r
.71549 .38655 .72082 .39406 .73223 .38901 .72678 .37908 Mtetra
.73 .698 .82 r
.72678 .37908 .73223 .38901 .74362 .38314 .73811 .37195 Mtetra
.709 .666 .805 r
.73811 .37195 .74362 .38314 .75501 .37691 .7495 .36535 Mtetra
.688 .65 .807 r
.7495 .36535 .75501 .37691 .76646 .37096 .76098 .35965 Mtetra
.673 .648 .817 r
.76098 .35965 .76646 .37096 .77796 .36538 .77256 .3547 Mtetra
.66 .654 .834 r
.77256 .3547 .77796 .36538 .78955 .36038 .78423 .35045 Mtetra
.65 .666 .853 r
.78423 .35045 .78955 .36038 .80122 .35583 .79599 .34667 Mtetra
.644 .683 .872 r
.79599 .34667 .80122 .35583 .81297 .35168 .80783 .34316 Mtetra
.639 .699 .889 r
.80783 .34316 .81297 .35168 .82479 .34779 .81973 .33983 Mtetra
.636 .714 .904 r
.81973 .33983 .82479 .34779 .83667 .34405 .83169 .33655 Mtetra
.637 .73 .915 r
.83169 .33655 .83667 .34405 .84861 .34035 .8437 .33321 Mtetra
.685 .758 .907 r
.20671 .53168 .21326 .53739 .22285 .53379 .21634 .52783 Mtetra
.688 .751 .899 r
.21634 .52783 .22285 .53379 .23248 .53014 .22602 .52384 Mtetra
.69 .741 .891 r
.22602 .52384 .23248 .53014 .24213 .52654 .23573 .51976 Mtetra
.689 .727 .879 r
.23573 .51976 .24213 .52654 .2518 .52311 .24548 .51563 Mtetra
.686 .708 .864 r
.24548 .51563 .2518 .52311 .26149 .51994 .25526 .51145 Mtetra
.675 .679 .846 r
.25526 .51145 .26149 .51994 .27117 .51723 .26505 .50749 Mtetra
.657 .646 .827 r
.26505 .50749 .27117 .51723 .28085 .51518 .27485 .50392 Mtetra
.631 .606 .807 r
.27485 .50392 .28085 .51518 .29051 .51387 .28463 .50107 Mtetra
.599 .567 .789 r
.28463 .50107 .29051 .51387 .30016 .51344 .29437 .49927 Mtetra
.566 .53 .775 r
.29437 .49927 .30016 .51344 .30983 .51354 .30408 .49863 Mtetra
.527 .5 .769 r
.30408 .49863 .30983 .51354 .31953 .51396 .31375 .49936 Mtetra
.495 .486 .776 r
.31375 .49936 .31953 .51396 .32933 .51386 .32342 .50106 Mtetra
.453 .49 .807 r
.32342 .50106 .32933 .51386 .33925 .51252 .33312 .50347 Mtetra
.404 .549 .886 r
.33312 .50347 .33925 .51252 .34933 .509 .34291 .50561 Mtetra
.213 .658 .95 r
.34291 .50561 .34933 .509 .35959 .50248 .35282 .50667 Mtetra
.222 0 0 r
.35282 .50667 .35959 .50248 .37001 .49306 .3629 .50554 Mtetra
.307 0 .131 r
.3629 .50554 .37001 .49306 .38056 .48079 .37318 .50126 Mtetra
.313 0 .252 r
.37318 .50126 .38056 .48079 .39111 .46782 .38363 .49349 Mtetra
.279 0 .281 r
.38363 .49349 .39111 .46782 .40162 .45571 .39425 .48203 Mtetra
.232 0 .267 r
.39425 .48203 .40162 .45571 .412 .44675 .40493 .46842 Mtetra
.107 0 .176 r
.40493 .46842 .412 .44675 .42223 .44251 .41563 .45371 Mtetra
0 0 0 r
.41563 .45371 .42223 .44251 .43236 .44327 .42629 .43913 Mtetra
.88 .83 .794 r
.42629 .43913 .43236 .44327 .44243 .44885 .43688 .4258 Mtetra
.689 .537 .675 r
.43688 .4258 .44243 .44885 .45255 .45618 .44739 .41524 Mtetra
.613 .439 .623 r
.44739 .41524 .45255 .45618 .46279 .4632 .45782 .40785 Mtetra
.588 .405 .601 r
.45782 .40785 .46279 .4632 .47318 .46739 .46824 .40169 Mtetra
.578 .39 .59 r
.46824 .40169 .47318 .46739 .48371 .46761 .47868 .39607 Mtetra
.573 .382 .585 r
.47868 .39607 .48371 .46761 .49433 .4647 .48914 .39101 Mtetra
.569 .378 .583 r
.48914 .39101 .49433 .4647 .505 .45975 .49963 .38652 Mtetra
.564 .375 .583 r
.49963 .38652 .505 .45975 .51571 .45632 .51014 .38301 Mtetra
.559 .371 .583 r
.51014 .38301 .51571 .45632 .52646 .4544 .5207 .38046 Mtetra
.556 .369 .582 r
.5207 .38046 .52646 .4544 .53725 .45044 .5313 .37849 Mtetra
.553 .368 .584 r
.5313 .37849 .53725 .45044 .54806 .44333 .54195 .3771 Mtetra
.551 .37 .588 r
.54195 .3771 .54806 .44333 .55885 .43221 .55267 .37625 Mtetra
.545 .373 .599 r
.55267 .37625 .55885 .43221 .56958 .4182 .56346 .37665 Mtetra
.515 .37 .623 r
.56346 .37665 .56958 .4182 .58029 .40383 .57437 .38028 Mtetra
.429 .371 .691 r
.57437 .38028 .58029 .40383 .591 .39122 .58543 .38673 Mtetra
0 .179 .637 r
.58543 .38673 .591 .39122 .60181 .38344 .59663 .39448 Mtetra
.64 .233 .258 r
.59663 .39448 .60181 .38344 .61277 .38074 .60795 .4024 Mtetra
.598 .258 .365 r
.60795 .4024 .61277 .38074 .62392 .38286 .61937 .40925 Mtetra
.567 .247 .385 r
.61937 .40925 .62392 .38286 .63528 .3882 .63083 .41395 Mtetra
.522 .204 .369 r
.63083 .41395 .63528 .3882 .64677 .39445 .64226 .4149 Mtetra
.452 .12 .311 r
.64226 .4149 .64677 .39445 .65835 .40002 .65363 .41228 Mtetra
.27 0 .123 r
.65363 .41228 .65835 .40002 .66992 .4027 .66491 .40644 Mtetra
0 0 0 r
.66491 .40644 .66992 .4027 .68143 .40242 .67612 .39833 Mtetra
.828 .887 .885 r
.67612 .39833 .68143 .40242 .69285 .39905 .68728 .38909 Mtetra
.772 .712 .796 r
.68728 .38909 .69285 .39905 .70419 .39344 .69844 .37955 Mtetra
.724 .632 .755 r
.69844 .37955 .70419 .39344 .71549 .38655 .70964 .37073 Mtetra
.696 .597 .741 r
.70964 .37073 .71549 .38655 .72678 .37908 .72091 .36288 Mtetra
.672 .581 .744 r
.72091 .36288 .72678 .37908 .73811 .37195 .73229 .35645 Mtetra
.656 .579 .757 r
.73229 .35645 .73811 .37195 .7495 .36535 .74378 .35121 Mtetra
.642 .588 .779 r
.74378 .35121 .7495 .36535 .76098 .35965 .75539 .34704 Mtetra
.631 .606 .806 r
.75539 .34704 .76098 .35965 .77256 .3547 .7671 .34363 Mtetra
.625 .631 .836 r
.7671 .34363 .77256 .3547 .78423 .35045 .7789 .34063 Mtetra
.62 .656 .864 r
.7789 .34063 .78423 .35045 .79599 .34667 .79077 .33784 Mtetra
.622 .683 .887 r
.79077 .33784 .79599 .34667 .80783 .34316 .80269 .33501 Mtetra
.622 .703 .903 r
.80269 .33501 .80783 .34316 .81973 .33983 .81467 .33213 Mtetra
.624 .719 .915 r
.81467 .33213 .81973 .33983 .83169 .33655 .82669 .32915 Mtetra
.628 .731 .922 r
.82669 .32915 .83169 .33655 .8437 .33321 .83876 .32602 Mtetra
.682 .757 .908 r
.20012 .52592 .20671 .53168 .21634 .52783 .20976 .52212 Mtetra
.687 .761 .907 r
.20976 .52212 .21634 .52783 .22602 .52384 .21946 .51817 Mtetra
.694 .764 .906 r
.21946 .51817 .22602 .52384 .23573 .51976 .2292 .51403 Mtetra
.701 .764 .901 r
.2292 .51403 .23573 .51976 .24548 .51563 .23899 .50967 Mtetra
.709 .759 .891 r
.23899 .50967 .24548 .51563 .25526 .51145 .24883 .50498 Mtetra
.711 .744 .878 r
.24883 .50498 .25526 .51145 .26505 .50749 .25871 .50015 Mtetra
.707 .719 .859 r
.25871 .50015 .26505 .50749 .27485 .50392 .26863 .49521 Mtetra
.69 .681 .836 r
.26863 .49521 .27485 .50392 .28463 .50107 .27855 .49058 Mtetra
.665 .636 .811 r
.27855 .49058 .28463 .50107 .29437 .49927 .28846 .48653 Mtetra
.63 .584 .784 r
.28846 .48653 .29437 .49927 .30408 .49863 .29833 .4835 Mtetra
.589 .533 .759 r
.29833 .4835 .30408 .49863 .31375 .49936 .30814 .48191 Mtetra
.551 .487 .737 r
.30814 .48191 .31375 .49936 .32342 .50106 .3179 .48186 Mtetra
.511 .448 .722 r
.3179 .48186 .32342 .50106 .33312 .50347 .32761 .48356 Mtetra
.482 .424 .716 r
.32761 .48356 .33312 .50347 .34291 .50561 .33732 .4865 Mtetra
.454 .414 .724 r
.33732 .4865 .34291 .50561 .35282 .50667 .34706 .49032 Mtetra
.441 .435 .756 r
.34706 .49032 .35282 .50667 .3629 .50554 .35689 .4939 Mtetra
.439 .507 .832 r
.35689 .4939 .3629 .50554 .37318 .50126 .36686 .49626 Mtetra
.457 .722 .982 r
.36686 .49626 .37318 .50126 .38363 .49349 .37702 .49597 Mtetra
.265 .755 .67 r
.37702 .49597 .38363 .49349 .39425 .48203 .38739 .49195 Mtetra
.016 0 0 r
.38739 .49195 .39425 .48203 .40493 .46842 .39794 .48432 Mtetra
.08 0 .083 r
.39794 .48432 .40493 .46842 .41563 .45371 .40862 .47321 Mtetra
.097 0 .145 r
.40862 .47321 .41563 .45371 .42629 .43913 .41937 .45983 Mtetra
.093 0 .159 r
.41937 .45983 .42629 .43913 .43688 .4258 .43012 .44539 Mtetra
.131 0 .166 r
.43012 .44539 .43688 .4258 .44739 .41524 .4408 .43262 Mtetra
.198 0 .169 r
.4408 .43262 .44739 .41524 .45782 .40785 .4514 .42291 Mtetra
.267 0 .165 r
.4514 .42291 .45782 .40785 .46824 .40169 .46193 .41619 Mtetra
.363 0 .201 r
.46193 .41619 .46824 .40169 .47868 .39607 .47244 .41229 Mtetra
.434 .077 .259 r
.47244 .41229 .47868 .39607 .48914 .39101 .48296 .41017 Mtetra
.466 .126 .305 r
.48296 .41017 .48914 .39101 .49963 .38652 .49353 .40869 Mtetra
.438 .116 .321 r
.49353 .40869 .49963 .38652 .51014 .38301 .50416 .40517 Mtetra
.396 .078 .306 r
.50416 .40517 .51014 .38301 .5207 .38046 .51485 .39961 Mtetra
.387 .054 .275 r
.51485 .39961 .5207 .38046 .5313 .37849 .52556 .39468 Mtetra
.408 .053 .247 r
.52556 .39468 .5313 .37849 .54195 .3771 .53631 .39154 Mtetra
.471 .096 .247 r
.53631 .39154 .54195 .3771 .55267 .37625 .54712 .39125 Mtetra
.541 .168 .283 r
.54712 .39125 .55267 .37625 .56346 .37665 .55803 .39398 Mtetra
.593 .233 .329 r
.55803 .39398 .56346 .37665 .57437 .38028 .56907 .39983 Mtetra
.611 .262 .354 r
.56907 .39983 .57437 .38028 .58543 .38673 .58025 .4074 Mtetra
.595 .251 .356 r
.58025 .4074 .58543 .38673 .59663 .39448 .59152 .41394 Mtetra
.565 .216 .336 r
.59152 .41394 .59663 .39448 .60795 .4024 .60286 .41821 Mtetra
.499 .131 .272 r
.60286 .41821 .60795 .4024 .61937 .40925 .6142 .41895 Mtetra
.324 0 .069 r
.6142 .41895 .61937 .40925 .63083 .41395 .6255 .41603 Mtetra
.481 .882 .73 r
.6255 .41603 .63083 .41395 .64226 .4149 .63672 .4093 Mtetra
.819 .831 .858 r
.63672 .4093 .64226 .4149 .65363 .41228 .64786 .39982 Mtetra
.763 .667 .757 r
.64786 .39982 .65363 .41228 .66491 .40644 .65896 .38909 Mtetra
.726 .599 .714 r
.65896 .38909 .66491 .40644 .67612 .39833 .67003 .37807 Mtetra
.698 .562 .698 r
.67003 .37807 .67612 .39833 .68728 .38909 .68115 .36794 Mtetra
.679 .546 .696 r
.68115 .36794 .68728 .38909 .69844 .37955 .69233 .35906 Mtetra
.66 .539 .706 r
.69233 .35906 .69844 .37955 .70964 .37073 .70362 .35197 Mtetra
.645 .543 .724 r
.70362 .35197 .70964 .37073 .72091 .36288 .71503 .34646 Mtetra
.63 .555 .752 r
.71503 .34646 .72091 .36288 .73229 .35645 .72656 .34243 Mtetra
.617 .577 .787 r
.72656 .34243 .73229 .35645 .74378 .35121 .73822 .33946 Mtetra
.606 .608 .827 r
.73822 .33946 .74378 .35121 .75539 .34704 .74997 .33709 Mtetra
.597 .642 .866 r
.74997 .33709 .75539 .34704 .7671 .34363 .76181 .33504 Mtetra
.597 .678 .897 r
.76181 .33504 .7671 .34363 .7789 .34063 .7737 .33289 Mtetra
.599 .705 .918 r
.7737 .33289 .7789 .34063 .79077 .33784 .78564 .33059 Mtetra
.609 .726 .929 r
.78564 .33059 .79077 .33784 .80269 .33501 .79762 .32795 Mtetra
.617 .738 .932 r
.79762 .32795 .80269 .33501 .81467 .33213 .80963 .32507 Mtetra
.624 .742 .932 r
.80963 .32507 .81467 .33213 .82669 .32915 .82169 .322 Mtetra
.63 .742 .929 r
.82169 .322 .82669 .32915 .83876 .32602 .83378 .31877 Mtetra
.669 .755 .914 r
.19348 .52013 .20012 .52592 .20976 .52212 .20311 .51664 Mtetra
.672 .767 .921 r
.20311 .51664 .20976 .52212 .21946 .51817 .21279 .51307 Mtetra
.68 .782 .928 r
.21279 .51307 .21946 .51817 .2292 .51403 .22252 .5093 Mtetra
.692 .799 .931 r
.22252 .5093 .2292 .51403 .23899 .50967 .23231 .50521 Mtetra
.709 .812 .929 r
.23231 .50521 .23899 .50967 .24883 .50498 .24217 .50068 Mtetra
.726 .821 .923 r
.24217 .50068 .24883 .50498 .25871 .50015 .2521 .49565 Mtetra
.745 .816 .908 r
.2521 .49565 .25871 .50015 .26863 .49521 .2621 .49002 Mtetra
.75 .793 .887 r
.2621 .49002 .26863 .49521 .27855 .49058 .27215 .48402 Mtetra
.745 .751 .857 r
.27215 .48402 .27855 .49058 .28846 .48653 .28224 .47777 Mtetra
.721 .692 .822 r
.28224 .47777 .28846 .48653 .29833 .4835 .29233 .47176 Mtetra
.685 .626 .783 r
.29233 .47176 .29833 .4835 .30814 .48191 .3024 .46637 Mtetra
.643 .559 .744 r
.3024 .46637 .30814 .48191 .3179 .48186 .31242 .46211 Mtetra
.6 .499 .711 r
.31242 .46211 .3179 .48186 .32761 .48356 .32237 .45947 Mtetra
.564 .451 .684 r
.32237 .45947 .32761 .48356 .33732 .4865 .33225 .45862 Mtetra
.531 .413 .664 r
.33225 .45862 .33732 .4865 .34706 .49032 .34208 .45981 Mtetra
.505 .386 .652 r
.34208 .45981 .34706 .49032 .35689 .4939 .35188 .46281 Mtetra
.48 .367 .648 r
.35188 .46281 .35689 .4939 .36686 .49626 .36167 .46746 Mtetra
.459 .362 .657 r
.36167 .46746 .36686 .49626 .37702 .49597 .37151 .47294 Mtetra
.43 .371 .691 r
.37151 .47294 .37702 .49597 .38739 .49195 .38143 .47855 Mtetra
.354 .427 .798 r
.38143 .47855 .38739 .49195 .39794 .48432 .39149 .48325 Mtetra
.284 0 0 r
.39149 .48325 .39794 .48432 .40862 .47321 .4017 .48634 Mtetra
.518 .131 .247 r
.4017 .48634 .40862 .47321 .41937 .45983 .41204 .48814 Mtetra
.519 .209 .382 r
.41204 .48814 .41937 .45983 .43012 .44539 .42248 .48878 Mtetra
.518 .237 .428 r
.42248 .48878 .43012 .44539 .4408 .43262 .43302 .48848 Mtetra
.52 .252 .449 r
.43302 .48848 .4408 .43262 .4514 .42291 .44362 .48784 Mtetra
.534 .271 .462 r
.44362 .48784 .4514 .42291 .46193 .41619 .45425 .48917 Mtetra
.546 .285 .471 r
.45425 .48917 .46193 .41619 .47244 .41229 .4649 .49281 Mtetra
.547 .289 .476 r
.4649 .49281 .47244 .41229 .48296 .41017 .47564 .49683 Mtetra
.54 .285 .478 r
.47564 .49683 .48296 .41017 .49353 .40869 .48649 .49934 Mtetra
.515 .266 .475 r
.48649 .49934 .49353 .40869 .50416 .40517 .49747 .49588 Mtetra
.488 .244 .47 r
.49747 .49588 .50416 .40517 .51485 .39961 .50853 .48644 Mtetra
.479 .235 .466 r
.50853 .48644 .51485 .39961 .52556 .39468 .51959 .47547 Mtetra
.476 .23 .462 r
.51959 .47547 .52556 .39468 .53631 .39154 .53065 .46485 Mtetra
.483 .232 .458 r
.53065 .46485 .53631 .39154 .54712 .39125 .54171 .45653 Mtetra
.488 .232 .452 r
.54171 .45653 .54712 .39125 .55803 .39398 .5528 .45017 Mtetra
.478 .217 .439 r
.5528 .45017 .55803 .39398 .56907 .39983 .56392 .44348 Mtetra
.449 .179 .411 r
.56392 .44348 .56907 .39983 .58025 .4074 .57504 .43581 Mtetra
.375 .084 .337 r
.57504 .43581 .58025 .4074 .59152 .41394 .58616 .42694 Mtetra
.079 0 .046 r
.58616 .42694 .59152 .41394 .60286 .41821 .59726 .41675 Mtetra
.885 .954 .845 r
.59726 .41675 .60286 .41821 .6142 .41895 .60832 .40488 Mtetra
.772 .651 .729 r
.60832 .40488 .6142 .41895 .6255 .41603 .61933 .39206 Mtetra
.704 .546 .671 r
.61933 .39206 .6255 .41603 .63672 .4093 .63033 .37935 Mtetra
.672 .505 .65 r
.63033 .37935 .63672 .4093 .64786 .39982 .64134 .36744 Mtetra
.65 .484 .645 r
.64134 .36744 .64786 .39982 .65896 .38909 .65241 .3572 Mtetra
.636 .475 .648 r
.65241 .3572 .65896 .38909 .67003 .37807 .66356 .3488 Mtetra
.622 .474 .66 r
.66356 .3488 .67003 .37807 .68115 .36794 .67481 .34248 Mtetra
.61 .482 .68 r
.67481 .34248 .68115 .36794 .69233 .35906 .68619 .338 Mtetra
.597 .497 .712 r
.68619 .338 .69233 .35906 .70362 .35197 .6977 .33518 Mtetra
.583 .524 .755 r
.6977 .33518 .70362 .35197 .71503 .34646 .70934 .33353 Mtetra
.568 .567 .812 r
.70934 .33353 .71503 .34646 .72656 .34243 .72107 .33253 Mtetra
.551 .62 .874 r
.72107 .33253 .72656 .34243 .73822 .33946 .7329 .33178 Mtetra
.543 .68 .928 r
.7329 .33178 .73822 .33946 .74997 .33709 .74478 .33078 Mtetra
.54 .728 .961 r
.74478 .33078 .74997 .33709 .76181 .33504 .7567 .3294 Mtetra
.56 .764 .974 r
.7567 .3294 .76181 .33504 .7737 .33289 .76864 .3274 Mtetra
.583 .781 .974 r
.76864 .3274 .7737 .33289 .78564 .33059 .78061 .32489 Mtetra
.608 .785 .966 r
.78061 .32489 .78564 .33059 .79762 .32795 .7926 .32191 Mtetra
.626 .781 .955 r
.7926 .32191 .79762 .32795 .80963 .32507 .80461 .3186 Mtetra
.637 .77 .943 r
.80461 .3186 .80963 .32507 .82169 .322 .81666 .31508 Mtetra
.642 .757 .932 r
.81666 .31508 .82169 .322 .83378 .31877 .82876 .31146 Mtetra
.653 .751 .921 r
.18679 .51429 .19348 .52013 .20311 .51664 .19641 .51118 Mtetra
.651 .764 .932 r
.19641 .51118 .20311 .51664 .21279 .51307 .20607 .50808 Mtetra
.653 .783 .943 r
.20607 .50808 .21279 .51307 .22252 .5093 .21577 .50489 Mtetra
.66 .807 .954 r
.21577 .50489 .22252 .5093 .23231 .50521 .22552 .50147 Mtetra
.669 .835 .963 r
.22552 .50147 .23231 .50521 .24217 .50068 .23534 .49775 Mtetra
.686 .87 .968 r
.23534 .49775 .24217 .50068 .2521 .49565 .24523 .49351 Mtetra
.71 .903 .964 r
.24523 .49351 .2521 .49565 .2621 .49002 .25521 .48857 Mtetra
.734 .929 .954 r
.25521 .48857 .2621 .49002 .27215 .48402 .26527 .48289 Mtetra
.766 .941 .939 r
.26527 .48289 .27215 .48402 .28224 .47777 .27542 .47638 Mtetra
.788 .932 .927 r
.27542 .47638 .28224 .47777 .29233 .47176 .28563 .46933 Mtetra
.801 .895 .91 r
.28563 .46933 .29233 .47176 .3024 .46637 .29587 .46194 Mtetra
.785 .826 .884 r
.29587 .46194 .3024 .46637 .31242 .46211 .30612 .45475 Mtetra
.744 .734 .843 r
.30612 .45475 .31242 .46211 .32237 .45947 .31633 .44822 Mtetra
.688 .636 .793 r
.31633 .44822 .32237 .45947 .33225 .45862 .32649 .44285 Mtetra
.631 .551 .746 r
.32649 .44285 .33225 .45862 .34208 .45981 .33659 .43912 Mtetra
.583 .483 .707 r
.33659 .43912 .34208 .45981 .35188 .46281 .34661 .43732 Mtetra
.541 .43 .677 r
.34661 .43732 .35188 .46281 .36167 .46746 .35657 .43774 Mtetra
.509 .392 .655 r
.35657 .43774 .36167 .46746 .37151 .47294 .36648 .44032 Mtetra
.482 .364 .642 r
.36648 .44032 .37151 .47294 .38143 .47855 .37638 .44495 Mtetra
.471 .354 .638 r
.37638 .44495 .38143 .47855 .39149 .48325 .38633 .45046 Mtetra
.468 .355 .642 r
.38633 .45046 .39149 .48325 .4017 .48634 .39637 .45606 Mtetra
.465 .362 .653 r
.39637 .45606 .4017 .48634 .41204 .48814 .40651 .46144 Mtetra
.47 .38 .672 r
.40651 .46144 .41204 .48814 .42248 .48878 .41678 .46596 Mtetra
.509 .427 .699 r
.41678 .46596 .42248 .48878 .43302 .48848 .42721 .46803 Mtetra
.561 .476 .716 r
.42721 .46803 .43302 .48848 .44362 .48784 .4378 .46735 Mtetra
.568 .48 .716 r
.4378 .46735 .44362 .48784 .45425 .48917 .44845 .46633 Mtetra
.559 .46 .699 r
.44845 .46633 .45425 .48917 .4649 .49281 .45915 .4657 Mtetra
.56 .44 .673 r
.45915 .4657 .4649 .49281 .47564 .49683 .46991 .46489 Mtetra
.565 .427 .652 r
.46991 .46489 .47564 .49683 .48649 .49934 .48075 .46344 Mtetra
.584 .43 .639 r
.48075 .46344 .48649 .49934 .49747 .49588 .49166 .45993 Mtetra
.603 .443 .638 r
.49166 .45993 .49747 .49588 .50853 .48644 .50263 .45436 Mtetra
.616 .462 .65 r
.50263 .45436 .50853 .48644 .51959 .47547 .51363 .44814 Mtetra
.629 .486 .668 r
.51363 .44814 .51959 .47547 .53065 .46485 .52466 .44172 Mtetra
.637 .51 .69 r
.52466 .44172 .53065 .46485 .54171 .45653 .53571 .43568 Mtetra
.65 .53 .704 r
.53571 .43568 .54171 .45653 .5528 .45017 .54679 .4293 Mtetra
.684 .55 .697 r
.54679 .4293 .5528 .45017 .56392 .44348 .55787 .42012 Mtetra
.698 .546 .677 r
.55787 .42012 .56392 .44348 .57504 .43581 .56892 .40844 Mtetra
.688 .523 .658 r
.56892 .40844 .57504 .43581 .58616 .42694 .57994 .39586 Mtetra
.676 .504 .646 r
.57994 .39586 .58616 .42694 .59726 .41675 .59094 .38301 Mtetra
.667 .491 .638 r
.59094 .38301 .59726 .41675 .60832 .40488 .60193 .37023 Mtetra
.657 .483 .636 r
.60193 .37023 .60832 .40488 .61933 .39206 .61291 .35831 Mtetra
.643 .475 .641 r
.61291 .35831 .61933 .39206 .63033 .37935 .62396 .34847 Mtetra
.631 .475 .652 r
.62396 .34847 .63033 .37935 .64134 .36744 .63507 .34081 Mtetra
.618 .481 .672 r
.63507 .34081 .64134 .36744 .65241 .3572 .6463 .33541 Mtetra
.604 .496 .704 r
.6463 .33541 .65241 .3572 .66356 .3488 .65764 .33198 Mtetra
.584 .524 .754 r
.65764 .33198 .66356 .3488 .67481 .34248 .6691 .33024 Mtetra
.553 .57 .825 r
.6691 .33024 .67481 .34248 .68619 .338 .68069 .32971 Mtetra
.497 .635 .915 r
.68069 .32971 .68619 .338 .6977 .33518 .69239 .32985 Mtetra
.403 .695 .98 r
.69239 .32985 .6977 .33518 .70934 .33353 .70417 .33023 Mtetra
.314 .729 .976 r
.70417 .33023 .70934 .33353 .72107 .33253 .71602 .33025 Mtetra
.281 .745 .948 r
.71602 .33025 .72107 .33253 .7329 .33178 .72791 .32973 Mtetra
.343 .79 .955 r
.72791 .32973 .7329 .33178 .74478 .33078 .73981 .32835 Mtetra
.437 .832 .982 r
.73981 .32835 .74478 .33078 .7567 .3294 .75173 .32622 Mtetra
.535 .854 .997 r
.75173 .32622 .7567 .3294 .76864 .3274 .76366 .32335 Mtetra
.598 .848 .992 r
.76366 .32335 .76864 .3274 .78061 .32489 .7756 .31994 Mtetra
.632 .826 .975 r
.7756 .31994 .78061 .32489 .7926 .32191 .78757 .3162 Mtetra
.65 .805 .957 r
.78757 .3162 .7926 .32191 .80461 .3186 .79957 .31224 Mtetra
.657 .785 .942 r
.79957 .31224 .80461 .3186 .81666 .31508 .81161 .30817 Mtetra
.658 .766 .93 r
.81161 .30817 .81666 .31508 .82876 .31146 .82371 .3041 Mtetra
.633 .746 .929 r
.18006 .50842 .18679 .51429 .19641 .51118 .18966 .50573 Mtetra
.626 .759 .943 r
.18966 .50573 .19641 .51118 .20607 .50808 .19928 .50314 Mtetra
.618 .777 .957 r
.19928 .50314 .20607 .50808 .21577 .50489 .20894 .5006 Mtetra
.609 .801 .973 r
.20894 .5006 .21577 .50489 .22552 .50147 .21864 .49806 Mtetra
.589 .831 .99 r
.21864 .49806 .22552 .50147 .23534 .49775 .22837 .49553 Mtetra
.567 .87 .995 r
.22837 .49553 .23534 .49775 .24523 .49351 .23817 .49274 Mtetra
.528 .898 .966 r
.23817 .49274 .24523 .49351 .25521 .48857 .24805 .48951 Mtetra
.468 .892 .874 r
.24805 .48951 .25521 .48857 .26527 .48289 .25802 .48555 Mtetra
.414 .853 .745 r
.25802 .48555 .26527 .48289 .27542 .47638 .2681 .48059 Mtetra
.369 .799 .62 r
.2681 .48059 .27542 .47638 .28563 .46933 .27829 .4746 Mtetra
0 0 0 r
.27829 .4746 .28563 .46933 .29587 .46194 .28858 .46745 Mtetra
.443 .819 .572 r
.28858 .46745 .29587 .46194 .30612 .45475 .29894 .45946 Mtetra
.578 .908 .671 r
.29894 .45946 .30612 .45475 .31633 .44822 .30936 .45081 Mtetra
.745 .993 .822 r
.30936 .45081 .31633 .44822 .32649 .44285 .31979 .44197 Mtetra
.83 .947 .898 r
.31979 .44197 .32649 .44285 .33659 .43912 .33022 .43331 Mtetra
.79 .787 .849 r
.33022 .43331 .33659 .43912 .34661 .43732 .34062 .42519 Mtetra
.715 .637 .769 r
.34062 .42519 .34661 .43732 .35657 .43774 .35099 .41794 Mtetra
.649 .53 .705 r
.35099 .41794 .35657 .43774 .36648 .44032 .36129 .4121 Mtetra
.602 .46 .661 r
.36129 .4121 .36648 .44032 .37638 .44495 .37154 .40798 Mtetra
.576 .419 .632 r
.37154 .40798 .37638 .44495 .38633 .45046 .38178 .40507 Mtetra
.562 .395 .612 r
.38178 .40507 .38633 .45046 .39637 .45606 .39201 .40303 Mtetra
.556 .382 .6 r
.39201 .40303 .39637 .45606 .40651 .46144 .40229 .40127 Mtetra
.557 .376 .591 r
.40229 .40127 .40651 .46144 .41678 .46596 .41263 .39902 Mtetra
.568 .38 .586 r
.41263 .39902 .41678 .46596 .42721 .46803 .4231 .39444 Mtetra
.581 .385 .581 r
.4231 .39444 .42721 .46803 .4378 .46735 .43368 .38676 Mtetra
.588 .387 .577 r
.43368 .38676 .4378 .46735 .44845 .46633 .44434 .37662 Mtetra
.589 .385 .572 r
.44434 .37662 .44845 .46633 .45915 .4657 .45504 .36487 Mtetra
.583 .377 .567 r
.45504 .36487 .45915 .4657 .46991 .46489 .46571 .35332 Mtetra
.572 .365 .562 r
.46571 .35332 .46991 .46489 .48075 .46344 .47635 .34384 Mtetra
.551 .347 .558 r
.47635 .34384 .48075 .46344 .49166 .45993 .48691 .34021 Mtetra
.531 .332 .556 r
.48691 .34021 .49166 .45993 .50263 .45436 .49747 .34244 Mtetra
.523 .328 .558 r
.49747 .34244 .50263 .45436 .51363 .44814 .50809 .34676 Mtetra
.521 .329 .562 r
.50809 .34676 .51363 .44814 .52466 .44172 .51881 .35132 Mtetra
.526 .337 .567 r
.51881 .35132 .52466 .44172 .53571 .43568 .52963 .35428 Mtetra
.538 .35 .574 r
.52963 .35428 .53571 .43568 .54679 .4293 .54052 .35478 Mtetra
.555 .365 .579 r
.54052 .35478 .54679 .4293 .55787 .42012 .55146 .35216 Mtetra
.569 .38 .585 r
.55146 .35216 .55787 .42012 .56892 .40844 .56242 .34718 Mtetra
.575 .389 .592 r
.56242 .34718 .56892 .40844 .57994 .39586 .57341 .3417 Mtetra
.579 .398 .601 r
.57341 .3417 .57994 .39586 .59094 .38301 .58443 .33649 Mtetra
.578 .407 .613 r
.58443 .33649 .59094 .38301 .60193 .37023 .59551 .33217 Mtetra
.575 .419 .632 r
.59551 .33217 .60193 .37023 .61291 .35831 .60666 .32907 Mtetra
.564 .435 .663 r
.60666 .32907 .61291 .35831 .62396 .34847 .61792 .32774 Mtetra
.545 .466 .718 r
.61792 .32774 .62396 .34847 .63507 .34081 .62928 .32785 Mtetra
.505 .53 .816 r
.62928 .32785 .63507 .34081 .6463 .33541 .64075 .32887 Mtetra
.365 .625 .952 r
.64075 .32887 .6463 .33541 .65764 .33198 .65233 .33044 Mtetra
0 .534 .783 r
.65233 .33044 .65764 .33198 .6691 .33024 .664 .33223 Mtetra
.303 0 0 r
.664 .33223 .6691 .33024 .68069 .32971 .67575 .33384 Mtetra
.354 0 0 r
.67575 .33384 .68069 .32971 .69239 .32985 .68756 .33478 Mtetra
.333 0 0 r
.68756 .33478 .69239 .32985 .70417 .33023 .6994 .33486 Mtetra
.25 0 0 r
.6994 .33486 .70417 .33023 .71602 .33025 .71125 .33377 Mtetra
.108 0 0 r
.71125 .33377 .71602 .33025 .72791 .32973 .72311 .3316 Mtetra
0 0 0 r
.72311 .3316 .72791 .32973 .73981 .32835 .73496 .3284 Mtetra
.386 .848 .846 r
.73496 .3284 .73981 .32835 .75173 .32622 .74681 .32444 Mtetra
.567 .915 .965 r
.74681 .32444 .75173 .32622 .76366 .32335 .75867 .32001 Mtetra
.648 .897 .983 r
.75867 .32001 .76366 .32335 .7756 .31994 .77057 .31531 Mtetra
.671 .855 .97 r
.77057 .31531 .7756 .31994 .78757 .3162 .7825 .31061 Mtetra
.678 .821 .952 r
.7825 .31061 .78757 .3162 .79957 .31224 .79449 .3059 Mtetra
.678 .795 .937 r
.79449 .3059 .79957 .31224 .81161 .30817 .80652 .30125 Mtetra
.674 .775 .926 r
.80652 .30125 .81161 .30817 .82371 .3041 .81861 .29669 Mtetra
.6 .736 .94 r
.17328 .5025 .18006 .50842 .18966 .50573 .18283 .50045 Mtetra
.586 .756 .959 r
.18283 .50045 .18966 .50573 .19928 .50314 .19241 .49851 Mtetra
.566 .776 .977 r
.19241 .49851 .19928 .50314 .20894 .5006 .20202 .49669 Mtetra
.535 .795 .993 r
.20202 .49669 .20894 .5006 .21864 .49806 .21166 .49503 Mtetra
.477 .808 1 r
.21166 .49503 .21864 .49806 .22837 .49553 .22132 .4936 Mtetra
.401 .812 .978 r
.22132 .4936 .22837 .49553 .23817 .49274 .23103 .4922 Mtetra
.28 .775 .889 r
.23103 .4922 .23817 .49274 .24805 .48951 .24079 .49076 Mtetra
.141 .683 .709 r
.24079 .49076 .24805 .48951 .25802 .48555 .25062 .48893 Mtetra
0 0 0 r
.25062 .48893 .25802 .48555 .2681 .48059 .26056 .48642 Mtetra
.072 0 0 r
.26056 .48642 .2681 .48059 .27829 .4746 .27061 .48296 Mtetra
.111 0 0 r
.27061 .48296 .27829 .4746 .28858 .46745 .2808 .47827 Mtetra
.136 0 0 r
.2808 .47827 .28858 .46745 .29894 .45946 .29109 .47234 Mtetra
.135 0 .027 r
.29109 .47234 .29894 .45946 .30936 .45081 .3015 .46512 Mtetra
.13 0 .056 r
.3015 .46512 .30936 .45081 .31979 .44197 .31199 .45688 Mtetra
.109 0 .058 r
.31199 .45688 .31979 .44197 .33022 .43331 .32254 .44781 Mtetra
.064 0 .028 r
.32254 .44781 .33022 .43331 .34062 .42519 .33313 .43816 Mtetra
0 0 0 r
.33313 .43816 .34062 .42519 .35099 .41794 .34374 .42818 Mtetra
.34374 .42818 .35099 .41794 .36129 .4121 .35433 .4185 Mtetra
.35433 .4185 .36129 .4121 .37154 .40798 .36488 .40959 Mtetra
.72 .989 .857 r
.36488 .40959 .37154 .40798 .38178 .40507 .37539 .40171 Mtetra
.774 .878 .922 r
.37539 .40171 .38178 .40507 .39201 .40303 .38586 .39502 Mtetra
.722 .721 .849 r
.38586 .39502 .39201 .40303 .40229 .40127 .39631 .38913 Mtetra
.681 .625 .786 r
.39631 .38913 .40229 .40127 .41263 .39902 .40678 .3837 Mtetra
.667 .579 .746 r
.40678 .3837 .41263 .39902 .4231 .39444 .41728 .37797 Mtetra
.676 .573 .731 r
.41728 .37797 .4231 .39444 .43368 .38676 .42784 .37127 Mtetra
.716 .603 .729 r
.42784 .37127 .43368 .38676 .44434 .37662 .43848 .36213 Mtetra
.752 .63 .725 r
.43848 .36213 .44434 .37662 .45504 .36487 .44918 .35061 Mtetra
.76 .636 .724 r
.44918 .35061 .45504 .36487 .46571 .35332 .45989 .33852 Mtetra
.739 .621 .728 r
.45989 .33852 .46571 .35332 .47635 .34384 .47055 .32801 Mtetra
.626 .552 .751 r
.47055 .32801 .47635 .34384 .48691 .34021 .48111 .32435 Mtetra
.448 .448 .766 r
.48111 .32435 .48691 .34021 .49747 .34244 .49164 .32754 Mtetra
.379 .419 .777 r
.49164 .32754 .49747 .34244 .50809 .34676 .50224 .33234 Mtetra
.394 .437 .786 r
.50224 .33234 .50809 .34676 .51881 .35132 .51295 .3366 Mtetra
.484 .487 .784 r
.51295 .3366 .51881 .35132 .52963 .35428 .52376 .33849 Mtetra
.557 .516 .766 r
.52376 .33849 .52963 .35428 .54052 .35478 .53464 .33793 Mtetra
.579 .518 .751 r
.53464 .33793 .54052 .35478 .55146 .35216 .54557 .3364 Mtetra
.586 .534 .763 r
.54557 .3364 .55146 .35216 .56242 .34718 .55656 .33458 Mtetra
.577 .574 .813 r
.55656 .33458 .56242 .34718 .57341 .3417 .56762 .33322 Mtetra
.531 .644 .906 r
.56762 .33322 .57341 .3417 .58443 .33649 .57875 .33268 Mtetra
.284 .69 .972 r
.57875 .33268 .58443 .33649 .59551 .33217 .58998 .33337 Mtetra
.276 0 0 r
.58998 .33337 .59551 .33217 .60666 .32907 .60131 .33512 Mtetra
.481 0 .002 r
.60131 .33512 .60666 .32907 .61792 .32774 .61274 .33767 Mtetra
.521 .087 .157 r
.61274 .33767 .61792 .32774 .62928 .32785 .62428 .34055 Mtetra
.522 .118 .217 r
.62428 .34055 .62928 .32785 .64075 .32887 .6359 .34312 Mtetra
.512 .123 .239 r
.6359 .34312 .64075 .32887 .65233 .33044 .64759 .3451 Mtetra
.495 .11 .239 r
.64759 .3451 .65233 .33044 .664 .33223 .65934 .34626 Mtetra
.467 .078 .218 r
.65934 .34626 .664 .33223 .67575 .33384 .67113 .34639 Mtetra
.42 .019 .171 r
.67113 .34639 .67575 .33384 .68756 .33478 .68293 .34518 Mtetra
.348 0 .088 r
.68293 .34518 .68756 .33478 .6994 .33486 .69473 .3427 Mtetra
.224 0 0 r
.69473 .3427 .6994 .33486 .71125 .33377 .70651 .33895 Mtetra
.025 0 0 r
.70651 .33895 .71125 .33377 .72311 .3316 .71829 .33421 Mtetra
0 0 0 r
.71829 .33421 .72311 .3316 .73496 .3284 .73006 .32876 Mtetra
.517 .916 .843 r
.73006 .32876 .73496 .3284 .74681 .32444 .74185 .32289 Mtetra
.649 .951 .948 r
.74185 .32289 .74681 .32444 .75867 .32001 .75367 .31696 Mtetra
.698 .924 .968 r
.75367 .31696 .75867 .32001 .77057 .31531 .76552 .31107 Mtetra
.706 .883 .963 r
.76552 .31107 .77057 .31531 .7825 .31061 .77743 .3054 Mtetra
.706 .848 .95 r
.77743 .3054 .7825 .31061 .79449 .3059 .78939 .29988 Mtetra
.703 .818 .936 r
.78939 .29988 .79449 .3059 .80652 .30125 .80141 .2945 Mtetra
.698 .791 .922 r
.80141 .2945 .80652 .30125 .81861 .29669 .81347 .28921 Mtetra
.566 .725 .949 r
.16646 .49655 .17328 .5025 .18283 .50045 .17596 .49506 Mtetra
.554 .743 .964 r
.17596 .49506 .18283 .50045 .19241 .49851 .18551 .49362 Mtetra
.536 .757 .978 r
.18551 .49362 .19241 .49851 .20202 .49669 .19509 .49228 Mtetra
.507 .766 .989 r
.19509 .49228 .20202 .49669 .21166 .49503 .2047 .49112 Mtetra
.462 .769 .996 r
.2047 .49112 .21166 .49503 .22132 .4936 .21433 .49023 Mtetra
.405 .766 .994 r
.21433 .49023 .22132 .4936 .23103 .4922 .22399 .48959 Mtetra
.31 .745 .968 r
.22399 .48959 .23103 .4922 .24079 .49076 .23368 .48929 Mtetra
.188 .702 .891 r
.23368 .48929 .24079 .49076 .25062 .48893 .24341 .48908 Mtetra
.02 .593 .71 r
.24341 .48908 .25062 .48893 .26056 .48642 .2532 .48884 Mtetra
.137 0 0 r
.2532 .48884 .26056 .48642 .27061 .48296 .26307 .48821 Mtetra
.238 0 0 r
.26307 .48821 .27061 .48296 .2808 .47827 .27306 .48688 Mtetra
.294 0 0 r
.27306 .48688 .2808 .47827 .29109 .47234 .28316 .48462 Mtetra
.316 0 .11 r
.28316 .48462 .29109 .47234 .3015 .46512 .29339 .48117 Mtetra
.332 0 .187 r
.29339 .48117 .3015 .46512 .31199 .45688 .30374 .47657 Mtetra
.34 .002 .237 r
.30374 .47657 .31199 .45688 .32254 .44781 .31419 .47079 Mtetra
.343 .023 .27 r
.31419 .47079 .32254 .44781 .33313 .43816 .32473 .46392 Mtetra
.344 .036 .291 r
.32473 .46392 .33313 .43816 .34374 .42818 .33536 .45601 Mtetra
.345 .045 .305 r
.33536 .45601 .34374 .42818 .35433 .4185 .34603 .44737 Mtetra
.345 .049 .311 r
.34603 .44737 .35433 .4185 .36488 .40959 .35674 .4383 Mtetra
.355 .057 .315 r
.35674 .4383 .36488 .40959 .37539 .40171 .36742 .42969 Mtetra
.372 .07 .318 r
.36742 .42969 .37539 .40171 .38586 .39502 .37807 .42213 Mtetra
.39 .083 .32 r
.37807 .42213 .38586 .39502 .39631 .38913 .38869 .41568 Mtetra
.415 .105 .327 r
.38869 .41568 .39631 .38913 .40678 .3837 .39927 .41067 Mtetra
.464 .15 .348 r
.39927 .41067 .40678 .3837 .41728 .37797 .40979 .40826 Mtetra
.505 .197 .378 r
.40979 .40826 .41728 .37797 .42784 .37127 .42028 .40826 Mtetra
.502 .209 .401 r
.42028 .40826 .42784 .37127 .43848 .36213 .43086 .40751 Mtetra
.49 .211 .417 r
.43086 .40751 .43848 .36213 .44918 .35061 .44155 .40476 Mtetra
.482 .213 .43 r
.44155 .40476 .44918 .35061 .45989 .33852 .45233 .40002 Mtetra
.479 .218 .439 r
.45233 .40002 .45989 .33852 .47055 .32801 .46317 .39405 Mtetra
.498 .237 .449 r
.46317 .39405 .47055 .32801 .48111 .32435 .474 .39042 Mtetra
.513 .249 .452 r
.474 .39042 .48111 .32435 .49164 .32754 .48484 .38913 Mtetra
.503 .238 .445 r
.48484 .38913 .49164 .32754 .50224 .33234 .49576 .38661 Mtetra
.484 .216 .431 r
.49576 .38661 .50224 .33234 .51295 .3366 .50674 .3821 Mtetra
.455 .181 .408 r
.50674 .3821 .51295 .3366 .52376 .33849 .51776 .37557 Mtetra
.426 .143 .378 r
.51776 .37557 .52376 .33849 .53464 .33793 .5288 .36827 Mtetra
.438 .137 .356 r
.5288 .36827 .53464 .33793 .54557 .3364 .53988 .36339 Mtetra
.468 .153 .348 r
.53988 .36339 .54557 .3364 .55656 .33458 .55101 .36114 Mtetra
.489 .169 .351 r
.55101 .36114 .55656 .33458 .56762 .33322 .56222 .36036 Mtetra
.506 .186 .359 r
.56222 .36036 .56762 .33322 .57875 .33268 .57351 .36072 Mtetra
.52 .201 .367 r
.57351 .36072 .57875 .33268 .58998 .33337 .58489 .36216 Mtetra
.526 .209 .372 r
.58489 .36216 .58998 .33337 .60131 .33512 .59637 .36408 Mtetra
.521 .204 .371 r
.59637 .36408 .60131 .33512 .61274 .33767 .60793 .36558 Mtetra
.511 .192 .362 r
.60793 .36558 .61274 .33767 .62428 .34055 .61955 .36635 Mtetra
.494 .17 .346 r
.61955 .36635 .62428 .34055 .6359 .34312 .63122 .36608 Mtetra
.47 .137 .319 r
.63122 .36608 .6359 .34312 .64759 .3451 .64292 .36469 Mtetra
.434 .088 .278 r
.64292 .36469 .64759 .3451 .65934 .34626 .65464 .36209 Mtetra
.378 .012 .211 r
.65464 .36209 .65934 .34626 .67113 .34639 .66637 .35831 Mtetra
.278 0 .096 r
.66637 .35831 .67113 .34639 .68293 .34518 .67809 .3533 Mtetra
.106 0 0 r
.67809 .3533 .68293 .34518 .69473 .3427 .68979 .34731 Mtetra
0 0 0 r
.68979 .34731 .69473 .3427 .70651 .33895 .70149 .3406 Mtetra
.505 .897 .747 r
.70149 .3406 .70651 .33895 .71829 .33421 .7132 .33346 Mtetra
.684 .974 .909 r
.7132 .33346 .71829 .33421 .73006 .32876 .72493 .32627 Mtetra
.74 .95 .946 r
.72493 .32627 .73006 .32876 .74185 .32289 .73669 .31917 Mtetra
.745 .911 .949 r
.73669 .31917 .74185 .32289 .75367 .31696 .7485 .3124 Mtetra
.74 .881 .945 r
.7485 .3124 .75367 .31696 .76552 .31107 .76036 .30589 Mtetra
.732 .857 .94 r
.76036 .30589 .76552 .31107 .77743 .3054 .77228 .29965 Mtetra
.726 .835 .932 r
.77228 .29965 .77743 .3054 .78939 .29988 .78424 .29358 Mtetra
.721 .815 .924 r
.78424 .29358 .78939 .29988 .80141 .2945 .79625 .28761 Mtetra
.718 .796 .913 r
.79625 .28761 .80141 .2945 .81347 .28921 .8083 .28168 Mtetra
.571 .727 .947 r
.15958 .49055 .16646 .49655 .17596 .49506 .16911 .48896 Mtetra
.579 .727 .944 r
.16911 .48896 .17596 .49506 .18551 .49362 .1787 .48725 Mtetra
.586 .72 .936 r
.1787 .48725 .18551 .49362 .19509 .49228 .18834 .48545 Mtetra
.59 .707 .924 r
.18834 .48545 .19509 .49228 .2047 .49112 .19803 .48362 Mtetra
.595 .688 .907 r
.19803 .48362 .2047 .49112 .21433 .49023 .20777 .48176 Mtetra
.589 .659 .885 r
.20777 .48176 .21433 .49023 .22399 .48959 .21754 .48007 Mtetra
.577 .627 .865 r
.21754 .48007 .22399 .48959 .23368 .48929 .22732 .47875 Mtetra
.563 .598 .846 r
.22732 .47875 .23368 .48929 .24341 .48908 .23711 .47781 Mtetra
.546 .575 .835 r
.23711 .47781 .24341 .48908 .2532 .48884 .24692 .47736 Mtetra
.537 .567 .833 r
.24692 .47736 .2532 .48884 .26307 .48821 .25676 .47716 Mtetra
.531 .573 .843 r
.25676 .47716 .26307 .48821 .27306 .48688 .26665 .47706 Mtetra
.534 .604 .869 r
.26665 .47706 .27306 .48688 .28316 .48462 .27661 .47673 Mtetra
.544 .662 .913 r
.27661 .47673 .28316 .48462 .29339 .48117 .28667 .47586 Mtetra
.547 .754 .973 r
.28667 .47586 .29339 .48117 .30374 .47657 .29684 .47432 Mtetra
.506 .854 .994 r
.29684 .47432 .30374 .47657 .31419 .47079 .3071 .47194 Mtetra
.316 .805 .8 r
.3071 .47194 .31419 .47079 .32473 .46392 .31747 .46877 Mtetra
0 0 0 r
.31747 .46877 .32473 .46392 .33536 .45601 .32792 .4648 Mtetra
.113 0 0 r
.32792 .4648 .33536 .45601 .34603 .44737 .33848 .45976 Mtetra
.186 0 .039 r
.33848 .45976 .34603 .44737 .35674 .4383 .34912 .45363 Mtetra
.252 0 .134 r
.34912 .45363 .35674 .4383 .36742 .42969 .3598 .44725 Mtetra
.305 0 .194 r
.3598 .44725 .36742 .42969 .37807 .42213 .37048 .44118 Mtetra
.342 0 .23 r
.37048 .44118 .37807 .42213 .38869 .41568 .38117 .43563 Mtetra
.385 .044 .259 r
.38117 .43563 .38869 .41568 .39927 .41067 .39184 .43126 Mtetra
.472 .129 .303 r
.39184 .43126 .39927 .41067 .40979 .40826 .40241 .43047 Mtetra
.545 .205 .344 r
.40241 .43047 .40979 .40826 .42028 .40826 .4129 .43369 Mtetra
.556 .228 .368 r
.4129 .43369 .42028 .40826 .43086 .40751 .42345 .43787 Mtetra
.546 .232 .387 r
.42345 .43787 .43086 .40751 .44155 .40476 .43411 .4414 Mtetra
.525 .226 .402 r
.43411 .4414 .44155 .40476 .45233 .40002 .44491 .44297 Mtetra
.501 .215 .411 r
.44491 .44297 .45233 .40002 .46317 .39405 .45585 .44183 Mtetra
.483 .205 .416 r
.45585 .44183 .46317 .39405 .474 .39042 .46689 .43822 Mtetra
.46 .186 .41 r
.46689 .43822 .474 .39042 .48484 .38913 .47801 .43213 Mtetra
.421 .146 .389 r
.47801 .43213 .48484 .38913 .49576 .38661 .48919 .42331 Mtetra
.372 .094 .356 r
.48919 .42331 .49576 .38661 .50674 .3821 .50039 .4125 Mtetra
.321 .035 .313 r
.50039 .4125 .50674 .3821 .51776 .37557 .51159 .40101 Mtetra
.296 0 .275 r
.51159 .40101 .51776 .37557 .5288 .36827 .52279 .39046 Mtetra
.359 .035 .273 r
.52279 .39046 .5288 .36827 .53988 .36339 .53399 .38394 Mtetra
.429 .088 .283 r
.53399 .38394 .53988 .36339 .55101 .36114 .54524 .38104 Mtetra
.451 .103 .285 r
.54524 .38104 .55101 .36114 .56222 .36036 .55656 .37933 Mtetra
.458 .104 .277 r
.55656 .37933 .56222 .36036 .57351 .36072 .56795 .37817 Mtetra
.458 .094 .259 r
.56795 .37817 .57351 .36072 .58489 .36216 .5794 .37732 Mtetra
.439 .059 .22 r
.5794 .37732 .58489 .36216 .59637 .36408 .59092 .37624 Mtetra
.377 0 .136 r
.59092 .37624 .59637 .36408 .60793 .36558 .60248 .37404 Mtetra
.253 0 0 r
.60248 .37404 .60793 .36558 .61955 .36635 .61407 .37075 Mtetra
0 0 0 r
.61407 .37075 .61955 .36635 .63122 .36608 .62569 .36664 Mtetra
.451 .883 .839 r
.62569 .36664 .63122 .36608 .64292 .36469 .63732 .36172 Mtetra
.702 .919 .967 r
.63732 .36172 .64292 .36469 .65464 .36209 .64897 .35592 Mtetra
.741 .815 .909 r
.64897 .35592 .65464 .36209 .66637 .35831 .66061 .34942 Mtetra
.736 .735 .85 r
.66061 .34942 .66637 .35831 .67809 .3533 .67227 .34236 Mtetra
.723 .687 .814 r
.67227 .34236 .67809 .3533 .68979 .34731 .68393 .33504 Mtetra
.711 .658 .796 r
.68393 .33504 .68979 .34731 .70149 .3406 .69563 .32781 Mtetra
.702 .646 .791 r
.69563 .32781 .70149 .3406 .7132 .33346 .70736 .32083 Mtetra
.694 .645 .797 r
.70736 .32083 .7132 .33346 .72493 .32627 .71915 .31434 Mtetra
.691 .656 .811 r
.71915 .31434 .72493 .32627 .73669 .31917 .731 .30824 Mtetra
.689 .675 .831 r
.731 .30824 .73669 .31917 .7485 .3124 .74292 .30251 Mtetra
.692 .699 .852 r
.74292 .30251 .7485 .3124 .76036 .30589 .75488 .29695 Mtetra
.698 .726 .872 r
.75488 .29695 .76036 .30589 .77228 .29965 .76688 .29136 Mtetra
.703 .747 .886 r
.76688 .29136 .77228 .29965 .78424 .29358 .77892 .28571 Mtetra
.707 .762 .895 r
.77892 .28571 .78424 .29358 .79625 .28761 .79098 .27997 Mtetra
.712 .771 .899 r
.79098 .27997 .79625 .28761 .8083 .28168 .80308 .27409 Mtetra
.616 .741 .935 r
.15266 .48451 .15958 .49055 .16911 .48896 .1623 .48209 Mtetra
.632 .719 .91 r
.1623 .48209 .16911 .48896 .1787 .48725 .17201 .47936 Mtetra
.643 .693 .882 r
.17201 .47936 .1787 .48725 .18834 .48545 .18179 .47633 Mtetra
.649 .665 .851 r
.18179 .47633 .18834 .48545 .19803 .48362 .19164 .47298 Mtetra
.654 .635 .819 r
.19164 .47298 .19803 .48362 .20777 .48176 .20157 .46921 Mtetra
.646 .6 .789 r
.20157 .46921 .20777 .48176 .21754 .48007 .21153 .4654 Mtetra
.632 .565 .762 r
.21153 .4654 .21754 .48007 .22732 .47875 .22152 .46178 Mtetra
.613 .531 .739 r
.22152 .46178 .22732 .47875 .23711 .47781 .23149 .45865 Mtetra
.591 .5 .72 r
.23149 .45865 .23711 .47781 .24692 .47736 .24143 .45632 Mtetra
.573 .476 .706 r
.24143 .45632 .24692 .47736 .25676 .47716 .25136 .45476 Mtetra
.556 .457 .697 r
.25136 .45476 .25676 .47716 .26665 .47706 .26126 .45404 Mtetra
.546 .447 .693 r
.26126 .45404 .26665 .47706 .27661 .47673 .27118 .45383 Mtetra
.54 .444 .695 r
.27118 .45383 .27661 .47673 .28667 .47586 .28114 .45391 Mtetra
.538 .45 .703 r
.28114 .45391 .28667 .47586 .29684 .47432 .29115 .45407 Mtetra
.541 .463 .717 r
.29115 .45407 .29684 .47432 .3071 .47194 .30123 .45411 Mtetra
.539 .483 .742 r
.30123 .45411 .3071 .47194 .31747 .46877 .31137 .45417 Mtetra
.535 .519 .784 r
.31137 .45417 .31747 .46877 .32792 .4648 .32158 .45422 Mtetra
.552 .599 .854 r
.32158 .45422 .32792 .4648 .33848 .45976 .33189 .45347 Mtetra
.582 .735 .948 r
.33189 .45347 .33848 .45976 .34912 .45363 .34233 .4515 Mtetra
.524 .868 .991 r
.34233 .4515 .34912 .45363 .3598 .44725 .35286 .44872 Mtetra
.293 .787 .763 r
.35286 .44872 .3598 .44725 .37048 .44118 .36347 .44534 Mtetra
0 0 0 r
.36347 .44534 .37048 .44118 .38117 .43563 .37415 .44129 Mtetra
.012 0 0 r
.37415 .44129 .38117 .43563 .39184 .43126 .38488 .43713 Mtetra
.251 0 0 r
.38488 .43713 .39184 .43126 .40241 .43047 .39554 .43563 Mtetra
.453 0 0 r
.39554 .43563 .40241 .43047 .4129 .43369 .40612 .4377 Mtetra
.534 .013 0 r
.40612 .4377 .4129 .43369 .42345 .43787 .41672 .44187 Mtetra
.574 .06 0 r
.41672 .44187 .42345 .43787 .43411 .4414 .42738 .44708 Mtetra
.561 .072 .051 r
.42738 .44708 .43411 .4414 .44491 .44297 .43815 .45172 Mtetra
.496 .045 .11 r
.43815 .45172 .44491 .44297 .45585 .44183 .44908 .45399 Mtetra
.312 0 .097 r
.44908 .45399 .45585 .44183 .46689 .43822 .46022 .45037 Mtetra
.014 0 0 r
.46022 .45037 .46689 .43822 .47801 .43213 .47149 .44084 Mtetra
0 0 0 r
.47149 .44084 .47801 .43213 .48919 .42331 .4828 .42892 Mtetra
.645 .905 .589 r
.4828 .42892 .48919 .42331 .50039 .4125 .49411 .41638 Mtetra
.709 .959 .693 r
.49411 .41638 .50039 .4125 .51159 .40101 .50539 .40486 Mtetra
.575 .906 .665 r
.50539 .40486 .51159 .40101 .52279 .39046 .51666 .39543 Mtetra
0 0 0 r
.51666 .39543 .52279 .39046 .53399 .38394 .52795 .3896 Mtetra
.131 0 0 r
.52795 .3896 .53399 .38394 .54524 .38104 .53927 .38645 Mtetra
.11 0 0 r
.53927 .38645 .54524 .38104 .55656 .37933 .55065 .38319 Mtetra
0 0 0 r
.55065 .38319 .55656 .37933 .56795 .37817 .56206 .37926 Mtetra
.387 .845 .795 r
.56206 .37926 .56795 .37817 .5794 .37732 .57352 .3747 Mtetra
.68 .92 .973 r
.57352 .3747 .5794 .37732 .59092 .37624 .585 .36933 Mtetra
.742 .786 .889 r
.585 .36933 .59092 .37624 .60248 .37404 .59649 .36269 Mtetra
.723 .676 .803 r
.59649 .36269 .60248 .37404 .61407 .37075 .60799 .35521 Mtetra
.692 .603 .752 r
.60799 .35521 .61407 .37075 .62569 .36664 .61951 .34772 Mtetra
.671 .561 .721 r
.61951 .34772 .62569 .36664 .63732 .36172 .63105 .34024 Mtetra
.661 .537 .702 r
.63105 .34024 .63732 .36172 .64897 .35592 .64261 .33261 Mtetra
.652 .521 .691 r
.64261 .33261 .64897 .35592 .66061 .34942 .65419 .32505 Mtetra
.644 .51 .685 r
.65419 .32505 .66061 .34942 .67227 .34236 .66581 .31778 Mtetra
.637 .505 .685 r
.66581 .31778 .67227 .34236 .68393 .33504 .67747 .31102 Mtetra
.628 .503 .69 r
.67747 .31102 .68393 .33504 .69563 .32781 .68921 .30512 Mtetra
.622 .506 .701 r
.68921 .30512 .69563 .32781 .70736 .32083 .70104 .3 Mtetra
.615 .515 .717 r
.70104 .3 .70736 .32083 .71915 .31434 .71295 .29572 Mtetra
.613 .532 .738 r
.71295 .29572 .71915 .31434 .731 .30824 .72495 .29193 Mtetra
.617 .557 .765 r
.72495 .29193 .731 .30824 .74292 .30251 .73701 .28835 Mtetra
.625 .589 .794 r
.73701 .28835 .74292 .30251 .75488 .29695 .74913 .28472 Mtetra
.642 .63 .823 r
.74913 .28472 .75488 .29695 .76688 .29136 .76126 .28065 Mtetra
.657 .668 .849 r
.76126 .28065 .76688 .29136 .77892 .28571 .77343 .27624 Mtetra
.671 .704 .872 r
.77343 .27624 .77892 .28571 .79098 .27997 .78562 .2715 Mtetra
.684 .737 .892 r
.78562 .2715 .79098 .27997 .80308 .27409 .79782 .26643 Mtetra
.69 .759 .904 r
.14569 .47843 .15266 .48451 .1623 .48209 .15555 .47422 Mtetra
.691 .708 .861 r
.15555 .47422 .1623 .48209 .17201 .47936 .16547 .46968 Mtetra
.687 .666 .824 r
.16547 .46968 .17201 .47936 .18179 .47633 .17545 .46484 Mtetra
.681 .631 .793 r
.17545 .46484 .18179 .47633 .19164 .47298 .18549 .4597 Mtetra
.676 .604 .768 r
.18549 .4597 .19164 .47298 .20157 .46921 .19559 .45421 Mtetra
.666 .579 .749 r
.19559 .45421 .20157 .46921 .21153 .4654 .20571 .44873 Mtetra
.652 .556 .734 r
.20571 .44873 .21153 .4654 .22152 .46178 .21583 .44353 Mtetra
.635 .533 .722 r
.21583 .44353 .22152 .46178 .23149 .45865 .22593 .43892 Mtetra
.614 .51 .712 r
.22593 .43892 .23149 .45865 .24143 .45632 .23597 .43522 Mtetra
.594 .489 .704 r
.23597 .43522 .24143 .45632 .25136 .45476 .24597 .43244 Mtetra
.573 .468 .696 r
.24597 .43244 .25136 .45476 .26126 .45404 .25592 .43072 Mtetra
.558 .453 .691 r
.25592 .43072 .26126 .45404 .27118 .45383 .26586 .42981 Mtetra
.545 .441 .687 r
.26586 .42981 .27118 .45383 .28114 .45391 .27581 .42957 Mtetra
.536 .433 .685 r
.27581 .42957 .28114 .45391 .29115 .45407 .28577 .42982 Mtetra
.529 .43 .686 r
.28577 .42982 .29115 .45407 .30123 .45411 .29577 .43044 Mtetra
.518 .426 .691 r
.29577 .43044 .30123 .45411 .31137 .45417 .3058 .43162 Mtetra
.504 .425 .7 r
.3058 .43162 .31137 .45417 .32158 .45422 .31586 .43335 Mtetra
.514 .443 .714 r
.31586 .43335 .32158 .45422 .33189 .45347 .32602 .43454 Mtetra
.539 .475 .732 r
.32602 .43454 .33189 .45347 .34233 .4515 .33633 .43458 Mtetra
.56 .507 .753 r
.33633 .43458 .34233 .4515 .35286 .44872 .34675 .43371 Mtetra
.587 .545 .774 r
.34675 .43371 .35286 .44872 .36347 .44534 .35728 .43183 Mtetra
.633 .589 .788 r
.35728 .43183 .36347 .44534 .37415 .44129 .36794 .42823 Mtetra
.67 .614 .784 r
.36794 .42823 .37415 .44129 .38488 .43713 .37872 .42298 Mtetra
.654 .592 .773 r
.37872 .42298 .38488 .43713 .39554 .43563 .38951 .41825 Mtetra
.609 .532 .743 r
.38951 .41825 .39554 .43563 .40612 .4377 .40027 .41511 Mtetra
.56 .463 .702 r
.40027 .41511 .40612 .4377 .41672 .44187 .41101 .41408 Mtetra
.523 .413 .67 r
.41101 .41408 .41672 .44187 .42738 .44708 .42174 .41517 Mtetra
.503 .384 .651 r
.42174 .41517 .42738 .44708 .43815 .45172 .4325 .41779 Mtetra
.509 .382 .643 r
.4325 .41779 .43815 .45172 .44908 .45399 .44335 .42014 Mtetra
.582 .434 .645 r
.44335 .42014 .44908 .45399 .46022 .45037 .45442 .41647 Mtetra
.641 .473 .641 r
.45442 .41647 .46022 .45037 .47149 .44084 .46565 .40675 Mtetra
.642 .474 .64 r
.46565 .40675 .47149 .44084 .4828 .42892 .47688 .39675 Mtetra
.634 .473 .647 r
.47688 .39675 .4828 .42892 .49411 .41638 .4881 .38826 Mtetra
.623 .479 .666 r
.4881 .38826 .49411 .41638 .50539 .40486 .49932 .3819 Mtetra
.61 .495 .697 r
.49932 .3819 .50539 .40486 .51666 .39543 .51055 .37765 Mtetra
.596 .525 .745 r
.51055 .37765 .51666 .39543 .52795 .3896 .52182 .37501 Mtetra
.591 .559 .787 r
.52182 .37501 .52795 .3896 .53927 .38645 .53315 .37289 Mtetra
.633 .596 .795 r
.53315 .37289 .53927 .38645 .55065 .38319 .54453 .36912 Mtetra
.667 .607 .778 r
.54453 .36912 .55065 .38319 .56206 .37926 .55594 .36358 Mtetra
.676 .592 .754 r
.55594 .36358 .56206 .37926 .57352 .3747 .56737 .35701 Mtetra
.679 .574 .731 r
.56737 .35701 .57352 .3747 .585 .36933 .57881 .34951 Mtetra
.683 .56 .71 r
.57881 .34951 .585 .36933 .59649 .36269 .59025 .34081 Mtetra
.679 .544 .694 r
.59025 .34081 .59649 .36269 .60799 .35521 .60169 .33154 Mtetra
.664 .526 .685 r
.60169 .33154 .60799 .35521 .61951 .34772 .61315 .32282 Mtetra
.653 .512 .68 r
.61315 .32282 .61951 .34772 .63105 .34024 .62465 .31465 Mtetra
.646 .505 .677 r
.62465 .31465 .63105 .34024 .64261 .33261 .63617 .30684 Mtetra
.639 .5 .677 r
.63617 .30684 .64261 .33261 .65419 .32505 .64773 .29954 Mtetra
.632 .497 .68 r
.64773 .29954 .65419 .32505 .66581 .31778 .65935 .2929 Mtetra
.624 .495 .685 r
.65935 .2929 .66581 .31778 .67747 .31102 .67104 .28709 Mtetra
.612 .493 .693 r
.67104 .28709 .67747 .31102 .68921 .30512 .68281 .28237 Mtetra
.601 .493 .703 r
.68281 .28237 .68921 .30512 .70104 .3 .69469 .2786 Mtetra
.59 .495 .715 r
.69469 .2786 .70104 .3 .71295 .29572 .70667 .27577 Mtetra
.582 .502 .73 r
.70667 .27577 .71295 .29572 .72495 .29193 .71875 .27355 Mtetra
.578 .514 .746 r
.71875 .27355 .72495 .29193 .73701 .28835 .73091 .27162 Mtetra
.58 .532 .766 r
.73091 .27162 .73701 .28835 .74913 .28472 .74315 .26972 Mtetra
.59 .56 .789 r
.74315 .26972 .74913 .28472 .76126 .28065 .75543 .26744 Mtetra
.601 .593 .816 r
.75543 .26744 .76126 .28065 .77343 .27624 .76776 .26486 Mtetra
.612 .634 .848 r
.76776 .26486 .77343 .27624 .78562 .2715 .78012 .26196 Mtetra
.624 .683 .886 r
.78012 .26196 .78562 .2715 .79782 .26643 .79252 .25872 Mtetra
.747 .767 .869 r
.13868 .4723 .14569 .47843 .15555 .47422 .14878 .46606 Mtetra
.733 .713 .831 r
.14878 .46606 .15555 .47422 .16547 .46968 .15893 .45963 Mtetra
.719 .671 .802 r
.15893 .45963 .16547 .46968 .17545 .46484 .1691 .45311 Mtetra
.706 .639 .78 r
.1691 .45311 .17545 .46484 .18549 .4597 .1793 .44658 Mtetra
.695 .615 .763 r
.1793 .44658 .18549 .4597 .19559 .45421 .1895 .44007 Mtetra
.684 .598 .754 r
.1895 .44007 .19559 .45421 .20571 .44873 .1997 .43384 Mtetra
.671 .584 .749 r
.1997 .43384 .20571 .44873 .21583 .44353 .20988 .42806 Mtetra
.658 .571 .746 r
.20988 .42806 .21583 .44353 .22593 .43892 .22003 .42284 Mtetra
.642 .557 .743 r
.22003 .42284 .22593 .43892 .23597 .43522 .23014 .41834 Mtetra
.624 .539 .738 r
.23014 .41834 .23597 .43522 .24597 .43244 .24021 .41458 Mtetra
.605 .52 .731 r
.24021 .41458 .24597 .43244 .25592 .43072 .25025 .41162 Mtetra
.588 .499 .722 r
.25025 .41162 .25592 .43072 .26586 .42981 .26028 .40937 Mtetra
.572 .48 .712 r
.26028 .40937 .26586 .42981 .27581 .42957 .2703 .40777 Mtetra
.559 .463 .702 r
.2703 .40777 .27581 .42957 .28577 .42982 .28032 .40679 Mtetra
.547 .448 .694 r
.28032 .40679 .28577 .42982 .29577 .43044 .29036 .40638 Mtetra
.533 .433 .687 r
.29036 .40638 .29577 .43044 .3058 .43162 .3004 .4067 Mtetra
.519 .42 .682 r
.3004 .4067 .3058 .43162 .31586 .43335 .31046 .40776 Mtetra
.526 .421 .679 r
.31046 .40776 .31586 .43335 .32602 .43454 .32061 .40852 Mtetra
.541 .43 .677 r
.32061 .40852 .32602 .43454 .33633 .43458 .33088 .40839 Mtetra
.55 .436 .676 r
.33088 .40839 .33633 .43458 .34675 .43371 .34124 .40771 Mtetra
.562 .445 .677 r
.34124 .40771 .34675 .43371 .35728 .43183 .3517 .4063 Mtetra
.598 .471 .678 r
.3517 .4063 .35728 .43183 .36794 .42823 .36234 .40254 Mtetra
.635 .494 .674 r
.36234 .40254 .36794 .42823 .37872 .42298 .37315 .39585 Mtetra
.651 .499 .664 r
.37315 .39585 .37872 .42298 .38951 .41825 .38408 .38723 Mtetra
.648 .484 .648 r
.38408 .38723 .38951 .41825 .40027 .41511 .39505 .37765 Mtetra
.619 .449 .63 r
.39505 .37765 .40027 .41511 .41101 .41408 .40597 .36945 Mtetra
.586 .413 .613 r
.40597 .36945 .41101 .41408 .42174 .41517 .41682 .36382 Mtetra
.552 .379 .6 r
.41682 .36382 .42174 .41517 .4325 .41779 .42758 .36173 Mtetra
.532 .359 .592 r
.42758 .36173 .4325 .41779 .44335 .42014 .43834 .362 Mtetra
.561 .378 .591 r
.43834 .362 .44335 .42014 .45442 .41647 .44927 .35826 Mtetra
.587 .397 .592 r
.44927 .35826 .45442 .41647 .46565 .40675 .46032 .35049 Mtetra
.573 .389 .594 r
.46032 .35049 .46565 .40675 .47688 .39675 .47135 .34507 Mtetra
.55 .378 .6 r
.47135 .34507 .47688 .39675 .4881 .38826 .48236 .34321 Mtetra
.529 .372 .612 r
.48236 .34321 .4881 .38826 .49932 .3819 .49341 .34394 Mtetra
.513 .374 .63 r
.49341 .34394 .49932 .3819 .51055 .37765 .50452 .34609 Mtetra
.522 .399 .654 r
.50452 .34609 .51055 .37765 .52182 .37501 .51572 .34728 Mtetra
.55 .433 .672 r
.51572 .34728 .52182 .37501 .53315 .37289 .52701 .34654 Mtetra
.593 .467 .678 r
.52701 .34654 .53315 .37289 .54453 .36912 .53835 .34283 Mtetra
.624 .487 .675 r
.53835 .34283 .54453 .36912 .55594 .36358 .54972 .33673 Mtetra
.631 .49 .671 r
.54972 .33673 .55594 .36358 .56737 .35701 .56111 .32987 Mtetra
.636 .492 .669 r
.56111 .32987 .56737 .35701 .57881 .34951 .57252 .32246 Mtetra
.647 .499 .668 r
.57252 .32246 .57881 .34951 .59025 .34081 .58393 .31411 Mtetra
.651 .503 .669 r
.58393 .31411 .59025 .34081 .60169 .33154 .59536 .30545 Mtetra
.645 .502 .674 r
.59536 .30545 .60169 .33154 .61315 .32282 .60681 .29752 Mtetra
.639 .502 .679 r
.60681 .29752 .61315 .32282 .62465 .31465 .61831 .29032 Mtetra
.636 .504 .686 r
.61831 .29032 .62465 .31465 .63617 .30684 .62985 .2837 Mtetra
.632 .509 .695 r
.62985 .2837 .63617 .30684 .64773 .29954 .64144 .27771 Mtetra
.627 .514 .705 r
.64144 .27771 .64773 .29954 .65935 .2929 .65309 .27238 Mtetra
.62 .519 .718 r
.65309 .27238 .65935 .2929 .67104 .28709 .66482 .26777 Mtetra
.61 .523 .731 r
.66482 .26777 .67104 .28709 .68281 .28237 .67663 .26399 Mtetra
.599 .525 .743 r
.67663 .26399 .68281 .28237 .69469 .2786 .68854 .26097 Mtetra
.586 .525 .753 r
.68854 .26097 .69469 .2786 .70667 .27577 .70055 .25869 Mtetra
.574 .524 .762 r
.70055 .25869 .70667 .27577 .71875 .27355 .71266 .257 Mtetra
.564 .525 .77 r
.71266 .257 .71875 .27355 .73091 .27162 .72487 .2558 Mtetra
.557 .53 .781 r
.72487 .2558 .73091 .27162 .74315 .26972 .73718 .25487 Mtetra
.555 .543 .796 r
.73718 .25487 .74315 .26972 .75543 .26744 .74957 .25399 Mtetra
.554 .564 .819 r
.74957 .25399 .75543 .26744 .76776 .26486 .76203 .2531 Mtetra
.552 .596 .851 r
.76203 .2531 .76776 .26486 .78012 .26196 .77458 .25212 Mtetra
.55 .64 .892 r
.77458 .25212 .78012 .26196 .79252 .25872 .78718 .25095 Mtetra
.768 .769 .853 r
.13161 .46613 .13868 .4723 .14878 .46606 .14186 .45886 Mtetra
.756 .741 .839 r
.14186 .45886 .14878 .46606 .15893 .45963 .15211 .45176 Mtetra
.744 .723 .832 r
.15211 .45176 .15893 .45963 .1691 .45311 .16234 .44492 Mtetra
.733 .714 .833 r
.16234 .44492 .1691 .45311 .1793 .44658 .17254 .43848 Mtetra
.722 .714 .843 r
.17254 .43848 .1793 .44658 .1895 .44007 .1827 .4326 Mtetra
.717 .729 .861 r
.1827 .4326 .1895 .44007 .1997 .43384 .19285 .42714 Mtetra
.711 .751 .883 r
.19285 .42714 .1997 .43384 .20988 .42806 .20298 .42207 Mtetra
.71 .773 .902 r
.20298 .42207 .20988 .42806 .22003 .42284 .21312 .41716 Mtetra
.713 .785 .908 r
.21312 .41716 .22003 .42284 .23014 .41834 .2233 .41221 Mtetra
.708 .77 .901 r
.2233 .41221 .23014 .41834 .24021 .41458 .23349 .40732 Mtetra
.699 .735 .879 r
.23349 .40732 .24021 .41458 .25025 .41162 .24371 .40252 Mtetra
.679 .683 .847 r
.24371 .40252 .25025 .41162 .26028 .40937 .25394 .39804 Mtetra
.653 .628 .812 r
.25394 .39804 .26028 .40937 .2703 .40777 .26415 .39406 Mtetra
.63 .58 .78 r
.26415 .39406 .2703 .40777 .28032 .40679 .27437 .39056 Mtetra
.609 .539 .751 r
.27437 .39056 .28032 .40679 .29036 .40638 .28458 .38758 Mtetra
.591 .505 .726 r
.28458 .38758 .29036 .40638 .3004 .4067 .2948 .38512 Mtetra
.576 .476 .704 r
.2948 .38512 .3004 .4067 .31046 .40776 .30503 .38315 Mtetra
.572 .456 .683 r
.30503 .38315 .31046 .40776 .32061 .40852 .31532 .38116 Mtetra
.572 .444 .668 r
.31532 .38116 .32061 .40852 .33088 .40839 .32567 .37891 Mtetra
.563 .43 .658 r
.32567 .37891 .33088 .40839 .34124 .40771 .33604 .37714 Mtetra
.557 .422 .653 r
.33604 .37714 .34124 .40771 .3517 .4063 .34644 .37576 Mtetra
.583 .441 .653 r
.34644 .37576 .3517 .4063 .36234 .40254 .35701 .37231 Mtetra
.621 .468 .653 r
.35701 .37231 .36234 .40254 .37315 .39585 .36778 .36561 Mtetra
.655 .491 .65 r
.36778 .36561 .37315 .39585 .38408 .38723 .37873 .35552 Mtetra
.673 .499 .642 r
.37873 .35552 .38408 .38723 .39505 .37765 .38979 .3427 Mtetra
.658 .48 .633 r
.38979 .3427 .39505 .37765 .40597 .36945 .40081 .33049 Mtetra
.628 .451 .624 r
.40081 .33049 .40597 .36945 .41682 .36382 .41173 .32072 Mtetra
.586 .414 .615 r
.41173 .32072 .41682 .36382 .42758 .36173 .42251 .31519 Mtetra
.551 .383 .607 r
.42251 .31519 .42758 .36173 .43834 .362 .43322 .31333 Mtetra
.566 .392 .604 r
.43322 .31333 .43834 .362 .44927 .35826 .44403 .30953 Mtetra
.581 .402 .604 r
.44403 .30953 .44927 .35826 .46032 .35049 .45493 .30376 Mtetra
.553 .385 .607 r
.45493 .30376 .46032 .35049 .47135 .34507 .46579 .30168 Mtetra
.513 .362 .613 r
.46579 .30168 .47135 .34507 .48236 .34321 .47663 .30387 Mtetra
.481 .348 .622 r
.47663 .30387 .48236 .34321 .49341 .34394 .48754 .30853 Mtetra
.466 .348 .634 r
.48754 .30853 .49341 .34394 .50452 .34609 .49854 .31385 Mtetra
.501 .382 .649 r
.49854 .31385 .50452 .34609 .51572 .34728 .50967 .31642 Mtetra
.548 .419 .656 r
.50967 .31642 .51572 .34728 .52701 .34654 .5209 .31558 Mtetra
.589 .446 .655 r
.5209 .31558 .52701 .34654 .53835 .34283 .53218 .31147 Mtetra
.611 .46 .652 r
.53218 .31147 .53835 .34283 .54972 .33673 .5435 .30524 Mtetra
.607 .456 .651 r
.5435 .30524 .54972 .33673 .56111 .32987 .55485 .29941 Mtetra
.604 .458 .656 r
.55485 .29941 .56111 .32987 .57252 .32246 .56624 .29405 Mtetra
.612 .47 .665 r
.56624 .29405 .57252 .32246 .58393 .31411 .57766 .28842 Mtetra
.619 .487 .679 r
.57766 .28842 .58393 .31411 .59536 .30545 .58912 .28277 Mtetra
.622 .504 .699 r
.58912 .28277 .59536 .30545 .60681 .29752 .60062 .27761 Mtetra
.623 .524 .722 r
.60062 .27761 .60681 .29752 .61831 .29032 .61218 .27297 Mtetra
.623 .547 .748 r
.61218 .27297 .61831 .29032 .62985 .2837 .6238 .26887 Mtetra
.621 .576 .782 r
.6238 .26887 .62985 .2837 .64144 .27771 .63549 .26526 Mtetra
.617 .611 .822 r
.63549 .26526 .64144 .27771 .65309 .27238 .64725 .26216 Mtetra
.611 .654 .868 r
.64725 .26216 .65309 .27238 .66482 .26777 .65908 .25939 Mtetra
.605 .701 .911 r
.65908 .25939 .66482 .26777 .67663 .26399 .67098 .25671 Mtetra
.596 .733 .94 r
.67098 .25671 .67663 .26399 .68854 .26097 .68294 .25411 Mtetra
.594 .747 .95 r
.68294 .25411 .68854 .26097 .70055 .25869 .69497 .25145 Mtetra
.589 .733 .943 r
.69497 .25145 .70055 .25869 .71266 .257 .70706 .24897 Mtetra
.577 .702 .928 r
.70706 .24897 .71266 .257 .72487 .2558 .71925 .24689 Mtetra
.563 .67 .91 r
.71925 .24689 .72487 .2558 .73718 .25487 .73154 .24526 Mtetra
.544 .642 .897 r
.73154 .24526 .73718 .25487 .74957 .25399 .74394 .24422 Mtetra
.528 .63 .896 r
.74394 .24422 .74957 .25399 .76203 .2531 .75645 .24359 Mtetra
.513 .63 .903 r
.75645 .24359 .76203 .2531 .77458 .25212 .76908 .24326 Mtetra
.497 .641 .92 r
.76908 .24326 .77458 .25212 .78718 .25095 .7818 .24311 Mtetra
.767 .768 .854 r
.12449 .45992 .13161 .46613 .14186 .45886 .13476 .45271 Mtetra
.756 .77 .865 r
.13476 .45271 .14186 .45886 .15211 .45176 .14498 .44606 Mtetra
.743 .784 .886 r
.14498 .44606 .15211 .45176 .16234 .44492 .15515 .44007 Mtetra
.725 .811 .918 r
.15515 .44007 .16234 .44492 .17254 .43848 .16524 .43485 Mtetra
.68 .851 .964 r
.16524 .43485 .17254 .43848 .1827 .4326 .17526 .43067 Mtetra
.618 .898 .987 r
.17526 .43067 .1827 .4326 .19285 .42714 .18526 .42695 Mtetra
.517 .905 .942 r
.18526 .42695 .19285 .42714 .20298 .42207 .19528 .42333 Mtetra
.449 .882 .855 r
.19528 .42333 .20298 .42207 .21312 .41716 .20539 .41927 Mtetra
.489 .901 .818 r
.20539 .41927 .21312 .41716 .2233 .41221 .21563 .41417 Mtetra
.573 .94 .848 r
.21563 .41417 .2233 .41221 .23349 .40732 .22596 .40834 Mtetra
.687 .976 .904 r
.22596 .40834 .23349 .40732 .24371 .40252 .23638 .4018 Mtetra
.752 .957 .939 r
.23638 .4018 .24371 .40252 .25394 .39804 .24684 .39514 Mtetra
.761 .891 .936 r
.24684 .39514 .25394 .39804 .26415 .39406 .25728 .38878 Mtetra
.748 .809 .901 r
.25728 .38878 .26415 .39406 .27437 .39056 .26774 .38264 Mtetra
.722 .728 .855 r
.26774 .38264 .27437 .39056 .28458 .38758 .27819 .37676 Mtetra
.698 .658 .807 r
.27819 .37676 .28458 .38758 .2948 .38512 .28866 .37094 Mtetra
.675 .599 .762 r
.28866 .37094 .2948 .38512 .30503 .38315 .29917 .36509 Mtetra
.649 .546 .725 r
.29917 .36509 .30503 .38315 .31532 .38116 .30968 .35953 Mtetra
.626 .507 .698 r
.30968 .35953 .31532 .38116 .32567 .37891 .32018 .35451 Mtetra
.591 .47 .683 r
.32018 .35451 .32567 .37891 .33604 .37714 .3306 .35126 Mtetra
.559 .442 .676 r
.3306 .35126 .33604 .37714 .34644 .37576 .34096 .34993 Mtetra
.577 .454 .676 r
.34096 .34993 .34644 .37576 .35701 .37231 .35144 .34742 Mtetra
.619 .487 .679 r
.35144 .34742 .35701 .37231 .36778 .36561 .36211 .3421 Mtetra
.672 .527 .679 r
.36211 .3421 .36778 .36561 .37873 .35552 .373 .33288 Mtetra
.713 .556 .675 r
.373 .33288 .37873 .35552 .38979 .3427 .38406 .31993 Mtetra
.713 .556 .674 r
.38406 .31993 .38979 .3427 .40081 .33049 .39511 .30687 Mtetra
.691 .538 .674 r
.39511 .30687 .40081 .33049 .41173 .32072 .40606 .29565 Mtetra
.643 .501 .674 r
.40606 .29565 .41173 .32072 .42251 .31519 .41687 .28833 Mtetra
.589 .458 .67 r
.41687 .28833 .42251 .31519 .43322 .31333 .42759 .28484 Mtetra
.59 .452 .662 r
.42759 .28484 .43322 .31333 .44403 .30953 .43835 .28099 Mtetra
.595 .455 .662 r
.43835 .28099 .44403 .30953 .45493 .30376 .44917 .27677 Mtetra
.542 .427 .672 r
.44917 .27677 .45493 .30376 .46579 .30168 .45995 .2764 Mtetra
.469 .388 .682 r
.45995 .2764 .46579 .30168 .47663 .30387 .47072 .27996 Mtetra
.422 .366 .689 r
.47072 .27996 .47663 .30387 .48754 .30853 .48157 .28539 Mtetra
.421 .37 .696 r
.48157 .28539 .48754 .30853 .49854 .31385 .49253 .29075 Mtetra
.505 .426 .701 r
.49253 .29075 .49854 .31385 .50967 .31642 .50362 .29237 Mtetra
.575 .466 .692 r
.50362 .29237 .50967 .31642 .5209 .31558 .51481 .29006 Mtetra
.613 .483 .679 r
.51481 .29006 .5209 .31558 .53218 .31147 .52606 .28489 Mtetra
.625 .486 .672 r
.52606 .28489 .53218 .31147 .5435 .30524 .53734 .27853 Mtetra
.6 .469 .674 r
.53734 .27853 .5435 .30524 .55485 .29941 .54867 .27411 Mtetra
.578 .462 .685 r
.54867 .27411 .55485 .29941 .56624 .29405 .56006 .27149 Mtetra
.573 .475 .704 r
.56006 .27149 .56624 .29405 .57766 .28842 .57151 .26943 Mtetra
.573 .502 .737 r
.57151 .26943 .57766 .28842 .58912 .28277 .58303 .26766 Mtetra
.578 .548 .784 r
.58303 .26766 .58912 .28277 .60062 .27761 .59462 .26587 Mtetra
.578 .603 .842 r
.59462 .26587 .60062 .27761 .61218 .27297 .60627 .26414 Mtetra
.558 .665 .908 r
.60627 .26414 .61218 .27297 .6238 .26887 .618 .26269 Mtetra
.512 .732 .973 r
.618 .26269 .6238 .26887 .63549 .26526 .62981 .26147 Mtetra
.4 .769 .993 r
.62981 .26147 .63549 .26526 .64725 .26216 .6417 .26057 Mtetra
.252 .747 .908 r
.6417 .26057 .64725 .26216 .65908 .25939 .65366 .25954 Mtetra
.161 .701 .771 r
.65366 .25954 .65908 .25939 .67098 .25671 .66566 .2578 Mtetra
.145 .684 .694 r
.66566 .2578 .67098 .25671 .68294 .25411 .6777 .2553 Mtetra
.236 .747 .719 r
.6777 .2553 .68294 .25411 .69497 .25145 .68974 .25172 Mtetra
.364 .835 .826 r
.68974 .25172 .69497 .25145 .70706 .24897 .70182 .24768 Mtetra
.48 .887 .938 r
.70182 .24768 .70706 .24897 .71925 .24689 .71395 .24376 Mtetra
.548 .872 .993 r
.71395 .24376 .71925 .24689 .73154 .24526 .72617 .2403 Mtetra
.54 .801 .994 r
.72617 .2403 .73154 .24526 .74394 .24422 .73852 .23792 Mtetra
.524 .743 .974 r
.73852 .23792 .74394 .24422 .75645 .24359 .75101 .23635 Mtetra
.505 .699 .957 r
.75101 .23635 .75645 .24359 .76908 .24326 .76362 .23548 Mtetra
.483 .67 .946 r
.76362 .23548 .76908 .24326 .7818 .24311 .77637 .23521 Mtetra
.737 .766 .876 r
.11732 .45366 .12449 .45992 .13476 .45271 .12746 .44775 Mtetra
.721 .807 .918 r
.12746 .44775 .13476 .45271 .14498 .44606 .13753 .44267 Mtetra
.682 .859 .967 r
.13753 .44267 .14498 .44606 .15515 .44007 .14752 .43842 Mtetra
.578 .894 .987 r
.14752 .43842 .15515 .44007 .16524 .43485 .15745 .43507 Mtetra
.311 .801 .863 r
.15745 .43507 .16524 .43485 .17526 .43067 .16729 .43286 Mtetra
0 0 0 r
.16729 .43286 .17526 .43067 .18526 .42695 .17714 .43092 Mtetra
.037 0 0 r
.17714 .43092 .18526 .42695 .19528 .42333 .18707 .42867 Mtetra
.032 0 0 r
.18707 .42867 .19528 .42333 .20539 .41927 .19715 .4255 Mtetra
0 0 0 r
.19715 .4255 .20539 .41927 .21563 .41417 .20742 .42067 Mtetra
.20742 .42067 .21563 .41417 .22596 .40834 .21783 .41473 Mtetra
.21783 .41473 .22596 .40834 .23638 .4018 .22835 .40786 Mtetra
.22835 .40786 .23638 .4018 .24684 .39514 .23891 .40074 Mtetra
.23891 .40074 .24684 .39514 .25728 .38878 .24946 .39392 Mtetra
.24946 .39392 .25728 .38878 .26774 .38264 .26004 .38701 Mtetra
.47 .862 .668 r
.26004 .38701 .26774 .38264 .27819 .37676 .27066 .37989 Mtetra
.616 .95 .784 r
.27066 .37989 .27819 .37676 .28866 .37094 .28133 .37227 Mtetra
.756 .992 .878 r
.28133 .37227 .28866 .37094 .29917 .36509 .29206 .36403 Mtetra
.791 .954 .923 r
.29206 .36403 .29917 .36509 .30968 .35953 .30276 .35632 Mtetra
.759 .888 .936 r
.30276 .35632 .30968 .35953 .32018 .35451 .31339 .34992 Mtetra
.644 .821 .968 r
.31339 .34992 .32018 .35451 .3306 .35126 .32387 .34635 Mtetra
.424 .727 .989 r
.32387 .34635 .3306 .35126 .34096 .34993 .33419 .34603 Mtetra
.377 .743 .991 r
.33419 .34603 .34096 .34993 .35144 .34742 .34457 .34566 Mtetra
.44 .844 .973 r
.34457 .34566 .35144 .34742 .36211 .3421 .35513 .34341 Mtetra
.566 .938 .858 r
.35513 .34341 .36211 .3421 .373 .33288 .36591 .33757 Mtetra
.608 .919 .668 r
.36591 .33757 .373 .33288 .38406 .31993 .3769 .32782 Mtetra
0 0 0 r
.3769 .32782 .38406 .31993 .39511 .30687 .38794 .31731 Mtetra
.38794 .31731 .39511 .30687 .40606 .29565 .39893 .30771 Mtetra
.13 0 0 r
.39893 .30771 .40606 .29565 .41687 .28833 .40982 .30088 Mtetra
.292 0 .088 r
.40982 .30088 .41687 .28833 .42759 .28484 .42064 .29701 Mtetra
.286 0 .076 r
.42064 .29701 .42759 .28484 .43835 .28099 .43149 .29314 Mtetra
.287 0 .077 r
.43149 .29314 .43835 .28099 .44917 .27677 .4424 .28928 Mtetra
.409 0 .146 r
.4424 .28928 .44917 .27677 .45995 .2764 .45327 .28839 Mtetra
.493 .075 .176 r
.45327 .28839 .45995 .2764 .47072 .27996 .46416 .2903 Mtetra
.512 .077 .149 r
.46416 .2903 .47072 .27996 .48157 .28539 .47512 .29314 Mtetra
.47 0 .047 r
.47512 .29314 .48157 .28539 .49253 .29075 .48618 .29523 Mtetra
.152 0 0 r
.48618 .29523 .49253 .29075 .50362 .29237 .49737 .29339 Mtetra
.497 .906 .836 r
.49737 .29339 .50362 .29237 .51481 .29006 .50863 .28793 Mtetra
.765 .948 .937 r
.50863 .28793 .51481 .29006 .52606 .28489 .51993 .28054 Mtetra
.778 .878 .92 r
.51993 .28054 .52606 .28489 .53734 .27853 .53126 .27311 Mtetra
.659 .815 .958 r
.53126 .27311 .53734 .27853 .54867 .27411 .54262 .26896 Mtetra
.491 .759 .99 r
.54262 .26896 .54867 .27411 .56006 .27149 .55406 .26769 Mtetra
.315 .72 .979 r
.55406 .26769 .56006 .27149 .57151 .26943 .56559 .26777 Mtetra
.085 .628 .844 r
.56559 .26777 .57151 .26943 .58303 .26766 .5772 .26839 Mtetra
.064 0 0 r
.5772 .26839 .58303 .26766 .59462 .26587 .58888 .2684 Mtetra
.151 0 0 r
.58888 .2684 .59462 .26587 .60627 .26414 .60064 .2679 Mtetra
.206 0 0 r
.60064 .2679 .60627 .26414 .618 .26269 .61246 .2672 Mtetra
.236 0 0 r
.61246 .2672 .618 .26269 .62981 .26147 .62435 .26642 Mtetra
.275 0 0 r
.62435 .26642 .62981 .26147 .6417 .26057 .63634 .26595 Mtetra
.276 0 0 r
.63634 .26595 .6417 .26057 .65366 .25954 .64839 .26523 Mtetra
.231 0 0 r
.64839 .26523 .65366 .25954 .66566 .2578 .66048 .26356 Mtetra
.164 0 0 r
.66048 .26356 .66566 .2578 .6777 .2553 .67259 .26075 Mtetra
.032 0 0 r
.67259 .26075 .6777 .2553 .68974 .25172 .68467 .25621 Mtetra
0 0 0 r
.68467 .25621 .68974 .25172 .70182 .24768 .69675 .25072 Mtetra
.69675 .25072 .70182 .24768 .71395 .24376 .70885 .24488 Mtetra
.405 .851 .766 r
.70885 .24488 .71395 .24376 .72617 .2403 .72101 .23933 Mtetra
.482 .894 .918 r
.72101 .23933 .72617 .2403 .73852 .23792 .73329 .23495 Mtetra
.531 .873 .99 r
.73329 .23495 .73852 .23792 .75101 .23635 .74569 .23151 Mtetra
.542 .81 .995 r
.74569 .23151 .75101 .23635 .76362 .23548 .75823 .22895 Mtetra
.531 .741 .972 r
.75823 .22895 .76362 .23548 .77637 .23521 .7709 .22725 Mtetra
.673 .755 .912 r
.1101 .44736 .11732 .45366 .12746 .44775 .12002 .44349 Mtetra
.62 .816 .975 r
.12002 .44349 .12746 .44775 .13753 .44267 .12985 .44052 Mtetra
.484 .846 .992 r
.12985 .44052 .13753 .44267 .14752 .43842 .13963 .43839 Mtetra
.211 .735 .832 r
.13963 .43839 .14752 .43842 .15745 .43507 .14936 .43703 Mtetra
.108 0 0 r
.14936 .43703 .15745 .43507 .16729 .43286 .15904 .4366 Mtetra
.217 0 0 r
.15904 .4366 .16729 .43286 .17714 .43092 .16878 .43612 Mtetra
.213 0 0 r
.16878 .43612 .17714 .43092 .18707 .42867 .17866 .43485 Mtetra
.147 0 0 r
.17866 .43485 .18707 .42867 .19715 .4255 .18872 .43236 Mtetra
.004 0 0 r
.18872 .43236 .19715 .4255 .20742 .42067 .19902 .42797 Mtetra
0 0 0 r
.19902 .42797 .20742 .42067 .21783 .41473 .20945 .42248 Mtetra
.20945 .42248 .21783 .41473 .22835 .40786 .21998 .41631 Mtetra
.21998 .41631 .22835 .40786 .23891 .40074 .23054 .41004 Mtetra
.029 0 0 r
.23054 .41004 .23891 .40074 .24946 .39392 .24108 .40421 Mtetra
.053 0 0 r
.24108 .40421 .24946 .39392 .26004 .38701 .25168 .39802 Mtetra
.032 0 0 r
.25168 .39802 .26004 .38701 .27066 .37989 .26237 .39105 Mtetra
0 0 0 r
.26237 .39105 .27066 .37989 .28133 .37227 .27316 .383 Mtetra
.27316 .383 .28133 .37227 .29206 .36403 .28406 .37374 Mtetra
.28406 .37374 .29206 .36403 .30276 .35632 .29491 .3651 Mtetra
.29491 .3651 .30276 .35632 .31339 .34992 .30565 .35831 Mtetra
.201 0 0 r
.30565 .35831 .31339 .34992 .32387 .34635 .31618 .35508 Mtetra
.441 0 .069 r
.31618 .35508 .32387 .34635 .33419 .34603 .32648 .35606 Mtetra
.491 .054 .136 r
.32648 .35606 .33419 .34603 .34457 .34566 .3368 .35814 Mtetra
.48 .068 .181 r
.3368 .35814 .34457 .34566 .35513 .34341 .34723 .3595 Mtetra
.419 .038 .208 r
.34723 .3595 .35513 .34341 .36591 .33757 .35789 .35813 Mtetra
.357 .01 .232 r
.35789 .35813 .36591 .33757 .3769 .32782 .36877 .3533 Mtetra
.364 .041 .277 r
.36877 .3533 .3769 .32782 .38794 .31731 .37975 .34721 Mtetra
.388 .078 .313 r
.37975 .34721 .38794 .31731 .39893 .30771 .39076 .34098 Mtetra
.423 .119 .342 r
.39076 .34098 .39893 .30771 .40982 .30088 .40175 .33604 Mtetra
.45 .147 .358 r
.40175 .33604 .40982 .30088 .42064 .29701 .41272 .33259 Mtetra
.446 .144 .358 r
.41272 .33259 .42064 .29701 .43149 .29314 .42376 .32873 Mtetra
.44 .139 .357 r
.42376 .32873 .43149 .29314 .4424 .28928 .43485 .32446 Mtetra
.46 .155 .361 r
.43485 .32446 .4424 .28928 .45327 .28839 .44594 .32168 Mtetra
.473 .163 .358 r
.44594 .32168 .45327 .28839 .46416 .2903 .45706 .3202 Mtetra
.466 .147 .341 r
.45706 .3202 .46416 .2903 .47512 .29314 .46825 .31859 Mtetra
.433 .102 .304 r
.46825 .31859 .47512 .29314 .48618 .29523 .47951 .31572 Mtetra
.323 0 .221 r
.47951 .31572 .48618 .29523 .49737 .29339 .49087 .30935 Mtetra
.154 0 .09 r
.49087 .30935 .49737 .29339 .50863 .28793 .50228 .3002 Mtetra
0 0 0 r
.50228 .3002 .50863 .28793 .51993 .28054 .5137 .29032 Mtetra
.5137 .29032 .51993 .28054 .53126 .27311 .52513 .28153 Mtetra
.151 0 0 r
.52513 .28153 .53126 .27311 .54262 .26896 .53658 .277 Mtetra
.338 0 0 r
.53658 .277 .54262 .26896 .55406 .26769 .5481 .27609 Mtetra
.426 0 .032 r
.5481 .27609 .55406 .26769 .56559 .26777 .55972 .27708 Mtetra
.459 .001 .077 r
.55972 .27708 .56559 .26777 .5772 .26839 .57144 .27872 Mtetra
.426 0 .088 r
.57144 .27872 .5772 .26839 .58888 .2684 .58322 .27915 Mtetra
.392 0 .083 r
.58322 .27915 .58888 .2684 .60064 .2679 .59506 .27847 Mtetra
.36 0 .063 r
.59506 .27847 .60064 .2679 .61246 .2672 .60696 .277 Mtetra
.333 0 .027 r
.60696 .277 .61246 .2672 .62435 .26642 .61892 .27517 Mtetra
.332 0 0 r
.61892 .27517 .62435 .26642 .63634 .26595 .63097 .2738 Mtetra
.306 0 0 r
.63097 .2738 .63634 .26595 .64839 .26523 .64309 .27232 Mtetra
.249 0 0 r
.64309 .27232 .64839 .26523 .66048 .26356 .65524 .27015 Mtetra
.167 0 0 r
.65524 .27015 .66048 .26356 .67259 .26075 .66742 .26685 Mtetra
.017 0 0 r
.66742 .26685 .67259 .26075 .68467 .25621 .67956 .26157 Mtetra
0 0 0 r
.67956 .26157 .68467 .25621 .69675 .25072 .69167 .25501 Mtetra
.69167 .25501 .69675 .25072 .70885 .24488 .70377 .24762 Mtetra
.405 .823 .64 r
.70377 .24762 .70885 .24488 .72101 .23933 .7159 .24016 Mtetra
.499 .904 .801 r
.7159 .24016 .72101 .23933 .73329 .23495 .72811 .23366 Mtetra
.592 .94 .934 r
.72811 .23366 .73329 .23495 .74569 .23151 .74042 .22795 Mtetra
.633 .898 .985 r
.74042 .22795 .74569 .23151 .75823 .22895 .75284 .22312 Mtetra
.627 .813 .972 r
.75284 .22312 .75823 .22895 .7709 .22725 .76539 .21923 Mtetra
.57 .727 .948 r
.10283 .44102 .1101 .44736 .12002 .44349 .11249 .43928 Mtetra
.46 .766 .996 r
.11249 .43928 .12002 .44349 .12985 .44052 .12211 .43832 Mtetra
.261 .733 .941 r
.12211 .43832 .12985 .44052 .13963 .43839 .1317 .43796 Mtetra
.026 .597 .748 r
.1317 .43796 .13963 .43839 .14936 .43703 .14129 .43806 Mtetra
.16 0 0 r
.14129 .43806 .14936 .43703 .15904 .4366 .1509 .43858 Mtetra
.173 0 0 r
.1509 .43858 .15904 .4366 .16878 .43612 .16061 .43867 Mtetra
.067 0 0 r
.16061 .43867 .16878 .43612 .17866 .43485 .17051 .43758 Mtetra
0 0 0 r
.17051 .43758 .17866 .43485 .18872 .43236 .18061 .43518 Mtetra
.305 .785 .705 r
.18061 .43518 .18872 .43236 .19902 .42797 .19093 .43105 Mtetra
.367 .823 .717 r
.19093 .43105 .19902 .42797 .20945 .42248 .20135 .42618 Mtetra
.318 .781 .655 r
.20135 .42618 .20945 .42248 .21998 .41631 .21182 .42121 Mtetra
0 0 0 r
.21182 .42121 .21998 .41631 .23054 .41004 .2223 .41649 Mtetra
.02 0 0 r
.2223 .41649 .23054 .41004 .24108 .40421 .23275 .41246 Mtetra
.08 0 0 r
.23275 .41246 .24108 .40421 .25168 .39802 .24328 .40794 Mtetra
.069 0 0 r
.24328 .40794 .25168 .39802 .26237 .39105 .25395 .40223 Mtetra
.018 0 0 r
.25395 .40223 .26237 .39105 .27316 .383 .26476 .39498 Mtetra
0 0 0 r
.26476 .39498 .27316 .383 .28406 .37374 .27573 .38599 Mtetra
.27573 .38599 .28406 .37374 .29491 .3651 .28668 .37746 Mtetra
.116 0 0 r
.28668 .37746 .29491 .3651 .30565 .35831 .2975 .37081 Mtetra
.315 0 .085 r
.2975 .37081 .30565 .35831 .31618 .35508 .30809 .36783 Mtetra
.484 .073 .186 r
.30809 .36783 .31618 .35508 .32648 .35606 .31844 .36934 Mtetra
.534 .131 .222 r
.31844 .36934 .32648 .35606 .3368 .35814 .32875 .37271 Mtetra
.541 .148 .245 r
.32875 .37271 .3368 .35814 .34723 .3595 .33914 .3764 Mtetra
.504 .125 .255 r
.33914 .3764 .34723 .3595 .35789 .35813 .34971 .37834 Mtetra
.453 .095 .266 r
.34971 .37834 .35789 .35813 .36877 .3533 .3605 .37759 Mtetra
.438 .1 .294 r
.3605 .37759 .36877 .3533 .37975 .34721 .37143 .37544 Mtetra
.436 .112 .318 r
.37143 .37544 .37975 .34721 .39076 .34098 .38245 .37243 Mtetra
.446 .131 .337 r
.38245 .37243 .39076 .34098 .40175 .33604 .39352 .36947 Mtetra
.453 .142 .348 r
.39352 .36947 .40175 .33604 .41272 .33259 .40463 .36666 Mtetra
.439 .132 .346 r
.40463 .36666 .41272 .33259 .42376 .32873 .41584 .3628 Mtetra
.424 .119 .341 r
.41584 .3628 .42376 .32873 .43485 .32446 .42712 .3579 Mtetra
.425 .118 .339 r
.42712 .3579 .43485 .32446 .44594 .32168 .43844 .35315 Mtetra
.42 .108 .328 r
.43844 .35315 .44594 .32168 .45706 .3202 .44979 .34843 Mtetra
.392 .074 .302 r
.44979 .34843 .45706 .3202 .46825 .31859 .46121 .34286 Mtetra
.338 .011 .255 r
.46121 .34286 .46825 .31859 .47951 .31572 .47268 .33586 Mtetra
.214 0 .167 r
.47268 .33586 .47951 .31572 .49087 .30935 .48422 .32613 Mtetra
.073 0 .062 r
.48422 .32613 .49087 .30935 .50228 .3002 .49578 .31461 Mtetra
.009 0 0 r
.49578 .31461 .50228 .3002 .5137 .29032 .50733 .30338 Mtetra
.056 0 0 r
.50733 .30338 .5137 .29032 .52513 .28153 .51887 .29402 Mtetra
.254 0 .06 r
.51887 .29402 .52513 .28153 .53658 .277 .53043 .28922 Mtetra
.392 0 .117 r
.53043 .28922 .53658 .277 .5481 .27609 .54205 .28814 Mtetra
.452 .026 .14 r
.54205 .28814 .5481 .27609 .55972 .27708 .55377 .289 Mtetra
.464 .037 .141 r
.55377 .289 .55972 .27708 .57144 .27872 .56557 .29033 Mtetra
.407 0 .107 r
.56557 .29033 .57144 .27872 .58322 .27915 .57744 .28991 Mtetra
.339 0 .053 r
.57744 .28991 .58322 .27915 .59506 .27847 .58936 .28792 Mtetra
.259 0 0 r
.58936 .28792 .59506 .27847 .60696 .277 .60131 .2847 Mtetra
.177 0 0 r
.60131 .2847 .60696 .277 .61892 .27517 .6133 .28098 Mtetra
.141 0 0 r
.6133 .28098 .61892 .27517 .63097 .2738 .62538 .27797 Mtetra
.07 0 0 r
.62538 .27797 .63097 .2738 .64309 .27232 .63753 .27522 Mtetra
0 0 0 r
.63753 .27522 .64309 .27232 .65524 .27015 .64973 .27237 Mtetra
.64973 .27237 .65524 .27015 .66742 .26685 .66197 .26875 Mtetra
.334 .801 .7 r
.66197 .26875 .66742 .26685 .67956 .26157 .67418 .26333 Mtetra
.454 .871 .736 r
.67418 .26333 .67956 .26157 .69167 .25501 .68636 .25654 Mtetra
.557 .923 .763 r
.68636 .25654 .69167 .25501 .70377 .24762 .69851 .24851 Mtetra
.629 .958 .807 r
.69851 .24851 .70377 .24762 .7159 .24016 .71065 .24001 Mtetra
.668 .975 .867 r
.71065 .24001 .7159 .24016 .72811 .23366 .72284 .23194 Mtetra
.715 .972 .928 r
.72284 .23194 .72811 .23366 .74042 .22795 .73509 .22432 Mtetra
.733 .928 .955 r
.73509 .22432 .74042 .22795 .75284 .22312 .74741 .21733 Mtetra
.718 .85 .945 r
.74741 .21733 .75284 .22312 .76539 .21923 .75983 .21113 Mtetra
.437 .675 .963 r
.09551 .43462 .10283 .44102 .11249 .43928 .10495 .43471 Mtetra
.304 .68 .976 r
.10495 .43471 .11249 .43928 .12211 .43832 .11438 .4353 Mtetra
.155 .646 .918 r
.11438 .4353 .12211 .43832 .1317 .43796 .12385 .43612 Mtetra
.049 .6 .829 r
.12385 .43612 .1317 .43796 .14129 .43806 .13338 .43694 Mtetra
.014 .583 .776 r
.13338 .43694 .14129 .43806 .1509 .43858 .143 .43754 Mtetra
.13 .67 .839 r
.143 .43754 .1509 .43858 .16061 .43867 .15278 .43733 Mtetra
.361 .81 .947 r
.15278 .43733 .16061 .43867 .17051 .43758 .16278 .43566 Mtetra
.527 .873 .989 r
.16278 .43566 .17051 .43758 .18061 .43518 .17295 .43281 Mtetra
.641 .895 .985 r
.17295 .43281 .18061 .43518 .19093 .43105 .1833 .4287 Mtetra
.65 .898 .983 r
.1833 .4287 .19093 .43105 .20135 .42618 .19371 .42443 Mtetra
.579 .897 .986 r
.19371 .42443 .20135 .42618 .21182 .42121 .20408 .42083 Mtetra
.422 .859 .925 r
.20408 .42083 .21182 .42121 .2223 .41649 .21442 .41797 Mtetra
0 0 0 r
.21442 .41797 .2223 .41649 .23275 .41246 .22472 .41612 Mtetra
.006 0 0 r
.22472 .41612 .23275 .41246 .24328 .40794 .23511 .41378 Mtetra
.004 0 0 r
.23511 .41378 .24328 .40794 .25395 .40223 .24568 .40997 Mtetra
0 0 0 r
.24568 .40997 .25395 .40223 .26476 .39498 .25644 .4043 Mtetra
.25644 .4043 .26476 .39498 .27573 .38599 .26741 .39646 Mtetra
.26741 .39646 .27573 .38599 .28668 .37746 .27838 .38867 Mtetra
.09 0 0 r
.27838 .38867 .28668 .37746 .2975 .37081 .28927 .38238 Mtetra
.292 0 .045 r
.28927 .38238 .2975 .37081 .30809 .36783 .29994 .37936 Mtetra
.465 .039 .146 r
.29994 .37936 .30809 .36783 .31844 .36934 .31039 .38056 Mtetra
.532 .106 .179 r
.31039 .38056 .31844 .36934 .32875 .37271 .32076 .38401 Mtetra
.559 .136 .195 r
.32076 .38401 .32875 .37271 .33914 .3764 .33117 .38853 Mtetra
.539 .122 .198 r
.33117 .38853 .33914 .3764 .34971 .37834 .34171 .39229 Mtetra
.496 .092 .204 r
.34171 .39229 .34971 .37834 .3605 .37759 .35245 .39429 Mtetra
.471 .088 .23 r
.35245 .39429 .3605 .37759 .37143 .37544 .36334 .39499 Mtetra
.453 .088 .254 r
.36334 .39499 .37143 .37544 .38245 .37243 .37435 .3945 Mtetra
.444 .092 .273 r
.37435 .3945 .38245 .37243 .39352 .36947 .38548 .39317 Mtetra
.432 .088 .281 r
.38548 .39317 .39352 .36947 .40463 .36666 .3967 .39095 Mtetra
.401 .063 .273 r
.3967 .39095 .40463 .36666 .41584 .3628 .40804 .38709 Mtetra
.365 .031 .26 r
.40804 .38709 .41584 .3628 .42712 .3579 .41949 .38159 Mtetra
.34 .007 .245 r
.41949 .38159 .42712 .3579 .43844 .35315 .43099 .37519 Mtetra
.304 0 .216 r
.43099 .37519 .43844 .35315 .44979 .34843 .44255 .36795 Mtetra
.235 0 .161 r
.44255 .36795 .44979 .34843 .46121 .34286 .45416 .35947 Mtetra
.128 0 .074 r
.45416 .35947 .46121 .34286 .47268 .33586 .46581 .34969 Mtetra
0 0 0 r
.46581 .34969 .47268 .33586 .48422 .32613 .47749 .33809 Mtetra
.47749 .33809 .48422 .32613 .49578 .31461 .48918 .32569 Mtetra
.48918 .32569 .49578 .31461 .50733 .30338 .50084 .31436 Mtetra
.50084 .31436 .50733 .30338 .51887 .29402 .51249 .30529 Mtetra
.22 0 .007 r
.51249 .30529 .51887 .29402 .53043 .28922 .52416 .30049 Mtetra
.363 0 .074 r
.52416 .30049 .53043 .28922 .54205 .28814 .53587 .29902 Mtetra
.413 0 .088 r
.53587 .29902 .54205 .28814 .55377 .289 .54767 .29909 Mtetra
.407 0 .062 r
.54767 .29909 .55377 .289 .56557 .29033 .55956 .29923 Mtetra
.294 0 0 r
.55956 .29923 .56557 .29033 .57744 .28991 .57149 .29715 Mtetra
.135 0 0 r
.57149 .29715 .57744 .28991 .58936 .28792 .58346 .29316 Mtetra
0 0 0 r
.58346 .29316 .58936 .28792 .60131 .2847 .59544 .28767 Mtetra
.59544 .28767 .60131 .2847 .6133 .28098 .60745 .28166 Mtetra
.422 .867 .822 r
.60745 .28166 .6133 .28098 .62538 .27797 .61953 .27669 Mtetra
.504 .898 .943 r
.61953 .27669 .62538 .27797 .63753 .27522 .63169 .27247 Mtetra
.531 .877 .988 r
.63169 .27247 .63753 .27522 .64973 .27237 .64393 .26894 Mtetra
.568 .873 .994 r
.64393 .26894 .64973 .27237 .66197 .26875 .65621 .26525 Mtetra
.645 .9 .983 r
.65621 .26525 .66197 .26875 .67418 .26333 .6685 .26024 Mtetra
.695 .93 .967 r
.6685 .26024 .67418 .26333 .68636 .25654 .68077 .254 Mtetra
.748 .958 .939 r
.68077 .254 .68636 .25654 .69851 .24851 .693 .24623 Mtetra
.774 .97 .922 r
.693 .24623 .69851 .24851 .71065 .24001 .70521 .2376 Mtetra
.783 .969 .918 r
.70521 .2376 .71065 .24001 .72284 .23194 .71742 .22872 Mtetra
.795 .951 .921 r
.71742 .22872 .72284 .23194 .73509 .22432 .72964 .21982 Mtetra
.794 .912 .92 r
.72964 .21982 .73509 .22432 .74741 .21733 .7419 .21115 Mtetra
.777 .855 .909 r
.7419 .21115 .74741 .21733 .75983 .21113 .75422 .20298 Mtetra
.347 .632 .959 r
.08813 .42819 .09551 .43462 .10495 .43471 .09746 .42921 Mtetra
.288 .638 .965 r
.09746 .42921 .10495 .43471 .11438 .4353 .10683 .43035 Mtetra
.278 .654 .969 r
.10683 .43035 .11438 .4353 .12385 .43612 .11629 .4313 Mtetra
.332 .688 .98 r
.11629 .4313 .12385 .43612 .13338 .43694 .12589 .43174 Mtetra
.437 .724 .986 r
.12589 .43174 .13338 .43694 .143 .43754 .13564 .43132 Mtetra
.548 .731 .96 r
.13564 .43132 .143 .43754 .15278 .43733 .14558 .42979 Mtetra
.634 .718 .908 r
.14558 .42979 .15278 .43733 .16278 .43566 .15575 .42671 Mtetra
.661 .689 .865 r
.15575 .42671 .16278 .43566 .17295 .43281 .16606 .42274 Mtetra
.672 .668 .838 r
.16606 .42274 .17295 .43281 .1833 .4287 .17648 .41818 Mtetra
.655 .653 .836 r
.17648 .41818 .1833 .4287 .19371 .42443 .18687 .41414 Mtetra
.61 .64 .856 r
.18687 .41414 .19371 .42443 .20408 .42083 .19715 .41157 Mtetra
.559 .644 .891 r
.19715 .41157 .20408 .42083 .21442 .41797 .20735 .41025 Mtetra
.466 .65 .939 r
.20735 .41025 .21442 .41797 .22472 .41612 .21748 .41028 Mtetra
.445 .708 .978 r
.21748 .41028 .22472 .41612 .23511 .41378 .22771 .40995 Mtetra
.505 .808 .999 r
.22771 .40995 .23511 .41378 .24568 .40997 .23814 .40808 Mtetra
.597 .903 .985 r
.23814 .40808 .24568 .40997 .25644 .4043 .24879 .40417 Mtetra
.698 .967 .935 r
.24879 .40417 .25644 .4043 .26741 .39646 .2597 .39775 Mtetra
.663 .973 .884 r
.2597 .39775 .26741 .39646 .27838 .38867 .27066 .39084 Mtetra
.537 .923 .819 r
.27066 .39084 .27838 .38867 .28927 .38238 .28159 .38473 Mtetra
.247 .749 .696 r
.28159 .38473 .28927 .38238 .29994 .37936 .29237 .38111 Mtetra
.121 0 0 r
.29237 .38111 .29994 .37936 .31039 .38056 .30295 .38096 Mtetra
.264 0 0 r
.30295 .38096 .31039 .38056 .32076 .38401 .31345 .38298 Mtetra
.315 0 0 r
.31345 .38298 .32076 .38401 .33117 .38853 .32395 .38642 Mtetra
.228 0 0 r
.32395 .38642 .33117 .38853 .34171 .39229 .33454 .38979 Mtetra
0 .487 .777 r
.33454 .38979 .34171 .39229 .35245 .39429 .34528 .39219 Mtetra
.004 .562 .813 r
.34528 .39219 .35245 .39429 .36334 .39499 .35617 .39364 Mtetra
.083 .633 .826 r
.35617 .39364 .36334 .39499 .37435 .3945 .36718 .39393 Mtetra
.151 .691 .821 r
.36718 .39393 .37435 .3945 .38548 .39317 .37833 .39309 Mtetra
.259 .768 .842 r
.37833 .39309 .38548 .39317 .3967 .39095 .3896 .39097 Mtetra
.438 .874 .893 r
.3896 .39097 .3967 .39095 .40804 .38709 .40099 .38709 Mtetra
.591 .944 .916 r
.40099 .38709 .40804 .38709 .41949 .38159 .4125 .38145 Mtetra
.682 .971 .918 r
.4125 .38145 .41949 .38159 .43099 .37519 .42408 .3745 Mtetra
.757 .978 .918 r
.42408 .3745 .43099 .37519 .44255 .36795 .43572 .36641 Mtetra
.813 .962 .906 r
.43572 .36641 .44255 .36795 .45416 .35947 .44741 .35715 Mtetra
.843 .94 .888 r
.44741 .35715 .45416 .35947 .46581 .34969 .45913 .34689 Mtetra
.862 .924 .867 r
.45913 .34689 .46581 .34969 .47749 .33809 .47088 .33565 Mtetra
.865 .935 .867 r
.47088 .33565 .47749 .33809 .48918 .32569 .48261 .32429 Mtetra
.828 .969 .892 r
.48261 .32429 .48918 .32569 .50084 .31436 .49434 .31435 Mtetra
.703 .981 .898 r
.49434 .31435 .50084 .31436 .51249 .30529 .50605 .3066 Mtetra
.331 .811 .77 r
.50605 .3066 .51249 .30529 .52416 .30049 .51778 .30237 Mtetra
0 0 0 r
.51778 .30237 .52416 .30049 .53587 .29902 .52956 .30068 Mtetra
.044 0 0 r
.52956 .30068 .53587 .29902 .54767 .29909 .54141 .2998 Mtetra
.081 .64 .703 r
.54141 .2998 .54767 .29909 .55956 .29923 .55334 .29844 Mtetra
.459 .881 .921 r
.55334 .29844 .55956 .29923 .57149 .29715 .5653 .29451 Mtetra
.688 .933 .967 r
.5653 .29451 .57149 .29715 .58346 .29316 .57729 .28848 Mtetra
.77 .885 .928 r
.57729 .28848 .58346 .29316 .59544 .28767 .58928 .28086 Mtetra
.771 .818 .89 r
.58928 .28086 .59544 .28767 .60745 .28166 .60128 .27285 Mtetra
.722 .749 .873 r
.60128 .27285 .60745 .28166 .61953 .27669 .61335 .26623 Mtetra
.679 .693 .856 r
.61335 .26623 .61953 .27669 .63169 .27247 .6255 .26087 Mtetra
.632 .648 .848 r
.6255 .26087 .63169 .27247 .64393 .26894 .63774 .25705 Mtetra
.616 .635 .847 r
.63774 .25705 .64393 .26894 .65621 .26525 .65007 .25375 Mtetra
.634 .653 .851 r
.65007 .25375 .65621 .26525 .6685 .26024 .66243 .24984 Mtetra
.663 .691 .866 r
.66243 .24984 .6685 .26024 .68077 .254 .6748 .24501 Mtetra
.715 .748 .878 r
.6748 .24501 .68077 .254 .693 .24623 .68714 .23855 Mtetra
.754 .799 .889 r
.68714 .23855 .693 .24623 .70521 .2376 .69945 .23092 Mtetra
.783 .838 .894 r
.69945 .23092 .70521 .2376 .71742 .22872 .71174 .22237 Mtetra
.799 .853 .891 r
.71174 .22237 .71742 .22872 .72964 .21982 .72401 .21328 Mtetra
.802 .849 .885 r
.72401 .21328 .72964 .21982 .7419 .21115 .73628 .20396 Mtetra
.795 .829 .878 r
.73628 .20396 .7419 .21115 .75422 .20298 .74857 .19475 Mtetra
.34 .628 .959 r
.0807 .4217 .08813 .42819 .09746 .42921 .09003 .42278 Mtetra
.365 .644 .962 r
.09003 .42278 .09746 .42921 .10683 .43035 .09945 .42358 Mtetra
.431 .663 .958 r
.09945 .42358 .10683 .43035 .11629 .4313 .10902 .42379 Mtetra
.514 .674 .936 r
.10902 .42379 .11629 .4313 .12589 .43174 .11876 .42306 Mtetra
.594 .671 .893 r
.11876 .42306 .12589 .43174 .13564 .43132 .12873 .42095 Mtetra
.637 .647 .844 r
.12873 .42095 .13564 .43132 .14558 .42979 .13889 .41757 Mtetra
.665 .625 .8 r
.13889 .41757 .14558 .42979 .15575 .42671 .14927 .41274 Mtetra
.665 .6 .773 r
.14927 .41274 .15575 .42671 .16606 .42274 .15973 .40744 Mtetra
.654 .579 .759 r
.15973 .40744 .16606 .42274 .17648 .41818 .1702 .40232 Mtetra
.626 .559 .759 r
.1702 .40232 .17648 .41818 .18687 .41414 .18057 .39841 Mtetra
.573 .531 .77 r
.18057 .39841 .18687 .41414 .19715 .41157 .19075 .39671 Mtetra
.52 .515 .79 r
.19075 .39671 .19715 .41157 .20735 .41025 .20081 .39673 Mtetra
.448 .497 .817 r
.20081 .39673 .20735 .41025 .21748 .41028 .21077 .39839 Mtetra
.441 .526 .849 r
.21077 .39839 .21748 .41028 .22771 .40995 .22083 .39985 Mtetra
.499 .599 .885 r
.22083 .39985 .22771 .40995 .23814 .40808 .2311 .39981 Mtetra
.592 .69 .911 r
.2311 .39981 .23814 .40808 .24879 .40417 .24162 .3976 Mtetra
.699 .775 .911 r
.24162 .3976 .24879 .40417 .2597 .39775 .25243 .39262 Mtetra
.739 .829 .92 r
.25243 .39262 .2597 .39775 .27066 .39084 .26337 .38651 Mtetra
.743 .857 .933 r
.26337 .38651 .27066 .39084 .28159 .38473 .27435 .38031 Mtetra
.686 .847 .96 r
.27435 .38031 .28159 .38473 .29237 .38111 .28524 .37558 Mtetra
.569 .776 .976 r
.28524 .37558 .29237 .38111 .30295 .38096 .29599 .3733 Mtetra
.493 .671 .943 r
.29599 .3733 .30295 .38096 .31345 .38298 .30667 .37281 Mtetra
.447 .575 .89 r
.30667 .37281 .31345 .38298 .32395 .38642 .31733 .37375 Mtetra
.458 .524 .838 r
.31733 .37375 .32395 .38642 .33454 .38979 .32804 .37506 Mtetra
.484 .504 .802 r
.32804 .37506 .33454 .38979 .34528 .39219 .33885 .37609 Mtetra
.506 .497 .781 r
.33885 .37609 .34528 .39219 .35617 .39364 .34977 .37662 Mtetra
.531 .501 .768 r
.34977 .37662 .35617 .39364 .36718 .39393 .3608 .37634 Mtetra
.557 .51 .759 r
.3608 .37634 .36718 .39393 .37833 .39309 .37195 .37509 Mtetra
.583 .522 .752 r
.37195 .37509 .37833 .39309 .3896 .39097 .38322 .37266 Mtetra
.613 .536 .744 r
.38322 .37266 .3896 .39097 .40099 .38709 .39461 .36874 Mtetra
.64 .552 .739 r
.39461 .36874 .40099 .38709 .4125 .38145 .4061 .36333 Mtetra
.661 .566 .737 r
.4061 .36333 .4125 .38145 .42408 .3745 .41767 .35672 Mtetra
.678 .578 .736 r
.41767 .35672 .42408 .3745 .43572 .36641 .4293 .34912 Mtetra
.693 .591 .737 r
.4293 .34912 .43572 .36641 .44741 .35715 .44097 .3407 Mtetra
.706 .606 .742 r
.44097 .3407 .44741 .35715 .45913 .34689 .45267 .33176 Mtetra
.72 .628 .754 r
.45267 .33176 .45913 .34689 .47088 .33565 .46439 .32251 Mtetra
.731 .659 .778 r
.46439 .32251 .47088 .33565 .48261 .32429 .47612 .31362 Mtetra
.727 .7 .824 r
.47612 .31362 .48261 .32429 .49434 .31435 .48784 .30617 Mtetra
.702 .751 .89 r
.48784 .30617 .49434 .31435 .50605 .3066 .49958 .30052 Mtetra
.606 .785 .967 r
.49958 .30052 .50605 .3066 .51778 .30237 .51134 .29735 Mtetra
.495 .778 .995 r
.51134 .29735 .51778 .30237 .52956 .30068 .52316 .2957 Mtetra
.498 .782 .996 r
.52316 .2957 .52956 .30068 .54141 .2998 .53505 .29395 Mtetra
.585 .789 .977 r
.53505 .29395 .54141 .2998 .55334 .29844 .547 .29106 Mtetra
.706 .782 .911 r
.547 .29106 .55334 .29844 .5653 .29451 .55898 .28532 Mtetra
.75 .747 .849 r
.55898 .28532 .5653 .29451 .57729 .28848 .57097 .27735 Mtetra
.761 .71 .805 r
.57097 .27735 .57729 .28848 .58928 .28086 .58295 .26781 Mtetra
.746 .673 .779 r
.58295 .26781 .58928 .28086 .60128 .27285 .59494 .25806 Mtetra
.705 .63 .771 r
.59494 .25806 .60128 .27285 .61335 .26623 .60698 .24998 Mtetra
.664 .592 .764 r
.60698 .24998 .61335 .26623 .6255 .26087 .6191 .24365 Mtetra
.616 .555 .763 r
.6191 .24365 .6255 .26087 .63774 .25705 .63134 .23961 Mtetra
.589 .538 .765 r
.63134 .23961 .63774 .25705 .65007 .25375 .64368 .23682 Mtetra
.586 .542 .773 r
.64368 .23682 .65007 .25375 .66243 .24984 .6561 .23421 Mtetra
.599 .567 .789 r
.6561 .23421 .66243 .24984 .6748 .24501 .66856 .23111 Mtetra
.64 .615 .808 r
.66856 .23111 .6748 .24501 .68714 .23855 .68101 .22651 Mtetra
.681 .668 .83 r
.68101 .22651 .68714 .23855 .69945 .23092 .69345 .22058 Mtetra
.727 .723 .847 r
.69345 .22058 .69945 .23092 .71174 .22237 .70584 .2132 Mtetra
.758 .763 .857 r
.70584 .2132 .71174 .22237 .72401 .21328 .7182 .20482 Mtetra
.779 .789 .861 r
.7182 .20482 .72401 .21328 .73628 .20396 .73054 .19579 Mtetra
.788 .801 .863 r
.73054 .19579 .73628 .20396 .74857 .19475 .74288 .18646 Mtetra
.437 .674 .963 r
.07322 .41517 .0807 .4217 .09003 .42278 .08269 .41521 Mtetra
.501 .667 .937 r
.08269 .41521 .09003 .42278 .09945 .42358 .0923 .41467 Mtetra
.56 .651 .896 r
.0923 .41467 .09945 .42358 .10902 .42379 .10207 .41331 Mtetra
.607 .633 .85 r
.10207 .41331 .10902 .42379 .11876 .42306 .11204 .41082 Mtetra
.647 .617 .805 r
.11204 .41082 .11876 .42306 .12873 .42095 .12225 .40677 Mtetra
.661 .596 .771 r
.12225 .40677 .12873 .42095 .13889 .41757 .13263 .40159 Mtetra
.67 .58 .745 r
.13263 .40159 .13889 .41757 .14927 .41274 .14316 .39535 Mtetra
.66 .561 .732 r
.14316 .39535 .14927 .41274 .15973 .40744 .15371 .38922 Mtetra
.639 .542 .729 r
.15371 .38922 .15973 .40744 .1702 .40232 .16417 .38407 Mtetra
.604 .522 .735 r
.16417 .38407 .1702 .40232 .18057 .39841 .17446 .38076 Mtetra
.538 .489 .75 r
.17446 .38076 .18057 .39841 .19075 .39671 .1845 .38025 Mtetra
.47 .464 .769 r
.1845 .38025 .19075 .39671 .20081 .39673 .19438 .38181 Mtetra
.381 .434 .791 r
.19438 .38181 .20081 .39673 .21077 .39839 .20416 .38516 Mtetra
.362 .455 .821 r
.20416 .38516 .21077 .39839 .22083 .39985 .21404 .38839 Mtetra
.422 .527 .86 r
.21404 .38839 .22083 .39985 .2311 .39981 .22414 .39005 Mtetra
.528 .624 .891 r
.22414 .39005 .2311 .39981 .24162 .3976 .23455 .38933 Mtetra
.655 .715 .892 r
.23455 .38933 .24162 .3976 .25243 .39262 .24528 .38546 Mtetra
.718 .764 .889 r
.24528 .38546 .25243 .39262 .26337 .38651 .25622 .3797 Mtetra
.749 .781 .879 r
.25622 .3797 .26337 .38651 .27435 .38031 .26728 .37285 Mtetra
.735 .761 .874 r
.26728 .37285 .27435 .38031 .28524 .37558 .27833 .36637 Mtetra
.688 .705 .86 r
.27833 .36637 .28524 .37558 .29599 .3733 .28931 .36121 Mtetra
.64 .627 .821 r
.28931 .36121 .29599 .3733 .30667 .37281 .30024 .35728 Mtetra
.595 .553 .777 r
.30024 .35728 .30667 .37281 .31733 .37375 .31112 .3546 Mtetra
.573 .501 .737 r
.31112 .3546 .31733 .37375 .32804 .37506 .32202 .35256 Mtetra
.561 .469 .707 r
.32202 .35256 .32804 .37506 .33885 .37609 .33296 .35079 Mtetra
.557 .449 .687 r
.33296 .35079 .33885 .37609 .34977 .37662 .34396 .34905 Mtetra
.558 .439 .673 r
.34396 .34905 .34977 .37662 .3608 .37634 .35503 .34708 Mtetra
.563 .435 .664 r
.35503 .34708 .3608 .37634 .37195 .37509 .36619 .34464 Mtetra
.57 .436 .658 r
.36619 .34464 .37195 .37509 .38322 .37266 .37743 .34154 Mtetra
.58 .44 .655 r
.37743 .34154 .38322 .37266 .39461 .36874 .38877 .33757 Mtetra
.591 .447 .655 r
.38877 .33757 .39461 .36874 .4061 .36333 .40018 .33272 Mtetra
.6 .456 .657 r
.40018 .33272 .4061 .36333 .41767 .35672 .41167 .3272 Mtetra
.608 .465 .662 r
.41167 .3272 .41767 .35672 .4293 .34912 .4232 .32121 Mtetra
.616 .477 .669 r
.4232 .32121 .4293 .34912 .44097 .3407 .43478 .31498 Mtetra
.622 .491 .681 r
.43478 .31498 .44097 .3407 .45267 .33176 .44638 .30877 Mtetra
.628 .51 .7 r
.44638 .30877 .45267 .33176 .46439 .32251 .45802 .30283 Mtetra
.631 .536 .728 r
.45802 .30283 .46439 .32251 .47612 .31362 .46968 .29752 Mtetra
.622 .567 .772 r
.46968 .29752 .47612 .31362 .48784 .30617 .48136 .29348 Mtetra
.601 .608 .831 r
.48136 .29348 .48784 .30617 .49958 .30052 .49308 .29069 Mtetra
.552 .648 .898 r
.49308 .29069 .49958 .30052 .51134 .29735 .50486 .28924 Mtetra
.519 .683 .94 r
.50486 .28924 .51134 .29735 .52316 .2957 .5167 .28818 Mtetra
.567 .725 .948 r
.5167 .28818 .52316 .2957 .53505 .29395 .52862 .28601 Mtetra
.649 .746 .92 r
.52862 .28601 .53505 .29395 .547 .29106 .54059 .28192 Mtetra
.736 .745 .859 r
.54059 .28192 .547 .29106 .55898 .28532 .55259 .27459 Mtetra
.769 .721 .808 r
.55259 .27459 .55898 .28532 .57097 .27735 .56459 .26481 Mtetra
.775 .693 .772 r
.56459 .26481 .57097 .27735 .58295 .26781 .57657 .25339 Mtetra
.76 .66 .752 r
.57657 .25339 .58295 .26781 .59494 .25806 .58854 .24182 Mtetra
.719 .62 .746 r
.58854 .24182 .59494 .25806 .60698 .24998 .60055 .23208 Mtetra
.676 .581 .741 r
.60055 .23208 .60698 .24998 .6191 .24365 .61263 .22445 Mtetra
.621 .538 .739 r
.61263 .22445 .6191 .24365 .63134 .23961 .62484 .21971 Mtetra
.583 .51 .738 r
.62484 .21971 .63134 .23961 .64368 .23682 .63717 .21686 Mtetra
.563 .498 .74 r
.63717 .21686 .64368 .23682 .6561 .23421 .6496 .21503 Mtetra
.561 .505 .749 r
.6496 .21503 .6561 .23421 .66856 .23111 .66212 .21331 Mtetra
.587 .534 .763 r
.66212 .21331 .66856 .23111 .68101 .22651 .67466 .2105 Mtetra
.617 .573 .783 r
.67466 .2105 .68101 .22651 .69345 .22058 .68721 .20652 Mtetra
.661 .625 .802 r
.68721 .20652 .69345 .22058 .70584 .2132 .69972 .2009 Mtetra
.698 .673 .822 r
.69972 .2009 .70584 .2132 .7182 .20482 .71221 .19409 Mtetra
.73 .719 .841 r
.71221 .19409 .7182 .20482 .73054 .19579 .72468 .1864 Mtetra
.755 .76 .857 r
.72468 .1864 .73054 .19579 .74288 .18646 .73713 .1781 Mtetra
.554 .721 .951 r
.06568 .40859 .07322 .41517 .08269 .41521 .07538 .40701 Mtetra
.603 .688 .902 r
.07538 .40701 .08269 .41521 .0923 .41467 .08524 .40467 Mtetra
.635 .655 .852 r
.08524 .40467 .0923 .41467 .10207 .41331 .09528 .40139 Mtetra
.658 .627 .808 r
.09528 .40139 .10207 .41331 .11204 .41082 .1055 .39697 Mtetra
.678 .608 .77 r
.1055 .39697 .11204 .41082 .12225 .40677 .11595 .391 Mtetra
.681 .587 .744 r
.11595 .391 .12225 .40677 .13263 .40159 .12653 .38418 Mtetra
.68 .572 .727 r
.12653 .38418 .13263 .40159 .14316 .39535 .1372 .37677 Mtetra
.664 .553 .719 r
.1372 .37677 .14316 .39535 .15371 .38922 .14781 .36998 Mtetra
.634 .531 .72 r
.14781 .36998 .15371 .38922 .16417 .38407 .15826 .36482 Mtetra
.591 .506 .726 r
.15826 .36482 .16417 .38407 .17446 .38076 .16849 .36193 Mtetra
.515 .464 .737 r
.16849 .36193 .17446 .38076 .1845 .38025 .17841 .3622 Mtetra
.442 .427 .747 r
.17841 .3622 .1845 .38025 .19438 .38181 .18817 .36471 Mtetra
.36 .389 .756 r
.18817 .36471 .19438 .38181 .20416 .38516 .19782 .36906 Mtetra
.351 .399 .771 r
.19782 .36906 .20416 .38516 .21404 .38839 .20757 .37332 Mtetra
.412 .453 .793 r
.20757 .37332 .21404 .38839 .22414 .39005 .21756 .376 Mtetra
.509 .525 .809 r
.21756 .376 .22414 .39005 .23455 .38933 .22787 .37617 Mtetra
.618 .597 .807 r
.22787 .37617 .23455 .38933 .24528 .38546 .23855 .37293 Mtetra
.68 .636 .799 r
.23855 .37293 .24528 .38546 .25622 .3797 .2495 .36721 Mtetra
.717 .652 .784 r
.2495 .36721 .25622 .3797 .26728 .37285 .26064 .35954 Mtetra
.72 .642 .77 r
.26064 .35954 .26728 .37285 .27833 .36637 .27184 .35127 Mtetra
.702 .612 .754 r
.27184 .35127 .27833 .36637 .28931 .36121 .28303 .34332 Mtetra
.674 .57 .73 r
.28303 .34332 .28931 .36121 .30024 .35728 .2942 .336 Mtetra
.642 .526 .706 r
.2942 .336 .30024 .35728 .31112 .3546 .30532 .32964 Mtetra
.617 .489 .683 r
.30532 .32964 .31112 .3546 .32202 .35256 .31641 .32404 Mtetra
.598 .46 .664 r
.31641 .32404 .32202 .35256 .33296 .35079 .3275 .31912 Mtetra
.584 .439 .65 r
.3275 .31912 .33296 .35079 .34396 .34905 .3386 .31471 Mtetra
.575 .425 .64 r
.3386 .31471 .34396 .34905 .35503 .34708 .34971 .31066 Mtetra
.57 .416 .633 r
.34971 .31066 .35503 .34708 .36619 .34464 .36087 .30677 Mtetra
.568 .411 .628 r
.36087 .30677 .36619 .34464 .37743 .34154 .37207 .30288 Mtetra
.568 .409 .626 r
.37207 .30288 .37743 .34154 .38877 .33757 .38332 .29885 Mtetra
.57 .41 .626 r
.38332 .29885 .38877 .33757 .40018 .33272 .39463 .29468 Mtetra
.57 .412 .628 r
.39463 .29468 .40018 .33272 .41167 .3272 .40598 .29051 Mtetra
.57 .416 .633 r
.40598 .29051 .41167 .3272 .4232 .32121 .41738 .2865 Mtetra
.569 .421 .64 r
.41738 .2865 .4232 .32121 .43478 .31498 .42881 .28285 Mtetra
.566 .427 .651 r
.42881 .28285 .43478 .31498 .44638 .30877 .44028 .27971 Mtetra
.561 .436 .666 r
.44028 .27971 .44638 .30877 .45802 .30283 .45179 .27727 Mtetra
.554 .448 .688 r
.45179 .27727 .45802 .30283 .46968 .29752 .46334 .2756 Mtetra
.538 .462 .718 r
.46334 .2756 .46968 .29752 .48136 .29348 .47495 .2749 Mtetra
.523 .483 .754 r
.47495 .2749 .48136 .29348 .49308 .29069 .48662 .27487 Mtetra
.509 .509 .792 r
.48662 .27487 .49308 .29069 .50486 .28924 .49838 .27516 Mtetra
.523 .545 .82 r
.49838 .27516 .50486 .28924 .5167 .28818 .51022 .27486 Mtetra
.583 .591 .826 r
.51022 .27486 .5167 .28818 .52862 .28601 .52214 .27258 Mtetra
.649 .623 .81 r
.52214 .27258 .52862 .28601 .54059 .28192 .53413 .26777 Mtetra
.713 .643 .777 r
.53413 .26777 .54059 .28192 .55259 .27459 .54614 .25946 Mtetra
.744 .645 .75 r
.54614 .25946 .55259 .27459 .56459 .26481 .55814 .24855 Mtetra
.756 .638 .73 r
.55814 .24855 .56459 .26481 .57657 .25339 .57012 .236 Mtetra
.748 .623 .721 r
.57012 .236 .57657 .25339 .58854 .24182 .58208 .22334 Mtetra
.717 .597 .721 r
.58208 .22334 .58854 .24182 .60055 .23208 .59408 .21254 Mtetra
.679 .568 .722 r
.59408 .21254 .60055 .23208 .61263 .22445 .60613 .20403 Mtetra
.624 .529 .726 r
.60613 .20403 .61263 .22445 .62484 .21971 .61831 .19876 Mtetra
.581 .5 .728 r
.61831 .19876 .62484 .21971 .63717 .21686 .63061 .19584 Mtetra
.549 .48 .731 r
.63061 .19584 .63717 .21686 .6496 .21503 .64305 .19461 Mtetra
.535 .477 .738 r
.64305 .19461 .6496 .21503 .66212 .21331 .6556 .19402 Mtetra
.548 .497 .75 r
.6556 .19402 .66212 .21331 .67466 .2105 .66821 .19284 Mtetra
.569 .527 .768 r
.66821 .19284 .67466 .2105 .68721 .20652 .68086 .19077 Mtetra
.61 .574 .789 r
.68086 .19077 .68721 .20652 .69972 .2009 .69349 .18709 Mtetra
.645 .622 .813 r
.69349 .18709 .69972 .2009 .71221 .19409 .70612 .18221 Mtetra
.679 .674 .839 r
.70612 .18221 .71221 .19409 .72468 .1864 .71873 .17635 Mtetra
.71 .729 .865 r
.71873 .17635 .72468 .1864 .73713 .1781 .73134 .16968 Mtetra
.64 .748 .926 r
.05808 .40196 .06568 .40859 .07538 .40701 .06804 .39872 Mtetra
.667 .707 .878 r
.06804 .39872 .07538 .40701 .08524 .40467 .07815 .39465 Mtetra
.684 .673 .833 r
.07815 .39465 .08524 .40467 .09528 .40139 .08842 .38964 Mtetra
.696 .646 .796 r
.08842 .38964 .09528 .40139 .1055 .39697 .09887 .38353 Mtetra
.708 .627 .764 r
.09887 .38353 .1055 .39697 .11595 .391 .10953 .37599 Mtetra
.707 .609 .744 r
.10953 .37599 .11595 .391 .12653 .38418 .12029 .36777 Mtetra
.702 .592 .73 r
.12029 .36777 .12653 .38418 .1372 .37677 .13111 .35923 Mtetra
.683 .573 .725 r
.13111 .35923 .1372 .37677 .14781 .36998 .14183 .35151 Mtetra
.65 .546 .724 r
.14183 .35151 .14781 .36998 .15826 .36482 .15235 .34559 Mtetra
.605 .514 .725 r
.15235 .34559 .15826 .36482 .16849 .36193 .16264 .34201 Mtetra
.535 .466 .725 r
.16264 .34201 .16849 .36193 .17841 .3622 .17262 .3415 Mtetra
.477 .423 .718 r
.17262 .3415 .17841 .3622 .18817 .36471 .18243 .34317 Mtetra
.429 .385 .708 r
.18243 .34317 .18817 .36471 .19782 .36906 .19213 .34659 Mtetra
.434 .382 .701 r
.19213 .34659 .19782 .36906 .20757 .37332 .20191 .35002 Mtetra
.474 .403 .697 r
.20191 .35002 .20757 .37332 .21756 .376 .21192 .35208 Mtetra
.527 .435 .693 r
.21192 .35208 .21756 .376 .22787 .37617 .22223 .35185 Mtetra
.586 .471 .689 r
.22223 .35185 .22787 .37617 .23855 .37293 .23289 .34844 Mtetra
.624 .495 .684 r
.23289 .34844 .23855 .37293 .2495 .36721 .24383 .34247 Mtetra
.652 .512 .679 r
.24383 .34247 .2495 .36721 .26064 .35954 .25499 .33427 Mtetra
.663 .516 .674 r
.25499 .33427 .26064 .35954 .27184 .35127 .26625 .32497 Mtetra
.662 .51 .668 r
.26625 .32497 .27184 .35127 .28303 .34332 .27755 .31536 Mtetra
.653 .498 .661 r
.27755 .31536 .28303 .34332 .2942 .336 .28883 .30596 Mtetra
.638 .48 .653 r
.28883 .30596 .2942 .336 .30532 .32964 .30008 .29722 Mtetra
.623 .462 .644 r
.30008 .29722 .30532 .32964 .31641 .32404 .31128 .28922 Mtetra
.608 .445 .636 r
.31128 .28922 .31641 .32404 .3275 .31912 .32245 .28205 Mtetra
.595 .43 .628 r
.32245 .28205 .3275 .31912 .3386 .31471 .33359 .27565 Mtetra
.584 .418 .623 r
.33359 .27565 .3386 .31471 .34971 .31066 .34472 .26999 Mtetra
.575 .408 .618 r
.34472 .26999 .34971 .31066 .36087 .30677 .35585 .26493 Mtetra
.568 .401 .615 r
.35585 .26493 .36087 .30677 .37207 .30288 .36698 .26041 Mtetra
.563 .396 .613 r
.36698 .26041 .37207 .30288 .38332 .29885 .37815 .25632 Mtetra
.559 .393 .613 r
.37815 .25632 .38332 .29885 .39463 .29468 .38933 .25267 Mtetra
.554 .391 .615 r
.38933 .25267 .39463 .29468 .40598 .29051 .40055 .24955 Mtetra
.548 .389 .618 r
.40055 .24955 .40598 .29051 .41738 .2865 .41179 .24704 Mtetra
.541 .388 .622 r
.41179 .24704 .41738 .2865 .42881 .28285 .42308 .24528 Mtetra
.533 .387 .628 r
.42308 .24528 .42881 .28285 .44028 .27971 .4344 .2443 Mtetra
.523 .386 .636 r
.4344 .2443 .44028 .27971 .45179 .27727 .44577 .24418 Mtetra
.513 .387 .646 r
.44577 .24418 .45179 .27727 .46334 .2756 .45721 .24481 Mtetra
.502 .389 .657 r
.45721 .24481 .46334 .2756 .47495 .2749 .46871 .24612 Mtetra
.496 .394 .669 r
.46871 .24612 .47495 .2749 .48662 .27487 .48031 .24767 Mtetra
.501 .405 .679 r
.48031 .24767 .48662 .27487 .49838 .27516 .492 .24891 Mtetra
.52 .424 .686 r
.492 .24891 .49838 .27516 .51022 .27486 .50379 .24906 Mtetra
.559 .452 .688 r
.50379 .24906 .51022 .27486 .52214 .27258 .51568 .24693 Mtetra
.599 .479 .687 r
.51568 .24693 .52214 .27258 .53413 .26777 .52763 .2422 Mtetra
.643 .507 .682 r
.52763 .2422 .53413 .26777 .54614 .25946 .53961 .23421 Mtetra
.672 .526 .678 r
.53961 .23421 .54614 .25946 .55814 .24855 .5516 .22386 Mtetra
.69 .54 .677 r
.5516 .22386 .55814 .24855 .57012 .236 .56358 .21208 Mtetra
.695 .547 .681 r
.56358 .21208 .57012 .236 .58208 .22334 .57554 .20028 Mtetra
.679 .542 .692 r
.57554 .20028 .58208 .22334 .59408 .21254 .58754 .19026 Mtetra
.654 .533 .703 r
.58754 .19026 .59408 .21254 .60613 .20403 .5996 .18247 Mtetra
.609 .511 .718 r
.5996 .18247 .60613 .20403 .61831 .19876 .61178 .17784 Mtetra
.567 .491 .729 r
.61178 .17784 .61831 .19876 .63061 .19584 .62409 .17561 Mtetra
.529 .475 .74 r
.62409 .17561 .63061 .19584 .64305 .19461 .63654 .17526 Mtetra
.508 .471 .751 r
.63654 .17526 .64305 .19461 .6556 .19402 .64912 .17576 Mtetra
.514 .487 .765 r
.64912 .17576 .6556 .19402 .66821 .19284 .66178 .17595 Mtetra
.53 .514 .782 r
.66178 .17595 .66821 .19284 .68086 .19077 .67451 .17544 Mtetra
.569 .558 .802 r
.67451 .17544 .68086 .19077 .69349 .18709 .68724 .17344 Mtetra
.601 .603 .826 r
.68724 .17344 .69349 .18709 .70612 .18221 .69999 .1703 Mtetra
.633 .653 .852 r
.69999 .1703 .70612 .18221 .71873 .17635 .71274 .16617 Mtetra
.664 .708 .881 r
.71274 .16617 .71873 .17635 .73134 .16968 .7255 .16118 Mtetra
.696 .76 .901 r
.05043 .39529 .05808 .40196 .06804 .39872 .06062 .39054 Mtetra
.709 .722 .86 r
.06062 .39054 .06804 .39872 .07815 .39465 .07095 .38501 Mtetra
.718 .692 .825 r
.07095 .38501 .07815 .39465 .08842 .38964 .08143 .37863 Mtetra
.725 .67 .796 r
.08143 .37863 .08842 .38964 .09887 .38353 .09206 .37128 Mtetra
.734 .654 .77 r
.09206 .37128 .09887 .38353 .10953 .37599 .10287 .36269 Mtetra
.733 .64 .756 r
.10287 .36269 .10953 .37599 .12029 .36777 .11376 .35357 Mtetra
.728 .628 .746 r
.11376 .35357 .12029 .36777 .13111 .35923 .12468 .34428 Mtetra
.711 .612 .745 r
.12468 .34428 .13111 .35923 .14183 .35151 .1355 .33583 Mtetra
.68 .589 .747 r
.1355 .33583 .14183 .35151 .15235 .34559 .14612 .32907 Mtetra
.636 .557 .749 r
.14612 .32907 .15235 .34559 .16264 .34201 .15652 .32442 Mtetra
.571 .51 .747 r
.15652 .32442 .16264 .34201 .17262 .3415 .16664 .32249 Mtetra
.519 .465 .736 r
.16664 .32249 .17262 .3415 .18243 .34317 .1766 .3225 Mtetra
.479 .425 .719 r
.1766 .3225 .18243 .34317 .19213 .34659 .18646 .32405 Mtetra
.48 .412 .702 r
.18646 .32405 .19213 .34659 .20191 .35002 .19639 .3257 Mtetra
.508 .418 .689 r
.19639 .3257 .20191 .35002 .21192 .35208 .2065 .32629 Mtetra
.546 .435 .679 r
.2065 .32629 .21192 .35208 .22223 .35185 .21686 .32498 Mtetra
.588 .459 .672 r
.21686 .32498 .22223 .35185 .23289 .34844 .22754 .32097 Mtetra
.619 .476 .666 r
.22754 .32097 .23289 .34844 .24383 .34247 .23847 .31465 Mtetra
.643 .491 .662 r
.23847 .31465 .24383 .34247 .25499 .33427 .24962 .30618 Mtetra
.656 .499 .659 r
.24962 .30618 .25499 .33427 .26625 .32497 .26089 .29645 Mtetra
.66 .5 .656 r
.26089 .29645 .26625 .32497 .27755 .31536 .27221 .28609 Mtetra
.658 .496 .653 r
.27221 .28609 .27755 .31536 .28883 .30596 .28354 .27567 Mtetra
.65 .487 .649 r
.28354 .27567 .28883 .30596 .30008 .29722 .29484 .26564 Mtetra
.639 .475 .645 r
.29484 .26564 .30008 .29722 .31128 .28922 .30609 .25625 Mtetra
.626 .462 .64 r
.30609 .25625 .31128 .28922 .32245 .28205 .3173 .24769 Mtetra
.613 .449 .636 r
.3173 .24769 .32245 .28205 .33359 .27565 .32846 .24 Mtetra
.601 .437 .632 r
.32846 .24 .33359 .27565 .34472 .26999 .33959 .23325 Mtetra
.589 .426 .628 r
.33959 .23325 .34472 .26999 .35585 .26493 .35069 .2274 Mtetra
.578 .416 .626 r
.35069 .2274 .35585 .26493 .36698 .26041 .36177 .22242 Mtetra
.568 .408 .625 r
.36177 .22242 .36698 .26041 .37815 .25632 .37285 .21828 Mtetra
.559 .402 .625 r
.37285 .21828 .37815 .25632 .38933 .25267 .38394 .21497 Mtetra
.549 .396 .626 r
.38394 .21497 .38933 .25267 .40055 .24955 .39504 .21254 Mtetra
.538 .39 .628 r
.39504 .21254 .40055 .24955 .41179 .24704 .40617 .21103 Mtetra
.527 .386 .632 r
.40617 .21103 .41179 .24704 .42308 .24528 .41733 .21045 Mtetra
.515 .381 .636 r
.41733 .21045 .42308 .24528 .4344 .2443 .42853 .21077 Mtetra
.503 .377 .642 r
.42853 .21077 .4344 .2443 .44577 .24418 .43979 .21195 Mtetra
.492 .375 .648 r
.43979 .21195 .44577 .24418 .45721 .24481 .45112 .21377 Mtetra
.484 .375 .654 r
.45112 .21377 .45721 .24481 .46871 .24612 .46254 .21603 Mtetra
.484 .38 .66 r
.46254 .21603 .46871 .24612 .48031 .24767 .47406 .21823 Mtetra
.495 .39 .665 r
.47406 .21823 .48031 .24767 .492 .24891 .48569 .21981 Mtetra
.516 .406 .667 r
.48569 .21981 .492 .24891 .50379 .24906 .49742 .22012 Mtetra
.55 .43 .669 r
.49742 .22012 .50379 .24906 .51568 .24693 .50925 .21826 Mtetra
.584 .453 .669 r
.50925 .21826 .51568 .24693 .52763 .2422 .52116 .21404 Mtetra
.621 .479 .668 r
.52116 .21404 .52763 .2422 .53961 .23421 .53311 .20707 Mtetra
.647 .501 .67 r
.53311 .20707 .53961 .23421 .5516 .22386 .54507 .19813 Mtetra
.666 .52 .676 r
.54507 .19813 .5516 .22386 .56358 .21208 .55705 .18809 Mtetra
.673 .533 .686 r
.55705 .18809 .56358 .21208 .57554 .20028 .56903 .17812 Mtetra
.663 .538 .702 r
.56903 .17812 .57554 .20028 .58754 .19026 .58105 .16974 Mtetra
.642 .538 .722 r
.58105 .16974 .58754 .19026 .5996 .18247 .59313 .16333 Mtetra
.597 .525 .744 r
.59313 .16333 .5996 .18247 .61178 .17784 .60533 .15972 Mtetra
.553 .51 .762 r
.60533 .15972 .61178 .17784 .62409 .17561 .61765 .15827 Mtetra
.508 .493 .775 r
.61765 .15827 .62409 .17561 .63654 .17526 .63012 .1586 Mtetra
.481 .487 .786 r
.63012 .1586 .63654 .17526 .64912 .17576 .64272 .15979 Mtetra
.483 .498 .797 r
.64272 .15979 .64912 .17576 .66178 .17595 .65542 .16083 Mtetra
.496 .52 .811 r
.65542 .16083 .66178 .17595 .67451 .17544 .6682 .16134 Mtetra
.532 .558 .827 r
.6682 .16134 .67451 .17544 .68724 .17344 .681 .16056 Mtetra
.561 .597 .847 r
.681 .16056 .68724 .17344 .69999 .1703 .69385 .15877 Mtetra
.589 .641 .87 r
.69385 .15877 .69999 .1703 .71274 .16617 .70672 .1561 Mtetra
.615 .69 .897 r
.70672 .1561 .71274 .16617 .7255 .16118 .71961 .15261 Mtetra
.725 .765 .884 r
.04273 .38856 .05043 .39529 .06062 .39054 .05308 .38282 Mtetra
.733 .74 .857 r
.05308 .38282 .06062 .39054 .07095 .38501 .06356 .37646 Mtetra
.74 .722 .835 r
.06356 .37646 .07095 .38501 .08143 .37863 .07415 .36941 Mtetra
.748 .71 .816 r
.07415 .36941 .08143 .37863 .09206 .37128 .08486 .3616 Mtetra
.76 .704 .8 r
.08486 .3616 .09206 .37128 .10287 .36269 .09572 .35284 Mtetra
.764 .703 .794 r
.09572 .35284 .10287 .36269 .11376 .35357 .10663 .3437 Mtetra
.765 .703 .794 r
.10663 .3437 .11376 .35357 .12468 .34428 .11756 .3345 Mtetra
.755 .703 .803 r
.11756 .3345 .12468 .34428 .1355 .33583 .12841 .32601 Mtetra
.73 .696 .818 r
.12841 .32601 .1355 .33583 .14612 .32907 .13909 .31892 Mtetra
.69 .678 .833 r
.13909 .31892 .14612 .32907 .15652 .32442 .14959 .31354 Mtetra
.625 .638 .843 r
.14959 .31354 .15652 .32442 .16664 .32249 .15987 .31033 Mtetra
.57 .588 .832 r
.15987 .31033 .16664 .32249 .1766 .3225 .17001 .30866 Mtetra
.526 .536 .809 r
.17001 .30866 .1766 .3225 .18646 .32405 .18008 .30821 Mtetra
.526 .507 .778 r
.18008 .30821 .18646 .32405 .19639 .3257 .1902 .30785 Mtetra
.549 .497 .75 r
.1902 .30785 .19639 .3257 .2065 .32629 .20046 .30669 Mtetra
.582 .5 .728 r
.20046 .30669 .2065 .32629 .21686 .32498 .21094 .30404 Mtetra
.618 .512 .711 r
.21094 .30404 .21686 .32498 .22754 .32097 .22167 .29925 Mtetra
.645 .523 .7 r
.22167 .29925 .22754 .32097 .23847 .31465 .23262 .29255 Mtetra
.668 .535 .693 r
.23262 .29255 .23847 .31465 .24962 .30618 .24376 .28403 Mtetra
.682 .543 .69 r
.24376 .28403 .24962 .30618 .26089 .29645 .25501 .27435 Mtetra
.69 .548 .688 r
.25501 .27435 .26089 .29645 .27221 .28609 .26632 .26398 Mtetra
.691 .549 .688 r
.26632 .26398 .27221 .28609 .28354 .27567 .27765 .25345 Mtetra
.688 .546 .688 r
.27765 .25345 .28354 .27567 .29484 .26564 .28895 .2432 Mtetra
.68 .54 .688 r
.28895 .2432 .29484 .26564 .30609 .25625 .30022 .23349 Mtetra
.669 .531 .688 r
.30022 .23349 .30609 .25625 .3173 .24769 .31143 .22456 Mtetra
.656 .521 .688 r
.31143 .22456 .3173 .24769 .32846 .24 .3226 .2165 Mtetra
.641 .51 .687 r
.3226 .2165 .32846 .24 .33959 .23325 .33372 .2094 Mtetra
.626 .499 .687 r
.33372 .2094 .33959 .23325 .35069 .2274 .34481 .20327 Mtetra
.611 .487 .687 r
.34481 .20327 .35069 .2274 .36177 .22242 .35588 .19812 Mtetra
.595 .477 .688 r
.35588 .19812 .36177 .22242 .37285 .21828 .36693 .19393 Mtetra
.579 .466 .689 r
.36693 .19393 .37285 .21828 .38394 .21497 .37798 .19071 Mtetra
.562 .456 .692 r
.37798 .19071 .38394 .21497 .39504 .21254 .38903 .18848 Mtetra
.544 .446 .694 r
.38903 .18848 .39504 .21254 .40617 .21103 .40011 .18722 Mtetra
.525 .436 .697 r
.40011 .18722 .40617 .21103 .41733 .21045 .41122 .18694 Mtetra
.506 .427 .701 r
.41122 .18694 .41733 .21045 .42853 .21077 .42237 .18754 Mtetra
.488 .418 .704 r
.42237 .18754 .42853 .21077 .43979 .21195 .43359 .18895 Mtetra
.475 .412 .706 r
.43359 .18895 .43979 .21195 .45112 .21377 .44488 .19092 Mtetra
.468 .409 .708 r
.44488 .19092 .45112 .21377 .46254 .21603 .45626 .19318 Mtetra
.472 .412 .709 r
.45626 .19318 .46254 .21603 .47406 .21823 .46774 .1953 Mtetra
.487 .422 .71 r
.46774 .1953 .47406 .21823 .48569 .21981 .47932 .19675 Mtetra
.513 .438 .709 r
.47932 .19675 .48569 .21981 .49742 .22012 .49102 .19703 Mtetra
.55 .462 .708 r
.49102 .19703 .49742 .22012 .50925 .21826 .50282 .19546 Mtetra
.586 .487 .708 r
.50282 .19546 .50925 .21826 .52116 .21404 .5147 .19194 Mtetra
.624 .515 .71 r
.5147 .19194 .52116 .21404 .53311 .20707 .52663 .18625 Mtetra
.653 .542 .716 r
.52663 .18625 .53311 .20707 .54507 .19813 .5386 .17903 Mtetra
.675 .569 .728 r
.5386 .17903 .54507 .19813 .55705 .18809 .55059 .17097 Mtetra
.686 .594 .748 r
.55059 .17097 .55705 .18809 .56903 .17812 .56261 .16298 Mtetra
.677 .614 .777 r
.56261 .16298 .56903 .17812 .58105 .16974 .57467 .15625 Mtetra
.654 .628 .811 r
.57467 .15625 .58105 .16974 .59313 .16333 .5868 .15109 Mtetra
.599 .624 .848 r
.5868 .15109 .59313 .16333 .60533 .15972 .59903 .14815 Mtetra
.539 .608 .871 r
.59903 .14815 .60533 .15972 .61765 .15827 .61138 .14698 Mtetra
.479 .583 .881 r
.61138 .14698 .61765 .15827 .63012 .1586 .62387 .14726 Mtetra
.446 .565 .881 r
.62387 .14726 .63012 .1586 .64272 .15979 .63648 .1483 Mtetra
.45 .564 .879 r
.63648 .1483 .64272 .15979 .65542 .16083 .64919 .14929 Mtetra
.467 .573 .879 r
.64919 .14929 .65542 .16083 .6682 .16134 .66198 .14989 Mtetra
.506 .599 .881 r
.66198 .14989 .6682 .16134 .681 .16056 .67483 .14951 Mtetra
.533 .624 .888 r
.67483 .14951 .681 .16056 .69385 .15877 .68774 .14835 Mtetra
.556 .653 .9 r
.68774 .14835 .69385 .15877 .70672 .1561 .70068 .14649 Mtetra
.578 .686 .915 r
.70068 .14649 .70672 .1561 .71961 .15261 .71368 .14397 Mtetra
.738 .766 .876 r
.03496 .38178 .04273 .38856 .05308 .38282 .04542 .37553 Mtetra
.743 .754 .861 r
.04542 .37553 .05308 .38282 .06356 .37646 .05596 .36884 Mtetra
.75 .747 .85 r
.05596 .36884 .06356 .37646 .07415 .36941 .06659 .36171 Mtetra
.759 .747 .842 r
.06659 .36171 .07415 .36941 .08486 .3616 .07731 .35409 Mtetra
.772 .754 .836 r
.07731 .35409 .08486 .3616 .09572 .35284 .08812 .34583 Mtetra
.781 .768 .841 r
.08812 .34583 .09572 .35284 .10663 .3437 .09898 .33735 Mtetra
.788 .786 .851 r
.09898 .33735 .10663 .3437 .11756 .3345 .10986 .32886 Mtetra
.785 .807 .87 r
.10986 .32886 .11756 .3345 .12841 .32601 .12067 .32088 Mtetra
.766 .824 .897 r
.12067 .32088 .12841 .32601 .13909 .31892 .13138 .3139 Mtetra
.733 .827 .923 r
.13138 .3139 .13909 .31892 .14959 .31354 .14196 .3081 Mtetra
.676 .806 .944 r
.14196 .3081 .14959 .31354 .15987 .31033 .15239 .30379 Mtetra
.631 .759 .94 r
.15239 .30379 .15987 .31033 .17001 .30866 .16274 .30054 Mtetra
.596 .699 .915 r
.16274 .30054 .17001 .30866 .18008 .30821 .17303 .29813 Mtetra
.594 .647 .872 r
.17303 .29813 .18008 .30821 .1902 .30785 .18337 .29578 Mtetra
.609 .612 .828 r
.18337 .29578 .1902 .30785 .20046 .30669 .19382 .29288 Mtetra
.631 .593 .793 r
.19382 .29288 .20046 .30669 .21094 .30404 .20442 .28895 Mtetra
.657 .589 .768 r
.20442 .28895 .21094 .30404 .22167 .29925 .21522 .28354 Mtetra
.678 .593 .753 r
.21522 .28354 .22167 .29925 .23262 .29255 .22618 .27677 Mtetra
.699 .603 .745 r
.22618 .27677 .23262 .29255 .24376 .28403 .23728 .26868 Mtetra
.715 .616 .745 r
.23728 .26868 .24376 .28403 .25501 .27435 .24848 .25972 Mtetra
.728 .63 .749 r
.24848 .25972 .25501 .27435 .26632 .26398 .25973 .25021 Mtetra
.738 .645 .757 r
.25973 .25021 .26632 .26398 .27765 .25345 .27101 .24056 Mtetra
.742 .659 .767 r
.27101 .24056 .27765 .25345 .28895 .2432 .28227 .23111 Mtetra
.743 .671 .78 r
.28227 .23111 .28895 .2432 .30022 .23349 .2935 .22208 Mtetra
.739 .681 .795 r
.2935 .22208 .30022 .23349 .31143 .22456 .3047 .21369 Mtetra
.731 .689 .81 r
.3047 .21369 .31143 .22456 .3226 .2165 .31586 .20604 Mtetra
.718 .693 .825 r
.31586 .20604 .3226 .2165 .33372 .2094 .32699 .19922 Mtetra
.701 .693 .84 r
.32699 .19922 .33372 .2094 .34481 .20327 .33809 .19325 Mtetra
.679 .69 .853 r
.33809 .19325 .34481 .20327 .35588 .19812 .34917 .18815 Mtetra
.654 .682 .864 r
.34917 .18815 .35588 .19812 .36693 .19393 .36024 .18393 Mtetra
.625 .67 .873 r
.36024 .18393 .36693 .19393 .37798 .19071 .37132 .18059 Mtetra
.592 .654 .879 r
.37132 .18059 .37798 .19071 .38903 .18848 .3824 .17812 Mtetra
.558 .633 .882 r
.3824 .17812 .38903 .18848 .40011 .18722 .3935 .17652 Mtetra
.523 .608 .88 r
.3935 .17652 .40011 .18722 .41122 .18694 .40464 .17576 Mtetra
.492 .582 .873 r
.40464 .17576 .41122 .18694 .42237 .18754 .41582 .17575 Mtetra
.467 .555 .862 r
.41582 .17575 .42237 .18754 .43359 .18895 .42706 .17639 Mtetra
.454 .532 .848 r
.42706 .17639 .43359 .18895 .44488 .19092 .43837 .17748 Mtetra
.453 .515 .832 r
.43837 .17748 .44488 .19092 .45626 .19318 .44977 .17878 Mtetra
.465 .505 .816 r
.44977 .17878 .45626 .19318 .46774 .1953 .46126 .17996 Mtetra
.489 .505 .8 r
.46126 .17996 .46774 .1953 .47932 .19675 .47285 .18059 Mtetra
.518 .511 .787 r
.47285 .18059 .47932 .19675 .49102 .19703 .48455 .18035 Mtetra
.556 .526 .778 r
.48455 .18035 .49102 .19703 .50282 .19546 .49634 .17878 Mtetra
.59 .546 .774 r
.49634 .17878 .50282 .19546 .5147 .19194 .50821 .17582 Mtetra
.626 .574 .776 r
.50821 .17582 .5147 .19194 .52663 .18625 .52015 .17135 Mtetra
.655 .605 .787 r
.52015 .17135 .52663 .18625 .5386 .17903 .53213 .16583 Mtetra
.677 .643 .809 r
.53213 .16583 .5386 .17903 .55059 .17097 .54416 .15974 Mtetra
.689 .686 .842 r
.54416 .15974 .55059 .17097 .56261 .16298 .55623 .15371 Mtetra
.677 .728 .888 r
.55623 .15371 .56261 .16298 .57467 .15625 .56835 .14852 Mtetra
.642 .76 .935 r
.56835 .14852 .57467 .15625 .5868 .15109 .58054 .14443 Mtetra
.564 .764 .972 r
.58054 .14443 .5868 .15109 .59903 .14815 .59282 .14186 Mtetra
.486 .741 .984 r
.59282 .14186 .59903 .14815 .61138 .14698 .60521 .14052 Mtetra
.423 .703 .98 r
.60521 .14052 .61138 .14698 .62387 .14726 .61771 .14021 Mtetra
.404 .672 .969 r
.61771 .14021 .62387 .14726 .63648 .1483 .63032 .14044 Mtetra
.425 .657 .956 r
.63032 .14044 .63648 .1483 .64919 .14929 .64303 .14068 Mtetra
.453 .649 .943 r
.64303 .14068 .64919 .14929 .66198 .14989 .65583 .14068 Mtetra
.494 .653 .93 r
.65583 .14068 .66198 .14989 .67483 .14951 .6687 .14005 Mtetra
.519 .66 .924 r
.6687 .14005 .67483 .14951 .68774 .14835 .68163 .13891 Mtetra
.538 .672 .924 r
.68163 .13891 .68774 .14835 .70068 .14649 .69463 .1373 Mtetra
.554 .689 .929 r
.69463 .1373 .70068 .14649 .71368 .14397 .70769 .13525 Mtetra
.737 .766 .876 r
.02714 .37496 .03496 .38178 .04542 .37553 .03763 .36867 Mtetra
.742 .767 .873 r
.03763 .36867 .04542 .37553 .05596 .36884 .04816 .3622 Mtetra
.748 .774 .874 r
.04816 .3622 .05596 .36884 .06659 .36171 .05875 .35554 Mtetra
.756 .789 .879 r
.05875 .35554 .06659 .36171 .07731 .35409 .06939 .34865 Mtetra
.768 .812 .887 r
.06939 .34865 .07731 .35409 .08812 .34583 .08009 .34149 Mtetra
.777 .846 .904 r
.08009 .34149 .08812 .34583 .09898 .33735 .09082 .33425 Mtetra
.781 .886 .921 r
.09082 .33425 .09898 .33735 .10986 .32886 .10157 .32702 Mtetra
.768 .927 .939 r
.10157 .32702 .10986 .32886 .12067 .32088 .1123 .32008 Mtetra
.73 .953 .948 r
.1123 .32008 .12067 .32088 .13138 .3139 .12298 .31365 Mtetra
.678 .957 .947 r
.12298 .31365 .13138 .3139 .14196 .3081 .13361 .30784 Mtetra
.622 .943 .95 r
.13361 .30784 .14196 .3081 .15239 .30379 .14417 .30279 Mtetra
.608 .927 .968 r
.14417 .30279 .15239 .30379 .16274 .30054 .1547 .29828 Mtetra
.618 .9 .986 r
.1547 .29828 .16274 .30054 .17303 .29813 .16522 .29421 Mtetra
.648 .856 .979 r
.16522 .29421 .17303 .29813 .18337 .29578 .17578 .29018 Mtetra
.672 .805 .946 r
.17578 .29018 .18337 .29578 .19382 .29288 .18641 .28587 Mtetra
.689 .766 .91 r
.18641 .28587 .19382 .29288 .20442 .28895 .19713 .28106 Mtetra
.708 .746 .881 r
.19713 .28106 .20442 .28895 .21522 .28354 .20796 .27549 Mtetra
.725 .746 .869 r
.20796 .27549 .21522 .28354 .22618 .27677 .2189 .26924 Mtetra
.745 .765 .869 r
.2189 .26924 .22618 .27677 .23728 .26868 .22992 .2623 Mtetra
.765 .801 .882 r
.22992 .2623 .23728 .26868 .24848 .25972 .24102 .2549 Mtetra
.782 .85 .902 r
.24102 .2549 .24848 .25972 .25973 .25021 .25216 .24722 Mtetra
.788 .909 .924 r
.25216 .24722 .25973 .25021 .27101 .24056 .26332 .23948 Mtetra
.766 .962 .931 r
.26332 .23948 .27101 .24056 .28227 .23111 .27449 .23188 Mtetra
.696 .98 .897 r
.27449 .23188 .28227 .23111 .2935 .22208 .28566 .22454 Mtetra
.569 .935 .805 r
.28566 .22454 .2935 .22208 .3047 .21369 .29682 .2176 Mtetra
.411 .835 .673 r
.29682 .2176 .3047 .21369 .31586 .20604 .30797 .21114 Mtetra
0 0 0 r
.30797 .21114 .31586 .20604 .32699 .19922 .31911 .2052 Mtetra
.31911 .2052 .32699 .19922 .33809 .19325 .33026 .19981 Mtetra
.33026 .19981 .33809 .19325 .34917 .18815 .3414 .195 Mtetra
.026 0 0 r
.3414 .195 .34917 .18815 .36024 .18393 .35255 .19075 Mtetra
.073 0 0 r
.35255 .19075 .36024 .18393 .37132 .18059 .36372 .18708 Mtetra
.105 0 0 r
.36372 .18708 .37132 .18059 .3824 .17812 .37491 .18399 Mtetra
.12 0 0 r
.37491 .18399 .3824 .17812 .3935 .17652 .38613 .18145 Mtetra
.38613 .18145 .3935 .17652 .40464 .17576 .39738 .17945 Mtetra
.096 0 0 r
.39738 .17945 .40464 .17576 .41582 .17575 .40869 .17793 Mtetra
.041 0 0 r
.40869 .17793 .41582 .17575 .42706 .17639 .42004 .17682 Mtetra
.058 .624 .714 r
.42004 .17682 .42706 .17639 .43837 .17748 .43147 .17598 Mtetra
.196 .713 .88 r
.43147 .17598 .43837 .17748 .44977 .17878 .44296 .17529 Mtetra
.338 .755 .978 r
.44296 .17529 .44977 .17878 .46126 .17996 .45453 .17455 Mtetra
.447 .748 .993 r
.45453 .17455 .46126 .17996 .47285 .18059 .46619 .17353 Mtetra
.516 .723 .967 r
.46619 .17353 .47285 .18059 .48455 .18035 .47793 .17206 Mtetra
.565 .706 .936 r
.47793 .17206 .48455 .18035 .49634 .17878 .48975 .1699 Mtetra
.597 .704 .918 r
.48975 .1699 .49634 .17878 .50821 .17582 .50165 .16703 Mtetra
.627 .719 .914 r
.50165 .16703 .50821 .17582 .52015 .17135 .51362 .1634 Mtetra
.646 .753 .927 r
.51362 .1634 .52015 .17135 .53213 .16583 .52564 .15925 Mtetra
.653 .8 .953 r
.52564 .15925 .53213 .16583 .54416 .15974 .53772 .15482 Mtetra
.636 .852 .982 r
.53772 .15482 .54416 .15974 .55623 .15371 .54985 .15042 Mtetra
.569 .882 .992 r
.54985 .15042 .55623 .15371 .56835 .14852 .56205 .14647 Mtetra
.469 .869 .964 r
.56205 .14647 .56835 .14852 .58054 .14443 .57431 .14308 Mtetra
.354 .819 .917 r
.57431 .14308 .58054 .14443 .59282 .14186 .58665 .14047 Mtetra
.296 .783 .903 r
.58665 .14047 .59282 .14186 .60521 .14052 .59908 .13849 Mtetra
.289 .768 .926 r
.59908 .13849 .60521 .14052 .61771 .14021 .61161 .13706 Mtetra
.334 .769 .968 r
.61161 .13706 .61771 .14021 .63032 .14044 .62423 .13592 Mtetra
.402 .765 .994 r
.62423 .13592 .63032 .14044 .64303 .14068 .63694 .13482 Mtetra
.456 .748 .992 r
.63694 .13482 .64303 .14068 .65583 .14068 .64973 .13362 Mtetra
.501 .729 .975 r
.64973 .13362 .65583 .14068 .6687 .14005 .6626 .13215 Mtetra
.525 .714 .958 r
.6626 .13215 .6687 .14005 .68163 .13891 .67554 .13045 Mtetra
.54 .705 .947 r
.67554 .13045 .68163 .13891 .69463 .1373 .68856 .12855 Mtetra
.551 .702 .94 r
.68856 .12855 .69463 .1373 .70769 .13525 .70165 .12647 Mtetra
.724 .764 .885 r
.01926 .36808 .02714 .37496 .03763 .36867 .02969 .3623 Mtetra
.725 .78 .896 r
.02969 .3623 .03763 .36867 .04816 .3622 .04015 .35657 Mtetra
.727 .803 .912 r
.04015 .35657 .04816 .3622 .05875 .35554 .05062 .3509 Mtetra
.728 .836 .931 r
.05062 .3509 .05875 .35554 .06939 .34865 .0611 .34528 Mtetra
.724 .878 .953 r
.0611 .34528 .06939 .34865 .08009 .34149 .07161 .33971 Mtetra
.704 .925 .966 r
.07161 .33971 .08009 .34149 .09082 .33425 .08215 .3342 Mtetra
.651 .952 .947 r
.08215 .3342 .09082 .33425 .10157 .32702 .0927 .32874 Mtetra
.551 .932 .871 r
.0927 .32874 .10157 .32702 .1123 .32008 .10328 .32333 Mtetra
.43 .863 .755 r
.10328 .32333 .1123 .32008 .12298 .31365 .11388 .31798 Mtetra
.334 .79 .654 r
.11388 .31798 .12298 .31365 .13361 .30784 .1245 .31268 Mtetra
0 0 0 r
.1245 .31268 .13361 .30784 .14417 .30279 .13515 .30743 Mtetra
.13515 .30743 .14417 .30279 .1547 .29828 .14583 .30224 Mtetra
.333 .793 .668 r
.14583 .30224 .1547 .29828 .16522 .29421 .15653 .29709 Mtetra
.409 .852 .757 r
.15653 .29709 .16522 .29421 .17578 .29018 .16727 .292 Mtetra
.48 .898 .836 r
.16727 .292 .17578 .29018 .18641 .28587 .17803 .28697 Mtetra
.522 .918 .881 r
.17803 .28697 .18641 .28587 .19713 .28106 .18882 .28198 Mtetra
.524 .919 .888 r
.18882 .28198 .19713 .28106 .20796 .27549 .19964 .27705 Mtetra
.472 .894 .843 r
.19964 .27705 .20796 .27549 .2189 .26924 .21049 .27217 Mtetra
.354 .817 .724 r
.21049 .27217 .2189 .26924 .22992 .2623 .22138 .26735 Mtetra
0 0 0 r
.22138 .26735 .22992 .2623 .24102 .2549 .2323 .26257 Mtetra
.2323 .26257 .24102 .2549 .25216 .24722 .24325 .25785 Mtetra
.132 0 0 r
.24325 .25785 .25216 .24722 .26332 .23948 .25424 .25318 Mtetra
.219 0 .017 r
.25424 .25318 .26332 .23948 .27449 .23188 .26526 .24856 Mtetra
.274 0 .101 r
.26526 .24856 .27449 .23188 .28566 .22454 .27632 .244 Mtetra
.311 0 .158 r
.27632 .244 .28566 .22454 .29682 .2176 .28742 .23949 Mtetra
.336 0 .196 r
.28742 .23949 .29682 .2176 .30797 .21114 .29856 .23502 Mtetra
.352 .001 .221 r
.29856 .23502 .30797 .21114 .31911 .2052 .30974 .23062 Mtetra
.364 .018 .239 r
.30974 .23062 .31911 .2052 .33026 .19981 .32096 .22626 Mtetra
.371 .029 .249 r
.32096 .22626 .33026 .19981 .3414 .195 .33222 .22196 Mtetra
.375 .035 .254 r
.33222 .22196 .3414 .195 .35255 .19075 .34353 .21771 Mtetra
.377 .036 .255 r
.34353 .21771 .35255 .19075 .36372 .18708 .35488 .21351 Mtetra
.376 .033 .251 r
.35488 .21351 .36372 .18708 .37491 .18399 .36628 .20936 Mtetra
.372 .025 .242 r
.36628 .20936 .37491 .18399 .38613 .18145 .37772 .20526 Mtetra
.364 .012 .227 r
.37772 .20526 .38613 .18145 .39738 .17945 .38921 .20122 Mtetra
.353 0 .203 r
.38921 .20122 .39738 .17945 .40869 .17793 .40075 .19723 Mtetra
.335 0 .169 r
.40075 .19723 .40869 .17793 .42004 .17682 .41233 .1933 Mtetra
.308 0 .117 r
.41233 .1933 .42004 .17682 .43147 .17598 .42397 .18941 Mtetra
.266 0 .042 r
.42397 .18941 .43147 .17598 .44296 .17529 .43566 .18558 Mtetra
.202 0 0 r
.43566 .18558 .44296 .17529 .45453 .17455 .44741 .1818 Mtetra
.102 0 0 r
.44741 .1818 .45453 .17455 .46619 .17353 .45921 .17808 Mtetra
0 0 0 r
.45921 .17808 .46619 .17353 .47793 .17206 .47106 .17441 Mtetra
.47106 .17441 .47793 .17206 .48975 .1699 .48298 .17079 Mtetra
.293 .79 .785 r
.48298 .17079 .48975 .1699 .50165 .16703 .49495 .16723 Mtetra
.339 .82 .84 r
.49495 .16723 .50165 .16703 .51362 .1634 .50698 .16371 Mtetra
.321 .809 .827 r
.50698 .16371 .51362 .1634 .52564 .15925 .51907 .16026 Mtetra
.257 .765 .761 r
.51907 .16026 .52564 .15925 .53772 .15482 .53123 .15685 Mtetra
0 0 0 r
.53123 .15685 .53772 .15482 .54985 .15042 .54344 .1535 Mtetra
.54344 .1535 .54985 .15042 .56205 .14647 .55573 .15021 Mtetra
.55573 .15021 .56205 .14647 .57431 .14308 .56808 .14697 Mtetra
.56808 .14697 .57431 .14308 .58665 .14047 .58049 .14378 Mtetra
.58049 .14378 .58665 .14047 .59908 .13849 .59298 .14065 Mtetra
.59298 .14065 .59908 .13849 .61161 .13706 .60554 .13757 Mtetra
.238 .754 .776 r
.60554 .13757 .61161 .13706 .62423 .13592 .61817 .13455 Mtetra
.371 .83 .917 r
.61817 .13455 .62423 .13592 .63694 .13482 .63087 .13159 Mtetra
.472 .846 .988 r
.63087 .13159 .63694 .13482 .64973 .13362 .64365 .12868 Mtetra
.53 .82 .999 r
.64365 .12868 .64973 .13362 .6626 .13215 .65651 .12583 Mtetra
.555 .785 .985 r
.65651 .12583 .6626 .13215 .67554 .13045 .66945 .12303 Mtetra
.567 .754 .966 r
.66945 .12303 .67554 .13045 .68856 .12855 .68246 .12029 Mtetra
.571 .73 .949 r
.68246 .12029 .68856 .12855 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Nooooo`;oTL7g1?nB^_800ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo057ooooo001Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool07Oooool3o`0000;ooooo00?o0000ooooooooool0F?oo
ool2ohk8o0GoTL7g0onB^_800ol0003oT[[booooo`0Eooooo`03o`000?oooooooooo053ooooo001P
ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0001cooooo0_l0001Kooooo`?oQm7o1On>
b?`5oi71m`;oT[[b00?o0000ohfcl?ooool05?ooool00ol0003oooooo`00001Aooooo`00H?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00006_ooool3o`0005Wooooo
0omhf?`5ohOAo`CoS/Sl0onA`OL2ohZdlP;oSK?`00?o0000ohfcl?n=/o005_ooool00ol0003ooooo
ooooo`1?ooooo`00H?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo
00006?ooool2o`0005Sooooo1?mNe>X4ogSHo0;oQm7o0_n0^_T5ohJfm@GoR[Cb00?oSK?`o`000?n=
/o000_n=/o0Fooooo`03o`000?oooooooooo04kooooo001Pooooo`05oa0@4?ooooooooooooooool@
41003?ooool00omgMgOoc<c<o`00000Eooooo`?o00000_ooool00ol0003oooooooooo`1Aooooo`;o
?<760omEa?L4ofK3oPCoM;om1?n0^_T5ohJfm@GoR[Cb00Co0000ohfcl?n=/>goSK3]5_ooool00ol0
003oooooooooo`1>ooooo`00H?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4
A?l000004oooool2o`0005?ooooo0_l00002od_8i`CoBLC]1?mEa?L4ofK3oPCoM;om1?n0^_T2ohJf
m@;oQ:S/1On9[>`00ol0003oSK3]ohf`k@02ohf`kAKooooo00?o0000ooooooooool0COooool0063o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00oooooo0ol0001Aoooo
o`;o00000on@`oP4ogbmn`CoK;?j1?mW[?P3ofbXm0CoLjKa1?mnYnh5ohBXk0CoRJc/00?o0000ohf`
kOn=/>d00on=/>dFooooo`03o`000?oooooooooo04cooooo0022ooooo`;o0000DOooool01?l0003o
N=kfojC2konT`^l5oi33n0CoO;gk1?m//oX4ofN/n0?oK:Sd1?mcY_44ogjWkPGoQ:S/0on9[>`01?l0
003oSK3]ohf`kOn=/>d2oi>_jQKooooo00?o0000ooooooooool0C?ooool007oooooo0ol00002oooo
o`03o`000?oooooooooo04[ooooo00Co0000oi7QoOnAhOgo[K[S1OnT`^l2oi33n0;oVIoI1?n9Vmh4
ogZEh@CoLY3Q0omcT>400om/Z?CoLjKaog>Vl@02og>Vl@CoOZO^0_n4Z>`2ohROh`?oSZOV00?o0000
oi>_j_nC[nX01?nC[nXDooooo`?o0000COooool007cooooo0ol0001>ooooo`;o00000_nRf_/00onA
hOgo[K[Sojfjh`02ojfjh`?oY<;_00?oYj3?oiVOfOnIWmT00onIWmT4ohVKgPCoNYGQ1?mbT>43og>@
h@CoMi;Q1?n1VN45ohROh`;oSZOV00?o0000ohjWi_nC[nX01?nC[nXGooooo`03o`000?oooooooooo
04[ooooo001jooooo`;o0000C_ooool00ol0003oYlccoj;Jn`03oj;Jn`03ok2_eon]^^?o[K[S00Co
[K[S00CoY<;_ojNPconWX<ooYj3?1?nIWmT5ohVKgP?oNYGQ1?mbT>44og>@h@CoMi;Q1?n1VN44ohRO
h`?oSZOV00Co0000ohjWi_nC[n[oTjoZ0onM/>DFooooo`03o`000?oooooooooo04[ooooo001goooo
o`?o0000COooool00om1`l;oYlccojO<l`03ojO<l`03oj;Jnon`[mOo/:oG00;o/:oG1?n]^^<00on]
WLKoYj3?ojNPc`02ojNPc`GoVIoI0_n9Vmh2ohf2``?oPWk600?oNYGQog:@hOmbT>400_mbT>44og>@
h@CoMi;Q1?n1VN44ohROh`;oSZOV00?o0000oiJTg_nM/>D01OnM/>DFooooo`03o`000?oooooooooo
04Wooooo001eooooo`;o00000_ooool00ol0003oooooooooo`17ooooo`;oD/oC0onU`>d4ojO<l`03
ojfTcon`[mOo/:oG00Co/:oG00?o[K[SojfMa_n]WLH00_n]WLH4ojNPc`;oVIoI0_nHQ[h5ohf2``?o
PWk61?mkO<T4og]oc0CoOXG?1?n8S]<4ohnHf0;oUZCN00?o0000oiJTg_nFY=h01?nM/>D00onY]N7o
ooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo001booooo`?o00001Oooool00ol0003ooooo
ooooo`12ooooo`;oE]7G0_nP^>T6ojG0k@03ojO<lon]Y<oo[JC?00;o[JC?1?n`[mL00on_V;oo[Ig6
ojfMaP03ojfMaP?oYj3?00?oY8VhoiR6__nHQ[h00onHQ[h4ohf2``CoPWk61?mkO<T4og]oc0CoOXG?
1?n8S]<4ohnHf003oiJTg_l0003oUZCN00;oUZCN00?oWK3UojVehOnY]N400_nY]N4Fooooo`03o`00
0?oooooooooo04Sooooo001`ooooo`;o0000BOooool3od_:b003oiRdjonP^>WoX;SY00?oX;SY1?nU
`>d00onWV/Wo[JC?ojfTc`03ojfTc`?o/:oG0on_V;l5ojfMaP04ojNPconTRKSoY8VhojB9^0CoV8Jn
1?n=P/<4oh9naPCoNgc91?mkOl`4ogj5c`CoR8kC1On?V=P01?l0003oUZCNoj:Wf_nRYmX6ojVehAKo
oooo00?o0000ooooooooool0Aoooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool5o`00023ooooo0ol00018ooooo`;o00000_n@]>l4oiRdj`GoX;SY00?oYL3]ojNJbOnW
V/T00_nWV/T5ojfTc`03ok2_eon_V;oo[iRo00;o[iRo1?n]WLH00onYRK?oY8VhojB9^002ojB9^0Co
V8Jn1On=P/<3oh9naPCoNgc91?mkOl`4ogj5c`GoR8kC0_n?V=P2oiVJd`03o`000?nRYm[oXZOJ00;o
XZOJ1?nY]N400one^]goooooooooo`0Cooooo`?o0000B?ooool003Sooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A401kooooo0_l00003oooo
o`03o`000?oooooooooo03oooooo0_lJ0003o`0000;oQ;Wg1?n@]>l4oiRdj`;oX;SY0_nPT/H5ojNJ
b@Co[JC?00?o[96jojnH_on_V;l00on_V;l3ojfMaP;oZHVc1?nTRKP5oiR6_PCoSH;31?n2O/H4og]l
b@CoNgo<1?mnQLl2ohR>d`;oTHk=1?nIV]<00ol0003oXZOJoj:WfP03oj:WfP03ojVehOne^]go]K[M
00;o]K[M5_ooool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo0_l000000ol@413oooooooooo`0Yooooo`00>?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h07?ooool3o`00037ooooo1?lN0003oaP00003o`X00?mE02_o
CP0M00?oCP0M1?m400X3oc<000?o6P0000?o0000og:oo_n4^OL01?n4^OL4oi2dk`;oV;C[00?oUh_6
oj2Ba_nPT/H00onPT/H5ojNJb@03ojfTcon/TK[o[96j00;o[96j1On_V;l00on]WLKoZHVcojV9/`02
ojV9/`CoY8Vh1?nHQ[h2ohf2``;oTGfj1?n7NKd4oh9h`0CoPgc31?n7PlP5oi6>c@?oVI[C00?o0000
oj:Wf_nRYmX00_nRYmX00on][=Ko]K[MokFjg@04okFjgAKooooo00?o0000ooooooooool01Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02[ooooo000h
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Hooooo`?o0000<?oo
ool00olJ003o7P00oah00002oah00003oed3>_mJ03?oFP0c00;oFP0c0omE02/4odh07@?oA00:0olc
00001?lJ003oMh7@ogN1d?mgPM03ogf1c0;oQ;Wg0_n4P/T4ohj6a`CoUh_61?nPT/H4ojNJb@03ojN:
]on/TK[o[96j00?o[96j1?n_V;l00on/R:ooZHVcojV9/`03ojV9/`CoY8Vh0_nHQ[h2oi^2]`GoTGfj
1?n7NKd4oh9h`0CoPgc31?n7PlP4oi6>c@?oVI[C00?o0000oiVJdonRYmX01?n][=H4okFjg@;o`L;K
5_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0002_o
oooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Eooooo`?o
0000;oooool01?lB003o6P00oaX00?lN0002oel6?@?oG@<j1?mJ03<2oeD0:`CoCP0M0om400X00olc
003oLh?Dog>3e002og>3e0CoMh7@0_mmPL`5ohB2b@CoSXK70onGRlH5oj2BaP03ojNJbOnWR[OoYhZg
00;oYhZg1?n/TKX3ojnH_`;o[8R_1OnYRK<4ojB9^0GoVh:g1?nAOKX4ohMi_@CoPWS01?n3O<<4ohN3
b0CoTHk=0onIV]<00ol0003oYIo@ojf/eP05ojf/eP03okFjgOo1`]_o`L;K00?o`L;K5Oooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0
000/ooooo`00>?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool04Ooo
ool3o`0000?ooooo00?o0000ooooooooool0:?ooool01_l6003o4P00oa800?lB003o6P00of08@0Co
G`Hm0omM0cX3oeX0<`?oE@0[1?m>01d01?m400[oMhkLogB8fOmdR=T4og>3e0CoMh7@0ommPL`4ohB2
b@CoSXK70onGRlH4oj2BaP03oin3]OnWR[OoYhZg00?oYhZg1On/TKX00on_V;oo[8R_ojb8[`02ojb8
[`GoZHVc0_nTRKP00onWR;?oVh:goi^2]`03oi^2]`CoTGfj1?n7NKd4oh9h`0CoPgc31?n7PlP5oi6>
c@03oiVJdonUWm3o000000;oYIo@1?n][=H00onj^=Oo`L;Kol72f`03ol72f`03olW=g?oooooooooo
01Cooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgM
oeEEEOoooooo0000;?ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooooiRHV?l@41004Oooool2o`0002kooooo00Co0000o`H00?l6003o4P000_mP2D43of08@0?o
G`Hm0omM0cX4oeX0<`?oE@0[0_m>01d4oga[]0?oNFVd0omcPm@4ogN1d0?oOH7<1?n4P/T4ohj6a`Co
Uh_600CoX9;6oin3]OnOPkGoWh>e1OnWR[L4ojbA^P03ojZ5[On/R:oo[8R_00?o[8R_1OnYRK<01?nT
RKSoYhRcojN8/onWR;<4oi^2]`GoTGfj1?n7NKd4oh9h`0CoPgc31?n7PlP2oi6>c@;oW9;90_nUWm00
0ol0003oYIo@ojFOd003ojf/eP?o^[SG0oo1`]/3olW=g1Kooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;?ooool003Sooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03_ooool3o`0002kooooo
0_l000000ol6003oG`Q1of09@@03of09@@;oH0Q01?mO1Sd3oed3>P?oFP0c0omE02/00om>01goPFfc
oh5]/`04oga[]0?oNFVd0omgJ;D00omcPmCoMh7@ogN1d002ogN1d0;oOH7<1On4P/T4ohj6a`;oUh_6
00?oUWbeoin3]OnOPkD00onOPkD5ojN:]`;o[96j0_nZQJd5ojb8[`CoZHVc00?o[HZaojN8/onWR;<0
0_nWR;<5oi^2]`CoTGfj1?n7NKd4oh9h`0;oPgc30_n<Okl4oi66a0GoW9;900?oYIo@o`000?nUWm00
0_nUWm000on][=Ko^[SGokZhe`03okZhe`03ol72foo9cMcobLgL00?obLgL5?ooool2o`0000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002cooooo001Iooooo`?o0000
;_ooool2o`000004oeh7?omO247oG`Q1oel8@@?oH0U10omP2403oel6?@CoG@<j0omJ03<01?mE02_o
QVnbohI_/_n6Kk83oh5]/`CoO6^d0_miJK@4ogMX]@CoN6Ve0omlK;D4ohB2b@;oSXK70_n<M[D4oiIl
]@CoWh>e1OnWR[L00on/TK[oZXF]ojZ5[@02ojZ5[@Go[8R_0_nYRK<2ojf:/@CoYhRc1OnKP[L2oi5m
^P;oU7nj1?n<N[/4ohQj_0GoS7no1?nAQ/@4oibBb@05ojFOd?l0003oYIo@ojFOd?nb[=801Onj^=L0
0oo7bMcobLgLolW=g003olW=g003ol_Dh?oooooooooo017ooooo00Co0000oooooooooooo00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0:oooool005Kooooo0ol0
0003ooooo`03o`000?oooooooooo02Sooooo0ol00003oeh7?`;oG`Q11?mP2D43of08@0?oG`Hm0omM
0cX2oeX0<`;oRg:a1?n6Kk83oh5]/`CoO6^d0omiJK@3ogMX]@CoN6Ve0omlK;D4oh=`]@CoS7Je1?nF
O;D4oin3]@CoYhZg00?oYH2[ojZ5[OnZQJd00onZQJd5ojb8[`03ojV9/on]R[7o[HZa00;o[HZa1?nW
R;<3oi^2]`03oin7^OnDOk[oU7nj00;oU7nj1On<N[/4ohQj_0CoS7no1?nAQ/@5oibBb@03o`000?nb
[=;o/ZcB00;o/ZcB0onj^=L3olO9g0?obLgL0oo;e>0Fooooo`03o`000?oooooooooo043ooooo001D
ooooo`;o0000<?ooool00ol0003oG@@moed4?@03oeh7?`?oG`Q11?mP2D42of08@0CoG`Hm00CoG@<j
ohmd/On?M;7oSgBa0on;L[44ohI_/P?oPFfc1?mlJk@3ogUY]0CoMfRe1?mhJKD2oga/]@CoPg2e1On<
M[D4oiIl]@CoWh>e0_nWR[L2ojF0Z`GoZXF]1On/R:l5ojf:/@CoYhRc00CoVh:goin7^OnOQkWoWhNi
1OnDOkX4ohaj^`CoR7Zl1?n<Okl4oi66a0CoW9;900?oZIo=o`000?nb[=801?nb[=800onj^=OoalWL
olO9g003olO9g003olW=g?o;e>3obmCP00;obmCP5_ooool00ol0003oooooooooo`10ooooo`00DOoo
ool3o`00033ooooo00?oFP0hoed4?OmM13d00_mM13d3oeh7?`?oG`Q10omP2D43of08@0;oG`Hm0_nD
Mk04ohmd/@CoRg:a1?n6Kk83oh5]/`?oO6^d0omiJK@4ogMX]@CoN6Ve0omlK;D4oh=`]@CoS7Je1?nF
O;D4oin3]@03ojN:]onUP:_oYH2[00;oYH2[1?nZQJd4ojb8[`03ok6<[_n]R[7o[HZa00?o[HZa1?nW
R;<5oin7^@CoU7nj1?n<N[/4ohQj_0GoS7no1?nAQ/@01OnLT/WoZIo=ojVOcOnYWlgo000000Co/ZcB
00?o`/?KolO9g?o7bM`00oo7bM`2olgIhP?obmCP0_o6f^PFooooo`03o`000?oooooooooo03oooooo
001>ooooo`Go0000<?ooool2oeX0>0?oG@@m1?mN1cl2oel8@@CoH0U10omP24000onHN[3oU7N`oiAg
/002oiAg/0CoSgBa0on;L[44ohI_/P?oPFfc1?mlJk@3ogUY]0?oMfRe1?mhJKD3oga/]@CoPg2e1?n<
M[D4oiIl]@?oWh>e00?oWWZ[ojF0ZonUP:/00onUP:/5ojZ5[@;o[8R_0onaS:h5ojf:/@;oYhRc0_n]
TKP4oin7^@CoU7nj1On<N[/4ohQj_0CoS7no0_nAQ/@2oifBb0CoZIo=00Co0000ok:/d_nb[=;o/ZcB
0oo2`m/3olO9g0CocMWR00?obmCPolKJj?o6f^P00_o6f^PFooooo`03o`000?oooooooooo03kooooo
001<ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03oeH0<_mJ03SoFP0h00CoG@@m0omN
1cl3oel8@@CoH0U100CoH0Q0oiQj/?nHN[3oV7Z`1?nDMk04ohmd/@;oRg:a00?oRF>PohIRXOn6HZ40
0_n6HZ43oh=QXP?oP62T00CoO6^dogUY]?miJKCoNFVd1?mgJ;D3ogQY]@?oO6be1?n3L;D4ohaf]@Go
UWbe00?oWh>eoiijZonNNZ/01OnUP:/5ojZ5[@03ojb8[onaS:ko/Hb^00;o/Hb^1On]R[401?nWR;?o
[I6hojfA^?n]TKP4oin7^@GoU7nj1?n<N[/4ohQj_0;oS7no0_nFR<<5oifBb0?oZIo=00?o0000ojVO
cOnb[=801Oo2`m/00oo7bMcocMWRolgIhP02olgIhP03ol_Yjoo6f^Soa][X00;oa][X00?o]mWaoooo
ooooool05?ooool00ol0003oooooooooo`0nooooo`00BOooool3o`0003?ooooo0omF0382oeX0>0Co
G@@m0omN1cl3oel8@@04of09@OnLO:ooW7b_oial[`GoV7Z`0_nDMk000on?IYooS6FPohaUX002ohaU
X0?oRF>P1?n6HZ43oh=QXPCoP62T0ommGjD3og]OY`03ogMX]OmhJKGoN6Ve00;oN6Ve0omlK;D4oh=`
]@CoS7Je0onFO;D00onELj_oWWZ[oiijZ`02oiijZ`CoYH2[1?nZQJd00on`RZgo/Hb^ok6<[P03ok6<
[PCo[HZa00?o]iRhojfA^?n]TKP00on]TKP4oin7^@CoU7nj0_n<N[/2oi1o_@CoSh6o1OnFR<<4oifB
b0CoZIo=00?o0000ol;3foo2`m/00oo2`m/2olcJi0?ocMWR0oo;jN/00oo6f^So]mWaokOIl@02okOI
lACooooo0ol0000oooooo`008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^023ooooo0_l0000eoooo
o`?oEP0b0omJ03P3oed4?@CoGPLo00CoG`Q1oj1o[onPOjooX7n_1?nLO:l4oiQj/003oiAg/?n?IYoo
SfJO00CoS6FP0on9Hj04ohIRX@?oPf6R1?n0H:@3ogeOY@CoNenW0omkHJP01?mhJKGoO6beoga/]Oml
K;D4oh=`]@CoS7Je00CoUWbeoiEcZonELj_oUG>[1?nNNZ/5ojF0Z`;oZXF]0_n`RZd6ok6<[P;o[HZa
0ongV;P4ojfA^0CoWhNi0_nDOkX2oiF2_0CoT7nm1On?PKl4oiJ8``GoWI;800GoZIo=okZif?nj^MSo
0000okZif003ol;3f`Coc=[T00CocMWRol_Yjoo;jN_obnW[0_nkkO@5okOIlAGooooo00?o0000oooo
ooooool0?Oooool002;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`?o00000_ooool00ol0
003oooooooooo`0aooooo`04odl0:?mF03;oEP0boeH0<P;oFP0h1?mM13d3oeh7?`03oel8@OnPOjoo
X7n_00;oX7n_1?nLO:l2oiQj/0;oTFRO0on?IYl4ohaUX0CoRF>P0on6HZ44oh=QXPCoP62T0ommGjD3
og]OY`CoNf6X0omnHjX4ohAWZPCoS6j[1OnELj/3oiijZ`GoYH2[00?oZXF]ok2:[On`RZd00_n`RZd5
ok6<[P03ojf:/OngV;So]iRh00;o]iRh1On]TKP2oin7^@03oij9_OnEP[coUH:l00?oUH:l1?n@Okd4
ohn1_`CoUXS31?nMT/P01On^ZmCo^[WHokZif?nj^MSo000000;o^[WH00?o`/?KolcJi?o<f^@00_o<
f^@2ol_cj`03ol_YjonkkOCo^ngd00?o^ngd0_ngfO43oj3@n1Gooooo00?o0000ooooooooool0??oo
ool002;ooooo00Go410@oooooooooooooooooa0@400Kooooo`;o0000>?ooool00om?02SoEP0boeH0
<P02oeH0<P;oFP0h1?mM13d01?mN1cooY8:_ojB2[onTPZl4oj1o[`;oW7b_0_nCJZ04oi5XW`CoSfJO
0on<IJ04ohUSX0?oQV:Q1?n3HJ84oh1PY0?oOEnU1?mkGjL3og]QZ0?oOV>Z1?n4IjX4oha^Z`GoUG>[
0onNNZ/5ojF0Z`Go/8Z]1OnaS:h5okNH^0Co[I6h00?o[IBmoij9_OnNRKd00_nNRKd4oiF2_0CoT7nm
1?n?PKl5oiJ8``03oifBb?n^ZmCo[Z_D00;o[Z_D0_nj^MP01?l0003o^[WHolSFi?o8e^@3olcJi0;o
bo?[0_ngn>d4ok_]m0;oX^Gl1OnPd?PEooooo`03o`000?oooooooooo03_ooooo000Rooooo`05o`00
0?ooooooooooooooool000006?ooool3o`0003Sooooo00?oAP0Iodl0:?m?02P00omF0383oeX0>003
oed4?OnWQK3oYhF`00;oYhF`1?nTPZl2oj1o[`03oiI]X?nCJZ3oTfZP00;oTfZP1?nAJ9l4ohmVW`?o
S6FP1?n9Hj04ohIRX@?oPf6R1?n0H:@3ogeOY@CoNenW1?mkHJP3ogiSZPCoQ6NZ1?n<KZ/4oiEcZ`?o
WWZ[1?nUP:/00on/QZgo/8Z]ok2:[@03ok2:[@Co/Hb^0_noWkP5okNH^0;o[I6h0_n]U;d4oij9_@Co
UH:l1?n@Okd5ohn1_`?oUXS300?oXig>ojj[e?n^Zm@00on^Zm@2okZif003o`000?o8e^Cob=KT00;o
b=KT00?oc=[Tol_cjoo;ln/01?ngn>d00onkkOCoX^Gloj;Uo003oj;Uo0;oX=3h0_n7_OPEooooo`03
o`000?oooooooooo03_ooooo000Rooooo`05o`000?ooooooooooooooool000005_ooool3o`0003So
oooo0om601T00om?02SoEP0boeH0<P02oeH0<P03oeX0>?n[Qk3oZhN`00GoYhF`1?nTPZl00onPOjoo
UVfPoiI]X004oi=ZX0CoTFRO1?n?IYl4ohaUX0?oRF>P1?n6HZ43oh=QXPCoP62T0ommGjD4og]OY`Co
Nf6X0omnHjX4ohAWZPCoS6j[1?nELj/4oiijZ`;oYH2[0on/QZd5ok2:[@;o/Hb^0onoWkP5okNH^003
ojfA^?n]U;go[IBm00;o[IBm0onNRKd5oiF2_0CoT7nm1?n?PKl00onFR<?oXig>oj>McP02oj>McPGo
[Z_D00?o^[WHo`000?o8e^@00_o8e^@2olShj`04ol_cjongn>go]oS]okOhk@CoUo3_0_nRiO`2oh[?
oPGoQkgh5Oooool00ol0003oooooooooo`0jooooo`008_ooool01Ol@413ooooooooooooooooo410@
01?ooooo0ol00002ooooo`03o`000?oooooooooo03Cooooo00Co>004odH06Om601WoAP0I0_m?02P4
oeH0<PCoZhN`1?nWQK03ojB2[`04oiU_XOnFKJ3oUVfPoiI]X0GoTfZP0onAJ9l4ohmVW`CoS6FP0on9
Hj04ohIRX@?oPf6R1?n0H:@3ogeOY@CoNenW1?mkHJP3ogiSZPCoQ6NZ1?n<KZ/4oiEcZ`CoWWZ[00?o
YH2[ojb6[On/QZd00_n/QZd5ok2:[@03ok6<[_noWkSo_inh00;o_inh1?ngV;P00onhW[ko[IBmojfD
_@03ojfD_@CoWXVm1?nEP[`4oi1o_@;oSh6o0_nITLT5oj>McPCo[Z_D0_o1c><00ol0003ob=KTolSF
i002olShj`;oZoWM0omoild2oiO`k`?oQmom1?n:coh4ohNmn1Kooooo00?o0000ooooooooool0>Ooo
ool002;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`?o0000>oooool2ocP010?oAP0I0_m?
02P00omF03;o_Z_7ojj:/005oj^7/0CoYhF`00CoY8:_oiU_XOnIKj7oVFnQ1?nFKJ04oi=ZX0?oTFRO
1?n?IYl4ohaUX0?oRF>P1?n6HZ44oh=QXPCoP62T0ommGjD3og]OY`CoNf6X0omnHjX4ohAWZPCoS6j[
1OnELj/2oiijZ`03ojB1[_n/QZgo[8J]00?o[8J]1On`RZd6oknO^0;o]iRh0onhW[h4ojfD_@CoWXVm
0_nEP[`2oiJ9``CoUX[51OnITLT5oj>McP03ojj[e?o1c>?o`LcS00;o`LcS00Go0000olSFi?o8n>_o
b?S[oj_ig@03ogoWc@?oNnC[0_n7god2ohJnn@GoPK;d1?mkZo8Dooooo`;o0000>oooool002;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`;o0000??ooool00olQ003o>004ocP01003odH06@04
odl0:?nmZ<Co_JS4okj[a`?o[XZ`1?n[Qk04ojN5/0CoVFnQ1?nFKJ04oi=ZX0CoTFRO0on?IYl4ohaU
X0CoRF>P0on6HZ44oh=QXPCoP62T0ommGjD4og]OY`?oNf6X0omnHjX4ohAWZPCoS6j[1OnELj/00onN
NZ_oY86^ojB1[P05ojb6[@Co/8Z]0_o1XkX5oknO^003okNH^?nhW[ko^9jn00;o^9jn1On]U;d2oij9
_@03oif>`onFRL?oUXW300?oUXW31?nFR/D4oiVAb@CoXig>0_ng_n04ol7<h`03o`000?o6n>coXOG>
00;oIm:S0omWfL@2og_Tj`;oR/gn1?n6__T5oh6bm0CoNj_b5Oooool00ol0003oooooooooo`0hoooo
o`00<_ooool5o`0003_ooooo0_lQ00000olh00CoAP0IodH06@02odH06@?o_JS41?n^R[05oj^7/0;o
YhF`00?oW7:RoiU_XOnIKj400onIKj43oiI]X0CoTfZP1?nAJ9l4ohmVW`?oS6FP1?n9Hj03ohIRX@Co
Pf6R1?n0H:@3ogeOY@CoNenW1?mkHJP3ogiSZPCoQ6NZ1?n<KZ/3oiEcZ`03oiUj[onTPJkoY86^00;o
Y86^1On/QZd2ok2:[@?o`J>j1OnoWkP5okRN_PGo[IBm00CoWXVmoif>`onMS/?oWHk31?nFRL<4oiJ:
a@GoVI7900?oXig>okNoh?ng_n000ong_n001_o1c>?oa_S/o`000?l0003oXOG>ofOBX`?oImW40on<
goh4oh[=oPCoQ[ki0_n1/_@2oh>Qi`CoOjC[5_ooool00ol0003oooooooooo`0gooooo`00<?ooool2
o`0003oooooo0_lQ0002ocP01003odH06OnlYL7o_JS400?o_JS400?o/8^`ojj:/?n^R[000_n^R[05
oj^7/003ojN5/?nLLZ;oW7:R00GoVFnQ0onFKJ04oi=ZX0CoTFRO1?n?IYl3ohaUX0CoRF>P0_n6HZ40
0on:HiooR6>PohQSX002ohQSX0CoQF:R0on3HjD4oh1SZ0?oOVB[00CoNf6XogiSZ_mnHj[oOV>Z1?n4
IjX4oha^Z`04oiEcZonINZooVGZ_oiUj[`CoY86^1On/QZd00on`RZgo`J>jol6S^P02ol6S^PCo_inh
0_o2Z<05okRN_P?o[IBm00?oZIO3oif>`onMS/<00_nMS/<4oiJ9``CoUX[51?nITLT00onY/=go]koP
okNoh003okNoh0?o000000?oa_S/o`000?l000000omjho02ohcOoP;oT:_X1?n;Y>D4ohNQi@GoPj7W
1?moY>/Eooooo`03o`000?oooooooooo03Oooooo000]ooooo`?o0000?oooool01Ol0003o8@00ob40
0?lh00CobNS/00?o_:G10onmZ<@3ok2;/0?o[XZ`1?n[Qk000onPMZ?oW7:RoiabXP02oiabXPCoVFnQ
0onFKJ04oi=ZX0CoTFRO1?n?IYl2ohaUX003oheTWOn<HikoS6>N00;oS6>N0on:Hil4ohQSX0CoQF:R
0on3HjD4oh1SZ0CoOVB[0on0Ijd4ohE/[`CoSg>`1OnINZl3ojB1[PGo[8J]1_o1XkX2oknO^0?o`ZS0
1OnhW[h00on]U;goZIO3ojVG``02ojVG``CoWHk31?nFRL<4oiJ:a@03oiVAbOnY/=goZK3M00;oZK3M
00Co]koPo`000?l0003o00000_nomO001?n>k<?oGMGCoiJklOl00004oi>ck@CoT:_X1?n;Y>D4ohNQ
i@GoPj7W1?moY>/Eooooo`03o`000?oooooooooo03Kooooo000/ooooo`;o0000@?ooool01Ol0003o
8@00ob400?lQ003o^Z6o00Go_:G100?o_JS4ok2;/?n`Rk000_n`Rk04ojj:/0;oZhN`0_nPMZ<4oiab
XPCoVFnQ0onFKJ05oi=ZX0?oTFRO0on?IYl01?n?I9coSFBMoheTWOn=I9d4ohaSWP?oRV>O1?n8Hj05
ohERXP?oPf>U1?n0HjP3ogiTZ`?oP6N]1?n5K:l4ohmc/0GoVGZ_0onTPJh4ojb6[@;o_ZFo1Oo1XkX0
0onoWkSo`ZS0ol:X`002ol:X`0Co^9jn00?o]:75ojVG`onYUl<00onYUl<4oif>``CoUXW30_nFR/D2
oj:Wf@?oZK3M0ol000001Ong_n3o_oG`okoel?nomO3oS^c300CoU[_a00?o0000oi>ckOnC/nd00_nC
/nd4oi2[j0CoRjCU1?n7XND2oh>Qi`;oSISI1On<Xn@Eooooo`03o`000?oooooooooo03Gooooo000/
ooooo`?o0000?Oooool2o`000003ob400?o8fNKob=WV00?o^Z6o1?nlYL45ok2;/0Co[XZ`00CoZhN`
oj1fXonPMZ?oX7JS1?nLLZ84oiU_X@CoUVfP1?nCJZ03oi5XW`04ohmVWon?I9coSfBLohmTW0?oSFBM
1?n<Hih4ohYSW`CoR6>P1?n5HZ83oh=SY@CoP6>X1?mnI:/3oh1W[@CoQFb_1?n?Lk04oiUj[`CoY86^
0_n/QZd3okjU_`Co`J>j00?oa[75ol:X`?o2Z<001?o2Z<000onhW[ko]:75okBQa@02okBQa@CoZIO3
1OnMS/<2oiJ9``03oifRf?nRYmWoXZOI00;oXZOI0ol00002ojV`g@?o/Nkg00Co_oG`oiRolonH_o?o
V;oc1?nF^o401?l0003oTk?]oi26aOn@Q/D4ohj7a`CoSX_;1?n=T=45ohfHf@GoS:?T5?ooool00ol0
003oooooooooo`0eooooo`00;?ooool01?l0003oooooo`000?l0000jooooo`;o00000oo3cN400oo8
fNKo^Z6ookZQ_`02okZQ_`?o_:G100?o/8b`ok2;/?n`Rk000on`Rk04ojj:/0GoX7JS0onLLZ84oiU_
X@CoUVfP1?nCJZ02oi5XW`03oi1UW?n?I9coSfBL00;oSfBL1?n=I9d4ohaSWP?oRV>O1?n8Hj04ohER
XP?oPf>U1?n0HjP4ogiTZ`?oP6N]1?n5K:l4ohmc/0CoVGZ_1?nTPJh00on/QZgo_ZFookjU_`02okjU
_`?o`J>j0oo6/LD4ol:X`003okj/aondXLGo]:7500?o]:751OnYUl<2oif>``;oXJGI1?nMX]P3o`00
00;oXZOI00?oZK3Mok7^monak_L00_nak_L2oiRkl0;oV;oc00?oUXK0oi:6`onBQ/<00_nBQ/<00ol0
003oT8K5oi26a@02oi26a@CoSXO71?n>Rl/4ohf@d@GoSISI0_n<Xn@2oin^hQ?ooooo00?o0000oooo
ool000002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o
0000oa0@4?o<c<`06Oooool002cooooo0_l00002ooooo`03o`000?oooooooooo03Gooooo0ol00004
ol?=h@Ko^Z6o00Co_:G1ok2</?n`S;3o/8b`1On`Rk02ojj:/003oj=iYOnPMZ?oX7JS00?oX7JS0onL
LZ85oiU_X@?oUVfP0_nCJZ02oi5VW@?oT6FL1?n?I9`4oheTW@CoS6>N0on:Hil4ohQSX0CoQF:R0on3
HjD4oh1SZ0CoOVB[0on0Ijd4ohE/[`CoSg>`1OnINZl2ojB1[P03okJTa_nnYKoo_ZFo00Co_ZFo00?o
`J>jolJaaOo6/LD00_o6/LD3ol:X`0?o_Zc71?ndXLD4ojVG``03ojfafonQYMWoXJGI00;oXJGI00Go
WJ;Ho`000?l0003o0000oifRf002oj:Wf@CoYNKk00?o/NkgoiRkl?nH^o000_nIQ[h4oiJ6`0CoTXK3
00Co0000oi26aOn@Q/GoT8K51?n>QlL4ohj;b`GoSI3A0_n=V=T2oibRf@GoWjkR5Oooool00ol0003o
ooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMg
MoooooooV9RHob4Q8@0Iooooo`00:oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
03?ooooo00Co0000okk3g_nn`mko_/?N0oo3cN42okNM_PCo^Z6o1On`S;05ok2;/004ojj:/?nSNJGo
XgVUoj=iY@CoX7JS0onLLZ85oiU_X@;oUVfP00?oTfRNoi5VWOnAIYd00_nAIYd3oi1UW0CoSfBL1?n=
I9d4ohaSWP?oRV>O1?n8Hj04ohERXP?oPf>U1?n0HjP4ogiTZ`?oP6N]1?n5K:l4ohmc/0GoVGZ_00Co
Y86^okJTa_nfY<Ko]ZC61OnnYKl6olJaa@03ol:X`?nn[<Oo_Zc700;o_Zc71OndXLD00onYUl?o[K7K
ojfaf`02ojfaf`;oXJGI0_l00003oifRf0;oTMon1?nUi_/2oib5^`GoVHJn0onFQ/04oi:6``04oi26
aOl0003oT8K5oi26a@CoSXO71On>Rl/2ohf@d@;oVIO@1OnLX]T4oin^hQGooooo00?o0000oooooooo
ool01Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000I
ooooo`00:oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo033ooooo0_mJdKT5okk3
gP04ol?=hOngWKko]ifnokNM_P?o^Z6o1_n`S;04ok2;/003ojIlY_nSNJGoXgVU00;oXgVU1?nPMZ<4
oiabXPCoVFnQ00?oUVfPoi=XW_nCJ9h01?nAIYd4oi1UW0?oSfBL1?n=I9d4ohaSWP?oRV>O1?n8Hj05
ohERXP?oPf>U1?n0HjP4ogiTZ`;oP6N]1On5K:l4ohmc/0?oVGZ_00?oYYo?okJTa_nfY<H00onfY<H3
okjU_`;oa;S>1?o6/LD00oo2]Lko_Zc7okj/a`03okj/a`Co]:7500?o^;oOojfafon]/M/00_n]/M/3
o`0000;oXJGI00?oWJ;Hoi7Oo_nAgoh00onAgoh00onUi__oW8Fkoib5^`03oib5^`CoVHJn0onFQ/04
oi:6``03oi26aOl0003oT8K500;oT8K51?n>QlL2ohj;b`;oUho91OnIUm04oibRf@;oWjkR0on__>@E
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B406Oooool002_ooooo0ol00005ooooo`03o`000?oooooooooo02kooooo00?o
F]6iokVng_ni_]h01?nn`mh00onbV[ko]ifnokNM_P03okNM_P03okZQ_on`S;3o/8b`00Ko/8b`0_n`
Rk02ojIlYPCoXgVU1?nPMZ<4oiabXP?oVFnQ00CoUF^Ooi=XW_nCJ9koTfRN1?nAIYd4oi1UW0?oSfBL
1?n=I9d4ohaSWP?oRV>O1On8Hj04ohERXP?oPf>U1?n0HjP4ogiTZ`?oP6N]1?n5K:l4ohmc/003oiUj
[onVWlooYYo?00;oYYo?1OnfY<H01?nnYKooa;S>olBhc_o4^<h3olJaa@?o`[G>1Onn[<L00ondXLGo
^;oOokRog`02okRog`?o00000_n]/M/2oj6Uf@?oQn3l0_nAgoh4oij4]`CoW8Fk1?nIQ[h4oiJ6`0Co
TXK300CoT8K5o`000?nCPkkoTh>n1?nDR<@5oiN?b@CoVIO@0onLX]T00on[]=oo[kcTojnli004ojnl
i1Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000
oeEEEOl0003o410@olc<c00Iooooo`00:oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo02_ooooo00?oN>CGokVng_ni_]h00oni_]h00onn`mko/YZnok:J_P02ok:J_PCo]ifn2On`S;00
1?n`Rk3oYWbVojIlY_nVO:H4oj=iY@GoX7JS0onLLZ801?nIKj7oUF^OoiE[WonEJil4oi=XWP?oTFJM
1?n@II`4ohmTW0?oSFBM1?n<Hih4ohYSW`CoR6>P1?n5HZ83oh=SY@;oP6>X0_n9M[L4ohEk`@?oPX;:
0_n5K:l2ohF;d@CoUIOC1OnVWll4okJTaP03okbnfoo4^<koa;S>00?oa;S>00?oa[75ol:ec_o2]Lh0
0_o2]Lh4okj/a`03olGAhonh_moo^;oO00?o000000?o^;oOojfafon]/M/00on1iO42ohOPo0;oWIcB
00?oX8>doij4]onNQ;L00onNQ;L4oib5^`GoVHJn0onFQ/02oi:6``;oU82j0_nCPkh00ol0003oTh>n
oi>3_P04oiB8a0CoUho91OnIUm001?nLX]WoZkCOoj^dgon[]=l4ojnli003okK5i_oooooooooo01?o
oooo00?o0000ooooooooool00oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7
Qoooool06oooool002_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Wooooo`;o
Q^_S0one_^43okVngP03ojfG`?nbV[ko/YZn00?o/YZn0ongWKh00on^Rk3o/8b`ok2</007ok2</0Co
YWbV1?nSNJD5oj1fX`;oW7:R00?oV6jPoiE[WonEJil00_nEJil4oi=XWP?oTFJM1?n@II`4ohmTW0?o
SFBM1On<Hih3ohYSW`CoR6>P0_n5HZ82ohm_ZP?oSG:`1On9M[L4ohEk`@;oPX;:1On5Rm44oiFGd`Co
YYo?0onfY<H3okbnf`Coa;S>1_o2]Lh00onn[<OoaM7SolGAh`03o`0000?o^;oO00?oK=gBoin<_onO
S;l01?nNTlP00onQP[7oX8>doj23]002oj23]0CoWXBg1OnLQK/4oiV6_P;oUXK000?oUgjgoiB0^_nD
P;X00onDP;X2oi>3_P03o`000?nCPkkoU8S400?oU8S41OnGSlT2oiVGd0;oZ:_I1On[]=l00on__>Co
]/GVokK5iP02okK5iQ?ooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooM
gMgo410@oiRHV00Kooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
02Cooooo00?oQ^_Sok34j?ne_^401One_^401?ni_]ko[IO0ojfG`?n]Ul05ok:J_P04okNM__n^Rk3o
[X^`ojj;/0Oo/8b`00?oZ7jWojIlY_nVO:H00_nVO:H5oj=iY@CoX7JS00?oW7:RoiQ^X?nHKZ001?nE
Jil4oi=XWPCoTFJM0on@II`4ohmTW0CoSFBM1?n<Hih3ohYSW`;oR6>P0_n@KJH4ohm_ZP?oSG:`1On9
M[L4ohEk`@?oPX;:1?n5Rm44oiFGd`GoYYo?00?o]ZC6okbnfonl_]/00_nl_]/3olBhcP;o_koI1?o2
]Lh01?o5h^go0000o`000?l00003olGAh`03okRogonOQ[SoWhbo00CoWhbo00CoWY?8oj62/OnQP[7o
XH:a1?nPPk@5oij4]`CoW8Fk0_nIQ[h2oiUn/`CoUgjg1?nDP;X2oi>3_P03o`000?nCPkkoU8S400?o
U8S41?nGSlT00onTXM;oZ:_IojR[f@03ojR[f@?oZkCO00?o]<?UokK5i_nfaNH01?nfaNHEooooo`09
o`000?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@
6Oooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooo
ooooo`04ooooo`?o00002_ooool00ol0003oooooooooo`0Qooooo`03ohG[hOn`a>So/<CX00;o/<CX
1?ne_^400onXU/Co[IO0ojfG`002ojfG`0Co/YZn00?oZhRaojj;/?n^Rk000_n^Rk06ok2</0?oZ7jW
1?nVO:H4oj=iY@?oX7JS00CoVg6RoiQ^X?nHKZ3oV6jP1?nEJil4oi=XWPCoTFJM0on@II`4ohmTW0Co
SFBM1?n<Hih2ohYSW`03oi5[Xon@KJKoT6fV00;oT6fV1On?KjX3oheb/0CoRGJg1?n5Nl43oh:2bPCo
QH_A1OnEUm<2ojJOc`;oY[k[1_nl_]/01?o4^<ko_koIoknofOno_mT2ol:ecP?o000000?oaN;]olGA
hoo5dN<00_o5dN<3oin6^0CoWhbo00?oXX6_oj62/OnQP[400onQP[43oj23]0GoWXBg0_nLQK/2oian
/@GoVGjc0onGO[L4oiB0^P?oTh>n00?o0000oi>3__nDR<@00onDR<@01?nGSlWoY:7BojBQd_nTXM85
ojR[f@03oj^dgond`nGo]<?U00;o]<?U1?nfaNH00ongbnWoooooooooo`0Cooooo`03o`000?oooooo
oooo02oooooo0008ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00005
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07Oooool2og[UeP?o[<kb1?n`a>P0
0one_^7oZ9K4ojRFa002ojRFa0?o[IO00onbV[h2oj^8/@Co[X^`1?n`S;000onXOjOoZ7jWojQnY`02
ojQnY`CoYWbV1?nSNJD01?nPMZ?oVg6Roi]aX_nKLJ84oiQ^X0?oUF^O1?nCJ9h4oi5VW@?oT6FL1?n?
I9`4oheTW@;oS6>N0_nAJZ83oi5[X`GoT6fV1?n?KjX3oheb/0GoRGJg1?n5Nl43oh:2bPCoQH_A0_nE
Um<2oi6ilPGoY[k[1?nl_]/00ondb>Wo_koIoknof@02oknof@;o00001Oo5h^d00oo5dN?oWh6boin1
/P04oin6^004oin<_onRPJooXX6_oj:1[`GoXH:a1?nPPk@3oij4]`03oimn[onLO[7oW7ja00;oW7ja
1OnIO[<3oiMn]`GoU82j0onCPkh00ol0003oU8S4oiB8a002oinFb`GoY:7B0onXZmT2ok>ohPGo]<?U
00?o]/GVokO;jOngbnT00_ngbnTEooooo`03o`000?oooooooooo02kooooo000@ooooo`05o`000?oo
ooooooooooooool000002oooool01?m4A4CogMgMooooool00006ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool06_ooool00omjiMKoYM_jojGKnP05ojc>lP;o/<CX00?oXIO;ojRFa?nX
U/@00onXU/@4ojfG`004ok:J__n[R;7oZhRaoj^8/@Go[X^`0_n`S;02ojQoY`CoZ7jW1?nVO:H3oj=i
Y@03oimfY?nKLJ;oVg6R00;oVg6R1?nHKZ04oiE[W`?oTfRN1?nAIYd4oi1UW0?oSfBL0on=I9d00onA
JJ3oTFZRoi5ZXP02oi5ZXPCoTF^S1?n@KJH4ohm_ZP?oSG:`1On9M[L2ohEk`@;oVI_D0on=YND5ohB^
l0CoTKWb1OnV_^/00onl_]_o]<SYokC8j@02okC8j@?o00000on`k_L2olGRk@03oiil[OnOPK;oWh6b
00;oWh6b1?nOQ[P5oj:1[`CoXH:a1?nPPk@01?nNQ;OoWgj_oimn[onOOZl5oian/@CoVGjc1?nGO[L4
oiB0^P;oTh>n00?oWHk3o`000?nOU//01?nOU//4ojBQdP03ojR[fOnc_n;o/koR00?o/koR0_nd`nD2
okS@k0Co]l_Y0_nbb^`Eooooo`03o`000?oooooooooo02gooooo000@ooooo`05o`000?oooooooooo
ooooool000002oooool01?oMgMgoEEEEooooool00006ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool05oooool2ofSJ`@CoYM_j0_n/c_82oi^Ld`CoXIO;1?nXU/@3ojfG`003ojF5/on[
R;7oZhRa00?oZhRa1?n^Rk001?n`S;3oZ7nWojQoYonXOjL4ojQnY`CoYWbV0_nSNJD2oimfY0CoVg6R
1?nHKZ04oiE[W`?oTfRN1?nAIYd4oi1UW0?oSfBL00CoSFBMoi5YX?nAJJ3oTFVP1?nAJZ84oi5[X`Co
T6fV1?n?KjX4oheb/0?oRGJg00?oWi75oiVKe?nIVm@00onIVm@3ohfUi@GoQ:k`1?nA^O82ojJnj`?o
ULWj00Ko]<SYo`000?l0003o0000okC8jOno_mT3ok3^m`CoWWb]1OnOPK82oin6^003oj>0[OnRPJoo
XX6_00?oXX6_1OnQP[42oj23]003oj5o[_nOOZooWgj_00?oWgj_1?nLO[45oiUn/`?oUgjg0_nDP;X2
oib8_0CoWHk300?o0000oinFbonOU//00onOU//2ojBQdP;o/[WO1?nc_n82okWEkPCo^=3/00?o]l_Y
ok;:k?nbb^`00onbb^`Dooooo`03o`000?oooooooooo02gooooo000@ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`;o00003oooool2o`0001Kooooo00CoJ=[1
oikVo?nNi_coW^Kl0_nUfoX00onHYMooVicCoi^Ld`03oi^Ld`?oXIO;1OnXU/@00on]Ul3oYHFcojF5
/`05oj^8/@?o[X^`00?oYgnXojQoYonXOjL00_nXOjL4ojQnY`CoYWbV00CoXgVUoimfY?nOMZCoWgJT
1?nKLJ84oiQ^X0CoUF^O1?nCJ9h3oi5VW@CoT6FL0_n?I9`00onAJ:3oTFVPoi5YX002oi5YX0CoTFZR
1?nAJj<4oi1]YPGoSfnZ0on=L[000on9M[OoWi75oinAa@02oinAa@CoVI_D1?n=YND2ohB^l0?oO/On
1Omob?h01?nEbO[o0000o`000?l00002okC8j@?oMN7[00?o/>kgoiahZ_nLN:X01?nNO:d5oin1/P04
oin6^?nSP:goXh2]oj>0[@CoXX6_1OnQP[400onPPkCoXGn^oj5o[P05oimn[`CoW7ja1OnIO[<2oiMn
]`03oif3]onLR;coW8Rl00?oW8Rl1?nMS/<01Ol0003oWiK;oinFbonOU/_o/K;J00Go/[WO00?o/koR
okWEk_nieNh00onieNh2okS@k0;o/m7_1?nbb^`00on/a^goooooooooo`0Cooooo`03o`000?oooooo
oooo02cooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000006
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool01?mEbj_oVnggoi_]monK
kOL2oikVo003oiRbj_nHYMooV:GO00;oV:GO1?nKW=<3oj6Gb`CoZ9K400?oWX>fojF5/onUQK<00_nU
QK<4oj^8/@;o[X^`0_nWOjP5ojQoY`CoZ7jW0_nVO:H00onSNZOoWgJToimfY003oimfY0CoVg6R0onH
KZ04oiE[W`CoTfRN0onAIYd2oi1UW0GoTFRP1OnAJJ03oi5ZXPCoTF^S1?n@KJH5ohm_ZP;oSG:`00?o
XHVjoinAaOnOTLD00onOTLD5oiVKe0;oSJGU0onKb?L4ogk7oP;oOlSn0ol00002oiUh[003oi]dY_nJ
MJOoVWFW00;oVWFW1?nLN:X5oiil[@?oWh6b00?oYH2/oj>0[OnSP:d00_nSP:d4oj:1[`CoXH:a00?o
Xgn]oj5o[_nQOjh00_nQOjh4oimn[`GoW7ja0onIO[<00onOPK?oWH>goif3]`02oif3]`CoW8Rl1OnM
S/<00ol0003o/K;Jok6bfP02ok6bfP?o/[WO0_nkfo04okWEkP03okCIloncdNoo/m7_00?o/m7_00?o
//[/ojc6kOn/a^d00_n/a^dCooooo`;o0000;_ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0<ooooo`04o`000?nOlO?oWo7coioal`;oVngg0_nQ`_03oiRbjPCoV:GO0onKW=<4oj6Gb`04ojRF
a?nNPkKoWX>foij3]PCoYHFc1?n[R;400on^Rk3oYgnXojMoZ002ojMoZ0CoZ7nW1?nXOZL00onVO:Ko
XgZWoj=jY`05oimfY0CoVg6R0onHKZ04oiE[W`CoTfRN0_nAIYd00onAJJ3oTFRPoi5XX005oi5XX0Go
TFVP1?nAJZ83oi5[X`GoT6fV0on?KjX00onPP[?oXHVjoj69^P02oj69^PGoWi750_nIVm@3ok?0h`?o
VlSg0_mDclD2oiak[@?o00000onOO:`00onIN:coVgBVoi]dYP05oiYeY`?oW7RZ1OnNO:d01?nOPK;o
YH2/ojF0[?nUP:`4oj>0[@GoXX6_0_nQP[42oj=o[@CoXGn^1?nOOZl5oian/@04oiUn/onOPK?oWh6c
oin1/`CoWH>g1?nLR;`4oif>``03ok2/e?l0003o/K;J00?o/K;J00?o/[WOok_Kl?nkfo000onkfo00
0onieNko]=WcokCIl`02okCIl`;o/m7_0on]bnl4ojc6kAGooooo00?o0000ooooooooool0:oooool0
02Wooooo0_l0000Dooooo`03o`000?oooooooooo00[ooooo0onOlO<3ojg>l@CoXL;`0onH/^X4oiRU
g`?oVicC0_nQUl/00onDOk[oWX>foij3]P02oij3]PCoYHFc1?n[R;45ojMoZ0CoZ7nW0onXOZL00onW
OjWoXgZWoj=jY`02oj=jY`CoWgJT1?nKLJ84oiQ^X0?oUF^O1?nCJ9h00onAIYgoTFVPoi5YX008oi5X
X0CoTFVP1?nAJZ84oi5[X`CoT6fV00CoSfnZoj22/onPP[?oX8:c1?nQRKX4oinAa@03okZcd_nc`>?o
/l3S00Co/l3S00?oVlSgoi=g/OnCMk400ol00002oiak[@?oWgb/00?oW7FVoi]dY_nKM:H00_nKM:H4
oiYeY`?oW7RZ1?nNO:d00onVP:_oYH2/ojF0[003ojF0[0?oXh2]1OnRPJl00onQP[7oXgn]oj=o[@02
oj=o[@?oXGn^1OnOOZl3oian/@03oj20/?nOPK?oWh6c00?oWh6c0onMPkL5oib8_003oif>`on`[=Co
/:cD00;o/:cD00?o0000ok6bf_na/]X00_nmhO44ok_Kl003okCRm_ndfO?o]=Wc00;o]=Wc0_n]d_<5
ojg;k`;o[<K]0_nXa>hEooooo`03o`000?oooooooooo02[ooooo000Yooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool01oooool2ojgdlP?o^m?/1?n]c_42oj72l004oi6Fe?n6RLooQXW?
ohJ9c`CoQX770on<Okl4oiAo^PCoWX>f1?nUQK<2oj^8/@03ojAmZOnWOjSoYgnX00?oYgnX1?nXOjL2
ojQnY`;oYgnY1?nSNZL4oimfY0CoVg6R1?nHKZ03oiE[W`;oTfRN0_nAJZ83oi5YX0SoTFRP1?nAJJ04
oi5ZXPCoTF^S0on@KJH00onOOJkoX8:coj22/`03oj22/`?oXHVj0onOTLD3okZcdPCo/l3S00Go/o_U
oi=g/Ol0003o0000oi=g/@04oiak[@04oiml[?nLMJKoW7FVoiaeYPCoVgBV1?nJMJL4oiahZP;oWWb]
0_nVP:/5ojF0[0CoXh2]0onRPJl00onUPJgoXgn]oj=o[@03oj=o[@?oXGn^1OnOOZl01?nLO[7oX82`
oj20/?nPP;05oin1/`CoWH>g0onLR;`00on`Yloo/:cDok2/e004ok2/e003o`000?nmhO7o_N7a00;o
_N7a00?o^m_`okCRm_ndh_H00_ndh_H00ondfO?o[M;cojgBl`03ojgBl`;o[L__0_nXb?45ojS4kQCo
oooo00?o0000ooooooooool0:_ooool002Wooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`03ooooo`04oeG:Yon]m?;o[OCbojgdlPGo^m?/0_n]c_400onOXmOoTIKDoi6Fe002oi6Fe0?o
QXW?1?n6PLL3ohao_`?oU7nj1?nNPkH4ojF5/`04oj^8/OnTOJWoY7fYojAmZ@CoYgnX1?nXOjL00onX
OZOoYgnYojMoZ@02ojMoZ@?oXgZW1?nOMZ@4oi]aXPCoV6jP0_nEJil00onCK:?oTFZRoi5ZXP02oi5Z
XPCoTFVP1onAJ:04oi5YX0CoTFZR1?nAJj<01?n@KJKoWgf^oimm[_nOOJh5oj22/`CoXHVj00?oWi75
okZcd_nj/m800onj/m800onc`>?o/o_Uo`000002o`0000?oTgNa0_nLNjd2oiIbY`GoW7FV0onKM:H4
oiYeY`CoW7RZ00?oWWb]ojJ0ZonVP:/00_nVP:/4ojF0[0CoXh2]00CoXX6_ojF1[OnUPJgoYH6]1OnS
Ojd4oj5o[P?oWgj_00?oXh6_oj20/?nPP;000onPP;04oin1/`CoWH>g00?oW8Rlok2Wcon`Yll00_n`
Yll4ok2/e003okkYl_nmhO7o000000;o_N7a0onbk?L2okCRmP;oZm[h1?n]d_<00onVc_CoZ<SaojS8
l@03ojS8l@;oZ<C^0onT`NhDooooo`03o`000?oooooooooo02Wooooo000Yooooo`03o`000?oooooo
oooo01Kooooo00Co0000ooooooooooooELZW0onjlo83olCBi@;o^m?/0_n`[MD4oinSe`?oTIKD0on6
RLl4ohJ1a`?oS7no0onDOkX4oij3]P?oYHFc00?oWWVZojAmZOnTOJT00_nTOJT4ojMoZ0CoZ7nW1OnW
OjT3oj=jY`GoWgJT0onKLJ82oiQ^X0;oUG2V0onCK:<4oi5ZXPCoTFVP1onAJ:04oi5YX0CoTFZR0onA
Jj<00onMNZ_oWgf^oimm[P03oimm[PCoX8:c1?nQRKX5okZcdP?o00000_n0HJH01?n1KK?oTgNaoi=g
/On<JjL4oiIbY`GoW7FV0onKM:H4oiYeY`CoW7RZ1OnVP:/4ojF0[0CoXh2]1OnUPJd4oj=o[@CoXGn^
00CoWgj_oj>1[onSPJooXh6_1OnPP;05oin1/`;oWH>g00?o/JG<ok2Wcon`Yll00on`Yll3ok2/e0?o
_^Wb00?o0000ok;/monbk?L00_nbk?L00onUiO_oZm[hoj_Jn003oj_Jn003ojgBlonVc_CoY/kd00;o
Y/kd0_nXb?43oj?5l@GoY<7^5?ooool00ol0003oooooooooo`0Xooooo`00:Oooool3o`0001Oooooo
0_m^g<43ok[clPCoa=;U1On`[MD3oinSe`?oTIKD0on6RLl4ohJ1a`?oS7no1?nDOkX3oij3]P04ojF5
/onNNJ[oWWVZoiiiZPCoY7fY1OnWOjP2ojQoY`03ojV2ZonWOjWoYgnY00?oYgnY0onSNZL5oimfY0;o
Vg6R00?oVGFYoiE`Y_nEL:H00_nEL:H3oi=/X`CoTFZR1?nAJJ07oi5XX0GoTFVP0onAJZ801?nAJj?o
WGZ[oiejZonMNZ/5oimm[PGoX8:c0_nQRKX2ok^Xa`04okZcd_l0003o0000o`0000;odoST1?n0HJH3
oha[Y`GoUW:W1?nLMJH3oi]dYPGoVWFW0_nLN:X00onUOj_oYX2[ojJ0Z`03ojJ0Z`GoYH2/0_nSP:d0
0onWPjkoYH6]ojF1[@03ojF1[@GoXgn]0_nQOjh00onTPZooXh6_oj>1[`03oj>1[`CoX82`1OnOPK<0
1?nMPkOo/JG<ok6Uc?naYL`5ok2Wc`04ok2/e?nnjO;o_^WbokkYlP;oY_?b00?o0000ok;/monUiO/0
0onUiO/2oj_Jn0CoXM?i0_nVc_@2oj37m0GoXlGa0_nT`Nh2oj6mkA?ooooo0_l0000Zooooo`00:Ooo
ool00ol0003oooooooooo`0Fooooo`04ofkL`Oo4kO3oa>g`olC]l0;ob<kN0oo4d^D2okZbd@Go/:gE
0onOXmL3oi6Fe0?oQXW?1?n6PLL3ohao_`?oU7nj0_nNPkH00onFMJcoWWVZoiiiZP03oiiiZP?oY7fY
1OnWOjP01?nXOjOoZH:[ojV2ZonYPZ/4ojMoZ@CoXgZW1?nOMZ@00onKLJ;oVGFYoiUeZ@04oiE`YPCo
TfbS0onAJZ84oi5YX0OoTFRP1OnAJJ02oi5ZXP03oi]gZOnMNZ_oWGZ[00?oWGZ[1?nOOJh5oj22/`03
oj69^_nkZ<Oo000000;o000000Co^[?Bom?hi?oCn>CodoST0_mgFJ83oh1QYPCoS6^W1?nFLZL4oiae
YPCoVgBV1?nJMJL01?nLN:[oYGn[ojEoZonUOj/4ojJ0Z`GoYH2/00CoXh2]ojN3[_nWPjkoYh>^1?nU
PJd5oj=o[@03oj5o[_nTPZooY8:_00GoXh6_1OnPP;03oin1/`03ok>Ub_naYLco/JG<00;o/JG<1?n`
Yll3okgclP03okkYl_nVlo;oY_?b00;oTN[g00?o0000ojGUnonUiO/01?nIfOd2oj7Cn@;oVlSg1OnP
ao@2oj?5l@;oWkg^1OnQ_NdDooooo`03o`000?oooooooooo02Oooooo000>ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00005ooooo`03o`000?oooooooooo01Gooooo00?o
SNkNolC]l?o4kO000_o4kO04olS>gP03olCBiOnj/]7o^[;A00;o^[;A0on`[MD01?nRS[ooTX:ooi:2
_onBP[l3ohAg_0?oNVbh0omjJK<01?n6PLOoS7noohao_on<Okl2oiAo^P04oh]_[OnFMJcoUWF/oiIe
[0GoWWVZ0onTOJT4ojMoZ003ojV4[?nYPZ_oZH:[00;oZH:[1?nWOjT4oj=jY`?oWgJT00CoWGf^oiUe
ZOnIMJWoVGFY1?nEL:H4oi=/X`?oTFZR1?nAJJ08oi5XX0CoTFVP00?oTFZRoi]gZOnKMjT01OnMNZ/4
oimm[PCoX8:c0ol00003ok^Xa`;ogNoM00CodoSTogMIX_mgFJ;oMeVR1?n0HJH3oha[Y`CoUW:W1?nL
MJH4oi]dYP?oVWFW00?oXWf[ojEoZonUOj/00_nUOj/5ojJ0Z`?oYH2/00?oZHJ_ojN3[_nWPjh00_nW
Pjh4ojF1[@CoXgn]00?oYXF`ojB2[onTPZl00_nTPZl4oj>1[`GoX82`00CoWh6cok>Ub_ncYL[o/jG:
1OnaYL`00on`Yloo_O?bokgclP02okgclPCoH]WH0_nAj_L00ol0003oR=[oohSJo`02oiWIo@;oULOi
1OnKb?L2oj37m0;oWKc^1OnO_Nh4oj6mkAGooooo00?o0000ooooooooool09_ooool000kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Go
oooo00?o0000ooooooooool05?ooool4olORj`03olC]l?o8c]kob<kN00;ob<kN00?o`K?=okZbdOnj
/]401?nj/]401?n`[MGoXXjooj:>_onRS[l3oi:2_`?oQ7Nl0_mjK;P4ogYY/`?oPV^`0on;Kjd4oiIe
[0CoWWVZ1?nTOJT2ojMoZ0;oZHB/1?nYPZ/5ojMoZ@?oXgZW00CoWgJToiem[_nMOJkoWGf^1?nIMJT3
oiE`YPCoTfbS1?nAJZ83oi5YX0SoTFRP0onAJJ000onIM:SoVgNYoi]gZ@02oi]gZ@CoWGZ[1OnOOJh3
o`0000;o^:311?nkZ<L2omg_g@04og]IWomgFJ;oMeVRogMIXPCoP66V0on<JjL4oiIbY`GoW7FV0onK
M:H01?nJMJOoXWf[oj9mZonROJ/4ojEoZ`GoYX2[00CoYH2/ojV6[onYQZooZHJ_1?nWPjh5ojF1[@;o
Xgn]0_nVQK04ojB2[`CoXh6_1?nPP;000onfZ<_o/jG:ok>UbP03ok>UbP?o/JG<0on_nNP01?nmlo;o
El[doeO:m?mGb_@4ofoDn`;oR=[o00?o0000oho3nOn?`oT01?nEaoT2oi_8m`;oVkW]1OnM_>h4oinm
kP;oXKg]0onP^n`Dooooo`03o`000?oooooooooo02Kooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool2o`0001;ooooo0_nVlo84olOR
j`CobLWI00Cob<kNol6ccOo1/lgo`K?=1?nj/]400on^U[ooXXjooj:>_`02oj:>_`?oTX:o0on4Mk`3
ogY/^0?oNVVc0on2Jk04oh]_[@?oUWF/1?nNNJX4ojAmZ@04ojMoZ?nYQ:coZHB/ojV4[0CoZH:[1OnW
OjT2oj=jY`03ojB6]?nMOJkoWGf^00;oWGf^1?nIMJT4oiE`YP?oTfbS1?nAJZ83oi5YX0SoTFRP00Co
TFVPoiUdZ?nIM:SoVGBX1?nKMjT4oiejZ`?oWgf^0_l000000onPP[?o^:31okRP`@02okRP`@?o^jS7
0ooMkmd01?mkFIooMeVRogMIX_mgFJ84oh1QYP?oS6^W1?nFLZL5oiaeYP;oVgBV00?oXGf[oj9mZonR
OJ/00onROJ/3ojEoZ`CoYX2[00?o[H^aojV6[onYQZl00onYQZl3ojN3[PGoYH6]00?oXgn]ojJ5/?nV
QK000_nVQK03ojB2[`GoXh6_0_nPP;03okJXb`Co/jG:00Co/JG<ojoij?n_nNSo[oWX0om7__82oeO:
m0;oRjk]1?n:^_H2oho3n@03o`000?n?`oWoSl?i00;oULOi0_nI]>/4oi^ik@GoWKc^0_nO_Nh2oinh
jPGoX;_/5?ooool00ol0003oooooooooo`0Uooooo`003_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`0>ooooo`Co]>cg0oo6f>L00oo7
h^_obLWIolW9f@02olW9f@03ol>cboo1/lgo`K?=00?o`K?=00?o^[;AojjF_on^U[l00_n^U[l3oj:>
_`?oTX:o0on4Mk`3ogY/^0?oNVVc0on2Jk04oh]_[@?oUWF/1?nNNJX4ojAmZ@CoZHB/1?nYPZ/5ojMo
Z@03oj=jYonTQ[CoY8Jd00CoWGf^1?nIMJT4oiE`YP?oTfbS1?nAJZ84oi5YX0KoTFRP00?oUg:WoiUd
Z?nIM:P00onIM:P3oi]gZ@CoWGZ[0ol000000onOOJko]9^mokRP`@05okRP`@04ok^XaooMkmgogNoM
omg_g@?oNeVO0_mgFJ84oh1QYP?oS6^W1OnFLZL4oiaeYP03oi]dY_nQOJ_oXGf[00GoXWf[1?nUOj/2
ojJ0Z`;o[H^a1OnYQZl4ojN3[P?oYH6]00?oZHVcojJ5/?nVQK000onVQK03ojB2[`GoXh6_00?oX82`
okJXbonfZ</00_nfZ</3ok>UbP;oPNFo0_nATLl4ohfNg`GoRjk]1?n:^_H2oho3n@03o`000?nH[NGo
VKC[00CoVKC[1?nK^Nd2oiflkP;oWk?W1OnO^>X2oj2kk0;oXk[Z5Oooool00ol0003oooooooooo`0T
ooooo`003_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01?ooool0
0ol0003oooooooooo`0=ooooo`Co]>cg0oo6f>L2olO4e`?obLWI0oo3/l/3ol6cc@03okJL__n^U[oo
[YJo00?o[YJo1?nRS[l3oi:2_`?oQ7Nl0_mjK;P4ogYY/`;oPV^`1?n;Kjd3oiIe[0GoWWVZ0_nTOJT0
0onVPjgoZHB/ojV4[003ojV4[0CoZH:[0onWOjT00on/TK[oY8JdojB6]002ojB6]0CoWGf^0onIMJT4
oiE`YPCoTfbS0onAJZ84oi5YX0?oTFRP00CoU72WoiMbYonGLZOoUg:W1OnIM:P3oi]gZ@06oiejZol0
003o0000o`000?nMNZ_oWgf^1?ndVkd4okRP`@?og>cM00?ogNoMog]IWomkFIl00_mkFIl3ogMIXP?o
P66V1?n<JjL4oiIbY`?oW7FV00?oWgb/oj5mZonQOJ/00_nQOJ/4oj9mZ`CoYGn[00?oYX2[ojf;/On]
Rk400_n]Rk44ojV6[`CoYh>^00CoYH6]ojV9/onYRK?oZHVc1OnVQK04ojB2[`?oXh6_00?o^Jo@okJX
bonfZ</01?nfZ</00oncYL[oPNFooiF6`@04oi6Ac`CoSIkO0_n;[^d2oi^Kd`GoV:CM00CoV:gUo`00
0?nH[NGoV:gU0_nI]>/2oijWg@CoWjkS1OnO/nL2oinhjP?oX[KW1?nS^^XCooooo`;o00002?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0
2Oooool000kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00?ooooo
0_l0000<ooooo`Co^N3c00Co]>cgolKHioo6f>Ooa]SW1?o7a=L00oo9bMWo`k?;ol>cb`03ol>cb`04
ol6ccOnfW;ko]YbnokJL_PCo[YJo1?nRS[l3oi:2_`?oQ7Nl0omjK;P3ogYY/`?oPV^`0on;Kjd3oiIe
[0GoWWVZ00CoY7fYojJ3[OnVPjgoYX>]1?nYQ:`4ojV2Z`04ojMoZOn/TK[o[96jojbA^PCoY8Jd1?nM
OJh3oiUeZ@CoUG2V1?nCK:<3oi5ZXPCoTFVP00CoTFRPoiA`YonDL:OoU72W1?nGLZL4oiUdZ004oi]g
ZOl0003o0000o`0000?oWGZ[00?o/INlokBK_OndVkd00ondVkd3okRP`@?og>cM0_n3G9`4og]IW`?o
MeVR1?n0HJH3oha[Y`CoUW:W00CoW7FVoiml[?nOO:coWgb/1?nQOJ/4oj9mZ`CoYGn[1On]Rk44ojV6
[`CoYh>^1OnYRK<4ojJ5/0CoY8:_00?oXh6_okV_d?ni[m000_ni[m04okJXb`04o`000?nEQ/7oUHK1
oiF6`@GoTI7?0_n=W]l00onMTlWoVi_Coi^Kd`03oi^Kd`GoV:CM00?oV:gUo`000?nOXMH01OnNYmd4
oin^h`;oWk?W0_nS/^<6oj:fi`;oXk[Z0_nV_>TDooooo`03o`000?oooooooooo00Gooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Wooooo
000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo0_l0000<ooooo`Co^N3c0oo4cn<00oo6f>OoalCGolO4e`03olO4e`Go`k?;00?o^Z2nokJL__nf
W;h00_nfW;h5ojjF_`;oXXjo00CoVX>iohQg^On8MkWoR7Ni0omjK;L3ofeR]@?oNVVc0on2Jk03oh]_
[@CoUWF/0onNNJX00onOOZooYX>]ojJ3[@02ojJ3[@CoZHB/0onYPZ/00oncW<7o[96jojbA^P02ojbA
^PCoY8Jd1?nMOJh4oiUeZ@?oUG2V1?nCK:<3oi5ZXP;oTFVP0_nAKjP4oiA`Y`CoUg:W0_nIM:P3o`00
00?oVgNY0_nMNZ/3ok6G_0Go]9^m00Co^:31omc/gOoLk=gog>cM0_n3G9`00on<H9WoQenLohMOW002
ohMOW0?oPenQ1?n0HJH3oha[Y`;oUW:W0_nGMjd5oiml[0?oXGf[1OnROJ/2ojEoZ`03ojj?]On]Rk7o
[H^a00?o[H^a1OnYQZl2ojN3[P03oj^?^?nYRK?oZHVc00?oZHVc1OnVQK02ojB2[`03okblfOni[m3o
^Jo@00Co^Jo@00Co]ZS;oiQo]_nHOkKoV7nf1?nEQ/42oi6Ac`;oXHk01?nMTlT5oi^Kd`;oV:CM0_nQ
Vlh2oinQeP03o`000?nOXMKoWZOM00CoWZOM0_nO[^<00onT[]ooXk;Soj>bh`03oj>bh`CoX[KW00?o
YkSVojJljOnV_>T00onV_>TDooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000002Oooool000kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool00ol0003oooooooooo`09oooo
o`?o^]K^00?o^N3colC?hoo4cn<00oo4cn<2olG1eP?oalCG1Oo3/l/3okZP_P?o]Ybn1?n^U[l00onV
RkWoVX>ioiZ3^@02oiZ3^@?oR7Ni0_mjK;L3ofeR]@?oKf6c0on2Jk04oh]_[@?oUWF/00CoWWVZoimn
[onOOZooWgj_1?nVPjd4ojV4[0;oZH:[0oncW<44ojbA^P?oY8Jd1?nMOJh4oiUeZ@?oUG2V0_nCK:<2
ohi`[0?oT6nY1?nAKjP4oiA`Y`?oUg:W0ol00002oiUdZ0CoVgNY00?oWGZ[ok6G_?naUk`00_naUk`5
okBK_@;oeo3S00?og>cMoi9SV?n<H9T00_n<H9T4ohMOW0?oPenQ1?n5IZL3oha^[0CoUgN]1OnOO:`3
oj5mZ`GoXWf[00CoYGn[ojj?]On^SkGo[Xne1?n]Rk45ojV6[`04ojN3[_n[SkSoZhnhoj^?^0CoZHVc
1OnVQK001?nTPZoo_;cIokblfOnl_=T4okV_d003oiak[_nHOkKoV7nf00;oV7nf0onEQ/400onURkWo
XHk0oj6>`002oj6>`0CoWI?91?nKVm<00onTU/OoXI_>oj6KcP02oj6KcP?oWj7F00Co0000oinQe_nN
YmgoWZOM0_nVZ]X4ojB^g`GoXk;S00?oX[KWojNhi_nW^>H00_nW^>H3ojJlj@03ojZojOoooooooooo
01;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8b
oiRHV?ooooooV9RHoc8b<P09ooooo`009oooool00ol0003oooooooooo`07ooooo`Co^]K^0oo1bN43
olC?h`CoaL7F00?oalCGol>cboo3/l/00oo3/l/4okZP_PCo]Ybn00Co[YJoojJ;^OnVRkWoYX^i1?nJ
PkT3ohQg^@?oNVbg0_m]H[D3ofmQ/`?oNFNb1?n;Kjd2oiIe[003oiIh/?nOOZooWgj_00;oWgj_1?nV
Pjd4ojV4[003ojV2ZoncW<7o/ic100;o/ic11?n/TKX4ojB6]0?oWGf^1?nIMJT2oiE`YP03ohib[on>
L:coSW2/00;oSW2/0on@KjT5oi5_Z0?oU72W0ol000000onGLZOoVGBXoiUdZ003oiUdZ0;oVgNY00?o
[I>lok6G_?naUk`00onaUk`4okBK_@;oeo3S0onBHiP3ohaPV@CoQenL0on3Gj44ohEVY`?oS6j/1OnG
Mjd4oiml[0?oXGf[1?nROJ/00on]T[_o[Xneojj?]@02ojj?]@Go[H^a0onYQZl00onaV/3oZhnhoj^?
^002oj^?^0GoZHVc0onVQK000onmd>So_;cIokblf@03okblf@04okV_d?nLNjkoW7^^oiak[PCoV7nf
00?oUHK1ojF;^OnURkT00_nURkT4oj6>`0CoWI?900?oVi_CojBFaonTU/L00_nTU/L4oj6KcP;oWj7F
00?o0000ojRWeOnVZ]X01?nVZ]X4ojB^g`;oXk;S0_nX]N85ojNhiP03ojJljOnZ_nWoZ[oY00;oZ[oY
5?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co
0000o`000?l0003oc<c<00Wooooo000Wooooo`;o00001_ooool4ok[=j@03ok[Fk_o1bN7o`LWQ00?o
`LWQ00?oa<oSolG1e_o5`MH00_o5`MH00oo2]<co`k?;ol>cb`03ol>cb`Go^Z2n0onfW;h00on^T[Wo
YX^iojJ;^@02ojJ;^@CoVX>i0on8MkT3ogY/]`?oKF:e0_m_HK<3ogUW/PCoQVna0onFN;04oimn[`Go
YX>]0_nYQ:`00onhY<Go/ic1ok>L`@03ok>L`@Co[96j1?nTQ[@2oiem[P03oi:0_?n?N;CoSgRd00;o
SgRd0on>LZl5ohi`[0?oT6nY1?nAKjP01?nDL:Oo0000o`000?nDL:L3oiMbY`GoVGBX00CoVgNYojfC
_?n]Tkco[I>l1OnaUk`2okBK_@;oeo3S1?nBHiP4ohaPV@CoQenL0on3Gj44ohEVY`?oS6j/1?nGMjd4
oiml[0CoXGf[0_nROJ/3ojfB^`?o[Xne1On]Rk400onYQZoo/I[0ok6J`002ok6J`0?oZhnh1OnYRK<0
0onVQK3o_M3Xokg@j002okg@j0?o_;cI00?oWgVXoiak[_nLNjh00onLNjh2oiQo]P03ojR9]?nURkWo
YH^i00?oYH^i1?nQS/02oifCb@;oYiC11OnTU/L4oj6KcP05oinQe_nXYmGoZ:OEo`000?nXYmD01?nV
Z]X2ojB^g`?oZ[?O1?nX]N82ojNhiP?oZkkX1?nZ_nTEooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41002Oooool002Oooooo
00?o0000ooooooooool00_ooool3okW7i@?o^/gY0_noa]l4ol79h@;o`[oG0oo5`MH3ol:dc0?o`k?;
0_nkXl45okZP_P04okJL__n^T[Wo[Y:iojjB^@CoYX^i1?nJPkT3ohQg^@;oNVbg0om]H[D3ofmQ/`;o
NFNb1?n6Kk44oiIh/0CoWgj_1?nVPjd01?nYQ:co^:C5okRTaOnhY<D5ok>L`@?o[96j0_nTQ[@2oiR=
aP?oTX2l1?n?N;@4ohib[`CoSW2/0on@KjT2oi5_Z0?o00000onDL:L4oiMbY`?oVGBX00?oZI2lojfC
_?n]Tk`00_n]Tk`5ok6G_004okBK_OoGl>?oeo3SoiIUU`CoTV>H1?n<H9T4ohMOW0?oPenQ1?n5IZL3
oha^[0CoUgN]1?nOO:`4oj5mZ`03oj9mZon]T[_o[I:k00;o[I:k1?n^SkD3ojf;/@03okV]cOnaV/3o
/I[000?o/I[01?n[SkP3ojV9/`;o/n_g1Onmd>P00onl_=WoWgVXoimiZ005oiak[P04oiQo]_nXRKCo
Z8VdojR9]0CoYH^i0onQS/000on/U;koYiC1ojND`@03ojND`@GoY9K70_nQVlh00on/YM7oZ:OEojRW
e@02ojRWe@05o`000?nVZ][oYZ[JojJZf_n//]d01_nZ/ml2ojRehP;o[;kV1On[_^P2ojZoj@;o[<?Z
4_ooool3o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj
^_l000002Oooool002Oooooo00Co0000oooooooooooooooo1OnianD00onjcNWo_lKOoko6g`02oko6
g`03ol79hOo2_mOo`[oG00?o`[oG00?oaL7Fol:dc?o2]<`00oo2]<`01?o3/l_o^j?1ok^S`OnkXl44
okZP_P03ok>G^_n^T[Wo[Y:i00;o[Y:i1?nVRkT4oiZ3^@?oR7Ni0omjK;L2ofeR]@?oKf6c0omiIk84
ohI_/@?oUWR`1?nOOZl3ojJ3[@03okNVb?nhY<Go^:C500?o^:C51?ncW<42ojbA^P03oj>Pd_nHSLKo
V8g600?oV8g60onBP;`4ohmh]0?oSW:_1?n>L:`2oi1_Z@?o00000_nAKjP4oiA`Y`CoUg:W0_nIM:P3
ojV@_0?o[I>l1?naUk`3om3fi`;oUVFG1?nBHiP4ohaPV@CoQenL0on3Gj44ohEVY`?oS6j/1?nGMjd5
oiml[0;oXGf[00?o[IO1ojfB^on]T[/00on]T[/4ojj?]@03ojf;/Oni[Lgo^Jg=00;o^Jg=1?naV/04
oj^?^003ojV9/oncjoOo/n_g00?o/n_g0_nmd>P2oj9iY@?oWgVX1?nLNjh00on]Rk;oZ8VdojR9]002
ojR9]0GoYH^i00CoXHk0ojbD__n/U;ko[9Bn1?nWU<44ojBFa`03ok2Vc_n/YM7o[:GA00;o[:GA0onX
YmD00ol0003oZ:OEojJZfP03ojbbg@CoZ[?O00?o[[oVojbni_n/_^H00on/_^H2oj^nj0;o[LC[1On/
`nXDooooo`09o`000?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@09ooooo`009_ooool3o`0000;o^L?R1?nianD2okg4g`?o_lKO0ono_mT3ol:o
e`03okned?o2]<co`[C<00?o`[C<00?o^jO5ok^S`OnkXl400_nkXl43okZP_P?o/iNj0on^T[T4ojJ;
^@;oVX>i0_nGPKT3oh=f_0?oLFfo0om]H[D2ofmQ/`?oNFNb1?n6Kk43oiIh/0CoWgj_0_nVPjd3okNV
b0Go^:C50_ncW<400on`]=coXj3Boj>PdP02oj>PdPCoV8g60onBP;`4ohmh]0?oSW:_0on>L:`3o`00
0003oi1_ZOnAKjSoTFnX00;oTFnX1?nDL:L4oiMbY`03oiUdZ?nYT;coZI2l00;oZI2l1?n]Tk`00ona
Ukcod?KWom3fi`02om3fi`CoUVFG0onBHiP4ohaPV@CoQenL0on3Gj44ohEVY`?oS6j/1OnGMjd4oiml
[004oj5mZon]Ul7o[IO1ojfG`@Go[I:k0_n^SkD00onmbN?o^Jg=okV]c@03okV]c@Go/I[00_n[SkP3
og?ReP;o/n_g00?oYW^Uoj9iYOnRNJD00onRNJD4oimiZ0;oW7^^0_n]Rk84ojR9]0CoYH^i00?o/YRm
ojbD__n/U;h00_n/U;h5ojND`@04ojBFaon`Y/ko/:K>ok2VcPGo[:GA0_nXYmD00on`]=co0000ojbb
g@04ojbbg@03ojZcgon^_nKo[[oV00;o[[oV0on/_^H00on]ango[LC[ojg4j`03ojg4j`;o[<?Z0_n[
a>`Eooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?ni`n;o^L?R00?o^L?R00?o^LOU
okg4gonma=l00onma=l00onoa]oo_koIoknof@03oknof@04ol:oeono]M3o_kG@okned0?o`[C<0onk
YlD4ok^S`@03okZP__ncUk[o/iNj00;o/iNj1?n^T[T2ojJ;^@03oj:7^?nGPKWoUh6i00?oUh6i0on3
M[`2og5]_`?oG6?10_m_HK<3ogUW/PCoQVna0onFN;04oimn[`03ojJ3[OngY/So]jK800;o]jK81?nh
Y<D00onl`]oo/;CLok2dg002ok2dg0CoXj3B0onHSLH3oi:0_0CoSgRd0on>LZl3o`000004ohi`[?n@
KjWoT6nYoi1_Z@GoTFnX0onDL:L2oiMbY`;oXhfm1OnYT;`4ojfC_0?o`O[[00?od?KWohmPUonFIIL0
0onFIIL3oi9SV0CoS62I1?n7Gi`3oh=OX@CoQFJW0on<KZ`5oiMg[@;oWgb/0_nZVlL4ojfG`@Go[I:k
00Co[Xneokg9honmbN?o_LWS1?ni[Ld5ok6J`003oj^?^?nQNJKoXGVV00;oXGVV00CoWW^/ojIkYOnV
NjGoYW^U1?nRNJD4oimiZ003oiak[_n]Rk;o[H^b00;o[H^b1?nXRK@2ojF;^@?o/YRm0on/U;h4ojND
`@03okFZc_n`Y/ko/:K>00?o/:K>0on/YM400ond^Mgo/;CLok2dg002ok2dg003o`000?n//]go[;;M
00?o/<;W1?n^_nH00on/_^Ko[LO]ojg7k@02ojg7k@?o[LC[0_n[anh4oj_4k1Cooooo00?o0000oooo
ooooool07_ooool001_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooo^L?R
00;o^L?R0onla>03okg4g`03okk1g?no_mWo_koI00?o_koI00?o_KSEokned?no]M000ono]M000oo2
]<co^jO5ok^Wa@02ok^Wa@Co^j?11OncUkX4ojjB^@04ojJ;^OnRQkSoXXNhoj:7^0CoUh6i0on3M[`3
og5]_`;oG6?10_mII/D00om_HK?oNFNbogUW/P04ohI_/@CoUWR`0_nOOZl00on^X/co]jK8okNVb003
okNVb0?o^:C50onl`]l3ok2dg0CoXj3B1?nHSLH3oi:0_0?oSgRd0ol00005ohi`[0?oT6nY1?nAKjP2
oiA`Y`03oib9__nSSKgoXhfm00?oXhfm1OnYT;`2ojfC_0?o`O[[0on?H9L4oiIUU`?oTV>H1?n<H9T4
ohMOW0CoPenQ1?n5IZL3oha^[0?oUgN]00?oXYS;ojZKaonZVlL00onZVlL3ojfG`@Co[I:k00?o[^_i
okg9honmbN<00_nmbN<5okV]c@;o/I[00_nTNJ@5oj5iYPCoYW^U1?nRNJD4oimiZ0Go[H^b1?nXRK@0
0onURkWo/YRmok:H_@02ok:H_@Co[9Bn00?oYiC1okFZc_neZ/h00_neZ/h4ok2VcP03ojbUdOnd^Mgo
];WM00;o];WM0on`]=`00onban[o0000ok32i`04ok32i`;o[[oV0_n^bnl5ojg7k@03ojg4jon[anko
ZlO^00;oZlO^0_n[a>`2ojS3kACooooo00?o0000ooooooooool07Oooool001_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`06ooooo`04o`000?oooooooooookW3hPGo_<CP00Co_LCOokk1g?nn`Mco_/7L
0ono_mT3okfhe@?o_kG@00?o^J_;ok^WaOnkYlD00onkYlD3ok^S`@;o]9^n1OncUkX2ojjB^@03ojV=
^?nRQkSoXXNh00;oXXNh1?nGPKT3oh=f_0?oLFfo0omLHl42oeUVa@?oNFNb1?n6Kk43oiIh/004oimn
[on^X/co[Z;<ojjRc0Go]jK800?o^:C5okc2gonl`]l00onl`]l3ok2dg0CoXj3B0onHSLH3oi:0_0?o
000000CoSgRdohib[on>LZooSW:_1?n>L:`3oi1_Z@;oTFnX0_nEQL04oib9_PCoXhfm1OnYT;`01?n]
Tkco`O[[ol7jjon8FiL4ohmPU`CoUVFG1?nBHiP3ohaPV@GoQenL0on3Gj44ohEVY`?oS6j/00?oUgN]
oj:HbonRV</00_nRV</4ojZKa`Co[IO100?o[I:kojk[nOn^joT00_n^joT4okg9h`;o^Jg=0onXNj84
ojAiY0?oXGVV00?o[86VojIkYOnVNjD00_nVNjD5oj9iY@;oWgVX00?o/Xnbojf;/_n]Rk800on]Rk84
ojR9]0Go/YRm1?n/U;h5okFZcP?o/:K>00?o^L?RokBigOnd^Md01?nd^Md01?n`]=co//OZok;7j_l0
0004ok32i`03ojkBlon^bnoo[/__00?o[/__0_n]and2oj_:l0CoZlO^00?oZ<O_ojS3kOnX`nd00onX
`ndCooooo`;o00007_ooool001_ooooo00Go410@oooooooooooooooooa0@4006ooooo`;o00000_oo
ool5okc4h0Go_/7L00?o_koIokfheOnm^=D00onm^=D01?no]M3o^J_;okV[boniZl/5ok^Wa@04ok^S
`OndVkko]9^nokBK_PGo/iNj00Co[Y:iojV=^?nYSKSoZHfh0onRQkP5oiN1^@?oPgJl0_maKKl3oeaS
`@;oFFK50omYLl/4ohI_/@;oUWR`00?oWYS>ojjRc?n^X/`00on^X/`3okNVb0;o_lOQ1?nl`]l2ojoH
m@?oTLKi0omnZo43og:Ch`?o00000omkPLd01?n?N;CoSW:_ohib[on>LZl4ohi`[0;oT6nY00?oSX;2
oiF5`?nEQL000onEQL03oib9_PCoXhfm1?nYT;`2ojkhj`?oR5^G1?n?H9L4oiIUU`CoTV>H1?n<H9T4
ohMOW0?oPenQ0_n5IZL2oiR6_P?oUho91OnRV</4ojZKa`?o[IO10omSf</4ojk[n@;o_LWS00?oTfRL
ojQkX_nXNj800onXNj84ojAiY0;oXGVV0on/PJH3ojIkY@GoXWVU00CoWgVXok:?/_nbSk;o/Xnb1On]
Rk82ojR9]0;o^J711OnbV;d2ojbD_P;o^[;A1OneZ/h01?n`Y/ko^L?RokW3h_ni`n84okBig@03ok?B
l?nban[o//OZ00;o//OZ00?o0000ok32ion^d_<00on^d_<2ojk;k`;oZ<kd1On[b_000on[ankoZ<O_
ojS7k`02ojS7k`;oZ<?]0_nU`NdBooooo`03o`000?oooooo000001kooooo000Kooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`Go_<CP0onn`M`3ok^mf`?o_KSE
00?o]k7CokV[boniZl/00oniZl/3ok^Wa@03okFP`ondVkko]9^n00;o]9^n1?ncUkX00on^T[[oZHfh
ojV=^002ojV=^0CoXXNh1?nGPKT3oh=f_0?oLFfo0_mLHl43oeUVa@;oJG?;1?n2Q/l4oijHcPGo[Z;<
00?o]jK8oko7hOnoan400_noan400onl`]oo[mSeojoHm@03ojoHm@?oTLKi0omnZo42o`000004og:C
homeQ]KoMHKFogF6eP?oNh7=0on1OlL4ohN0a0CoSX;21?nEQL03oib9_PGoXhfm00?oZI2lojkhjon^
n>/00_n=HIT4ohQKU`?oSf2G1?nFIIL4oi9SV0CoS62I1?n7Gi`2oh=OX@03oian/_nHQ[koV8Jn00?o
V8Jn0onGSlT4oj:Hb`GoZY_700Co[IO1oi=SUonCHiOoTf>G1OnDIIT2oi=XW003ojYmXonXNj;oZ7^R
00?oZ7^R1?nTNJ@00onQNJKo[86Vojb1YP02ojb1YP?oYW^U1OnRNJD4ok:?/PGo[H^b00CoZ8VdokVQ
`OniXL7o^J711OnbV;d01?n/U;ko^[;AokZbdOnj/]44okFZcP03okkFk?ni`n;o^L?R00?o^L?R00?o
];WMok?Bl?ncd_000_ncd_02ok;7jP;oZM[h00?o0000ojkBlon^d_<00onUdoP4ojS>m0;oZl[`1?nV
b_82ojS7k`;oY<C_1?nU`NdDooooo`03o`000?oooooooooo01_ooooo000Kooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`03ooooo`Go_<CP00?o_/7Lok^mfonk_M/00onk
_M/01?nm^=Go]k7CokNadong/M<5okV[b`04ok^WaOneX<?o]J33okFP``Co]9^n00?o/iNjojjB^_n^
T[X00_n^T[X3ojV=^0CoXXNh0_nGPKT2oiZ5_0?oRGfo0omhM/@3of5_bP;oFFK50omYLl/4oh:6c`?o
WYS>1?n^X/`2okO3h`?o_lOQ1?nnfnh2ojoHm@;o?knb0_n/VL<3o`000003ogj[lOmbTn?oLY?S00?o
MHKF1?mkPLd3oh5oa`CoQh340on>P/84oiF5`0CoW8Vn0onSSKd2oiOajP04oiIYW?n=HIWoSF6IoheQ
V@CoR5^G0on?H9L4oiIUU`CoTV>H1?n<H9T3ohMOW003oimjZ_nLO[;oW7jb00;oW7jb1?nHQ[h3oiN?
b@GoXYS;0_nZVlL3oi5QU@?oTf>G1OnDIIT01?nCJ9coZWfSojYmXonZOJ<4ojQkXPCoY7VT1On/PJH4
ojIkY@?oXWVU00?o^IVfok:?/_nbSk800_nbSk84ojf;/P03olFfboniXL7o^J7100;o^J711?nbV;d0
0oo2a=_o^[;AokZbd@03okZbd@03okFZc_nne^co_]K/00;o_]K/0_ni`n84ojkOn0;o/m;`0onNhod2
ojWJn003o`000?nMeocoYM?h00CoYM?h0_nXc_@2oj?=mPCoY/[b00?oXlGaojC4konTa>l00onTa>l2
ojG1k@03oj>okOoooooooooo01?ooooo00?o0000ooooooooool06_ooool001_ooooo00Go410@oooo
oooooooooooooa0@4005ooooo`03o`000?oooooooooo00Gooooo0onla>02okW3hPCo^kgK00?o]KSL
okNadong/M<00_ng/M<4okV[b`03ok:UboneX<?o]J3300;o]J330ondVkh00on^U[ko[Y:jojjB^P03
ojjB^PCoZHfh0_nRQkP00onSR[[oVXFloiZ5_003oiZ5_0?oRGfo0omhM/@2of5_bP?oG7CB0_mYLl/4
oh:6c`CoWYS>00?o[Z;<okO3hong`n<00ong`n<00onoan7o_]_^okkKkP02okkKkP;oRNcA0_nbZ<h3
o`000004oi=i]?nBM:koTWB^oi9d[P?oTW6[0_meQ]H4og^1c@?oPGo71?n7P<@3ohj2`PGoUHG00onL
RKh01?nSSKgoUo7ZoiOaj_nGlNX2oiIYW0?oSF6I1?n8FiL3ohmPU`CoUVFG1?nBHiP4ohaPV@04ohMO
W?nONZ[oWgZZoimjZPCoW7jb1?nHQ[h4oiN?b@;oXYS;0on>GI@4oi5QU@CoTf>G1?nDIIT4ojYmX`Go
Z7^R0onTNJ@5ojb1YPCoYW^U0_nRNJD3okVI]PCo/Xnb0_n]Rk83olFfb`Co^J7100?o/YRmol;4foo2
a=/00_o2a=/3okZbd@?o]>kf0_nne^`3oiOYnP;o[]oh0on3h_T2oikSo@;oSmSo0onMeo`01?l0003o
WMOlojGCn?nUdoP3oik?n@CoXlgf00?oY/[boj?5lOnSaO400_nSaO42ojC4k`;oX/3_1?nS_ndDoooo
o`03o`000?oooooooooo01[ooooo000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`00
00Oooooo00?o_<CPokW3h_ni`n800_ni`n800onk_M_o]KSLokFhg002okFhg0Co]k7C00?o^J_;ok:U
bonbYL/00_nbYL/4okFP``04okBK__n^U[ko[YJnojjF_PCo[Y:j1?nYSKP01?nRQkSoXhZjoj>:^_nS
R[X4oiZ5_0?oRGfo0omhM/@3of5_bP;oG7CB0om/Q]`4oh:6c`;oWYS>0_nW]n@4okO3h`?o_MC[00Co
_]_^ohW/dOn9k=7oRNcA0ol000001?nGPKWoTgVdoi=i]?nCNK@4oi9d[P?oTW6[00?oT6jXocX00?mk
PLd00_mkPLd3oh5oa`CoQh341?n>P/84oiF5`0;oW8Vn0_m`gn@2oiibX@?oUVVL0on=HIT4ohQKU`Co
Sf2G0onFIIL4oi9SV0?oS62I00?oXWVUoimjZ_nONZX00onONZX3oian/PGoV8Jn0_nGSlT3ohUITP?o
SUfD1?nAHID4oi=SU`?oU6FI00?o[H6UojYmXonZOJ<00_nZOJ<5ojQkXP;oY7VT0_ndRj/4ojb1YPCo
YW^U00?oXWVUokVI]_niVKH00_niVKH4ok:?/P03ojf;/_o5]/_oaKK;00;oaKK;0oniXL42ol?RkPCo
`/CK00Co^[;AokC^m_ndk_Ko]>kf0omFdMT2oiOYnP?oD/kS0_n3h_T4ogkDo`?oSmSo0_nMeo`00onG
c__o0000oiO>n`02oik?n@?oW<Gd1?nPa_<2oj?5l@;oXL7_1OnR`>l4oj>okACooooo00?o0000oooo
ooooool06Oooool001_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo
00Oooooo0oni`n82ok;2iPGo]KSL0_ng/M<00on_[=Go/ZG;ok:Ub`03ok:Ub`?o]J3300?o[I_5ojjF
__n^U[h00_n^U[h5ojjB^P;oZHfh00?oZ8nkoj>:^_nSR[X00_nSR[X4oiZ5_0?oRGfo0omhM/@3of5_
bP?oG7CB0om/Q]`4ohNOi0CoYkOT00?o]l?SokgDjonme>/00_nme>/2ojWihP?o000000?oVhW0oiN1
^OnGPKT00_nGPKT3oi=i]0?oTWB^0onBLJ/3oi1^Z003ohi/Yolj003oNh7=00?oPGo71?n7P<@3ohj2
`P;oUHG00om2a=L00onUNjGoWW:QoiibX@02oiibX@?oUVVL1?n=HIT3ohQKU`CoSf2G1?nFIIL3oi9S
V0;oS62I0_nRNJD5oimjZPCoW7jb0onHQ[h2ohIFT@CoREVB0on>GI@4oi5QU@CoTf>G0_nDIIT3ojf1
Y@?oZWfS1OnXNj801?nTNJCo]8^[okB;ZondRj/5ojb1YP?oYW^U1OniVKH4ok:?/PKoaKK;00?o^J71
ol?Rk_o3h^h00_o3h^h2ol;4f`03ofWKb?l^ZNgo39c800?o39c80_lT/<T3ofk3oPCoKL_n0_mne?l2
ohc4nPGoSl_l0_nGc_/00ol0003oV/?doic5m004oic5m0;oX<Kc0_nO_o04oj71k`CoX/3_0_nS_nd2
oj6nkACooooo00?o0000ooooooooool06Oooool002Gooooo00?o0000ooooooooool02?ooool00oni
`n;o//;Vok;2iP02ok;2iP?o]KSL00?oZ[CPojn/eOn_[=D00_n_[=D5ok:Ub`04okFP`on]VlGo[I_5
ojfKa@?o[YJn1On^T[X01?nYSKSoZ8nkojR?^onXSk/3oj>:^PGoVXFl0on9OKl3ogQfa0;oHFo:0omL
M=84ofb6g0CoQioT0_nW]n@4ok;6j@05okgDjol0003o0000o`000?nQU<L00onKRL04oiN1^@?oTgVd
0onBM:h4oi9aZ`?oT6jX0on>K:L4oiE`Y`;o5J;C0_nNMjL01?nWOJKoYWnYojIoZOnVOjT3ojEkY@Co
WW:Q0onFJI`4oheQV@?oR5^G1?n?H9L4oiIUU`?oTV>H00?oS62Ioj9iYOnRNJD00_nRNJD4oimjZPCo
W7jb00?oV8JnohEDSon6EY400_n6EY44ohUITP?oSUfD1OnAHID3oi=SU`03oiAUVOn]PJGo[H6U00;o
[H6U0onZOJ<5ojQkXPCo]8^[1On/PJH2ojIkY@;o`j[11OniVKH2ok:?/P;odn?R1?o5]//2ohG[f@;o
`n;^00?oIZ7boifJdOnMV]401On?YnH4ogZen0;oK/?n0_nC[NP3ohbim0GoS<Cj0_n?bo`2oiNnlP;o
V/?d00?o0000oi[3m?nJ`o@00_nLaO@2oifmk`GoWko`1?nQ`Nl2oj;0k`;oXKk^1?nQ_^dBooooo`03
o`000?oooooo000001[ooooo000Uooooo`03o`000?oooooooooo00[ooooo1?nb`^H01?ne^=coZ[CP
ojZdh?nZ]>03ojn/e@Co/ZG;00?oZ:3>ojfKaOn]VlD00_n]VlD4ojjF_P?o[Y:j00?oZiBnojR?^onX
Sk/00_nXSk/4oj>:^PCoVXFl0_n9OKl01?nBQlGoQH?:ohF3b_n5PlX3og9od@?oG7CB1?m/Q]`2ohNO
i0;oUk3Y0onba^T3o`000004ok;gkonQU<OoXIC7oj6Da`CoVhW00onGPKT3oi=i]0?oTWB^1?nBLJ/3
oi1^Z0CoSVbW0onEL:L3oiigY`03oj9n[?nVOjWoYWnY00;oYWnY1?nUNjD3oiibX@?oUVVL1?n=HIT3
ohQKU`CoSf2G1?nFIIL3oi9SV0GoXWVU1?nONZX4oian/P;oQEB?0on6EY44ohUITP?oSUfD1OnAHID3
oi=SU`Go[H6U1?nZOJ<3ojQkXP03olFV^_ndRj_o]8^[00;o]8^[1On/PJH01?nVNjGo`j[1ol>Z`Oo3
Z/45okVI]P03ok:?/_oChn;odn?R00;odn?R00KoaKK;ohG[fOn5jmWoQN_IohV@donXUL85oifJd@?o
SjOV00?oY9_<oi^QfOnKXMT00_nKXMT5oi>]j0?oS;Wd0_n<a?X3oiVhk@CoUkkb0_nJ`o@00ol0003o
WK[]oifmk`04oifmk`;oWko`1_nP_^h5oj6nkP;oXKk]0_nP_NhDooooo`03o`000?oooooooooo01Oo
oooo000Uooooo`;o00003?ooool2ok;2iP;oXko]0onZ]>04ojn/e@03ok:UbonXX<koZ:3>00;oZ:3>
0on]VlD4ojjF_P03ojjB^_n[U;koZiBn00;oZiBn0onXSk/4oj>:^P;oVXFl0_nPSl84oi:7a@?oQH?:
0_mbOm43og26f@CoOiWR1OnG/>T2o`0000?o/_O_00CoYj3?oj6DaonQU<OoXIC71?nKRL04oiN1^@;o
TgVd0onBM:h4oi9aZ`?oT6jX1?n>K:L3oiE`Y`04oiigYonROZcoXWj/oj9n[0CoYWnY1?nUNjD3oiib
X@?oUVVL1?n=HIT3ohQKU`CoSf2G1?nFIIL2oi9SV003ojAiXonRNJGoXWVU00?oXWVU1OnONZX2oian
/P?oQEB?0on6EY44ohUITP?oSUfD1OnAHID3oi=SU`Go[H6U1?nZOJ<2ojQkXP?oaJJj0ondRj/4ojb1
YP03om7Dfoo3Z/7o`j[100;o`j[11?niVKH2o`0000;odn?R1?nIQK`00onbUKWoZ9G2ojRE`P02ojRE
`PCoWI[A00?oSjOVojBKc?nTVl`00_nTVl`4oi^Qf@;oTjgX0_nSZmd4oibaiPGoVKS]0_nG__82oijf
j@;oWK[]00Co0000oifjkOnM_NooWKg_0onO_>d8oj2nkP;oXKk^0_nP_^h5oj2mkQ?ooooo00?o0000
ooooooooool05oooool002Cooooo00?o0000ooooooooool03Oooool4oj>ok@?oZ[CP0_n_[=D2oj:W
fPCoZ:3>1?n]VlD2ojjF_P03ojVHaOn[U;koZiBn00?oZiBn1?nXSk/2oj>:^P03ojND`_nPSl;oX8o2
00?oX8o20onBQlD3ohF3bP?oLWoA0om`Q]T4ognIhP04oiN`jOl0003o0000o`0000?oV>Ol00?o/_O_
ojNPconWX<l01?nQU<L3oi^9`0CoUh6i0onCNK@3oi9d[P?oTW6[0on@KZP4ohi/Y`;oUG2W00?oVGR]
oj9n[?nROZ`00_nROZ`4ojIoZ@CoYG^U1?nNLZ43oiIYW0?oSF6I0on8FiL4ohmPU`CoUVFG00CoTV>H
ojAiXonTNJ?oY7VS1?nRNJD5oimjZP03oian/_n5E8ooQEB?00;oQEB?0on6EY44ohUITPCoSUfD1?nA
HID2oi=SU`;o/8FX1?n]PJD4ojYmX`03ojQkX_o5Y[[oaJJj00;oaJJj1?ndRj/2ojb1YP?odMCK1?o3
Z/401?niVKKo[hR/ojn8[?n_R:`4ojB3/@;oVHFl0_nbUKT5ojRE`P;oWI[A00?o[IW3ojBKc?nTVl`0
0onTVl`3oi^Qf@03oj^Xe?nSZmgoXj_M00?oXj_M1?nL/NH2oiVhk@;oXK;T1OnN]^T2oifjk@03o`00
0?nQ^ncoWkc]00CoWkc]3?nP_^h2oj2mkP;oWkk^5?ooool00ol0003oooooooooo`0Fooooo`009?oo
ool00ol0003oooooooooo`0>ooooo`;oXko]00?oSKScoiZ`i_nJ/>H00_nJ/>H4oj:WfP?oZ:3>0on]
VlD00onUWLkoZIS5ojVHa@02ojVHa@CoZiBn1?nXSk/01?nSR[[oYiC2ojND`_nWU<84oj2?`P?oTXO5
1?n5PlX3og9od@?oL8KI00GoOiWRo`000?l0003o0000oiN`j@03oiSWo0?o[JkH0onWX<l2oj6Da`04
ohmf/on<L[7oS7:aohab/@CoR6j_0on4Jjh3oi9d[P?oTW6[0on@KZP2ohi/Y`;oSg6]0onIN:d4oj9n
[0CoYWnY1?nUNjD4oiibX@?oUVVL0on=HIT4ohQKU`?oSf2G0onFIIL00onTNJCoY7VSojAiX`02ojAi
X`CoXWVU1?nONZX00onemK7oQE>>ohEDS`03ohEDS`?oQUJA1?n9FI84ohiMU0CoTF6E00CoTf>Gok25
Z?n`QJSo/8FX1On]PJD3ojYmX`GoaJJj1?ndRj/00on/PJKodMCKom7Df`02om7Df`?o`j[100?oX8Nj
ojn8[?n_R:`00_n_R:`4ojB3/@03oiV5_?nbUKWo/YFi00;o/YFi0onXUL800onfW[oo[IW3ojfI``02
ojfI``GoY9_<00CoVj7Ioj^Xe?n[Z=CoZjSD1?nSZmd2oibaiP?oY[3O1?nQ/^@2oijfj@;oXk[Y0_nQ
^n`00ol0003oXK_/oj6kk002oinlk@;oXKk^2_nP_^h3oinok`CoWkk^5?ooool00ol0003ooooooooo
o`0Eooooo`009?ooool3o`0000oooooo0on=^?<4oiZ`iPCoXZOJ0onXX<h01?n]VlGoYIg>ojFMc_nU
WLh3ojVHa@GoZiBn0_nXSk/00onZVLGoYiC2ojND`P02ojND`PCoX8o21?nBQlD2ohF3bP03ohnTi?mg
Y_3oMjK`00;oMjK`0ol000001?ma]O[oPLkooh7>oon1c_l3ok:lh@;o[JkH00CoUWnhoi9j]_nBN[Ko
TWZf0on?M[<3ohab/@CoR6j_0on4Jjh3ohI[[@?oRVj]0on<Kjd4ohma[@CoVGR]1?nROZ`4ojIoZ@?o
YG^U1?nNLZ43oiIYW0?oSF6I1?n8FiL3ohmPU`;oUVFG0_nTNJ@4ojAiX`GoXWVU0_nONZX00onemK7o
QE>>ohECSP04ohEDS`?oQUJA1On9FI83ohiMU0CoTF6E1?n`QJP5ojf1Y@;oZWfS0_oRm=P5olFV^P;o
]8^[0_mkhKX5om7Df`03ol>Z`OnZQJko[hR/00Co[hR/1?nTPk45ok:E^@;oZ9G20onfW[l4ojfI``;o
Y9_<0_nbZ<h5oj^Xe0;oXj_M0_n/[mX5ojJ`g`;oXK;T0_nV^NL4oj>jj@;oXK_/00?o0000oj:nkOnQ
_^h01?nQ_^h6oj2nkP;oWl3`1OnO_nl2oinnkP;oW[k_4_ooool2o`0000Wooooo1?l000000ol@413o
ooooooooo`07ooooo`009?ooool00ol0003oooooooooo`0@ooooo`?oSKSc1?nJ/>H2oj:WfP04ohnV
iOnKX]WoVj;Ioi^Rf@CoYIg>0onYV<D4oj^D_P03ojZOc?nZVLGoZYW500;oZYW50onWU<85oj2?`P;o
TXO500?oW:?KohnTi?n?Y>@00_n?Y>@3o`0000;oMjK`0oma]OX00on1c_oo/[cQok:lh@02oiZ5^`?o
UWnh0onBN[H4ohmf/`?oS7:a0on8KZl3ohA[[P?oQV^]0on:KZd3oha_[@GoSg6]0onIN:d4oj9n[0Co
YWnY0onUNjD4oiibX@?oUVVL0on=HIT4ohQKU`?oSf2G00CoUVFGojAiY?nTNJCoY7VT1?nTNJ<5oj9i
Y@03oimjZ_nUiiKoQE>>00;oQE>>1?n5E8l3ohIFT@GoREVB0on>GI@3oi5QU@03ok:;[On`QJSo/8FX
00;o/8FX1On]PJD01?nZOJ?oh_CHon;df?oRm=P5olFV^P03okB;ZomkhK[oNn6j00;oNn6j0_oAe=/4
ojZ5[PKo[hR/0_nTPk42okZJ]`Co/YFi00?oZ9G2okJN_onfW[l00_nfW[l4ojfI``Go/ZS>0on[Z=@0
0ond/mSo[:oJojb_fP03ojb_fP;oY[3O0_n/^n@5ojJii`;oXk[Y0_nU`>d2oj:nk@04o`000?nR_^go
XKk^oj6nkP?oX<?a1?nO`_44oio0l0;oWko_0_nM`?45oijnka?ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`09ooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`Go00001_ooool00ol0003oooooooooo`0Booooo`?oKjcf0_n0Z^l4ohnVi@?oVj;I0onU
WLh4ojVHa@03oj^D__nZWlcoZYo<00;oZYo<0onZVLD4ojND`P;oX8o20_nWYmH4oibSf`?o000000?o
SjCTogNVl?mgY_000onfb>P2okG5iP03oin9_?nJQK_oVXFk00;oVXFk1?nFOkP3oi9j]P?oSgJc0on<
L[43ohQ^[`?oQ6^^1?n6Jjd3ohY^[@?oS6n]1?n?LJd3oiUh[@CoXWj/1?nVOjT2ojEkY@03oi^8__n?
M[?oSgJc00;oSgJc0on5JJ/3oh1RYPCoR5^G0_n?H9L00onDKjGoY7VTojAiY003ojAiY0?oY7VS1OnR
NJD00onUiiKoQeB>ohECSP02ohECSPCoQEB?1?n6EY44ohUITP?oSUfD0_nAHID3ok:;[@?o/8FX1On]
PJD00on^Oj7oh_CHon;df002on;df0;oaJJj1OnLLJ45ok>9Z@;oZXF^0_njTjh5ojn8[004ojB3/Onj
V[Oo^YZgokZJ]`Co/YFi1OnfW[l3ojfI``;o_:k<1?nbZ<h00on[Z=Co];?HokBcf002okBcf0?o[:oJ
00?o/KoTojbki?n/^n@00on/^n@2ojJii`;oZ<;/1OnU`>d01?nR_^go0000oj76l_nQa_85oj33l@;o
Wl;a0_nMa?@3oig2lPGoWL3a0_nN_^l2oi^ml1Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`09ooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0Cooooo`?oKjcf0_n0Z^l3ohnV
i@CoVj;I0onUWLh2ojVHa@03oj>Uf?nZWlcoZYo<00?oZYo<1?nZVLD2ojND`P03ojb[e_nWYmKoYjOF
00?oYjOF0ol000001?nLXm_oSjCTohnTi?m/fn`2okG5iP;o]/SX00?oY8jnoin9_?nORK`00_nORK`3
oiZ5^`CoUWnh0onBN[H3ohmf/`?oS7:a1?n8KZl2ohA[[PCoQV^]0on:KZd3oha_[@CoSg6]0onIN:d4
oj9n[0;oYWnY0_nWUlD3oi^8_PCoSgJc0on5JJ/3oh1RYP?oPV6T00CoR5^GohmPUonDKjGoU6nU1OnT
NJ@4ojAiX`?oXWVU00?oYNNFohMDS_n7E8h00on5Dhh5ohEDS`?oQUJA1?n9FI83ohiMU003oi5QUOnb
Rjgo/X^]00;o/X^]1?n`QJP3ojf1Y@03ojj2Y_n^Oj7o[WnQ00;o[WnQ1?nTMYl3oiaaX@;o^i6[1?nc
RJT01?nZQJko^Y>^okZC[_njTjh5ojn8[0Co^YZg0onbUKT2olB/`PGo]Yjo00Co[IW3okb^c?nl[/co
_:k<0onbZ<h00onk^mWo];?HokBcf003okBcf003ojb_f_na_nCo/KoT00;o/KoT0on/^n@2ojg7k@Co
Z<;/0_nU`>d2oj?8l`;oXLKb00?o0000oj76l_nQa_800_nP`o42oig7m@GoWLCd0onM`_82oig0l@;o
V/3b1OnK_O0Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool000Wooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000oooooooo
ool05Oooool3oeNPm@;oGJCf0on?Y^D2oi^Rf@04oh>/konHZnCoV:_ToiR[i0CoXjGH1?nZWl`3ojZI
a@03ojV`gOn/ZmKo[:_F00;o[:_F0_nWYmH2o`000003ojNWe_nLXm_oW:?K00;oU>Gl0oneaNH00onX
T[koY8jnojB>_P02ojB>_P?oWhVl1?nJQK/3oiIo^0?oTWZf0on?M[<3ohab/@CoR6j_0on4Jjh3ohI[
[@?oRVj]0on<Kjd4ohma[@CoVGR]0_nROZ`00on[WLSoYiO5ojNGa@03ojNGa@?oVhRn0on?M[<4ohEY
Z`;oP6:V1?n2HJ@3oiA_Y@GoY7VT1?nTNJ<2oj9iY@04ojGWU_n7E8koQeB>ohMDSPCoQE>>1?n5E8l3
ohIFT@CoREVB0_n>GI@00on_S;;o/X^]ok:;[@03ok:;[@Co/8FX0_n]PJD00on^PZKo`IJZojioX@03
ojioX@CoY7JO0_nLLJ43ok^AZ`Co/hVY1?njTjh4ojn8[0;oajVl1?njV[L01?nbUKWoa:c2olB/`_o4
[<84okJN_`03olBkd_nl[/co_:k<00?o_:k<00Co/ZS>ok^kfOnk^mWo^k_I0ond/mP2okS7iPGo/KoT
00?o[;_Tojg7kOn]and00_n]and2ojS2k0;oYLcd1?nSb?<2oj76lP03o`000?nMboOoWLOe00CoWLOe
0_nMa?@2oiW6mPGoV/?d0onJ`?82oi^ml0?oUkca4oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Wooooo0009ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP05ooooo`?o00005_ooool3oeNPm@;oGJCf0om^ZOD3oh>/k`?oV:_T0onSYMP5ojZOc004ojZI
aOnY/=goZK3MojV`g@;o[:_F0ol000001OnWYmKoY^GkojKUnonViO_oGM:g00?o]/3R00Co]LGVojRB
__nXT[koZ9:n0onTS[h3oin9_0CoVXFk1?nFOkP3oi9j]P?oSgJc0on<L[43ohQ^[`?oQ6^^0on6Jjd3
ohY^[@?oS6n]1On?LJd3oiUh[@04oj9n[?n[WLSoZig8oj^Mb0CoYiO50onKR;h3ohmf/`CoQFV[0_n0
HZH4oh9QY0CoU6nU1?nTNJ@4ojAiX`03oj9iYOn=F8koSER>00CoQeB>0on5Dhh4ohEDS`?oQUJA1?n9
FI800on>GICo[hbbojn</P05ok:;[@Co/8FX00?o[H6Uojj2Y_o1UZX00_o1UZX3ojioX@CoY7JO00?o
W76Qok^AZonkTJ/00_nkTJ/4ok>9Z@Go^Y>^0_n_R:`3olNY_0Co^YZg1Oo4[<800onfW[ooa;_BolBk
dP02olBkdP?o_:k<00?oa<gQok^kfOnk^mT00onk^mT00ond/mSo^<OVokS7iP02okS7iP;o/KoT0_n`
c_04ojg7k@03ojSAm_nUc?CoYLcd00?oYLcd0_nSb?<2oik>n0;oWL_g00Co0000oig;monMaoGoWLOe
0_nHb?P5oiW6mP;oV/?d0_nF`_H4oiJol`GoUkca4Oooool3o`0000Oooooo00?o0000ooooooooool0
2Oooool000Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool06?ooool3oeRQm@04odVSmom^ZOGoKZWeofjYm@?oPjc_0onHZn@3oj>Uf0;o
ZYo<0onR]nP2ojV`g@?o000000?o[:_FojCUo?nTiO`00_nTiO`00onViO_o]k[LokK0hP02okK0hP03
oj^E_onXT[koZ9:n00;oZ9:n0onTS[h4oin9_0?oVXFk1?nFOkP3oi9j]P?oSgJc0on<L[43ohQ^[`?o
Q6^^1?n6Jjd3ohY^[@?oS6n]1?n?LJd2oiUh[@03oj:FbOn[WLSoZig800;oZig81?nWUlD3oi^8_PCo
SgJc0on5JJ/3oh1RYPCoPV6T0onDKjD4ojAiY0CoY7VS0on=F8h4ohMDSP?oQE>>1?n5E8l3ohIFT@?o
REVB00?oYXNdojn</_n_S;800_n_S;84ok:;[@Co/8FX0_n^PZH3ol6FZP?o[WnQ1?nTMYl5ok^AZ`?o
/hVY0_o@/;X4okZC[P03ojn8[?o7ZKcoajVl00;oajVl1?njV[L00ooAb=7oa:c2olB/`P02olB/`PGo
a;_B00?o_:k<olC=hOo4cN400_o4cN42ok^kf@?o^]?]0onhanH2ok7Im@Co/<k`00?o[LO]ojSAm_nX
dOH00_nXdOH2ojG<m0;oWm7i1OnNc_P00onMboOo0000oiW;n@02oiW;n@?oV<Sh0_nIa_H3oiG5n0Co
U/;f1?nF_o<2oiNll@;oTk[b3_ooool4o`000003ooooool0003ooooo00Kooooo00?o0000oooooooo
ool02Oooool000Wooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool06Oooool3oeRQm@?oBJ?g0_m7YoP3oeB`nP?oKkWl0on<^oD2oj:gj0?o
00000_nY/=d00on/ZmKoY>GlojCUo002ojCUo0Co]k[L00Co]/3Roj^E_on[UKooZiFo0onXT[h4ojB>
_P;oWhVl00CoV7fdoi9g/_nBMk;oTWNb1?n>Lk03oh]`[`?oRFj_0on7KZl3ohA]/0?oPFbc1?n6Jjd3
ohY^[@?oS6n]0_n?LJd2oiJ;aPCoXYK90on[WLP5ojNGa@?oVhRn0on?M[<3ohEYZ`?oP6:V1?n2HJ@3
oiA_Y@GoY7VT0onTNJ<3oheHSPCoQeB>0on5Dhh4ohEDS`?oQUJA00CoREVBojJ7]?nVQkCoYXNd1?n_
S;85ok:;[@;o/8FX00?o/8>Tojj2Y_o1UZX00oo1UZX4ojioX@?oY7JO1_nkTJ/01?ncRJWod;2jom2`
^_o@/;X4okZC[PKoajVl0_njV[L2om78d@?oa:c20_o=fN83olBkdP;o`>Sb0oo4cN42ok?Sm`Go^]?]
00?o^<OVok7ImOnafOD00_nafOD2ok3>l0?oYmGh0_nXdOH3oj;Dn@?oWm7i0_nNc_P3oi[=nP04oiW;
nOl0003oU/WioiK9n@GoULOi1?nEaOP2oiK2mP;oT[of0onB_O@5oi>jlP[ooooo0ol00005ooooo`03
o`000?oooooooooo00?ooooo00?oEEEEofIVI_l000002oooool000Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool2o`0001_ooooo0om_[?H4odf^
n@04obNUjomD/?[oE;3joeB`nP?oKkWl00GoS;_eo`000?l0003o0000oj:gj003oec?lP;oQ]om0onh
]]L4okNjg003ojnI`On[UKooZiFo00;oZiFo1?nXT[h2ojB>_P04oif2]_nHOKCoV7fdoiQm]0?oTWNb
1?n>Lk03oh]`[`?oRFj_0on7KZl3ohA]/0?oPFbc1?n3LKH3ohUi^`?oSh701OnFRlH3oj:Fb@CoZig8
0_nWUlD2ohmUW0?oSV6I0on?M[<3ohEYZ`?oP6:V1?n2HJ@3oiA_Y@GoY7VT0_nTNJ<01?nBGHooSER>
oheHS_n=F8h4ohMDSP?oQE>>1?n5E8l2ohIFT@03oj>2/?nVQkCoYXNd00?oYXNd0on_S;85ok:;[@03
ok25Z?n`PjCo/8>T00Go`IJZ1?n^Oj42ojAfW`;ob:Be1OnkTJ/01?ncRJWod;2jom2`^_o@/;X4okZC
[P03omC=doo7ZKcoajVl00?oajVl00?o^YZgom78dOoAb=400_oAb=400oo4[<;ocMWRolgIhP02olgI
hP03olBkd_o0j?;o`>Sb00;o`>Sb00?oa<gQok?SmonchoL00_nchoL2ok[Ck@?oZ>;k0_nafOD3ojCH
nP;oYmGh1OnRe?T2oj;>m`GoWLki0_nJcOX2oi[:n004oiK9nOl0003oU/WioiK9n@;oULOi0_nD`oL5
oi;2m`CoT[of0onB_O@2oi>jlP;oSkSb1_ooool4o`0000Sooooo00?o0000ooooooooool04Oooool0
00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Ooo
ool00ol0003oooooooooo`0Kooooo`?oKjcf0_m=[_T3ogG4oP;o@[_`00CoNmSmo`000?l0003o0000
0_n^foL00onCi?co^Lo[okW?j`02okW?j`03ok^feOnh]]Oo^;KG00?o^;KG00Co]k[LojnI`On_VL7o
[iW11?n[UKl3ojRB_P04oj:8^?nMP[KoWH:foif2]PCoV7fd0onBMk83ohic/0?oRg2_1?n9KZl3ohM^
[`?oQ6f`0on1K;<4oh=a]P?oRGVk0on?PL04oiJ;aPCoXYK90_n[WLP2oi=[X@?oSfFL0on>HIT3ohiP
U`CoQFV[0_n0HZH4oh9QY0?oU6nU1OnTNJ@00onTNJ?oTUf?oi9MS`03oheHSPCoQeB>0on5Dhh4ohED
S`03ohIFTOnSP[3oXh:`00GoYXNd1?n_S;83ok:;[@Co/8>T1Oo1UZX4ojioX@04ojAfWoo8Y;Gob:Be
olRT]@Go^i6[1Oo@/;X2okZC[P;oe<gC1?o7ZK`00oo2o]kodLSAom78d@02om78d@03oj7dkOo=fN;o
cMWR00;ocMWR0_mehm/2ol3XlP?oS>Gj0_nchoL4oi7Ro@;oZ>;k0onMeo`2ojCHnP;oX]7h0onRe?T2
ojK:l`CoX/kg0_nMc_T3oio9m@CoV/[h00Co0000oiK9nOnHa?KoV<Cf1?nD`oL2oi;2m`;oTKke1?n?
_?D4ohnjl`CoSkSb0_ooool3o`0000cooooo00?o0000ooooooooool04Oooool002;ooooo00?o0000
ooooooooool07Oooool4oi6jlP;oMLCn00GoW]3io`000?l0003o0000og_Ho@03ojkKm`Co_/SR00Co
^Lo[ok^feOnk]]Go^kKE0onh]]L00onaWL?o[iW1ojnI`@03ojnI`@CoZiFo00?oZ9:noj:8^?nRR;P0
1?nMP[H3oiQm]0?oTWNb1?n>Lk03oh]`[`?oRFj_0on7KZl3ohA]/0?oPFbc1?n3LKH3ohUi^`?oSh70
1?nFRlH3oj:Fb@03og]MY?nJMJWoTf^Q00;oTf^Q0on?II`3ohiQV@?oSV2G0_nAHIH2ohEYZ`;oP6:V
1?n2HJ@4oiA_Y@?oY7VT1?nBGHl3oheHSPCoQeB>0on5Dhh3ohEDS`03oj5lZonSP[3oXh:`00;oXh:`
1?nVQk@4ojn</P04ok:;[OnaQZKo/HJVok66YP;o/8>T0_o[h<H5ol6FZP?o[WnQ1?o8Y;D4ok^AZ`03
omcoaoo@/;[od;2j00?od;2j00?o^Y>^omC=dooDcM<00_oDcM<00oo7ZKco`_kNol;ngP02ol;ngP03
om78dOnQm>goXOC]00;oXOC]00?ocMWRo`jKdol>Vm<01?li_=h2ohcUnP?oM=Gl0_nAh_d3oiG@o0;o
WMOl0_nRbO@5oj;An003oj;DnOnVb_?oY/[c00;oY/[c0_nRc_L3ojO6l0;oWlWe0_nU`>d4oig3lP04
o`000?nHa?KoV<CfoiS4mP;oU<?g0_nE__@4oi6nm@CoSkce1?n?^_<2ohnhlP;oS;Ga00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0Nooooo`;o
TK[b0_n/`NT2o`0000;oW]3i0onhc^/00on^foOo_/SRokk8hP02okk8hP03okjie?nk]]Go^kKE00?o
^kKE00Co^;KGok6M`onaWL?o/Ig31?n_VL43oj^E_`03ojJ>^onRR;SoXXRh00;oXXRh0onMP[H3oiQm
]0?oTWNb1?n>Lk03oh]`[`?oRFj_0on7KZl3ohA]/0?oPFbc1?n3LKH3ohUi^`?oSh701OnFRlH01?nR
U/WoNefTog]MY?mkGJ@2ogQJX`04oi=[XOn?IIcoSfFLohmUW0?oSV6I0on>H9L3oi5QUP04oiARU?n0
HZKoP6:Voh1RYPCoPV6T0onDKjD2ojAiY003oiEPTOnBGHooTUf?00;oTUf?0on=F8h4ohMDSP?oQE>>
00CoQEB?oj5lZonQO:_oXGb[1?nSP[05ojJ7]0;o[hbb1OnaQZH01?n`PjCojn36on_Pa_o[h<H5ol6F
ZP;o[WnQ0_oGfMT4olRT]@;o^i6[0ooLolL3om2`^P;oH]:[0ooDcM<4oijCb0;oNYgX00?oXYK8oh^J
g?n;V]`00_n;V]`5ogN]m0;oH[km0_nD/>X5oi?4m`;oUM3l0_nQ_Nd4oj;9m0;oX]7h0onX`^`2ojK:
l`;o[;oX1?nWa_000on/_>GoYL3]ojG0k@03ojG0k@;oWL?b0_nS_>`01?l0003oVkkaoi^nlOnK__44
oiFnm0;oTKke0_nC^O43ohnhlPGoSKOb1?n<]O4@ooooo`03o`000?oooooooooo013ooooo000Roooo
o`;o00008?ooool3o`000003ojc1jOnla>3o_<CP00?o^<k[0_o1aMd3okk8hP?o_[WD0onk]]D00ond
XlOo/Ig3ok6M``02ok6M``Co[iW100?oZiFoojJ>^onVS[/00_nVS[/3oj:8^0?oWH:f0onHOK@4oi9g
/P?oSW>`0on;L:l4ohU^[`?oQfj_0on4KK03oh5//`CoPg6f0on9NK/3ohn1`0;oUX_60on2I:L3og]M
Y0?oN5ZS0on?II`3ohiQV@?oSV2G0onAHIH3oiARU003oh1RY_n2HJCoPV6T00;oPV6T0onDKjD00onT
NJCoUF2AoiEPT@04oi9MS`?oSER>1?n7E8h2ohECSP03oiefY_nQO:_oXGb[00?oXGb[0onSP[05ojJ7
]003ojn</_n_Qj_o/HJV00Co/HJV00Co/8>Ton_Pa_o[h<Kojn361Oo1UZX01?n^Oj7oemWIomOIfOoG
fMT4olRT]@06ok^AZonYRK?oZHVcokjF[_n`SK7od;2j0_n`SK401OnDQl?o/iJjof;BZooDcM?o/iJj
00?oWY?800?o/iVloj:Fb?nRU/P00_nRU/P4oh^Jg0;oMjgd0onMXmX4oiB`jP;oTlCg0_nT/N45oj6m
k@;oX/Wd0_nZ^N@3ojS2k0;o[kOO1?n/_nP00onWa_3o[;cUojbli@02ojbli@;oYL3]0_nZ^^@5oj>l
k003o`000?nK__7oX;W[00CoV;[_1OnC^O43ohnhlP;oSKOb0_n<]?44oh^clA3ooooo00?o0000oooo
ooooool04?ooool002;ooooo00?o0000ooooooooool07?ooool3o`000003oooooon/`NWo_<CP00Co
_<CP00?o^<k[ol75gOo1aMd00_o1aMd00onnb>;o_[WDokjie003okjie004ok^feOndXlOo]:?7okBS
a`Co/Ig30_n_VL400onZU;ooYXjkojJ>^`03ojJ>^`?oXXRh1?nMP[H3oiQm]0?oTWNb0on>Lk03oh]`
[`CoRFj_0on7KZl3ohA]/0?oPFbc1?n3LKH2ohUi^`?oU;cb00?oQ]kmohY^[On:KZd00on2I:L3og]M
Y0?oN5ZS0_mgFZ@01?n?IIcoSV6IohiQVOn>HIT3ohiPU`CoTF6F0onDHY@4oh9QY0;oU6nU00CoUV:B
oiEPTOnEH97oUF2A1?nBGHl3oheHSPCoQeB>00?oQE>>oiefY_nMMZH01OnQO:/4oj>2/0?oYXNd0on_
Qj/4ok66YP?o_YB[0oo[h<H3ol6FZP03oj=hXooGfMWoemWI00;oemWI0oo8Y;D00onhSJ[oZHVcojV9
/`02okjF[PCo/8fa1_ncU[X01?nNTlSo/iVlok>I_?ncVK`4oj:Fb0;oRi[L0_nVWLd5oifSfP;oU;3Z
0_nVYMD4ojBah@;oXKg]0_n[/=/5ojZii003ojS2k?n_]moo[kOO00;o[kOO0_n/_nP2ok6fg@?o[;cU
00?o/KKLojZji?nZ^^@00onZ^^@2oj>lk0;oYkOT00Co0000oj2ijonP^N_oX;W[1?nH^^l2oi>il@;o
UKK^1?n?]O04ohbdl@CoRk?a3oooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0003ooooo
ooooo`0Iooooo`?o00001_ooool3okc4h0;oa<CJ0oo1aMd3ol6meP?o_[WD00?o^:_=okBSaondXlL0
0_ndXlL3ok6M``03ojfJa?nZU;ooZYBo00;oZYBo1?nVS[/4oj:8^0?oWH:f0onHOK@2oi9g/P04ohid
/_n;L[7oRg:aoh]b/@?oRW6a1?n9Lk<3ohYf]`?oRG^m0on8Q<P5ohfIfP?oU;cb00CoUG^dohY^[On:
KZgoRVj]0on2I:L3og]MY0?oN5ZS0omgFZ@3ohiQV@?oSV2G1?nAHIH3oiARU0?oUV>C1?nFHY83oiEP
T@CoTUf?0on=F8h3ohMDSP03oiYaXonMMZKoWGJV00;oWGJV1?nQO:/4oj>2/003ojJ7]?nXQk7oZ8Na
00Co[hN[0_naQZH00ooAYJ_o_YB[okjDZ`02okjDZ`;o]8JT00?o`IJZokB6Y?ndQZ@00_nSN:<4omOI
f@04olRT]OnhSJ[o^8fZojV9/`?o_YJ^1?n`SK400oo7Y;Ko/iJjok>F^P03ok>F^PCo/iVl0onRU/P0
0oncX<GoYYg=ojJMc@03ojJMc@;oWJ?J0_n[X<`5ojJUe@;oY;7Q00?o[ZWCoj^`fon[/=/00on[/=/2
ojZii0;o/:oG1?n_]ml00ond/=Co/KKMok6fg@03ok6fg@04ojbliOna]]co/KKLok6fg0?oZ[[T00?o
[kGMojNgi?nW]n@00onW]n@01?l0003oX;W[ojBfiOnT]^D3oibfj`GoUKK^1?n?]O02ohbdl@;oSK;_
0on:/_0?ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo01Kooooo0ol0
000:ooooo`03okc4h?o4a=[oa<CJ00;oa<CJ00?o`LGMol6me_o1_MH00oo1_MH01?nn^MCo^:_=okR[
cOnhZld4okBSa`04ok6M`on]V/Co[I[4ojfJa0?oZYBo1OnVS[/3oj:8^0;oWH:f00CoUgnhoi9i]?nB
NKCoTWVd0on>M;83oh]b/@?oRW6a1?n9Lk<4ohYf]`?oRG^m0on8Q<P5ohfIfP04oiBll_nENkCoUG^d
oiEk]0;oRVj]0on2I:L3og]MY0?oN5ZS0omgFZ@2ogMLY`04ohiQVOn>H9OoSV2GohiPU`CoTF6F0onD
HY@3oiIST`CoUV:B0onEH944oi9MS`?oSER>00CoQeB>oiYaXonJLJ?oVW6S1?nMMZH4oj5lZ`CoXh:`
0onXQk44ojn7Z`03ok66Y_oAYJ_odJF[00?o_YB[0_oC[;85okB6Y0;oXgRS0_nnU:`4okR=ZPGo_YJ^
0_n`SK42olNT]PCo/iJj00?o`JBlok>I_?ncVK`00oncVK`01?nRU/So/j35ok>PaOncX<D3ojJMc@03
ok6RbOn[X<coZj3<00?oZj3<0onVYMD00onaY/go[ZWCojjYd`02ojjYd`?oZk3K00?o/JW@ok2_eon`
[mL00on`[mL00on_]moo];3DokB`e002okB`e0?o/KKM00?o][7Dok6fg?na]]`00_na]]`00onZ^^Co
[kGMojneg@02ojneg@;oYkOT0_n/]=h00onT]^Go0000ojBfi@02ojBfi@?oW;K[0_nE]^h3oiRdj`?o
TK?^1On=/^l3ohZbl0kooooo00?o0000ooooooooool04?ooool002;ooooo0_l0000Dooooo`?o0000
3_ooool5olC4fPCo`KgF00?o^kKDokR[cOnhZld00_nhZld3okBSa`03ojjQbon]V/Co[I[400;o[I[4
0onZU;l5ojJ>^`;oXXRh00CoW8NmoiMo^?nGOkSoUgnh0onBNK@4ohid/P?oRg:a0on:LK43ohUc/`Co
RWJg0on9Nkd3ohR4b0CoSIWJ0_n7JJT3oh5RYP?oRVj]0_n2I:L4og]MY0;oN5ZS0omgFZ@3ogMLY`?o
SV2G1?nAHIH3oiARU0?oUV>C1?nFHY83oiEPT@CoTUf?0_n=F8h00onEKZ?oVW6SoiYaX`02oiYaX`Co
WGJV1OnQO:/2oj>2/004oin5]onXQk7oZ8NaojR7/@Co[hN[0ooAYJ/3okjDZ`;odjbb1OndQZ@01?nS
N:?o_YB/okjD[?nnU:`4okR=ZPGo_YJ^00Co/8faolNT]_o7Y;KoajBf0oncU[X3ol6T_0?o/iVl00?o
`j_3ok>PaOncX<D00oncX<D01?nVWLgo/J;9ok6RbOnaX/T4oj^Pc004ojJUeOnaY/go/JK=ok6Vc@Go
[ZWC00CoZk3Kok6Yd?naZM3o/JW@0on`[mL00onfZloo];3DokB`e003okB`e003ok6fgOnf/MCo][7D
00;o][7D0_na]]`2okJbe@?o[kGM00?o/k;Hojbdg_n/]=h00on/]=h01?nT]^Go0000ojBfiOnX]>44
oj2diPGoV;C[0onA/nh2ohfbk`;oSk7^1?n;/Nl=ooooo`03o`000?oooooooooo013ooooo000Qoooo
o`;o00004_ooool3o`0001;ooooo1Oo4a=X00oo1_MKo^kKDok^fe002ok^fe0Co^:_=00Co]:?7ojjQ
bon^XL_o[Z7;0on]V/@4ojZD_`;oYXjk0_nQT<<3oib7_@CoUgnh0onBNK@3ohid/P?oRg:a0on:LK44
ohUc/`?oRWJg0on9Nkd4ohR4b003ohfIf_n@LjooQfVY00;oQfVY0on1HZH2ogYMY@04ohY^[On2I:Oo
PVBWoh9TY`?oNefT0_mhFZ<4ogMJY0;oMebW0omhHJ`4oi5QUP?oU6:D0onFHi<4oiIRTP?oUF2A0_nB
GHl2oi1]YP?oUFjS1OnJLJ<3oiefYPGoXGb[00?oXh:`oin5]onOQKL01?nXQk42ojn7Z`03oheUW_oA
YJ_odJF[00;odJF[00Co_YB[om>//_oC[;;odjbb1OndQZ@01?nSN:?o_YB/okjD[?nnU:`3okR=ZP;o
djjd1?nnUZh5olNT]P03ok>F^_o1Y;co`JBl00;o`JBl0_ncVK`2ol>[``Co/j3500?o^jg;ok6RbOna
X/T00_naX/T3oj^Pc003ok>WcOnaY/go/JK=00?o/JK=0on^ZM<00oncY/co/JW@ok6Yd003ok6Yd004
ok2_eonfZloo]Z_?okJ[c`?o];3D0_ni[Lh3okJae003okV_conf/]Go][;E00?o][;E00Co[kGMok>b
f?nc/]So/k;H1?n/]=h00onT]^Go0000ojRdh@02ojRdh@CoX;CV0_nH]>/2oi^bj0CoU;;[1?n?/Nh4
oh^ak`cooooo00?o0000ooooooooool04?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool03oooool2
o`0001Kooooo0oo4a=X2oko4gPGo^kKD0_nhZld00on_Z];o[Z7;ojjQb`02ojjQb`Co[I[40_nZU;l0
0onUVLWoXI33oj6@``02oj6@``?oW8Nm1?nGOkP3oi9i]0?oSWBb0on;L[43ohYa/@CoRG>c1?n:M[L3
ohUk_@;oR8C80on@Ljl3ohMYZ@?oPF:V0omjGJD3oh9TY`?oNefT0omhFZ<3ogMJY0;oMebW0omhHJ`3
oh9]/P04oi5QU_nDHYCoU6:DoiARU0;oUV>C00?oTGZgohme/_n?MK800_n?MK83ohm`[0CoT6fV0onE
KZ<5oiYaX`?oWGJV1?nQO:/4oin5]`CoZ8Na00?o[hN[oi9TVOn=IIh01?oAYJ/01?nnU:_odjbbom>/
/_oC[;85okB6Y0Co_YB/0onhSJX2om>^]0Co_YJ^00?of;o1olNT]_o7Y;H00_o7Y;H5ol6T_003ok>I
_?o3Zl?o`j_300;o`j_30_ncX<D2ok^]b`Go/J;900CoZj3<ok>WcOncYlgo/jO=1?naY/d00on^ZM?o
/jK<ok>Vc002ok>Vc0?o/JW@00?o]ZS;okJ[confZll00onfZll00ond/=Co^Jg>okV]cP02okV]cP04
okJae?ni[loo^Jo?okV_c`?o][;E00?o^K7Aok>bf?nc/]P00onc/]P2ojbdgP;o/;?K00CoZ;CQo`00
0?nX]>7oZ;CQ0_nP]>H2oj>ci0GoVk;X1?nD/^/2ohnakP;oTK7/0on=/^l=ooooo`03o`000?oooooo
oooo00oooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`?o00006Oooool00oo4a=[o_lCNoko4gP02
oko4gP?o^kKD00?o/;GLojnZd_n_Z]800_n_Z]84ojjQb`;o[I[400?oYj;AojFIbOnUVLT00_nUVLT4
oj6@``?oW8Nm0onGOkP3oi9i]0?oSWBb1?n;L[43ohYa/@?oRG>c1?n:M[L2ohUk_@03oe3>c?nIOkKo
VGnf00?oT7>_0on7JJT3oh5RYP?oNUfU0omeG:P3og]MY0?oN5ZS0omgFZ@3ogMLY`;oN66/1?n2KK83
ohmi]`?oTGZg1?n?MK83ohm`[0CoT6fV1?nEKZ<4oiYaX`CoWGJV0_nQO:/2oiN1^P?oWhFg0_nXQk44
oi9TV@GodJF[1?oC[;84okB6Y003olR[_OnnU:co_YB/00?o_YB/00Co^8fZom>^]?oC[[Codjjd0onn
UZh2omRo`@CoajBf00?of<K8ol6T_?o1Y;`00_o1Y;`5ol>[``03ok>PaOnk[L_o^jg;00;o^jg;0ona
X/T00ong/=;o/jO=ok>Wc@02ok>Wc@?o/JK=00?o]ZS<ok>Vc?ncY/`00oncY/`00onaZM3o]ZS;okJX
b`02okJXb`?o]Z_?00?o^J[:okV]c_ni[Lh00_ni[Lh00onl[L_o^Jo?okV_c`03okV_c`04okJbeOni
/M7o^K7AokVad@?o/k;H00?o]k;Eok2cfon`/m/00on`/m/01?nX]>7o0000ojbcg_n//mh4oj>ci0;o
Vk;X0_nN/^H4oiNajPGoTK7/0on=/^l<ooooo`03o`000?oooooooooo00oooooo0007ooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0000Gooooo0_l0000:ooooo`?o00007Oooool5oko4gP04
ok^fe?n`]Mco/;GLok2eg0Co[j[B0_n^XL/00onVZ]WoYj;AojNRd@02ojNRd@?oYIW91?nQT<<3oib7
_@CoUgnh0onBNK@3ohid/P?oRg:a0on:LK43ohUc/`;oRWJg0on1f_h01?nTSkkoVGnfoiUo]_nIOkH4
oi1c[`;oQfVY0on1HZH3ogYMY@?oMEbX0_m^G[001?mkGJCoN5ZSogQJXomhFZ<3ogMJY0?oMebW0omh
HJ`4oh9]/P?oSgVg0onAN[L4ohme/P?oSg2/1?n@KJH3oiE^X`CoVW6S1?nMMZH01?nQO:_oUh6joiN1
^_nGPKX2oin5]`CoU6BG0onBI9T00ooP_KGodJF[om6UZ`02om6UZ`03o`002_oC[;;odjbb00;odjbb
0_ndQZ@2olR[_@Go_YB/00?o^8fZom>^]?oC[[@00_oC[[@01?nnUZkof;o1omRo`OoH_l43olNT]P;o
f<K80oo1Y;`2olVmc`?o`j_300?oblGDok^]bonk[L/00onk[L/00onaX/Wo]k3BokN`dP02okN`dPCo
/jO=00Co/JK=okJXc?nfZ<co]ZS<0oncY/`00ongZL_o]ZS;okJXb`03okJXb`03okJ[coniZ/[o^J[:
00;o^J[:0_ni[Lh3okb]b`?o^Jo?00?o_Jo<okVadOni/M400oni/M401?nc/]So]k;EokNbeOng/]D3
ok2cf`03ok>cf?n//mko000000?o[;?N0_nS/n@2ojNchPCoW[;V1?nG/NX2oi6ak0;oU;;[1?n@/^h;
ooooo`03o`000?oooooooooo00oooooo0007ooooo`05o`000?ooooooooooooooool000002oooool0
1?m4A4CogMgMooooool00006ooooo`03o`000?oooooooooo00Kooooo0ol0000Qooooo`;o_lCN0on`
`^L4ok2eg0;o[j[B00?oY;7QojJZfOnVZ]T00_nVZ]T3ojNRd@?oYIW91?nQT<<3oib7_@CoUgnh0onB
NK@3ohid/P;oRg:a00?oR9[Noh^YjOn;ZNT00_n;ZNT4ohc1n@03ojnPb?nTSkkoY8nn00;oY8nn0_nI
OkH4oi1c[`?oQfVY0_n1HZH4ogYMY@;oMEbX0om^G[03ogQJX`?oMeZT0omgG:L3ogQQ[0CoPVfb0on?
NKL3oi5j]`CoSgFb0on?L:`4oi1]YP?oUFjS1?nJLJ<4oiefYP;oSV6H0onAHYL5oiATU`;oTVBI0_oP
_KD3om6UZ`;oRfVV1?oC[;800ondQZCob:^molR[_@02olR[_@Co_YB/1OoC[[@00onnUZkof;o1omRo
`@02omRo`@03olNT]_oHa/Sof<K800;of<K800?o`JBlolVmcoo9_Ll00_o9_Ll01?o3Zl?oblGDol_5
e?o;aM@3ok^]b`03okc3gong/=;o]k3B00?o]k3B0_ncYld2okJ_dPGo]ZS<00Co/jK<okNYbongZL_o
]jW;0onfZ</00oniZLWo^J[:okVZbP03okVZbP03okV]c_nl[L_o_:g;00;o_:g;00?o^Jo?okf_c?nm
[l`00_nm[l`3okVad@03okfbcong/]Go]k;E00;o]k;E00?o/;?Kok>cf?nc/mP00_nc/mP01?n//mko
0000ojndgOn_]=d5ojNchP;oW[;V00?oXK?UoiZbj?nJ/^P00_nJ/^P5oiBbj`CoT;;^2_ooool00ol0
003oooooooooo`0?ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEE
EOoooooo00001_ooool00ol0003oooooooooo`03ooooo`?o00009_ooool4ok32i`;o/;GL00?oXKSX
ojBahOnT/N400_nT/N43ojJZf@CoYj;A0onUVLT2oj6@``04oi>PgOn@VMSoT9WHoi2If0CoRi?E0on9
TMD3ohNBe`CoR9[N1?n;ZNT00on<`OWo[j38ojnPb002ojnPb0?oY8nn0onIOkH3oi1c[`?oQfVY0on1
HZH3ogYMY@?oMEbX0_m^G[02oeY]c003ogQJXomgFZCoMeZT00;oMeZT0_mgG:L3ogQQ[0CoPVfb0on?
NKL3oi5j]`CoSgFb0on?L:`4oi1]YP?oUFjS1OnJLJ<3oiefYP;oSV6H0onAHYL5oiATU`;oTVBI0_oP
_KD2om6UZ`04oiIZW_n;JJKoRfVVoh]YYP;odjbb00?oD<CcolR[_Oo8Zkd00oo8Zkd3okjD[003onO[
dOoC[[Codjjd00;odjjd0_o8o/P3omRo`@;oY_K:0ooHa/P2okkYl`?obKg?00?o_^Caol_5e?o;aM@0
0oo;aM@01?nk[L_o_<?Ookc3gonl`ml3okN`dP03ok>ohonf[m;o]ZoB00?o]ZoB0onfZ<`00ong[]7o
]jW;okNYb`03okNYb`04okJXboniZLWo^JW9okVYb@?o^J[:00?o_:c9okb]bonl[L/00onl[L/5okf_
c003okVadOnm//oo_K;?00;o_K;?0_ng/]D2okZcd`?o/k?H00Co]kKHojndgOn_]=go00000_n_]=d2
ojNchP;oZKCQ1?nQ/nD4oiZbj0CoU;;[0_n@/^h2oi>dk@[ooooo00?o0000ooooooooool03oooool0
00Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Gooooo00Co0000
oooooooooooooooo0ol0000Zooooo`;o/<;W0_nM_Nl3oj6hj0CoY;7Q0onVZ]T2ojNRd@04oiR`j?nF
Z>;oUZSRoiJXhPCoTj3M0on@VMP4oh^Ce@?oRI7E0on7T]L4ohRJgP;oRjWY0onh/M82ojnPb004oiJ8
`_n=O;coSGblohel_0?oPW:h0on@Ljl3ohMYZ@?oPF:V0omjGJD3ogELZ0?oKUj`0_mJKL`4ogMJY0?o
MebW0omhHJ`4oh9]/P?oSgVg0onAN[L3ohme/P?oSg2/1?n@KJH3oiE^X`GoVW6S0_nMMZH3ohiQV0?o
TF:G1OnDI9L00onBI9Woh;feon2m]@02on2m]@03om6UZonFJYkoRfVV00CoRfVV00?o`J2goe34loo8
Zkd00oo8Zkd2okjD[0?oin_A0_oC[[@4olSnb003omRo`OnVm/[oY_K:00;oY_K:00?of<K8okkYlonn
jO<00_nnjO<01?o9_Loo_^CaokkTlOnni?43ol_5e0;o^>?d1?nl`ml01?ng/=;o/koSok>ohonc_n<5
okJ_dP04okJXc?ng[]7o]jkAokN^d@?o]jW;00?o]jc=okVYbOniZLT00oniZLT01?niZ/[o_:c9okb/
bOnl[<T3okb]b`;o_jo91?nm[l`5okfbc`03okNbeOnj/m?o^[?C00;o^[?C00Co/k?HokNff?ng]]So
]kKH0_n_]=d00ol0003o/KKLojVdh@04ojVdh@CoXK?U0_nJ/^P2oifcj0?oUk?[1OnC]>d9ooooo`03
o`000?oooooooooo00oooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000005ooooo`Co0000;_ooool4oifmk`?oXKSX0_nT/N42oiJhk`?oUkC/0onH/>P3oiJXhPCo
Tj3M0on@VMP4oh^Ce@?oRI7E0on7T]L2ohRJgP?o_/3K0_nh/M800onQULSoUXS2oiJ8`P02oiJ8`P?o
SGbl0_n2L[P3og]/]`?oQfVY0on1HZH3ogYMY@?oMEbX0om^G[03oeY]c003oj:NdOn4MkgoMeZT00?o
MebW0omhHJ`4oh9]/P?oSgVg0onAN[L3ohme/P?oSg2/1?n@KJH3oiE^X`GoVW6S00?oWGJVoiAYW_n>
HIP00_n>HIP4oi5RU`CoU6BG00?oTVBIon2m]OoP_KD00_oP_KD2oiIZWPGoRfVV0_o1X;L4olR[_@03
okjD[?oWjm7oin_A00;oin_A00CodjjdoiQl/onHO;?oV7bc1?n1L[T4of1_b`;o_^Wc0ol/]=H4okkT
l@03ol_5e?nhhoCo^>?d00;o^>?d0_nl`ml2oj?HnPCo/koS0_nf[m82ok6hg`Go]jkA00Co]jW;okN/
cOng[<go]jc=1?niZLT5okb/b@04okb]bono[lWo_jo9okn_b@?o_Jo<0_o0/L`3okfbc`;o_kC?0onj
/m<00onm]]?o]kKHokNff003okNff004ojndgOl0003o/KKLok6fg0CoZKCQ0_nQ/nD2ojBdi0GoWK?X
0onG/n/2oi>dk@;oU[G]2Oooool00ol0003oooooooooo`0?ooooo`001oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01?ooool2o`00037ooooo0_nM_Nl2oi:jlP?oU;[a
1?nF^>l3oiNdk0?oV;3X0onFZ>82oi>Pg@CoCkkg0_l`/n@01OlT[[Go]NOfokGWm_neioKo^ngd00Go
_l_S0_nn`=/00onZX/ooXIG8oj6Eb002oj6Eb0?oUXS20on=O;`3oh9b^0;oNfbg0omdJKT3oh5RYP?o
NUfU0omeG:P4ofiN/004oeY]c?miJ;?oNFRcoj:Nd@;oQ7Nm0om/G[02ofAF[0?oOUfQ0omdE9h3ofU?
X@?oEe>b0_n?MK83ohm`[0?oT6fV1?nEKZ<3oiYaX`03ob4_Y_nDJIkoU6VN00CoSV6H0onAHYL4oiAT
U`Coh;fe0onFJYh4oh]YYP;o^8^V00Co`J2gono7ZOo8Zkgob:^m0oolgj82onO[d@;o]iRh1?nHO;<4
oh5b^@;oH6o;00?oV8>kohVGfon9Um/00on9Um/00om5[OSo18oFofWGlP02ofWGlP;o^>?d0omFcnT4
oj?HnP;o/koS00?oU/Ohok6hgona^=l00ona^=l3okN^d@03ok:cf?ng[<go]jc=00;o]jc=0oniZLT2
ok^]b`Co_:c91Ono[lT00onm[lco`;7<ol2ac002ol2ac003okfbcono]<oo_kC?00;o_kC?00Co^[?C
okffdonm]]?o_KKC0ong]]P01?ni^=So/KKLok6fg?l00002ok6fg0;oZKCQ0_n/]^44ojBdi0;oWK?X
0_nO]NL4oiZdjPCoU[G]2?ooool00ol0003oooooooooo`0?ooooo`008_ooool00ol0003ooooooooo
o`0_ooooo`CoT[[b0onD^_42oiJhk`;oRL7j1?n1a?d3ogK4oP;oIlCn1?mVcoX2odO6h`04ohOUmone
ioKo]NOfokGWmP?o_]3X0_nobn<2ok2^ePCoZZ;?0onQULP3oiJ8`P?oSGbl0on2L[P3og]/]`;oM6Vi
0om`Kl44ogYMY@?oMEbX0_m^G[000om3`J_oTX6mogUX/`02ogUX/`;oQ7Nm0om/G[02ofAF[0;oH5Na
0_mnGJ42ogADWPCoJDnQ0_mGDk800ol0003oRX[>ohm`[002ohm`[0CoT6fV0onEKZ<2oiYaX`04o`ln
_OlQ;jKo3Bn_oiAYWPCoSV6H0onAHYL3oiATU`;ojNc?0_oP_KD00onEJYkoUVZNoiIZWP02oiIZWP;o
RfVV0onhRjH00oo1X;OoklNYono7Z@03oocOXP;oknC31?ngV;P3oiQl/`;oPG:i0_nKO:l4oiR3^`?o
RIOK00?o]:S=oiC7nOnDaoT00_nDaoT2ok_<i`;oCl7f0on3c_l01?l0R[SoC/7fodk1m_m>`OH3oiK7
n0Co/KSO00?o]jkAok:cf?nb/mP00_nb/mP4okN/c@04okVYbOnk[L_o^jg;ok^]b`?o_:c90_nn[lX3
okn_b@03ol:bboo0/Lco`;7<00;o`;7<00?o`[G=okndcono]<l00_no]<l00oo2^=3o_KKCokffd`02
okffd`03okNff?ni^=So^KSH00;o^KSH0_na]]`00ol0003o/kSMojbfh@04ojbfh@;oY;CT00?oY[KT
oineionO]NL00onO]NL4oiZdjP;oU[G]00?oVKO]ooooooooool01oooool00ol0003oooooooooo`0>
ooooo`008oooool00ol0003oooooooooo`0_ooooo`;oT[[b0_n@^O84ohfnmP?oRL7j0_n1a?d4ohS;
oP;oN/ko0onFe?d2oi7NoP;o[mkg0_nid^`3okk@j003okBhfon`[]Ko/:kF00?o/:kF0onZX/l4oj6E
b0?oUXS20on=O;`2oh9b^0?oNfbg0omdJKT2og1_`@?oL87D00GoNUfUogELZ?meG:SoMEbXofiN/003
oi:1_@?oNFRc0_mZG:l00on4MkgoK5j`ofaN/002ofAF[0?oH5Na00CoOUfQogADW_mdE9koM5BN0omY
Cj400omGDk;oYm;folOOj`02ohZ:cP;oGeZe1?n@KJH3oiE^X`04oiYaXomOC:Go3cjmo`ln_@;o3Bn_
1?n>HIP3oi5RU`;oU6BG0ooYk<l00ooP_KGoUFZNoiEZWP04oiIZWP;oRfVV0onhRjH00oo1X;OoklNY
ono7Z@02oocOXP?oknC31?ngV;P2oiQl/`03oiil[OnKO:ooVgb_00;oVgb_1OnHPk/01On9Um_o]:S=
okBXcOndZ<goU<Oi00Co^lcW0_o?d=T2oh?>o`?oW<[h00?o5hSXo`1hc_l0QL/00_mF]O/01?nFaoSo
/KSOok6hgonO_>d5ok:cf0;o]jc=0_nf[m85ok^]b`05okb/bOnn[l[o_Zo:okj_b_no[lT01?o2///2
ol2ac0?o`[G=0_no]<l3ol:hd0;o_KKC0_no^M@3okVhf004ok^kfOnc^=go/kSMo`0000;o/kSM0_n/
]^42ojfhh@CoY[KT0_nO]NL2oj:gi`GoWKKZ0onI]nd8ooooo`03o`000?oooooooooo00kooooo000T
ooooo`03o`000?oooooooooo02oooooo1?n@^O82ohfnmP;oU/7e1On@a_X2ohS;oP?oVlgi0_nFe?d3
oj_EmP03ojoNmonid^co^M;/00;o^M;/00Co_]3XokBhfond^=_o];SK1On`[]H3ojZRc`;oXIG800Co
T8O6ohIoa?n6OlCoQWo40on=O;`3oh9b^0;oNfbg0omdJKT3og1_`@GoL87D00?oM;SkojbQc?n/XL`0
0onBPKd2ogUX/`?oJUb_0_m/G[03ofAF[0?oH5Na0omdE9h2ofU?X@?oYm;f00?oO7[5oeaI]On:R/h0
0omOF[D2of1E[P03oi1]Y_nEKZ?oUFjS00CoGdbU0_l??[d00ol=;joo4EcDoa5Le002ohiQV0?oTF:G
00GoU6BGonW/cooYk<oojNc?oiQbYP03oiEZWPCoUVZN00?oRfVVokR;Y_nhRjH00_nhRjH00ooecZGo
klNYono7Z@02oocOXPCoknC30_ngV;P01?nPQKKoWWb]oiil[OnNO:d5oi]l[`?oV8>k00?o]YJfokBX
cOndZ<d00_ndZ<d01?o;]<?o^lcWok_<ionkc>L3olo@f@03omS@d_nLb_SoW<[h00;oY/;^0om1T>l0
0ol0HLcoE[GkoeJen`04oinlk@?o/[?H00?oZ;CRokJ_d_nf[m800onf[m83ok^]b`03ok^`conn[l[o
_Zo:00;o_Zo:1Oo2///00oo0/Lco`[G=ol:ec@02ol:ec@03okndcoo2^=3o`[S@00;o`[S@00?o_KKC
oknie?no^M@00_no^M@01?ni^=So^k_Iok^kfOnk^mT2ok>hg@03o`000?nd^mko];_N00Co[KSQ0_nV
]^@2ojNhi@CoX[OW0_nM]^X2oinhjPCoW;S/1oooool00ol0003oooooooooo`0>ooooo`009Oooool2
o`00033ooooo0_n@^O82oiVll0CoU/7e0_n@a_X4oik6m0;oVlgi0_nXc_@3oj_EmP?o]Lo]0_nid^`2
okJnh0Co];SK0_n`[]H2oj6KcP?oVI791?n@QlH2ohIoa0?oOWc60omcOLh3og]/]`;oM6Vi0om`Kl44
og21e004olC6g?n/XLco[:7<ojbQc0?oTX6m0omiJ;<2ofYL[`;oEeFd00?oK5j`ofAF[?mTEZ`00omP
Ek43og5fb004ofU?XOnWd_KoYm;fojOBmP;oO7[50_mLFKD00on:R/koGeZeoemJ]@03of1E[P?oKE>R
0omOC:D01?l??[gol=jmoo3N_OnYfWD3oa5Le0;oTF:G0on7i?T00ooYk<ooV7:VoiQbYP03oiEZWPCo
UVZN1OnhRjH2ooG>Y@03oocOX_l0003o01RT00;oknC30_nL^>`3oj25]PCoWWb]1?nKO:l2oiR3^`?o
]YJf0_ndZ<d3ol^d``04ok_<ioo?d=Wocm3Iolo@f@;of=3B00?of]3?ojK2k_nV`^h00_nV`^h3od6@
k`03o`1Xf_lJS>Wo6XcY00CoWkc]00Co/[?HojRdh_nX]>;oZ;CR1?nf[m800onk[L_o^k3?ok^`c`02
ok^`c`;o_Zo:0_o0/ld3ol:bb`;oa;K=0oo2]Ld2olFic`?o`[S@0_o4_=83oknie003ol6meonk^mWo
^k_I00?o^k_I00?o/kSMokBkg_l000000_nd^mh2ojfhh@03ojnjh_nW^>GoYkSU00?oYkSU0_nR]nL2
oj>hj0CoWkSZ1?nL^>`6ooooo`03o`000?oooooooooo00kooooo000Wooooo`03o`000?oooooooooo
02kooooo1?nI_?02oiK1m@CoX<;a0_nNa_@2ojO8l@CoZ<kd00CoZmGfokG?kOnecngo]Lo]0_ne`^@4
okJnh0;o];SK00?oZ:GCoj6Kc_nQVlh00_nQVlh3oiVAb@CoT8O60on6Ol@3ogilaP;oLgg>0omWS>83
ogAY^@?oL6o100CoL87DolC6g?o4a]coVYWB0on1OlP3oi:1_@?oNFRc0omZG:l2oeME]0;oI5J/0omP
Ek45og5fb003ojOBm_nh^=SoO7[500;oO7[50_mLFKD3oemJ]@;oH5F^0_m_I;D00om]Dj;oGdbUoem<
Y@03ok6Qb003ojWJMOoPcLGo_jg700Co4EcD0_n7i?T01?ngW[ooV7:VoiQbY_nHLZH4oiEZWP?oUVZN
1?nhRjH3ooG>Y@;o00000_l06:@3oibhk0CoX8Ff0onNO:d4oi]l[`03oiR3^onfU[Ko]YJf00;o]YJf
00?o]:S=ol^d`oo;]<<00_o;]<<2omc1_P04olo@fOoHd=;of=3BomS@dP;of]3?0_nV`^h2ojNji`;o
FI7[00Go@I3_o`1Xf_l0J=[o06oJoaZ<j@02oh6dmPGoZ;CR0_nf[m800onb/]Wo^k3?ok^`c`03ok^`
c`03okj_b_o0/lgo`;?=00;o`;?=00?o`[;;olBfcOo4]/d00_o4]/d00oo2]LgoaKW?olFic`02olFi
c`03ol:hd?o4_=;oa;cB00;oa;cB00Co_kWDol6meoo1_MOo`KgG0_nk^mT2okbnf`?o];_N00?o0000
okFmh?n_^^800on_^^82ojNhi@;oZK[U1OnS^>P2oinhjP;oXKWZ0onO^^`6ooooo`03o`000?oooooo
oooo00kooooo000Xooooo`03o`000?oooooooooo02kooooo0_nI_?04oj:nk@;oX<;a0_nV`nh4ojO8
l@;oZ<kd0onac>h00onecngo]L;TokG2i002okG2i0;o][kP00?o[:gHojRUdonXYM<00_nXYM<4oj6K
cP?oVI790on@QlH3ohIoa0?oOWc60omcOLh4ofN<hP05ocJXlooBj>God^SUom;XiOn`]Md01?nJVM82
oh5ob0?oLFo10omiJ;<3ofYL[`;oEeFd0_m3JM801?mTEZcoH5Naof1G/OmPEk43og5fb004on;afOnh
^=So^;SHokRhf0;oO7[50_mLFKD00olnA[;oGeZeoemJ]@03of1E[P;oKfBe00?oGdbUok6Qb?naXLP0
0_naXLP3on3=a@03okn]aonTQkKoY8Nf00;oPfnd0_lUAK/4oiQbYP?oUFZN0_nFJYh2ok62XP?o^8^V
0ooecZD01Ol0003oWhFgoaP^ZOl06:CoXB@000;oW;S/1?nPQKH3oiil[@CoVgb_1OnfU[H5ol^d``;o
g<6n0ooHd=83om[@c`GoYk[W0_mITN/2oae^g`;o06GI0omNY?D2ojRdhP;oV;;Z1?nb/]T3ok^`c`03
okZddoo0/lgo`;?=00?o`;?=1Oo4]/d4olFic`03olJnd_o4_=;oa;cB00;oa;cB00?oa/7Eol6meoo1
_ML00_o1_ML5okbnf`03okBkg_ne_N3o000000;o]KgP0_n_^^82ojnlh`CoZK[U0_nS^>P2ojFjj0Go
XKWZ0onO^^`5ooooo`03o`000?oooooooooo00kooooo000Yooooo`03o`000?oooooooooo02oooooo
0_nR_^d3ojO0j`CoY/?^0_nWb?43ojk8k@;o/Lc^0_nc`nH3okG2i003ojnegOn/[MSo[:gH00;o[:gH
0onXYM<4oj6KcP?oVI791?n@QlH3ohIoa0?oOWc60omcOLh2ofN<hP;oboWX00?o_lgUok2egOn`]Md0
0_n`]Md3oiZIdP?oPGo80_maKl42of5V`@;oNFRc0_mZG:l3oeME]0;o@fWB0omPEk401?maM/Soh_7I
ojfdgOn]]=d3oh63c@03odmK_omlN/GoG5Ve00;oG5Ve00?o?TJboemJ]OmPEJh00_mPEJh2ofmT]@Co
/J7800CoZMYeon3=aOoPcLGo_J:m1?nTQkH2oh=_]003obE5^omTDj[oI5>Z00;oV7:V0onEJYh01?nF
JYko/H:Rok62X_naPZ83okR;YP;omLjU00?o0000oin5]onOQKL00_lH;ZT01?l008Co5d>ooibhk?nL
^>`3oj25]PCoWWb]0_nKO:l2ojj:[`Co]YJf00CobjJcol^d`oo;]<?obkC30ooL`Kh00ooWc;_of=3B
om[@c`02om[@c`;of<o@0_nW^^L2ojBbh`?oIi3U0_lMK]l2o`1Uf@?oGZCe1?nH/^X4ok:bf@04ok^`
conj]=?o^[CCokZdd`?o`;?=0_o1]m43olBfc@;oa[_@0_o5^Ll3olJndP;oa;cB0oo6`MD2ol6me`;o
`/7I0onl_]/01_nl`Mko]KgPokFmh?ne_N3o0000okK0hPGo[kcS0_nY^^D2ojVkiPCoYK[X0_nQ^NX2
oj>kjPCoXK_/1?ooool00ol0003oooooooooo`0>ooooo`00:_ooool2o`00037ooooo1?nW`>/2ojK3
kP;o[<C[0on^b>d2ok73i`Co/l?V00Co]L;TojnegOn_]Mgo[kGM1?n/[MP3ojRUd`;oXI_>00CoUY_G
ohfFeon=U]OoSIKG1?n7UMX4oh2IhPCoOj_a00CoNlcooj3edOo;nNSoboWX0onocND4ok2eg@;oVYWB
0on1OlP3og5_`@?oHFK10omZG:l2oeME]0?o@fWB00?oTnk2olgLi?o=g>@00on]]=d3oh63c@;oCe^o
00?oO7[5oeaI]OmLFKD00_lnA[83of1E[P?oKfBe0_naXLP00onYfWGoh<g5on3=a@02okfR_@CoY8Nf
0_n3Kk@01OlUAK_oI5>ZofACZ_mTDj[oV7:V00?oUFZN00CoUVZNok62X_naPZ;o/H:R0_nhRjH3ooG>
Y@CoWhFg0_lH;ZT00ol008Co5d>ooibhk003oj25]PCoWWb]00CoVgb_ojj:[on^RZoo[XZ_0onfU[H3
ol^V/`04ol^d`ooL`Kkog<6nomc1_P;oilbk0_o/e;/01OoJd<oof<o@omS?d?oHcm3od/gD00CoY;;S
0omWT>D01?lfM=oo7FkOo`aUf_l0IMT2odRBk`04oejTmOnH/^[oV;;ZoiRbjP;o/[;I0_n[]=l5okZd
d`03ol2ccOo1]m7o`KOA00;o`KOA00Goa;K=olJkd?o6^m3oa[_@olFic`04olJndP03olBld_o6`MGo
a/7E00;oa/7E00?o`KgGol;1fOo2`MT00_o2`MT01Onl_]_o_<7Nokc1g_nl`Mko]KgP00;o]/3R00?o
0000okK0h_n__><00_n__><00on__^GoZK_VojVkiP03ojVkiP;oYK[X00?oY[_Xoj>kj_nS^nX00onS
^nX2oj6kk0;oXkc[0oooool00ol0003oooooooooo`0>ooooo`00;?ooool00ol0003oooooooooo`0_
ooooo`;oYl3[0_n[`NT4ojc4j`03ojk8kOna`nOo/L?W00;o/L?W0_nc`nH2ok2jh@Co[kGM0_n/[MP0
1?nRZM_oW:;IoibRfOnLX]T4oiJKe`?oSIKG1?n7UMX4oh2IhP;oOj_a00?oClc3okkkjOnnnnT00_o6
g^X4oko=i@;o/;GM00CoU9?@oh:3bon2Pl_oPX?;0_n1OlP3og5_`@?oHFK10omVN=43oeME]003od=Y
d_n5]oGocMcT00?ocMcT0on]]=d3oh63c@;oCe^o0_mLFKD2oci6/P;oAVG>0_mPEJh3ofmT]@03ok6Q
b?o_iLCoh<g500?o_J:m1?nTQkH3oh=_]004obE5^omTDj[oI5>ZofACZP;oUFZN00?oV76Uok62X_na
PZ800_naPZ82okR;YP?omLjU00Cocj:Zoin5]onOQKOoWX>f0_lH;ZT00ol008Co5d>ooaM3_`04oj25
]P;oWWb]00?oY8:_ojj:[on^RZl00_n^RZl3okJF]P?objJc0ooL`Kh3onO<^`;ok=Bk0ooHcm03om;=
e0?oY;;S1?mWT>D2ocIdg`;o36GJ0_m8T^l4ohJ/kPCoZkCO0_nj]=<2okRhf@Co`KOA00?o`KcFolJk
d?o6^m000_o6^m001?o7`MCoa[kBolJnd_o6_]82olO3eP?oa/7E00?oa/GIol;1fOo2`MT00_o2`MT0
1?o2aMgo_<7Nokc1g_nl`Mh2okc4h0?o]/3R00?o0000ojnlhon__^D00on__^D2ojVkiP;oZ[gW1?nV
^nP2oj>kjP;oY;cZ1OnS_>/3ooooo`03o`000?oooooooooo00gooooo000]ooooo`03o`000?oooooo
oooo02oooooo1?n[`NT2ojc4j`?o[l;X0_na`nL2ok2mi0Co/;[Q0_n_]Md00onW/=koXZWKoj:Yf`02
oj:Yf`?oW:;I0onFVmL4ohfFe`?oQiGJ0_n0VN83og;Fn`03oikdjOnnnnWo___Y00Coa]kZ0_nocND0
0onVY]KoU9?@oiBCd002oiBCd0;oPX?;0om[ML/2og5_`@?oHFK11?mVN=43ohFgm@;oeo;S0_o=g>@0
1?nWYmKoPhG=oh>5cOn3QLd3oh63c@;oCe^o0_m4F/@00omLFKGo?TJboci6/P03odIUcP;oKfBe00?o
S^ClonoUa?o_iL@01OnmX[d4ojB7]P;oPfnd00Co9DFkofACZ_mTDj[oI5>Z0onHLJD5ok62XP03okR;
Y_oecZGomLjU00;ocj:Z1?nNPkH2oaP^Z@03o`00Q?lG@kooQGBh00;oQGBh00CoX8Ffoiil[OnTPZoo
Y8:_1On^RZl00onfU[KobjJcol^V/`02ol^V/`03omni/OoL`Kkog<6n00;oilbk0oo/e;/00oo^fkoo
f<o@om;=e003om;=e0CoWjgQ0om_Sn82odMjg`;o86[L0oloR>/4ohJ/kP;oZkCO00?oY;GUokRhfOnh
^=T00onh^=T00oo1]m7o`KcFol6leP02ol6leP;oa[_@0oo7`M@00oo6_];oal?FolO3eP02olO3eP05
olK1eOo6aMWoa/GIolK5fOo2`MT01?o2aMd00onl`Mko_<CPokc4h002okc4h0;o]/3R00?o0000okG2
i?n__^D00_n__^D00on_`>KoZ[gWojZmi`03ojZmi`;oY[_X0_nW_>T4ojBljP;oXkc[0_nT_N/3oooo
o`03o`000?oooooooooo00gooooo000^ooooo`03o`000?oooooooooo02oooooo0_n[`NT2ojk1j0?o
[l;X0_n``>H4ok2mi0;o/;[Q00?oZ[GQojN`g_nW/=h00_nW/=h4oj:Yf`?oW:;I0onFVmL2ohfFe`;o
R;;a1On2`o`00ombe__o[_K`ojkfl003ol?Vk`;oa]kZ00?o];[NojJVe_nVY]H00_nVY]H3oiBCd0?o
PX?;0_m[ML/3of5je@?oHFK11?mVN=401?n5]oGoeo;SomObhoo2b=h4ojNWeP;oPhG=0om/L<D3odmK
_`;oA5[40_lnA[84odIUcP03ohkTo?o_iLCoknG400;of<S:1?nmX[d4ojB7]P;oPfnd00CoVWV]ofAC
Z_mTDj[oI5>Z0onHLJD5ok62XP?omLjU0_o?XZX01oo=XZcoWX>foij3]_nNPkKo<Cf^oaP^ZOl008@0
0_lG@kl3ohEd^0CoY8:_1?n^RZl01?nfU[KobjJcol^V/oo;Y[<2omni/@03omc1__oWc;_oilbk00?o
k=Bk0_o^fkl01?oZglOod/gDom;=e?oBcM@2ol[9f@CoWjgQ0om_Sn82odMjg`;o86[L0oloR>/3ogRU
k`CoY;GU0onh^=T00onf_=ko`KcFol6leP03ol6leP03olJkd?o7`MCoal7D00;oal7D1?o7`mH01?o8
bM[oa/GIolK5fOo6aMT2olK:g@?o`/GM00?o`LWPokc4h?nla>000_nla>001onkan?o]L;TokG2i?ne
`^Co0000okG2i?n__^D00on_`>H2ojZmi`;oZ[kX1OnW_>T2ojBljP03ojFmj_nT_N_oY;g[00?oY;g[
0_ooool00ol0003oooooooooo`0=ooooo`00;oooool00ol0003oooooooooo`0_ooooo`Co[/7X00?o
[l;Xok30i_n``>H00_n``>H2ok2mi003ojbji?nZ]N7oZ[GQ00;oZ[GQ1?nW/=h2oj:Yf`03oi^/h_nE
Z^CoUJ[T00;oUJ[T0on@ZnP4ohRbl@;oP/?l00CoVNWjojkfl?n^m_3o[_K`0oo3i^l2ok_8i@?o];[N
1?nVY]H3oiBCd0;oPX?;0om[ML/3of5je@;oFY_a0_mVN=401?nUm?3o]o_6omObhooGl^<3ol;8gP?o
YjOF0on3QLd2ofa`a@;oDfS:00CoCe^oodAJa?m4F/CoA5[40_m3P>D2odIUcP03odW5/_o_iLCoknG4
00?of<S:1?nmX[d2ojB7]P;oV7Z_0onJNJd3ofACZPCoV76U1?naPZ82oo[UZ`04ooG>YOo?XZ[ocJ:/
olfR[0?oWX>f0_la?Jh00ol008Wo01:NoaM3_`03ohEd^0CoY8:_1?n^RZl4ol^V/`;ogkVa0_o]b[00
1?oWc;_ok=BkoncD^oo/e;/2onkK_`;oj]o700?od/gDol[9fOo:bMT00_o:bMT2oin]h@04oiVXhOmb
T>7oLY3Qog:@h@?oAg[O00Go<W;Nob1Zg?m1Q>So@HCXocn8j`03ogRUk`CoY;GU00Co^;SIokJlg_nf
_=ko][cN0oo1_=H2ol72f`?oal7D0_o7a]T00oo7`mKob<WJolS9fP02olS9fP03olK5fOo6b]goa/[M
00;oa/[M00Go`/GMol79h?o1bN3o`LWPokc4h004ok_7h`;o]L;T00?o]<CVo`000?nda>H00_n_`>H2
ojk1j0CoZ[kX0_nW_>T2ojNmj@CoYKgZ0_nT_N/2ojFnj`;ooooo00?o0000ooooooooool03Oooool0
033ooooo0_l0000`ooooo`;o[/7X0_n_`^P3ok30iP03ojfni_n/^^Co[;[T00;o[;[T1?nZ]N42ojN`
gP;oX;3S0onK[>84oiFZi0?oT:_X0_n8/_42oiOHoP?oY^kh0onmi_<00oo3i^oo^lSUok_8i@02ok_8
i@?o];[N0_nVY]H01?nCWM[oPY7Joh:Af_n2TMX3ogR?g@?oJgG;0omQN]D00omJVo7oYOC`ojGdl003
olWhjP03olWOj?o2b=ko`/SN00;o`/SN0onWYmH2oh>5c@?oK7350omCJ<X3odAJa0;o@h3U00CoPnS:
on?ceooSlmOoh>WI1?oHb<X2okfR_@03oj27^OnHNZooV7Z_00;oV7Z_0onJNJd01?lUAK_oI5>ZofAC
Z_mTDjX3oiQaY@Co/H:R0_ojiJ/2olnRZP;ocJ:/1?nNPkH2oc4m[P03o`00Q?l04YkoQGBh00?oQGBh
0onTPZl4ojj:[`03ol2J/Oo;Y[?objJc00?ogkVa0_o]b[000ooefK3ok=BkoncD^`02onkK_`?oj]o7
1?o:bMT00onn`mkoVJSQoiVXh@02oiVXh@?oLY3Q0_mBOn000om7N]oo<W;Noc9bgP02od64j0?oKj7_
0_nT]ND2oijfj@Go][cN00?o`KcFol72foo1`]/00_o1`]/01Oo7`MCoalKIolO6fOo7a]WoalcN00?o
b<WJ00?oalkOolK:gOo6b]d00_o6b]d01?o5c^7o`LWPol79h?o1bN02oko<i0?o^lOS0_nibNH2okC4
iP03o`000?nbaNSo[/7X00Co[/7X0_nZ_^P00onZ_nWoYkgYojNmj@03ojNmj@;oYKgZ0_nV_NX4ojFn
j`03ooooool0003ooooo00kooooo000booooo`03o`000?oooooooooo02kooooo1?n_`^P01?n``>Ko
[KkVojfni_n]_^H4ojbji0;oZ[GQ0_nT]>@4oj2`h`?oVjcR0_nEZ^@2oiJol`?oU/Wi0onPh_`01?nV
k_So_NKcokgVlonmi_<3okgBjP;o^lSU0_n/]n44oj2[gP?oTigJ0on2TMX3ogR?g@?oL9SX0on2`od0
1?nFl^GobOSZolWhj_o9n>X3olWOj0;o`/SN00CoY:OHohfAd_n=TM;oSI7B0om]Nm02ofa`a@?oDfS:
1?mXWo02ol[Wj`;oho?G0_oPjMT2omS8bP04ok6ZdOnPQkWoX8Nioj27^@CoV7Z_1?nJNJd3ofACZP?o
V76U0onaPZ83oo[UZ`03olnRZ_o=XZcocJ:/00;ocJ:/0onNPkH2oc4m[P03o`00Q?l04Yko5d>o00?o
QGBh1?nTPZl2ojj:[`;o`9Za0_o;Y[<2omni/@?okLZ`0_oefK000oo/e;_ok]^oon[Oa`02on[Oa`;o
hn7A00?ob/WIokk3g_nn`mh00_nn`mh3oiVXh@CoLY3Q0_mBOn02od5jh@?oAhKX0om_XNl4oijfj@;o
][cN0_nc`N@4ol72f`04ol38h?o7a]WoalKIolO6f@?oalcN00Gob<WJolO>goo7c]ooalkOolK:g@04
olG>h@03ol79h?noc>Co_lcT00;o_lcT00?o^lOSokW9i_nibNH00_nibNH01?nda>Ko//GXo`000?nb
aNP2ojk1j0;o[L;Y1?nZ_nT2ojNmj@;oYkkY1OnV_NX2ojFnj`03ojJnjooooooo000000oooooo000c
ooooo`03o`000?oooooooooo02kooooo0_n_`^P2ojg1j@Co[KkV0_n/^^@2ojNhiPCoY;CT0_nP/><2
oibik0CoV[[_0onF_o<01?nFbOWoX>;loj3Ro?nPh_`2okCRmP;o^]O_0onmd^X00onc`NGo[;OQojbg
h@03ojbgh@CoX:_N0onCWMX3oh:AfP?oN8oM0om`V>P01On2`ogo]o3eokO`mOngl?GobOSZ00?obMoX
00?o/[cQojBWf?nTYmP00_nTYmP3ohfAdP;oKG_@0om`PmH3oe=XbP04ofROl?o:in_ob^O[ol[Wj`;o
ho?G0_oPjMT00oo8g^Wo/J[Aok6Zd@02ok6Zd@?oX8Ni0onHNZl4oiYi[@?oI5>Z0onHLJD3ok62XP;o
n^F[0_o?XZX4olfR[0;oWX>f00CoXXo0oc4m[_la?Jko00:C0_l04Yh3ohEd^0CoY8:_00?o[XZ_ol2J
/Oo0V[400_o0V[400oo;Y[?ogkVaomni/@02ong:/0?omMV`00Con>JaonkK_ooZglOoj]o70_oShM43
omOMg0;o_/?N00?o/[gRoi>UhOnCYN400_nCYN43ogFBh@;oG8GR00?oDWoPod5jhOm1N^400om7Q^P2
ofbPl003ofnQkonN]^WoW[KY00;oVKS]1?nc`N@00oo1`]_o`<SPol38h002ol38h005olO6fOo7c=ko
alcNolO<g_o5d^@00oo7c]l2olKCi0?oaLkQ0oo3d^H2oko<i0;o_LoX0_nibNH2okK;j@?o//GX00?o
0000ok36j_n]`^T00on]`^T2ojZoj@;oZKoZ1?nW_^T2ojJmjP;oYkkZ1?nV_^/00ol0003ooooooooo
o`0=ooooo`00=?ooool00ol0003oooooooooo`0^ooooo`Co[L7Y0_n]_^H2ojRlj0CoYkSV0_nT]>@2
oinij`CoW;W/0_nJ^^l3oic=n0;oWMKl0on]foL00ondh_Ko^]O_ok[Gk`02ok[Gk`04okgBj_nc`NGo
/l7Uok?1i@Co[;OQ0_nPZmh2oiBVhP?oRZ;T1?mmXn/4ogffn004ohOHoongl?Go]o3eokO`m@?oa>c`
00CobMoXok:lhOnb_>7o/[cQ0onTYmP3ohfAdP?oKG_@0om`PmH4ohbWi`03ol[WjooSlmOoho?G00;o
h>WI0oo8g^T3ok6Zd@?oX8Ni1?nHNZl3oiYi[@03oj>6]_mTDj[oI5>Z00?oV76U0onaPZ82oo[UZ`03
omVZY_o?XZ[ocJ:/00?ocJ:/1?nRSl02oc4m[P;o01:N0_m_JK`2ohEd^0;oY8:_00?o[8feol2J/Oo0
V[400oo0V[42omni/@?okLZ`0ooefK001Oohi[7omNjgooG^]oo_mL?ohn7A00CoemgL1?nb_N84oi>U
h@?oMI;Q0_mLQN83od5jh@;oCh_Y00?oAhKXofbPl?m/X?001OnI^>d2ok?1i0;o/<GY0oo0b>001?no
c^GoalcNolO<g_o7c=h3olGBi003olO>goo6dnCoa]?T00;oa]?T00GoaLkQol?Bi_o3d^Ko`m;VokoE
jP03okg?j0;o^M3[1?nfbnT01OnbaNSo/<KZok36j_l0003o/<KZ00;o[L;Y00?oZl;[ojVoj_nY_nX0
0onY_nX2ojNnj@KoYkkZ0_nV_^/00ooooooo0000ooooo`0>ooooo`00=Oooool2o`0002oooooo0_n]
`NT3ojW0j`?oZ;cX0_nW^>H2oj:kj`CoWkW[0_nL^N`2oic6m@?oW<gh0onXe?L2ojgKm`?o]]Oa0_nj
enl2okG7j0Co/l7U0_n/]n42oj6^h@CoU:KR0on:X^@4ogfSj`;oOKKh0onLg?d00ongl?Goa>c`olC/
l002ok[?jPCo/[cQ1?nTYmP3ohfAdP;oKG_@1?m`PmH2ohbWi`;o_^;a0ooBm>L2olOjj0?ob=kY0_na
Z]43oj27^@CoV7Z_0onJNJd2ol:H[003ofACZ_nHLJGoV76U00;oV76U00?o/H:Roo[UZoojiJ/00_oI
ZZH5olfR[0CoXXo000?o;DNkoc4m[_l00Y<00_l04Yh3ofmY_004ojB2[on/SKGo[8feojb=]@Co`9Za
00?oeK:fomni/Oo]b[000_o]b[02ooGI/0;on>Ja0_oek[L00oo_mL?oi?KEomOMg002omOMg0;ob=KT
1?nb_N82oi>Uh@04ohjShomfUN?oMYGSogJEh`?oG8GR0_m>Pn@00om1N^7oCh_Yodn;j@03offRl@;o
VKS]0_nF^_45ok35j@05ol38h?noc^Go_lkUoko>iOo7c=h00oo5d^@2ol?Gj@?oa]?T0_o3enT00oo3
d^Ko_mGZokoEjP02okoEjP03okg?j?nid>_o^M3[00;o^M3[0_nfbnT2ok?;k0;o/<KZ00?o0000ojg6
k?n[`^/00on[`^/2ojVojP;oZ;oZ1_nW_^X6ooooo`03o`000?oooooooooo00cooooo000gooooo`03
o`000?oooooooooo02kooooo0_nY`>/2ojBok0CoXkg/0onR^n/2oinij`?oW/;a0onLa_D01?nLcOSo
Z=CgojSDmonXe?L2ok3ClP?o]]Oa0_nfbnX4okG7j0;o/l7U0_nY]^84oj6^h@?oU:KR0on:X^@2ogfS
j`?oS/Kj0_nLg?d2ojkZn@?o]]Wb0onjcnX2ok:lh@03oijRf?nCUM;oTiGB00;oTiGB0on5S=<3og::
f`;oL8?F0on9[nl01?nnh_7od_CWom;diooBm>L2olOjj004oio_m_mm_ocoOKologfoo0?oIX;J0onP
QkT3oiQj[`;oVWV]0_n/Qjh00oo2V:coI5>ZofACZP03oiQaY@03ok62X_ojiJ_on^F[00;ofJZV00Co
g;2YolfR[?o=XZcocJ:/0_oC[[@3oj:?`0;o;DNk00?o00:Co`00SOl04Yh00om_JK`4ojb=]@?o`9Za
0_oE/[H00ooO^K7okLZ`ong:/003ooGI/003ooSV/Ooek[OomNjg00;okoG30_oTm]D00ooGgMcob=KT
olSFi002okO:j@?oY[KT1?n>Xn<3ogJEh`;oHhgU00?oG8GRodj3i?m>Pn@00omHT^`4offRl@?oU[[a
0_n`aNT3ojk:kP;o_lkU0onmdn/00oo5d^Co`mOYol?Gj@02ol?Gj@03olKCi?o3enWo`mOY00;o_m_]
0onoeNX2ok_GkP;o^M3[0_nedNl3ok?;k006ojo;k_n]a^co[LK/ojg6k?l0003o[LK/0_n[`^/2ojW2
k0CoZ;oZ0_nW_^X9ooooo`03o`000?oooooooooo00cooooo000hooooo`03o`000?oooooooooo02ko
oooo1?nT_n`2oj>mk0;oXKo^1?nO`?02oik2l@;oXlSc1?nTcOD00onXe?Oo/=?bok3ClP02ok3ClP03
okKGlOnfbn[o]/_Z00;o]/_Z0_neanP2ojjli0CoZKKR0_nQ[^42oi^ejP?oTK?^1?n>^O<2ohk6nP?o
W]km00Go[^[iokKIl_nffO;o]]Wbojc1j@04ojNbh0?oWZ;H1?nCUM83ohF<d`?oLX[K0on9[nl3ojgO
n003om;dioo7n^SoWnof00?oWnof0omm_o`2ofJ2fP?oOgJo0onHNZl01?nJNJgo[8N^ojb7[_n/Qjh2
ol:H[005ofACZ_nHLJGoV76UoiQaYOnaPZ800ooIZZH2omb`Z@?ocJ:/0_oC[[@4oj:?`004obe7^ol0
0Y?o00:Co`0BWP?oKfVl1?n/SKD2ol2J/@?oeK:f00?oj<biong:/?o]b[000_oefK000oohi[7omNjg
ooG^]`02onoe``;oi?KE0_oEl>D00oo8e^Co]l[YokO:j@02okO:j@?oY[KT0on>Xn<4ogJEh`;oHhgU
0omHSNT3oeRBk0?oL:Oc1OnD__@2ojk:kP03ojc?l_nmdn_o_M?[00;o_M?[0_njf>l2ol?Gj@?o`=c]
00?o`mOYokoKkOnofnd00_nofnd01?noeN[o^mO^ok_Gk_nff?85okGAk`04ok?;k?n_bnko[l_^ojo;
kP;o[LK/00?oZ/G^o`000?nY`^`01?nY`^`2ojRojPcooooo00?o0000ooooooooool03?ooool003Wo
oooo00?o0000ooooooooool0;_ooool2ojBok0;oX[k]1?nQ_nh2oio0l0;oX/Ca1?nSb?<2ojC=m@?o
[<ob0_n`do83ok?<k0;o]/_Z0_na`NH4ojjli0;oZKKR0_nS^>P4oi^ejP?oTK?^0_n>^O<3oiKAo0;o
W]km0on^foL01?nffO;o[<7Yojc1jOn/`NT4ojNbh0?oWZ;H0onCUM83ohF<d`CoLX[K00GoRJo_ojgO
n?n]goSo[MohokWfl002ok_ik@;o^?Ga0oncj?L00ol=SN;o06OGofJ2fP02ofJ2fP;oOgJo0onDN[<4
ojb7[P;o`YR/00Cocj6XoiQaYOnHLJGocj6X1?oIZZH2omb`Z@;ocJ:/0ooC[[@2oj:?`0;oYJ7A0_lV
FLh00ol00Y?o002=o`0BWP02ofmY_0Go[8fe00Co`9ZaomFb]_oE/[KoeK:f0_oXc;T01Oo]b[3omMV`
ooGI/?ohi[7omNjg00;okoG300Coi?KEomG`iOoEl>GoeO3U0oo2hNh2okO:j@03ojVoj_nL/NKoW;7V
00;oW;7V0on:XnD3ogRIi@?oJICX0omHSNT2of2Kl004oeRBk?m`Yo?oL:Ocog2Wl`;oU;kd0_nCa?L4
ojc?lP04okgCjonjf>oo^]S_ok[Hk`;o]mgc0oo0g>d2ok_OlP;o_m_]0onjgO401?nkenko]]SbokKH
l_nff?82okGAk`?o/=7a0_n_bnh2oj_:l0?oZ/G^00?o0000ojW2k?nY`^`04?ooool00ol0003ooooo
ooooo`0<ooooo`00>_ooool2o`0002oooooo1?nR_^d2oj6okP;oX/7_1?nRa?42oj?8l`?oZL_a0_n/
co83ok3:k@;o/lc/0_naa>P4ok71iP;o[[cT0_nY_>L4oj>hj0;oVkGZ0_nK`_<4oiG6n0;oU]7l0onU
f?X2ojkKm`?o[Lg`0on/`NT2ojNbh004oiFNf_nBV=KoTYSFoi:HeP?oSiOG1?n?Wmh4oi2ck`03ojgO
n?nim_3o^OK`00;o^oW]0_nhmO43ok?Xm`03ojgFmOl0K=Go06cE00;o03:i00?oIX;Jogmf_omoM[l0
0onDN[<5ojb7[P03ol:H[?o?XJSocj6X00;ocj6X00CofZfYomVZY_oIZZKofJZV0ooL/:T01?o=XZco
djjdom>^]?oC[[@5ojFQd@;o9UW>00?o00:Co`00SOm_JK`00_m_JK`3ojb=]@04ok^T`ooE/[KoeK:f
omFb]P?oj<bi0_oei[T01Ooam[7ohOV/olgi[_o=nJkoaOg500;o_?gO00GoeO3Uol;Qk_o2hNko`^7^
ok7?l004ojVojPCoW;7V0on:XnD3ogRIi@?oJICX0_mRUnd01?mHSNWoH9_`of2Kl?mPVo04ogB^mP?o
TlCg0_n/co83oj[DmP03ok[HkonggO?o]mgc00;o]mgc00?o`=c]ok_Ol_nkgo800_nfhOD2ok[Ml@?o
]=ke0_nff?83ok3Hm@;o/=7a00?oZ]3doj_:l?n[b_000on[b_02oj[5kP03o`000?oooooooooo013o
oooo00?o0000ooooooooool03?ooool003cooooo00?o0000ooooooooool0;Oooool2oj:nk@;oXko]
1?nR`Nl2oj;4l@?oYlK`0_nYbo42ojg8k@?o/<[]0_naaNT4ok74j0;o/L7V0_n]_nL4ojVli`;oXkSX
0_nQ`>l4oi_2l`;oULKh0onPdoT2ojGHnP?oZM?f0_n]cO001?nR]^OoW:[PoibZh?nLZ^04oiFNfP?o
TYSF0on?UmL4ohnOgP;oT;?_0_ncfo@2olc/j`?oenkS00?of^CMok?Xmon]e_D00on]e_D2o`1/e@;o
03:i0omoM[l3oiAj/`Co[8N^00Co`YR/olnQZ?o?XJSocj6X0_oJ[JT2omVZYPCog;2Y1?oC[[@00ooI
`<7oYJ7AojFQd@02ojFQd@;o9UW>00Go00>Fo`00Q_mHJL[oF6W:ofmY_002ojb=]@;o^jC30ooE/[H3
onS<^@;omNJi00ColOJaon7i[?o=nJkoaOg50_nloMl2okGam@03ol;Qk_naco3o/Lo`00;o/Lo`0onY
_nX2oibaiP;oUZgV0on8Y>H3og^Nj@CoJICX0_mRUnd4ofRUl`?oNKKi1?nCbOX2oj[DmP?oYmWi0_ng
gO<3ok;Pm`03ok_Ol_nfhOGo]^7e00?o[n;h0_ndg_D2ojgMn0;o/=Se0_nYe_L4oj[@m0;oZl[`1Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo000mooooo`03o`000?oooooo
oooo02gooooo1?nS_nd2oj;1k`?oY/?^0_nWa_02ojc6k@Co[LS]00?o/<[]ok75jOnaaNT00_naaNT2
ok74j0;o[/;X1?n]_nL2ojVli`?oY/7/0onQ`>l2oi_2l`?oXLoh0_nPdoT3ojKEn0;oZM?f0_nT`Nh3
oj:fi`?oW:[P0onEW]X4oi:HeP?oSiOG0_n?Wmh3ojJkj003ok?Km?o<k>_oc>c[00?oenkS0_oJi=d2
omSIf@;o[MKe0onYa>d00ol0ImWo03:io`0b^@02ogmf_`?oU7Zc1?n/Qjh4olnQZ0;ofZfY0_oIZZH4
omb`Z@03onFo/OoC[[Codjjd00?ofL310_nUXM42ojO5k`04o`E^gOlVFLko00>Fo`00S@;oF6W:00?o
[8feok^T`onkY<<00_nkY<<01?oE/[Koj<bionS<^OoXc;T2ooGV^@04oo7f/OoQnJcocOV^olGma@;o
QNW^0_nelOD3oj[Kn@;o/Lo`0_nT_n`3oijej0CoUZgV0on8Y>H3og^Nj@?oL9g]0omZX_84ofRUl`?o
NKKi0_nCbOX3oi??o0;oYmWi0onTgO/2ok;Pm`;o[N?i00Co]^7eojoRn?n_h_So[n;h0_nXh_X2ojgM
n0?oY]cj0onYe_L2oj[@m0Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<oooo
o`00?_ooool00ol0003oooooooooo`0]ooooo`;oXko]0onV_n`2ojK3kP;oZ/?/1?n/a^d2ojg8k@?o
[lGZ0_naaNT2ojo3j0Co[/;X0_n]_nL3oj[1j`;oY/7/0_nWb_84oj;<m@;oXLoh0onTeOT2ojKEn0;o
YL[c1?nT`Nh3oj:fi`?oW:[P0onEW]X3oi:HePCoVjCK0onV^nP3ol7Bi`;od]cO00?oenkSom[TgOoJ
i=d00ooHfMT2om;<e0;oZLC]0_nY^>@2o`0b^@03odYMaOmoM[ooU7Zc00;oU7Zc1?n/Qjh01?njUK7o
cj6XolnQZ?o?XJP3omZ]Z@04omVZY_oL/:Wog;2Yomb`Z@;oiKna00?odjjdomW0`OoI`<400_oI`<40
0ooPh=CoYlG_ojO5k`02ojO5k`;o1FkM00?o0026oeQYb_mHJLX01OnkY<<00ooE/[Koj<bionS<^@02
ooGV^@03oo7f/OoQnJco000000?oQNW^0onCgOh2oj[Kn@03oj75l_nT_ncoY;o/00?oY;o/0onN]NP3
oiJ]iP?oR:CV1?mkW^T3og2Mk@CoJZ;b0om`[oP3ogfno0;oTlol0onCe?h2ojCMn`?oX=ol0_n]hoT2
ojOSn`04ojoRn?nXh_[oZ>;jojSRnP;oXN3l0_nVg?X@ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03?ooool003oooooo0_l0000_ooooo`;oY[o/0_nY`>X4oj[3k0;o[<K]0on^a>X2
ojo5jP;o[l?Y1?n_`nP2ojk2j0?o[L;Y0_nZ`N/2oj[8l0CoYl[b0_nRc?D3ojGCn0;oY=Gi0onVcoH3
ojG:l`;oY<7^00CoVJoVoiJTgonFY=ooUZCO0onBVmT3ohjEePCoTYSF1?nKY=/01?nV^nSo`M;Wol7B
ioo1d^L2om;Lg`;of]WF00Cof^CMomSIfOoHfMWof=WI0ooBc=@00oo=`]3oZKSTojVhi002ojVhi004
o`0b^Om:GLGoBUg5ogmf_`?oU7Zc0_n/Qjh2okZE/@;ocj6X1?oJ[JT4omb`Z@;oiKna00CokMJlomW0
`OoI`<7ofL310ooPh=@2ojO5k`05oi?RoOmghO3oMn7`og7Ojol008H00_mHJLX4ok^T``;ocl[E00Go
j<biooGV^Ooei[WolOJaoek5o002ogCCoP;oSL?i1?nHa_L3oj75lP;oY;o/0_nM/nL3oiV_iPCoTj_V
0on9Y^P3ognUj`CoMjK`0omc[OH4ogNinPCoPLKm0_nCe?h2oi?HoP;oX=ol0onLhOd2ojOSn`?oXN?l
00?oZ>;joj7Po?nQh?`05?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo
0011ooooo`03o`000?oooooooooo02gooooo1?nY`>X2oj[3k0;o[L?Z0on^a>X6ojo3j@;o[l?X0on^
`nT2ojg2j@;o[<O]1?nZb?02ojO:lP?oZM7e0_nUdoP3ojSBmP;oY/of0_nRaO43oifkk@?oVJoV0onF
Y=l3oi:Kf@?oSYGF1?nBV=H2oi^Tf`?o/KSN00?o`M;Wom;LgooBg=l00ooJfMH2omcCc`04omSIfOoB
c=Cod/cDom;<e0?ocL;@0_nY^>@00on[/McoC8SYo`0b^@02odYMa@?oU7Zc00Co[8N^okZE/OnjUK7o
^YFa0_o?XJP4omZ]Z@03onBk[OoL/:Wog;2Y00?oiKna0_o]e[`01OoI`<7oh>3Don3Pe?oPh=Coe?[Q
00;o]ocQ00GoYOOTok3bmOn`l_Go/?;eohkSo002ocafg`?o^jC30oo?b]D00ooJn=komNJiojod]P04
ohJmn@?oSL?i0_nHa_L2oiVek0?oW;KZ1?nM/nL3oiV_iPCoTj_V0on9Y^P3ognUj`CoMjK`0omc[OH2
ogNinP?oO/;m0on5cOl2oi?HoP?oT]_n0_nLhOd2oiWQo@;oXN?l0_nKh_dHooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool02oooool004;ooooo00?o0000ooooooooool0;Oooool2ojW0
jP;o[<7Y1?n]`nX00on^a>[o[l?Yojo3j@04ojo3j@Go[/?Y0_n^a^`4ojc7k@;oZ/S`0on[co82ojWA
m@?o[=?d0_nXd_H2ojK<l`CoX/Ga0onM^nd3oiV_iP?oUZCO0onBVmT3ohjEeP;oTYSF0_nMXmX3ok6h
gP;oa<GK00Cod]cOom[Ie_oJfMKof]WF0ooLdll2omW:b`05om;<e?o=`]3ocL;@olg2d?o8^ld01?n[
/M`00ol0<[WoBUg5odYMa@03ohem_@Go^YFa00Cocj6XomZ]ZOoJ[JWofZfY0_oT^jd2omb`Z@;oiKna
0oo]e[`2ongcb005on3Pe?oDn^7o]ocQokOlhOnUmn@00on`l_D2okGRmP04o`00Q_llM]oo?7KOok^T
``?ocl[E0_oJn=h01?n_m;KoS;cfohJmnOn6_OT2oi>_jP?oUK?/1OnI]N`3oibfjP;oWK?W00?oVjcS
oiR[i?nHZn@00_nHZn@3oi>ZiPCoSJ[Y1?n5Znh3ogn`l`?oO;Oh0_mn`_d3ohK9oP?oR]?o0_nBfoh3
oi?MoP;oVN7m00?oUn7mooooooooool06oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo0013ooooo`03o`000?oooooooooo02gooooo1?n/`NT2ojg3jP?o[/;Y1?n_`nT5ojk3
j@Co[/K/0_n/and3ojk=l0;oZlob0on^d_82ojcCm0?o[=3c0onVc?<2oj;5l@04oiZfjonBZ^OoTZ[W
oi:Zi`?oSJ3P0on;V=/3ohbDe`?oSiOG1OnMXmX01?na^=koa<GKolC5foo4aM/2om7:d`04om[Ie_oL
dloog=??omcCc`?ofL[;0oo=`]03olRkc@;oZk7L00?o[ZkGog2Hj?m:GLD00_m:GLD3ohem_@Co^YFa
1?oJ[JT3onBk[@03omb`ZOoU_k7oiKna00?okMJl0_o]llP00oo@olKo/?S5ojGgdP02okOhkP;o_>Oc
0_neh_H2okC9jPCo?7KO00Cocl[Eom[hg_oJn=ko[oBf1?nH[nL3oi>_jP?oUK?/0_nI]N`2oiZZhP?o
VjcR1?nK[><4oiR[i0?oTj[V0_n=Z^T2oi:^j@?oSK;_1?n9^?D4ohK0nP;oQ/Wn0_n>d?h2ohoGo`?o
U=_n0_nDgohPooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool004Cooooo
00?o0000ooooooooool0;Oooool2ojc1j@?o[L7X0_n^`^T2ojo2j0Co[l?Y0_n^`nT3ojo5j`;o[/K/
0on_b^h2ojk=l0?o/=3`0_n^d_82ok3Al@;o[=3c0_nZanl4oj70kP?oV[K[0onBZ^L3ohfPh0?oRiSK
0on<U=L3ohnGe`;oWJ?J0_n]/=X3olC5f`?odL[C0_oGblh00ooLdloofL[;omW:b`02omW:b`03omK4
b?o=`]3ob;_=00?ob;_=00OoZk7Lojj^eon^[]Oo[ZkGog2Hj?l08jooBUg500?oSGfm1?njUK44omZ]
Z@?oi;^]0_oU_k43ongF_0;okO?800?od?o6ok3haOnUmm800_ngn>h2okcWl`;o^/kY0ondbNX00on`
^=ooZ;?QojRch@02ojRch@04om[hg_nO/>CoWk3Toin`i0;oV:oW00?oW:CKoiVUg_nIYMh00_nIYMh3
oiVWh0CoVZ[R0onK[>84oi^/h`;oV:_T00?oVZ[RoiN/iOnG[>D00_nG[>D4oi:^j@?oSK;_0_n9^?D2
oi>om@CoT<Oj0_n>d?h3oiODo@;oU=_n9?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo0015ooooo`;o0000;oooool2ojg1j0;o[/7X1?n_`^P2ojo3j@?o[lCY0_n_aN/2ok38
k0?o[l[^0_nbcNh3ok3@l0;o/m7_0_n`dO42ok3<kPCoZ/O_0_nQ`>h01?nI]>[oT:WVoi2Yi_n@ZNH3
ohNMhP?oQ9GL0on;V=/3ohbDe`;oSiOG00?oVIkGojf`f_n]/=X00on]/=X00oo4aM_odL[Com7:d`02
om7:d`;oel_>00Cof<O9omW:booIb/_ofL[;0_oFa<P01?oC_lKob;_=olRkcOo8^ld2olJgb`Co[ZkG
00?oL9SXo`0S[on=OKd00_n=OKd4okZE/@03olRY^ooJ[JWofZfY00Coi;^]00Cokm>fonFo/Oo]e[co
kMJl0_o]llP01?o@olKoRNVnojohjon_n>/2okgZl`03okcWlonjc^Wo^/kY00;o^/kY00Co]<WZok2h
gon`^=oo/;SO1?nX/n42oin`i003oj6Uf?nLY=_oW:CK00;oW:CK1?nIYMh3oiVWh0?oVZ[R0_nK[>82
oibVg@?oW:SO1?nJZ^84oiN/i@;oTZkY00?oVK;YoiJhkonF^>l00onF^>l3oi>om@;oT<Oj0_nJcOT2
oiODoBWooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`00Aoooool00ol0
003oooooooooo`0]ooooo`Co[/7X0_n_`^P3ojo3j0;o[lCY0_n`a^X4ok38k003ojo:k_nbcNko//g^
00;o//g^00?o/=3`ok?AkoncdNl00_ndcNd4ok3<kP;oZ/O_0_nU_^/3oiVdjP?oT:WV0on7WN82ohBE
g0?oQI;H0on<U=H4oiVNe`?o[K3J0_nl^]P3om7:d`?oel_>0_oHalT01?oIb/_oe/C8omK4b?oFa<P2
om>oaP03olRkcOo6]l_oa[O;00;oa[O;0_n^[]L2ok:^e0;o02>_0on=OKd2okZE/@;ob:Vk0_oJ[JT3
onBk[@;okm>f0_obl;d01Oo]e[cokO?8ohWY__n9jKko[oS[00?o_N[c0onmdNT2ok[>j@03okJlg_n`
^=oo/;SO00;o/;SO0_nX/n42ojNXe`CoXJGH0onLY=/2oiVUgP;oWIoF0onLXMP4oibTf`CoW:KM0onL
Z=l2oiZZhP;oWZ[O0onL[^@4oiVbj@;oU[S_0_nO_>d4oig4m0;oV/gi;?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00_ooooo0018ooooo`03o`000?oooooooooo02gooooo0_n^`NP2
ojo2i`?o[l?X0_n`a>P4ok36jP;o/<S/0onbbn`2ok;=kP;o]<o]00?o/m7_okC=kOndcNd00_ndcNd2
ok3<kP?o[LG[0onU_^/3oiVdjP?oT:WV0on7WN82ohBEg0?oQI;H0on<U=H4oiVNe`03ojf`f_nl^]So
_;[H00;o_;[H00CodL[ComO;c_oGblkoel_>0ooHalT3omK4b0?odko61Oo6]l/00oo5]L_o/ZkDok:^
e002ok:^e005o`0S[omkRMKoNhWFog^9e_njUK401?o8ZK/00ooJ[JWoi;^]onBk[@03onoC]P;ol_2m
00?oe?beod6oZon@kNl00_naiOP2okS@k0?o_M7Y00?o^;oOokJlg_nf_=h00_nf_=h2ok2hg`;o[J_F
1?nWZ=L3oj6Uf0;oW:CK00?oWikCoifOe_nMWmH00onMWmH3oibQf0CoW:CK0_nLY]d00onOY=WoWjOL
oinWg002oinWg0CoWZ[O0onL[^@2oiVbj@;oXKKW1?nO_>d2oig4m33ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0;ooooo`00BOooool00ol0003oooooooooo`0]ooooo`Co[l;W00?o
[l?Xok34j?n`a>P00_n`a>P2ok36jP?o//SZ0_nbbn`2okG<j`;o]<o]0onfcN/2okC=k@?o/lSZ0_n]
aN/2ojRmj0?oW[CX0on@ZNH3ohJNh`;oO9CO0ommT=/3ohFBf0?oS9CF0_nIW]L2ojJXf0?o_;[H0oo7
`=@00ooGblkof<O9omS7b@02omS7b@03omS4aooFa<Sodko600?odko600Cod;c6olJgboo6]l_oa[O;
0oo5]L/2ok:^e003okJ`donMZ^3o02>_00;oNhWF1?o8ZK/01?oFb<coi;^]onBk[OoT^jd2onoC]P?o
l_2m0onTfOX00onaiOSo^=3/okS@k002okS@k004okgAjOnh_moo^;oOokRog`;o][cN0_na[mH4ojf[
eP;oYjSG00?oYZ7@oj:Od_nRWm800_nRWm83oinNd`CoWIoF0onLXMP2oibTf`;oWj7F1?nOY=T4oinW
g0;oWZ[O00CoXjcNoj:`h_nR/>;oX[3R1OnQ]^L2oinlkCCooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`00B_ooool2o`0002kooooo0_n_`^L3ok32i`;o/<CX0_nbaNP3ok;8
jP04okG9jOnec>_o]Lc[okG<j`?o]l_Y0_nfcN/2okO:j@?o/lSZ0_n``^L4ojRmj0?oW[CX0on@ZNH3
ohJNh`;oO9CO0_mmT=/3oh>Af@CoTY[H1?nVZ=P00onl^]Soal3DolO0e002olO0e004olg2d?oHalWo
f<O9omS7b@;of<C700Coe/;6om>oa_oC_lKodko60oo@_<H00oo6]l_oaKG;olFeb`02olFeb`Co][3C
00CoWJ[Pog^9e_mkRMKoNhWF0_o8ZK/3omK8c003onBk[Oo_dkKokm>f00?ol_2m00?oW<WgojCIn_nT
fOX00_nbb^`2okS@k0?o]koQ0_nh_ml2okBbe`Co/JoF0_n]ZmH00onZXm3oYZ7@ojJQd002ojJQd0Co
XYoB0onOW]<2oifOeP03oinLdOnOW]?oWikC00;oWikC1?nOXMH3oinTf@;oWjOL0_nSZ=X4oj>/gP?o
X[3R0_nQ]^Liooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool004cooooo
00?o0000ooooooooool0;?ooool3ok32i`;o//;V1?nbaNP01Onbb>[o]LWYokG9jOnebNWo]Lc[00?o
]l_Y0_nibNL4okO:j@03ok?8j_n``^Oo/<;W00;o/<;W0_nX_NP00onR]^KoUZcVoiJ/iP02oiJ/iP;o
Qj7T0ommUn43ogF>gP;oOI3K0on3TMT4oi:Jf0;oYZSH0_nb/MP3olO0e0?ocL;@00?of<O9omS4aooH
a<L00ooF`/H00ooC_lKod;c6om2laP02om2laP04oljkb?o5]L_oaKG;olFeb`;oa;K<0_nf/=<2okZc
d`04ojV_g?lcSnoo<ho_olRY^`Coe/S<0_oGmn801?o_dkKol_2moo;`_OnLbOL2ojc2j@;o//[/0_nd
_^43okNoh@03okBdfOnd/]Oo];;G00?o];;G0_na[mH00on]Y]7oZZ?@ojZSd002ojZSd0CoYZ7@0_nR
Wm801?nSVlgoXI_?oj6KconQVll4oinLd@CoWikC0onOXMH2oinTf@;oXjCG1?nSZ=X3oj>/gP;oX[3R
??ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo001=ooooo`03o`000?oo
oooooooo02cooooo00?o/<;Wok;2i_nb`^H00_nb`^H2ok;5j0?o]LKW00Go]LWYokS9ionhbNOo^<WW
okO;j@04okW9i`;o]l[Y0oneaNH2ok32i`;o[;cV0onR]^H4oiJ/iP;oQj7T0ommUn42ogF>gP?oNHkL
0on3TMT2oi:Jf003oiZRf_nb/MSo/[7H00?o/[7H00Coal3Dolg2d?o=`]3ocL;@0_o@`ld00ooHa<Oo
e/;6omK2aP02omK2aP04omC0a_o@_<Kod;c6om2laP?oc[_800GoaKG;olBfc?o4]/coa;K<okJ`d`04
okZcd`03ojV_g?lcSnoo<ho_00?oe/S<0_oGmn800ommh;3oW;_^oj^ji003ojc2j@;o/K_P1?nd_^40
1?ng_n7o];CIokBdfOnd]=T3okBbe`03ok2Zd_n]Y]7o[JKA00;o[JKA1?nZXm02ojJQd004ojFMcOnS
VlgoXi_=oj>Kc@CoXI_?1?nOW=42oinNd`03oj:NdOnSXM?oXj7C00;oXj7C1?nSY=L2oj>XfT?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`00C_ooool00ol0003ooooooooo
o`0]ooooo`;o//;V0one`n@2okG6i`;o^<KU0_nhbNL3ok[8i@;o^LWW0onia^D2okG5iP;o/l7T1?n/
_>H3oj:fiP;oUZcV00CoSjKUognKi?moVnCoOi_T0ommUn42ogF>gP?oNHkL0on5UM/3oiZRfP?o/[7H
00Co_;SFolg2d?o=`]3ocL;@0oo@`ld01?oA`lcoe/;6omK2a_oF`/H3omC0aP05om2la_o>^lSoc[_8
oljkb?o<^lX00oo4]/`2olBhcP?o^[?C00?o_;KDok6cf_na/mX00_na/mX01?oFb<coeoORomOgh_n`
]mh4oj^ji003ojc2jOna^n3o/K_P00;o/K_P0_nd_^42ok>efPCo];CI00Co];;Gok2Zd_n`Z];o/:[B
0on]Y]42ojZSd0;oZ9o=1?nUWLd3oj>Kc@CoXI_?0_nOW=400onRW<koXYkAoj:Nd@02oj:Nd@CoXj7C
0_nSY=M7ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool004oooooo0_l0
000^ooooo`?o]L?T00Co^<?SokS6iOnha^Go^<KU0_nja^<3ok[8i@;o^lKS0onia^D2okS3h`Co/l7T
0_n/_>H2ojNgi0;oW;3U1?n?Y^D2ognKi0?oMI;Q0om_SMl3ogV>g0?oQIGK0onJX]X01Onb/MSo_;SF
okbhe_nl^=KocL;@00Cod<?=0_oA`l`00ooF`/Koe<36omC0aP02omC0aP?oc[_80oo<^lX00oo4]/co
a;S>olBhcP02olBhcP04okZcdonl]]Co_;KDokbfe0?o/K?J00?o][OIok2gg_n`]mh00_n`]mh2oj^j
i0;o/KSN0ona^n02ok:ef`Co/kGJ0_nd]=T00on`[=Co/:[Bok2ZdP02ok2ZdP;o[JKA00?oZZ7>ojRO
cOnXWld00onXWld3ojFMc@?oXi_=0_nQVll2oj>Kc@CoXYc>0onRW]42oj>Qddcooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0:ooooo`00DOooool00ol0003oooooooooo`0/ooooo`05
okG3i?nh`n?o^<?SokS3honha^D01?nja^<00onjb>Go^lKSok_6h`02ok_6h`03okW6iOnh`n?o^<?S
00;o^<?S0_nc`N@2ok2mh`CoYkOT0_nL/>D3ohnVi@?oOi_T0omeT^42ofn=g`?oN97O0on:W=l3oj>[
g0?o_;SF0_o2_MD3om33c@?odL?<00CodL?=omC0a_oD`<Koe<360_oB`<P00oo>^lSoc;_:olbkbP02
olbkbPGoa;S>1Onl]]@01?na/m[o][OIokJgfOnf]mT2ok2ggP;o];OL1?na^=h00ona^n3o/[GKok:e
f`02ok:ef`;o/kGJ00?o/JoFok2/e?n`[=@00_n`[=@2ok2ZdP03ojbTconZXLkoZZ7>00;oZZ7>1?nX
Wld2ojFMc@04ojFKbonTV/_oY9[;ojBJb`GoXi_=0onRW<h2oj:NdDoooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0:ooooo`00D_ooool00ol0003oooooooooo`0[ooooo`?o^<?S0_nj
`n43ok[6h`?o_<GQ0_nka^<2ok_4h@?o^<?S0_nf`>84ok2mh`;oYkOT00CoXk?ToiJ[iOnFZnGoUZ_U
0on8X^D2ogRGi0?oKi7S0om_SMl3ogRAg`?oRYcO0onSZm`00onl^=Ko`[gEol:me@02ol:me@04om33
cOoA`lcodL?<om73c0?odL?=00Goe<36om;0b?oB`<Sod/38om32c003olbkbP;obkk>0oo4^<h2olBk
d@?o_;KD00Co_K[FokJgfOnf]mWo][OI0_nh^MX4okBgg0;o/KSN00?o/[KKok:efonb]M/00_nb]M/0
0ona/MSo/JoFok6_eP02ok6_eP;o/:cD00?o[JOBojbTcon/Y<l00_n/Y<l4ojZQcP;oZ9o=00?oYYc<
ojFKbonUVl/00_nUVl/3ojBJb`CoXi_=0_nRW<iCooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02_ooool005?ooooo00?o0000ooooooooool0:oooool00onh`n?o^/?Qok[3h@02ok[3
h@04ok[6honlaN7o_<GQokc5h@;o_<CP1?nka>400onh`n?o]/3RokK0hP02okK0hP;o/;gS00?o[;WS
oj>ci?nS/n@00_nS/n@3oiJ[i@?oR:;U0_mhUn@3ofnAh`;oJhkR0omhTMl3ohZLg`;oXj_L0_nZ/]h3
ol:me@?oa/7E00?odL?<om73cOoA`ld00_oA`ld3om;0b0?od<;<00?oc;_:ol^nc_o;_/h00_o;_/h0
1Oo4^<koa;_AolBkdOo4^m7o_;KD00Co_K[F00?o][OIokRif_nh^MX00_nh^MX2okBgg003okFgfonb
]]_o/[KK00;o/[KK00?o/[GKok6af?na/MP00_na/MP3ok6_eP04ok2/e?n]Ym;o[JOBojfWdPCo[:C?
0_nZXLh00onXW/goYYc<ojJLc002ojJLc0?oYI_;1?nTV//2oj>KcEOooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`09ooooo`00E?ooool2o`0002gooooo0_nj`n43okc4h003okc5hOnl
a>3o_<CP00;o_<CP0_nka>43ok[2h0;o]/3R00?o/kgQojbihon/^N<00_n/^N<2oj>ci0;oW[7U0on@
ZNH2oh:Pi`?oLIKV0om_TN<2of^>hP?oN9KS0on?Xn84ojZbgP03ol:meOo6`MGoa/7E00;oa/7E00Co
b<CFom73cOoA`lgodL?=0_o@aLl00ooB`<Sod<;<om32c002om32c005olo4d?o;_/kobkk>ol^nc_o:
`M800oo4^m42olBoe@?o_K[F0_nn_MT3okRifP03okRjfone]m_o]KOK00;o]KOK0_nb]]/2ok:cf@Co
/K7H0_na[mH2ojj[e0Co[JOB0_n/Y<l00onYXLooZ9k=ojRNc@02ojRNc@?oYYc<1?nUVl/2ojBJbe[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`00E_ooool00ol0003ooooo
ooooo`0[ooooo`?o_<CP0_nma=l3okc4h0;o_<?O0onj`^000oni`>3o/kgQok>mh@02ok>mh@;o[;WS
0_nY]n<4oijai@?oT:WV0_n2X>L3og6FiP;oJY;V0omYT^H3ogRFh`?oSj?R0_nZ/]h2ok2ih0?oa/7E
0oo8a=H01OoA`lgod<G?om35coo@aLooclOC00?od<;<0oo?a=001Oo;_/kob/7Bol[1d_o:`M;oa;_A
00Coa;oE00?o_K[FokjmfOnn_MT00_nn_MT01?nh^M[o^;[KokRjfonh^]/2okFgf`;o];OK1?nb/mT2
ok6af0;o[jkG1?n^Zm@2ojfWdP03ojZTdOnYXLooZJ7?00;oZJ7?1?nXW/d3ojJLc0;oYI_;G_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo001Gooooo`03o`000?oooooooooo
02_ooooo00?o_<CPokg4gonma=l00_nma=l00onla>3o_<?Ookc3g`02okc3g`04ok[2h?ni`>3o^L3P
okW0h0;o/kgQ0_na_>44ojVgh`;oW[7U00CoVjoVohbWj?n<YnSoS:OX0ommX>P3og6FiP;oJY;V0omY
T^H2ogZMj0CoU:cV1?n`^N000oo6`MGob<CFolS4eP02olS4eP?od<G?0oo?am<00oo@`/coclC@olo4
d002olo4d0?ob/7B0_o8aML3olBoe@;o`l?J0onn_MT01?nl`=co^;[KokRjfonh^]/2okJkg@Co];OK
0_nb/mT2ojnaf@Co[jkG0_n^Zm@00on[Z=CoZZCAojZTd@02ojZTd@?oZJ7?0_nXW/eVooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02Oooool005Sooooo00?o0000ooooooooool0;?oo
ool5okg4g`;o_<?O0onl`]l00oni`>3o]koPokNoh004ok6lh@;oZKOS0_nV]N@3oi^_iP?oS:OX0omm
X>P3offGj@;oIiGY0omYT^H2ogZMj0CoU:cV0_n`^N02ok>oh`?ob<CF0_o8amT00oo@aLooclOColo7
d`02olo7d`04olg;f?o?a=3oclC@olo4d0;ocLSE00?ob/7BolS5eoo8aML00_o8aML00oo4_mGo`l?J
ol?3fP02ol?3fP05okjmfOnl`=co_<3Lokc0g?nh^]/01?nf^md2okBgf`;o/KKL1?n_/MT2ojn^e`03
oj^[eon[Z=CoZjSD00;oZjSD0onZY=42ojVQcf[ooooo00Go0000ooooooooooooooooo`00000;oooo
o`00FOooool00ol0003oooooooooo`0/ooooo`Go_LCO0onl`]l00onj`]oo]koPokNoh002okNoh0;o
/KcQ0_n_^^84ojJei0?oVjoV0on<YnP3ogfPj0?oKIOY0_mWUNT2ofRHj`?oNjC]0_nD[>H2oiVdj`Co
/koS00?ob<CFolS7fOo8amT00_o8bm`3olo7d`?ocL_H00?oclC@olg8eOo=b=D00_o;cM/3olS5e`?o
a/WM0_o3`mX2ol36g`;o_<3L0_nj`^03okJkg@03ok>kh?na]]co/KKL00?o/KKL0_n_/MT00on/[m[o
Zj_Goj^[e`02oj^[e`?oZjSD0_nZY=5]ooooo`05o`000?ooooooooooooooool000002oooool005[o
oooo0_l0000]ooooo`Go_LCO00Co_<;Ook[2gonj`]oo^/;O0_ng_n02okBnh@Co[k[R0_nV]N@2oj>e
i@?oV:oW0_n9Z>X3ogZQj`?oJY[/0omUV^h2ofRHj`?oNjC]1?nI]>/2ok>oh`;o]/GV00?ob<OIolS;
g?o8bm`00_o8bm`01?o?am?ocL_Holg;f?o=bmP2ol_?g@03olg8eOo;cM_oblgK00;oblgK00Gob<GG
olK9gOo6bMgoa/WMol?>h`03ol36g`;o_<WT1?nj`^001?nf^mgo/k_Pok>kh?nc^n03ok6fg003ojfd
g_n/[m[o[:oJ00;o[:oJ0on[ZmL2oj^Xe77ooooo00Co0000oooooooooooo00002oooool005cooooo
00?o0000ooooooooool0:oooool3okg4g`04okc4h?nj`]oo^/;Ook[2g`;o^L7P1?nd_^42ojnjhP;o
[;WS1?nS]ND3oiR_i`;oRJSZ0omjXN/3ofZJk0;oII[^0omXWo03ogf/lPCoVkc_0_nfaNH2okK;jP?o
b<_L0oo6d>400oo=bmSobloMol_?g@02olODh`?oblgK0oo7dN801Oo6bMgo`lkSol?>hoo3c^?o`<KO
00Co_<WT0_nj`^02okG2i0Co/k_P00Co/KKLojfdg_n]]=ko[KCN0on/[mX2oj^[egGooooo00?o0000
ooooool000002oooool005gooooo00?o0000ooooooooool0:oooool01Onma=oo_<CPokc4h?nla>3o
^/;O00Co^L7P0_nd_^43ok:mhP?o[;WS0_nS]ND01?nQ]NKoU[3YoiJ`jOnF/>T4ohNYk0;oNJC^0omY
Wo02ofFOl@?oJ9o`0omm[?82oi^lk`;oW<?c1?nfbnX01?o8bmcoa]3QolK@hOo6d>42ol?Di`03ol_?
gOo7e>?oamCS00;oamCS00GoblgKolOAh_o7dN;oam7Rol;Fj003ol?>h`?o_M7Y0_nlbN@00ongb^Wo
]L;TokG2i003okG2i0;o/k_P00?o[[[Sojfdg_n]]=h00_n]]=h2ojb_fWSooooo00Co0000oooooooo
oooo00002_ooool005kooooo00?o0000ooooooooool0:oooool2okc4h0?o^l?Q0_ni`N02okO0hP?o
/[gR0_n`_N<3ojZii0?oXKGV0onF/>T2ohNYk0;oQZc^0_miZ?03ofVOl0?oIIoa0_mYY_@3ogjdmPCo
W<?c0_nfbnX3okC@kP03olK@hOo3e>Oo`mCW00;o_mW/0oo7e><3ol?Hj@05olOAh_o2e^So`]KXol;F
j?o3c^<00onmdNT00ongdnko]l[YokO:j@02okO:j@;o]L;T0on_`^P3ojjjh`;o[KCNO?ooool00ol0
003oooooo`00000:ooooo`00Goooool2o`0002cooooo0onk`n42okW3hPCo]l3R00?o/[gRok2mhon`
_N<00_n`_N<00onZ^NCoZ;WVojRiiP03oinej0CoUK7[0on6[>h3ogVXl0;oJjCc0omVY_D2of^^n0?o
O[Cf0_nL`o<3oic9m`;o]=3^0_nbeO800oo3e>Oo_mW/okoIk002okoIk004olODhoo3f>Wo`mSYol?H
j@;o_Mg_0_o2e^P3okcIk`04okgAjOngdnko]m?^okOCkP;o]l[Y0on_b^h2ojo2j8?ooooo0_l0000:
ooooo`00HOooool00ol0003oooooooooo`0Zooooo`03ok_3hOni`n;o^L?R00;o^L?R0_ng`>83okC0
h`;o/;gS00?o[[gTojRii_nX^NH00_nX^NH3oinej0;oUK7[0_nE/n`3ohN_l0?oNjgc0_m^ZoH3ofJV
m@?oJjkh0omo^oX2oic9m`;oV/oj0_nbeO83ojkJm`;o_mW/0onjgO800oo3f>Wo_Mg_okgMk`03okKO
m0;o_=W_0_ndfo@2okOCkP?o[];c0_n_b^j5ooooo`?o00002_ooool006;ooooo00?o0000oooooooo
ool0:oooool2okW3hP;o]l?S0ond`><00onb`>Co[[gTojjmi002ojjmi0;oZ;WV0_nW^^L4oijfj@?o
UK?/0on7[o03og^]l`;oKZ_f0omY[_P3ofjen`?oOl;m0_nJcoX3oiSDo0;o[][g0onYgOX2ok[MlP04
ok?Qm_n/hoWo[>?iojcSn@;o]]od0_n^h?T2okCKm0?oZ][h0_n^d_>4ooooo`Co00003Oooool006?o
oooo00?o0000ooooooooool0:oooool4okO3h`04okC0honb`>Co//3Tok;0i0;o[[gT0_n/_NH4ojNj
i`;oW[KY00CoW[S[oiJfkOnF]^goU[K]0on:/o44ognbm@?oLk;h0om_]O/3og:mo@?oP<Sn0_nHe?`3
oiGGoP;oZMgj0_nTgo`01?nchOKo[>?iojcSnOn/hoT3ojGSn`04ojkPnOnTgo_oY=okojCOn`;oZ][h
Poooool4o`00017ooooo001Tooooo`;o0000;?ooool2okO3h`;o]L?U0_nb`>@2ok2oi@Co[;gV0_nW
^^L2ojJjj0?oW[S[0onF]^d3ohZcl@;oOk;e0_n4]oH3ogZhnPCoM[cl0omg`oh3oh;=o`;oUMOn0_nC
f_h2ojCOo0;oW^7m0onJhOd2ojGSn`;oWN;m0_nTgo^3ooooo`?o00005Oooool006Kooooo00?o0000
ooooooooool0:oooool00one`nGo//;Vok;2iP04ok2oi@;o[;gV0_n[_NL4ojJjj003oijhjonN^N_o
W[W[00CoUkS^0on=]o83ohBgmP?oN[Sj0_mf_?`2ogk3o@?oO/Wo0_n5d_l3ohSFo`;oT]cn0onBg_h2
oi[Qo@03oiOQoOoooooooooo08?ooooo1?l0000Hooooo`00Ioooool00ol0003oooooooooo`0Zoooo
o`Co//;V0_n`_nD3ojjoiP?oZkgW0_nV^^P2ojFkj@?oW[W[0_nG^>h2oiZjk`CoT[_c0on;_?L2oh:n
nP;oO/?m0on7bOd3ohG?o`;oR=Ko0on>fOl2oi;NoP03oiCOo_oooooooooo08;ooooo1?l0000Loooo
o`00J?ooool00ol0003oooooooooo`0Zooooo`;o//;V0on``^L2ojjoiP;o[KoW0onY_NP2ojFkj@;o
YKcZ1?nO^n`3oiZjk`;oT[_c00?oUkkboi71monA`OL00_nA`OL3oh_4nP;oQlWm0on@c_d2ohgCo`;o
U]On0_nDfoj3ooooo`Co00008?ooool006Wooooo0_l0000/ooooo`;o/<;W0_n^`NP4ojfoi`03ojVm
j?nX_NWoZ;gY00CoYKcZ0_nO^n`2oj6lk0?oWKg_0onG__82oi71m`?oVLCf0onDb?X2oi3>o@;oVM7k
0_nFeoj2ooooo`Co00009?ooool006_ooooo00?o0000ooooooooool0:_ooool4ojk1j0;o[KoW00?o
ZkoXojRmjOnX_NT00_nX_NT2ojFljP;oYKgZ1?nQ_>`00onM_NooX;o^oj2okP04oic1lP;oVLCf0onO
ao@2oic<n0;oVM7kP_ooool3o`0002Sooooo001/ooooo`03o`000?oooooooooo02[ooooo0_n^`NP0
0on]`NWoZkoXoj^oj002oj^oj0;oZ;gY0onX_^T3ojFmjP;oXKc/0_nS_N`3oj2okP;oW<7b0onR`o02
oio7m8?ooooo1?l0000[ooooo`00KOooool00ol0003oooooooooo`0[ooooo`;o[L7Y0_n[_nP3ojZo
j@?oZ;kY1?nV_NX2oj>mk0;oYKk[1?nT`>d2oj;3l8;ooooo1?l0000_ooooo`00K_ooool00ol0003o
ooooooooo`0Zooooo`CoZl7Y0_nZ_nT2ojVoj@?oZ;kY0_nV_NX2ojNnjPCoYKk[0_nT`>f1ooooo`Co
0000<oooool006oooooo0_l0000[ooooo`;oZl7Y0_nZ`NX4ojVoj@03ojRnjOnW_^[oYkkZ00CoYkkZ
0_nU_^^0ooooo`Co0000=oooool0077ooooo00?o0000ooooooooool0:_ooool3oj[1jP;oZKoY0_nX
_nX2ojNnjX;ooooo1?l0000kooooo`00L_ooool00ol0003oooooooooo`0Zooooo`?oZ<3[0_nX_nZ2
ooooo`?o0000?oooool007?ooooo00?o0000ooooooooool0:_ooool00onX`>_oooooooooo`1ooooo
o`Co0000@_ooool007Cooooo0_l0000Zooooo`03o`000?oooooooooo07_ooooo1?l00016ooooo`00
M_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07Sooooo1?l0001:ooooo`00Mooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07Cooooo1?l0001>ooooo`00N?ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo077ooooo0ol0001Booooo`00NOooool2o`00
02Cooooo00?o0000ooooooooool0KOooool4o`0005Gooooo001kooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0JOooool4o`0005Wooooo001looooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool0IOooool4o`0005gooooo001mooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool0HOooool4o`00067ooooo001nooooo`;o00007oooool00ol0003oooooooooo`1M
ooooo`Co0000IOooool0083ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Joooo
o`?o0000JOooool0087ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Fooooo`Co
0000K?ooool008;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Booooo`Co0000
L?ooool008?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1>ooooo`Co0000M?oo
ool008Cooooo0_l0000Iooooo`03o`000?oooooooooo04[ooooo1?l0001hooooo`00Q_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo04Kooooo1?l0001looooo`00Qoooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo04?ooooo0ol00020ooooo`00R?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo03oooooo1?l00023ooooo`00ROooool2o`0001Cooooo00?o
0000ooooooooool0>oooool4o`0008Oooooo002;ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0=oooool4o`0008_ooooo002<ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0<oooool4o`0008oooooo002=ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0<?ooool3o`0009?ooooo002>ooooo`;o00003oooool00ol0003oooooooooo`0/ooooo`Co0000
U_ooool0093ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Xooooo`Co0000V_oo
ool0097ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Tooooo`Co0000W_ooool0
09;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`Co0000X_ooool009?o
oooo0_l00009ooooo`03o`000?oooooooooo01gooooo1?l0002Vooooo`00UOooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01[ooooo0ol0002Zooooo`00U_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Kooooo1?l0002]ooooo`00Uoooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01;ooooo1?l0002aooooo`00V?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00kooooo1?l0002eooooo`00VOooool2o`0000?ooooo00?o0000oooooooo
ool02_ooool4o`000;Wooooo002Kooooo`04o`000?ooooooooooo`0000Wooooo0ol0002mooooo`00
W?ooool00ol0003oooooo`000005ooooo`Co0000`?ooool009gooooo0_l000000ooooooo0000o`00
0002o`000<Cooooo002Nooooo`;o0000b?ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:kooooo
00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`Go00000oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
00Gooooo0_lQ8B6Hooooo`00[_ooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo1_l000001_oo
ooooV9RHob4Q8Oo^k^koooooodA4A0?ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@05ooooo`;o8B4Q
V?ooool00:kooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP04ooooo`05o`000?oo
ooooooooooooool00000Woooool00:kooooo00?o0000ooooooooool01?ooool6o`0000?ooooo00?o
V9RHob4Q8Oo^k^h00oooool01Olb<S;oV9RHoooooonHV9So<S8b09oooooo002^ooooo`03o`000?oo
oooooooo00kooooo00?oMgMgofIVI_ooool00_ooool01Oo<c<co0000o`000?l0003oc<c<09oooooo
002/ooooo`03oa0@4?l0003o000000?o00003_ooool02Ol0003ooooooooooooooooo410@okZj^_oo
oooo^[Zjoa0@402Oooooo`00[_ooool00ol0003oooooooooo`0;ooooo`05o`000?nj^[[ooooooiRH
V?l@41000oooool01Ol0003o^[Zjoooooonj^[[o000009oooooo002^ooooo`03o`000?oooooooooo
00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0Wooo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "The wavefronts curve toward the region of lower ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " according to Snell's law, and as they do so the amplitude and wavelength \
decrease, as expected from our WKB analysis of this equation in Chapter ",
  ButtonBox["5",
    ButtonData:>{"Chapter5.nb", None},
    ButtonStyle->"Hyperlink"],
  ".  However, note the formation of a focus at a point behind the region of \
low wave speed, where the amplitude increases as wave energy is concentrated. \
This region is acting as a lens for the waves [see Exercise (13) in Sec. ",
  ButtonBox["5.2",
    ButtonData:>{"Chapter5.nb", "c:33"},
    ButtonStyle->"Hyperlink"],
  ", and the examples in Sec. ",
  ButtonBox["5.3.1",
    ButtonData:>{"Chapter5.nb", "c:35"},
    ButtonStyle->"Hyperlink"],
  " for  similar problems in which the ray trajectories for the waves are \
evaluated]. "
}], "Text",
  CellTags->"i:28"]
}, Closed]],

Cell[CellGroupData[{

Cell["Implicit Methods and Operator Splitting", "Subsubsection",
  CellTags->"i:27"],

Cell["\<\
\t Putting implicit methods in multidimensional form takes a bit \
more thought.  For example, if we try to implement the Crank-Nicolson scheme \
directly in two dimensions, we obtain\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\_\(j\ k\)\%n\), "=", 
          RowBox[{\(T\_\(j\ k\)\%\(n - 1\)\), "+", 
            RowBox[{\(1\/2\), 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], 
              " ", \((S\_\(j\ k\)\%n + S\_\(j\ k\)\%\(n - 1\))\)}], " ", "+", 
            " ", \(\(D\_x\) T\_\(j\ k\)\%n\), 
            "+", \(\(D\_\(\(x\)\(\ \)\)\) T\_\(j\ k\)\%\(n - 1\)\), 
            "+", \(\(D\_\(\(y\)\(\ \)\)\) T\_\(j\ k\)\%n\), 
            "+", \(\(D\_\(\(y\)\(\ \)\)\) \(T\_\(j\ k\)\%\(n - 
                    1\)\)\(\ \)\)}]}], TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(6.2.30)"],

Cell["where for convenience we have introduced the notation", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(D\_\(\(x\)\(\ \)\)\) T\_\(j\ k\)\%n\), "=", 
          RowBox[{\(1\/2\), 
            FractionBox[
              RowBox[{"\[Chi]", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]]}], 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"]], \((T\_\(j + 1\ k\)\%n - 
                2  T\_\(j\ k\)\%n + T\_\(j - 1\ k\)\%\(\(\ \)\(n\)\))\)}]}], 
        TraditionalForm]]],
  ",\n\n",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(D\_\(\(y\)\(\ \)\)\) T\_j\%n\), "=", 
          RowBox[{\(1\/2\), 
            FractionBox[
              RowBox[{"\[Chi]", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]]}], 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["y",
                      FontSlant->"Italic"]}]], "2"]], \((T\_\(j\ k + 1\)\%n - 
                2  T\_\(j\ k\)\%n + T\_\(j\ k - 1\)\%\(\(\ \)\(n\)\))\)}]}], 
        TraditionalForm]]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "( ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\(\(x\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`D\_y\)]],
  " are difference operators for second derivatives in the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " directions respectively, multiplied by ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Chi]", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], "/", "2"}]}], TraditionalForm]]],
  ". )"
}], "Text"],

Cell[TextData[{
  "\tSolution of Eq. ",
  ButtonBox["(6.2.30)",
    ButtonData:>"(6.2.30)",
    ButtonStyle->"Hyperlink"],
  " requires some finesse, since the number of coupled equations for ",
  Cell[BoxData[
      \(TraditionalForm\`T\_\(j\ k\)\%n\)]],
  " equals ",
  Cell[BoxData[
      \(TraditionalForm\`\((M\_x - 1)\)\ \((M\_y - 1)\)\)]],
  ", which can easily exceed several hundred. The problem is even worse in \
three dimensions, where thousands of coupled equations must be solved \
simultaneously. However, the equations are sparse, and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s  ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is sufficiently adept at solving  such problems so that even in \
three dimensions, the solution can be obtained directly without too much \
difficulty.  We leave this brute-force approach to the problems at the end of \
the section.\t"
}], "Text"],

Cell[TextData[{
  "\tRather than using a direct solution of the coupled equations, it is \
often preferable to generalize the Crank-Nicolson scheme to multiple \
dimensions in a slightly different way.   The idea is to split the spatial \
operator ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\)]],
  " into its constituent operators ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2\(\(/\)\(\[PartialD]x\^2\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2\(\(/\)\(\[PartialD]y\^2\)\)\)]],
  ", and also split the time step into two half steps, each of size ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "/", "2"}], TraditionalForm]]],
  ".  We treat  the ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2\(\(/\)\(\[PartialD]x\^2\)\)\)]],
  "part of the operator implicitly in the first half step, and  the ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2\(\(/\)\(\[PartialD]y\^2\)\)\)]],
  " part implicitly in the next half step. [Note: this type of operator \
splitting is called the ",
  StyleBox["alternating-direction implicit method",
    FontSlant->"Italic"],
  ". Another type of operator splitting is discussed in Chapter ",
  ButtonBox["7",
    ButtonData:>{"Chapter7.nb", None},
    ButtonStyle->"Hyperlink"],
  " in relation to a nonlinear convection/diffusion equation: see Eqs. ",
  ButtonBox["(7.2.29)",
    ButtonData:>{"Chapter7.nb", "(7.2.29)"},
    ButtonStyle->"Hyperlink"],
  "-",
  ButtonBox["(7.2.31)",
    ButtonData:>{"Chapter7.nb", "(7.2.31)"},
    ButtonStyle->"Hyperlink"],
  ". For more on operator splitting, see ",
  ButtonBox["Press et al. (1992)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ".] The equations used for each half step are"
}], "Text",
  CellTags->"i:69"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\_\(j\ k\)\%\(n - 1/2\)\), "=", " ", 
          RowBox[{\(T\_\(j\ k\)\%\(n - 1\)\), "+", " ", 
            RowBox[{\(1\/2\), 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], 
              " ", \(S\_\(j\ k\)\%\(n - 1\)\)}], "+", 
            " ", \(\(D\_\(\(x\)\(\ \)\)\) T\_\(j\ k\)\%\(n - 1/2\)\), "+", 
            " ", \(\(D\_\(\(y\)\(\ \)\)\) T\_\(j\ k\)\%\(n - 1\)\)}]}], 
        TraditionalForm]]],
  ",\n\n",
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\_\(j\ k\)\%n\), "=", 
          RowBox[{\(T\_\(j\ k\)\%\(n - 1/2\)\), "+", 
            RowBox[{\(1\/2\), 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], " ", \(S\_\(j\ k\)\%n\)}], 
            "+", \(\(D\_\(\(x\)\(\ \)\)\) T\_\(j\ k\)\%\(n - 1/2\)\), "+", 
            " ", \(\(D\_\(\(y\)\(\ \)\)\) T\_\(j\ k\)\%n\)}]}], 
        TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.31)"],

Cell[TextData[{
  "In the first half step, the source and ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2\(\(/\)\(\[PartialD]y\^2\)\)\)]],
  " are treated with forward time differencing as in Euler's method, and ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2\(\(/\)\(\[PartialD]x\^2\)\)\)]],
  " is treated with a backward-difference; but in the next half step this is \
reversed and ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2\(\(/\)\(\[PartialD]x\^2\)\)\)]],
  " is treated with a forward-difference derivative, while the source and ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2\(\(/\)\(\[PartialD]y\^2\)\)\)]],
  " are treated with a backward-difference derivative. As a result of this \
time symmetry, the method is still second-order accurate in time (and in \
space as well, due to the centered-difference form for ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\(\(x\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`D\_y\)]],
  "). Also, one can show that it is still absolutely stable. Now, however,  \
we need only solve a one-dimensional set of coupled equations in each half \
step.  In the first half step we must solve",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(M\_x - 1\)\)\)]],
  " coupled equations for each value of ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ", and in the second half step we solve ",
  Cell[BoxData[
      \(TraditionalForm\`M\_y - 1\)]],
  " equations for each value of ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  ". All in all, we still have to solve ",
  Cell[BoxData[
      \(TraditionalForm\`\((M\_x - 1)\)\ \((M\_y - 1)\)\)]],
  " equations,  but they are only coupled in batches of ",
  Cell[BoxData[
      \(TraditionalForm\`M\_x - 1\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`M\_y - 1\)]],
  " equations at a time, and this simplifies the task enormously.  The method \
is implemented below. "
}], "Text"],

Cell[BoxData[
    \(L\_x = 1; L\_y = 2; M\_x = 10; 
    M\_y\  = 10; \[CapitalDelta]t = 0.05; \[CapitalDelta]x = 
      L\_x/M\_x; \[CapitalDelta]y = L\_y/M\_y\ ; \[Chi]\  = \ 1/4;\)], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 6.78"],

Cell[TextData[{
  "\tWe now must choose initial and boundary conditions on all four sides of \
the rectangle. For simplicity, we take homogeneous Dirichlet conditions,  no \
source term, and an initial condition corresponding to the slowest-varying \
eigenmode of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\)]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox[\( (*\ initial\ condition\ *) \),
        FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
      RowBox[{\(T0[x_, y_]\  = \ Sin[Pi\ y/L\_y]\ Sin[Pi\ x/L\_x]\  // N;\), 
        "\[IndentingNewLine]", "\n", 
        StyleBox[\( (*\ boundary\ conditions\ on\ the\ four\ sides\ *) \),
          FontColor->RGBColor[1, 0, 0]], 
        "\[IndentingNewLine]", \(T[j_, 0, n_]\  := \ 0;\), 
        "\[IndentingNewLine]", \(T[0, k_, n_]\  := \ 0;\), 
        "\[IndentingNewLine]", \(T[j_, M\_y, n_]\  := \ 0;\), 
        "\[IndentingNewLine]", \(T[M\_x, k_, n_]\  := \ 0;\), "\n", 
        "\[IndentingNewLine]", 
        StyleBox[\( (*\ source\ term\ *) \),
          FontColor->RGBColor[1, 0, 0]], 
        "\[IndentingNewLine]", \(S[j_, k_, n_]\  = \ 0;\)}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.79"],

Cell["This initial condition should decay away according to", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`T(x, 
          t)\  = \ \(\[ExponentialE]\^\(\(-\[Chi]\)\ t\ \((\ \[Pi]\^2/\ 
                      L\_x\^2 + \ \[Pi]\^2/\ L\_y\^2)\)\)\) 
          sin\ \((\[Pi]\ x/L\_x)\) sin\ \((\[Pi]\ y/L\_y)\)\)]],
  "."
}], "NE2",
  CellTags->"(6.2.32)"],

Cell[TextData[{
  "Now we solve Eq. ",
  ButtonBox["(6.2.31)",
    ButtonData:>"(6.2.31)",
    ButtonStyle->"Hyperlink"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`T\_\(j\ k\)\%n\)]],
  ". Just as in the implementation of the 1D Crank-Nicolson method, we define \
 ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["sol",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["n",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  StyleBox[" ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " as a  list of substitutions for the solution at ",
  "time step",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(n\)\)\)]],
  StyleBox[". ",
    FontWeight->"Bold"],
  "The initial condition is given by the following list:"
}], "Text"],

Cell[BoxData[
    \(\(sol[0]\  = \ 
        Flatten[Table[
            T[j, k, 0] \[Rule] \ 
              T0[j\ \[CapitalDelta]x, k\ \[CapitalDelta]y], {j, 1, 
              M\_x - 1}, {k, 1, M\_y - 1}]];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.80"],

Cell["\<\
Also, we define the second-derivative difference functions to \
simplify the notation:\
\>", "Text"],

Cell[BoxData[{
    \(\(Dx[j_, k_, 
          n_]\  := \(\(\[Chi]\ \[CapitalDelta]t\)\/\(2  \[CapitalDelta]x\^2\)\
\) \((\ T[j + 1, k, n]\  - 2\ T[j, k, n]\  + \ T[j - 1, k, n])\);\)\), "\n", 
    \(\(Dy[j_, k_, 
          n_]\  := \ \(\(\[Chi]\ \[CapitalDelta]t\)\/\(2  \[CapitalDelta]y\^2\
\)\) \((T[j, k + 1, n]\  - 2\ T[j, k, n]\  + \ 
              T[j, k - 1, n])\);\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.81"],

Cell["Then we have", "Text"],

Cell[BoxData[
    RowBox[{\(sol[n_]\), " ", ":=", " ", 
      RowBox[{\(sol[n]\), " ", "=", " ", "\[IndentingNewLine]", 
        RowBox[{"Module", "[", 
          RowBox[{\({}\), ",", "\[IndentingNewLine]", 
            
            StyleBox[\( (*define\ the\ variables\ for\ the\ first\ half - 
                  step\ *) \),
              FontColor->RGBColor[1, 0, 0]], " ", 
            
            RowBox[{\(vars1[k_]\  := \ 
                Table[T[j, k, n - 1/2], {j, 1, M\_x - 1}]\), ";", 
              
              StyleBox[\( (*define\ the\ equations\ for\ the\ first\ half - 
                    step\ in\ Eqs . \ \((6  .2  .31)\), 
                  substituting\ for\ the\ values\ of\ T\ determined\ at\ the\ \
last\ time\ step\ \ *) \),
                FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
              RowBox[{\(eqns1[k_]\), " ", ":=", " ", 
                RowBox[{"Flatten", "[", 
                  
                  RowBox[{\(Table[
                      T[j, k, n - 1/2] - 
                          T[j, k, 
                            n - 1]\  == \(1\/2\) \[CapitalDelta]t\ S[j, k, 
                              n - 1] + Dx[j, k, n - 1/2]\  + 
                          Dy[j, k, n - 1], {j, 1, M\_x - 1}]\), " ", 
                    StyleBox["/.",
                      FontColor->RGBColor[0, 0, 1]], 
                    StyleBox[\(sol[n - 1]\),
                      FontColor->RGBColor[0, 0, 1]]}], "]"}]}], ";", 
              "\[IndentingNewLine]", 
              StyleBox[
                RowBox[{"(*", 
                  RowBox[{
                  "solve", " ", "the", " ", "equations", " ", Cell[""]}], 
                  "*)"}],
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(sol1\  = \ 
                Flatten[Table[Solve[eqns1[k], vars1[k]], {k, 1, M\_y - 1}]]\),
               ";", 
              
              StyleBox[\( (*define\ the\ variables\ for\ the\ second\ half - 
                    step\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              " ", \(vars2[j_]\  := \ Table[T[j, k, n], {k, 1, M\_y - 1}]\), 
              ";", " ", "\[IndentingNewLine]", 
              
              StyleBox[\( (*define\ the\ equations\ for\ the\ second\ half - 
                    step\ in\ Eqs . \ \((6  .2  .31)\), 
                  substituting\ for\ the\ values\ of\ T\ determined\ at\ the\ \
last\ time\ step\ \ and\ the\ first\ half - step*) \),
                FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
              RowBox[{\(eqns2[j_]\), " ", ":=", 
                RowBox[{"Flatten", "[", 
                  
                  RowBox[{\(Table[
                      T[j, k, n] - 
                          T[j, k, 
                            n - 1/2]\  == \(1\/2\) \[CapitalDelta]t\ S[j, k, 
                              n] + Dx[j, k, n - 1/2]\  + \ Dy[j, k, n], {k, 
                        1, M\_y - 1}]\), "/.", 
                    RowBox[{"Join", "[", 
                      RowBox[{
                        StyleBox[\(sol[n - 1]\),
                          FontColor->RGBColor[0, 0, 1]], ",", "sol1"}], 
                      "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
              StyleBox[
                RowBox[{"(*", 
                  RowBox[{
                  "solve", " ", "the", " ", "equations", " ", Cell[""]}], 
                  "*)"}],
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(Flatten[
                Table[Solve[eqns2[j], vars2[j]], {j, 1, M\_x - 1}]]\)}]}], 
          "]"}]}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.82"],

Cell[TextData[{
  "In Cell ",
  ButtonBox["6.84",
    ButtonData:>"Cell 6.84",
    ButtonStyle->"Hyperlink"],
  " we display the result, after creating an interpolation function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"Tsol", "[", 
          RowBox[{
            StyleBox["x",
              FontSlant->"Plain"], ",", 
            StyleBox["y",
              FontSlant->"Plain"], ",", 
            StyleBox["t",
              FontSlant->"Plain"]}], "]"}], TraditionalForm]],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Tsol\  = \ 
      Interpolation[
        Flatten[Table[
            Table[{j\ \[CapitalDelta]x, k\ \ \[CapitalDelta]y, 
                  n\ \[CapitalDelta]t, T[j, k, n]}, {j, 0, M\_x}, {k, 0, 
                  M\_y}] /. sol[n], {n, 0, 20}], 2]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.83"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.`, 1.`}, {0.`, 2.`}, {0.`, 1.`}}, 
        "<>"]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        Plot3D[Tsol[x, y, t], {x, 0, L\_x}, {y, 0, L\_y}, 
          PlotRange \[Rule] {0, 1}, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
          PlotLabel \[Rule] "\<T[x,y,t],t=\>" <> ToString[t] <> "\<\n\>", 
          BoxRatios \[Rule] {L\_x, L\_y, 1}], {t, 0, 1,  .1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.84"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11253 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.066106 1.21212 -1.11022e-16 1.21212 [
[.5 1.12503 -38 0 ]
[.5 1.12503 38 24.5 ]
[.03831 .17557 -5.85635 -9 ]
[.03831 .17557 .14365 0 ]
[.12814 .13981 -17.2021 -9 ]
[.12814 .13981 .79789 0 ]
[.22015 .10319 -16.8352 -9 ]
[.22015 .10319 1.16484 0 ]
[.31441 .06568 -16.4682 -9 ]
[.31441 .06568 1.53178 0 ]
[.411 .02725 -16.1013 -9 ]
[.411 .02725 1.89873 0 ]
[.51 -0.01213 -5.24477 -9 ]
[.51 -0.01213 .75523 0 ]
[.21792 .02683 -9.25094 -12 ]
[.21792 .02683 .74906 0 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[.1484 .76875 -18 -3.08128 ]
[.1484 .76875 0 5.91872 ]
[.29382 .89692 -6 -3.18183 ]
[.29382 .89692 0 5.81817 ]
[.42456 1.01215 -18 -3.26907 ]
[.42456 1.01215 0 5.73093 ]
[.54272 1.11629 -6 -3.34548 ]
[.54272 1.11629 0 5.65452 ]
[.22112 .91822 -10 -4.24244 ]
[.22112 .91822 0 7.75756 ]
[.03467 .19213 -6 -2.71522 ]
[.03467 .19213 0 6.28478 ]
[.02559 .27239 -18 -2.7611 ]
[.02559 .27239 0 6.2389 ]
[.01617 .35567 -18 -2.80881 ]
[.01617 .35567 0 6.19119 ]
[.00638 .44212 -18 -2.85847 ]
[.00638 .44212 0 6.14153 ]
[-0.00378 .53194 -18 -2.9102 ]
[-0.00378 .53194 0 6.0898 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 1.11253 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.12503 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
.04875 .18654 m
.0558 .18375 L
s
[(0)] .03467 .19213 1 -0.39662 Mshowa
.03972 .26693 m
.04679 .2642 L
s
[(0.2)] .02559 .27239 1 -0.38642 Mshowa
.03035 .35034 m
.03744 .34767 L
s
[(0.4)] .01617 .35567 1 -0.37582 Mshowa
.02062 .43693 m
.02774 .43433 L
s
[(0.6)] .00638 .44212 1 -0.36478 Mshowa
.01051 .52689 m
.01765 .52437 L
s
[(0.8)] -0.00378 .53194 1 -0.35329 Mshowa
0 .62042 m
.00717 .61797 L
s
[(1)] -0.01434 .62532 1 -0.3413 Mshowa
.125 Mabswid
.04653 .20636 m
.05076 .2047 L
s
.04428 .22637 m
.04851 .22471 L
s
.04201 .24656 m
.04625 .24491 L
s
.03741 .28749 m
.04165 .28587 L
s
.03508 .30825 m
.03933 .30663 L
s
.03272 .32919 m
.03698 .32759 L
s
.02795 .37168 m
.03221 .37009 L
s
.02553 .39322 m
.02979 .39164 L
s
.02309 .41497 m
.02735 .4134 L
s
.01813 .45909 m
.0224 .45755 L
s
.01561 .48147 m
.01989 .47994 L
s
.01307 .50407 m
.01736 .50255 L
s
.00792 .54993 m
.01221 .54843 L
s
.00531 .5732 m
.0096 .5717 L
s
.00267 .59669 m
.00696 .59521 L
s
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
.5561 .7194 m
.04875 .18654 L
s
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.5561 .7194 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
0 0 m
1 0 L
1 1.11253 L
0 1.11253 L
closepath
clip
newpath
.5 Mabswid
.24 .545 .927 r
.52593 .68772 .5561 .7194 .58394 .7109 .55408 .69725 Metetra
0 .458 .792 r
.55408 .69725 .58394 .7109 .61197 .70234 .58262 .70596 Metetra
.378 0 0 r
.58262 .70596 .61197 .70234 .64019 .69372 .61155 .713 Metetra
.457 0 0 r
.61155 .713 .64019 .69372 .66861 .68504 .64082 .7175 Metetra
.459 .002 .077 r
.64082 .7175 .66861 .68504 .69723 .6763 .67038 .71871 Metetra
.436 .015 .14 r
.67038 .71871 .69723 .6763 .72605 .6675 .70014 .7161 Metetra
.398 0 .159 r
.70014 .7161 .72605 .6675 .75507 .65863 .73004 .7093 Metetra
.341 0 .144 r
.73004 .7093 .75507 .65863 .7843 .6497 .75999 .69812 Metetra
.257 0 .091 r
.75999 .69812 .7843 .6497 .81374 .64071 .78991 .6827 Metetra
.118 0 0 r
.78991 .6827 .81374 .64071 .84339 .63166 .81976 .66337 Metetra
.81976 .66337 .84339 .63166 .87325 .62254 .84949 .64064 Metetra
.514 .856 .59 r
.84949 .64064 .87325 .62254 .90333 .61335 .87908 .61522 Metetra
.813 .999 .843 r
.87908 .61522 .90333 .61335 .93362 .6041 .90855 .58797 Metetra
.858 .901 .863 r
.90855 .58797 .93362 .6041 .96413 .59478 .93794 .55978 Metetra
0 .052 .562 r
.49498 .6552 .52593 .68772 .55408 .69725 .5232 .68217 Metetra
.644 .091 0 r
.5232 .68217 .55408 .69725 .58262 .70596 .55205 .70784 Metetra
.684 .154 0 r
.55205 .70784 .58262 .70596 .61155 .713 .58149 .73046 Metetra
.648 .158 .075 r
.58149 .73046 .61155 .713 .64082 .7175 .61146 .74822 Metetra
.586 .129 .136 r
.61146 .74822 .64082 .7175 .67038 .71871 .64184 .75956 Metetra
.509 .077 .155 r
.64184 .75956 .67038 .71871 .70014 .7161 .67249 .76329 Metetra
.412 0 .14 r
.67249 .76329 .70014 .7161 .73004 .7093 .70326 .75861 Metetra
.28 0 .087 r
.70326 .75861 .73004 .7093 .75999 .69812 .73396 .74512 Metetra
.089 0 0 r
.73396 .74512 .75999 .69812 .78991 .6827 .76446 .72311 Metetra
.76446 .72311 .78991 .6827 .81976 .66337 .79462 .69332 Metetra
.564 .825 .463 r
.79462 .69332 .81976 .66337 .84949 .64064 .82436 .65685 Metetra
.849 .976 .673 r
.82436 .65685 .84949 .64064 .87908 .61522 .85365 .61524 Metetra
.941 .952 .752 r
.85365 .61524 .87908 .61522 .90855 .58797 .88252 .5703 Metetra
.928 .868 .759 r
.88252 .5703 .90855 .58797 .93794 .55978 .91103 .52381 Metetra
.756 .279 0 r
.4632 .62183 .49498 .6552 .5232 .68217 .49129 .66476 Metetra
.809 .322 0 r
.49129 .66476 .5232 .68217 .55205 .70784 .52021 .70617 Metetra
.796 .316 .08 r
.52021 .70617 .55205 .70784 .58149 .73046 .54996 .74345 Metetra
.746 .277 .134 r
.54996 .74345 .58149 .73046 .61146 .74822 .58043 .77384 Metetra
.67 .21 .152 r
.58043 .77384 .61146 .74822 .64184 .75956 .61149 .7949 Metetra
.563 .112 .137 r
.61149 .7949 .64184 .75956 .67249 .76329 .64294 .80476 Metetra
.409 0 .082 r
.64294 .80476 .67249 .76329 .70326 .75861 .67452 .80212 Metetra
.171 0 0 r
.67452 .80212 .70326 .75861 .73396 .74512 .706 .78636 Metetra
.706 .78636 .73396 .74512 .76446 .72311 .73714 .75796 Metetra
.574 .82 .443 r
.73714 .75796 .76446 .72311 .79462 .69332 .76775 .71806 Metetra
.851 .952 .602 r
.76775 .71806 .79462 .69332 .82436 .65685 .79769 .66846 Metetra
.957 .948 .67 r
.79769 .66846 .82436 .65685 .85365 .61524 .82691 .61157 Metetra
.971 .896 .691 r
.82691 .61157 .85365 .61524 .88252 .5703 .85544 .55014 Metetra
.95 .836 .695 r
.85544 .55014 .88252 .5703 .91103 .52381 .88337 .48685 Metetra
.858 .415 .008 r
.43058 .58756 .4632 .62183 .49129 .66476 .45834 .64407 Metetra
.867 .42 .088 r
.45834 .64407 .49129 .66476 .52021 .70617 .48713 .69906 Metetra
.847 .396 .133 r
.48713 .69906 .52021 .70617 .54996 .74345 .51695 .74913 Metetra
.804 .346 .149 r
.51695 .74913 .54996 .74345 .58043 .77384 .54773 .79065 Metetra
.73 .261 .134 r
.54773 .79065 .58043 .77384 .61149 .7949 .57929 .82035 Metetra
.605 .121 .079 r
.57929 .82035 .61149 .7949 .64294 .80476 .61139 .83567 Metetra
.376 0 0 r
.61139 .83567 .64294 .80476 .67452 .80212 .64373 .83484 Metetra
.64373 .83484 .67452 .80212 .706 .78636 .67597 .81701 Metetra
.546 .839 .51 r
.67597 .81701 .706 .78636 .73714 .75796 .70781 .78282 Metetra
.852 .962 .627 r
.70781 .78282 .73714 .75796 .76775 .71806 .73899 .73386 Metetra
.958 .945 .654 r
.73899 .73386 .76775 .71806 .79769 .66846 .76932 .6726 Metetra
.981 .899 .657 r
.76932 .6726 .79769 .66846 .82691 .61157 .79872 .60227 Metetra
.975 .853 .656 r
.79872 .60227 .82691 .61157 .85544 .55014 .82722 .52653 Metetra
.957 .812 .658 r
.82722 .52653 .85544 .55014 .88337 .48685 .85493 .44884 Metetra
.894 .475 .099 r
.39706 .55236 .43058 .58756 .45834 .64407 .42436 .6193 Metetra
.892 .467 .136 r
.42436 .6193 .45834 .64407 .48713 .69906 .45285 .68481 Metetra
.874 .439 .148 r
.45285 .68481 .48713 .69906 .51695 .74913 .48257 .7449 Metetra
.839 .385 .133 r
.48257 .7449 .51695 .74913 .54773 .79065 .51345 .79522 Metetra
.771 .287 .081 r
.51345 .79522 .54773 .79065 .57929 .82035 .54533 .83178 Metetra
.627 .098 0 r
.54533 .83178 .57929 .82035 .61139 .83567 .57793 .85145 Metetra
.272 0 0 r
.57793 .85145 .61139 .83567 .64373 .83484 .6109 .85202 Metetra
.408 .829 .658 r
.6109 .85202 .64373 .83484 .67597 .81701 .64386 .83244 Metetra
.837 .993 .742 r
.64386 .83244 .67597 .81701 .70781 .78282 .67643 .79352 Metetra
.953 .952 .704 r
.67643 .79352 .70781 .78282 .73899 .73386 .70829 .73723 Metetra
.978 .898 .669 r
.70829 .73723 .73899 .73386 .76932 .6726 .7392 .66661 Metetra
.979 .855 .648 r
.7392 .66661 .76932 .6726 .79872 .60227 .76904 .58561 Metetra
.971 .822 .639 r
.76904 .58561 .79872 .60227 .82722 .52653 .79783 .49861 Metetra
.958 .794 .637 r
.79783 .49861 .82722 .52653 .85493 .44884 .82567 .40974 Metetra
.908 .501 .141 r
.36263 .5162 .39706 .55236 .42436 .6193 .38941 .58978 Metetra
.903 .489 .15 r
.38941 .58978 .42436 .6193 .45285 .68481 .41749 .66208 Metetra
.887 .459 .136 r
.41749 .66208 .45285 .68481 .48257 .7449 .44696 .72868 Metetra
.855 .401 .089 r
.44696 .72868 .48257 .7449 .51345 .79522 .47778 .78474 Metetra
.785 .285 0 r
.47778 .78474 .51345 .79522 .54533 .83178 .50979 .82579 Metetra
.594 .02 0 r
.50979 .82579 .54533 .83178 .57793 .85145 .54273 .84826 Metetra
.003 .578 .746 r
.54273 .84826 .57793 .85145 .6109 .85202 .57621 .84967 Metetra
.718 .974 .926 r
.57621 .84967 .6109 .85202 .64386 .83244 .60981 .82881 Metetra
.914 .946 .807 r
.60981 .82881 .64386 .83244 .67643 .79352 .6431 .78661 Metetra
.957 .889 .722 r
.6431 .78661 .67643 .79352 .70829 .73723 .67571 .72531 Metetra
.966 .847 .673 r
.67571 .72531 .70829 .73723 .7392 .66661 .70735 .64835 Metetra
.966 .819 .645 r
.70735 .64835 .7392 .66661 .76904 .58561 .73786 .5602 Metetra
.962 .798 .631 r
.73786 .5602 .76904 .58561 .79783 .49861 .76723 .46573 Metetra
.956 .781 .626 r
.76723 .46573 .79783 .49861 .82567 .40974 .79557 .36951 Metetra
.912 .509 .154 r
.32723 .47902 .36263 .5162 .38941 .58978 .35353 .55506 Metetra
.905 .495 .14 r
.35353 .55506 .38941 .58978 .41749 .66208 .3812 .62989 Metetra
.888 .461 .098 r
.3812 .62989 .41749 .66208 .44696 .72868 .41034 .69892 Metetra
.848 .391 .009 r
.41034 .69892 .44696 .72868 .47778 .78474 .44099 .75712 Metetra
.744 .238 0 r
.44099 .75712 .47778 .78474 .50979 .82579 .473 .79982 Metetra
.41 0 0 r
.473 .79982 .50979 .82579 .54273 .84826 .50611 .82326 Metetra
.34 .705 .983 r
.50611 .82326 .54273 .84826 .57621 .84967 .53995 .82482 Metetra
.773 .862 .916 r
.53995 .82482 .57621 .84967 .60981 .82881 .57409 .80325 Metetra
.89 .847 .795 r
.57409 .80325 .60981 .82881 .6431 .78661 .60805 .7595 Metetra
.928 .821 .72 r
.60805 .7595 .6431 .78661 .67571 .72531 .64142 .69597 Metetra
.943 .801 .675 r
.64142 .69597 .67571 .72531 .70735 .64835 .67389 .61625 Metetra
.949 .788 .647 r
.67389 .61625 .70735 .64835 .73786 .5602 .70525 .52503 Metetra
.951 .778 .632 r
.70525 .52503 .73786 .5602 .76723 .46573 .73545 .4274 Metetra
.951 .771 .624 r
.73545 .4274 .76723 .46573 .79557 .36951 .76458 .32809 Metetra
.908 .501 .141 r
.29083 .44079 .32723 .47902 .35353 .55506 .31679 .51483 Metetra
.898 .483 .102 r
.31679 .51483 .35353 .55506 .3812 .62989 .34412 .58763 Metetra
.869 .439 .025 r
.34412 .58763 .3812 .62989 .41034 .69892 .37298 .65472 Metetra
.796 .342 0 r
.37298 .65472 .41034 .69892 .44099 .75712 .40341 .71117 Metetra
.587 .12 0 r
.40341 .71117 .44099 .75712 .473 .79982 .43533 .75242 Metetra
0 .303 .795 r
.43533 .75242 .473 .79982 .50611 .82326 .46849 .7748 Metetra
.486 .639 .923 r
.46849 .7748 .50611 .82326 .53995 .82482 .50255 .77577 Metetra
.743 .739 .848 r
.50255 .77577 .53995 .82482 .57409 .80325 .53707 .7541 Metetra
.843 .758 .769 r
.53707 .7541 .57409 .80325 .60805 .7595 .57159 .71073 Metetra
.889 .761 .714 r
.57159 .71073 .60805 .7595 .64142 .69597 .60569 .64799 Metetra
.914 .76 .677 r
.60569 .64799 .64142 .69597 .67389 .61625 .639 .56939 Metetra
.928 .76 .653 r
.639 .56939 .67389 .61625 .70525 .52503 .6713 .4795 Metetra
.937 .761 .638 r
.6713 .4795 .70525 .52503 .73545 .4274 .70251 .3833 Metetra
.943 .764 .63 r
.70251 .3833 .73545 .4274 .76458 .32809 .73265 .28543 Metetra
.894 .475 .099 r
.25338 .40146 .29083 .44079 .31679 .51483 .27925 .46913 Metetra
.872 .447 .027 r
.27925 .46913 .31679 .51483 .34412 .58763 .30644 .53546 Metetra
.812 .379 0 r
.30644 .53546 .34412 .58763 .37298 .65472 .33514 .59633 Metetra
.654 .227 0 r
.33514 .59633 .37298 .65472 .40341 .71117 .36541 .64723 Metetra
0 .061 .622 r
.36541 .64723 .40341 .71117 .43533 .75242 .39721 .68401 Metetra
.194 .386 .825 r
.39721 .68401 .43533 .75242 .46849 .7748 .43033 .70337 Metetra
.534 .574 .841 r
.43033 .70337 .46849 .7748 .50255 .77577 .46446 .70302 Metetra
.708 .654 .794 r
.46446 .70302 .50255 .77577 .53707 .7541 .49922 .68186 Metetra
.797 .689 .746 r
.49922 .68186 .53707 .7541 .57159 .71073 .53415 .64073 Metetra
.848 .709 .709 r
.53415 .64073 .57159 .71073 .60569 .64799 .56883 .58172 Metetra
.881 .723 .682 r
.56883 .58172 .60569 .64799 .639 .56939 .60293 .50802 Metetra
.904 .734 .662 r
.60293 .50802 .639 .56939 .6713 .4795 .63618 .42375 Metetra
.92 .745 .649 r
.63618 .42375 .6713 .4795 .70251 .3833 .66845 .33349 Metetra
.933 .757 .642 r
.66845 .33349 .70251 .3833 .73265 .28543 .69976 .24147 Metetra
.858 .415 .008 r
.21484 .36098 .25338 .40146 .27925 .46913 .24095 .4182 Metetra
.803 .363 0 r
.24095 .4182 .27925 .46913 .30644 .53546 .2683 .47396 Metetra
.663 .245 0 r
.2683 .47396 .30644 .53546 .33514 .59633 .29705 .52471 Metetra
0 0 .549 r
.29705 .52471 .33514 .59633 .36541 .64723 .32731 .56665 Metetra
.025 .232 .737 r
.32731 .56665 .36541 .64723 .39721 .68401 .35903 .59628 Metetra
.352 .424 .796 r
.35903 .59628 .39721 .68401 .43033 .70337 .39207 .61089 Metetra
.556 .533 .785 r
.39207 .61089 .43033 .70337 .46446 .70302 .42616 .60859 Metetra
.678 .596 .756 r
.42616 .60859 .46446 .70302 .49922 .68186 .46098 .58846 Metetra
.754 .635 .729 r
.46098 .58846 .49922 .68186 .53415 .64073 .49612 .55121 Metetra
.806 .664 .706 r
.49612 .55121 .53415 .64073 .56883 .58172 .53123 .49856 Metetra
.844 .687 .688 r
.53123 .49856 .56883 .58172 .60293 .50802 .56595 .43313 Metetra
.874 .709 .674 r
.56595 .43313 .60293 .50802 .63618 .42375 .60004 .35839 Metetra
.897 .729 .665 r
.60004 .35839 .63618 .42375 .66845 .33349 .63336 .27818 Metetra
.917 .751 .661 r
.63336 .27818 .66845 .33349 .69976 .24147 .66586 .19616 Metetra
.756 .279 0 r
.17516 .3193 .21484 .36098 .24095 .4182 .20195 .36248 Metetra
.611 .172 0 r
.20195 .36248 .24095 .4182 .2683 .47396 .22981 .40416 Metetra
0 .006 .579 r
.22981 .40416 .2683 .47396 .29705 .52471 .25892 .44156 Metetra
0 .202 .718 r
.25892 .44156 .29705 .52471 .32731 .56665 .28936 .47175 Metetra
.266 .351 .765 r
.28936 .47175 .32731 .56665 .35903 .59628 .32111 .49212 Metetra
.448 .446 .764 r
.32111 .49212 .35903 .59628 .39207 .61089 .35407 .50062 Metetra
.569 .509 .748 r
.35407 .50062 .39207 .61089 .42616 .60859 .38804 .49586 Metetra
.653 .555 .731 r
.38804 .49586 .42616 .60859 .46098 .58846 .42276 .47718 Metetra
.714 .591 .716 r
.42276 .47718 .46098 .58846 .49612 .55121 .45792 .4451 Metetra
.762 .622 .704 r
.45792 .4451 .49612 .55121 .53123 .49856 .4932 .40087 Metetra
.802 .651 .695 r
.4932 .40087 .53123 .49856 .56595 .43313 .52832 .34647 Metetra
.836 .681 .69 r
.52832 .34647 .56595 .43313 .60004 .35839 .56306 .28447 Metetra
.866 .711 .688 r
.56306 .28447 .60004 .35839 .63336 .27818 .59727 .21784 Metetra
.893 .744 .689 r
.59727 .21784 .63336 .27818 .66586 .19616 .63089 .14942 Metetra
0 .052 .562 r
.13429 .27638 .17516 .3193 .20195 .36248 .16223 .30264 Metetra
0 .191 .722 r
.16223 .30264 .20195 .36248 .22981 .40416 .19105 .32756 Metetra
.108 .303 .778 r
.19105 .32756 .22981 .40416 .25892 .44156 .22085 .34925 Metetra
.298 .377 .776 r
.22085 .34925 .25892 .44156 .28936 .47175 .25173 .36579 Metetra
.426 .427 .758 r
.25173 .36579 .28936 .47175 .32111 .49212 .28366 .37545 Metetra
.514 .465 .739 r
.28366 .37545 .32111 .49212 .35407 .50062 .3166 .37696 Metetra
.58 .496 .724 r
.3166 .37696 .35407 .50062 .38804 .49586 .35039 .36945 Metetra
.633 .525 .714 r
.35039 .36945 .38804 .49586 .42276 .47718 .38487 .35248 Metetra
.677 .553 .708 r
.38487 .35248 .42276 .47718 .45792 .4451 .41982 .32639 Metetra
.716 .582 .705 r
.41982 .32639 .45792 .4451 .4932 .40087 .45502 .29197 Metetra
.752 .614 .705 r
.45502 .29197 .4932 .40087 .52832 .34647 .49027 .25046 Metetra
.787 .648 .709 r
.49027 .25046 .52832 .34647 .56306 .28447 .52539 .20354 Metetra
.82 .687 .717 r
.52539 .20354 .56306 .28447 .59727 .21784 .56026 .15315 Metetra
.854 .733 .729 r
.56026 .15315 .59727 .21784 .63089 .14942 .59481 .1012 Metetra
.24 .545 .927 r
.09217 .23214 .13429 .27638 .16223 .30264 .12177 .23951 Metetra
.371 .521 .876 r
.12177 .23951 .16223 .30264 .19105 .32756 .15198 .24598 Metetra
.447 .497 .818 r
.15198 .24598 .19105 .32756 .22085 .34925 .18285 .25062 Metetra
.497 .484 .773 r
.18285 .25062 .22085 .34925 .25173 .36579 .21444 .25249 Metetra
.534 .481 .743 r
.21444 .25249 .25173 .36579 .28366 .37545 .24674 .2508 Metetra
.564 .483 .722 r
.24674 .2508 .28366 .37545 .3166 .37696 .27972 .24496 Metetra
.59 .491 .71 r
.27972 .24496 .3166 .37696 .35039 .36945 .31332 .23455 Metetra
.615 .504 .704 r
.31332 .23455 .35039 .36945 .38487 .35248 .34745 .2194 Metetra
.64 .521 .703 r
.34745 .2194 .38487 .35248 .41982 .32639 .38201 .19965 Metetra
.664 .544 .707 r
.38201 .19965 .41982 .32639 .45502 .29197 .41688 .17566 Metetra
.69 .571 .716 r
.41688 .17566 .45502 .29197 .49027 .25046 .45195 .148 Metetra
.719 .607 .731 r
.45195 .148 .49027 .25046 .52539 .20354 .48713 .11745 Metetra
.75 .652 .752 r
.48713 .11745 .52539 .20354 .56026 .15315 .52235 .08494 Metetra
.784 .709 .781 r
.52235 .08494 .56026 .15315 .59481 .1012 .55756 .05142 Metetra
.666 .738 .904 r
.04875 .18654 .09217 .23214 .12177 .23951 .08051 .17394 Metetra
.651 .653 .839 r
.08051 .17394 .12177 .23951 .15198 .24598 .11254 .16124 Metetra
.635 .592 .788 r
.11254 .16124 .15198 .24598 .18285 .25062 .14483 .14843 Metetra
.622 .55 .752 r
.14483 .14843 .18285 .25062 .21444 .25249 .1774 .13551 Metetra
.612 .521 .728 r
.1774 .13551 .21444 .25249 .24674 .2508 .21025 .12249 Metetra
.605 .503 .712 r
.21025 .12249 .24674 .2508 .27972 .24496 .24339 .10934 Metetra
.602 .493 .703 r
.24339 .10934 .27972 .24496 .31332 .23455 .27681 .09609 Metetra
.6 .49 .7 r
.27681 .09609 .31332 .23455 .34745 .2194 .31052 .08272 Metetra
.602 .493 .703 r
.31052 .08272 .34745 .2194 .38201 .19965 .34452 .06923 Metetra
.605 .503 .712 r
.34452 .06923 .38201 .19965 .41688 .17566 .37882 .05563 Metetra
.612 .521 .728 r
.37882 .05563 .41688 .17566 .45195 .148 .41342 .04191 Metetra
.622 .55 .752 r
.41342 .04191 .45195 .148 .48713 .11745 .44833 .02806 Metetra
.635 .592 .788 r
.44833 .02806 .48713 .11745 .52235 .08494 .48355 .01409 Metetra
.651 .653 .839 r
.48355 .01409 .52235 .08494 .55756 .05142 .51908 0 Metetra
0 g
.25 Mabswid
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282.75, 314.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005Q0001RB000`400?l00000o`00003ooooooomR
ooooo`00oooooomRooooo`00oooooomRooooo`00^_ooool4o`000003oa0@4?oooooooooo0:3ooooo
002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002loooo
o`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`00
0?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002jooooo`03oeEEEOmVIVKo
00000:Cooooo003oooooof;ooooo003oooooof;ooooo001Mooooo`;o00000_ooool2o`000?kooooo
001Mooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgMo_ooool005kooooo00CogMgMo`000?l@413o
c<c<:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`07oooool2o`0009oooooo001Nooooo`04onk^k_lQ8B7o410@onk^kR[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01cooooo
0ol000000onVYmKo0000o`00002Nooooo`00G_ooool01?lQ8B7oMgMgogMgMolb<S8Zooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001[ooooo0ol00003ojJW
eP?o0000WOooool005gooooo0_l00002ooooo`;o0000:Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`?o00001_nVYmH00ol0003oYZOFo`00002M
ooooo`00S?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00Eooooo`?o00000_nVYmH00ol0003oYZOFojJWeP03ojJWeP04o`000?nVYmKoYZOFo`0009cooooo
002<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@01;o
oooo1?l0000:ojJWeP04o`000?nVYmKoYZOFo`0009cooooo002<ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000013ooooo1?l000000onRUlWo0000ojJWeP09
ojJWeP05o`000?nVYmKoYZOFojJWe_l00000Voooool008cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT03Oooool4o`000003oj:GbOl0003oXYO900;oXYO9
00?o0000ojJWe_nVYmH01onVYmH00ol0003oYZOFojJWeP02ojJWeP03o`000?oooooooooo09Sooooo
002/ooooo`Co00001onRUlT00ol0003oYZOFojJWeP07ojJWeP03o`000?nVYmKoYZOF00?oYZOF00?o
0000ooooooooool0Uoooool00:Wooooo1?l0000;oj:Gb@03o`000?nVYmKoYZOF00KoYZOF00?o0000
ojJWe_nVYmH00onVYmH00ol0003oooooooooo`2Gooooo`00Yoooool6o`0000coXYO900?o0000ojJW
e_nVYmH01OnVYmH00ol0003oYZOFojJWeP04ojJWeP03o`000?oooooooooo09Kooooo002Tooooo`Co
00001OnOS<000ol0003oXYO9oj:Gb@09oj:Gb@03o`000?nVYmKoYZOF00GoYZOF00?o0000ojJWe_nV
YmH01OnVYmH00ol0003oooooooooo`2Eooooo`00KOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`08?ooool3o`0000SoWhc000?o0000oj:G
bOnRUlT02_nRUlT00ol0003oYZOFojJWeP04ojJWeP03o`000?nVYmKoYZOF00KoYZOF00?o0000oooo
ooooool0U?ooool006gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q01gooooo0ol000000onOS<3o0000oin<`009oin<`003o`000?nRUlWo
XYO900WoXYO900?o0000ojJWe_nVYmH01?nVYmH00ol0003oYZOFojJWeP06ojJWeP03o`000?oooooo
oooo09Cooooo001]ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000001_ooooo0ol000001OnLQK[o0000oin<`?nOS<3o000000WoWhc000?o0000oj:GbOnRUlT0
2_nRUlT00ol0003oYZOFojJWeP03ojJWeP03o`000?nVYmKoYZOF00OoYZOF00?o0000ooooooooool0
Toooool006gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B406?ooool3o`0000GoW8Fj00?o0000oin<`?nOS<002OnOS<000ol0003oXYO9oj:Gb@0:oj:Gb@03
o`000?nVYmKoYZOF00?oYZOF00?o0000ojJWe_nVYmH02?nVYmH00ol0003oooooooooo`2Booooo`00
KOooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Eoooo
o`Co000000?oW8Fjo`000?nLQKX01?nLQKX00ol0003oWhc0oin<`00:oin<`003o`000?nRUlWoXYO9
00[oXYO900?o0000ojJWe_nVYmH00_nVYmH00ol0003oYZOFojJWeP08ojJWeP;o0000Toooool006go
oooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo01Gooooo0ol0000:oib5
^P03o`000?nOS<3oWhc000[oWhc000?o0000oj:GbOnRUlT02onRUlT01Ol0003oYZOFojJWe_nVYmKo
000000WoYZOF00?o0000olReaol00000Toooool006gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`03omgMgOl@413oV9RH01?ooooo1?l0000<oib5^P03o`000?nOS<3oWhc000[oWhc000?o0000
oj:GbOnRUlT02_nRUlT01Ol0003oYZOFojJWe_nVYmKo000000SoYZOF00Go0000olReaoo8]LOob;G7
o`00002Booooo`00KOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o
410@3oooool2o`0000;oVX2f0_l0000<oib5^P03o`000?nOS<3oWhc000[oWhc000?o0000oj:GbOnR
UlT02onRUlT01?l0003oYZOFojJWe_l00007ojJWeP03o`000?o8]LOob;G700?ob;G700?o0000oooo
ooooool0Soooool008kooooo0ol00006oiZ0]P03o`000?nLQK[oW8Fj00WoW8Fj00?o0000oin<`?nO
S<002onOS<000ol0003oXYO9oj:Gb@0:oj:Gb@04o`000?nVYmKoYZOFo`0000KoYZOF00?o0000olRe
aoo8]LL01Oo8]LL00ol0003oooooooooo`2>ooooo`00S?ooool3o`0000SoVX2f00?o0000oib5^_nL
QKX02_nLQKX00ol0003oWhc0oin<`00:oin<`003o`000?nRUlWoXYO900_oXYO900?o0000ojJWe_l0
00001OnVYmH00ol0003ob;G7olRea`06olRea`;o0000Soooool008Wooooo1?l000000onJP;Ko0000
oiZ0]P07oiZ0]P03o`000?nLQK[oW8Fj00[oW8Fj00?o0000oin<`?nOS<002onOS<000ol0003oXYO9
oj:Gb@0:oj:Gb@03o`000?nVYmKo000000CoYZOF00?o0000olReaoo8]LL02?o8]LL00ol0003ooooo
ooooo`2=ooooo`00D?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o0000
00?o410@ooooooooool08?ooool4o`000003oiYn/ol0003oVX2f00[oVX2f00?o0000oib5^_nLQKX0
2OnLQKX00ol0003oWhc0oin<`00;oin<`003o`000?nRUlWoXYO900_oXYO90_l00003ojJWeP03o`00
0?o8]LOob;G700[ob;G700?o0000ooooooooool0S?ooool0053ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Nooooo`Co00001?nJO[<00ol0003oVX2f
oiZ0]P09oiZ0]P03o`000?nLQK[oW8Fj00[oW8Fj00?o0000oin<`?nOS<002_nOS<000ol0003oXYO9
oj:Gb@0<oj:Gb@04o`000?nVYmKoYZOFo`0000kob;G700?o0000ooooooooool0Roooool0053ooooo
00Go410@oooooooooooooooooa0@400;ooooo`Go00007Oooool3o`000003oiYn/ol0003oVWjc00Go
VWjc00?o0000oiZ0]_nJP;H02?nJP;H00ol0003oW8Fjoib5^P0:oib5^P03o`000?nOS<3oWhc000_o
Whc000?o0000oj:GbOnRUlT02onRUlT00ol0003oYZOFo`00000?olRea`;o0000S?ooool0053ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo0ol00005oiYn
/`03o`000?nJO[?oVWjc00?oVWjc00?o0000oiZ0]_nJP;H02OnJP;H00ol0003oW8Fjoib5^P0:oib5
^P03o`000?nOS<3oWhc000[oWhc000?o0000oj:GbOnRUlT02onRUlT2o`00017ob;G70_l0002;oooo
o`00D?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00006Oooool3
o`000003oiUm/ol0003oVWjc00[oVWjc00?o0000oiZ0]_nJP;H02OnJP;H00ol0003oW8Fjoib5^P0:
oib5^P03o`000?nOS<3oWhc000_oWhc000?o0000oj:GbOnRUlT02_nRUlT2o`0001;ob;G700?o0000
ooooooooool0ROooool0053ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co
000001Kooooo0ol00002oiUm/`03o`000?nIOK?o000000coVWjc00?o0000oiZ0]_nJP;H02?nJP;H0
0ol0003oW8Fjoib5^P0:oib5^P03o`000?nOS<3oWhc000_oWhc000?o0000oj:GbOnRUlT02OnRUlT2
o`000003oknV`?l0003ob;G7017ob;G700?o0000ooooooooool0R?ooool0053ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000001Cooooo0ol00007oiUm/`03o`000?nJO[?o
VWjc00WoVWjc00?o0000oiZ0]_nJP;H02OnJP;H00ol0003oW8Fjoib5^P0:oib5^P03o`000?nOS<3o
Whc000_oWhc000?o0000oj:GbOnRUlT01onRUlT01Ol0003o_jK0o`000?noY/3o000001;ob;G70_l0
0029ooooo`00D?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool04?oo
ool3o`0000[oVGfc00?o0000oiYn/onJO[<02OnJO[<00ol0003oVX2foiZ0]P09oiZ0]P03o`000?nL
QK[oW8Fj00[oW8Fj00?o0000oin<`?nOS<002onOS<000ol0003oXYO9oj:Gb@06oj:Gb@04o`000?no
Y/3o_jK0o`0000;o_jK000?o0000olReaoo8]LL04?o8]LL2o`0008Sooooo001cooooo`?o000000?o
VWjco`000?l000002OnIOK<00ol0003oVWjcoiYn/`09oiYn/`03o`000?nJP;KoVX2f00WoVX2f00?o
0000oib5^_nLQKX02_nLQKX00ol0003oWhc0oin<`00<oin<`003o`000?nRUlWoXYO900CoXYO900Go
0000oknV`?noY/3o_jK0o`000003oknV`003o`000?o8]LOob;G7013ob;G70_l00027ooooo`00L?oo
ool3o`0000CoVWjc00?o0000oiUm/onIOK<02OnIOK<00ol0003oVWjcoiYn/`09oiYn/`03o`000?nJ
P;KoVX2f00WoVX2f00?o0000oib5^_nLQKX02_nLQKX00ol0003oWhc0oin<`00;oin<`003o`000?nR
UlWoXYO900?oXYO900?o0000oknV`?noY/000_noY/001Ol0003o_jK0oknV`?noY/3o000001?ob;G7
00?o0000ooooooooool0QOooool006kooooo0ol00007oiYn/`03o`000?nIOK?oVGfc00SoVGfc00?o
0000oiYn/onJO[<02OnJO[<00ol0003oVX2foiZ0]P09oiZ0]P03o`000?nLQK[oW8Fj00[oW8Fj00?o
0000oin<`?nOS<002onOS<000ol0003oXYO9oj:Gb@02oj:Gb@03o`000?noY/3o_jK000?o_jK000?o
0000oknV`?noY/000_noY/000ol0003ob;G7olRea`0?olRea`?o0000Q_ooool003?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo0ol00002oiYn/`03o`000?nJ
O[?oVWjc00GoVWjc00?o0000oiUm/onIOK<02?nIOK<00ol0003oVWjcoiYn/`09oiYn/`03o`000?nJ
P;KoVX2f00WoVX2f00?o0000oib5^_nLQKX02_nLQKX00ol0003oWhc0oin<`00<oin<`004o`000?nR
UlWoXYO9o`0000Ko_jK000?o0000oknV`?noY/000_noY/000ol0003ob;G7olRea`0>olRea`03o`00
0?oJ^k[of[^j00;o0000QOooool003?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4027ooooo0ol000000onJP;Ko0000oiYn/`09oiYn/`03
o`000?nIOK?oVGfc00SoVGfc00?o0000oiYn/onJO[<02OnJO[<00ol0003oVX2foiZ0]P0:oiZ0]P03
o`000?nLQK[oW8Fj00[oW8Fj00?o0000oin<`?nOS<002onOS<000ol0003oXYO9o`000007oknV`003
o`000?noY/3o_jK000?o_jK000?o0000olReaoo8]LL03Oo8]LL01?l0003of[^jomZk^_oJ^kX2o`00
08Cooooo000cooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Ooooo
o`Co00000onJP;H00ol0003oVWjcoiYn/`08oiYn/`03o`000?nIOK?oVGfc00WoVGfc00?o0000oiYn
/onJO[<02OnJO[<00ol0003oVX2foiZ0]P09oiZ0]P03o`000?nLQK[oW8Fj00[oW8Fj00?o0000oin<
`?nOS<002onOS<02o`0000So_jK000?o0000oknV`?noY/000onoY/000ol0003ob;G7olRea`0<olRe
a`03o`000?oJ^k[of[^j00?of[^j00?o0000ooooooooool0P_ooool003?ooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01_ooooo0ol00004oiZ0]P05o`000?nJP;KoVX2f
oiZ0]_l000002_nJO[<00ol0003oVGfcoiUm/`08oiUm/`03o`000?nJO[?oVWjc00WoVWjc00?o0000
oiZ0]_nJP;H02OnJP;H00ol0003oW8Fjoib5^P0;oib5^P03o`000?nOS<3oWhc000WoWhc000?o0000
okRK^ol000002?noY/000ol0003o_jK0oknV`004oknV`003o`000?o8]LOob;G700[ob;G700?o0000
omZk^_oJ^kX01?oJ^kX2o`0008?ooooo000cooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`0Hooooo`?o00002_nJP;H00ol0003oVWjcoiYn/`08oiYn/`03o`000?nIOK?o
VGfc00SoVGfc00?o0000oiYn/onJO[<02OnJO[<00ol0003oVX2foiZ0]P0:oiZ0]P03o`000?nLQK[o
W8Fj00[oW8Fj00?o0000oin<`?nOS<002?nOS<001Ol0003o^9^kokRK^onhVk_o000000Oo_jK000?o
0000oknV`?noY/001OnoY/000ol0003ob;G7olRea`09olRea`03o`000?oJ^k[of[^j00Gof[^j0_l0
0022ooooo`00<oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool05?oo
ool3o`000003oib5^_l0003oVX2f00[oVX2f00?o0000oiYn/onJO[<02?nJO[<00ol0003oVGfcoiUm
/`09oiUm/`03o`000?nJO[?oVWjc00WoVWjc00?o0000oiZ0]_nJP;H02OnJP;H00ol0003oW8Fjoib5
^P0:oib5^P03o`000?nOS<3oWhc000OoWhc000?o0000okRK^onhVk/00_nhVk/00ol0003o_jK0oknV
`005oknV`003o`000?noY/3o_jK000Go_jK000?o0000olReaoo8]LL02?o8]LL00ol0003of[^jomZk
^P07omZk^P;o0000POooool003?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooooiRHV?l@41005?ooool3o`0000?oW8Fj00?o0000oiZ0]_nJP;H02OnJP;H00ol0003oVWjc
oiYn/`08oiYn/`03o`000?nIOK?oVGfc00WoVGfc00?o0000oiYn/onJO[<02OnJO[<00ol0003oVX2f
oiZ0]P09oiZ0]P03o`000?nLQK[oW8Fj00_oW8Fj00?o0000oin<`?nOS<001OnOS<000ol0003o^9^k
okRK^`03okRK^`03o`000?noY/3o_jK000Go_jK000?o0000oknV`?noY/001_noY/000ol0003ob;G7
olRea`06olRea`03o`000?oJ^k[of[^j00Wof[^j00?o0000ooooooooool0Ooooool003?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool3o`0000Oo
W8Fj00?o0000oiZ0]_nJP;H02OnJP;H00ol0003oVWjcoiYn/`08oiYn/`03o`000?nIOK?oVGfc00So
VGfc00?o0000oiYn/onJO[<02OnJO[<00ol0003oVX2foiZ0]P0:oiZ0]P03o`000?nLQK[oW8Fj00[o
W8Fj00?o0000oin<`?nOS<001?nOS<000ol0003o^9^kokRK^`05okRK^`03o`000?noY/3o_jK000Co
_jK000?o0000oknV`?noY/001_noY/000ol0003ob;G7olRea`05olRea`03o`000?oJ^k[of[^j00[o
f[^j0_l00020ooooo`00Eoooool3o`000003oib5^_l0003oW8Fj00KoW8Fj00?o0000oiZ0]_nJP;H0
2OnJP;H00ol0003oVWjcoiYn/`08oiYn/`03o`000?nIOK?oVGfc00SoVGfc00?o0000oiYn/onJO[<0
2OnJO[<00ol0003oVX2foiZ0]P0:oiZ0]P03o`000?nLQK[oW8Fj00[oW8Fj00?o0000oin<`?nOS<00
0onOS<000ol0003o^9^kokRK^`06okRK^`03o`000?noY/3o_jK000Co_jK000?o0000oknV`?noY/00
1onoY/000ol0003ob;G7olRea`04olRea`03o`000?oJ^k[of[^j00_of[^j0_l0001oooooo`00E?oo
ool3o`000003oin<`?l0003oW8Fj00WoW8Fj00?o0000oiZ0]_nJP;H02OnJP;H00ol0003oVWjcoiYn
/`08oiYn/`03o`000?nIOK?oVGfc00WoVGfc00?o0000oiYn/onJO[<02OnJO[<00ol0003oVX2foiZ0
]P09oiZ0]P03o`000?nLQK[oW8Fj00_oW8Fj00Go0000oin<`?nOS<3oWhc0o`00000:okRK^`03o`00
0?noY/3o_jK000?o_jK000?o0000oknV`?noY/001onoY/000ol0003ob;G7olRea`03olRea`03o`00
0?oJ^k[of[^j00gof[^j00?o0000ooooooooool0OOooool005;ooooo0ol00004oin<`003o`000?nL
QK[oW8Fj00SoW8Fj00?o0000oiZ0]_nJP;H02?nJP;H00ol0003oVWjcoiYn/`08oiYn/`03o`000?nI
OK?oVGfc00WoVGfc00?o0000oiYn/onJO[<02OnJO[<00ol0003oVX2foiZ0]P0:oiZ0]P03o`000?nL
QK[oW8Fj00[oW8Fj00Co0000oin<`?nOS<3o00002onhVk/00ol0003o_jK0oknV`003oknV`003o`00
0?noY/3o_jK000So_jK000Go0000olReaoo8]LOob;G7o`00000AomZk^P03o`000?oooooooooo07co
oooo000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool4o`000003oin<`?l0003oWhc000?o
Whc000?o0000oib5^_nLQKX02?nLQKX00ol0003oVX2foiZ0]P09oiZ0]P03o`000?nJO[?oVWjc00So
VWjc00?o0000oiUm/onIOK<02?nIOK<00ol0003oVWjcoiYn/`09oiYn/`03o`000?nJP;KoVX2f00[o
VX2f00?o0000oib5^_nLQKX02_nLQKX00ol0003oWhc0o`00000<okRK^`03o`000?noY/3o_jK000?o
_jK000?o0000oknV`?noY/002OnoY/001?l0003ob;G7olReaol0000AomZk^P;o0000OOooool002Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`?o00002OnOS<000ol0003oW8Fjoib5^P08oib5
^P03o`000?nJP;KoVX2f00WoVX2f00?o0000oiYn/onJO[<02?nJO[<00ol0003oVGfcoiUm/`09oiUm
/`03o`000?nJO[?oVWjc00SoVWjc00?o0000oiZ0]_nJP;H02_nJP;H00ol0003oW8Fjoib5^P0:oib5
^P;o00003_nhVk/00ol0003o_jK0oknV`002oknV`003o`000?noY/3o_jK000Wo_jK000?o0000olRe
aol000004ooJ^kX2o`0007cooooo000Wooooo`05oa0@4?ooooooooooooooool@41007_ooool5o`00
00_oWhc000?o0000oib5^_nLQKX02?nLQKX00ol0003oVX2foiZ0]P08oiZ0]P03o`000?nJO[?oVWjc
00SoVWjc00?o0000oiUm/onIOK<02OnIOK<00ol0003oVWjcoiYn/`09oiYn/`03o`000?nJP;KoVX2f
00[oVX2f00?o0000oib5^_nLQKX02?nLQKX00ol0003o/9:go`00000>okRK^`03o`000?noY/3o_jK0
00;o_jK000?o0000oknV`?noY/002_noY/000ol0003of[^jomZk^P0ComZk^P03o`000?oooooooooo
07[ooooo000Wooooo`05o`000?ooooooooooooooool000007?ooool3o`0000;oXYO900?o0000oj:G
bOl000002_nOS<000ol0003oW8Fjoib5^P08oib5^P03o`000?nJP;KoVX2f00WoVX2f00?o0000oiYn
/onJO[<01onJO[<00ol0003oVGfcoiUm/`09oiUm/`03o`000?nJO[?oVWjc00WoVWjc00?o0000oiZ0
]_nJP;H02_nJP;H00ol0003oW8Fjoib5^P07oib5^P05o`000?n`T[Oo/9:gok2B]ol000003_nhVk/0
1Ol0003o_jK0oknV`?noY/3o000000co_jK000?o0000omZk^_oJ^kX04_oJ^kX00ol0003oi;j`o`00
001kooooo`009oooool01Ol0003ooooooooooooooooo000001Wooooo1?l00005oj:Gb@;o00002_nO
S<000ol0003oW8Fjoib5^P08oib5^P03o`000?nJP;KoVX2f00WoVX2f00?o0000oiYn/onJO[<02?nJ
O[<00ol0003oVGfcoiUm/`08oiUm/`03o`000?nJO[?oVWjc00WoVWjc00?o0000oiZ0]_nJP;H02_nJ
P;H00ol0003oW8Fjoib5^P05oib5^P;o00001?n`T[L00ol0003o^9^kokRK^`0<okRK^`05o`000?no
Y/3o_jK0oknV`?l000002onoY/000ol0003odJngo`00000ComZk^P04o`000?oT_[3o0000o`0007[o
oooo000Wooooo`05oa0@4?ooooooooooooooool@41005oooool3o`0000WoXYO900?o0000oin<`?nO
S<002OnOS<000ol0003oW8Fjoib5^P07oib5^P03o`000?nJP;KoVX2f00WoVX2f00?o0000oiYn/onJ
O[<02?nJO[<00ol0003oVGfcoiUm/`09oiUm/`03o`000?nJO[?oVWjc00WoVWjc00?o0000oiZ0]_nJ
P;H02_nJP;H00ol0003oW8Fjoib5^P03oib5^P03o`000?n`T[Oo/9:g00Co/9:g00?o0000okRK^onh
Vk/03OnhVk/01?l0003o_jK0oknV`?l0000:oknV`005o`000?oA[kOodJngom6_]ol000004OoJ^kX0
1?l0003oi;j`onBn/?oT_[02o`0007Wooooo000Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL05?oo
ool5o`000003oj:GbOl0003oXYO900SoXYO900?o0000oin<`?nOS<002?nOS<000ol0003oW8Fjoib5
^P08oib5^P03o`000?nJP;KoVX2f00SoVX2f00?o0000oiYn/onJO[<02?nJO[<00ol0003oVGfcoiUm
/`09oiUm/`03o`000?nJO[?oVWjc00WoVWjc00?o0000oiZ0]_nJP;H02_nJP;H01?l0003oW8Fjoib5
^_nLQKX2o`0000So/9:g00?o0000okRK^onhVk/03?nhVk/01?l0003o_jK0oknV`?l0000:oknV`005
o`000?oA[kOodJngom6_]ol000004OoJ^kX00ol0003oi;j`onBn/002onBn/003o`000?oooooooooo
07Oooooo000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool3o`0000CoYZOF00?o0000oj:G
bOnRUlT02?nRUlT00ol0003oWhc0oin<`008oin<`003o`000?nLQK[oW8Fj00SoW8Fj00?o0000oiZ0
]_nJP;H02OnJP;H00ol0003oVWjcoiYn/`08oiYn/`03o`000?nIOK?oVGfc00SoVGfc00?o0000oiYn
/onJO[<02OnJO[<00ol0003oVX2foiZ0]P0:oiZ0]P04o`000?nLQK[oW8Fjo`0000[o/9:g00?o0000
okRK^onhVk/03?nhVk/01?l0003o_jK0oknV`?l00009oknV`003o`000?oA[kOodJng00?odJng00?o
0000omZk^_oJ^kX03OoJ^kX00ol0003oi;j`onBn/004onBn/003o`000?oooooooooo07Kooooo000k
ooooo`Go00001OnVYmH00ol0003oXYO9oj:Gb@08oj:Gb@03o`000?nOS<3oWhc000WoWhc000?o0000
oib5^_nLQKX01onLQKX00ol0003oVX2foiZ0]P09oiZ0]P03o`000?nJO[?oVWjc00SoVWjc00?o0000
oiUm/onIOK<02OnIOK<00ol0003oVWjcoiYn/`08oiYn/`03o`000?nJP;KoVX2f00_oVX2f0_l0000<
ok2B]`03o`000?nhVk_o^9^k00co^9^k00?o0000oknV`?l000002?noY/000ol0003odJngom6_]`04
om6_]`03o`000?oJ^k[of[^j00gof[^j00?o0000onBn/?oT_[001?oT_[02o`0007Oooooo000ioooo
o`?o00002_nVYmH00ol0003oXYO9oj:Gb@08oj:Gb@03o`000?nOS<3oWhc000SoWhc000?o0000oib5
^_nLQKX02?nLQKX00ol0003oVX2foiZ0]P08oiZ0]P03o`000?nJO[?oVWjc00SoVWjc00?o0000oiUm
/onIOK<02OnIOK<00ol0003oVWjcoiYn/`09oiYn/`03o`000?nJP;KoVX2f00WoVX2f0_l0000=ok2B
]`03o`000?nhVk_o^9^k00co^9^k00?o0000oknV`?l000002?noY/000ol0003odJngom6_]`05om6_
]`03o`000?oJ^k[of[^j00_of[^j00?o0000onBn/?oT_[001_oT_[02o`0007Kooooo000gooooo`Co
00002onVYmH00ol0003oXYO9oj:Gb@08oj:Gb@03o`000?nOS<3oWhc000SoWhc000?o0000oib5^_nL
QKX02?nLQKX00ol0003oVX2foiZ0]P08oiZ0]P03o`000?nJO[?oVWjc00SoVWjc00?o0000oiUm/onI
OK<02OnIOK<00ol0003oVWjcoiYn/`09oiYn/`03o`000?nJP;KoVX2f00SoVX2f00?o0000ojV;]?l0
00003On`T[L00ol0003o^9^kokRK^`0=okRK^`;o00001onoY/000ol0003odJngom6_]`07om6_]`03
o`000?oJ^k[of[^j00[of[^j00?o0000onBn/?oT_[001ooT_[000ol0003oooooooooo`1dooooo`00
=?ooool3o`000005ojZliol0003oZ[cWojZliol000002onVYmH00ol0003oXYO9oj:Gb@08oj:Gb@03
o`000?nOS<3oWhc000SoWhc000?o0000oib5^_nLQKX01onLQKX00ol0003oVX2foiZ0]P09oiZ0]P03
o`000?nJO[?oVWjc00SoVWjc00?o0000oiUm/onIOK<02?nIOK<00ol0003oVWjcoiYn/`09oiYn/`03
o`000?nJP;KoVX2f00OoVX2f00Go0000ojV;]?nYRkCoZH^do`00000=ok2B]`03o`000?nhVk_o^9^k
00co^9^k0_l00006oknV`003o`000?oA[kOodJng00SodJng00?o0000omZk^_oJ^kX02OoJ^kX00ol0
003oi;j`onBn/009onBn/003o`000?oooooooooo07?ooooo000booooo`?o00001onZ_>L00ol0003o
YZOFojJWeP08ojJWeP03o`000?nRUlWoXYO900SoXYO900?o0000oin<`?nOS<002?nOS<000ol0003o
W8Fjoib5^P08oib5^P03o`000?nJP;KoVX2f00SoVX2f00?o0000oiYn/onJO[<02?nJO[<00ol0003o
VGfcoiUm/`09oiUm/`03o`000?nJO[?oVWjc00SoVWjc00?o0000oiZ0]_nJP;H01OnJP;H2o`0000Co
ZH^d00?o0000ok2B]on`T[L02on`T[L00ol0003o^9^kokRK^`0<okRK^`;o00001OnoY/000ol0003o
dJngom6_]`0:om6_]`03o`000?oJ^k[of[^j00Sof[^j00?o0000onBn/?oT_[002OoT_[02o`0007Co
oooo000aooooo`03o`000?nZ_>OoZ[cW00SoZ[cW00?o0000ojJWe_nVYmH02?nVYmH00ol0003oXYO9
oj:Gb@08oj:Gb@03o`000?nOS<3oWhc000SoWhc000?o0000oib5^_nLQKX02?nLQKX00ol0003oVX2f
oiZ0]P08oiZ0]P03o`000?nJO[?oVWjc00SoVWjc00?o0000oiUm/onIOK<02OnIOK<00ol0003oVWjc
oiYn/`09oiYn/`03o`000?nJP;KoVX2f00?oVX2f00?o0000ojV;]?nYRk@01?nYRk@00ol0003o/9:g
ok2B]`0;ok2B]`03o`000?nhVk_o^9^k00go^9^k00?o0000oknV`?noY/000onoY/000ol0003odJng
om6_]`0:om6_]`03o`000?oJ^k[of[^j00Sof[^j00?o0000onBn/?oT_[002_oT_[000ol0003ooooo
ooooo`1booooo`00<Oooool2o`0000[oZ[cW00?o0000ojJWe_nVYmH02?nVYmH00ol0003oXYO9oj:G
b@08oj:Gb@03o`000?nOS<3oWhc000SoWhc000?o0000oib5^_nLQKX01onLQKX00ol0003oVX2foiZ0
]P08oiZ0]P03o`000?nJO[?oVWjc00SoVWjc00?o0000oiUm/onIOK<02OnIOK<00ol0003oVWjcoiYn
/`09oiYn/`04o`000?nJP;KoVX2foiZ0]P;o00002?nYRk@00ol0003o/9:gok2B]`0;ok2B]`03o`00
0?nhVk_o^9^k00co^9^k00?o0000oknV`?noY/000_noY/000ol0003odJngom6_]`0<om6_]`03o`00
0?oJ^k[of[^j00Kof[^j00?o0000onBn/?oT_[003?oT_[000ol0003oooooooooo`1aooooo`009Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo0_l0000;ojZli`03o`000?nVYmKoYZOF00OoYZOF
00?o0000oj:GbOnRUlT02?nRUlT00ol0003oWhc0oin<`008oin<`003o`000?nLQK[oW8Fj00OoW8Fj
00?o0000oiZ0]_nJP;H02OnJP;H00ol0003oVWjcoiYn/`08oiYn/`03o`000?nIOK?oVGfc00WoVGfc
00?o0000oiYn/onJO[<02?nJO[<01?l0003oVX2foiZ0]_l0000:ojV;]003o`000?n`T[Oo/9:g00_o
/9:g00?o0000okRK^onhVk/03?nhVk/2o`0000;o_jK000?o0000om6_]ooA[kL03_oA[kL00ol0003o
f[^jomZk^P05omZk^P03o`000?oT_[3oi;j`00goi;j`00?o0000ooooooooool0L?ooool002Gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03o`000?oooooo000000[oZ[cW00?o0000ojJWe_nV
YmH02?nVYmH00ol0003oXYO9oj:Gb@07oj:Gb@03o`000?nOS<3oWhc000SoWhc000?o0000oib5^_nL
QKX02?nLQKX00ol0003oVX2foiZ0]P08oiZ0]P03o`000?nJO[?oVWjc00SoVWjc00?o0000oiUm/onI
OK<02OnIOK<00ol0003oVWjcoiYn/`09oiYn/`;o00002onYRk@00ol0003o/9:gok2B]`0<ok2B]`03
o`000?nhVk_o^9^k00_o^9^k0_l00002oknV`003o`000?oA[kOodJng00kodJng00?o0000omZk^_oJ
^kX01?oJ^kX00ol0003oi;j`onBn/00>onBn/0;o0000LOooool002Gooooo00Go410@oooooooooooo
oooooa0@4007ooooo`04o`000?ooooooooooo`0000[oZ[cW00?o0000ojJWe_nVYmH01onVYmH00ol0
003oXYO9oj:Gb@08oj:Gb@03o`000?nOS<3oWhc000SoWhc000?o0000oib5^_nLQKX01onLQKX00ol0
003oVX2foiZ0]P08oiZ0]P03o`000?nJO[?oVWjc00SoVWjc00?o0000oiUm/onIOK<02OnIOK<00ol0
003oVWjcoiYn/`08oiYn/`;o00003OnYRk@00ol0003o/9:gok2B]`0;ok2B]`03o`000?nhVk_o^9^k
00_o^9^k0_l000000onoY/3o0000om6_]`0Aom6_]`03o`000?oJ^k[of[^j00?of[^j00?o0000onBn
/?oT_[003ooT_[000ol0003oooooooooo`1_ooooo`009Oooool01Ol0003ooooooooooooooooo0000
00Kooooo0_l00003ooooo`03o`000?nZ_>OoZ[cW00SoZ[cW00?o0000ojJWe_nVYmH01onVYmH00ol0
003oXYO9oj:Gb@07oj:Gb@03o`000?nOS<3oWhc000SoWhc000?o0000oib5^_nLQKX01onLQKX00ol0
003oVX2foiZ0]P08oiZ0]P03o`000?nJO[?oVWjc00SoVWjc00?o0000oiUm/onIOK<02OnIOK<00ol0
003oVWjcoiYn/`06oiYn/`;o000000?oXhFco`000?nYRk@03?nYRk@00ol0003o/9:gok2B]`0;ok2B
]`03o`000?nhVk_o^9^k00_o^9^k00?o0000okRK^ol000004ooA[kL00ol0003of[^jomZk^P02omZk
^P03o`000?oT_[3oi;j`00ooi;j`00?o0000on[0ZOl00000L?ooool002Gooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo00?o0000ojZlionZ_>L01onZ_>L00ol0
003oYZOFojJWeP07ojJWeP03o`000?nRUlWoXYO900SoXYO900?o0000oin<`?nOS<001onOS<000ol0
003oW8Fjoib5^P08oib5^P03o`000?nJP;KoVX2f00SoVX2f00?o0000oiYn/onJO[<02?nJO[<00ol0
003oVGfcoiUm/`09oiUm/`03o`000?nJO[?oVWjc00CoVWjc00Go0000oj>5/onSQK?oXhFco`00000=
ojV;]003o`000?n`T[Oo/9:g00co/9:g00?o0000okRK^onhVk/02_nhVk/00ol0003o^9^ko`00000D
om6_]`05o`000?oJ^k[of[^jomZk^_l000004OoT_[001?l0003oj/2Yon[0ZOl0001_ooooo`009Ooo
ool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool01?ooool00ol0003oZ[cW
ojZli`07ojZli`03o`000?nVYmKoYZOF00OoYZOF00?o0000oj:GbOnRUlT01onRUlT00ol0003oWhc0
oin<`008oin<`003o`000?nLQK[oW8Fj00OoW8Fj00?o0000oiZ0]_nJP;H02?nJP;H00ol0003oVWjc
oiYn/`08oiYn/`03o`000?nIOK?oVGfc00WoVGfc00?o0000oiYn/onJO[<00_nJO[<2o`0000GoXhFc
00?o0000ojV;]?nYRk@02onYRk@00ol0003o/9:gok2B]`0;ok2B]`03o`000?nhVk_o^9^k00[o^9^k
0_l000000oo9YKGo0000om6_]`0Com6_]`03o`000?oJ^k[o000001;oi;j`00?o0000on[0ZOoZ`:T0
0_l0001^ooooo`009Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oZ[cWojZli`06ojZli`03o`000?nVYmKoYZOF00OoYZOF00?o0000oj:GbOnRUlT0
1onRUlT00ol0003oWhc0oin<`008oin<`003o`000?nLQK[oW8Fj00OoW8Fj00?o0000oiZ0]_nJP;H0
2?nJP;H00ol0003oVWjcoiYn/`08oiYn/`03o`000?nIOK?oVGfc00WoVGfc00?o0000oiYn/onJO[<0
0_l00007oj>5/`03o`000?nYRkCoZH^d00_oZH^d00?o0000ok2B]on`T[L03?n`T[L00ol0003o^9^k
okRK^`09okRK^`04o`000?o9YKGobJFeo`0001CodJng00?o0000omZk^_l000004OoT_[000ol0003o
j/2Yon[0Z@02on[0Z@03o`000?oooooooooo06cooooo000Uooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oooooooooo`06ooooo`03o`000?nZ_>OoZ[cW00KoZ[cW00?o0000ojJWe_nV
YmH01onVYmH00ol0003oXYO9oj:Gb@07oj:Gb@03o`000?nOS<3oWhc000OoWhc000?o0000oib5^_nL
QKX02?nLQKX00ol0003oVX2foiZ0]P08oiZ0]P03o`000?nJO[?oVWjc00OoVWjc00?o0000oiUm/onI
OK<02_nIOK<2o`0000WoXhFc00?o0000ojV;]?nYRk@02onYRk@00ol0003o/9:gok2B]`0<ok2B]`03
o`000?nhVk_o^9^k00So^9^k0_l00003olVU]@03o`000?oA[kOodJng01;odJng00?o0000onBn/?oT
_[004?oT_[000ol0003oj/2Yon[0Z@03on[0Z@03o`000?oooooooooo06_ooooo000`ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ojZlionZ_>L01_nZ_>L00ol0003oYZOFojJWeP06ojJWeP03o`00
0?nRUlWoXYO900OoXYO900?o0000oin<`?nOS<002?nOS<000ol0003oW8Fjoib5^P07oib5^P03o`00
0?nJP;KoVX2f00SoVX2f00?o0000oiYn/onJO[<02?nJO[<00ol0003oVGfcoiUm/`08oiUm/`;o0000
2onSQK<00ol0003oZH^dojV;]00;ojV;]003o`000?n`T[Oo/9:g00_o/9:g00?o0000okRK^onhVk/0
2?nhVk/2o`0000?obJFe00?o0000om6_]ooA[kL04_oA[kL00ol0003oi;j`onBn/00?onBn/003o`00
0?oZ`:Woj/2Y00Goj/2Y00?o0000ooooooooool0J_ooool0033ooooo00?o0000ooooooooool02?oo
ool00ol0003oZ[cWojZli`05ojZli`03o`000?nVYmKoYZOF00OoYZOF00?o0000oj:GbOnRUlT01_nR
UlT00ol0003oWhc0oin<`008oin<`003o`000?nLQK[oW8Fj00OoW8Fj00?o0000oiZ0]_nJP;H02?nJ
P;H00ol0003oVWjcoiYn/`08oiYn/`03o`000?nIOK?oVGfc00KoVGfc0_l000000onMPKCo0000oj>5
/`0:oj>5/`03o`000?nYRkCoZH^d00_oZH^d00?o0000ok2B]on`T[L03?n`T[L00ol0003o^9^kokRK
^`06okRK^`03o`000?o9YKGo000000CobJFe00?o0000om6_]ooA[kL04?oA[kL00ol0003ogKJ`o`00
000@onBn/003o`000?oZ`:Woj/2Y00Goj/2Y00?o0000ooooooooool0J_ooool002oooooo0_l0000;
ooooo`03o`000?nZ_>OoZ[cW00GoZ[cW00?o0000ojJWe_nVYmH01_nVYmH00ol0003oXYO9oj:Gb@07
oj:Gb@03o`000?nOS<3oWhc000OoWhc000?o0000oib5^_nLQKX01onLQKX00ol0003oVX2foiZ0]P08
oiZ0]P03o`000?nJO[?oVWjc00SoVWjc00?o0000oiUm/onIOK<00onIOK<3o`0000?oWH6d00?o0000
oj>5/onSQK<02OnSQK<00ol0003oZH^dojV;]00;ojV;]003o`000?n`T[Oo/9:g00co/9:g00?o0000
okRK^onhVk/01OnhVk/01?l0003obJFeolVU]Ol00004olVU]@03o`000?oA[kOodJng013odJng00?o
0000omff/?l000004?oT_[000ol0003oj/2Yon[0Z@06on[0Z@03o`000?oooooooooo06Wooooo000`
ooooo`03o`000?oooooooooo00[ooooo00?o0000ojZlionZ_>L01OnZ_>L00ol0003oYZOFojJWeP05
ojJWeP03o`000?nRUlWoXYO900OoXYO900?o0000oin<`?nOS<002?nOS<000ol0003oW8Fjoib5^P07
oib5^P03o`000?nJP;KoVX2f00SoVX2f00?o0000oiYn/onJO[<01onJO[<01?l0003oVGfcoiUm/onI
OK<2o`0000OoWH6d00?o0000oj>5/onSQK<02OnSQK<00ol0003oZH^dojV;]00;ojV;]003o`000?n`
T[Oo/9:g00_o/9:g00?o0000okRK^onhVk/01OnhVk/01?l0003obJFeolVU]Ol00005olVU]@03o`00
0?oA[kOodJng00kodJng00Go0000omff/?oM][3ogKJ`o`00000>onBn/003o`000?oZ`:Woj/2Y00So
j/2Y00?o0000ooooooooool0J?ooool002oooooo00?o0000ooooooooool03?ooool3o`0000CoZ[cW
00?o0000ojJWe_nVYmH01_nVYmH00ol0003oXYO9oj:Gb@07oj:Gb@03o`000?nOS<3oWhc000OoWhc0
00?o0000oib5^_nLQKX01onLQKX00ol0003oVX2foiZ0]P08oiZ0]P03o`000?nJO[?oVWjc00SoVWjc
0ol00009oif1]003o`000?nSQK?oXhFc00WoXhFc00?o0000ojV;]?nYRk@02onYRk@00ol0003o/9:g
ok2B]`0<ok2B]`03o`000?nhVk_o^9^k00?o^9^k00Go0000olVU]Oo9YKGobJFeo`000005olVU]@03
o`000?oA[kOodJng00kodJng00?o0000omff/?oM][000_oM][000ol0003oi;j`onBn/00;onBn/003
o`000?oZ`:Woj/2Y00Woj/2Y00?o0000ooooooooool0Ioooool002oooooo00?o0000ooooooooool0
3Oooool00ol0003o?H_]o`000005o`0000OoYZOF00?o0000oj:GbOnRUlT01onRUlT00ol0003oWhc0
oin<`007oin<`003o`000?nLQK[oW8Fj00OoW8Fj00?o0000oiZ0]_nJP;H02?nJP;H00ol0003oVWjc
oiYn/`06oiYn/`?o00002onMPK@00ol0003oXhFcoj>5/`09oj>5/`03o`000?nYRkCoZH^d00_oZH^d
00?o0000ok2B]on`T[L03?n`T[L00ol0003o^9^kokRK^`02okRK^`03o`000?o9YKGobJFe00;obJFe
00?o0000olVU]Oo9YKD01?o9YKD00ol0003odJngom6_]`0<om6_]`03o`000?oM][3ogKJ`00?ogKJ`
00?o0000onBn/?oT_[002_oT_[000ol0003oj/2Yon[0Z@0:on[0Z@03o`000?oooooooooo06Oooooo
000_ooooo`03o`000?oooooooooo00kooooo00?o0000ocf;kOlmRnd00olmRnd4o`0000GoYZOF00?o
0000oj:GbOnRUlT01_nRUlT00ol0003oWhc0oin<`008oin<`003o`000?nLQK[oW8Fj00OoW8Fj00?o
0000oiZ0]_nJP;H01onJP;H00ol0003oVWjcoiYn/`03oiYn/`?o00000_nGOKD00ol0003oWH6doif1
]009oif1]003o`000?nSQK?oXhFc00[oXhFc00?o0000ojV;]?nYRk@02onYRk@00ol0003o/9:gok2B
]`0<ok2B]`04o`000?nhVk_o^9^ko`0000GobJFe00?o0000olVU]Oo9YKD01?o9YKD00ol0003odJng
om6_]`0<om6_]`03o`000?oM][3ogKJ`00CogKJ`00?o0000onBn/?oT_[002OoT_[000ol0003oj/2Y
on[0Z@0;on[0Z@03o`000?oooooooooo06Kooooo000_ooooo`03o`000?oooooooooo00oooooo00?o
0000ocf;kOlmRnd00olmRnd00ol0003oGXGPoej5h006o`0000WoXYO900?o0000oin<`?nOS<001onO
S<000ol0003oW8Fjoib5^P07oib5^P03o`000?nJP;KoVX2f00SoVX2f00?o0000oiYn/ol000000_l0
0005oiMm]@03o`000?nMPKCoWH6d00[oWH6d00?o0000oj>5/onSQK<02OnSQK<00ol0003oZH^dojV;
]00;ojV;]003o`000?n`T[Oo/9:g00co/9:g00Co0000okRK^onhVk_o00001Oo9YKD00ol0003obJFe
olVU]@05olVU]@03o`000?oA[kOodJng00[odJng00?o0000omff/?oM][001OoM][000ol0003oi;j`
onBn/009onBn/003o`000?oZ`:Woj/2Y00coj/2Y00?o0000ooooooooool0IOooool002kooooo0ol0
000Aooooo`03o`000?lmRngo?H_]00?o?H_]00?o0000oej5h?mNQN001?mNQN05o`0000GoXYO900?o
0000oin<`?nOS<001onOS<000ol0003oW8Fjoib5^P07oib5^P03o`000?nJP;KoVX2f00KoVX2f1?l0
0009oiMm]@03o`000?nMPKCoWH6d00WoWH6d00?o0000oj>5/onSQK<02OnSQK<00ol0003oZH^dojV;
]00;ojV;]003o`000?n`T[Oo/9:g00co/9:g00?o0000okRK^ol000001_o9YKD00ol0003obJFeolVU
]@05olVU]@03o`000?oA[kOodJng00[odJng00?o0000omff/?oM][001_oM][000ol0003oi;j`onBn
/007onBn/003o`000?oZ`:Woj/2Y00goj/2Y0_l0001Vooooo`00;oooool00ol0003oooooooooo`0A
ooooo`03o`000?lmRngo?H_]00?o?H_]00?o0000oej5h?mNQN001?mNQN001?l0003oLWoAog9odOmb
Om46o`0000[oWhc000?o0000oib5^_nLQKX01onLQKX00ol0003oVX2foiZ0]P05o`0000;oT7^h00?o
0000oiMm]OnGOKD02?nGOKD00ol0003oWH6doif1]009oif1]003o`000?nSQK?oXhFc00WoXhFc00?o
0000ojV;]?nYRk@03?nYRk@00ol0003o/9:gok2B]`0<ok2B]`03o`000?o9YKGobJFe00GobJFe00?o
0000olVU]Oo9YKD01Oo9YKD00ol0003odJngom6_]`09om6_]`03o`000?oM][3ogKJ`00SogKJ`00?o
0000onBn/?oT_[001_oT_[000ol0003oj/2Yon[0Z@0<on[0Z@03o`000?o^`JCo000006Kooooo000_
ooooo`03o`000?oooooooooo01;ooooo00?o0000ocf;kOlmRnd00_lmRnd00ol0003oGXGPoej5h005
oej5h003o`000?mbOm7oLWoA00GoLWoA6?l00007oi1k^003o`000?nGOKGoUgfe00SoUgfe00?o0000
oif1]?nMPK@02_nMPK@00ol0003oXhFcoj>5/`09oj>5/`03o`000?nYRkCoZH^d00_oZH^d00?o0000
ok2B]on`T[L03?n`T[L00ol0003obJFeolVU]@05olVU]@03o`000?o9YKGobJFe00KobJFe00?o0000
om6_]ooA[kL01ooA[kL00ol0003ogKJ`omff/009omff/003o`000?oT_[3oi;j`00Goi;j`00?o0000
on[0ZOoZ`:T03OoZ`:T01?l0003ok/6Tonk1Y?l0001Uooooo`00;oooool00ol0003oooooooooo`0C
ooooo`03o`000?lmRngo?H_]00;o?H_]00?o0000oej5h?mNQN001?mNQN000ol0003oLWoAog9od@06
og9od@03o`000?moNlGoOg_500OoOg_500?o0000ohQk__n8Nkh01on8Nkh00ol0003oT7^hoi1k^008
oi1k^003o`000?nGOKGoUgfe00OoUgfe00?o0000oif1]?nMPK@02_nMPK@00ol0003oXhFcoj>5/`09
oj>5/`03o`000?nYRkCoZH^d00_oZH^d00?o0000ok2B]on`T[L02on`T[L00ol0003o`9fdo`000006
olVU]@03o`000?o9YKGobJFe00KobJFe00?o0000om6_]ooA[kL01ooA[kL00ol0003ogKJ`omff/00:
omff/003o`000?oT_[3oi;j`00Coi;j`00?o0000on[0ZOoZ`:T03OoZ`:T01Ol0003ok/6Tonk1Y?o^
`JCo000006Cooooo000_ooooo`03o`000?oooooooooo01?ooooo0_l00004ocf;k@03o`000?mNQN3o
GXGP00CoGXGP00?o0000og9odOmbOm401_mbOm400ol0003oOg_5ogmka@06ogmka@03o`000?n8Nkko
R7^n00OoR7^n00?o0000oi1k^?n@NkP02?n@NkP00ol0003oUgfeoiMm]@08oiMm]@03o`000?nMPKCo
WH6d00WoWH6d00?o0000oj>5/onSQK<02OnSQK<00ol0003oZH^dojV;]00<ojV;]003o`000?n`T[Oo
/9:g00Wo/9:g00Co0000ol2M]?o0WKCo00001_o9YKD00ol0003obJFeolVU]@07olVU]@03o`000?oA
[kOodJng00GodJng00?o0000omff/?oM][002ooM][000ol0003oi;j`onBn/004onBn/003o`000?oZ
`:Woj/2Y00coj/2Y00?o0000onk1Y?o^`J@00_o^`J@2o`0006?ooooo000^ooooo`03o`000?oooooo
oooo01Gooooo0_l00003ocf;k@03o`000?mNQN3oGXGP00CoGXGP00?o0000og9odOmbOm401_mbOm40
0ol0003oOg_5ogmka@07ogmka@03o`000?n8NkkoR7^n00OoR7^n00?o0000oi1k^?n@NkP01on@NkP0
0ol0003oUgfeoiMm]@08oiMm]@03o`000?nMPKCoWH6d00WoWH6d00?o0000oj>5/onSQK<02_nSQK<0
0ol0003oZH^dojV;]00;ojV;]003o`000?n`T[Oo/9:g00So/9:g00Go0000ol2M]?o0WKCo`9fdo`00
0006olVU]@03o`000?o9YKGobJFe00OobJFe00?o0000om6_]ooA[kL01OoA[kL00ol0003ogKJ`omff
/00<omff/003o`000?oT_[3oi;j`00;oi;j`00?o0000on[0ZOoZ`:T03OoZ`:T00ol0003ok/6Tonk1
Y003onk1Y003o`000?oooooooooo067ooooo000^ooooo`?o00005_ooool2o`0000?o?H_]00?o0000
oej5h?mNQN001?mNQN000ol0003oLWoAog9od@05og9od@03o`000?moNlGoOg_500OoOg_500?o0000
ohQk__n8Nkh01on8Nkh00ol0003oT7^hoi1k^008oi1k^003o`000?nGOKGoUgfe00OoUgfe00?o0000
oif1]?nMPK@02_nMPK@00ol0003oXhFcoj>5/`09oj>5/`03o`000?nYRkCoZH^d00_oZH^d00?o0000
ok2B]on`T[L01on`T[L00ol0003o`9fdol2M]003ol2M]003o`000?o9YKGobJFe00?obJFe00?o0000
olVU]Oo9YKD02?o9YKD00ol0003odJngom6_]`03om6_]`03o`000?oM][3ogKJ`00gogKJ`00?o0000
onBn/?oT_[000_oT_[000ol0003oj/2Yon[0Z@0=on[0Z@03o`000?o^`JCok/6T00Cok/6T00?o0000
ooooooooool0H?ooool002kooooo00?o0000ooooooooool05oooool2o`0000?o?H_]00?o0000oej5
h?mNQN000omNQN000ol0003oLWoAog9od@06og9od@03o`000?moNlGoOg_500KoOg_500?o0000ohQk
__n8Nkh01on8Nkh00ol0003oT7^hoi1k^008oi1k^003o`000?nGOKGoUgfe00SoUgfe00?o0000oif1
]?nMPK@02OnMPK@00ol0003oXhFcoj>5/`09oj>5/`03o`000?nYRkCoZH^d00coZH^d00?o0000ok2B
]on`T[L01On`T[L00ol0003o`9fdol2M]004ol2M]003o`000?o9YKGobJFe00?obJFe00?o0000olVU
]Oo9YKD02?o9YKD00ol0003odJngom6_]`03om6_]`03o`000?oM][3ogKJ`00kogKJ`00Co0000onBn
/?oT_[3o00003ooZ`:T00ol0003ok/6Tonk1Y006onk1Y003o`000?oooooooooo05oooooo000Boooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00007ooooo`03o`000?oooooo
oooo01Sooooo0_l00002ocf;k@03o`000?mNQN3oGXGP00CoGXGP00?o0000og9odOmbOm401OmbOm40
0ol0003oOg_5ogmka@07ogmka@03o`000?n8NkkoR7^n00OoR7^n00?o0000oi1k^?n@NkP01on@NkP0
0ol0003oUgfeoiMm]@08oiMm]@03o`000?nMPKCoWH6d00WoWH6d00?o0000oj>5/onSQK<02_nSQK<0
0ol0003oZH^dojV;]00;ojV;]003o`000?n`T[Oo/9:g00Co/9:g00?o0000ol2M]?o0WK@01Oo0WK@0
0ol0003obJFeolVU]@03olVU]@03o`000?o9YKGobJFe00WobJFe00Go0000om6_]ooA[kOodJngo`00
000Bomff/003o`000?oT_[3o000000ooj/2Y00?o0000onk1Y?o^`J@01oo^`J@00ol0003ooooooooo
o`1Nooooo`004_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01oooool00ol0003oooooooooo`0Iooooo`;o00000_lmRnd00ol0003oGXGP
oej5h003oej5h003o`000?mbOm7oLWoA00KoLWoA00?o0000ogmkaOmoNlD01_moNlD00ol0003oR7^n
ohQk_P07ohQk_P03o`000?n@NkSoT7^h00OoT7^h00?o0000oiMm]OnGOKD02?nGOKD00ol0003oWH6d
oif1]009oif1]003o`000?nSQK?oXhFc00[oXhFc00?o0000ojV;]?nYRk@02onYRk@00ol0003o/9:g
ok2B]`04ok2B]`03o`000?o0WKCo`9fd00Ko`9fd00?o0000olVU]Oo9YKD00_o9YKD00ol0003obJFe
olVU]@09olVU]@05o`000?oA[kOodJngom6_]ol000004_oM][000ol0003oi;j`o`00000?on[0Z@03
o`000?o^`JCok/6T00Ook/6T00?o0000ooooooooool0G_ooool001;ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Sooooo00?o0000ooooooooool06_ooool2o`000003
ocf;kOl0003oGXGP00GoGXGP00?o0000og9odOmbOm401OmbOm400ol0003oOg_5ogmka@06ogmka@03
o`000?n8NkkoR7^n00OoR7^n00?o0000oi1k^?n@NkP02?n@NkP00ol0003oUgfeoiMm]@07oiMm]@03
o`000?nMPKCoWH6d00[oWH6d00?o0000oj>5/onSQK<02OnSQK<00ol0003oZH^dojV;]00<ojV;]003
o`000?n`T[Oo/9:g00;o/9:g00?o0000ol2M]?o0WK@01oo0WK@00ol0003obJFeolVU]@02olVU]@03
o`000?o9YKGobJFe00[obJFe00?o0000om6_]ol000005?oM][000ol0003oj/2Yon[0Z@0=on[0Z@03
o`000?o^`JCok/6T00Wok/6T00?o0000ooooooooool0GOooool001;ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool06oooool2o`000003
ocf;kOl0003oGXGP00CoGXGP00?o0000og9odOmbOm401OmbOm400ol0003oOg_5ogmka@07ogmka@03
o`000?n8NkkoR7^n00KoR7^n00?o0000oi1k^?n@NkP02?n@NkP00ol0003oUgfeoiMm]@08oiMm]@03
o`000?nMPKCoWH6d00WoWH6d00?o0000oj>5/onSQK<02_nSQK<00ol0003oZH^dojV;]00;ojV;]005
o`000?n`T[Oo/9:gok2B]ol000002_o0WK@00ol0003obJFeolVU]@02olVU]@03o`000?o9YKGobJFe
00[obJFe00?o0000om6_]ol000005?oM][000ol0003oj/2Yon[0Z@0=on[0Z@03o`000?o^`JCok/6T
00[ok/6T00?o0000ooooooooool0G?ooool001;ooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo00Kooooo00?o0000ooooooooool07?ooool2o`000003ocf;kOl0003oGXGP
00CoGXGP00?o0000og9odOmbOm401OmbOm400ol0003oOg_5ogmka@06ogmka@03o`000?n8NkkoR7^n
00OoR7^n00?o0000oi1k^?n@NkP01on@NkP00ol0003oUgfeoiMm]@08oiMm]@03o`000?nMPKCoWH6d
00WoWH6d00?o0000oj>5/onSQK<02_nSQK<00ol0003oZH^dojV;]00;ojV;]004o`000?n`T[Oo/9:g
o`0000co`9fd00Go0000olVU]Oo9YKGobJFeo`00000=olVU]@03o`000?oM][3ogKJ`01;ogKJ`00?o
0000onFjZ_l000003_oZ`:T00ol0003ok/6Tonk1Y00;onk1Y003o`000?oooooooooo05_ooooo000B
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`;o00007ooo
ool3o`0000GoGXGP00?o0000og9odOmbOm401OmbOm400ol0003oOg_5ogmka@06ogmka@03o`000?n8
NkkoR7^n00OoR7^n00?o0000oi1k^?n@NkP01on@NkP00ol0003oUgfeoiMm]@08oiMm]@03o`000?nM
PKCoWH6d00[oWH6d00?o0000oj>5/onSQK<02OnSQK<00ol0003oZH^dojV;]00<ojV;]0;o00003Oo0
WK@01Ol0003obJFeolVU]Oo9YKGo000000gobJFe00?o0000omff/?oM][004_oM][000ol0003oiKZZ
o`00000=on[0Z@03o`000?o^`JCok/6T00cok/6T00?o0000ooooooooool0Foooool001;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003o
ooooooooo`0Oooooo`?o00001?mNQN000ol0003oLWoAog9od@06og9od@03o`000?moNlGoOg_500Ko
Og_500?o0000ohQk__n8Nkh01_n8Nkh00ol0003oT7^hoi1k^008oi1k^003o`000?nGOKGoUgfe00Oo
Ugfe00?o0000oif1]?nMPK@02_nMPK@00ol0003oXhFcoj>5/`09oj>5/`03o`000?nYRkCoZH^d00co
ZH^d00?o0000ol2M]?o0WK@03Oo0WK@01?l0003obJFeolVU]Ol0000<olVU]@03o`000?oF[[3o0000
01;ogKJ`00Go0000onFjZ_oU^Z[oiKZZo`00000<on[0Z@03o`000?o^`JCok/6T00cok/6T0_l0001L
ooooo`004_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c006ooooo`03o`000?oooooooooo023ooooo0ol00004oej5h003o`000?mbOm7oLWoA00GoLWoA00?o
0000ogmkaOmoNlD01_moNlD00ol0003oR7^nohQk_P07ohQk_P03o`000?n@NkSoT7^h00OoT7^h00?o
0000oiMm]OnGOKD02?nGOKD00ol0003oWH6doif1]009oif1]003o`000?nSQK?oXhFc00[oXhFc00?o
0000ojV;]?nYRk@02_nYRk@2o`0000oo`9fd00Co0000olVU]Oo9YKGo00003?o9YKD00ol0003oeZj`
o`00000Bomff/003o`000?oU^Z[oiKZZ00;oiKZZ00?o0000on[0ZOoZ`:T02?oZ`:T00ol0003ok/6T
onk1Y00<onk1Y004o`000?oa`j7olL>Qo`0005_ooooo000]ooooo`03o`000?oooooooooo027ooooo
0_l00004oej5h003o`000?mbOm7oLWoA00GoLWoA00?o0000ogmkaOmoNlD01_moNlD00ol0003oR7^n
ohQk_P07ohQk_P03o`000?n@NkSoT7^h00OoT7^h00?o0000oiMm]OnGOKD02?nGOKD00ol0003oWH6d
oif1]009oif1]003o`000?nSQK?oXhFc00[oXhFc00?o0000ojV;]?nYRk@02OnYRk@00ol0003o]iBd
o`00000?ol2M]004o`000?o9YKGobJFeo`0000_obJFe00Go0000omJ^/?oF[[3oeZj`o`00000Aomff
/003o`000?oU^Z[oiKZZ00;oiKZZ00?o0000on[0ZOoZ`:T02?oZ`:T00ol0003ok/6Tonk1Y00<onk1
Y005o`000?oa`j7olL>Qoo73XOl00000F_ooool002gooooo00?o0000ooooooooool08Oooool00ol0
003o00f?o`000004oej5h003o`000?mbOm7oLWoA00GoLWoA00?o0000ogmkaOmoNlD01_moNlD00ol0
003oR7^nohQk_P06ohQk_P03o`000?n@NkSoT7^h00SoT7^h00?o0000oiMm]OnGOKD01onGOKD00ol0
003oWH6doif1]00:oif1]003o`000?nSQK?oXhFc00WoXhFc00?o0000ojV;]?nYRk@02?nYRk@01Ol0
003o]iBdokND]?ngU;Co000000oo`9fd00?o0000olVU]Ol000002_o9YKD00ol0003oeZj`omJ^/002
omJ^/003o`000?oM][3ogKJ`00kogKJ`00?o0000onFjZ_oU^ZX01?oU^ZX00ol0003oj/2Yon[0Z@07
on[0Z@03o`000?o^`JCok/6T00cok/6T00Go0000oo73XOoa`j7olL>Qo`00001Jooooo`00;Oooool0
0ol0003oooooooooo`0Rooooo`04o`000?l03Hoo0000o`0000;oGXGP00?o0000og9odOmbOm401Omb
Om400ol0003oOg_5ogmka@06ogmka@03o`000?n8NkkoR7^n00KoR7^n00?o0000oi1k^?n@NkP02?n@
NkP00ol0003oUgfeoiMm]@08oiMm]@03o`000?nMPKCoWH6d00WoWH6d00?o0000oj>5/onSQK<02_nS
QK<00ol0003oZH^dojV;]006ojV;]003o`000?ngU;Co]iBd00;o]iBd00?o0000ol2M]?o0WK@03Oo0
WK@00ol0003obJFeo`00000:olVU]@03o`000?oF[[3oeZj`00?oeZj`00?o0000omff/?oM][003OoM
][000ol0003oiKZZonFjZP04onFjZP03o`000?oZ`:Woj/2Y00Koj/2Y00?o0000onk1Y?o^`J@03?o^
`J@00ol0003olL>Qoo73X@03oo73X@03o`000?oooooooooo05Oooooo000/ooooo`?o00009?ooool2
o`000005o`0`^?l0003oGXGPoej5h?l000001ombOm400ol0003oOg_5ogmka@05ogmka@03o`000?n8
NkkoR7^n00OoR7^n00?o0000oi1k^?n@NkP01on@NkP00ol0003oUgfeoiMm]@08oiMm]@03o`000?nM
PKCoWH6d00WoWH6d00?o0000oj>5/onSQK<02_nSQK<00ol0003oZH^dojV;]005ojV;]003o`000?ng
U;Co]iBd00?o]iBd00?o0000ol2M]?o0WK@03Oo0WK@00ol0003obJFeo`000009olVU]@03o`000?oF
[[3oeZj`00CoeZj`00?o0000omff/?oM][003?oM][000ol0003oiKZZonFjZP06onFjZP03o`000?oZ
`:Woj/2Y00Goj/2Y00?o0000onk1Y?o^`J@03?o^`J@00ol0003olL>Qoo73X@04oo73X@03o`000?oo
oooooooo05Kooooo000]ooooo`03o`000?oooooooooo02Cooooo0_l000001?l0<;So0000oej5h?l0
0007og9od@03o`000?moNlGoOg_500KoOg_500?o0000ohQk__n8Nkh01_n8Nkh00ol0003oT7^hoi1k
^007oi1k^003o`000?nGOKGoUgfe00SoUgfe00?o0000oif1]?nMPK@02OnMPK@00ol0003oXhFcoj>5
/`0:oj>5/`03o`000?nYRkCoZH^d00CoZH^d00?o0000okND]?ngU;@01OngU;@00ol0003o`9fdol2M
]00=ol2M]0;o00002Oo9YKD00ol0003oeZj`omJ^/005omJ^/003o`000?oM][3ogKJ`00_ogKJ`00?o
0000onFjZ_oU^ZX01ooU^ZX00ol0003oj/2Yon[0Z@04on[0Z@03o`000?o^`JCok/6T00cok/6T00?o
0000oo73XOoa`j401Ooa`j400ol0003oooooooooo`1Eooooo`00;Oooool00ol0003oooooooooo`0U
ooooo`;o000000Co032ho`000?mNQN3o00001_mbOm400ol0003oOg_5ogmka@06ogmka@03o`000?n8
NkkoR7^n00KoR7^n00?o0000oi1k^?n@NkP02?n@NkP00ol0003oUgfeoiMm]@07oiMm]@03o`000?nM
PKCoWH6d00[oWH6d00?o0000oj>5/onSQK<02_nSQK<00ol0003oZH^dojV;]002ojV;]003o`000?ng
U;Co]iBd00Ko]iBd00?o0000ol2M]?o0WK@03Oo0WK@2o`0000SobJFe00?o0000omJ^/?oF[[001_oF
[[000ol0003ogKJ`omff/00:omff/003o`000?oU^Z[oiKZZ00SoiKZZ00?o0000on[0ZOoZ`:T00ooZ
`:T00ol0003ok/6Tonk1Y00<onk1Y003o`000?oa`j7olL>Q00KolL>Q0_l0001Fooooo`00;Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?l0<;So032h00;o00001ombOm400ol0003oOg_5ogmka@05
ogmka@03o`000?n8NkkoR7^n00OoR7^n00?o0000oi1k^?n@NkP01on@NkP00ol0003oUgfeoiMm]@08
oiMm]@03o`000?nMPKCoWH6d00WoWH6d00?o0000oj>5/onSQK<02_nSQK<01Ol0003oZH^dojV;]?nY
RkCo000000Wo]iBd00?o0000ol2M]?o0WK@03_o0WK@00ol0003obJFeolVU]@05olVU]@03o`000?oF
[[3oeZj`00SoeZj`00?o0000omff/?oM][002OoM][000ol0003oiKZZonFjZP09onFjZP03o`000?oZ
`:Woj/2Y00;oj/2Y00?o0000onk1Y?o^`J@03?o^`J@00ol0003olL>Qoo73X@07oo73X@03o`000?oo
oooooooo05Cooooo000/ooooo`03o`000?oooooooooo02Sooooo00?o0000o`0`^?l0<;P00_l00006
og9od@03o`000?moNlGoOg_500GoOg_500?o0000ohQk__n8Nkh01on8Nkh00ol0003oT7^hoi1k^007
oi1k^003o`000?nGOKGoUgfe00SoUgfe00?o0000oif1]?nMPK@02OnMPK@00ol0003oXhFcoj>5/`0:
oj>5/`04o`000?nYRkCoZH^do`0000_o]iBd00?o0000ol2M]?o0WK@03Oo0WK@00ol0003obJFeolVU
]@05olVU]@03o`000?oF[[3oeZj`00SoeZj`00?o0000omff/?oM][002?oM][000ol0003oiKZZonFj
ZP0:onFjZP03o`000?oZ`:Woj/2Y00;oj/2Y00?o0000onk1Y?o^`J@03?o^`J@00ol0003olL>Qoo73
X@08oo73X@03o`000?oooooooooo05?ooooo000/ooooo`03o`000?oooooooooo02Sooooo0_l00002
o`0`^003o`000?mbOm7oLWoA00GoLWoA00?o0000ogmkaOmoNlD01OmoNlD00ol0003oR7^nohQk_P06
ohQk_P03o`000?n@NkSoT7^h00OoT7^h00?o0000oiMm]OnGOKD02?nGOKD00ol0003oWH6doif1]009
oif1]003o`000?nSQK?oXhFc00_oXhFc0_l0000<okND]003o`000?o0WKCo`9fd00go`9fd00?o0000
olVU]Oo9YKD01?o9YKD00ol0003oeZj`omJ^/00:omJ^/003o`000?oM][3ogKJ`00OogKJ`00?o0000
onFjZ_oU^ZX02ooU^ZX01?l0003oj/2Yon[0ZOl0000?onk1Y003o`000?oa`j7olL>Q00WolL>Q00?o
0000ooooooooool0D_ooool002cooooo0_l0000Zooooo`04o`000?l0<;So032ho`0`^0;o00001Omb
Om400ol0003oOg_5ogmka@05ogmka@03o`000?n8NkkoR7^n00OoR7^n00?o0000oi1k^?n@NkP01on@
NkP00ol0003oUgfeoiMm]@07oiMm]@03o`000?nMPKCoWH6d00[oWH6d00?o0000oj>5/onSQK<02OnS
QK<2o`0000go]iBd00?o0000ol2M]?o0WK@03Oo0WK@2o`0000GobJFe00?o0000omJ^/?oF[[002_oF
[[000ol0003ogKJ`omff/007omff/003o`000?oU^Z[oiKZZ00coiKZZ00?o0000on[0ZOl000003_o^
`J@00ol0003olL>Qoo73X@0:oo73X@;o0000Doooool002cooooo00?o0000ooooooooool0:_ooool0
1_l0003o032ho`0`^?l0003o6dg7o`0000CoLWoA00?o0000ogmkaOmoNlD01OmoNlD00ol0003oR7^n
ohQk_P07ohQk_P03o`000?n@NkSoT7^h00OoT7^h00?o0000oiMm]OnGOKD02?nGOKD00ol0003oWH6d
oif1]009oif1]003o`000?nSQK?oXhFc00SoXhFc00?o0000ojf=]Ol000003_ngU;@00ol0003o`9fd
ol2M]00<ol2M]0;o00001?o9YKD00ol0003oeZj`omJ^/00;omJ^/003o`000?oM][3ogKJ`00KogKJ`
00?o0000onFjZ_oU^ZX03OoU^ZX00ol0003oj/2Yo`00000>onk1Y003o`000?oa`j7olL>Q00_olL>Q
00?o0000ooooooooool0DOooool002cooooo00?o0000ooooooooool0:_ooool2o`0000;o032h00Co
0000oa]=aol0003o00000ombOm400ol0003oOg_5ogmka@05ogmka@03o`000?n8NkkoR7^n00KoR7^n
00?o0000oi1k^?n@NkP01on@NkP00ol0003oUgfeoiMm]@08oiMm]@03o`000?nMPKCoWH6d00WoWH6d
00?o0000oj>5/onSQK<01onSQK<01Ol0003o[Hfeojf=]On]SKGo000000go]iBd00?o0000ol2M]?o0
WK@03?o0WK@2o`0000CobJFe00?o0000omJ^/?oF[[003?oF[[000ol0003ogKJ`omff/005omff/003
o`000?oU^Z[oiKZZ00koiKZZ00?o0000onk1Y?o^`J@03Oo^`J@00ol0003olL>Qoo73X@0;oo73X@;o
0000D_ooool002cooooo00?o0000ooooooooool0:oooool01?l0003o032ho`0`^?l00003oa]=a`04
o`000?mbOm7oLWoAo`0000OoOg_500?o0000ohQk__n8Nkh01_n8Nkh00ol0003oT7^hoi1k^008oi1k
^003o`000?nGOKGoUgfe00OoUgfe00?o0000oif1]?nMPK@02_nMPK@00ol0003oXhFcoj>5/`04oj>5
/`;o00001?n]SKD00ol0003o]iBdokND]00;okND]003o`000?o0WKCo`9fd00co`9fd00?o0000ol2M
]?l000000_o9YKD00ol0003oeZj`omJ^/00=omJ^/003o`000?oM][3ogKJ`00CogKJ`00?o0000onFj
Z_oU^ZX03ooU^ZX00ol0003ok/6Tonk1Y00<onk1Y003o`000?oa`j7olL>Q00_olL>Q00Co0000oo?5
WoocaIoo0000DOooool002cooooo00?o0000ooooooooool0;?ooool01?l0003o032ho`0`^?l00003
oa]=a`04o`000?mbOm7oLWoAo`0000KoOg_500?o0000ohQk__n8Nkh01on8Nkh00ol0003oT7^hoi1k
^007oi1k^003o`000?nGOKGoUgfe00OoUgfe00?o0000oif1]?nMPK@02_nMPK@00ol0003oXhFcoj>5
/`03oj>5/`03o`000?n]SKGo[Hfe00Co[Hfe00?o0000okND]?ngU;@03?ngU;@00ol0003o`9fdol2M
]00;ol2M]005o`000?o0WKCo0000olVU]Ol000004OoF[[000ol0003ogKJ`omff/003omff/003o`00
0?oU^Z[oiKZZ00ooiKZZ0_l0000=onk1Y003o`000?oa`j7olL>Q00_olL>Q00?o0000oo?5WoocaIl0
0_l0001@ooooo`00;?ooool00ol0003oooooooooo`0]ooooo`03o`000?l0<;So000000Co6dg70ol0
0007ogmka@03o`000?n8NkkoR7^n00KoR7^n00?o0000oi1k^?n@NkP01on@NkP00ol0003oUgfeoiMm
]@08oiMm]@03o`000?nMPKCoWH6d00WoWH6d00Co0000oj>5/onSQK?oXhFc0_l00008ojf=]@03o`00
0?ngU;Co]iBd00_o]iBd00?o0000ol2M]?o0WK@02oo0WK@01Ol0003o`9fdo`000?o9YKGo0000017o
eZj`00?o0000omff/?oM][000_oM][000ol0003oiKZZonFjZP0?onFjZP04o`000?o[_ZKojkjVo`00
00cok/6T00?o0000oo73XOoa`j402ooa`j401Ol0003ollFOoo?5WoocaIoo0000053ooooo000/oooo
o`;o0000;_ooool01?l0003o032ho`0`^?l00005oa]=a`03o`000?moNlGoOg_500GoOg_500?o0000
ohQk__n8Nkh01_n8Nkh00ol0003oT7^hoi1k^007oi1k^003o`000?nGOKGoUgfe00SoUgfe00?o0000
oif1]?nMPK@02OnMPK@01?l0003oXhFcoj>5/ol0000:ojf=]@03o`000?ngU;Co]iBd00_o]iBd00?o
0000ol2M]?o0WK@02oo0WK@01?l0003o`9fdol2M]?l0000ComJ^/005o`000?oM][3ogKJ`omff/?l0
00004OoU^ZX01Ol0003ojkjVon^nY_o[_ZKo000000[ok/6T00?o0000oo73XOoa`j402ooa`j400ol0
003ollFOoo?5W`03oo?5W`03o`000?oooooooooo04gooooo000[ooooo`03o`000?oooooooooo02oo
oooo00?o0000o`0`^?l000001_lKCLL2o`0000GoOg_500?o0000ohQk__n8Nkh01on8Nkh00ol0003o
T7^hoi1k^007oi1k^003o`000?nGOKGoUgfe00OoUgfe00?o0000oif1]?nMPK@02_nMPK@2o`0000_o
[Hfe00?o0000okND]?ngU;@03?ngU;@00ol0003o`9fdol2M]00:ol2M]004o`000?o0WKCo`9fdo`00
01?oeZj`00Go0000omff/?oM][3ogKJ`o`00000AonFjZP05o`000?o[_ZKojkjVon^nY_l000002_o^
`J@00ol0003olL>Qoo73X@0;oo73X@03o`000?ocaIoollFO00CollFO00?o0000ooooooooool0C?oo
ool002_ooooo00?o0000ooooooooool0<?ooool00ol0003o032ho`000005oa]=a`04o`000?m<H<Ko
0000o`0000CoOg_500?o0000ohQk__n8Nkh01_n8Nkh00ol0003oT7^hoi1k^007oi1k^003o`000?nG
OKGoUgfe00SoUgfe00?o0000oif1]?nMPK@02?nMPK@2o`0000go[Hfe00?o0000okND]?ngU;@02ong
U;@00ol0003o`9fdol2M]00:ol2M]005o`000?o0WKCo0000olfV/Ol000004ooF[[000ol0003ogKJ`
o`00000AonFjZP03o`000?o[_ZKojkjV00?ojkjV00?o0000onk1Y?o^`J@01oo^`J@00ol0003olL>Q
oo73X@0;oo73X@03o`000?ocaIoollFO00CollFO0_l0001=ooooo`004?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?l0<;So000000Ko6dg700?o0000odaPa_m<H<H00_l00002ogmka@03o`00
0?n8NkkoR7^n00KoR7^n00?o0000oi1k^?n@NkP01on@NkP00ol0003oUgfeoiMm]@08oiMm]@03o`00
0?nMPKCoWH6d00KoWH6d0_l000000onRQ[Ko0000ojf=]@0<ojf=]@03o`000?ngU;Co]iBd00_o]iBd
00?o0000ol2M]?o0WK@02_o0WK@2o`0000;ocJJa00?o0000omJ^/?oF[[004OoF[[000ol0003ogKJ`
o`00000AonFjZP03o`000?o[_ZKojkjV00CojkjV00?o0000onk1Y?o^`J@01_o^`J@00ol0003olL>Q
oo73X@0;oo73X@03o`000?ocaIoollFO00GollFO0_l0001<ooooo`004?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
<Oooool00ol0003o032ho`000005oa]=a`03o`000?m<H<KoC63600;oC63600?o0000ogmkaOl00000
2?n8Nkh00ol0003oT7^hoi1k^007oi1k^003o`000?nGOKGoUgfe00SoUgfe00?o0000oif1]?nMPK@0
0onMPK@3o`0000?oXXJf00?o0000ojf=]On]SKD02on]SKD00ol0003o]iBdokND]00<okND]003o`00
0?o0WKCo`9fd00Wo`9fd0_l00003olfV/@03o`000?oF[[3oeZj`017oeZj`00?o0000onFjZ_oU^ZX0
4?oU^ZX00ol0003ojkjVon^nYP05on^nYP03o`000?o^`JCok/6T00Cok/6T00?o0000oo73XOoa`j40
2ooa`j400ol0003ollFOoo?5W`07oo?5W`03o`000?oooooooooo04[ooooo000@ooooo`05oa0@4?oo
ooooooooooooool@41002oooool5o`0000Kooooo00?o0000ooooooooool0<_ooool2o`0000Go6dg7
00?o0000odaPa_m<H<H00om<H<H3o`0000SoR7^n00?o0000oi1k^?n@NkP01on@NkP00ol0003oUgfe
oiMm]@07oiMm]@04o`000?nMPKCoWH6doif1]0;o00001onRQ[H00ol0003o[Hfeojf=]@0;ojf=]@03
o`000?ngU;Co]iBd00_o]iBd00?o0000ol2M]?o0WK@02Oo0WK@00ol0003ocJJaolfV/@02olfV/@03
o`000?oF[[3oeZj`017oeZj`00?o0000onFjZ_oU^ZX03ooU^ZX00ol0003ojkjVon^nYP06on^nYP03
o`000?o^`JCok/6T00Cok/6T00?o0000oo73XOoa`j402ooa`j400ol0003ollFOoo?5W`08oo?5W`03
o`000?oooooooooo04Wooooo000@ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4Co
gMgMooooool00007ooooo`03o`000?oooooooooo03;ooooo00?o0000o`0`^?l000001OlKCLL00ol0
003oC636odaPaP04odaPaP?o00001_n8Nkh00ol0003oT7^hoi1k^007oi1k^003o`000?nGOKGoUgfe
00SoUgfe0ol00009oj:6]P03o`000?n]SKGo[Hfe00_o[Hfe00?o0000okND]?ngU;@02ongU;@00ol0
003o`9fdol2M]008ol2M]0;o00001?o=Y[400ol0003oeZj`omJ^/00@omJ^/003o`000?oO]Jco0000
013oiKZZ00?o0000on^nY_o[_ZH01oo[_ZH00ol0003ok/6Tonk1Y003onk1Y003o`000?oa`j7olL>Q
00_olL>Q00?o0000oo?5WoocaIl02?ocaIl2o`0004[ooooo000@ooooo`05o`000?oooooooooooooo
ool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo03?ooooo0_l00005
oa]=a`03o`000?m<H<KoC63600CoC63600?o0000ofe]`_m]KL800ol00003ohQk_P03o`000?n@NkSo
T7^h00OoT7^h00?o0000oiMm]OnGOKD01_nGOKD3o`0000_oXXJf00?o0000ojf=]On]SKD02on]SKD0
0ol0003o]iBdokND]00<okND]003o`000?o0WKCo`9fd00Oo`9fd0_l00005olfV/@03o`000?oF[[3o
eZj`00ooeZj`00Co0000omne[?oO]Jco00003ooU^ZX00ol0003ojkjVon^nYP08on^nYP05o`000?o^
`JCok/6Tonk1Y?l000003Ooa`j400ol0003ollFOoo?5W`0:oo?5W`;o0000BOooool0013ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo0_l0000fooooo`;o0000
1OlKCLL00ol0003oC636odaPaP04odaPaP03o`000?m]KL;oKFg200;oKFg20ol000000on8Nkko0000
oi1k^008oi1k^003o`000?nGOKGoUgfe00Go00000_nDO[T00ol0003oXXJfoj:6]P0:oj:6]P03o`00
0?n]SKGo[Hfe00_o[Hfe00?o0000okND]?ngU;@02ongU;@00ol0003o`9fdol2M]006ol2M]003o`00
0?o=Y[7o000000GocJJa00?o0000omJ^/?oF[[003_oF[[001Ol0003ogkF/omne[?oO]Jco000000ko
iKZZ00?o0000on^nY_o[_ZH02Oo[_ZH01Ol0003ok/6Tonk1Y?o^`JCo000000golL>Q00?o0000oo?5
WoocaIl02oocaIl00ol0003oooooooooo`17ooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0dooooo`;o00001OlKCLL00ol0
003oC636odaPaP04odaPaP03o`000?m]KL;oKFg200GoKFg23_l00007oiAn^@03o`000?nRQ[KoXXJf
00[oXXJf00?o0000ojf=]On]SKD02on]SKD00ol0003o]iBdokND]00;okND]003o`000?o0WKCo`9fd
00Go`9fd00Co0000olfV/Oo=Y[7o00001_o=Y[400ol0003oeZj`omJ^/00=omJ^/003o`000?oO]Jco
gkF/00;ogkF/00?o0000onFjZ_oU^ZX02ooU^ZX00ol0003ojkjVon^nYP0:on^nYP04o`000?o^`JCo
k/6To`0000golL>Q00?o0000oo?5WoocaIl02oocaIl2o`0004Sooooo000@ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05ooooo`03o`000?oooooooooo03Kooooo0_l0
0004oa]=a`03o`000?m<H<KoC63600CoC63600?o0000ofe]`_m]KL801_m]KL800ol0003oPgNmoh=g
_@07oh=g_@03o`000?nDO[WoU7ji00SoU7ji00?o0000oj:6]_nRQ[H02OnRQ[H00ol0003o[Hfeojf=
]@0;ojf=]@03o`000?ngU;Co]iBd00co]iBd00?o0000ol2M]?o0WK@01?o0WK@01?l0003ocJJaolfV
/Ol00006olfV/@03o`000?oF[[3oeZj`00goeZj`00?o0000omne[?oO]J`00_oO]J`00ol0003oiKZZ
onFjZP0;onFjZP03o`000?o[_ZKojkjV00_ojkjV0_l0000=oo73X@03o`000?ocaIoollFO00_ollFO
00Co0000ooC7X?l0003o0000Aoooool002[ooooo00?o0000ooooooooool0=_ooool2o`0000Go6dg7
00?o0000odaPa_m<H<H01?m<H<H00ol0003oKFg2ofe]`P05ofe]`P03o`000?n3MkgoPgNm00OoPgNm
00?o0000oiAn^OnDO[T02?nDO[T00ol0003oXXJfoj:6]P0:oj:6]P03o`000?n]SKGo[Hfe00_o[Hfe
00?o0000okND]?ngU;@02ongU;@00ol0003o`9fdol2M]003ol2M]005o`000?o=Y[7ocJJaolfV/Ol0
00001oo=Y[400ol0003oeZj`omJ^/00;omJ^/003o`000?oO]JcogkF/00CogkF/00?o0000onFjZ_oU
^ZX02OoU^ZX00ol0003ojkjVon^nYP0=on^nYP03o`000?oa`j7olL>Q00_olL>Q00?o0000oo?5Wooc
aIl02oocaIl01?l0003om<NPooC7X?l00017ooooo`00:_ooool00ol0003oooooooooo`0gooooo`;o
00001?lKCLL00ol0003oC636odaPaP04odaPaP03o`000?m]KL;oKFg200KoKFg200?o0000oh=g_On3
Mkd01on3Mkd00ol0003oU7jioiAn^@07oiAn^@03o`000?nRQ[KoXXJf00[oXXJf00?o0000ojf=]On]
SKD02on]SKD00ol0003o]iBdokND]00;okND]003o`000?o0WKCo`9fd00?o`9fd00Go0000olfV/Oo=
Y[7ocJJao`000007olfV/@03o`000?oF[[3oeZj`00_oeZj`00?o0000omne[?oO]J`01OoO]J`00ol0
003oiKZZonFjZP08onFjZP03o`000?o[_ZKojkjV00gojkjV00?o0000oo73XOoa`j402ooa`j400ol0
003ollFOoo?5W`0;oo?5W`05o`000?odaj3om<NPooC7X?l00000A_ooool002[ooooo00?o0000oooo
ooooool0>?ooool00ol0003o6dg7oa]=a`03oa]=a`03o`000?m<H<KoC63600?oC63600?o0000ofe]
`_m]KL801_m]KL800ol0003oPgNmoh=g_@07oh=g_@03o`000?nDO[WoU7ji00SoU7ji00?o0000oj:6
]_nRQ[H02OnRQ[H00ol0003o[Hfeojf=]@0;ojf=]@03o`000?ngU;Co]iBd00co]iBd00Go0000ol2M
]?o0WKCo`9fdo`000004olfV/@03o`000?o=Y[7ocJJa00KocJJa00?o0000omJ^/?oF[[002OoF[[00
0ol0003ogkF/omne[006omne[003o`000?oU^Z[oiKZZ00SoiKZZ00?o0000on^nY_o[_ZH03?o[_ZH0
0ol0003okl:So`00000<oo73X@03o`000?ocaIoollFO00[ollFO00?o0000ooC7X?odaj000oodaj00
0ol0003oooooooooo`13ooooo`00:Oooool3o`0003Wooooo0_l00004oa]=a`03o`000?m<H<KoC636
00CoC63600?o0000ofe]`_m]KL801Om]KL800ol0003oPgNmoh=g_@07oh=g_@03o`000?nDO[WoU7ji
00SoU7ji00?o0000oj:6]_nRQ[H02_nRQ[H00ol0003o[Hfeojf=]@0;ojf=]@03o`000?ngU;Co]iBd
00_o]iBd00Co0000ol2M]?o0WKCo00001Oo=Y[400ol0003ocJJaolfV/@06olfV/@03o`000?oF[[3o
eZj`00WoeZj`00?o0000omne[?oO]J`01ooO]J`00ol0003oiKZZonFjZP06onFjZP03o`000?o[_ZKo
jkjV00gojkjV00Co0000ono2Xoo_`Z?o00002_oa`j400ol0003ollFOoo?5W`0;oo?5W`03o`000?od
aj3om<NP00?om<NP0_l00014ooooo`00:_ooool00ol0003oooooooooo`0iooooo`03o`000?lKCLOo
6dg700;o6dg700?o0000odaPa_m<H<H01?m<H<H00ol0003oKFg2ofe]`P06ofe]`P03o`000?n3Mkgo
PgNm00OoPgNm00?o0000oiAn^OnDO[T01onDO[T00ol0003oXXJfoj:6]P0:oj:6]P03o`000?n]SKGo
[Hfe00_o[Hfe00?o0000okND]?ngU;@02ongU;@01?l0003o`9fdol2M]?l00005olfV/@03o`000?o=
Y[7ocJJa00KocJJa00?o0000omJ^/?oF[[002?oF[[000ol0003ogkF/omne[008omne[003o`000?oU
^Z[oiKZZ00KoiKZZ00?o0000on^nY_o[_ZH03Oo[_ZH01Ol0003okl:Sono2Xoo_`Z?o000000WolL>Q
00?o0000oo?5WoocaIl02oocaIl00ol0003om<NPooC7X004ooC7X003o`000?oooooooooo04;ooooo
000Zooooo`03o`000?oooooooooo03Wooooo0_l00004oa]=a`03o`000?m<H<KoC63600?oC63600?o
0000ofe]`_m]KL801_m]KL800ol0003oPgNmoh=g_@07oh=g_@03o`000?nDO[WoU7ji00SoU7ji00?o
0000oj:6]_nRQ[H02OnRQ[H00ol0003o[Hfeojf=]@0;ojf=]@03o`000?ngU;Co]iBd00co]iBd0_l0
0006olfV/@03o`000?o=Y[7ocJJa00OocJJa00?o0000omJ^/?oF[[001ooF[[000ol0003ogkF/omne
[009omne[003o`000?oU^Z[oiKZZ00GoiKZZ00?o0000on^nY_o[_ZH03?o[_ZH00ol0003okl:Sono2
X`02ono2X`03o`000?oa`j7olL>Q00OolL>Q00?o0000oo?5WoocaIl02_ocaIl00ol0003om<NPooC7
X006ooC7X003o`000?oooooooooo047ooooo000Zooooo`03o`000?oooooooooo03[ooooo00?o0000
oa]=aolKCLL00_lKCLL00ol0003oC636odaPaP04odaPaP03o`000?m]KL;oKFg200GoKFg200?o0000
oh=g_On3Mkd01on3Mkd00ol0003oU7jioiAn^@08oiAn^@03o`000?nRQ[KoXXJf00[oXXJf00?o0000
ojf=]On]SKD02on]SKD00ol0003o]iBdokND]00;okND]003o`000?o=Y[7ocJJa00GocJJa00?o0000
olfV/Oo=Y[401oo=Y[400ol0003oeZj`omJ^/007omJ^/003o`000?oO]JcogkF/00[ogkF/00?o0000
onFjZ_oU^ZX00ooU^ZX00ol0003ojkjVon^nYP0=on^nYP03o`000?o_`Z?okl:S00?okl:S00?o0000
oo73XOoa`j401Ooa`j400ol0003ollFOoo?5W`0;oo?5W`03o`000?odaj3om<NP00Oom<NP00?o0000
ooooooooool0@?ooool002Wooooo00?o0000ooooooooool0??ooool01Ol0003o6dg7oa]=aolKCLOo
000000KoC63600?o0000ofe]`_m]KL801_m]KL800ol0003oPgNmoh=g_@07oh=g_@03o`000?nDO[Wo
U7ji00OoU7ji00?o0000oj:6]_nRQ[H02_nRQ[H00ol0003o[Hfeojf=]@0;ojf=]@03o`000?ngU;Co
]iBd00_o]iBd00?o0000olfV/Oo=Y[401Oo=Y[400ol0003ocJJaolfV/@08olfV/@03o`000?oF[[3o
eZj`00GoeZj`00?o0000omne[?oO]J`02ooO]J`00ol0003oiKZZonFjZP03onFjZP03o`000?o[_ZKo
jkjV00gojkjV00?o0000ono2Xoo_`Z<01?o_`Z<00ol0003olL>Qoo73X@04oo73X@03o`000?ocaIoo
llFO00_ollFO00?o0000ooC7X?odaj001oodaj000ol0003oooooooooo`10ooooo`00:Oooool00ol0
003oooooooooo`0looooo`03o`000?lKCLOo6dg700;o6dg700?o0000odaPa_m<H<H01?m<H<H00ol0
003oKFg2ofe]`P05ofe]`P03o`000?n3MkgoPgNm00OoPgNm00?o0000oiAn^OnDO[T02?nDO[T00ol0
003oXXJfoj:6]P09oj:6]P03o`000?n]SKGo[Hfe00_o[Hfe00?o0000okND]?ngU;@02_ngU;@00ol0
003o`indo`000006olfV/@03o`000?o=Y[7ocJJa00SocJJa00?o0000omJ^/?oF[[001OoF[[000ol0
003ogkF/omne[00<omne[003o`000?oU^Z[oiKZZ00;oiKZZ00?o0000on^nY_o[_ZH03?o[_ZH00ol0
003okl:Sono2X`05ono2X`03o`000?oa`j7olL>Q00ColL>Q00?o0000oo?5WoocaIl02oocaIl00ol0
003om<NPooC7X008ooC7X003o`000?oooooooooo03oooooo000Yooooo`03o`000?oooooooooo03go
oooo00Go0000oa]=aolKCLOo6dg7o`000006odaPaP03o`000?m]KL;oKFg200GoKFg200?o0000oh=g
_On3Mkd01on3Mkd00ol0003oU7jioiAn^@08oiAn^@03o`000?nRQ[KoXXJf00[oXXJf00?o0000ojf=
]On]SKD02on]SKD00ol0003o]iBdokND]008okND]004o`000?o3WkCo`indo`0000KocJJa00?o0000
olfV/Oo=Y[402Oo=Y[400ol0003oeZj`omJ^/003omJ^/003o`000?oO]JcogkF/00gogkF/00Go0000
onFjZ_oU^Z[oiKZZo`00000?on^nYP03o`000?o_`Z?okl:S00Kokl:S00?o0000oo73XOoa`j400ooa
`j400ol0003ollFOoo?5W`0:oo?5W`03o`000?odaj3om<NP00[om<NP00?o0000ooooooooool0?_oo
ool002Wooooo0_l0000nooooo`;o00000olKCLL00ol0003oC636odaPaP03odaPaP03o`000?m]KL;o
KFg200KoKFg200?o0000oh=g_On3Mkd01on3Mkd00ol0003oU7jioiAn^@07oiAn^@03o`000?nRQ[Ko
XXJf00[oXXJf00?o0000ojf=]On]SKD02on]SKD00ol0003o]iBdokND]007okND]005o`000?o3WkCo
`indol>O]?l000001_o=Y[400ol0003ocJJaolfV/@09olfV/@03o`000?oF[[3oeZj`00?oeZj`00?o
0000omne[?oO]J`03_oO]J`01?l0003oiKZZonFjZ_l0000?on^nYP03o`000?o_`Z?okl:S00Ookl:S
00Go0000oo73XOoa`j7olL>Qo`00000=oo?5W`03o`000?odaj3om<NP00[om<NP0_l0000oooooo`00
:Oooool00ol0003oooooooooo`0nooooo`;o00000_lKCLL00ol0003oC636odaPaP04odaPaP03o`00
0?m]KL;oKFg200GoKFg200?o0000oh=g_On3Mkd01on3Mkd00ol0003oU7jioiAn^@07oiAn^@03o`00
0?nRQ[KoXXJf00[oXXJf00?o0000ojf=]On]SKD02on]SKD00ol0003o]iBdokND]007okND]003o`00
0?o3WkCo`ind00;o`ind00?o0000olfV/Oo=Y[400oo=Y[400ol0003ocJJaolfV/@0:olfV/@05o`00
0?oF[[3oeZj`omJ^/?l000004_oO]J`00ol0003oiKZZo`00000>on^nYP03o`000?o_`Z?okl:S00Wo
kl:S00Co0000oo73XOoa`j7o00003OocaIl00ol0003om<NPooC7X009ooC7X003o`000?oebj?o0000
03oooooo000Yooooo`03o`000?oooooooooo03oooooo0_l000000olKCLOo0000odaPaP05odaPaP03
o`000?m]KL;oKFg200GoKFg200?o0000oh=g_On3Mkd01on3Mkd00ol0003oU7jioiAn^@08oiAn^@03
o`000?nRQ[KoXXJf00WoXXJf00?o0000ojf=]On]SKD03?n]SKD00ol0003o]iBdokND]005okND]003
o`000?o3WkCo`ind00?o`ind00?o0000olfV/Oo=Y[400oo=Y[400ol0003ocJJaolfV/@0:olfV/@05
o`000?oF[[3oeZj`omJ^/?l000004_oO]J`2o`0000oojkjV00?o0000ono2Xoo_`Z<02Oo_`Z<01?l0
003olL>Qoo73XOl0000<oo?5W`03o`000?odaj3om<NP00[om<NP00Co0000ooG;Xooebj?o0000?_oo
ool002Wooooo00?o0000ooooooooool0?oooool01Ol0003o006Do`000?lKCLOo000000GoC63600?o
0000ofe]`_m]KL801Om]KL800ol0003oPgNmoh=g_@07oh=g_@03o`000?nDO[WoU7ji00SoU7ji00?o
0000oj:6]_nRQ[H02_nRQ[H00ol0003o[Hfeojf=]@0;ojf=]@03o`000?ngU;Co]iBd00Co]iBd00?o
0000ol>O]?o3Wk@01Oo3Wk@00ol0003ocJJaolfV/@02olfV/@03o`000?o=Y[7ocJJa00[ocJJa00Go
0000omJ^/?oF[[3oeZj`o`00000Comne[003o`000?o[_ZKojkjV00gojkjV00?o0000ono2Xoo_`Z<0
2_o_`Z<2o`0000gollFO00?o0000ooC7X?odaj002_odaj001Ol0003omL^SooG;Xooebj?o000003go
oooo000Yooooo`03o`000?oooooooooo043ooooo0_l000000olKCLOo0000odaPaP05odaPaP03o`00
0?m]KL;oKFg200GoKFg200?o0000oh=g_On3Mkd01on3Mkd00ol0003oU7jioiAn^@07oiAn^@03o`00
0?nRQ[KoXXJf00[oXXJf00?o0000ojf=]On]SKD02on]SKD00ol0003o]iBdokND]003okND]003o`00
0?o3WkCo`ind00Ko`ind00?o0000olfV/Oo=Y[400_o=Y[400ol0003ocJJaolfV/@0;olfV/@03o`00
0?oF[[3o000001CogkF/00?o0000on^nY_o[_ZH03?o[_ZH00ol0003okl:Sono2X`0<ono2X`03o`00
0?ocaIoollFO00_ollFO00?o0000ooC7X?odaj002Oodaj000ol0003omL^SooG;X`02ooG;X`;o0000
??ooool002Wooooo00?o0000ooooooooool0@?ooool01Ol0003o006Do`000?lKCLOo000000GoC636
00?o0000ofe]`_m]KL801Om]KL800ol0003oPgNmoh=g_@07oh=g_@03o`000?nDO[WoU7ji00SoU7ji
00?o0000oj:6]_nRQ[H02OnRQ[H00ol0003o[Hfeojf=]@0<ojf=]@05o`000?ngU;Co]iBdokND]?l0
00002Oo3Wk@00ol0003ocJJaolfV/@02olfV/@03o`000?o=Y[7ocJJa00_ocJJa00?o0000omJ^/?l0
00004ooO]J`00ol0003oik^Yo`00000=on^nYP03o`000?o_`Z?okl:S00cokl:S00?o0000oo?5Wooc
aIl02_ocaIl00ol0003om<NPooC7X00:ooC7X003o`000?oebj?omL^S00?omL^S00?o0000oooooooo
ool0>_ooool002Sooooo0ol00012ooooo`04o`000?l00ICo0000o`0000GoC63600?o0000ofe]`_m]
KL801Om]KL800ol0003oPgNmoh=g_@07oh=g_@03o`000?nDO[WoU7ji00SoU7ji00?o0000oj:6]_nR
Q[H02_nRQ[H00ol0003o[Hfeojf=]@0;ojf=]@05o`000?ngU;Co]iBdokND]?l000002_o3Wk@01Ol0
003ocJJaolfV/Oo=Y[7o000000kocJJa00?o0000omne[?oO]J`04_oO]J`00ol0003oik^Yo`00000=
on^nYP03o`000?o_`Z?okl:S00cokl:S0_l0000;oo?5W`03o`000?odaj3om<NP00[om<NP00?o0000
ooG;Xooebj<01?oebj<00ol0003oooooooooo`0iooooo`00:?ooool00ol0003oooooooooo`12oooo
o`04o`000?l00ICo006Do`0000KoC63600?o0000ofe]`_m]KL801Om]KL800ol0003oPgNmoh=g_@07
oh=g_@03o`000?nDO[WoU7ji00OoU7ji00?o0000oj:6]_nRQ[H02_nRQ[H00ol0003o[Hfeojf=]@0;
ojf=]@04o`000?ngU;Co]iBdo`0000_o`ind00Go0000olfV/Oo=Y[7ocJJao`00000>olfV/@03o`00
0?oO]JcogkF/01;ogkF/00Co0000onNkZOoW^jWo00002oo[_ZH00ol0003okl:Sono2X`0<ono2X`04
o`000?ocaj7ollNQo`0000[ollFO00?o0000ooC7X?odaj002Oodaj000ol0003omL^SooG;X`06ooG;
X`03o`000?oooooooooo03Sooooo000<ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c007ooooo`03o`000?oooooooooo04?ooooo00Co0000
o`01U?l00ICo00001Om<H<H00ol0003oKFg2ofe]`P05ofe]`P03o`000?n3MkgoPgNm00OoPgNm00?o
0000oiAn^OnDO[T02?nDO[T00ol0003oXXJfoj:6]P09oj:6]P03o`000?n]SKGo[Hfe00co[Hfe0_l0
000=ol>O]004o`000?o=Y[7ocJJao`0000gocJJa00?o0000omR_/?l000004_oO]J`00ol0003oik^Y
onNkZ@02onNkZ@03o`000?o[_ZKojkjV00SojkjV00?o0000ono2Xoo_`Z<03?o_`Z<01Ol0003ollNQ
oo?7XOocaj7o000000WollFO00?o0000ooC7X?odaj002Oodaj000ol0003omL^SooG;X`06ooG;X`;o
0000>Oooool000cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q00Oooooo00?o0000ooooooooool0A?ooool01?l0003o006Do`000?l00005
odaPaP03o`000?m]KL;oKFg200CoKFg200?o0000oh=g_On3Mkd01on3Mkd00ol0003oU7jioiAn^@08
oiAn^@03o`000?nRQ[KoXXJf00[oXXJf00?o0000ojf=]On]SKD02_n]SKD2o`0000ko`ind00Co0000
olfV/Ol0003o00003Oo=Y[400ol0003of:n`o`00000Bomne[003o`000?oW^jWoik^Y00;oik^Y00?o
0000on^nY_o[_ZH02?o[_ZH00ol0003okl:Sono2X`0<ono2X`03o`000?ocaj7ollNQ00;ollNQ00?o
0000oo?5WoocaIl01OocaIl00ol0003om<NPooC7X00:ooC7X003o`000?oebj?omL^S00OomL^S00?o
0000ooooooooool0=oooool000cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooooooo`14ooooo`03o`000?l00ICo006D00;o0000
1?m<H<H00ol0003oKFg2ofe]`P05ofe]`P03o`000?n3MkgoPgNm00OoPgNm00?o0000oiAn^OnDO[T0
1onDO[T00ol0003oXXJfoj:6]P0:oj:6]P03o`000?n]SKGo[Hfe00Wo[Hfe00?o0000okJG]ol00000
3Oo3Wk@3o`000003olfV/Ol0003ocJJa00_ocJJa00Go0000omR_/?oH[k3of:n`o`00000@omne[003
o`000?oW^jWoik^Y00Coik^Y00?o0000on^nY_o[_ZH01_o[_ZH00ol0003okl:Sono2X`0<ono2X`03
o`000?ocaj7ollNQ00CollNQ00?o0000oo?5WoocaIl01?ocaIl00ol0003om<NPooC7X009ooC7X003
o`000?oebj?omL^S00WomL^S00?o0000ooooooooool0=_ooool000cooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401oooool00ol0003oooooooooo`15oooo
o`05o`000?l00ICo0000o`0c]ol000000om<H<H00ol0003oKFg2ofe]`P05ofe]`P03o`000?n3Mkgo
PgNm00OoPgNm00?o0000oiAn^OnDO[T02?nDO[T00ol0003oXXJfoj:6]P09oj:6]P03o`000?n]SKGo
[Hfe00So[Hfe00Go0000okJG]onfUkOo]YNgo`000009ol>O]0?o00000_o3Wk@01?l0003ocJJaolfV
/Ol0000;olfV/@05o`000?oH[k3of:n`omR_/?l000004?oO]J`00ol0003oik^YonNkZ@04onNkZ@03
o`000?o[_ZKojkjV00KojkjV00?o0000ono2Xoo_`Z<03?o_`Z<00ol0003ollNQoo?7X@04oo?7X@03
o`000?ocaIoollFO00CollFO00?o0000ooC7X?odaj002Oodaj000ol0003omL^SooG;X`0:ooG;X`03
o`000?oooooooooo03Gooooo000<ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003o
EEEEo`000?l@413oc<c<00Oooooo00?o0000ooooooooool0AOooool01_l0003o006Do`01U?l0003o
03>go`0000?oC63600?o0000ofe]`_m]KL801?m]KL800ol0003oPgNmoh=g_@07oh=g_@03o`000?nD
O[WoU7ji00SoU7ji00?o0000oj:6]_nRQ[H02_nRQ[H00ol0003o[Hfeojf=]@06ojf=]@03o`000?nf
UkOo]YNg00;o]YNg00?o0000ol>O]?o3Wk@01?o3Wk@3o`0000Go`ind00Go0000olfV/Oo=Y[7ocJJa
o`000009olfV/@03o`000?oH[k3of:n`00?of:n`00?o0000omne[?oO]J`03?oO]J`00ol0003oik^Y
onNkZ@06onNkZ@03o`000?o[_ZKojkjV00GojkjV00?o0000ono2Xoo_`Z<03?o_`Z<00ol0003ollNQ
oo?7X@05oo?7X@03o`000?ocaIoollFO00;ollFO00?o0000ooC7X?odaj002_odaj000ol0003omL^S
ooG;X`0:ooG;X`;o0000=_ooool000cooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEE
EOn7QhOooooo00Wooooo00?o0000ooooooooool0A_ooool00ol0003o006Do`000002o`0c]`04o`00
0?m<H<KoC636o`0000KoKFg200?o0000oh=g_On3Mkd02?n3Mkd00ol0003oU7jioiAn^@07oiAn^@03
o`000?nRQ[KoXXJf00[oXXJf00?o0000ojf=]On]SKD01On]SKD00ol0003o]YNgokJG]`03okJG]`04
o`000?o3WkCo`indol>O]0?o00002Oo3Wk@01Ol0003ocJJaolfV/Oo=Y[7o000000OocJJa00?o0000
omR_/?oH[k001?oH[k000ol0003ogkF/omne[00<omne[003o`000?oW^jWoik^Y00Ooik^Y00?o0000
on^nY_o[_ZH00oo[_ZH00ol0003okl:Sono2X`0<ono2X`03o`000?ocaj7ollNQ00OollNQ00Go0000
oo?5WoocaIoollFOo`00000;ooC7X003o`000?oebj?omL^S00[omL^S00?o0000ooC?Z?l00000=_oo
ool000cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo0_l0
0018ooooo`04o`000?l00ICo006Do`0000;o03>g00?o0000odaPa_l000001om]KL800ol0003oPgNm
oh=g_@07oh=g_@03o`000?nDO[WoU7ji00OoU7ji00?o0000oj:6]_nRQ[H02_nRQ[H00ol0003o[Hfe
ojf=]@04ojf=]@03o`000?nfUkOo]YNg00Go]YNg0ol0000<ol>O]003o`000?o=Y[7ocJJa00;ocJJa
00?o0000olfV/Oo=Y[401?o=Y[400ol0003of:n`omR_/005omR_/003o`000?oO]JcogkF/00_ogkF/
00?o0000onNkZOoW^jT01ooW^jT00ol0003ojkjVon^nYP03on^nYP03o`000?o_`Z?okl:S00cokl:S
00?o0000oo?7XOocaj402?ocaj401?l0003ollFOoo?5Wol0000;ooC7X003o`000?oebj?omL^S00[o
mL^S00Co0000ooC?Z?odcjSo0000=Oooool000cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0B?ooool00ol0003o006Do`000003
o`0c]`03o`000?m<H<Ko000000KoKFg200?o0000oh=g_On3Mkd01on3Mkd00ol0003oU7jioiAn^@08
oiAn^@03o`000?nRQ[KoXXJf00[oXXJf00?o0000ojf=]On]SKD00_n]SKD00ol0003o]YNgokJG]`03
okJG]`Co00003_o3Wk@00ol0003ocJJaolfV/@03olfV/@03o`000?o=Y[7ocJJa00;ocJJa00?o0000
omR_/?oH[k001_oH[k000ol0003ogkF/omne[00:omne[003o`000?oW^jWoik^Y00Woik^Y00?o0000
on^nY_o[_ZH00_o[_ZH00ol0003okl:Sono2X`0<ono2X`03o`000?ocaj7ollNQ00WollNQ0_l0000<
ooC7X003o`000?oebj?omL^S00[omL^S00Go0000ooC?Z?odcjSom<nXo`00000dooooo`009oooool0
0ol0003oooooooooo`19ooooo`;o00001?l0<kL2o`0000KoKFg200?o0000oh=g_On3Mkd01on3Mkd0
0ol0003oU7jioiAn^@08oiAn^@03o`000?nRQ[KoXXJf00[oXXJf00Go0000ojf=]On]SKGo[Hfeo`00
0003okJG]`?o00000onfUkL00ol0003o`indol>O]00=ol>O]003o`000?o=Y[7ocJJa00?ocJJa00Go
0000olfV/Oo=Y[7ocJJao`000009omR_/003o`000?oO]JcogkF/00WogkF/00?o0000onNkZOoW^jT0
2OoW^jT01Ol0003ojkjVon^nY_o[_ZKo000000ookl:S00?o0000oo?7XOocaj402_ocaj400ol0003o
m<NPooC7X009ooC7X003o`000?oebj?omL^S00[omL^S00?o0000ooC?Z?odcjP00oodcjP00ol0003o
ooooooooo`0aooooo`009oooool00ol0003oooooooooo`19ooooo`03o`000?l00ICo000000Co03>g
00?o0000ofe]`_m]KL801Om]KL800ol0003oPgNmoh=g_@07oh=g_@03o`000?nDO[WoU7ji00OoU7ji
00?o0000oj:6]_nRQ[H02_nRQ[H01Ol0003o[Hfeojf=]Ol0003o]YNg00?o00001onfUkL00ol0003o
`indol>O]00<ol>O]003o`000?o=Y[7ocJJa00CocJJa00?o0000olfV/Ol000002_oH[k000ol0003o
gkF/omne[008omne[003o`000?oW^jWoik^Y00_oik^Y00Co0000on^nY_o[_ZKo00003_o_`Z<00ol0
003ollNQoo?7X@0;oo?7X@03o`000?odaj3om<NP00Wom<NP00?o0000ooG;Xooebj<02_oebj<00ol0
003om<nXooC?Z003ooC?Z0;o0000<_ooool002Oooooo00?o0000ooooooooool0B_ooool2o`0000Go
03>g0_l00005ofe]`P03o`000?n3MkgoPgNm00OoPgNm00?o0000oiAn^OnDO[T02?nDO[T00ol0003o
XXJfoj:6]P0:oj:6]PCo00002_nfUkL00ol0003o`indol>O]00=ol>O]003o`000?o=Y[7ocJJa00?o
cJJa00?o0000olfV/Ol000002ooH[k000ol0003ogkF/omne[007omne[003o`000?oW^jWoik^Y00co
ik^Y00?o0000on^nY_l000003_o_`Z<00ol0003ollNQoo?7X@0;oo?7X@;o00002_odaj000ol0003o
mL^SooG;X`09ooG;X`03o`000?odcjSom<nX00Gom<nX00?o0000ooooooooool0<?ooool002Oooooo
00?o0000ooooooooool0B_ooool00ol0003o006Do`000004o`0c]`03o`000?m4FL?o000000CoKFg2
00?o0000oh=g_On3Mkd01on3Mkd00ol0003oU7jioiAn^@08oiAn^@03o`000?nRQ[KoXXJf00SoXXJf
0ol0000=okJG]`03o`000?o3WkCo`ind00go`ind00?o0000olfV/Oo=Y[401?o=Y[400ol0003of:n`
omR_/00:omR_/003o`000?oO]JcogkF/00KogkF/00?o0000onNkZOoW^jT03OoW^jT2o`0000ookl:S
00?o0000oo?7XOocaj402_ocaj401?l0003om/bQooK<XOl00008ooC7X003o`000?oebj?omL^S00[o
mL^S00?o0000ooC?Z?odcjP01_odcjP00ol0003oooooooooo`0_ooooo`009oooool2o`0004cooooo
0_l00005o`0c]`04o`000?m4FL?o0000o`0000?oKFg200?o0000oh=g_On3Mkd01on3Mkd00ol0003o
U7jioiAn^@07oiAn^@03o`000?nRQ[KoXXJf00GoXXJf1?l000000onWS[_o0000okJG]`0=okJG]`03
o`000?o3WkCo`ind00co`ind00?o0000olfV/Oo=Y[401?o=Y[42o`0000_of:n`00?o0000omne[?oO
]J`01_oO]J`00ol0003oik^YonNkZ@0>onNkZ@03o`000?o_`Z?okl:S00cokl:S00?o0000oo?7XOoc
aj402oocaj401Ol0003om/bQooK<XOofc:7o000000Oom<NP00?o0000ooG;Xooebj<02_oebj<00ol0
003om<nXooC?Z007ooC?Z003o`000?oooooooooo02kooooo000Vooooo`;o0000COooool00ol0003o
006Do`000004o`0c]`05o`000?m4FL?oA5W3odAI`ol000000_m]KL800ol0003oPgNmoh=g_@07oh=g
_@03o`000?nDO[WoU7ji00SoU7ji00Co0000oj:6]_nRQ[KoXXJf1Ol00004ojN>^`03o`000?nfUkOo
]YNg00_o]YNg00?o0000ol>O]?o3Wk@03Oo3Wk@00ol0003ocJJaolfV/@02olfV/@04o`000?oH[k3o
f:n`o`0000_of:n`00?o0000omne[?oO]J`01OoO]J`00ol0003oik^YonNkZ@0>onNkZ@03o`000?o_
`Z?okl:S00cokl:S00?o0000oo?7XOocaj402oocaj400ol0003om/bQooK<X@02ooK<X@03o`000?od
aj3om<NP00Com<NP00?o0000ooG;Xooebj<02Ooebj<00ol0003om<nXooC?Z008ooC?Z0;o0000;ooo
ool002Oooooo00?o0000ooooooooool0C?ooool2o`0000Co03>g00?o0000odAI`om4FL<00_m4FL<3
o`0000WoPgNm00?o0000oiAn^OnDO[T02?nDO[T4o`0000;oXXJf00?o0000ojN>^onWS[/01?nWS[/0
0ol0003o]YNgokJG]`0;okJG]`03o`000?o3WkCo`ind00go`ind00Go0000olfV/Oo=Y[7ocJJao`00
0004omR_/003o`000?oH[k3of:n`00Sof:n`00?o0000omne[?oO]J`01?oO]J`00ol0003oik^YonNk
Z@0>onNkZ@03o`000?o]`ZOo000000gokl:S00?o0000oo?7XOocaj402_ocaj400ol0003om/bQooK<
X@04ooK<X@03o`000?odaj3om<NP00;om<NP00?o0000ooG;Xooebj<02_oebj<00ol0003om<nXooC?
Z009ooC?Z0;o0000;_ooool002Oooooo00?o0000ooooooooool0COooool2o`0000Co03>g00?o0000
odAI`om4FL<00om4FL<2o`0000WoPgNm00?o0000oiAn^OnDO[T01OnDO[T3o`0000?oXXJf0_l00007
ojN>^`03o`000?nfUkOo]YNg00co]YNg00?o0000ol>O]?o3Wk@03Oo3Wk@01?l0003ocJJaolfV/Ol0
0005omR_/003o`000?oH[k3of:n`00Sof:n`00?o0000omne[?oO]J`00ooO]J`00ol0003oik^YonNk
Z@0>onNkZ@04o`000?o]`ZOokL:Wo`0000_okl:S00?o0000oo?7XOocaj402oocaj400ol0003om/bQ
ooK<X@05ooK<X@05o`000?odaj3om<NPooC7X?l000002ooebj<00ol0003om<nXooC?Z00;ooC?Z003
o`000?oooooooooo02cooooo000Vooooo`03o`000?oooooooooo04kooooo0_l00004o`0c]`03o`00
0?m4FL?oA5W300CoA5W30ol00007oh=g_@03o`000?nDO[WoU7ji00;oU7ji0ol00003oiAn^@?o0000
2_nWS[/00ol0003o]YNgokJG]`0;okJG]`03o`000?o3WkCo`ind00go`ind00?o0000olfV/Ol00000
1ooH[k000ol0003of:n`omR_/007omR_/003o`000?oO]JcogkF/00;ogkF/00?o0000onNkZOoW^jT0
3ooW^jT01Ol0003okL:Wong2Yoo]`ZOo000000[okl:S00?o0000oo?7XOocaj402oocaj400ol0003o
m/bQooK<X@06ooK<X@04o`000?odaj3om<NPo`0000_omL^S00?o0000ooC?Z?odcjP02_odcjP00ol0
003olmJao`00000]ooooo`009_ooool00ol0003oooooooooo`1?ooooo`;o00000ol0<kL00ol0003o
A5W3odAI``04odAI``03o`000?mbL/?oLW;300Co00000on3Mkd00ol0003oU7jio`000002o`0000Co
U7ji0ol0000<ojN>^`03o`000?nfUkOo]YNg00_o]YNg00?o0000ol>O]?o3Wk@03Oo3Wk@00ol0003o
cJJao`000008omR_/003o`000?oH[k3of:n`00Oof:n`00Go0000omne[?oO]JcogkF/o`00000@onNk
Z@03o`000?o]`ZOokL:W00?okL:W00?o0000ono2Xoo_`Z<01oo_`Z<00ol0003ollNQoo?7X@0:oo?7
X@03o`000?ofc:7om/bQ00Som/bQ0_l0000<ooG;X`03o`000?odcjSom<nX00[om<nX00Co0000oo?F
/Ol0003o0000;?ooool002Kooooo00?o0000ooooooooool0Coooool2o`0000Co03>g00?o0000odAI
`om4FL<01?m4FL<00ol0003oLW;3og9b``03og9b``Go00000_nDO[T5o`0000;oTH:o00?o0000ojN>
^onWS[/02_nWS[/00ol0003o]YNgokJG]`0<okJG]`03o`000?o3WkCo`ind00go`ind00?o0000omR_
/?oH[k001ooH[k000ol0003of:n`omR_/007omR_/004o`000?oO]JcogkF/o`00017oik^Y00?o0000
ong2Yoo]`ZL00oo]`ZL00ol0003okl:Sono2X`07ono2X`03o`000?ocaj7ollNQ00[ollNQ00?o0000
ooK<XOofc:402Oofc:42o`0000[omL^S00?o0000ooC?Z?odcjP02_odcjP01Ol0003olmJaoo?F/Ooc
e[7o000002cooooo000Vooooo`;o0000DOooool2o`0000?o03>g00?o0000odAI`om4FL<01?m4FL<0
0ol0003oLW;3og9b``03og9b``;o000000?oLW;3o`000?l000000_l00008oi62_`03o`000?nWS[_o
Yhjk00[oYhjk00?o0000okJG]onfUkL02onfUkL00ol0003o`indol>O]00=ol>O]003o`000?oH[k3o
f:n`00Sof:n`00?o0000omR_/?oH[k001ooH[k000ol0003ogkF/o`00000AonNkZ@03o`000?o]`ZOo
kL:W00CokL:W00?o0000ono2Xoo_`Z<01Oo_`Z<00ol0003ollNQoo?7X@0;oo?7X@03o`000?ofc:7o
m/bQ00Wom/bQ00?o0000ooSBXol000002Ooebj<00ol0003om<nXooC?Z00:ooC?Z003o`000?oce[7o
lmJa00;olmJa00?o0000ooooooooool0:Oooool002Kooooo00?o0000ooooooooool0D?ooool2o`00
00Co03>g00?o0000odAI`om4FL<00om4FL<00ol0003oLW;3og9b``03o`0000CoLW;300?o0000oi62
_onAP[l02?nAP[l00ol0003oYhjkojN>^`0:ojN>^`03o`000?nfUkOo]YNg00_o]YNg00?o0000ol>O
]?o3Wk@03?o3Wk@00ol0003ocZVdo`00000:omR_/003o`000?oH[k3of:n`00Kof:n`00?o0000omne
[?l000004?oW^jT00ol0003okL:Wong2Y`06ong2Y`03o`000?o_`Z?okl:S00Cokl:S00?o0000oo?7
XOocaj402_ocaj400ol0003om/bQooK<X@09ooK<X@05o`000?ohdZ?on=:SooSBXol000002?oebj<0
0ol0003om<nXooC?Z00:ooC?Z003o`000?oce[7olmJa00?olmJa00?o0000ooooooooool0:?ooool0
02Kooooo00?o0000ooooooooool0DOooool00ol0003o03>go`0c]`02o`0c]`03o`000?m4FL?oA5W3
00?oA5W30ol00008og9b``03o`000?nAP[ooTH:o00OoTH:o00?o0000ojN>^onWS[/02_nWS[/00ol0
003o]YNgokJG]`0<okJG]`03o`000?o3WkCo`ind00[o`ind00Co0000oljY]?o>ZKCo00002ooH[k00
0ol0003of:n`omR_/006omR_/003o`000?oW^jWoik^Y00ooik^Y00?o0000ong2Yoo]`ZL01oo]`ZL0
0ol0003okl:Sono2X`03ono2X`03o`000?ocaj7ollNQ00[ollNQ00?o0000ooK<XOofc:402Oofc:40
0ol0003on=:SooSBX`02ooSBX`03o`000?oebj?omL^S00ComL^S00?o0000ooC?Z?odcjP02_odcjP0
0ol0003olmJaoo?F/@04oo?F/@03o`000?oooooooooo02Sooooo000Vooooo`03o`000?oooooooooo
057ooooo0_l00003o`0c]`03o`000?m4FL?oA5W300?o000000?oA5W3o`000?mbL/<02?mbL/<00ol0
003oTH:ooi62_`08oi62_`03o`000?nWS[_oYhjk00[oYhjk00?o0000okJG]onfUkL02onfUkL00ol0
003o`indol>O]00:ol>O]005o`000?o>ZKCocZVdoljY]?l000002ooH[k000ol0003of:n`omR_/005
omR_/003o`000?oW^jWoik^Y00ooik^Y00?o0000ong2Yoo]`ZL01oo]`ZL00ol0003okl:Sono2X`02
ono2X`03o`000?ocaj7ollNQ00_ollNQ00?o0000ooK<XOofc:402Oofc:400ol0003on=:SooSBX`03
ooSBX`03o`000?oebj?omL^S00?omL^S00?o0000ooC?Z?odcjP02_odcjP00ol0003olmJaoo?F/@05
oo?F/@03o`000?oooooooooo02Oooooo000Vooooo`03o`000?oooooooooo05;ooooo00Co0000o`0c
]ol0<kOo03>g0ol00004odAI``03o`000?mbL/?oLW;300OoLW;300?o0000oi62_onAP[l02?nAP[l0
0ol0003oYhjkojN>^`0:ojN>^`03o`000?nfUkOo]YNg00_o]YNg00?o0000ol>O]?o3Wk@02Oo3Wk@0
0ol0003ocZVdoljY]002oljY]003o`000?oH[k3of:n`00[of:n`00?o0000omR_/?oH[k000ooH[k00
0ol0003ohKV^o`00000?onNkZ@03o`000?o]`ZOokL:W00WokL:W00Go0000ono2Xoo_`Z?okl:So`00
000<oo?7X@03o`000?ofc:7om/bQ00Wom/bQ00?o0000ooSBXoohdZ<01OohdZ<01Ol0003omL^SooG;
Xooebj?o000000com<nX00?o0000oo?F/Ooce[401ooce[400ol0003oooooooooo`0Vooooo`009_oo
ool00ol0003oooooooooo`1Cooooo`?o000000?o03>go`000?m4FL<01Om4FL<00ol0003oLW;3og9b
``07og9b``03o`000?nAP[ooTH:o00OoTH:o00?o0000ojN>^onWS[/02_nWS[/00ol0003o]YNgokJG
]`0<okJG]`03o`000?o3WkCo`ind00Oo`ind00?o0000oljY]?o>ZK@01?o>ZK@00ol0003of:n`omR_
/00:omR_/003o`000?oH[k3of:n`00;of:n`00?o0000on6i[_l000003ooW^jT00ol0003okL:Wong2
Y`0:ong2Y`04o`000?o_`Z?okl:So`0000collNQ00?o0000ooK<XOofc:402Oofc:400ol0003on=:S
ooSBX`06ooSBX`04o`000?oebj?omL^So`0000com<nX00?o0000oo?F/Ooce[401ooce[42o`0002Oo
oooo000Uooooo`03o`000?oooooooooo057ooooo1?l00004o`0c]`03o`000?m4FL?oA5W300?oA5W3
00?o0000og9b`ombL/<01ombL/<00ol0003oTH:ooi62_`08oi62_`03o`000?nWS[_oYhjk00[oYhjk
00?o0000okJG]onfUkL02onfUkL00ol0003o`indol>O]007ol>O]003o`000?o>ZKCocZVd00CocZVd
00?o0000omR_/?oH[k002_oH[k001Ol0003of:n`omR_/?oH[k3o000000?ohKV^00?o0000onNkZOoW
^jT03?oW^jT00ol0003okL:Wong2Y`0;ong2Y`;o00003Oocaj400ol0003om/bQooK<X@09ooK<X@03
o`000?ohdZ?on=:S00Oon=:S00?o0000ooG;Xol000002oodcjP00ol0003olmJaoo?F/@09oo?F/@03
o`000?oooooooooo02Gooooo000Uooooo`?o0000C_ooool3o`0000Cooooo00Go0000o`0c]ol0<kOo
03>go`000006odAI``03o`000?mbL/?oLW;300KoLW;300?o0000oi62_onAP[l02?nAP[l00ol0003o
YhjkojN>^`0:ojN>^`03o`000?nfUkOo]YNg00_o]YNg00?o0000ol>O]?o3Wk@01_o3Wk@00ol0003o
cZVdoljY]005oljY]003o`000?oH[k3of:n`00_of:n`00Co0000omR_/?oH[k3o00001?oQ^Jh00ol0
003oik^YonNkZ@0:onNkZ@03o`000?o]`ZOokL:W00gokL:W00?o0000oo?7XOocaj402oocaj400ol0
003om/bQooK<X@08ooK<X@03o`000?ohdZ?on=:S00Won=:S0_l0000;ooC?Z003o`000?oce[7olmJa
00[olmJa00?o0000ooooooooool09?ooool002Gooooo00?o0000ooooooooool0Boooool3o`0000Oo
oooo00Go0000o`0c]ol0<kOo03>go`000006odAI``03o`000?mbL/?oLW;300OoLW;300?o0000oi62
_onAP[l01onAP[l00ol0003oYhjkojN>^`0:ojN>^`03o`000?nfUkOo]YNg00co]YNg00?o0000ol>O
]?o3Wk@01?o3Wk@00ol0003ocZVdoljY]007oljY]003o`000?oH[k3of:n`00_of:n`00?o0000omR_
/?l000001?oQ^Jh00ol0003oik^YonNkZ@0:onNkZ@03o`000?o]`ZOokL:W00gokL:W00?o0000oo?7
XOocaj402_ocaj400ol0003om/bQooK<X@09ooK<X@03o`000?ohdZ?on=:S00Won=:S00?o0000ooWJ
Yol000002OodcjP00ol0003olmJaoo?F/@0;oo?F/@;o00009Oooool000Wooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Oooooo00?o0000
ooooooooool0B?ooool3o`0000_ooooo00Go0000o`0c]ol0<kOo03>go`000005odAI``03o`000?mb
L/?oLW;300OoLW;300?o0000oi62_onAP[l02?nAP[l00ol0003oYhjkojN>^`0:ojN>^`03o`000?nf
UkOo]YNg00_o]YNg00?o0000ol>O]?o3Wk@00oo3Wk@00ol0003ocZVdoljY]008oljY]003o`000?oH
[k3of:n`00cof:n`00?o0000on6i[_oQ^Jh01?oQ^Jh00ol0003oik^YonNkZ@08onNkZ@03o`000?o]
`ZOokL:W00gokL:W00?o0000oo;9YOl000002oocaj400ol0003om/bQooK<X@09ooK<X@03o`000?oh
dZ?on=:S00Son=:S00Go0000ooWJYooifZOonMZWo`000008ooC?Z003o`000?oce[7olmJa00[olmJa
00Co0000ongN`_l0003o00009?ooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Oooooo00?o0000ooooooooool0AOooool3o`00
00kooooo0_l00002o`0c]`03o`000?m4FL?oA5W300CoA5W300?o0000og9b`ombL/<01_mbL/<00ol0
003oTH:ooi62_`08oi62_`03o`000?nWS[_oYhjk00[oYhjk00?o0000okJG]onfUkL02onfUkL00ol0
003o`indol>O]003ol>O]003o`000?o>ZKCocZVd00WocZVd00?o0000omR_/?oH[k002ooH[k02o`00
00GohKV^00?o0000onNkZOoW^jT02?oW^jT00ol0003okL:Wong2Y`0=ong2Y`04o`000?obbJGol/VU
o`0000[ollNQ00?o0000ooK<XOofc:402?ofc:400ol0003on=:SooSBX`09ooSBX`03o`000?oifZOo
nMZW00;onMZW00?o0000ooC?Z?odcjP01?odcjP00ol0003olmJaoo?F/@0:oo?F/@05o`000?o]g/;o
kMk2ongN`_l000009?ooool000Wooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooooooo`12ooooo`?o00004_ooool01?l0003o03>g
o`0c]ol00006odAI``03o`000?mbL/?oLW;300OoLW;300?o0000oi62_onAP[l01onAP[l00ol0003o
YhjkojN>^`0:ojN>^`03o`000?nfUkOo]YNg00co]YNg00Go0000ol>O]?o3WkCo`indo`00000<oljY
]003o`000?oH[k3of:n`00[of:n`00Co0000on6i[_oQ^Jko00001OoQ^Jh00ol0003oik^YonNkZ@07
onNkZ@03o`000?o]`ZOokL:W00gokL:W00Go0000oo;9YOobbJGol/VUo`000008oo?7X@03o`000?of
c:7om/bQ00Wom/bQ00?o0000ooSBXoohdZ<02OohdZ<00ol0003onMZWooWJY`03ooWJY`03o`000?od
cjSom<nX00?om<nX00?o0000oo?F/Ooce[402_oce[400ol0003okMk2ongN`P02ongN`P03o`000?oo
oooooooo027ooooo0009ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooo
oonHV9So<S8b00Oooooo00?o0000ooooooooool0?oooool3o`0001Gooooo0_l00002o`0c]`03o`00
0?m4FL?oA5W300?oA5W300?o0000og9b`ombL/<01ombL/<00ol0003oTH:ooi62_`08oi62_`03o`00
0?nWS[_oYhjk00[oYhjk00?o0000okJG]onfUkL02onfUkL01?l0003o`indol>O]?l0000>oljY]003
o`000?oH[k3of:n`00Wof:n`00Go0000on6i[_oQ^JkohKV^o`000005on6i[P03o`000?oW^jWoik^Y
00Goik^Y00?o0000ong2Yoo]`ZL03Oo]`ZL00ol0003ol/VUoo;9Y@03oo;9Y@03o`000?ocaj7ollNQ
00GollNQ00?o0000ooK<XOofc:402Oofc:400ol0003on=:SooSBX`08ooSBX`03o`000?oifZOonMZW
00GonMZW00?o0000ooC?Z?odcjP00_odcjP00ol0003olmJaoo?F/@09oo?F/@03o`000?o]g/;okMk2
00?okMk20_l0000Rooooo`002Oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`00
0?l0003o0000olc<c007ooooo`03o`000?oooooooooo03cooooo0ol0000Iooooo`;o000000?o03>g
o`000?m4FL<01Om4FL<00ol0003oLW;3og9b``06og9b``03o`000?nAP[ooTH:o00SoTH:o00?o0000
ojN>^onWS[/02_nWS[/00ol0003o]YNgokJG]`0;okJG]`04o`000?o3WkCo`indo`0000kocZVd00?o
0000omR_/?oH[k002?oH[k000ol0003ohKV^on6i[P03on6i[P03o`000?oQ^JkohKV^00;ohKV^00?o
0000onNkZOoW^jT01OoW^jT00ol0003okL:Wong2Y`0=ong2Y`03o`000?obbJGol/VU00Col/VU00?o
0000oo?7XOocaj401?ocaj400ol0003om/bQooK<X@08ooK<X@03o`000?ohdZ?on=:S00Won=:S00?o
0000ooWJYooifZL01_oifZL01?l0003om<nXooC?Z?l0000;oo?F/@03o`000?o]g/;okMk200GokMk2
0_l0000Qooooo`002Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo
^[Zjoa0@4007ooooo`03o`000?oooooooooo03Wooooo0ol0000Mooooo`;o000000?o03>go`000?m4
FL<01?m4FL<00ol0003oLW;3og9b``07og9b``03o`000?nAP[ooTH:o00OoTH:o00?o0000ojN>^onW
S[/02_nWS[/00ol0003o]YNgokJG]`0<okJG]`;o00004?o>ZK@00ol0003of:n`omR_/007omR_/003
o`000?oQ^JkohKV^00?ohKV^00?o0000on6i[_oQ^Jh00ooQ^Jh00ol0003oik^YonNkZ@04onNkZ@03
o`000?o]`ZOokL:W00gokL:W00?o0000oo;9YOobbJD01OobbJD00ol0003ollNQoo?7X@02oo?7X@03
o`000?ofc:7om/bQ00Wom/bQ00?o0000ooSBXoohdZ<02OohdZ<00ol0003onMZWooWJY`07ooWJY`03
o`000?odcjSo000000_olmJa00?o0000ongN`_o]g/801_o]g/800ol0003oooooooooo`0Oooooo`00
2Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo03Oooooo0ol0000Pooooo`;o000000?o03>go`000?m4FL<01Om4FL<00ol0
003oLW;3og9b``06og9b``03o`000?nAP[ooTH:o00SoTH:o00?o0000ojN>^onWS[/02_nWS[/00ol0
003o]YNgokJG]`0;okJG]`03o`000?o>ZKCocZVd00oocZVd00?o0000omR_/?oH[k001ooH[k000ol0
003ohKV^on6i[P04on6i[P03o`000?oQ^JkohKV^00;ohKV^00?o0000onNkZOoW^jT00ooW^jT00ol0
003okL:Wong2Y`0=ong2Y`03o`000?obbJGol/VU00Ool/VU00Go0000oo?7XOocaj7ollNQo`00000;
ooK<X@03o`000?ohdZ?on=:S00Son=:S00?o0000ooWJYooifZL02OoifZL2o`0000[olmJa00?o0000
ongN`_o]g/801oo]g/82o`00023ooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0=?ooool3o`0002Cooooo0ol0
0006odAI``03o`000?mbL/?oLW;300KoLW;300?o0000oi62_onAP[l02?nAP[l00ol0003oYhjkojN>
^`0:ojN>^`03o`000?nfUkOo]YNg00_o]YNg00?o0000oljY]?o>ZK@04?o>ZK@00ol0003of:n`omR_
/005omR_/003o`000?oQ^JkohKV^00KohKV^00?o0000on6i[_oQ^Jh00_oQ^Jh00ol0003oik^YonNk
Z@02onNkZ@03o`000?o]`ZOokL:W00gokL:W00?o0000oo;9YOobbJD02?obbJD01?l0003ollNQoo?7
XOl0000:ooK<X@03o`000?ohdZ?on=:S00Won=:S00?o0000ooWJYooifZL02OoifZL00ol0003on>F`
o`000009oo?F/@03o`000?o]g/;okMk200SokMk20_l0000Oooooo`009?ooool00ol0003ooooooooo
o`0aooooo`?o00009oooool01?l0003o002<o`000?l00005odAI``03o`000?mbL/?oLW;300OoLW;3
00?o0000oi62_onAP[l01onAP[l00ol0003oYhjkojN>^`0:ojN>^`03o`000?nfUkOo]YNg00[o]YNg
00?o0000ol6R^_l000004Oo>ZK@00ol0003of:n`omR_/005omR_/003o`000?oQ^JkohKV^00OohKV^
00Go0000on6i[_oQ^JkohKV^o`000004onNkZ@03o`000?o]`ZOokL:W00gokL:W00?o0000oo;9YOob
bJD02OobbJD2o`0000_om/bQ00?o0000ooSBXoohdZ<02OohdZ<00ol0003onMZWooWJY`08ooWJY`05
o`000?ohiK3on>F`ooSU/?l000001ooce[400ol0003okMk2ongN`P0:ongN`P;o00007_ooool002Co
oooo00?o0000ooooooooool0;oooool2o`0002_ooooo0ol00006odAI``03o`000?mbL/?oLW;300Ko
LW;300?o0000oi62_onAP[l02?nAP[l00ol0003oYhjkojN>^`0:ojN>^`03o`000?nfUkOo]YNg00So
]YNg00Co0000ol6R^_o1X[[o00004_o>ZK@00ol0003of:n`omR_/003omR_/003o`000?oQ^JkohKV^
00WohKV^00Go0000on6i[_oQ^JkohKV^o`000002onNkZ@03o`000?o]`ZOokL:W00gokL:W00?o0000
oo;9YOobbJD02oobbJD2o`0000[om/bQ00?o0000ooSBXoohdZ<02?ohdZ<00ol0003onMZWooWJY`09
ooWJY`03o`000?ohiK3on>F`00;on>F`0_l00004oo?F/@03o`000?o]g/;okMk200_okMk20_l0000N
ooooo`009?ooool00ol0003oooooooooo`0/ooooo`?o0000;Oooool00ol0003o002<o`000006odAI
``03o`000?mbL/?oLW;300KoLW;300?o0000oi62_onAP[l02?nAP[l00ol0003oYhjkojN>^`0:ojN>
^`03o`000?nfUkOo]YNg00Oo]YNg00?o0000ol6R^_o1X[X00_o1X[X00ol0003ocZVdoljY]00?oljY
]003o`000?oH[k3of:n`00?of:n`00?o0000on6i[_oQ^Jh02_oQ^Jh01ol0003ohKV^on6i[_oQ^Jko
0000onNkZOl000003oo]`ZL00ol0003ol/VUoo;9Y@0;oo;9Y@03o`000?ogdJGo000000Som/bQ00?o
0000ooSBXoohdZ<02OohdZ<00ol0003onMZWooWJY`08ooWJY`03o`000?ohiK3on>F`00Gon>F`00Go
0000oo?F/Ooce[7olmJao`00000<ongN`P04o`000?oKi]co0000o`0001gooooo000Tooooo`03o`00
0?oooooooooo02Wooooo0ol0000aooooo`04o`000?l008co0000o`0000CoA5W300?o0000og9b`omb
L/<01ombL/<00ol0003oTH:ooi62_`07oi62_`03o`000?nWS[_oYhjk00[oYhjk00?o0000okJG]onf
UkL01_nfUkL00ol0003o`J:jol6R^P03ol6R^P03o`000?o>ZKCocZVd00oocZVd00?o0000omR_/?oH
[k000_oH[k000ol0003ohKV^on6i[P0<on6i[P06o`000?oQ^JkohKV^o`000?oW^jWo00003oo]`ZL0
0ol0003ol/VUoo;9Y@0:oo;9Y@05o`000?ogdJGomm6UooOAYOl000001oofc:400ol0003on=:SooSB
X`09ooSBX`03o`000?oifZOonMZW00SonMZW00?o0000ooSU/?ohiK001_ohiK000ol0003olmJao`00
000<ongN`P04o`000?oKi]cofnKLom_Vg0;o00007?ooool002Cooooo00?o0000ooooooooool09_oo
ool3o`0003Cooooo00Go0000o`00S?l0003o1S^lo`000004odAI``03o`000?mbL/?oLW;300KoLW;3
00?o0000oi62_onAP[l02?nAP[l00ol0003oYhjkojN>^`0:ojN>^`03o`000?nfUkOo]YNg00Co]YNg
00?o0000ol6R^_o1X[X01?o1X[X00ol0003ocZVdoljY]00@oljY]005o`000?oH[k3of:n`omR_/?l0
00003ooQ^Jh01?l0003ohKV^on6i[_l0000?ong2Y`03o`000?obbJGol/VU00_ol/VU00?o0000ooOA
YOogdJD00_ogdJD00ol0003om/bQooK<X@04ooK<X@03o`000?ohdZ?on=:S00Son=:S00?o0000ooWJ
YooifZL02?oifZL00ol0003on>F`ooSU/008ooSU/0;o00002oo]g/800ol0003ofnKLom_Vg003om_V
g0;o00006oooool002?ooooo0_l0000Uooooo`?o0000>?ooool01Ol0003o002<o`000?l6>kco0000
00?oA5W300?o0000og9b`ombL/<01_mbL/<00ol0003oTH:ooi62_`08oi62_`03o`000?nWS[_oYhjk
00[oYhjk00?o0000okJG]onfUkL01?nfUkL00ol0003o`J:jol6R^P05ol6R^P03o`000?o>ZKCocZVd
00oocZVd00Go0000omR_/?oH[k3of:n`o`00000?on6i[P04o`000?oQ^JkohKV^o`0000ookL:W00?o
0000oo;9YOobbJD02oobbJD00ol0003omm6UooOAY@03ooOAY@03o`000?ofc:7om/bQ00;om/bQ00?o
0000ooSBXoohdZ<02OohdZ<00ol0003onMZWooWJY`08ooWJY`03o`000?ohiK3on>F`00Son>F`00?o
0000oo3c`?l000002Oo]g/800ol0003ofnKLom_Vg005om_Vg003o`000?oooooooooo01Wooooo000T
ooooo`03o`000?oooooooooo023ooooo0ol0000kooooo`03o`000?l008co000000;o1S^l00Go0000
odAI`om4FL?oA5W3o`000008og9b``03o`000?nAP[ooTH:o00OoTH:o00?o0000ojN>^onWS[/02_nW
S[/00ol0003o]YNgokJG]`03okJG]`03o`000?o1X[[o`J:j00Ko`J:j00?o0000oljY]?o>ZK@04?o>
ZK@00ol0003of:n`o`00000Aon6i[P;o000000?ojL:]o`000?o]`ZL03?o]`ZL00ol0003ol/VUoo;9
Y@0;oo;9Y@03o`000?ogdJGomm6U00Gomm6U00Go0000ooK<XOofc:7om/bQo`00000;ooSBX`03o`00
0?oifZOonMZW00OonMZW00?o0000ooSU/?ohiK002?ohiK001?l0003ol??0oo3c`?o`ll02o`0000Ko
kMk200?o0000om_Vg?oKi]`01ooKi]`00ol0003oooooooooo`0Hooooo`008oooool00ol0003ooooo
ooooo`0Nooooo`?o0000?oooool00ol0003o002<o`000002o`Hk_004o`000?m4FL?oA5W3o`0000So
LW;300?o0000oi62_onAP[l02?nAP[l00ol0003oYhjkojN>^`0:ojN>^`05o`000?nfUkOo]YNgokJG
]ol000002_o1X[X00ol0003ocZVdoljY]00?oljY]003o`000?oH[k3o000001;ohKV^00Co0000onW2
[OoY`Zgo00003?o]`ZL00ol0003ol/VUoo;9Y@0;oo;9Y@03o`000?ogdJGomm6U00Komm6U00Co0000
ooK<XOofc:7o00002_ohdZ<00ol0003onMZWooWJY`08ooWJY`03o`000?ohiK3on>F`00Oon>F`00?o
0000oo3c`?o`ll001?o`ll02o`0000?okMk200?o0000om_Vg?oKi]`02OoKi]`00ol0003ooooooooo
o`0Gooooo`008oooool00ol0003oooooooooo`0Kooooo`?o0000@oooool2o`0000?o1S^l00?o0000
odAI`ol000002?mbL/<00ol0003oTH:ooi62_`08oi62_`03o`000?nWS[_oYhjk00[oYhjk00Co0000
okJG]onfUkOo00002oo1X[X00ol0003ocZVdoljY]00@oljY]003o`000?oQ^JkohKV^017ohKV^0_l0
0002onW2[@03o`000?o]`ZOokL:W00WokL:W00?o0000oo;9YOobbJD02oobbJD00ol0003omm6UooOA
Y@07ooOAY@;o00002oohdZ<00ol0003onMZWooWJY`07ooWJY`03o`000?ohiK3on>F`00Son>F`00?o
0000oo3c`?o`ll001_o`ll000ol0003okMk2o`00000<om_Vg0;o00006?ooool002?ooooo00?o0000
ooooooooool06?ooool3o`0004Kooooo00?o0000o`00S?l000000ol6>k`00ol0003oA5W3o`000008
og9b``03o`000?nAP[ooTH:o00OoTH:o00?o0000ojN>^onWS[/02_nWS[/00ol0003o]YNgo`00000=
ol6R^P03o`000?o>ZKCocZVd00oocZVd00?o0000on6i[_oQ^Jh04?oQ^Jh01?l0003ojL:]onW2[Ol0
0002onW2[@03o`000?o]`ZOokL:W00OokL:W00?o0000oo;9YOobbJD02oobbJD00ol0003omm6UooOA
Y@09ooOAY@;o00002_ohdZ<00ol0003onMZWooWJY`07ooWJY`03o`000?ohiK3on>F`00Oon>F`00?o
0000oo3c`?o`ll002?o`ll02o`0000gofnKL00?o0000ooooooooool05_ooool002?ooooo00?o0000
ooooooooool05Oooool3o`0004[ooooo0_l00004o`Hk_0;o00002?mbL/<00ol0003oTH:ooi62_`08
oi62_`03o`000?nWS[_oYhjk00WoYhjk0_l0000>ol6R^P03o`000?o>ZKCocZVd00kocZVd00?o0000
omVe]Ol000004OoQ^Jh01ol0003ojL:]onW2[OoY`Zgo0000onW2[Ol000002Oo]`ZL00ol0003ol/VU
oo;9Y@0;oo;9Y@03o`000?ogdJGomm6U00Womm6U00Co0000oo[JYOl0003o00001oohdZ<00ol0003o
nMZWooWJY`08ooWJY`03o`000?ohiK3on>F`00Kon>F`00?o0000oo3c`?o`ll002?o`ll001?l0003o
d?oGom3oeol0000=om_Vg003o`000?oooooooooo01Gooooo000Sooooo`03o`000?oooooooooo01;o
oooo0ol0001=ooooo`03o`000?l008co000000Co1S^l00?o0000og9b`ombL/<01_mbL/<00ol0003o
TH:ooi62_`08oi62_`03o`000?nWS[_oYhjk00OoYhjk0_l000000on]V<7o0000ol6R^P0=ol6R^P03
o`000?o>ZKCocZVd00gocZVd00Co0000omVe]OoI]KGo00004?oQ^Jh00ol0003ojL:]onW2[@03onW2
[@03o`000?oY`Zgo000000SokL:W00?o0000oo;9YOobbJD02_obbJD00ol0003omm6UooOAY@09ooOA
Y@03o`000?ojfZGon]ZU00;on]ZU0_l00005ooSBX`03o`000?oifZOonMZW00OonMZW00?o0000ooSU
/?ohiK001oohiK000ol0003ol??0oo3c`007oo3c`003o`000?o@omOod?oG00;od?oG0_l0000<om_V
g003o`000?oooooooooo01Cooooo000Rooooo`?o00004?ooool3o`00057ooooo0_l00005o`Hk_0;o
00001ombL/<00ol0003oTH:ooi62_`07oi62_`03o`000?nWS[_oYhjk00GoYhjk0_l00004ojfH`@03
o`000?o1X[[o`J:j00co`J:j00?o0000oljY]?o>ZK@03?o>ZK@01Ol0003ofKFeomVe]OoI]KGo0000
00oohKV^00?o0000onW2[OoY`Zd01?oY`Zd00ol0003ojL:]o`000006ong2Y`03o`000?obbJGol/VU
00_ol/VU00?o0000ooOAYOogdJD02OogdJD00ol0003on]ZUoo[JY@04oo[JY@;o00000oohdZ<00ol0
003onMZWooWJY`07ooWJY`03o`000?ohiK3on>F`00Kon>F`00?o0000oo3c`?o`ll001oo`ll000ol0
003od?oGom3oe`05om3oe`;o00002OoKi]`3o`0001Gooooo000Sooooo`03o`000?oooooooooo00co
oooo0ol0001Dooooo`03o`000?l008co000000Co1S^l00?o0000oeY/bol000000_l00004og9b``03
o`000?nAP[ooTH:o00SoTH:o00?o0000ojN>^onWS[/00onWS[/00ol0003o[IS1ojfH`@04ojfH`@03
o`000?o1X[[o`J:j00co`J:j00?o0000oljY]?o>ZK@02oo>ZK@00ol0003ofKFeomVe]@02omVe]@03
o`000?oQ^JkohKV^00cohKV^00?o0000onW2[OoY`Zd01OoY`Zd01?l0003ojL:]onW2[Ol00005ong2
Y`03o`000?obbJGol/VU00_ol/VU00?o0000ooOAYOogdJD02OogdJD00ol0003on]ZUoo[JY@06oo[J
Y@?o00002OoifZL00ol0003on>F`ooSU/007ooSU/003o`000?o`ll3ol??000Kol??000?o0000om3o
eoo@omL02?o@omL01?l0003ofnKLom_Vg?oKi]`5o`0000;ooooo00?o0000ooooooooool04oooool0
02?ooooo00?o0000ooooooooool02Oooool3o`0005Sooooo0_l00005o`Hk_004o`000?mJK<_oFVc;
oeY/b`;o00000_mbL/<00ol0003oTH:ooi62_`08oi62_`04o`000?nWS[_oYhjkojN>^`;o00001on]
V<400ol0003o`J:jol6R^P0=ol6R^P03o`000?o>ZKCocZVd00[ocZVd00?o0000omVe]OoI]KD00ooI
]KD00ol0003ohKV^on6i[P0;on6i[P03o`000?oY`ZgojL:]00KojL:]00?o0000onW2[Ol000001Oo]
`ZL00ol0003ol/VUoo;9Y@0:oo;9Y@03o`000?ogdJGomm6U00Womm6U00?o0000oo[JYOojfZD02Ooj
fZD2o`0000SonMZW00?o0000ooSU/?ohiK001_ohiK000ol0003ol??0oo3c`006oo3c`003o`000?o@
omOod?oG00Wod?oG1_l00005ooooo`03o`000?oooooooooo01?ooooo000Sooooo`03o`000?oooooo
oooo00Kooooo0ol0001Kooooo`03o`000?l008co000000Co1S^l00?o0000oeY/bomJK</00omJK</4
o`0000WoTH:o00Co0000ojN>^ol0003o00002_n]V<400ol0003o`J:jol6R^P0<ol6R^P03o`000?o>
ZKCocZVd00WocZVd00?o0000omVe]OoI]KD01OoI]KD00ol0003ohKV^on6i[P0:on6i[P03o`000?oY
`ZgojL:]00OojL:]00?o0000onW2[Ol000000oo]`ZL00ol0003ol/VUoo;9Y@0;oo;9Y@03o`000?og
dJGomm6U00Womm6U00?o0000oo[JYOojfZD02OojfZD00ol0003onnJXo`000002o`0000ConMZW00?o
0000ooSU/?ohiK001_ohiK000ol0003ol??0oo3c`006oo3c`003o`000?o@omOod?oG00Ood?oG1_l0
0008ooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo00Cooooo0ol0001O
ooooo`;o00001Ol6>k`00ol0003oFVc;oeY/b`05oeY/b`co00003?n]V<400ol0003o`J:jol6R^P0=
ol6R^P03o`000?o>ZKCocZVd00OocZVd00?o0000omVe]OoI]KD01_oI]KD00ol0003ohKV^on6i[P09
on6i[P03o`000?oY`ZgojL:]00WojL:]00?o0000onW2[Ol000000_o]`ZL00ol0003ol/VUoo;9Y@0;
oo;9Y@03o`000?ogdJGomm6U00Womm6U00?o0000oo[JYOojfZD02?ojfZD00ol0003onnJXoo_VZ003
oo_VZ0?o000000?onMZWo`000?ohiK001oohiK000ol0003ol??0oo3c`005oo3c`003o`000?o@omOo
d?oG00God?oG1Ol0000<ooooo`03o`000?oooooooooo01?ooooo000Rooooo`04o`000?oooooooooo
ooooo`?o0000Hoooool00ol0003o1S^lo`Hk_003o`Hk_003o`000?mJK<_oFVc;00GoFVc;00?o0000
ohj8b?n>R<P02?n>R<P00ol0003o[IS1ojfH`@0;ojfH`@03o`000?o1X[[o`J:j00co`J:j00?o0000
oljY]?o>ZK@01oo>ZK@00ol0003ofKFeomVe]@07omVe]@03o`000?oQ^JkohKV^00SohKV^00?o0000
onW2[OoY`Zd02_oY`Zd01Ol0003ojL:]o`000?o]`ZOo000000col/VU00?o0000ooOAYOogdJD02Oog
dJD00ol0003on]ZUoo[JY@09oo[JY@03o`000?okiZSonnJX00KonnJX1Ol00004ooSU/003o`000?o`
ll3ol??000Gol??000?o0000om3oeoo@omL02?l0000?ooooo`03o`000?oooooooooo01?ooooo000R
ooooo`Co0000I_ooool2o`0000Co1S^l00?o0000oeY/bomJK</01_mJK</00ol0003oSXS8ohj8b008
ohj8b003o`000?n]V<7o[IS100[o[IS100?o0000ol6R^_o1X[X03?o1X[X00ol0003ocZVdoljY]006
oljY]003o`000?oI]KGofKFe00SofKFe00?o0000on6i[_oQ^Jh01ooQ^Jh00ol0003ojL:]onW2[@0<
onW2[@03o`000?oY`Zgo000000gol/VU00?o0000ooOAYOogdJD02OogdJD00ol0003on]ZUoo[JY@08
oo[JY@03o`000?okiZSonnJX00OonnJX00?o0000ooCbZoodlZ/00_odlZ/Do`0001;ooooo00?o0000
ooooooooool04oooool002;ooooo0ol0001Xooooo`03o`000?l6>kco1S^l00?o1S^l00?o0000oeY/
bomJK</01OmJK</00ol0003oSXS8ohj8b008ohj8b003o`000?n]V<7o[IS100[o[IS100?o0000ol6R
^_o1X[X03Oo1X[X00ol0003ocZVdoljY]005oljY]003o`000?oI]KGofKFe00WofKFe00?o0000on6i
[_oQ^Jh01_oQ^Jh00ol0003ojL:]onW2[@0=onW2[@?o00003?obbJD00ol0003omm6UooOAY@09ooOA
Y@03o`000?ojfZGon]ZU00Son]ZU00?o0000oo_VZ?okiZP01_okiZP00ol0003om?:[ooCbZ`06ooCb
Z`03o`000?oInJcofOV/00?ofOV/00?o0000oh?KUon3fiL01?l0000Gooooo`03o`000?oooooooooo
01;ooooo000Tooooo`03o`000?oooooooooo06Kooooo0_l00004o`Hk_003o`000?mJK<_oFVc;00Go
FVc;00?o0000ohj8b?n>R<P02?n>R<P00ol0003o[IS1ojfH`@0;ojfH`@03o`000?o1X[[o`J:j00co
`J:j00?o0000oljY]?o>ZK@01?o>ZK@00ol0003ofKFeomVe]@0:omVe]@03o`000?oQ^JkohKV^00Ko
hKV^00?o0000onW2[OoY`Zd03OoY`Zd01?l0003olLf/oo7=[?l0000:oo;9Y@03o`000?ogdJGomm6U
00Womm6U00?o0000oo[JYOojfZD02OojfZD00ol0003onnJXoo_VZ006oo_VZ003o`000?odlZ_om?:[
00Gom?:[00?o0000omWi[?oInJ`00ooInJ`5o`0001[ooooo00?o0000ooooooooool04_ooool001Ko
oooo00?ok^k^o`000?l000000_l000000ol@413oooooooooo`07ooooo`03o`000?oooooooooo06Ko
oooo00?o0000o`Hk_?l6>k`00ol6>k`00ol0003oFVc;oeY/b`05oeY/b`03o`000?n>R<SoSXS800So
SXS800?o0000ojfH`On]V<402_n]V<400ol0003o`J:jol6R^P0=ol6R^P03o`000?o>ZKCocZVd00;o
cZVd00?o0000omVe]OoI]KD03?oI]KD00ol0003ohKV^on6i[P04on6i[P03o`000?oY`ZgojL:]00ko
jL:]0_l00002oo7=[003o`000?obbJGol/VU00Ool/VU00?o0000ooOAYOogdJD02OogdJD00ol0003o
n]ZUoo[JY@08oo[JY@03o`000?okiZSonnJX00KonnJX00?o0000ooCbZoodlZ/01OodlZ/00ol0003o
fOV/omWi[003omWi[0?o00007Oooool00ol0003oooooooooo`0Booooo`005_ooool01OmgMgOoV9RH
ooooool0003oMgMg00_ooooo00?o0000ooooooooool0IOooool2o`0000Co1S^l00?o0000oeY/bomJ
K</01OmJK</00ol0003oSXS8ohj8b008ohj8b003o`000?n]V<7o[IS100_o[IS100?o0000ol6R^_o1
X[X03?o1X[X00ol0003ocZVdoljY]002oljY]003o`000?oI]KGofKFe00cofKFe00?o0000on6i[_oQ
^Jh01?oQ^Jh00ol0003ojL:]onW2[@0>onW2[@03o`000?oacJco000000;olLf/00?o0000oo;9YOob
bJD01OobbJD00ol0003omm6UooOAY@09ooOAY@03o`000?ojfZGon]ZU00Won]ZU00?o0000oo_VZ?ok
iZP01_okiZP00ol0003om?:[ooCbZ`05ooCbZ`03o`000?oInJcofOV/00;ofOV/0_l0000Oooooo`03
o`000?oooooooooo01;ooooo000Fooooo`05oa0@4?ooooooooooo`000?l@41003?ooool00ol0003o
ooooooooo`1Uooooo`03o`000?l6>kco1S^l00?o1S^l00?o0000oeY/bomJK</01OmJK</00ol0003o
SXS8ohj8b008ohj8b003o`000?n]V<7o[IS100[o[IS100?o0000ol6R^_o1X[X03Oo1X[X01?l0003o
cZVdoljY]?l0000@omVe]@03o`000?oQ^JkohKV^00;ohKV^00?o0000onW2[OoY`Zd03_oY`Zd01Ol0
003olLf/oo7=[?oacJco000000;olLf/00?o0000oo;9YOobbJD01?obbJD00ol0003omm6UooOAY@09
ooOAY@03o`000?ojfZGon]ZU00Son]ZU00?o0000oo_VZ?okiZP01_okiZP00ol0003om?:[ooCbZ`05
ooCbZ`03o`000?oInJcofOV/00;ofOV/0_l0000Pooooo`03o`000?oooooooooo01;ooooo000Foooo
o`03o`000?oooooooooo00;o00003Oooool00ol0003oooooooooo`1Tooooo`;o00001?l6>k`00ol0
003oFVc;oeY/b`05oeY/b`03o`000?n>R<SoSXS800SoSXS800?o0000ojfH`On]V<402_n]V<400ol0
003o`J:jol6R^P0=ol6R^P04o`000?o>ZKCocZVdo`00017ofKFe00Go0000on6i[_oQ^JkohKV^o`00
000@onW2[@03o`000?oacJcolLf/00;olLf/00Co0000oo7=[?oacJco00001OobbJD00ol0003omm6U
ooOAY@09ooOAY@03o`000?ojfZGon]ZU00Son]ZU00?o0000oo_VZ?okiZP01_okiZP00ol0003om?:[
ooCbZ`04ooCbZ`03o`000?oInJcofOV/00;ofOV/00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0Booooo`005_ooool00ol0003oooooooooo`02o`0000kooooo00?o0000ooooooooool0I?oo
ool00ol0003o1S^lo`Hk_003o`Hk_003o`000?mJK<_oFVc;00GoFVc;00?o0000ohj8b?n>R<P02?n>
R<P00ol0003o[IS1ojfH`@0:ojfH`@03o`000?o1X[[o`J:j00co`J:j00?o0000oljY]?l000004_oI
]KD01?l0003ohKV^on6i[_l0000@onW2[@03o`000?oacJcolLf/00ColLf/00Co0000oo7=[?oacJco
00000oobbJD00ol0003omm6UooOAY@09ooOAY@03o`000?ojfZGon]ZU00Son]ZU00?o0000oo_VZ?ok
iZP01_okiZP00ol0003om?:[ooCbZ`04ooCbZ`03o`000?oInJcofOV/00;ofOV/00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Booooo`005_ooool01Ol@413oooooooooool0003o410@00oo
oooo00?o0000ooooooooool0I?ooool00ol0003o1S^lo`Hk_002o`Hk_003o`000?mJK<_oFVc;00Go
FVc;00?o0000ohj8b?n>R<P02?n>R<P00ol0003o[IS1ojfH`@0:ojfH`@03o`000?o1X[[o`J:j00go
`J:j00?o0000omVe]OoI]KD04_oI]KD00ol0003ohKV^o`00000@onW2[@03o`000?oacJcolLf/00Go
lLf/00Co0000oo7=[?oacJco00000_obbJD00ol0003omm6UooOAY@09ooOAY@03o`000?ojfZGon]ZU
00Son]ZU00?o0000oo_VZ?okiZP01OokiZP00ol0003om?:[ooCbZ`05ooCbZ`03o`000?oInJcofOV/
00;o00009?ooool00ol0003oooooooooo`0Booooo`005_ooool01OmgMgOoV9RHooooool0003oMgMg
013ooooo0_l0001Tooooo`03o`000?l6>kco1S^l00;o1S^l00?o0000oeY/bomJK</01OmJK</00ol0
003oSXS8ohj8b008ohj8b003o`000?n]V<7o[IS100[o[IS100?o0000ol6R^_o1X[X03Oo1X[X00ol0
003ofKFeomVe]@0BomVe]@03o`000?oQ^Jko0000013ojL:]00?o0000oo7=[?oacJ`01_oacJ`01_l0
003olLf/oo7=[?l0003ol/VUo`0000_omm6U00?o0000oo[JYOojfZD02?ojfZD00ol0003onnJXoo_V
Z005oo_VZ003o`000?odlZ_om?:[00Com?:[00Co0000omWi[?oInJco00009_ooool00ol0003ooooo
ooooo`0Booooo`005_ooool01Oo^k^ko0`<3o`000?l0003ok^k^01;ooooo00?o0000ooooooooool0
H_ooool00ol0003o1S^lo`Hk_002o`Hk_003o`000?mJK<_oFVc;00GoFVc;00?o0000ohj8b?n>R<P0
2?n>R<P00ol0003o[IS1ojfH`@0:ojfH`@03o`000?o1X[[o`J:j00_o`J:j00?o0000olb`__l00000
5?oI]KD00ol0003ojL:]onW2[@0>onW2[@03o`000?oacJcolLf/00OolLf/00Co0000oo7=[?oacJco
lLf/0_l0000:ooOAY@03o`000?ojfZGon]ZU00Son]ZU00?o0000oo_VZ?okiZP01OokiZP00ol0003o
m?:[ooCbZ`04ooCbZ`04o`000?oInJco0000o`0002Oooooo00?o0000ooooooooool04_ooool002co
oooo00?o0000ooooool00000Hoooool00ol0003o1S^lo`Hk_002o`Hk_003o`000?mJK<_oFVc;00Go
FVc;00?o0000ohj8b?n>R<P02?n>R<P00ol0003o[IS1ojfH`@0:ojfH`@03o`000?o1X[[o`J:j00[o
`J:j00Co0000olb`__o</;ko00005?oI]KD00ol0003ojL:]onW2[@0>onW2[@03o`000?oacJcolLf/
00SolLf/00Go0000oo7=[?oacJco0000ooOH[002o`0000Somm6U00?o0000oo[JYOojfZD02?ojfZD0
0ol0003onnJXoo_VZ005oo_VZ003o`000?odlZ_om?:[00Com?:[0ol0000Xooooo`03o`000?oooooo
oooo01;ooooo000_ooooo`03o`000?oooooooooo067ooooo00?o0000o`Hk_?l6>k`00_l6>k`00ol0
003oFVc;oeY/b`05oeY/b`03o`000?n>R<SoSXS800SoSXS800?o0000ojfH`On]V<402_n]V<400ol0
003o`J:jol6R^P08ol6R^P03o`000?o</;koc;2n00;oc;2n00?o0000omVe]OoI]KD04?oI]KD00ol0
003ohl:fo`00000>onW2[@03o`000?oacJcolLf/00[olLf/0_l00004ooOH[003o`000?ogdJGomm6U
00Gomm6U00?o0000oo[JYOojfZD01oojfZD00ol0003onnJXoo_VZ005oo_VZ003o`000?odlZ_om?:[
00Com?:[0_l0000[ooooo`03o`000?oooooooooo017ooooo000`ooooo`03o`000?oooooooooo067o
oooo00Go0000o`Hk_?l6>kco1S^lo`000007oeY/b`03o`000?n>R<SoSXS800SoSXS800?o0000ojfH
`On]V<402_n]V<400ol0003o`J:jol6R^P07ol6R^P03o`000?o</;koc;2n00Coc;2n00?o0000omVe
]OoI]KD03ooI]KD01?l0003ohl:fon?2]_l0000=onW2[@03o`000?oacJcolLf/00_olLf/00?o0000
ooOH[?ogf:`00oogf:`2o`0000Comm6U00?o0000oo[JYOojfZD02?ojfZD00ol0003onnJXoo_VZ005
oo_VZ003o`000?odlZ_om?:[00;om?:[0ol0000/ooooo`03o`000?oooooooooo017ooooo000aoooo
o`03o`000?oooooooooo063ooooo0_l00003o`Hk_003o`000?mJK<_oFVc;00CoFVc;00?o0000ohj8
b?n>R<P02?n>R<P00ol0003o[IS1ojfH`@0:ojfH`@03o`000?o1X[[o`J:j00Ko`J:j00?o0000olb`
__o</;h01Oo</;h00ol0003ofKFeomVe]@0>omVe]@03o`000?oS`[Kohl:f00;ohl:f00?o0000onW2
[OoY`Zd02_oY`Zd00ol0003olLf/oo7=[00;oo7=[0;o00001_ogf:`2o`0000;omm6U00?o0000oo[J
YOojfZD01oojfZD00ol0003onnJXoo_VZ005oo_VZ003o`000?odlZ_om?:[00?o000000?ofO>Jo`00
0?ooool0;?ooool00ol0003oooooooooo`0Aooooo`00<_ooool00ol0003oooooooooo`1Pooooo`;o
00000_l6>k`00ol0003oFVc;oeY/b`05oeY/b`03o`000?n>R<SoSXS800SoSXS800?o0000ojfH`On]
V<402_n]V<400ol0003o`J:jol6R^P04ol6R^P03o`000?o</;koc;2n00Ooc;2n00?o0000omVe]OoI
]KD03OoI]KD00ol0003ohl:fon?2]P02on?2]P03o`000?oY`ZgojL:]00WojL:]00?o0000oo7=[?oa
cJ`02ooacJ`01?l0003ommR/ooOH[?l00007ooOH[003o`000?ogdJGo000000Won]ZU00?o0000oo_V
Z?okiZP01OokiZP3o`0000?ofO>J00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Aoooo
o`00<oooool00ol0003oooooooooo`1Oooooo`03o`000?l03ioo000000;o1S^l00?o0000oeY/bomJ
K</01?mJK</00ol0003oSXS8ohj8b008ohj8b003o`000?n]V<7o[IS100[o[IS100?o0000ol6R^_o1
X[X00oo1X[X00ol0003oc;2nolb`_P08olb`_P03o`000?oI]KGofKFe00cofKFe00?o0000on?2]_oS
`[H01?oS`[H00ol0003ojL:]onW2[@08onW2[@03o`000?oacJcolLf/00_olLf/00Go0000ooOH[?og
f:commR/o`000007ooOH[0Ko00001OojfZD00ol0003onnJXoo_VZ005o`0000GofO>J0_l0000^oooo
o`03o`000?oooooooooo017ooooo000dooooo`;o0000H?ooool01Ol0003o00nOo`000?l6>kco0000
00OoFVc;00?o0000ohj8b?n>R<P02?n>R<P00ol0003o[IS1ojfH`@0:ojfH`@05o`000?o1X[[o`J:j
ol6R^_l000003?o</;h00ol0003ofKFeomVe]@0;omVe]@03o`000?oS`[Kohl:f00Gohl:f00?o0000
onW2[OoY`Zd01_oY`Zd00ol0003olLf/oo7=[00<oo7=[003o`000?ogf:commR/00;ommR/00?o0000
ooOH[?ogf:`01?ogf:`00ol0003on^F[oo[UZ`03oo[UZ`So00001?oelJL00ol0003ofO>JomWcVP02
omWcVP;o0000;oooool00ol0003oooooooooo`0Aooooo`00=_ooool00ol0003oooooooooo`1Noooo
o`04o`000?l03ioo0000o`0000OoFVc;00?o0000ohj8b?n>R<P02?n>R<P00ol0003o[IS1ojfH`@0:
ojfH`@04o`000?o1X[[o`J:jo`0000goc;2n00?o0000omVe]OoI]KD02_oI]KD00ol0003ohl:fon?2
]P07on?2]P03o`000?oY`ZgojL:]00GojL:]00?o0000oo7=[?oacJ`02ooacJ`00ol0003ommR/ooOH
[003ooOH[003o`000?ogf:commR/00?ommR/00?o0000oo[UZoojiJ/02?ojiJ/00ol0003omO6WooGa
Y`04ooGaY`03o`000?oIli[ofO>J00;ofO>J0_l0000`ooooo`03o`000?oooooooooo017ooooo000g
ooooo`;o0000G_ooool00ol0003o00nOo`0?W`02o`0000KoFVc;00?o0000ohj8b?n>R<P02?n>R<P0
0ol0003o[IS1ojfH`@0:ojfH`@03o`000?o1X[[o000000ooc;2n00?o0000omVe]OoI]KD02OoI]KD0
0ol0003ohl:fon?2]P07on?2]P03o`000?oY`ZgojL:]00GojL:]00?o0000oo7=[?oacJ`02ooacJ`0
0ol0003ommR/ooOH[004ooOH[003o`000?ogf:commR/00;ommR/00?o0000oo[UZoojiJ/01oojiJ/0
0ol0003omO6WooGaY`05ooGaY`04o`000?oIli[ofO>JomWcVP;o0000<Oooool00ol0003ooooooooo
o`0Aooooo`00=_ooool00ol0003oooooo`00001Oooooo`04o`000?l03ioo00nOo`0000OoFVc;00?o
0000ohj8b?n>R<P02?n>R<P00ol0003o[IS1ojfH`@09ojfH`@;o00004Oo</;h00ol0003ofKFeomVe
]@07omVe]@03o`000?oS`[Kohl:f00Wohl:f00?o0000onW2[OoY`Zd00ooY`Zd00ol0003olLf/oo7=
[00;oo7=[003o`000?ogf:commR/00KommR/00Co0000ooOH[?ogf:co00002_ojiJ/00ol0003omO6W
ooGaY`04ooGaY`03o`000?oIli[ofO>J00;ofO>J00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`0Aooooo`00>Oooool00ol0003oooooooooo`1Mooooo`03o`000?l03ioo00nO00;o00001OmJ
K</00ol0003oSXS8ohj8b008ohj8b003o`000?n]V<7o[IS100So[IS100?o0000okFWbol000004Oo<
/;h00ol0003ofKFeomVe]@06omVe]@03o`000?oS`[Kohl:f00_ohl:f00?o0000onW2[OoY`Zd00_oY
`Zd00ol0003olLf/oo7=[00;oo7=[003o`000?ogf:commR/00OommR/00?o0000ooOH[?l000002Ooj
iJ/00ol0003omO6WooGaY`04ooGaY`03o`000?oIli[ofO>J00;ofO>J00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0Aooooo`00>_ooool00ol0003oooooooooo`1Looooo`05o`000?l03ioo
00nOo`000?laH]<00_l00004oeY/b`03o`000?n>R<SoSXS800SoSXS800?o0000ojfH`On]V<401On]
V<42o`0000?o]JO;00?o0000olb`__o</;h03oo</;h00ol0003ofKFeomVe]@05omVe]@03o`000?oS
`[Kohl:f00_ohl:f00Go0000onW2[OoY`ZgojL:]o`00000>oo7=[003o`000?ogf:commR/00SommR/
0_l00009oo[UZ`03o`000?oelJOomO6W00ComO6W00Go0000omWcV_oIli[ofO>Jo`00000dooooo`03
o`000?oooooooooo017ooooo000kooooo`03o`000?oooooooooo05cooooo00Co0000o`0?Wol03ioo
00000_laH]<01Ol0003oFVc;oeY/bomJK<_o000000[oSXS800?o0000ojfH`On]V<401?n]V<400ol0
003o]JO;okFWb`03okFWb`03o`000?o</;koc;2n00ooc;2n00?o0000omVe]OoI]KD01?oI]KD00ol0
003ohl:fon?2]P0=on?2]P04o`000?oY`ZgojL:]o`0000golLf/00?o0000ooOH[?ogf:`02Oogf:`2
o`0000Son^F[00?o0000ooGaYooelJL01?oelJL01Ol0003ofO>JomWcV_oIli[o000003Kooooo00?o
0000ooooooooool04?ooool003cooooo00?o0000ooooooooool0G?ooool00ol0003o00nOo`000003
oc5Rd`;o00000_mJK</00ol0003oSXS8ohj8b008ohj8b003o`000?n]V<7o[IS100;o[IS100?o0000
okFWboneYl/01OneYl/00ol0003oc;2nolb`_P0?olb`_P03o`000?oI]KGofKFe00?ofKFe00?o0000
on?2]_oS`[H03_oS`[H00ol0003ojL:]o`00000=oo7=[003o`000?ogf:commR/00WommR/00?o0000
oo[UZol000001oojiJ/00ol0003omO6WooGaY`04ooGaY`04o`000?oIli[ofO>Jo`0003Oooooo00?o
0000ooooooooool04?ooool003gooooo0_l0001Looooo`04o`000?l03ioo00nOo`0000Co<F;C0ol0
000:ohj8b003o`000?n]V<7o[IS100;o00002?neYl/00ol0003oc;2nolb`_P0?olb`_P03o`000?oI
]KGofKFe00;ofKFe00?o0000on?2]_oS`[H04?oS`[H2o`0000golLf/00?o0000ooOH[?ogf:`02?og
f:`01Ol0003on^F[oo[UZoojiJ_o000000Gon^F[00?o0000ooGaYooelJL01?oelJL01?l0003ofO>J
omWcV_l0000hooooo`03o`000?oooooooooo013ooooo000oooooo`03o`000?oooooooooo05[ooooo
00Co0000o`0?Wol03ioo00001OlaH]<00ol0003oSXS8ohj8b008ohj8b003o`000?n]V<7o000000_o
]JO;00?o0000olb`__o</;h03oo</;h01Ol0003ofKFeomVe]OoI]KGo000001;ohl:f00?o0000ongB
^?l000002ooacJ`00ol0003ommR/ooOH[009ooOH[005o`000?ojiJ_on^F[oo[UZol000001OojiJ/0
0ol0003omO6WooGaY`04ooGaY`03o`000?oIli[o000003Wooooo00?o0000ooooooooool04?ooool0
043ooooo00?o0000ooooooooool0FOooool01?l0003o00nOo`0?Wol00006oc5Rd`co00003?neYl/0
0ol0003oc;2nolb`_P0@olb`_P03o`000?oI]KGo000001;ohl:f00Go0000ongB^?o]d[SokM:ho`00
000:oo7=[003o`000?ogf:commR/00SommR/00?o0000oo[UZoojiJ/00oojiJ/01Ol0003on^F[oo[U
ZoojiJ_o000000KomO6W00?o0000omWcV_l00000>_ooool00ol0003oooooooooo`0@ooooo`00@Ooo
ool2o`0005[ooooo00Co0000o`0?Wol03ioo00001OlaH]<00ol0003oR9;GohRBe`08ohRBe`03o`00
0?neYl_o]JO;00_o]JO;00?o0000olb`__o</;h03oo</;h00ol0003ofKFeo`00000Bon?2]P03o`00
0?o]d[SokM:h00;okM:h00?o0000oo7=[?oacJ`01_oacJ`00ol0003ommR/ooOH[009ooOH[003o`00
0?ojiJ_on^F[00Con^F[00?o0000oo[UZol000001ooelJL2o`0003_ooooo00?o0000ooooooooool0
4?ooool0043ooooo00?o0000ooooool00000Foooool00ol0003o00nOo`000006oc5Rd`03o`000?n8
T]OoR9;G00SoR9;G00?o0000okFWboneYl/02_neYl/00ol0003oc;2nolb`_P0@olb`_P03o`000?oS
`[Kohl:f013ohl:f00?o0000ongB^?o]d[P01?o]d[P2o`0000KolLf/00?o0000ooOH[?ogf:`02Oog
f:`00ol0003on^F[oo[UZ`05oo[UZ`;o00001_oelJL2o`0003cooooo00?o0000ooooooooool04?oo
ool004?ooooo00?o0000ooooooooool0F?ooool01?l0003o00nOo`0?Wol00005oc5Rd`03o`000?n8
T]OoR9;G00SoR9;G00?o0000okFWboneYl/02oneYl/00ol0003oc;2nolb`_P0?olb`_P03o`000?oS
`[Kohl:f013ohl:f00?o0000ongB^?o]d[P01_o]d[P00ol0003olLf/oo7=[003oo7=[003o`000?og
f:commR/00SommR/00?o0000oo[UZoojiJ/01_ojiJ/2o`0000GomO6W0_l0000mooooo`03o`000?oo
oooooooo013ooooo0014ooooo`03o`000?oooooooooo05Sooooo00?o0000o`0?Wol000001_laH]<0
0ol0003oR9;GohRBe`08ohRBe`03o`000?neYl_o]JO;00[o]JO;00?o0000olb`__o</;h03_o</;h0
0ol0003oel;4o`00000@on?2]P03o`000?o]d[SokM:h00SokM:h00Go0000oo7=[?oacJcolLf/o`00
000;ooOH[003o`000?ojiJ_on^F[00Kon^F[00?o0000ooGaYol000001?oelJL00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo013ooooo0015ooooo`03o`000?oooooooooo05Sooooo00?o0000
o`0?Wol000001OlaH]<00ol0003oR9;GohRBe`08ohRBe`03o`000?neYl_o]JO;00_o]JO;00?o0000
olb`__o</;h03?o</;h01Ol0003oel;4omO2a?oG`/Co000000oohl:f00?o0000ongB^?o]d[P02Oo]
d[P01?l0003olLf/oo7=[?l0000:ooOH[003o`000?ojiJ_on^F[00Kon^F[00Ko0000ooGaYooelJOo
mO6Wo`000?oelJL2o`0003oooooo00?o0000ooooooooool04?ooool004Kooooo0_l0001Iooooo`03
o`000?l03ioo000000Go<F;C00?o0000ohRBeon8T]L02?n8T]L00ol0003o]JO;okFWb`0;okFWb`03
o`000?o</;koc;2n00[oc;2n00?o0000omO2a?oG`/@00ooG`/@00ol0003ohl:fon?2]P0;on?2]P03
o`000?o]d[SokM:h00_okM:h00?o0000oo7=[?l000002_ogf:`00ol0003on^F[oo[UZ`06oo[UZ`04
o`000?oelJOomO6WooGaY`;o000000?of_JPo`000?ooool0?_ooool00ol0003oooooooooo`0@oooo
o`00B?ooool00ol0003oooooooooo`1Fooooo`03o`000?l03ioo000000Ko<F;C00?o0000ohRBeon8
T]L01on8T]L00ol0003o]JO;okFWb`0;okFWb`03o`000?o</;koc;2n00Woc;2n00?o0000omO2a?oG
`/@01?oG`/@00ol0003ohl:fon?2]P0;on?2]P03o`000?o]d[SokM:h00cokM:h0ol00008ooOH[003
o`000?ojiJ_on^F[00Kon^F[00?o0000ooGaYol000000_l000000ooJmZ3o0000o`000011ooooo`03
o`000?oooooooooo00oooooo0019ooooo`03o`000?oooooooooo05Kooooo00?o0000o`0?Wol00000
1OlaH]<00ol0003oR9;GohRBe`08ohRBe`03o`000?neYl_o]JO;00_o]JO;00?o0000olb`__o</;h0
2?o</;h00ol0003oel;4omO2a005omO2a003o`000?oS`[Kohl:f00Wohl:f00?o0000ongB^?o]d[P0
3Oo]d[P00ol0003om>>hooCS^003o`0000GommR/00?o0000oo[UZoojiJ/01_ojiJ/2o`0000Cof_JP
0_l00011ooooo`03o`000?oooooooooo00oooooo001:ooooo`03o`000?oooooooooo05Kooooo0_l0
0006oc5Rd`03o`000?n8T]OoR9;G00OoR9;G00?o0000okFWboneYl/02oneYl/00ol0003oc;2nolb`
_P07olb`_P03o`000?oG`/Coel;400Ooel;400?o0000on?2]_oS`[H01ooS`[H00ol0003okM:hongB
^00=ongB^003o`000?odhkSom>>h00Com>>h0ol00002ooOH[004o`000?ojiJ_on^F[oo[UZ`Go0000
1OoJmZ001?l0003oooooooooool00010ooooo`03o`000?oooooooooo00oooooo001:ooooo`;o0000
F?ooool2o`0000Go<F;C00?o0000ohRBeon8T]L02?n8T]L00ol0003o]JO;okFWb`0;okFWb`03o`00
0?o</;koc;2n00Goc;2n00?o0000omO2a?oG`/@02OoG`/@00ol0003ohl:fon?2]P06on?2]P03o`00
0?o]d[SokM:h00gokM:h00?o0000ooCS^?odhkP01oodhkP6o`0000Colo>d00?o0000om[fX?oJmZ00
0ooJmZ001Ol0003ooooooooooooooooo000003oooooo00?o0000ooooooooool03oooool004cooooo
00?o0000ooooooooool0EOooool2o`0000Ko<F;C00?o0000ohRBeon8T]L01on8T]L00ol0003o]JO;
okFWb`0;okFWb`03o`000?o</;koc;2n00Coc;2n00?o0000omO2a?oG`/@02_oG`/@00ol0003ohl:f
on?2]P05on?2]P03o`000?o]d[SokM:h00gokM:h00?o0000ooCS^?odhkP02OodhkP00ol0003olo>d
oo?c]005oo?c]003o`000?oJmZ3of_JP00?of_JP00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo00oooooo001=ooooo`03o`000?oooooooooo05Gooooo0_l0
0005oc5Rd`03o`000?n8T]OoR9;G00SoR9;G00?o0000okFWboneYl/02oneYl/00ol0003oc;2nolb`
_P03olb`_P03o`000?oG`/Coel;400_oel;400?o0000on?2]_oS`[H01?oS`[H00ol0003okM:hongB
^00=ongB^003o`000?odhkSom>>h00Som>>h00?o0000oo?c]?oclk@01Ooclk@00ol0003of_JPom[f
X003om[fX003o`000?oooooooooo00Gooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0?ooooo`00C_ooool00ol0003oooooooooo`1Eooooo`;o00001OlaH]<00ol0003oR9;GohRBe`07
ohRBe`03o`000?neYl_o]JO;00_o]JO;00?o0000olb`__o</;h00_o</;h00ol0003oel;4omO2a00=
omO2a003o`000?oS`[Kohl:f00;ohl:f00?o0000ongB^?o]d[P03Oo]d[P00ol0003om>>hooCS^009
ooCS^003o`000?oclkColo>d00Golo>d00?o0000om[fX?oJmZ000_oJmZ000ol0003oooooooooo`07
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool03oooool004oooooo0_l0001Eoooo
o`;o00001OlaH]<00ol0003oR9;GohRBe`08ohRBe`03o`000?neYl_o]JO;00_o]JO;00Co0000olb`
__o</;ko00004?oG`/@00ol0003ohl:fon?2]P02on?2]P03o`000?o]d[SokM:h00gokM:h00?o0000
ooCS^?odhkP02?odhkP00ol0003olo>doo?c]005oo?c]003o`000?oJmZ3of_JP00?of_JP00?o0000
ooooooooool01oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00oooooo001Aoooo
o`03o`000?oooooooooo05?ooooo0ol00004oc5Rd`03o`000?n8T]OoR9;G00OoR9;G00?o0000okFW
boneYl/02oneYl/00ol0003oc;2no`00000BomO2a004o`000?oS`[Kohl:fo`0000ookM:h00?o0000
ooCS^?odhkP02?odhkP00ol0003olo>doo?c]006oo?c]003o`000?oJmZ3of_JP00;of_JP00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00oooooo001Boooo
o`03o`000?oooooooooo05?ooooo00?o0000o`1=bol000000olaH]<00ol0003oR9;GohRBe`08ohRB
e`03o`000?neYl_o]JO;00[o]JO;0_l0000DomO2a003o`000?oS`[Ko000000ookM:h00?o0000ooCS
^?odhkP02?odhkP00ol0003olo>doo?c]005oo?c]003o`000?oJmZ3of_JP00;of_JP00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00oooooo001Cooooo`03
o`000?oooooooooo05?ooooo00Co0000o`1=bol0003o00000_laH]<00ol0003oR9;GohRBe`07ohRB
e`03o`000?neYl_o]JO;00So]JO;0_l000000onn_MWo0000omO2a00DomO2a0;o00003_o]d[P00ol0
003om>>hooCS^008ooCS^003o`000?oclkColo>d00Golo>d00Co0000om[fX?oJmZ3of_JP0_l0000?
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03oooool005Cooooo0ol0001Boooo
o`;o00000_l0CL/01?l0003o<F;Coc5Rdol00009ohRBe`03o`000?neYl_o]JO;00Go]JO;0_l00004
okjmf@03o`000?oG`/Coel;401;oel;400?o0000on?Hbol000003?o]d[P00ol0003om>>hooCS^009
ooCS^003o`000?oclkColo>d00Golo>d00Co0000om[fX?oJmZ3o00004_ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00oooooo001Dooooo`;o0000E?ooool2o`0000;o04g;00?o0000
oc5Rdol000002On8T]L00ol0003o]JO;okFWb`04okFWb`03o`000?nn_MWo_[gI00Go_[gI00?o0000
omO2a?oG`/@04?oG`/@01Ol0003ohmS;on?HbooSf<_o000000_okM:h00?o0000ooCS^?odhkP02?od
hkP00ol0003olo>doo?c]005oo?c]004o`000?oJmZ3of_JPo`0001Cooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0>ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd02?ooool00ol0003oooooooooo`1Booooo`04
o`000?l0CL_o04g;o`1=b`?o00002On8T]L01?l0003o]JO;okFWboneYl/2o`0000Wo_[gI00?o0000
omO2a?oG`/@03_oG`/@00ol0003ohmS;on?Hb`03on?Hb`03o`000?o]d[SokM:h00OokM:h00?o0000
ooCS^?odhkP02OodhkP00ol0003olo>doo?c]005oo?c]0?o00005_ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo00kooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool02?ooool00ol0003oooooooooo`1Booooo`03o`000?l0CL_o
04g;00;o04g;00?o0000ohRBeon8T]L01on8T]L01?l0003o]JO;o`000?l0000;okjmf@03o`000?oG
`/Coel;400goel;400?o0000on?HbooSf</01OoSf</2o`0000OokM:h00?o0000ooCS^?odhkP02?od
hkP00ol0003olo>doo?c]005oo?c]0?o00006?ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo00kooooo000hooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`08ooooo`;o0000D_ooool2o`0000Co04g;2ol0000>okjmf@03o`000?oG`/Coel;400_oel;400?o
0000on?HbooSf</02?oSf</00ol0003okM:hongB^003ongB^003o`000?odhkSom>>h00Wom>>h00?o
0000oo?c]?oclk@01?oclk@3o`0001Wooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0>ooooo`00>?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool02ooo
ool00ol0003oooooooooo`1@ooooo`;o00000ol0CL/00ol0003oO:?/ogbSk007ogbSk003o`000?nn
_MWo_[gI00go_[gI00?o0000omO2a?oG`/@02_oG`/@00ol0003ohmS;on?Hb`09on?Hb`03o`000?o]
d[SokM:h00;okM:h00?o0000ooCS^?odhkP02?odhkP00ol0003olo>doo?c]005oo?c]0;o00006ooo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00kooooo000hooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00gooooo00?o0000ooooooooool0
D?ooool00ol0003o04g;o`1=b`02o`1=b`03o`000?mlXncoO:?/00OoO:?/00?o0000okjmfOnn_MT0
3Onn_MT00ol0003oel;4omO2a008omO2a003o`000?oSf<_ohmS;00_ohmS;00Co0000ongB^?o]d[So
00002_odhkP00ol0003olo>doo?c]004oo?c]0?o00007Oooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo00kooooo000hooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo053ooooo00?o0000o`1=bol0CL/00_l0CL/00ol0003o
O:?/ogbSk007ogbSk003o`000?nn_MWo_[gI00co_[gI00?o0000omO2a?oG`/@01ooG`/@00ol0003o
hmS;on?Hb`0=on?Hb`03o`000?o]d[So000000[om>>h00Co0000oo?c]?oclkColo>d0ol000000ooF
o[go0000ooooo`0Nooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03_ooool003So
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0D?ooool00ol0003o04g;o`1=b`02o`1=b`03o`000?mlXncoO:?/00OoO:?/00?o0000okjm
fOnn_MT03?nn_MT00ol0003oel;4omO2a005omO2a003o`000?oSf<_ohmS;00oohmS;1?l00007ooCS
^003o`000?oclkColo>d00;o00000ooFo[d00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool03_ooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00004?ooool2o`00057ooooo00?o0000o`1=bol0CL/00_l0CL/00ol0003oO:?/ogbSk008ogbS
k003o`000?nn_MWo_[gI00co_[gI00?o0000omO2a?oG`/@01?oG`/@00ol0003ohmS;on?Hb`0?on?H
b`04o`000?oYl/kojO;>onWbcPGo00000_odhkP3o`0000Coe_jm00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00kooooo001Oooooo`03o`000?oooooooooo
04oooooo00?o0000o`1=bol0CL/00_l0CL/00ol0003oO:?/ogbSk007ogbSk003o`000?nn_MWo_[gI
00co_[gI00?o0000omO2a?oG`/@00ooG`/@00ol0003ohmS;on?Hb`0?on?Hb`03o`000?oYl/kojO;>
00OojO;>0_l00006omKn_@03o`000?oooooooooo02?ooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0>ooooo`00H?ooool00ol0003oooooooooo`1?ooooo`03o`000?l0CL_o04g;00;o
04g;00?o0000ogbSk?mlXn`01omlXn`00ol0003o_[gIokjmf@0<okjmf@05o`000?oG`/Coel;4omO2
a?l000004OoSf</00ol0003ojO;>onWbcP09onWbcP03o`000?oFo[goe_jm00?oe_jm00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00kooooo001Qooooo`;o
0000D?ooool2o`0000?o04g;00?o0000ogbSk?mlXn`01omlXn`00ol0003o_[gIokjmf@0<okjmf@03
o`000?oG`/Co0000017ohmS;00?o0000onWbc_oYl/h02OoYl/h00ol0003oe_jmomKn_@03omKn_@03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0=ooooo`00
Hoooool00ol0003oooooooooo`1?ooooo`04o`000?l0CL_o04g;o`0000[oO:?/00?o0000okjmfOnn
_MT02onn_MT3o`00013ohmS;00?o0000onWbc_oYl/h02OoYl/h00ol0003oe_jmomKn_@03omKn_@03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0=ooooo`00
I?ooool00ol0003oooooooooo`1?ooooo`;o000000?o04g;o`000?mlXn`02OmlXn`00ol0003o_[gI
okjmf@08okjmf@;o00000oo5g>X00ol0003ohmS;on?Hb`0<on?Hb`03o`000?oYl/kojO;>00WojO;>
00?o0000omKn_OoFo[d00ooFo[d00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool03Oooool006Gooooo00?o0000ooooooooool0D?ooool00ol0003o04g;o`00
0009ogbSk003o`000?nn_MWo_[gI00Oo_[gI00?o0000olGLj_o5g>X01?o5g>X00ol0003ohmS;on?H
b`0:on?Hb`03o`000?oYl/kojO;>00WojO;>00?o0000omKn_OoFo[d00ooFo[d00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03Oooool006Kooooo00?o0000
ooooooooool0D?ooool2o`0000[oO:?/00?o0000okjmfOnn_MT01?nn_MT2o`0000SoaMcZ0_l0000:
on?Hb`03o`000?oYl/kojO;>00SojO;>00?o0000omKn_OoFo[d00ooFo[d00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool03Oooool006Kooooo0ol0001Aoooo
o`;o00002_mlXn`01?l0003o_[gIokjmfOnn_MT2o`0000coaMcZ00?o0000on?HbooSf</01_oSf</0
0ol0003ojO;>onWbcP09onWbcP04o`000?oFo[goe_jmomKn_@;o0000<_ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo00gooooo001Xooooo`03o`000?oooooooooo057ooooo00?o0000
ogbSk?mlXn`02?mlXn`00ol0003o_[gIo`00000?olGLjP;o00001OoSf</00ol0003ojO;>onWbcP09
onWbcP03o`000?oFo[goe_jm00;o0000=Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00gooooo001Yooooo`03o`000?oooooooooo057ooooo3Ol0000AolGLjP05o`000?oSf<_ohmS;
on?Hbol000002ooYl/h01?l0003oe_jmo`000?l0000hooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool03Oooool006[ooooo0_l0001Cooooo`03o`000?mG]?_oEkCk00SoEkCk00?o0000
olGLj_o5g>X03oo5g>X00ol0003ohmS;o`00000;onWbcP?o0000>_ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo00gooooo001/ooooo`03o`000?oooooooooo057ooooo0_l00009oeNd
n`03o`000?o5g>[oaMcZ00koaMcZ2?l00005onWbcP;o0000?Oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo00gooooo001]ooooo`03o`000?oooooooooo05;ooooo00?o0000oeNdnomG
]?/01omG]?/2o`0000coaMcZ0_l00008okOik@Go0000@?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00gooooo001^ooooo`03o`000?oooooooooo05;ooooo0_l00009oeNdn`03o`00
0?o5g>[oaMcZ00SoaMcZ00?o0000okOikOngnNd02OngnNd2o`0004?ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0<ooooo`00Koooool00ol0003oooooooooo`1Cooooo`03o`000?mG
]?_oEkCk00OoEkCk0_l00006olGLjP;o00002ongnNd00ol0003oooooooooo`14ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool03?ooool006oooooo0ol0001Dooooo`;o00002OmG]?/0
1?l0003oaMcZolGLj_o5g>X2o`0000_o]oW]0_l00018ooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool03?ooool0077ooooo00?o0000ooooooooool0E?ooool00ol0003oEkCkoeNdn`07
oeNdn`03o`000?o5g>[o000000_o]oW]0_l0001;ooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool03?ooool007;ooooo00?o0000ooooooooool0E?oooolAo`0000Go]oW]00?o0000oooo
ooooool0Boooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00cooooo001cooooo`;o
0000F?ooool00ol0003oooooooooo`0?o`0004oooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0<ooooo`00MOooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo05oooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0<ooooo`00M_ooool00ol0003ooooooooo
o`1Dooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0<ooooo`00Moooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0<ooooo`00N?ooool2o`0005?ooooo00?o0000oooo
ooooool0H_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00cooooo001hooooo`;o
0000Doooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool03?ooool007[ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1Tooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool03?ooool007_ooooo00?o0000ooooooooool0Cooo
ool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02ooo
ool007cooooo0_l0001?ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0;ooooo`00O_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
06Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0;ooooo`00Ooooool00ol0003o
ooooooooo`1;ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0;ooooo`00P?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo06Sooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0;ooooo`00POooool3o`0004Wooooo00?o
0000ooooooooool0JOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00_ooooo001f
ooooo`Co000000?o410@ooooooooool01Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo06[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`00N?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0Joooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo001hooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool02oooool007Sooooo00?o0000ooooooooool02_ooool2o`0004Kooooo
00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo
001Looooo`?o000000?o410@ooooooooool05_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo04?ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00_ooooo001Nooooo`03oa0@4?nj^[[ooooo01Oooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`12ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0:ooooo`00G_ooool00onHV9So<S8booooo`0Gooooo`03o`000?oooooooooo
00kooooo0_l00012ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0:ooooo`00G_ooool00ooMgMgo0000okZj^P0Eooooo`03oeEEEOmVIVKo0000013o
oooo0_l00012ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0:ooooo`00G_ooool00omEEEGoMgMgodA4A00Zooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00[ooooo
001Mooooo`05omgMgOl@413oooooob4Q8OoMgMd0:_ooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`00GOoo
ool01OmVIVKoQhN7oooooonHV9SoEEEE02_ooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool005cooooo00?o
k^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`0Zooooo`;o0000?Oooool00ol0003ooooooooo
o`1cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool005cooooo00Co410@
o`000?l0003ooooo0_l000000ol@413oooooooooo`0[ooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool0M?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo002A
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00[ooooo002Aooooo`;o0000>_ooool00ol0003oooooooooo`1foooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool009?ooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02_ooool009Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1hooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool009Gooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool009Kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool009Oooooo0_l0000dooooo`03o`000?oooooooooo
07[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`00VOooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`09ooooo`00VOooool3o`00037ooooo00?o0000ooooooooool0O?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Wooooo002Kooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0OOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo002L
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Wooooo002Mooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0Ooooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo002Nooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Wooooo002Oooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
P?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo002Pooooo`;o0000:ooo
ool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?oo
ool00:7ooooo0_l0000Zooooo`03o`000?oooooooooo08;ooooo00Go0000ooooooooooooooooo`00
000:ooooo`00Xoooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo08?ooooo00Co0000
oooooooooooo00002_ooool00:Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`24
ooooo`03o`000?oooooo000000[ooooo002Uooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0QOooool2o`0000[ooooo002Vooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0Q?ooool3o`0000[ooooo002Wooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
P?ooool4o`0000gooooo002Xooooo`04o`000?oooooo0000o`00027ooooo00?o0000ooooooooool0
O?ooool4o`00017ooooo002>ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@06ooooo`;o00008_ooool00ol0003oooooooooo`1hooooo`Co0000
5Oooool0093ooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo07Cooooo1?l0000Iooooo`00T?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`1`ooooo`Co00007Oooool0093ooooo00?o0000ooooooooool03_ooool00omg
MgOo<S8booooo`09ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0KOooool3o`00
027ooooo002@ooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00;oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0JOooool4o`0002Cooooo002@ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo06Gooooo1?l0000Xooooo`00T?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00oooooo0ol0000Jooooo`03o`000?oooooooooo067ooooo1?l0000/ooooo`00S_oo
ool00omEEEGoIVIVo`00000=ooooo`Co00003_ooool2o`0001_ooooo00?o0000ooooooooool0GOoo
ool4o`00033ooooo002booooo`;o00006Oooool00ol0003oooooooooo`1Iooooo`Co0000=?ooool0
0;Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Eooooo`Co0000>?ooool00;Go
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Aooooo`Co0000??ooool00;Kooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`1=ooooo`Co0000@?ooool00;Oooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`19ooooo`Co0000A?ooool00;Sooooo0_l0000C
ooooo`03o`000?oooooooooo04Gooooo1?l00018ooooo`00^Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo047ooooo1?l0001<ooooo`00^_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo03kooooo0ol0001@ooooo`00^oooool2o`00013ooooo00?o0000ooooooooool0
>_ooool4o`0005?ooooo002mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0=_oo
ool4o`0005Oooooo002nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0<_ooool4
o`0005_ooooo002oooooo`;o00003?ooool00ol0003oooooooooo`0^ooooo`Co0000Goooool00;oo
oooo0_l0000<ooooo`03o`000?oooooooooo02[ooooo1?l0001Sooooo`00`Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo02Kooooo1?l0001Wooooo`00`_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo02;ooooo1?l0001[ooooo`00`oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01kooooo1?l0001_ooooo`00a?ooool2o`0000Oooooo00?o0000oooo
ooooool06_ooool4o`0007?ooooo0036ooooo`?o00001?ooool00ol0003oooooooooo`0Fooooo`Co
0000Moooool00<Kooooo0_l00005ooooo`03o`000?oooooooooo01?ooooo0ol0001kooooo`00b?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo1?l0001nooooo`00bOooool0
1Ol0003ooooooooooooooooo000000gooooo1?l00022ooooo`00b_ooool01?l0003oooooooooool0
0009ooooo`Co0000Q_ooool00<_ooooo00?o0000ooooool000001Oooool4o`0008[ooooo003<oooo
o`Oo0000S_ooool00<;ooooo1Ol00006ooooo`;o0000T_ooool00<;ooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A02Jooooo`00`oooool00onHV9So8B4Qonk^kP2Kooooo`00a?ooool00onHV9So8B4Qonk^
kP2Jooooo`00aOooool00omgMgOoIVIVooooo`2Iooooo`00a_ooool00ol0003oooooooooo`2Hoooo
o`00`_ooool01Ol0003o^[ZjoooooonHV9So410@09[ooooo0032ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0V_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool0
0?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool0
0?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00:gooooo0ol00000
0ol@413oooooooooo`2^ooooo`00V_ooool2o`0000_ooooo00?o0000okZj^_ooool01Oooool00ol@
413o^[Zjooooo`04ooooo`03o`000?nj^[[ooooo00cooooo0_l00006ooooo`03o`000?nj^[[ooooo
097ooooo002Jooooo`03o`000?oooooooooo00[ooooo0_lb<S86ooooo`03oiRHV?lb<S;ooooo00Co
oooo0_lb<S8>ooooo`03o`000?oooooooooo00Cooooo0_lb<S:Booooo`00T?ooool01Ol@413o0000
o`000?l0003o410@00Gooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l00002ooooo`03
ohN7Qol0003o^[Zj00Gooooo00?ogMgMo`000?nj^[X01?ooool00on7QhOo0000okZj^P05ooooo`05
oiRHV?l0003o0000odA4A?nj^[X00oooool00ol0003oooooooooo`04ooooo`03ohN7Qol0003o^[Zj
00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N_oo
ool009;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`06onk^k_lQ8B7o
QhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@4005ooooo`03oeEEEOmgMgOoA4A400Cooooo
00?oc<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000oooooooo
ool01?ooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool6o`00
0006oooooomgMgOoV9RHoooooonHV9SoMgMgN_ooool009;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`04omgMgOl0003o410@olc<c0[ooooo00GogMgMoa0@4?oooooo8B4Q
omgMg@0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`05oa0@4?ooooooooooooooool@4100N_ooool009;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo00GoIVIVohN7Qooo
ooooV9RHoeEEE@0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`04ooooo`Ko000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`1hoooo
o`00T_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Co8B4QogMgMomg
MgOo<S8b2Oooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo00Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go0000oooo
ooooooooooooo`00001jooooo`00Soooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l00008ooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool01_ooool00ol@413o0000o`000003o`0000Cooooo00?o
0000ooooooooool02Oooool00ol@413o0000o`000003o`0000[ooooo00Go410@oooooooooooooooo
oa0@401jooooo`00Soooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool01OmgMgOoV9RHoooooonHV9SoMgMg07[ooooo002?ooooo`Oo0000
1?ooool2o`0002;ooooo00?o0000ooooooooool01?ooool2o`0000gooooo00?o0000ooooooooool0
2oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07[ooooo003oooooof;ooooo003oooooof;ooooo003o
ooooof;ooooo0000\
\>"],
  ImageRangeCache->{{{0, 352.438}, {392.188, 0}} -> {-0.0365789, -0.0401404, \
0.00334761, 0.00334761}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11253 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.066106 1.21212 -1.11022e-16 1.21212 [
[.5 1.12503 -44 0 ]
[.5 1.12503 44 24.5 ]
[.03831 .17557 -5.85635 -9 ]
[.03831 .17557 .14365 0 ]
[.12814 .13981 -17.2021 -9 ]
[.12814 .13981 .79789 0 ]
[.22015 .10319 -16.8352 -9 ]
[.22015 .10319 1.16484 0 ]
[.31441 .06568 -16.4682 -9 ]
[.31441 .06568 1.53178 0 ]
[.411 .02725 -16.1013 -9 ]
[.411 .02725 1.89873 0 ]
[.51 -0.01213 -5.24477 -9 ]
[.51 -0.01213 .75523 0 ]
[.21792 .02683 -9.25094 -12 ]
[.21792 .02683 .74906 0 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[.1484 .76875 -18 -3.08128 ]
[.1484 .76875 0 5.91872 ]
[.29382 .89692 -6 -3.18183 ]
[.29382 .89692 0 5.81817 ]
[.42456 1.01215 -18 -3.26907 ]
[.42456 1.01215 0 5.73093 ]
[.54272 1.11629 -6 -3.34548 ]
[.54272 1.11629 0 5.65452 ]
[.22112 .91822 -10 -4.24244 ]
[.22112 .91822 0 7.75756 ]
[.03467 .19213 -6 -2.71522 ]
[.03467 .19213 0 6.28478 ]
[.02559 .27239 -18 -2.7611 ]
[.02559 .27239 0 6.2389 ]
[.01617 .35567 -18 -2.80881 ]
[.01617 .35567 0 6.19119 ]
[.00638 .44212 -18 -2.85847 ]
[.00638 .44212 0 6.14153 ]
[-0.00378 .53194 -18 -2.9102 ]
[-0.00378 .53194 0 6.0898 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 1.11253 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.12503 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
.04875 .18654 m
.0558 .18375 L
s
[(0)] .03467 .19213 1 -0.39662 Mshowa
.03972 .26693 m
.04679 .2642 L
s
[(0.2)] .02559 .27239 1 -0.38642 Mshowa
.03035 .35034 m
.03744 .34767 L
s
[(0.4)] .01617 .35567 1 -0.37582 Mshowa
.02062 .43693 m
.02774 .43433 L
s
[(0.6)] .00638 .44212 1 -0.36478 Mshowa
.01051 .52689 m
.01765 .52437 L
s
[(0.8)] -0.00378 .53194 1 -0.35329 Mshowa
0 .62042 m
.00717 .61797 L
s
[(1)] -0.01434 .62532 1 -0.3413 Mshowa
.125 Mabswid
.04653 .20636 m
.05076 .2047 L
s
.04428 .22637 m
.04851 .22471 L
s
.04201 .24656 m
.04625 .24491 L
s
.03741 .28749 m
.04165 .28587 L
s
.03508 .30825 m
.03933 .30663 L
s
.03272 .32919 m
.03698 .32759 L
s
.02795 .37168 m
.03221 .37009 L
s
.02553 .39322 m
.02979 .39164 L
s
.02309 .41497 m
.02735 .4134 L
s
.01813 .45909 m
.0224 .45755 L
s
.01561 .48147 m
.01989 .47994 L
s
.01307 .50407 m
.01736 .50255 L
s
.00792 .54993 m
.01221 .54843 L
s
.00531 .5732 m
.0096 .5717 L
s
.00267 .59669 m
.00696 .59521 L
s
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
.5561 .7194 m
.04875 .18654 L
s
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.5561 .7194 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
0 0 m
1 0 L
1 1.11253 L
0 1.11253 L
closepath
clip
newpath
.5 Mabswid
.397 .629 .947 r
.52593 .68772 .5561 .7194 .58394 .7109 .55406 .69242 Metetra
.245 .656 .962 r
.55406 .69242 .58394 .7109 .61197 .70234 .58254 .69648 Metetra
.01 .576 .791 r
.58254 .69648 .61197 .70234 .64019 .69372 .61135 .69927 Metetra
.174 0 0 r
.61135 .69927 .64019 .69372 .66861 .68504 .64047 .70017 Metetra
.25 0 0 r
.64047 .70017 .66861 .68504 .69723 .6763 .66984 .69864 Metetra
.259 0 0 r
.66984 .69864 .69723 .6763 .72605 .6675 .69943 .6943 Metetra
.228 0 0 r
.69943 .6943 .72605 .6675 .75507 .65863 .72917 .68687 Metetra
.158 0 0 r
.72917 .68687 .75507 .65863 .7843 .6497 .759 .67624 Metetra
.04 0 0 r
.759 .67624 .7843 .6497 .81374 .64071 .78887 .66249 Metetra
.78887 .66249 .81374 .64071 .84339 .63166 .81875 .64586 Metetra
.421 .83 .637 r
.81875 .64586 .84339 .63166 .87325 .62254 .84859 .62672 Metetra
.684 .98 .847 r
.84859 .62672 .87325 .62254 .90333 .61335 .8784 .60557 Metetra
.805 .961 .912 r
.8784 .60557 .90333 .61335 .93362 .6041 .90817 .58305 Metetra
.816 .867 .885 r
.90817 .58305 .93362 .6041 .96413 .59478 .93794 .55978 Metetra
0 .339 .811 r
.49498 .6552 .52593 .68772 .55406 .69242 .52323 .67264 Metetra
0 .248 .664 r
.52323 .67264 .55406 .69242 .58254 .69648 .552 .68902 Metetra
.439 0 0 r
.552 .68902 .58254 .69648 .61135 .69927 .58126 .70306 Metetra
.467 0 0 r
.58126 .70306 .61135 .69927 .64047 .70017 .61096 .71347 Metetra
.429 0 0 r
.61096 .71347 .64047 .70017 .66984 .69864 .64101 .71916 Metetra
.35 0 0 r
.64101 .71916 .66984 .69864 .69943 .6943 .67131 .71929 Metetra
.233 0 0 r
.67131 .71929 .69943 .6943 .72917 .68687 .70176 .71332 Metetra
.062 0 0 r
.70176 .71332 .72917 .68687 .759 .67624 .73222 .70095 Metetra
.73222 .70095 .759 .67624 .78887 .66249 .76259 .68241 Metetra
.469 .833 .578 r
.76259 .68241 .78887 .66249 .81875 .64586 .79278 .65818 Metetra
.732 .977 .741 r
.79278 .65818 .81875 .64586 .84859 .62672 .82273 .62904 Metetra
.871 .992 .815 r
.82273 .62904 .84859 .62672 .8784 .60557 .8524 .59609 Metetra
.903 .931 .822 r
.8524 .59609 .8784 .60557 .90817 .58305 .88182 .56058 Metetra
.887 .855 .804 r
.88182 .56058 .90817 .58305 .93794 .55978 .91103 .52381 Metetra
0 0 .503 r
.4632 .62183 .49498 .6552 .52323 .67264 .49143 .6509 Metetra
.617 .075 0 r
.49143 .6509 .52323 .67264 .552 .68902 .52032 .67863 Metetra
.65 .093 0 r
.52032 .67863 .552 .68902 .58126 .70306 .54987 .70314 Metetra
.619 .061 0 r
.54987 .70314 .58126 .70306 .61096 .71347 .58001 .7225 Metetra
.538 0 0 r
.58001 .7225 .61096 .71347 .64101 .71916 .61063 .73501 Metetra
.403 0 0 r
.61063 .73501 .64101 .71916 .67131 .71929 .64159 .73939 Metetra
.197 0 0 r
.64159 .73939 .67131 .71929 .70176 .71332 .6727 .73478 Metetra
.6727 .73478 .70176 .71332 .73222 .70095 .70381 .72074 Metetra
.456 .834 .599 r
.70381 .72074 .73222 .70095 .76259 .68241 .73473 .6976 Metetra
.739 .974 .721 r
.73473 .6976 .76259 .68241 .79278 .65818 .76533 .66613 Metetra
.887 .991 .765 r
.76533 .66613 .79278 .65818 .82273 .62904 .79551 .62756 Metetra
.936 .948 .768 r
.79551 .62756 .82273 .62904 .8524 .59609 .82523 .58354 Metetra
.937 .891 .758 r
.82523 .58354 .8524 .59609 .88182 .56058 .85449 .536 Metetra
.919 .836 .747 r
.85449 .536 .88182 .56058 .91103 .52381 .88337 .48685 Metetra
.703 .217 0 r
.43058 .58756 .4632 .62183 .49143 .6509 .45863 .6265 Metetra
.747 .24 0 r
.45863 .6265 .49143 .6509 .52032 .67863 .48751 .66396 Metetra
.743 .221 0 r
.48751 .66396 .52032 .67863 .54987 .70314 .51719 .69752 Metetra
.697 .158 0 r
.51719 .69752 .54987 .70314 .58001 .7225 .54763 .72466 Metetra
.6 .039 0 r
.54763 .72466 .58001 .7225 .61063 .73501 .57869 .74313 Metetra
.418 0 0 r
.57869 .74313 .61063 .73501 .64159 .73939 .61019 .75122 Metetra
.095 0 0 r
.61019 .75122 .64159 .73939 .6727 .73478 .64193 .74778 Metetra
.358 .81 .685 r
.64193 .74778 .6727 .73478 .70381 .72074 .67366 .73222 Metetra
.715 .982 .784 r
.67366 .73222 .70381 .72074 .73473 .6976 .70518 .70497 Metetra
.883 .992 .783 r
.70518 .70497 .73473 .6976 .76533 .66613 .73629 .6671 Metetra
.941 .949 .757 r
.73629 .6671 .76533 .66613 .79551 .62756 .76684 .62022 Metetra
.954 .9 .733 r
.76684 .62022 .79551 .62756 .82523 .58354 .79679 .56654 Metetra
.947 .856 .718 r
.79679 .56654 .82523 .58354 .85449 .536 .82613 .50859 Metetra
.932 .817 .71 r
.82613 .50859 .85449 .536 .88337 .48685 .85493 .44884 Metetra
.791 .322 0 r
.39706 .55236 .43058 .58756 .45863 .6265 .42486 .59885 Metetra
.802 .32 0 r
.42486 .59885 .45863 .6265 .48751 .66396 .45359 .6438 Metetra
.784 .285 0 r
.45359 .6438 .48751 .66396 .51719 .69752 .48327 .68438 Metetra
.733 .205 0 r
.48327 .68438 .51719 .69752 .54763 .72466 .51386 .71758 Metetra
.62 .053 0 r
.51386 .71758 .54763 .72466 .57869 .74313 .54523 .74071 Metetra
.375 0 0 r
.54523 .74071 .57869 .74313 .61019 .75122 .57717 .7517 Metetra
.102 .658 .759 r
.57717 .7517 .61019 .75122 .64193 .74778 .60945 .74912 Metetra
.61 .953 .905 r
.60945 .74912 .64193 .74778 .67366 .73222 .64179 .73227 Metetra
.846 .986 .86 r
.64179 .73227 .67366 .73222 .70518 .70497 .67392 .70169 Metetra
.925 .943 .791 r
.67392 .70169 .70518 .70497 .73629 .6671 .7056 .65866 Metetra
.948 .897 .742 r
.7056 .65866 .73629 .6671 .76684 .62022 .73667 .60516 Metetra
.952 .859 .712 r
.73667 .60516 .76684 .62022 .79679 .56654 .76703 .54385 Metetra
.947 .829 .695 r
.76703 .54385 .79679 .56654 .82613 .50859 .79668 .47774 Metetra
.936 .803 .687 r
.79668 .47774 .82613 .50859 .85493 .44884 .82567 .40974 Metetra
.827 .371 0 r
.36263 .5162 .39706 .55236 .42486 .59885 .39011 .56746 Metetra
.823 .356 0 r
.39011 .56746 .42486 .59885 .45359 .6438 .41863 .61719 Metetra
.796 .31 0 r
.41863 .61719 .45359 .6438 .48327 .68438 .44821 .66227 Metetra
.732 .213 0 r
.44821 .66227 .48327 .68438 .51386 .71758 .47884 .69936 Metetra
.583 .021 0 r
.47884 .69936 .51386 .71758 .54523 .74071 .51039 .72547 Metetra
0 .341 .686 r
.51039 .72547 .54523 .74071 .57717 .7517 .54266 .73827 Metetra
.338 .77 .97 r
.54266 .73827 .57717 .7517 .60945 .74912 .57539 .73616 Metetra
.728 .925 .957 r
.57539 .73616 .60945 .74912 .64179 .73227 .60827 .71836 Metetra
.87 .914 .857 r
.60827 .71836 .64179 .73227 .67392 .70169 .64101 .68545 Metetra
.919 .879 .78 r
.64101 .68545 .67392 .70169 .7056 .65866 .67332 .6389 Metetra
.937 .849 .731 r
.67332 .6389 .7056 .65866 .73667 .60516 .70501 .58092 Metetra
.942 .825 .7 r
.70501 .58092 .73667 .60516 .76703 .54385 .73595 .51449 Metetra
.941 .806 .683 r
.73595 .51449 .76703 .54385 .79668 .47774 .76612 .44295 Metetra
.936 .791 .675 r
.76612 .44295 .79668 .47774 .82567 .40974 .79557 .36951 Metetra
.837 .385 0 r
.32723 .47902 .36263 .5162 .39011 .56746 .35444 .53199 Metetra
.822 .36 0 r
.35444 .53199 .39011 .56746 .41863 .61719 .38273 .58345 Metetra
.781 .301 0 r
.38273 .58345 .41863 .61719 .44821 .66227 .41217 .63014 Metetra
.686 .179 0 r
.41217 .63014 .44821 .66227 .47884 .69936 .44276 .66862 Metetra
.463 0 0 r
.44276 .66862 .47884 .69936 .51039 .72547 .47439 .69575 Metetra
0 .444 .859 r
.47439 .69575 .51039 .72547 .54266 .73827 .50688 .7091 Metetra
.483 .743 .985 r
.50688 .7091 .54266 .73827 .57539 .73616 .53995 .70699 Metetra
.744 .829 .917 r
.53995 .70699 .57539 .73616 .60827 .71836 .5733 .6886 Metetra
.849 .832 .83 r
.5733 .6886 .60827 .71836 .64101 .68545 .6066 .65456 Metetra
.894 .819 .766 r
.6066 .65456 .64101 .68545 .67332 .6389 .63956 .60639 Metetra
.916 .806 .723 r
.63956 .60639 .67332 .6389 .70501 .58092 .67194 .54642 Metetra
.927 .795 .696 r
.67194 .54642 .70501 .58092 .73595 .51449 .70359 .47775 Metetra
.931 .787 .679 r
.70359 .47775 .73595 .51449 .76612 .44295 .73445 .40386 Metetra
.932 .781 .671 r
.73445 .40386 .76612 .44295 .79557 .36951 .76458 .32809 Metetra
.827 .371 0 r
.29083 .44079 .32723 .47902 .35444 .53199 .31786 .49222 Metetra
.797 .334 0 r
.31786 .49222 .35444 .53199 .38273 .58345 .34599 .54214 Metetra
.727 .254 0 r
.34599 .54214 .38273 .58345 .41217 .63014 .37531 .58737 Metetra
.57 .094 0 r
.37531 .58737 .41217 .63014 .44276 .66862 .40583 .62452 Metetra
0 .182 .698 r
.40583 .62452 .44276 .66862 .47439 .69575 .43749 .65055 Metetra
.199 .491 .901 r
.43749 .65055 .47439 .69575 .50688 .7091 .4701 .66308 Metetra
.544 .673 .922 r
.4701 .66308 .50688 .7091 .53995 .70699 .50342 .66046 Metetra
.726 .74 .863 r
.50342 .66046 .53995 .70699 .5733 .6886 .53714 .64191 Metetra
.815 .76 .802 r
.53714 .64191 .5733 .6886 .6066 .65456 .57093 .60803 Metetra
.863 .766 .754 r
.57093 .60803 .6066 .65456 .63956 .60639 .60449 .5603 Metetra
.89 .768 .72 r
.60449 .5603 .63956 .60639 .67194 .54642 .63757 .50102 Metetra
.908 .769 .697 r
.63757 .50102 .67194 .54642 .70359 .47775 .67 .4332 Metetra
.918 .771 .682 r
.67 .4332 .70359 .47775 .73445 .40386 .70169 .36025 Metetra
.925 .774 .675 r
.70169 .36025 .73445 .40386 .76458 .32809 .73265 .28543 Metetra
.791 .322 0 r
.25338 .40146 .29083 .44079 .31786 .49222 .28042 .44816 Metetra
.733 .266 0 r
.28042 .44816 .31786 .49222 .34599 .54214 .30852 .49335 Metetra
.608 .152 0 r
.30852 .49335 .34599 .54214 .37531 .58737 .3378 .53409 Metetra
0 .047 .597 r
.3378 .53409 .37531 .58737 .40583 .62452 .3683 .56729 Metetra
0 .3 .795 r
.3683 .56729 .40583 .62452 .43749 .65055 .39996 .59016 Metetra
.341 .503 .874 r
.39996 .59016 .43749 .65055 .4701 .66308 .43264 .60052 Metetra
.569 .617 .861 r
.43264 .60052 .4701 .66308 .50342 .66046 .4661 .59691 Metetra
.702 .673 .819 r
.4661 .59691 .50342 .66046 .53714 .64191 .50008 .57859 Metetra
.78 .702 .778 r
.50008 .57859 .53714 .64191 .57093 .60803 .53426 .54613 Metetra
.829 .72 .745 r
.53426 .54613 .57093 .60803 .60449 .5603 .56834 .50086 Metetra
.861 .733 .72 r
.56834 .50086 .60449 .5603 .63757 .50102 .60208 .44487 Metetra
.884 .745 .702 r
.60208 .44487 .63757 .50102 .67 .4332 .63528 .38091 Metetra
.901 .755 .691 r
.63528 .38091 .67 .4332 .70169 .36025 .66785 .31211 Metetra
.913 .767 .685 r
.66785 .31211 .70169 .36025 .73265 .28543 .69976 .24147 Metetra
.703 .217 0 r
.21484 .36098 .25338 .40146 .28042 .44816 .24214 .39996 Metetra
.59 .128 0 r
.24214 .39996 .28042 .44816 .30852 .49335 .27043 .43746 Metetra
0 .023 .579 r
.27043 .43746 .30852 .49335 .3378 .53409 .29983 .47096 Metetra
0 .217 .74 r
.29983 .47096 .3378 .53409 .3683 .56729 .33039 .4978 Metetra
.21 .39 .823 r
.33039 .4978 .3683 .56729 .39996 .59016 .36208 .51563 Metetra
.433 .506 .834 r
.36208 .51563 .39996 .59016 .43264 .60052 .39479 .52263 Metetra
.581 .578 .814 r
.39479 .52263 .43264 .60052 .4661 .59691 .42832 .51758 Metetra
.679 .624 .786 r
.42832 .51758 .4661 .59691 .50008 .57859 .46244 .49986 Metetra
.745 .655 .761 r
.46244 .49986 .50008 .57859 .53426 .54613 .49688 .46994 Metetra
.793 .68 .74 r
.49688 .46994 .53426 .54613 .56834 .50086 .53136 .42895 Metetra
.828 .701 .723 r
.53136 .42895 .56834 .50086 .60208 .44487 .56564 .37863 Metetra
.856 .72 .712 r
.56564 .37863 .60208 .44487 .63528 .38091 .59955 .32129 Metetra
.878 .74 .705 r
.59955 .32129 .63528 .38091 .66785 .31211 .63297 .25961 Metetra
.896 .76 .703 r
.63297 .25961 .66785 .31211 .69976 .24147 .66586 .19616 Metetra
0 0 .503 r
.17516 .3193 .21484 .36098 .24214 .39996 .20303 .34793 Metetra
0 .112 .65 r
.20303 .34793 .24214 .39996 .27043 .43746 .23177 .37518 Metetra
0 .248 .761 r
.23177 .37518 .27043 .43746 .29983 .47096 .2615 .39908 Metetra
.184 .366 .811 r
.2615 .39908 .29983 .47096 .33039 .4978 .29227 .41756 Metetra
.367 .452 .815 r
.29227 .41756 .33039 .4978 .36208 .51563 .32407 .42882 Metetra
.497 .51 .801 r
.32407 .42882 .36208 .51563 .39479 .52263 .35682 .43149 Metetra
.59 .553 .781 r
.35682 .43149 .39479 .52263 .42832 .51758 .39035 .42463 Metetra
.659 .587 .763 r
.39035 .42463 .42832 .51758 .46244 .49986 .42451 .4078 Metetra
.712 .616 .748 r
.42451 .4078 .46244 .49986 .49688 .46994 .45905 .38135 Metetra
.755 .643 .737 r
.45905 .38135 .49688 .46994 .53136 .42895 .49376 .34612 Metetra
.79 .669 .729 r
.49376 .34612 .53136 .42895 .56564 .37863 .52843 .30343 Metetra
.821 .695 .725 r
.52843 .30343 .56564 .37863 .59955 .32129 .56291 .25504 Metetra
.847 .722 .725 r
.56291 .25504 .59955 .32129 .63297 .25961 .59708 .20304 Metetra
.871 .752 .729 r
.59708 .20304 .63297 .25961 .66586 .19616 .63089 .14942 Metetra
0 .339 .811 r
.13429 .27638 .17516 .3193 .20303 .34793 .16308 .29252 Metetra
.115 .399 .851 r
.16308 .29252 .20303 .34793 .23177 .37518 .19259 .30754 Metetra
.273 .441 .846 r
.19259 .30754 .23177 .37518 .2615 .39908 .22291 .32006 Metetra
.392 .471 .822 r
.22291 .32006 .2615 .39908 .29227 .41756 .25407 .32872 Metetra
.48 .496 .797 r
.25407 .32872 .29227 .41756 .32407 .42882 .28609 .33232 Metetra
.546 .518 .775 r
.28609 .33232 .32407 .42882 .35682 .43149 .3189 .32998 Metetra
.598 .539 .759 r
.3189 .32998 .35682 .43149 .39035 .42463 .3524 .32108 Metetra
.642 .561 .747 r
.3524 .32108 .39035 .42463 .42451 .4078 .38648 .30534 Metetra
.68 .583 .74 r
.38648 .30534 .42451 .4078 .45905 .38135 .42098 .28298 Metetra
.714 .608 .737 r
.42098 .28298 .45905 .38135 .49376 .34612 .45573 .25456 Metetra
.745 .635 .738 r
.45573 .25456 .49376 .34612 .52843 .30343 .4906 .22092 Metetra
.775 .666 .742 r
.4906 .22092 .52843 .30343 .56291 .25504 .52546 .18323 Metetra
.804 .701 .751 r
.52546 .18323 .56291 .25504 .59708 .20304 .56021 .14286 Metetra
.831 .74 .765 r
.56021 .14286 .59708 .20304 .63089 .14942 .59481 .1012 Metetra
.397 .629 .947 r
.09217 .23214 .13429 .27638 .16308 .29252 .12226 .23433 Metetra
.46 .589 .895 r
.12226 .23433 .16308 .29252 .19259 .30754 .15287 .23579 Metetra
.503 .559 .846 r
.15287 .23579 .19259 .30754 .22291 .32006 .18404 .23586 Metetra
.535 .54 .806 r
.18404 .23586 .22291 .32006 .25407 .32872 .2158 .23386 Metetra
.562 .53 .777 r
.2158 .23386 .25407 .32872 .28609 .33232 .24817 .22921 Metetra
.585 .528 .758 r
.24817 .22921 .28609 .33232 .3189 .32998 .2811 .2215 Metetra
.607 .532 .745 r
.2811 .2215 .3189 .32998 .3524 .32108 .31456 .21043 Metetra
.627 .542 .738 r
.31456 .21043 .3524 .32108 .38648 .30534 .34848 .19587 Metetra
.648 .556 .737 r
.34848 .19587 .38648 .30534 .42098 .28298 .38279 .17794 Metetra
.669 .575 .74 r
.38279 .17794 .42098 .28298 .45573 .25456 .41741 .15687 Metetra
.692 .6 .749 r
.41741 .15687 .45573 .25456 .4906 .22092 .45225 .13308 Metetra
.715 .631 .762 r
.45225 .13308 .4906 .22092 .52546 .18323 .48726 .10713 Metetra
.74 .67 .782 r
.48726 .10713 .52546 .18323 .56021 .14286 .52237 .07968 Metetra
.765 .718 .808 r
.52237 .07968 .56021 .14286 .59481 .1012 .55756 .05142 Metetra
.666 .738 .904 r
.04875 .18654 .09217 .23214 .12226 .23433 .08051 .17394 Metetra
.655 .673 .855 r
.08051 .17394 .12226 .23433 .15287 .23579 .11254 .16124 Metetra
.644 .623 .814 r
.11254 .16124 .15287 .23579 .18404 .23586 .14483 .14843 Metetra
.633 .586 .783 r
.14483 .14843 .18404 .23586 .2158 .23386 .1774 .13551 Metetra
.625 .559 .761 r
.1774 .13551 .2158 .23386 .24817 .22921 .21025 .12249 Metetra
.619 .542 .746 r
.21025 .12249 .24817 .22921 .2811 .2215 .24339 .10934 Metetra
.616 .532 .737 r
.24339 .10934 .2811 .2215 .31456 .21043 .27681 .09609 Metetra
.615 .529 .734 r
.27681 .09609 .31456 .21043 .34848 .19587 .31052 .08272 Metetra
.616 .532 .737 r
.31052 .08272 .34848 .19587 .38279 .17794 .34452 .06923 Metetra
.619 .542 .746 r
.34452 .06923 .38279 .17794 .41741 .15687 .37882 .05563 Metetra
.625 .559 .761 r
.37882 .05563 .41741 .15687 .45225 .13308 .41342 .04191 Metetra
.633 .586 .783 r
.41342 .04191 .45225 .13308 .48726 .10713 .44833 .02806 Metetra
.644 .623 .814 r
.44833 .02806 .48726 .10713 .52237 .07968 .48355 .01409 Metetra
.655 .673 .855 r
.48355 .01409 .52237 .07968 .55756 .05142 .51908 0 Metetra
0 g
.25 Mabswid
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282.75, 314.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005Q0001RB000`400?l00000o`00003ooooooomR
ooooo`00oooooomRooooo`00oooooomRooooo`00^_ooool4o`000003oa0@4?oooooooooo0:3ooooo
002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002loooo
o`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`00
0?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002jooooo`03oeEEEOmVIVKo
00000:Cooooo003oooooof;ooooo003oooooof;ooooo001Mooooo`;o00000_ooool2o`000?kooooo
001Mooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgMo_ooool005kooooo00CogMgMo`000?l@413o
c<c<:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`07oooool2o`0009oooooo001Nooooo`04onk^k_lQ8B7o410@onk^kR[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01cooooo
0ol000000onW[=[o0000o`00002Nooooo`00G_ooool01?lQ8B7oMgMgogMgMolb<S8Zooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001[ooooo0ol00003ojN/
fP?o0000WOooool005gooooo0_l00002ooooo`;o0000:Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`?o00001_nW[=X00ol0003oYjcJo`00002M
ooooo`00S?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00Eooooo`?o00000_nW[=X00ol0003oYjcJojN/fP03ojN/fP04o`000?nW[=[oYjcJo`0009cooooo
002<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@01;o
oooo1?l0000:ojN/fP04o`000?nW[=[oYjcJo`0009cooooo002<ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000013ooooo1?l000000onTWm3o0000ojN/fP09
ojN/fP05o`000?nW[=[oYjcJojN/f_l00000Voooool008cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT03Oooool4o`000003ojBOd?l0003oY9o@00;oY9o@
00?o0000ojN/f_nW[=X01onW[=X00ol0003oYjcJojN/fP02ojN/fP03o`000?oooooooooo09Sooooo
002/ooooo`Co00002?nTWm000ol0003oYjcJojN/fP06ojN/fP03o`000?nW[=[oYjcJ00?oYjcJ00?o
0000ooooooooool0Uoooool00:Wooooo1?l0000;ojBOd003o`000?nW[=[oYjcJ00KoYjcJ00?o0000
ojN/f_nW[=X00onW[=X00ol0003oooooooooo`2Gooooo`00Yoooool6o`0000coY9o@00?o0000ojN/
f_nW[=X01OnW[=X00ol0003oYjcJojN/fP04ojN/fP03o`000?oooooooooo09Kooooo002Tooooo`Co
00001OnRU/P00ol0003oY9o@ojBOd009ojBOd003o`000?nW[=[oYjcJ00GoYjcJ00?o0000ojN/f_nW
[=X01OnW[=X00ol0003oooooooooo`2Eooooo`00KOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`08?ooool3o`0000SoXYK800?o0000ojBO
d?nTWm002_nTWm000ol0003oYjcJojN/fP04ojN/fP03o`000?nW[=[oYjcJ00KoYjcJ00?o0000oooo
ooooool0U?ooool006gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q01gooooo0ol000000onRU/So0000oj:Fb009oj:Fb003o`000?nTWm3o
Y9o@00[oY9o@00?o0000ojN/f_nW[=X00onW[=X00ol0003oYjcJojN/fP06ojN/fP03o`000?oooooo
oooo09Cooooo001]ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000001_ooooo0ol000001OnOSl;o0000oj:Fb?nRU/So000000WoXYK800?o0000ojBOd?nTWm00
2_nTWm000ol0003oYjcJojN/fP03ojN/fP03o`000?nW[=[oYjcJ00OoYjcJ00?o0000ooooooooool0
Toooool006gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B406?ooool3o`0000GoWho200?o0000oj:Fb?nRU/P02_nRU/P00ol0003oY9o@ojBOd00:ojBOd003
o`000?nW[=[oYjcJ00;oYjcJ00?o0000ojN/f_nW[=X02?nW[=X00ol0003oooooooooo`2Booooo`00
KOooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Eoooo
o`Co000000?oWho2o`000?nOSl801?nOSl800ol0003oXYK8oj:Fb00:oj:Fb003o`000?nTWm3oY9o@
00[oY9o@00?o0000ojN/f_nW[=X00_nW[=X00ol0003oYjcJojN/fP08ojN/fP;o0000Toooool006go
oooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo01Gooooo0ol0000;oin?
`P03o`000?nRU/SoXYK800[oXYK800?o0000ojBOd?nTWm002_nTWm001Ol0003oYjcJojN/f_nW[=[o
000000WoYjcJ00?o0000ol>gc_l00000Toooool006gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`03omgMgOl@413oV9RH01?ooooo1?l0000<oin?`P03o`000?nRU/SoXYK800[oXYK800?o0000
ojBOd?nTWm002onTWm001?l0003oYjcJojN/f_l00008ojN/fP05o`000?o3]lko`kO>ol>gc_l00000
T_ooool006gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40oo
oooo0_l00002oij:_P03o`000?nNR[ko000000_oWho200?o0000oj:Fb?nRU/P02onRU/P00ol0003o
Y9o@ojBOd00:ojBOd004o`000?nW[=[oYjcJo`0000OoYjcJ00?o0000ol>gc_o3]lh00oo3]lh00ol0
003oooooooooo`2?ooooo`00S_ooool3o`0000KoWXZn00?o0000oin?`_nOSl802_nOSl800ol0003o
XYK8oj:Fb00:oj:Fb003o`000?nTWm3oY9o@00_oY9o@00?o0000ojN/f_l000001OnW[=X2o`0000Oo
`kO>00?o0000ooooooooool0S_ooool008cooooo0ol00008oij:_P03o`000?nOSl;oWho200[oWho2
00?o0000oj:Fb?nRU/P02onRU/P00ol0003oY9o@ojBOd00:ojBOd003o`000?nW[=[o000000CoYjcJ
00?o0000ol>gc_o3]lh01oo3]lh2o`0008oooooo0029ooooo`Co000000?oWXZno`000?nNR[h02?nN
R[h00ol0003oWho2oin?`P0:oin?`P03o`000?nRU/SoXYK800[oXYK800?o0000ojBOd?nTWm002onT
Wm02o`0000?oYjcJ00?o0000ol>gc_o3]lh02Oo3]lh00ol0003oooooooooo`2=ooooo`00D?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool08?oo
ool4o`000003oif8_?l0003oWXZn00[oWXZn00?o0000oin?`_nOSl802_nOSl800ol0003oXYK8oj:F
b00;oj:Fb003o`000?nTWm3oY9o@00_oY9o@00Co0000ojN/f_nW[=[o00003Oo3]lh00ol0003ooooo
ooooo`2<ooooo`00D?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo01kooooo1?l00005oif8_003o`000?nNR[koWXZn00SoWXZn00?o0000oin?`_nOSl80
2onOSl800ol0003oXYK8oj:Fb00:oj:Fb003o`000?nTWm3oY9o@00_oY9o@00?o0000ojN/f_l00000
3oo3]lh00ol0003oooooooooo`2;ooooo`00D?ooool01Ol@413ooooooooooooooooo410@00_ooooo
1Ol0000Mooooo`?o000000?oWHRlo`000?nMR;`01OnMR;`00ol0003oWXZnoij:_P09oij:_P03o`00
0?nOSl;oWho200[oWho200?o0000oj:Fb?nRU/P02onRU/P00ol0003oY9o@ojBOd00:ojBOd0;o0000
4?o3]lh2o`0008cooooo001@ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgM
ooooool0000Kooooo`?o00001OnMR;`00ol0003oWHRloif8_003oif8_003o`000?nNR[koWXZn00Wo
WXZn00?o0000oin?`_nOSl802_nOSl800ol0003oXYK8oj:Fb00;oj:Fb003o`000?nTWm3oY9o@00Wo
Y9o@0ol0000Aol>gcP;o0000Roooool0053ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
omgMgOmEEEGoooooo`0001Wooooo0ol000000onMQk_o0000oif8_00;oif8_003o`000?nNR[koWXZn
00WoWXZn00?o0000oin?`_nOSl802_nOSl800ol0003oXYK8oj:Fb00;oj:Fb003o`000?nTWm3oY9o@
00OoY9o@00Go0000okf[b?l0003o_J_8o`00000Aol>gcP03o`000?oooooooooo08Wooooo001@oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Fooooo`?o00000_nMQk/0
1?l0003oWHNkoif7^ol0000;oif8_003o`000?nNR[koWXZn00WoWXZn00?o0000oin?`_nOSl802_nO
Sl800ol0003oXYK8oj:Fb00;oj:Fb003o`000?nTWm3oY9o@00KoY9o@00Co0000okf[b?nmZlSo0000
0_nmZlP00ol0003o`kO>ol>gcP0?ol>gcP03o`000?oooooooooo08Sooooo001@ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000Dooooo`?o00001onMQk/00ol0003oWHRl
oif8_009oif8_003o`000?nNR[koWXZn00WoWXZn00?o0000oin?`_nOSl802onOSl800ol0003oXYK8
oj:Fb00;oj:Fb003o`000?nTWm3oY9o@00?oY9o@0_l00003okf[b004o`000?nmZlSo_J_8o`00017o
`kO>0_l00029ooooo`00D?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?oo
ool04?ooool3o`0000[oWHNk00?o0000oif8_?nMR;`02_nMR;`00ol0003oWXZnoij:_P09oij:_P03
o`000?nOSl;oWho200[oWho200?o0000oj:Fb?nRU/P02onRU/P00ol0003oY9o@ojBOd002ojBOd003
o`000?nmZlSo_J_800?o_J_800Go0000okf[b?nmZlSo_J_8o`00000Aol>gcP;o0000R?ooool007?o
oooo0ol000000onMR;co0000o`00000:oif7^`03o`000?nMR;coWHRl00WoWHRl00?o0000oij:__nN
R[h02OnNR[h00ol0003oWho2oin?`P0;oin?`P03o`000?nRU/SoXYK800_oXYK800Co0000ojBOd?nT
Wm3o00001_nmZlP01Ol0003o_J_8okf[b?nmZlSo000001;o`kO>0_l00027ooooo`00L?ooool3o`00
00CoWHRl00?o0000oif7^onMQk/02OnMQk/00ol0003oWHRloif8_009oif8_003o`000?nNR[koWXZn
00WoWXZn00?o0000oin?`_nOSl802onOSl800ol0003oXYK8oj:Fb00;oj:Fb003o`000?nTWm3o0000
00Oo_J_800?o0000okf[b?nmZlP00_nmZlP00ol0003o`kO>ol>gcP0@ol>gcP03o`000?oooooooooo
08Gooooo001^ooooo`?o00001onMR;`00ol0003oWHNkoif7^`08oif7^`03o`000?nMR;coWHRl00[o
WHRl00?o0000oij:__nNR[h02OnNR[h00ol0003oWho2oin?`P0:oin?`P03o`000?nRU/SoXYK800_o
XYK80_l00008okf[b003o`000?nmZlSo_J_800?o_J_800?o0000ol>gc_o3]lh03_o3]lh3o`0008Ko
oooo000cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000Sooooo`?o
00000_nMR;`00ol0003oWHRloif8_005oif8_003o`000?nMQk_oWHNk00WoWHNk00?o0000oif8_?nM
R;`02OnMR;`00ol0003oWXZnoij:_P09oij:_P03o`000?nOSl;oWho200_oWho200?o0000oj:Fb?nR
U/P02OnRU/P00ol0003o]j73o`000008okf[b003o`000?nmZlSo_J_800?o_J_800?o0000ol>gc_o3
]lh03Oo3]lh00ol0003oe;g3omBm``02o`0008Gooooo000cooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Qooooo`?o000000?oWXZno`00
0?nMR;`02OnMR;`00ol0003oWHNkoif7^`09oif7^`03o`000?nMR;coWHRl00WoWHRl00?o0000oij:
__nNR[h02_nNR[h00ol0003oWho2oin?`P0:oin?`P03o`000?nRU/SoXYK800SoXYK800Go0000okNQ
`ongXL?o]j73o`000007okf[b003o`000?nmZlSo_J_800Co_J_800?o0000ol>gc_o3]lh02oo3]lh0
0ol0003oe;g3omBm``02omBm``;o0000Q?ooool003?ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^01oooooo1?l00003oij:_P03o`000?nMR;coWHRl00WoWHRl00?o0000
oif7^onMQk/02?nMQk/00ol0003oWHRloif8_00:oif8_003o`000?nNR[koWXZn00WoWXZn00?o0000
oin?`_nOSl802onOSl800ol0003oXYK8oj:Fb005oj:Fb0;o00001?ngXL<00ol0003o_J_8okf[b005
okf[b003o`000?nmZlSo_J_800Go_J_800?o0000ol>gc_o3]lh02Oo3]lh00ol0003oe;g3omBm``04
omBm``03o`000?oooooooooo08;ooooo000cooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP0Kooooo`?o00001?nNR[h01Ol0003oWXZnoij:__nNR[ko000000[oWHRl00?o
0000oif7^onMQk/02OnMQk/00ol0003oWHRloif8_009oif8_003o`000?nNR[koWXZn00WoWXZn00?o
0000oin?`_nOSl802onOSl800ol0003oXYK8oj:Fb004oj:Fb003o`000?ngXL?o]j7300Go]j7300?o
0000okf[b?nmZlP01?nmZlP00ol0003o_J_8okf[b005okf[b003o`000?o3]lko`kO>00So`kO>00?o
0000omBm`ooD_L<01OoD_L<2o`0008?ooooo000cooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`0Hooooo`?o00002_nNR[h00ol0003oWHRloif8_008oif8_003o`000?nM
Qk_oWHNk00WoWHNk00?o0000oif8_?nMR;`02OnMR;`00ol0003oWXZnoij:_P0:oij:_P03o`000?nO
Sl;oWho200_oWho200Co0000oj:Fb?nRU/SoXYK80_l00008okNQ``03o`000?nmZlSo_J_800Co_J_8
00?o0000okf[b?nmZlP01_nmZlP00ol0003o`kO>ol>gcP06ol>gcP03o`000?oD_L?oe;g300Ooe;g3
0_l00022ooooo`00<oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
5?ooool3o`000003oin?`_l0003oWXZn00[oWXZn00?o0000oif8_?nMR;`02OnMR;`00ol0003oWHNk
oif7^`08oif7^`03o`000?nMR;coWHRl00[oWHRl00?o0000oij:__nNR[h02OnNR[h00ol0003oWho2
oin?`P0;oin?`P04o`000?nRU/SoXYK8o`0000_o]j7300?o0000okf[b?nmZlP00onmZlP00ol0003o
_J_8okf[b007okf[b003o`000?o3]lko`kO>00Go`kO>00?o0000omBm`ooD_L<02?oD_L<2o`00087o
oooo000cooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
01Cooooo0ol00004oin?`P03o`000?nNR[koWXZn00WoWXZn00?o0000oif8_?nMR;`02?nMR;`00ol0
003oWHNkoif7^`09oif7^`03o`000?nMR;coWHRl00WoWHRl00?o0000oij:__nNR[h02OnNR[h00ol0
003oWho2oin?`P0;oin?`P03o`000?nRU/So000000co]j7300?o0000okf[b?nmZlP00onmZlP00ol0
003o_J_8okf[b007okf[b003o`000?o3]lko`kO>00Co`kO>00?o0000omBm`ooD_L<02_oD_L<00ol0
003oooooooooo`1oooooo`00<oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00Aooooo`?o00001onOSl800ol0003oWXZnoij:_P09oij:_P03o`000?nMR;co
WHRl00SoWHRl00?o0000oif7^onMQk/02OnMQk/00ol0003oWHRloif8_009oif8_003o`000?nNR[ko
WXZn00[oWXZn00?o0000oin?`_nOSl802_nOSl82o`0000go]j7300?o0000okf[b?nmZlP00onmZlP0
0ol0003o_J_8okf[b008okf[b003o`000?o3]lko`kO>00;o`kO>00?o0000omBm`ooD_L<02ooD_L<2
o`00083ooooo001Gooooo`?o000000?oWho2o`000?nOSl801_nOSl800ol0003oWXZnoij:_P09oij:
_P03o`000?nMR;coWHRl00WoWHRl00?o0000oif7^onMQk/02?nMQk/00ol0003oWHRloif8_00:oif8
_003o`000?nNR[koWXZn00WoWXZn00?o0000oin?`_nOSl802OnOSl800ol0003o/IVoo`00000>okNQ
``03o`000?nmZlSo_J_800;o_J_800?o0000okf[b?nmZlP02?nmZlP01Ol0003o`kO>ol>gc_o3]lko
000000ooe;g30_l0001oooooo`00E?ooool3o`000003oj:Fb?l0003oWho200[oWho200?o0000oij:
__nNR[h02OnNR[h00ol0003oWHRloif8_008oif8_003o`000?nMQk_oWHNk00WoWHNk00?o0000oif8
_?nMR;`02OnMR;`00ol0003oWXZnoij:_P0:oij:_P03o`000?nOSl;oWho200OoWho200Go0000ok6I
_onaVKoo/IVoo`00000=okNQ``03o`000?nmZlSo_J_800;o_J_800?o0000okf[b?nmZlP02OnmZlP0
0ol0003o`kO>o`00000AomBm``03o`000?oooooooooo07gooooo001Booooo`?o00001?nRU/P00ol0
003oWho2oin?`P08oin?`P03o`000?nNR[koWXZn00WoWXZn00?o0000oif8_?nMR;`02?nMR;`00ol0
003oWHNkoif7^`09oif7^`03o`000?nMR;coWHRl00WoWHRl00?o0000oij:__nNR[h02_nNR[h00ol0
003oWho2oin?`P05oin?`P;o00001?naVKl00ol0003o]j73okNQ``0<okNQ``05o`000?nmZlSo_J_8
okf[b?l000003?nmZlP00ol0003oe;g3omBm``0AomBm``03o`000?oooooooooo07cooooo000Woooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool4o`000003oj:Fb?l0003oXYK800?oXYK800?o0000
oin?`_nOSl802?nOSl800ol0003oWXZnoij:_P09oij:_P03o`000?nMR;coWHRl00WoWHRl00?o0000
oif7^onMQk/02?nMQk/00ol0003oWHRloif8_00:oif8_003o`000?nNR[koWXZn00WoWXZn00?o0000
oin?`_nOSl801?nOSl800ol0003o/IVook6I_`05ok6I_`03o`000?ngXL?o]j7300_o]j7300Go0000
okf[b?nmZlSo_J_8o`00000<okf[b003o`000?oD_L?oe;g3017oe;g30_l0001mooooo`009oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg027ooooo0ol00009oj:Fb003o`000?nOSl;oWho200WoWho200?o
0000oij:__nNR[h02OnNR[h00ol0003oWHRloif8_008oif8_003o`000?nMQk_oWHNk00WoWHNk00?o
0000oif8_?nMR;`02OnMR;`00ol0003oWXZnoij:_P0:oij:_P04o`000?nOSl;oWho2oin?`P;o0000
2?naVKl00ol0003o]j73okNQ``0<okNQ``04o`000?nmZlSo_J_8o`0000_o_J_800?o0000olfc`?l0
00004ooD_L<2o`0007cooooo000Wooooo`05oa0@4?ooooooooooooooool@41007_ooool5o`0000_o
XYK800?o0000oin?`_nOSl802?nOSl800ol0003oWXZnoij:_P09oij:_P03o`000?nMR;coWHRl00So
WHRl00?o0000oif7^onMQk/02OnMQk/00ol0003oWHRloif8_009oif8_003o`000?nNR[koWXZn00[o
WXZn00Co0000oin?`_nOSl;o00002_naVKl00ol0003o]j73okNQ``0<okNQ``04o`000?nmZlSo_J_8
o`0000[o_J_800Co0000olfc`?o=/l3o00005?oD_L<00ol0003oooooooooo`1jooooo`009oooool0
1Ol0003ooooooooooooooooo000001cooooo0ol00002ojBOd003o`000?nTWm3o000000[oXYK800?o
0000oin?`_nOSl802?nOSl800ol0003oWXZnoij:_P09oij:_P03o`000?nMR;coWHRl00WoWHRl00?o
0000oif7^onMQk/02?nMQk/00ol0003oWHRloif8_00:oif8_003o`000?nNR[koWXZn00WoWXZn00?o
0000oin?`_l000003?naVKl00ol0003o]j73okNQ``0<okNQ``03o`000?nmZlSo000000Wo_J_800?o
0000olfc`?o=/l000_o=/l000ol0003oe;g3omBm``0@omBm``03o`000?oN`;[o000007_ooooo000W
ooooo`05o`000?ooooooooooooooool000006Oooool4o`0000GoY9o@0_l0000;oj:Fb003o`000?nO
Sl;oWho200SoWho200?o0000oij:__nNR[h02OnNR[h00ol0003oWHRloif8_008oif8_003o`000?nM
Qk_oWHNk00WoWHNk00?o0000oif8_?nMR;`02OnMR;`00ol0003oWXZnoij:_P09oij:_P;o00003Ona
VKl00ol0003o]j73okNQ``0<okNQ``03o`000?nmZlSo000000So_J_800?o0000olfc`?o=/l001?o=
/l000ol0003oe;g3omBm``0>omBm``03o`000?oN`;[og/2j00;o0000N_ooool002Oooooo00Go410@
oooooooooooooooooa0@400Gooooo`?o00002_nTWm000ol0003oXYK8oj:Fb008oj:Fb003o`000?nO
Sl;oWho200SoWho200?o0000oij:__nNR[h02OnNR[h00ol0003oWHRloif8_008oif8_003o`000?nM
Qk_oWHNk00WoWHNk00?o0000oif8_?nMR;`02OnMR;`00ol0003oWXZnoij:_P07oij:_P;o000000?o
Zi>mo`000?naVKl03OnaVKl00ol0003o]j73okNQ``0<okNQ``;o00001onmZlP00ol0003ocK?0olfc
`005olfc`003o`000?oD_L?oe;g300koe;g300Co0000omk0^_oN`;[og/2j0_l0001iooooo`009ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo1Ol000000onTWm3o0000ojBOd008ojBOd003o`00
0?nRU/SoXYK800SoXYK800?o0000oin?`_nOSl802OnOSl800ol0003oWXZnoij:_P08oij:_P03o`00
0?nMR;coWHRl00SoWHRl00?o0000oif7^onMQk/02OnMQk/00ol0003oWHRloif8_00:oif8_003o`00
0?nNR[koWXZn00CoWXZn0_l00004oj^C_@03o`000?naVKoo/IVo00_o/IVo00?o0000okNQ`ongXL<0
3?ngXL<2o`0000Ko_J_800?o0000olfc`?o=/l001oo=/l000ol0003oe;g3omBm``0<omBm``03o`00
0?oN`;[og/2j00?og/2j00?o0000ooooooooool0Moooool002Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Booooo`?o00001?nW[=X00ol0003oY9o@ojBOd008ojBOd003o`000?nRU/SoXYK800WoXYK8
00?o0000oin?`_nOSl802?nOSl800ol0003oWXZnoij:_P09oij:_P03o`000?nMR;coWHRl00SoWHRl
00?o0000oif7^onMQk/02OnMQk/00ol0003oWHRloif8_009oif8_003o`000?nNR[koWXZn00?oWXZn
00?o0000oj^C_On[Tkd01?n[Tkd00ol0003o/IVook6I_`0<ok6I_`03o`000?ngXL?o]j7300_o]j73
0_l00006okf[b003o`000?o=/l3ocK?000OocK?000?o0000omBm`ooD_L<02ooD_L<00ol0003og/2j
omk0^P05omk0^P03o`000?oooooooooo07Kooooo000kooooo`Go00001OnW[=X00ol0003oY9o@ojBO
d009ojBOd003o`000?nRU/SoXYK800SoXYK800?o0000oin?`_nOSl802?nOSl800ol0003oWXZnoij:
_P09oij:_P03o`000?nMR;coWHRl00SoWHRl00?o0000oif7^onMQk/02OnMQk/00ol0003oWHRloif8
_009oif8_004o`000?nNR[koWXZnoij:_P;o00001on[Tkd00ol0003o/IVook6I_`0<ok6I_`03o`00
0?ngXL?o]j7300co]j7300?o0000okf[b?nmZlP00onmZlP00ol0003ocK?0olfc`009olfc`003o`00
0?oD_L?oe;g300[oe;g300?o0000omk0^_oN`;X01OoN`;X2o`0007Oooooo000iooooo`?o00002_nW
[=X00ol0003oY9o@ojBOd008ojBOd003o`000?nRU/SoXYK800WoXYK800?o0000oin?`_nOSl802?nO
Sl800ol0003oWXZnoij:_P08oij:_P03o`000?nMR;coWHRl00SoWHRl00?o0000oif7^onMQk/02OnM
Qk/00ol0003oWHRloif8_00:oif8_0?o00002_n[Tkd00ol0003o/IVook6I_`0<ok6I_`03o`000?ng
XL?o]j7300_o]j7300?o0000okf[b?nmZlP00_nmZlP00ol0003ocK?0olfc`00;olfc`003o`000?oD
_L?oe;g300Soe;g300?o0000omk0^_oN`;X01ooN`;X2o`0007Kooooo000gooooo`Co00003?nW[=X0
0ol0003oY9o@ojBOd008ojBOd003o`000?nRU/SoXYK800SoXYK800?o0000oin?`_nOSl802?nOSl80
0ol0003oWXZnoij:_P08oij:_P03o`000?nMR;coWHRl00WoWHRl00?o0000oif7^onMQk/02OnMQk/0
0ol0003oWHRloif8_008oif8_0;o00003?n[Tkd00ol0003o/IVook6I_`0<ok6I_`03o`000?ngXL?o
]j7300_o]j730_l00002okf[b003o`000?o=/l3ocK?000cocK?000?o0000omBm`ooD_L<01ooD_L<0
0ol0003og/2jomk0^P09omk0^P03o`000?oooooooooo07Cooooo000dooooo`?o000000GoZ[cWo`00
0?nZ_>OoZ[cWo`00000;ojN/fP03o`000?nTWm3oY9o@00SoY9o@00?o0000oj:Fb?nRU/P02?nRU/P0
0ol0003oWho2oin?`P08oin?`P03o`000?nNR[koWXZn00WoWXZn00?o0000oif8_?nMR;`02?nMR;`0
0ol0003oWHNkoif7^`09oif7^`03o`000?nMR;coWHRl00KoWHRl0_l000000onUS[co0000oj^C_@0<
oj^C_@03o`000?naVKoo/IVo00_o/IVo00?o0000okNQ`ongXL<02ongXL<2o`000003okf[b?l0003o
cK?000oocK?000?o0000omBm`ooD_L<01_oD_L<00ol0003og/2jomk0^P0:omk0^P03o`000?oooooo
oooo07?ooooo000booooo`?o00001onZ_>L00ol0003oYjcJojN/fP09ojN/fP03o`000?nTWm3oY9o@
00SoY9o@00?o0000oj:Fb?nRU/P02?nRU/P00ol0003oWho2oin?`P08oin?`P03o`000?nNR[koWXZn
00SoWXZn00?o0000oif8_?nMR;`02?nMR;`00ol0003oWHNkoif7^`09oif7^`03o`000?nMR;coWHRl
00GoWHRl00?o0000ojF>_?nUS[`00_nUS[`00ol0003oZi>moj^C_@0:oj^C_@03o`000?naVKoo/IVo
00co/IVo00?o0000okNQ`ongXL<02_ngXL<00ol0003o]j73o`00000Aolfc`003o`000?oD_L?oe;g3
00Goe;g300?o0000omk0^_oN`;X02ooN`;X2o`0007Cooooo000aooooo`03o`000?nZ_>OoZ[cW00Wo
Z[cW00?o0000ojN/f_nW[=X02?nW[=X00ol0003oY9o@ojBOd008ojBOd003o`000?nRU/SoXYK800So
XYK800?o0000oin?`_nOSl802?nOSl800ol0003oWXZnoij:_P08oij:_P03o`000?nMR;coWHRl00Wo
WHRl00?o0000oif7^onMQk/02OnMQk/00ol0003oWHRloif8_002oif8_0;o00001OnUS[`00ol0003o
Zi>moj^C_@0:oj^C_@03o`000?naVKoo/IVo00co/IVo00?o0000okNQ`ongXL<02_ngXL<00ol0003o
]j73o`00000Bolfc`003o`000?oD_L?oe;g300Coe;g300?o0000omk0^_oN`;X03?oN`;X00ol0003o
ooooooooo`1booooo`00<Oooool2o`0000[oZ[cW00?o0000ojN/f_nW[=X02OnW[=X00ol0003oY9o@
ojBOd008ojBOd003o`000?nRU/SoXYK800SoXYK800?o0000oin?`_nOSl801onOSl800ol0003oWXZn
oij:_P09oij:_P03o`000?nMR;coWHRl00SoWHRl00?o0000oif7^onMQk/02OnMQk/00ol0003oWHRl
oif8_002o`0000OoYHjl00?o0000oj^C_On[Tkd02on[Tkd00ol0003o/IVook6I_`0<ok6I_`03o`00
0?ngXL?o]j7300Wo]j730_l000000oo6Z[go0000olfc`00@olfc`003o`000?oD_L?oe;g300?oe;g3
00?o0000omk0^_oN`;X03_oN`;X00ol0003oooooooooo`1aooooo`009Oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Oooooo0_l0000;ojZli`03o`000?nW[=[oYjcJ00SoYjcJ00?o0000ojBOd?nTWm00
2?nTWm000ol0003oXYK8oj:Fb008oj:Fb003o`000?nOSl;oWho200SoWho200?o0000oij:__nNR[h0
2?nNR[h00ol0003oWHRloif8_008oif8_003o`000?nMQk_oWHNk00WoWHNk00?o0000oif8_?l00000
2_nUS[`00ol0003oZi>moj^C_@0:oj^C_@03o`000?naVKoo/IVo00co/IVo00?o0000okNQ`ongXL<0
2OngXL<01?l0003oaZZmolJZ_Ol0000Bolfc`005o`000?oD_L?oe;g3omBm`ol000004_oN`;X00ol0
003oooooooooo`1`ooooo`009Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?o0000oooo
ool000002onZ_>L00ol0003oYjcJojN/fP08ojN/fP03o`000?nTWm3oY9o@00OoY9o@00?o0000oj:F
b?nRU/P02?nRU/P00ol0003oWho2oin?`P08oin?`P03o`000?nNR[koWXZn00SoWXZn00?o0000oif8
_?nMR;`02OnMR;`00ol0003oWHNkoif7^`08oif7^`;o00002onUS[`00ol0003oZi>moj^C_@0;oj^C
_@03o`000?naVKoo/IVo00co/IVo00?o0000okNQ`ongXL<01ongXL<2o`0000?oaZZm00?o0000olfc
`?o=/l004?o=/l001?l0003oe;g3omBm`ol0000Bomk0^P;o0000LOooool002Gooooo00Go410@oooo
oooooooooooooa0@4007ooooo`04o`000?ooooooooooo`0000[oZ[cW00?o0000ojN/f_nW[=X02OnW
[=X00ol0003oY9o@ojBOd007ojBOd003o`000?nRU/SoXYK800SoXYK800?o0000oin?`_nOSl802?nO
Sl800ol0003oWXZnoij:_P08oij:_P03o`000?nMR;coWHRl00SoWHRl00?o0000oif7^onMQk/01OnM
Qk/3o`000003oj2:_?l0003oYHjl00[oYHjl00?o0000oj^C_On[Tkd02on[Tkd00ol0003o/IVook6I
_`0<ok6I_`03o`000?ngXL?o]j7300Ko]j7300?o0000olJZ_Ol000000oo6Z[d00ol0003ocK?0olfc
`00@olfc`003o`000?oD_L?o000001Cog/2j00?o0000ooooooooool0Koooool002Gooooo00Go0000
ooooooooooooooooo`000006ooooo`;o00000oooool00ol0003oZ[cWojZli`08ojZli`03o`000?nW
[=[oYjcJ00SoYjcJ00?o0000ojBOd?nTWm001onTWm000ol0003oXYK8oj:Fb008oj:Fb003o`000?nO
Sl;oWho200SoWho200?o0000oij:__nNR[h02?nNR[h00ol0003oWHRloif8_008oif8_003o`000?nM
Qk_oWHNk00;oWHNk0ol00005oj2:_003o`000?nUS[coYHjl00WoYHjl00?o0000oj^C_On[Tkd02_n[
Tkd00ol0003o/IVook6I_`0=ok6I_`03o`000?ngXL?o]j7300Co]j7300Co0000olJZ_Oo6Z[go0000
1?o6Z[d00ol0003ocK?0olfc`00@olfc`003o`000?oN`;[og/2j01;og/2j00?o0000onG2/ol00000
L?ooool002Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo
00?o0000ojZlionZ_>L02?nZ_>L00ol0003oYjcJojN/fP08ojN/fP03o`000?nTWm3oY9o@00OoY9o@
00?o0000oj:Fb?nRU/P02?nRU/P00ol0003oWho2oin?`P07oin?`P03o`000?nNR[koWXZn00SoWXZn
00?o0000oif8_?nMR;`02OnMR;`4o`0000SoX8Zl00?o0000ojF>_?nUS[`02OnUS[`00ol0003oZi>m
oj^C_@0;oj^C_@03o`000?naVKoo/IVo00co/IVo00?o0000okNQ`ongXL<00ongXL<01Ol0003oaZZm
olJZ_Oo6Z[go000000GoaZZm00?o0000olfc`?o=/l003oo=/l000ol0003og/2jomk0^P0Bomk0^P04
o`000?oU`[?oiL:co`0006oooooo000Uooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0
003oooooooooo`04ooooo`03o`000?nZ_>OoZ[cW00SoZ[cW00?o0000ojN/f_nW[=X01onW[=X00ol0
003oY9o@ojBOd007ojBOd003o`000?nRU/SoXYK800SoXYK800?o0000oin?`_nOSl802?nOSl800ol0
003oWXZnoij:_P08oij:_P03o`000?nMR;coWHRl00OoWHRl0_l0000;oj2:_003o`000?nUS[coYHjl
00[oYHjl00?o0000oj^C_On[Tkd02_n[Tkd00ol0003o/IVook6I_`0<ok6I_`03o`000?ngXL?o]j73
00;o]j7300?o0000olJZ_Oo6Z[d00_o6Z[d00ol0003oaZZmolJZ_@03olJZ_@03o`000?o=/l3ocK?0
00kocK?000?o0000omRh^Ol000004_oN`;X01?l0003oiL:conG2/ooU`[<2o`0006kooooo000Uoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`05ooooo`03o`000?nZ_>Oo
Z[cW00OoZ[cW00?o0000ojN/f_nW[=X02?nW[=X00ol0003oY9o@ojBOd007ojBOd003o`000?nRU/So
XYK800OoXYK800?o0000oin?`_nOSl802?nOSl800ol0003oWXZnoij:_P08oij:_P03o`000?nMR;co
WHRl00CoWHRl0ol000000onKR;ko0000oj2:_00;oj2:_003o`000?nUS[coYHjl00WoYHjl00?o0000
oj^C_On[Tkd02on[Tkd00ol0003o/IVook6I_`0<ok6I_`04o`000?ngXL?o]j73o`0000GoaZZm00?o
0000olJZ_Oo6Z[d01?o6Z[d00ol0003ocK?0olfc`00<olfc`005o`000?oH^;Wof;RiomRh^Ol00000
4OoN`;X00ol0003oiL:conG2/`02onG2/`03o`000?oooooooooo06cooooo000Uooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`06ooooo`03o`000?nZ_>OoZ[cW00OoZ[cW
00?o0000ojN/f_nW[=X01onW[=X00ol0003oY9o@ojBOd007ojBOd003o`000?nRU/SoXYK800SoXYK8
00?o0000oin?`_nOSl801onOSl800ol0003oWXZnoij:_P08oij:_P03o`000?nMR;coWHRl00;oWHRl
0_l00005oi^8_P03o`000?nPR[coX8Zl00WoX8Zl00?o0000ojF>_?nUS[`02OnUS[`00ol0003oZi>m
oj^C_@0;oj^C_@03o`000?naVKoo/IVo00co/IVo00?o0000okNQ`ol000001_o6Z[d00ol0003oaZZm
olJZ_@04olJZ_@03o`000?o=/l3ocK?000cocK?000Go0000omRh^OoH^;Wof;Rio`00000@omk0^P03
o`000?oU`[?oiL:c00CoiL:c00?o0000ooooooooool0Joooool0033ooooo00?o0000ooooooooool0
1oooool00ol0003oZ[cWojZli`07ojZli`03o`000?nW[=[oYjcJ00OoYjcJ00?o0000ojBOd?nTWm00
1onTWm000ol0003oXYK8oj:Fb007oj:Fb003o`000?nOSl;oWho200SoWho200?o0000oij:__nNR[h0
2?nNR[h4o`0000OoVhRn00?o0000oj2:_?nPR[`02OnPR[`00ol0003oYHjlojF>_00:ojF>_003o`00
0?n[TkgoZi>m00[oZi>m00?o0000ok6I_onaVKl03OnaVKl00ol0003oaZZmolJZ_@05olJZ_@03o`00
0?o6Z[goaZZm00GoaZZm00?o0000olfc`?o=/l002_o=/l000ol0003of;RiomRh^@03omRh^@03o`00
0?oN`;[og/2j00gog/2j00?o0000onG2/ooU`[<01OoU`[<00ol0003oooooooooo`1Zooooo`00<?oo
ool00ol0003oooooooooo`08ooooo`03o`000?nZ_>OoZ[cW00KoZ[cW00?o0000ojN/f_nW[=X01onW
[=X00ol0003oY9o@ojBOd007ojBOd003o`000?nRU/SoXYK800SoXYK800?o0000oin?`_nOSl801onO
Sl800ol0003oWXZnoij:_P06oij:_P?o00002_nKR;h00ol0003oX8Zloj2:_00:oj2:_003o`000?nU
S[coYHjl00WoYHjl00?o0000oj^C_On[Tkd02on[Tkd00ol0003o/IVook6I_`0;ok6I_`;o00001oo6
Z[d00ol0003oaZZmolJZ_@05olJZ_@03o`000?o=/l3ocK?000[ocK?000?o0000omRh^OoH^;T01?oH
^;T00ol0003og/2jomk0^P0;omk0^P03o`000?oU`[?oiL:c00KoiL:c00?o0000ooooooooool0J_oo
ool002oooooo0_l0000;ooooo`03o`000?nZ_>OoZ[cW00KoZ[cW00?o0000ojN/f_nW[=X01onW[=X0
0ol0003oY9o@ojBOd006ojBOd003o`000?nRU/SoXYK800SoXYK800?o0000oin?`_nOSl801onOSl80
1?l0003oWXZnoij:__nNR[h5o`0000;oUHO200?o0000oi^8__nKR;h02OnKR;h00ol0003oX8Zloj2:
_009oj2:_003o`000?nUS[coYHjl00WoYHjl00?o0000oj^C_On[Tkd02on[Tkd00ol0003o/IVook6I
_`0:ok6I_`04o`000?nnX[co_Z:lo`0000KoaZZm00?o0000olJZ_Oo6Z[d01_o6Z[d00ol0003ocK?0
olfc`008olfc`003o`000?oH^;Wof;Ri00Kof;Ri00?o0000omk0^_oN`;X02_oN`;X00ol0003oiL:c
onG2/`07onG2/`03o`000?oooooooooo06Wooooo000`ooooo`03o`000?oooooooooo00[ooooo00?o
0000ojZlionZ_>L01_nZ_>L00ol0003oYjcJojN/fP07ojN/fP03o`000?nTWm3oY9o@00KoY9o@00?o
0000oj:Fb?nRU/P01onRU/P00ol0003oWho2oin?`P03oin?`PSo00002?nEQl800ol0003oVhRnoi^8
_P08oi^8_P03o`000?nPR[coX8Zl00WoX8Zl00?o0000ojF>_?nUS[`02_nUS[`00ol0003oZi>moj^C
_@0;oj^C_@03o`000?naVKoo/IVo00So/IVo00Go0000okjR_?nnX[co_Z:lo`000006olJZ_@03o`00
0?o6Z[goaZZm00KoaZZm00?o0000olfc`?o=/l001oo=/l000ol0003of;RiomRh^@07omRh^@03o`00
0?oN`;[og/2j00Wog/2j00?o0000onG2/ooU`[<02OoU`[<00ol0003oooooooooo`1Xooooo`00;ooo
ool00ol0003oooooooooo`0<ooooo`oo00000onW[=X00ol0003oY9o@ojBOd006ojBOd003o`000?nR
U/SoXYK800?oXYK82_l00005ohn7aP03o`000?nEQl;oUHO200SoUHO200?o0000oi^8__nKR;h02?nK
R;h00ol0003oX8Zloj2:_00:oj2:_003o`000?nUS[coYHjl00WoYHjl00?o0000oj^C_On[Tkd02on[
Tkd00ol0003o/IVook6I_`07ok6I_`03o`000?nnX[co_Z:l00;o_Z:l00?o0000olJZ_Oo6Z[d01?o6
Z[d00ol0003oaZZmolJZ_@07olJZ_@03o`000?o=/l3ocK?000KocK?000?o0000omRh^OoH^;T02?oH
^;T00ol0003og/2jomk0^P07omk0^P03o`000?oU`[?oiL:c00_oiL:c00?o0000ooooooooool0Iooo
ool002oooooo00?o0000ooooooooool03Oooool00ol0003oIJ7bofFQlP05ofFQlP03o`000?meU^Go
MIKU00?oMIKU4_l00005ohR:cP03o`000?n?QlKoShO600SoShO600?o0000oiF7`_nEQl801onEQl80
0ol0003oVhRnoi^8_P09oi^8_P03o`000?nPR[coX8Zl00WoX8Zl00?o0000ojF>_?nUS[`02_nUS[`0
0ol0003oZi>moj^C_@0:oj^C_@03o`000?naVKoo/IVo00Ko/IVo00?o0000okjR_?nnX[`01?nnX[`0
0ol0003oaZZmolJZ_@03olJZ_@03o`000?o6Z[goaZZm00OoaZZm00?o0000olfc`?o=/l001Oo=/l00
0ol0003of;RiomRh^@0:omRh^@03o`000?oN`;[og/2j00Kog/2j00?o0000onG2/ooU`[<02ooU`[<0
0ol0003oooooooooo`1Wooooo`00;oooool00ol0003oooooooooo`0>ooooo`03o`000?mUXO;oIJ7b
00GoIJ7b00?o0000ogFFiOmeU^D01_meU^D00ol0003oP8oHoh2?f006oh2?f003o`000?n8R/koR8[>
00SoR8[>00?o0000ohn7a_n?QlH01on?QlH00ol0003oUHO2oiF7`P08oiF7`P03o`000?nKR;koVhRn
00SoVhRn00?o0000oj2:_?nPR[`02_nPR[`00ol0003oYHjlojF>_009ojF>_003o`000?n[TkgoZi>m
00_oZi>m00?o0000ok6I_onaVKl01?naVKl00ol0003o_Z:lokjR_005okjR_003o`000?o6Z[goaZZm
00?oaZZm00?o0000olJZ_Oo6Z[d02?o6Z[d00ol0003ocK?0olfc`003olfc`003o`000?oH^;Wof;Ri
00_of;Ri00?o0000omk0^_oN`;X01OoN`;X00ol0003oiL:conG2/`0=onG2/`03o`000?oooooooooo
06Kooooo000_ooooo`03o`000?oooooooooo00oooooo00?o0000ofFQl_mUXO801OmUXO800ol0003o
MIKUogFFi@06ogFFi@03o`000?n0SmSoP8oH00KoP8oH00?o0000ohR:c_n8R/h01on8R/h00ol0003o
ShO6ohn7aP07ohn7aP03o`000?nEQl;oUHO200SoUHO200?o0000oi^8__nKR;h02?nKR;h00ol0003o
X8Zloj2:_00:oj2:_003o`000?nUS[coYHjl00WoYHjl00?o0000oj^C_On[Tkd02on[Tkd00ol0003o
/IVook6I_`03ok6I_`03o`000?nnX[co_Z:l00Oo_Z:l00?o0000olJZ_Oo6Z[d00_o6Z[d00ol0003o
aZZmolJZ_@09olJZ_@03o`000?o=/l3ocK?000;ocK?000?o0000omRh^OoH^;T03?oH^;T00ol0003o
g/2jomk0^P04omk0^P03o`000?oU`[?oiL:c00koiL:c00?o0000ooooooooool0IOooool002kooooo
0ol0000Aooooo`03o`000?mUXO;oIJ7b00GoIJ7b00?o0000ogFFiOmeU^D01OmeU^D00ol0003oP8oH
oh2?f006oh2?f003o`000?n8R/koR8[>00OoR8[>00?o0000ohn7a_n?QlH02?n?QlH00ol0003oUHO2
oiF7`P07oiF7`P03o`000?nKR;koVhRn00WoVhRn00?o0000oj2:_?nPR[`02OnPR[`00ol0003oYHjl
ojF>_00:ojF>_003o`000?n[TkgoZi>m00_oZi>m00Go0000ok6I_onaVKoo/IVoo`00000:okjR_003
o`000?o6Z[goaZZm00;oaZZm00?o0000olJZ_Oo6Z[d02Oo6Z[d01Ol0003ocK?0olfc`?o=/l3o0000
013of;Ri00?o0000omk0^_oN`;X00_oN`;X00ol0003oiL:conG2/`0?onG2/`;o0000I_ooool002oo
oooo00?o0000ooooooooool04Oooool00ol0003oIJ7bofFQlP04ofFQlP03o`000?meU^GoMIKU00Ko
MIKU00?o0000oh2?f?n0SmP01_n0SmP00ol0003oR8[>ohR:cP07ohR:cP03o`000?n?QlKoShO600Oo
ShO600?o0000oiF7`_nEQl802?nEQl800ol0003oVhRnoi^8_P08oi^8_P03o`000?nPR[coX8Zl00[o
X8Zl00?o0000ojF>_?nUS[`02OnUS[`00ol0003oZi>moj^C_@0;oj^C_@04o`000?naVKoo/IVoo`00
00co_Z:l00Go0000olJZ_Oo6Z[goaZZmo`00000<olJZ_@04o`000?o=/l3ocK?0o`00017of;Ri00Go
0000omk0^_oN`;[og/2jo`00000@onG2/`03o`000?oYa:oo000006Kooooo000_ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ofFQl_mUXO801?mUXO800ol0003oMIKUogFFi@05ogFFi@03o`000?n0
SmSoP8oH00KoP8oH00?o0000ohR:c_n8R/h01on8R/h00ol0003oShO6ohn7aP07ohn7aP03o`000?nE
Ql;oUHO200SoUHO200?o0000oi^8__nKR;h02?nKR;h00ol0003oX8Zloj2:_00:oj2:_003o`000?nU
S[coYHjl00WoYHjl00?o0000oj^C_On[Tkd02on[Tkd00ol0003o/IVoo`00000=okjR_005o`000?o6
Z[goaZZmolJZ_Ol000003?o6Z[d00ol0003ocK?0o`00000BomRh^@04o`000?oN`;[og/2jo`00017o
iL:c00Co0000onW4[ooYa:oo0000IOooool002oooooo00?o0000ooooooooool04oooool00ol0003o
IJ7bofFQlP04ofFQlP03o`000?meU^GoMIKU00GoMIKU00?o0000oh2?f?n0SmP01_n0SmP00ol0003o
R8[>ohR:cP07ohR:cP03o`000?n?QlKoShO600OoShO600?o0000oiF7`_nEQl801onEQl800ol0003o
VhRnoi^8_P09oi^8_P03o`000?nPR[coX8Zl00WoX8Zl00?o0000ojF>_?nUS[`02_nUS[`00ol0003o
Zi>moj^C_@0:oj^C_@;o00003_nnX[`01Ol0003oaZZmolJZ_Oo6Z[go000000goaZZm00?o0000omRh
^OoH^;T04_oH^;T00ol0003og/2jo`00000@onG2/`03o`000?oYa:oojLB_00;ojLB_00?o0000oooo
ooooool0H_ooool002oooooo00?o0000ooooooooool04oooool2o`0000GoIJ7b00?o0000ogFFiOme
U^D01_meU^D00ol0003oP8oHoh2?f005oh2?f003o`000?n8R/koR8[>00OoR8[>00?o0000ohn7a_n?
QlH01on?QlH00ol0003oUHO2oiF7`P08oiF7`P03o`000?nKR;koVhRn00SoVhRn00?o0000oj2:_?nP
R[`02_nPR[`00ol0003oYHjlojF>_009ojF>_003o`000?n[TkgoZi>m00WoZi>m00?o0000okJK_?l0
00003onnX[`01?l0003oaZZmolJZ_Ol0000=olJZ_@03o`000?oH^;Wof;Ri01?of;Ri00?o0000onG2
/ooU`[<03ooU`[<00ol0003ojLB_onW4[`02onW4[`;o0000Hoooool002kooooo00?o0000oooooooo
ool05Oooool2o`0000GoIJ7b00?o0000ogFFiOmeU^D01OmeU^D00ol0003oP8oHoh2?f005oh2?f003
o`000?n8R/koR8[>00OoR8[>00?o0000ohn7a_n?QlH02?n?QlH00ol0003oUHO2oiF7`P07oiF7`P03
o`000?nKR;koVhRn00SoVhRn00?o0000oj2:_?nPR[`02_nPR[`00ol0003oYHjlojF>_00:ojF>_003
o`000?n[TkgoZi>m00OoZi>m00Go0000okJK_?nfVkco]Y^lo`00000>okjR_004o`000?o6Z[goaZZm
o`0000coaZZm00?o0000om:a^Ol000005?oH^;T00ol0003oiL:conG2/`0>onG2/`03o`000?oYa:oo
jLB_00CojLB_00?o0000ooooooooool0HOooool002kooooo0ol0000Fooooo`;o00001OmUXO800ol0
003oMIKUogFFi@05ogFFi@03o`000?n0SmSoP8oH00GoP8oH00?o0000ohR:c_n8R/h01on8R/h00ol0
003oShO6ohn7aP07ohn7aP03o`000?nEQl;oUHO200SoUHO200?o0000oi^8__nKR;h02?nKR;h00ol0
003oX8Zloj2:_009oj2:_003o`000?nUS[coYHjl00[oYHjl00?o0000oj^C_On[Tkd01On[Tkd2o`00
00Co]Y^l00?o0000okjR_?nnX[`03OnnX[`00ol0003oaZZmo`00000;olJZ_@04o`000?oB/KWod[6i
o`0001?of;Ri00?o0000on2m]?l000003ooU`[<00ol0003ojLB_onW4[`05onW4[`03o`000?oooooo
oooo063ooooo000^ooooo`03o`000?oooooooooo01Oooooo0_l00005ofFQlP03o`000?meU^GoMIKU
00CoMIKU00?o0000oh2?f?n0SmP01On0SmP00ol0003oR8[>ohR:cP07ohR:cP03o`000?n?QlKoShO6
00OoShO600?o0000oiF7`_nEQl802?nEQl800ol0003oVhRnoi^8_P08oi^8_P03o`000?nPR[coX8Zl
00[oX8Zl00?o0000ojF>_?nUS[`02OnUS[`00ol0003oZi>moj^C_@04oj^C_@03o`000?nfVkco]Y^l
00Go]Y^l00?o0000okjR_?nnX[`03?nnX[`00ol0003oaZZmo`00000:olJZ_@03o`000?oB/KWod[6i
00;od[6i00?o0000omRh^OoH^;T04?oH^;T01?l0003oh;fdon2m]?l0000=onG2/`03o`000?oYa:oo
jLB_00OojLB_00?o0000ooooooooool0Goooool001;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool5o`0000Oooooo00?o0000ooooooooool06?ooool2o`0000CoIJ7b00?o0000
ogFFiOmeU^D01OmeU^D00ol0003oP8oHoh2?f005oh2?f003o`000?n8R/koR8[>00OoR8[>00?o0000
ohn7a_n?QlH01on?QlH00ol0003oUHO2oiF7`P07oiF7`P03o`000?nKR;koVhRn00WoVhRn00?o0000
oj2:_?nPR[`02OnPR[`00ol0003oYHjlojF>_00:ojF>_004o`000?n[TkgoZi>moj^C_@;o00002?nf
Vk`00ol0003o_Z:lokjR_00=okjR_0;o00002_o6Z[d00ol0003od[6iom:a^@02om:a^@03o`000?oH
^;Wof;Ri00oof;Ri00Go0000on2m]?oP_KCoh;fdo`00000=onG2/`03o`000?oYa:oojLB_00SojLB_
00?o0000ooooooooool0G_ooool001;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o0000ooooooooool06Oooool3o`0000?o
IJ7b00?o0000ogFFiOmeU^D01?meU^D00ol0003oP8oHoh2?f005oh2?f003o`000?n8R/koR8[>00Oo
R8[>00?o0000ohn7a_n?QlH01on?QlH00ol0003oUHO2oiF7`P08oiF7`P03o`000?nKR;koVhRn00So
VhRn00?o0000oj2:_?nPR[`02_nPR[`00ol0003oYHjlojF>_009ojF>_004o`000?n[TkgoZi>mo`00
00[o]Y^l00?o0000okjR_?nnX[`03OnnX[`2o`0000WoaZZm00?o0000om:a^OoB/KT01?oB/KT00ol0
003of;RiomRh^@0=omRh^@03o`000?oP_KCoh;fd00?oh;fd00?o0000onG2/ooU`[<02OoU`[<00ol0
003ojLB_onW4[`09onW4[`03o`000?oooooooooo05kooooo000Booooo`05oa0@4?oooooooooooooo
ool@41003?ooool00onHV9So8B4Qonk^kP08ooooo`03o`000?oooooooooo01[ooooo00Co0000o`1F
col0003o00000_mUXO800ol0003oMIKUogFFi@04ogFFi@03o`000?n0SmSoP8oH00GoP8oH00?o0000
ohR:c_n8R/h01_n8R/h00ol0003oShO6ohn7aP07ohn7aP03o`000?nEQl;oUHO200SoUHO200?o0000
oi^8__nKR;h02?nKR;h00ol0003oX8Zloj2:_00:oj2:_003o`000?nUS[coYHjl00WoYHjl00?o0000
oj^C_Ol000003?nfVk`00ol0003o_Z:lokjR_00<okjR_0;o00002?o6Z[d00ol0003od[6iom:a^@06
om:a^@03o`000?oH^;Wof;Ri00cof;Ri00?o0000on2m]?oP_K@00ooP_K@00ol0003oiL:conG2/`09
onG2/`03o`000?oYa:oojLB_00[ojLB_00?o0000ooooooooool0GOooool001;ooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool06oooool0
0ol0003o05K?o`1Fc`03o`0000KoMIKU00?o0000oh2?f?n0SmP01On0SmP00ol0003oR8[>ohR:cP07
ohR:cP03o`000?n?QlKoShO600OoShO600?o0000oiF7`_nEQl801onEQl800ol0003oVhRnoi^8_P09
oi^8_P03o`000?nPR[coX8Zl00WoX8Zl00?o0000ojF>_?nUS[`02OnUS[`2o`0000go]Y^l00?o0000
okjR_?nnX[`03OnnX[`00ol0003oaZZmolJZ_@05olJZ_@03o`000?oB/KWod[6i00Ood[6i00?o0000
omRh^OoH^;T02ooH^;T00ol0003oh;fdon2m]005on2m]003o`000?oU`[?oiL:c00SoiL:c00?o0000
onW4[ooYa:l02ooYa:l00ol0003oooooooooo`1Looooo`004_ooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool01_ooool00ol0003oooooooooo`0Looooo`04o`000?l0E/oo
05K?o`1Fc`;o00001_meU^D00ol0003oP8oHoh2?f005oh2?f003o`000?n8R/koR8[>00KoR8[>00?o
0000ohn7a_n?QlH01on?QlH00ol0003oUHO2oiF7`P08oiF7`P03o`000?nKR;koVhRn00SoVhRn00?o
0000oj2:_?nPR[`02_nPR[`00ol0003oYHjlojF>_007ojF>_003o`000?n^UKgo000000ko]Y^l00?o
0000okjR_?nnX[`03?nnX[`00ol0003oaZZmolJZ_@05olJZ_@03o`000?oB/KWod[6i00Sod[6i00?o
0000omRh^OoH^;T02_oH^;T00ol0003oh;fdon2m]006on2m]003o`000?oU`[?oiL:c00KoiL:c00?o
0000onW4[ooYa:l03OoYa:l00ol0003oooooooooo`1Kooooo`004_ooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool01?ooool2o`0001oooooo00Co0000o`1Fcol0E/oo05K?
0_l00005ogFFi@03o`000?n0SmSoP8oH00GoP8oH00?o0000ohR:c_n8R/h01on8R/h00ol0003oShO6
ohn7aP07ohn7aP03o`000?nEQl;oUHO200OoUHO200?o0000oi^8__nKR;h02?nKR;h00ol0003oX8Zl
oj2:_00:oj2:_003o`000?nUS[coYHjl00GoYHjl0_l00003ojjE_@03o`000?nfVkco]Y^l00_o]Y^l
00?o0000okjR_?nnX[`03?nnX[`2o`0000GoaZZm00?o0000om:a^OoB/KT02OoB/KT00ol0003of;Ri
omRh^@09omRh^@03o`000?oP_KCoh;fd00Ooh;fd00?o0000onG2/ooU`[<01_oU`[<00ol0003ojLB_
onW4[`0=onW4[`03o`000?oooooooooo05_ooooo000Booooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool07oooool00ol0003o
05K?o`1Fc`02o`1Fc`;o00001?meU^D00ol0003oP8oHoh2?f005oh2?f003o`000?n8R/koR8[>00Ko
R8[>00?o0000ohn7a_n?QlH01on?QlH00ol0003oUHO2oiF7`P07oiF7`P03o`000?nKR;koVhRn00Wo
VhRn00?o0000oj2:_?nPR[`02OnPR[`00ol0003oYHjlojF>_004ojF>_003o`000?n^UKgo[YFm00?o
[YFm00?o0000okJK_?nfVk`03?nfVk`00ol0003o_Z:lokjR_00;okjR_0;o00001?o6Z[d00ol0003o
d[6iom:a^@0;om:a^@03o`000?oH^;Wof;Ri00Oof;Ri00?o0000on2m]?oP_K@02OoP_K@00ol0003o
iL:conG2/`04onG2/`03o`000?oYa:oojLB_00gojLB_00?o0000onc6[?l00000G?ooool001;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0
003oooooooooo`0Pooooo`06o`000?l0E/oo05K?o`1Fcol0003o7FKI0_l00003ogFFi@03o`000?n0
SmSoP8oH00CoP8oH00?o0000ohR:c_n8R/h01_n8R/h00ol0003oShO6ohn7aP07ohn7aP03o`000?nE
Ql;oUHO200SoUHO200?o0000oi^8__nKR;h02?nKR;h00ol0003oX8Zloj2:_00:oj2:_003o`000?nU
S[coYHjl00;oYHjl00?o0000ojjE_On^UKd01?n^UKd00ol0003o]Y^lokJK_00<okJK_003o`000?nn
X[co_Z:l00_o_Z:l00?o0000okjR_?l000000oo6Z[d00ol0003od[6iom:a^@0;om:a^@03o`000?oH
^;Wof;Ri00Oof;Ri00?o0000on2m]?oP_K@02_oP_K@00ol0003oiL:conG2/`03onG2/`03o`000?oY
a:oojLB_00gojLB_00Co0000onc6[?o/aZco0000Foooool002gooooo00?o0000ooooooooool08Ooo
ool01Ol0003o05K?o`1Fcol0E/oo000000;o7FKI0_l000000omeU^Go0000oh2?f006oh2?f003o`00
0?n8R/koR8[>00KoR8[>00?o0000ohn7a_n?QlH01on?QlH00ol0003oUHO2oiF7`P07oiF7`P03o`00
0?nKR;koVhRn00SoVhRn00?o0000oj2:_?nPR[`02_nPR[`00ol0003oYHjlojF>_002o`0000So[YFm
00?o0000okJK_?nfVk`02onfVk`00ol0003o_Z:lokjR_00;okjR_003o`000?nnX[co000000;oaZZm
00?o0000om:a^OoB/KT03OoB/KT00ol0003of;RiomRh^@05omRh^@03o`000?oP_KCoh;fd00_oh;fd
00?o0000onG2/ooU`[<00_oU`[<00ol0003ojLB_onW4[`0>onW4[`05o`000?o/aZcok<J/onc6[?l0
0000F_ooool002gooooo00?o0000ooooooooool08Oooool00ol0003o05K?o`1Fc`02o`1Fc`07o`00
0?lMI]Wo7FKIoaeVfOl0003oMIKUo`000006oh2?f003o`000?n8R/koR8[>00KoR8[>00?o0000ohn7
a_n?QlH01on?QlH00ol0003oUHO2oiF7`P08oiF7`P03o`000?nKR;koVhRn00SoVhRn00?o0000oj2:
_?nPR[`02OnPR[`00ol0003oYHjlo`00000:ojjE_@03o`000?nfVkco]Y^l00co]Y^l00?o0000okjR
_?nnX[`02_nnX[`01Ol0003o_Z:lo`000?o6Z[go0000013od[6i00?o0000omRh^OoH^;T01OoH^;T0
0ol0003oh;fdon2m]00<on2m]005o`000?oU`[?oiL:conG2/ol000003ooYa:l00ol0003ok<J/onc6
[002onc6[003o`000?oooooooooo05Sooooo000]ooooo`03o`000?oooooooooo02;ooooo00Go0000
o`1Fcol0E/oo05K?o`000004oaeVf@;o00001_n0SmP00ol0003oR8[>ohR:cP07ohR:cP03o`000?n?
QlKoShO600KoShO600?o0000oiF7`_nEQl802?nEQl800ol0003oVhRnoi^8_P08oi^8_P03o`000?nP
R[coX8Zl00WoX8Zl0_l0000<ojjE_@03o`000?nfVkco]Y^l00_o]Y^l00?o0000okjR_?nnX[`02_nn
X[`01?l0003o_Z:lokjR_?l0000Bom:a^@03o`000?oH^;Wof;Ri00?of;Ri00?o0000on2m]?oP_K@0
3OoP_K@01?l0003oiL:conG2/ol0000@onW4[`03o`000?o/aZcok<J/00?ok<J/00?o0000oooooooo
ool0Eoooool002cooooo0ol0000Tooooo`05o`000?l0E/oo05K?o`1Fcol000001OlMI]T2o`0000Go
P8oH00?o0000ohR:c_n8R/h01_n8R/h00ol0003oShO6ohn7aP07ohn7aP03o`000?nEQl;oUHO200Oo
UHO200?o0000oi^8__nKR;h02?nKR;h00ol0003oX8Zloj2:_007oj2:_0;o000000?oY8noo`000?n^
UKd02on^UKd00ol0003o]Y^lokJK_00<okJK_003o`000?nnX[co_Z:l00Wo_Z:l00Co0000okjR_?nn
X[co00004ooB/KT00ol0003of;RiomRh^@02omRh^@03o`000?oP_KCoh;fd00koh;fd00?o0000onG2
/ol000003ooYa:l00ol0003ok<J/onc6[005onc6[003o`000?oooooooooo05Kooooo000]ooooo`03
o`000?oooooooooo02Cooooo00Go0000o`1Fcol0E/oo05K?o`000004oaeVf@04o`000?m5L=So0000
o`0000?oP8oH00?o0000ohR:c_n8R/h01_n8R/h00ol0003oShO6ohn7aP07ohn7aP03o`000?nEQl;o
UHO200SoUHO200?o0000oi^8__nKR;h02?nKR;h00ol0003oX8Zloj2:_003oj2:_0?o00001?nTSkl0
0ol0003o[YFmojjE_@09ojjE_@03o`000?nfVkco]Y^l00co]Y^l00?o0000okjR_?nnX[`02OnnX[`0
1Ol0003o_Z:lo`000?o:Zk[o000001;od[6i00Go0000omRh^OoH^;Wof;Rio`00000Bon2m]003o`00
0?oYa:oojLB_00kojLB_00?o0000onc6[?o/aZ`01_o/aZ`00ol0003oooooooooo`1Eooooo`00;Ooo
ool00ol0003oooooooooo`0Uooooo`05o`000?l0E/oo05K?o`1Fcol000001?lMI]T00ol0003oAG3H
odE`f003o`000003oh2?f?l0003oR8[>00OoR8[>00?o0000ohn7a_n?QlH01on?QlH00ol0003oUHO2
oiF7`P07oiF7`P03o`000?nKR;koVhRn00SoVhRn00Co0000oj2:_?nPR[coX8Zl0_l00007ojB?_`03
o`000?n^UKgo[YFm00[o[YFm00?o0000okJK_?nfVk`03?nfVk`00ol0003o_Z:lokjR_008okjR_0;o
00000_o:ZkX00ol0003od[6iom:a^@0Aom:a^@03o`000?oH^;Wo000001?oh;fd00?o0000onW4[ooY
a:l03_oYa:l00ol0003ok<J/onc6[006onc6[0;o0000E_ooool002gooooo00?o0000ooooooooool0
9_ooool01?l0003o05K?o`1Fcol00004oaeVf@03o`000?m5L=SoAG3H00?oAG3H0_l00008ohR:cP03
o`000?n?QlKoShO600OoShO600?o0000oiF7`_nEQl801onEQl800ol0003oVhRnoi^8_P08oi^8_P04
o`000?nPR[co0000o`0000WoY8no00?o0000ojjE_On^UKd02_n^UKd00ol0003o]Y^lokJK_00<okJK
_003o`000?nnX[co_Z:l00So_Z:l00?o0000olZ[^_o:ZkX00_o:ZkX00ol0003od[6iom:a^@0@om:a
^@03o`000?oH^;Wo000001;oh;fd00?o0000onK1/?l000003_oYa:l00ol0003ok<J/onc6[008onc6
[003o`000?oooooooooo05Cooooo000/ooooo`03o`000?oooooooooo02Sooooo0_l000000ol0E/oo
0000oaeVf@03oaeVf@03o`000?m5L=SoAG3H00CoAG3H0ol00006ohR:cP03o`000?n?QlKoShO600Ko
ShO600?o0000oiF7`_nEQl802?nEQl800ol0003oVhRnoi^8_P06oi^8_P?o00003?nTSkl00ol0003o
[YFmojjE_@09ojjE_@03o`000?nfVkco]Y^l00co]Y^l00?o0000okjR_?nnX[`02?nnX[`00ol0003o
bZ^jolZ[^P02olZ[^P03o`000?oB/KWod[6i017od[6i00?o0000on2m]?oP_K@04OoP_K@01?l0003o
i/6`onK1/?l0000=onW4[`03o`000?o/aZcok<J/00Wok<J/00?o0000ooooooooool0Doooool002co
oooo00?o0000ooooooooool0:Oooool2o`000003o`1Fcol0003o7FKI00?o7FKI00?o0000odE`f?m5
L=P00om5L=P00ol0003oI7SBofAhdP03o`0000?oR8[>00?o0000ohn7a_n?QlH01on?QlH00ol0003o
UHO2oiF7`P07oiF7`P03o`000?nKR;koVhRn00?oVhRn0ol00002oiV9`P03o`000?nTSkooY8no00[o
Y8no00?o0000ojjE_On^UKd02_n^UKd00ol0003o]Y^lokJK_00<okJK_003o`000?nnX[co_Z:l00Ko
_Z:l0_l00005olZ[^P03o`000?oB/KWod[6i013od[6i00?o0000on2m]?oP_K@04?oP_K@00ol0003o
i/6`onK1/002onK1/003o`000?oYa:oojLB_00WojLB_00?o0000onc6[?o/aZ`02oo/aZ`00ol0003o
ooooooooo`1Booooo`00;?ooool2o`0002_ooooo0ol00004oaeVf@03o`000?m5L=SoAG3H00CoAG3H
00?o0000ofAhd_mTN=800_mTN=84o`0000WoShO600?o0000oiF7`_nEQl801onEQl800ol0003oVhRn
oi^8_P03o`0000KoVHW200?o0000ojB?_onTSkl02OnTSkl00ol0003o[YFmojjE_@0:ojjE_@03o`00
0?nfVkco]Y^l00co]Y^l00?o0000okjR_?nnX[`01OnnX[`00ol0003obZ^jo`000005olZ[^P03o`00
0?oB/KWod[6i00ood[6i00?o0000om^h]_l000004OoP_K@00ol0003oi/6`onK1/002onK1/003o`00
0?oYa:oojLB_00WojLB_00?o0000onc6[?o/aZ`02oo/aZ`2o`0005?ooooo000/ooooo`03o`000?oo
oooooooo02_ooooo0ol00004oaeVf@03o`000?m5L=SoAG3H00?oAG3H00?o0000ofAhd_mTN=801OmT
N=87o`0000?oShO600?o0000oiF7`_nEQl800onEQl87o`0000WoVHW200?o0000ojB?_onTSkl02_nT
Skl00ol0003o[YFmojjE_@0:ojjE_@03o`000?nfVkco]Y^l00co]Y^l00?o0000okjR_?nnX[`00onn
X[`01?l0003obZ^jolZ[^_l00006olZ[^P03o`000?oB/KWod[6i00kod[6i00?o0000om^h]_l00000
4?oP_K@00ol0003oi/6`onK1/004onK1/003o`000?oYa:oojLB_00SojLB_00?o0000onc6[?o/aZ`0
3?o/aZ`00ol0003oooooooooo`1Aooooo`00;?ooool00ol0003oooooooooo`0/ooooo`?o00000olM
I]T00ol0003oAG3HodE`f004odE`f003o`000?mTN=;oI7SB00GoI7SB00?o0000ogYnc?mjO/`00omj
O/`9o`0000GoRhC600?o0000oiV9`_nIRL802?nIRL800ol0003oY8noojB?_`0:ojB?_`03o`000?n^
UKgo[YFm00[o[YFm00?o0000okJK_?nfVk`03?nfVk`00ol0003o_Z:lokjR_002okjR_005o`000?o:
Zk[obZ^jolZ[^_l000001_o:ZkX00ol0003od[6iom:a^@0=om:a^@05o`000?oK^;KofkRfom^h]_l0
00003ooP_K@00ol0003oi/6`onK1/005onK1/003o`000?oYa:oojLB_00KojLB_00?o0000onc6[?o/
aZ`03?o/aZ`00ol0003ok/N[o`00001Booooo`00;?ooool00ol0003oooooooooo`0]ooooo`?o0000
0olMI]T00ol0003oAG3HodE`f003odE`f003o`000?mTN=;oI7SB00KoI7SB00?o0000ogYnc?mjO/`0
1_mjO/`00ol0003oRhC6oh^4aP08oh^4aP03o`000?nIRL;oVHW200SoVHW200?o0000ojB?_onTSkl0
2OnTSkl00ol0003o[YFmojjE_@0:ojjE_@03o`000?nfVkco]Y^l00go]Y^l00Go0000okjR_?nnX[co
_Z:lo`000003olZ[^P03o`000?o:Zk[obZ^j00GobZ^j00?o0000om:a^OoB/KT02ooB/KT00ol0003o
fkRfom^h]P03om^h]P03o`000?oP_KCoh;fd00coh;fd00?o0000onK1/?oV`K001_oV`K000ol0003o
jLB_onW4[`05onW4[`03o`000?o/aZcok<J/00cok<J/00Co0000onk7Zoo^aj_o0000DOooool002co
oooo00?o0000ooooooooool0;_ooool2o`0000?o7FKI00?o0000odE`f?m5L=P01?m5L=P00ol0003o
I7SBofAhdP05ofAhdP03o`000?mjO/coNWk<00OoNWk<00?o0000oh^4a_n;Q<H01on;Q<H00ol0003o
VHW2oiV9`P08oiV9`P03o`000?nTSkooY8no00[oY8no00?o0000ojjE_On^UKd02_n^UKd00ol0003o
]Y^lokJK_00<okJK_004o`000?nnX[co_Z:lo`0000CobZ^j00?o0000olZ[^_o:ZkX01Oo:ZkX00ol0
003od[6iom:a^@0;om:a^@03o`000?oK^;KofkRf00?ofkRf00?o0000on2m]?oP_K@02ooP_K@00ol0
003oi/6`onK1/007onK1/003o`000?oYa:oojLB_00GojLB_00?o0000onc6[?o/aZ`03?o/aZ`00ol0
003ok/N[onk7Z`02o`00053ooooo000/ooooo`03o`000?oooooooooo02oooooo0_l00003oaeVf@03
o`000?m5L=SoAG3H00?oAG3H00?o0000ofAhd_mTN=801_mTN=800ol0003oNWk<ogYnc006ogYnc003
o`000?n;Q<KoRhC600OoRhC600?o0000oiV9`_nIRL802?nIRL800ol0003oY8noojB?_`0:ojB?_`03
o`000?n^UKgo[YFm00[o[YFm00?o0000okJK_?nfVk`03?nfVk`00ol0003o_Z:lo`000005olZ[^P03
o`000?o:Zk[obZ^j00KobZ^j00?o0000om:a^OoB/KT02OoB/KT00ol0003ofkRfom^h]P05om^h]P03
o`000?oP_KCoh;fd00[oh;fd00?o0000onK1/?oV`K002?oV`K000ol0003ojLB_onW4[`03onW4[`03
o`000?o/aZcok<J/00cok<J/00?o0000onk7Zoo^aj/00_o^aj/00ol0003oooooooooo`1>ooooo`00
;?ooool2o`00037ooooo0_l00003oaeVf@03o`000?m5L=SoAG3H00?oAG3H00?o0000ofAhd_mTN=80
1OmTN=800ol0003oNWk<ogYnc006ogYnc003o`000?n;Q<KoRhC600SoRhC600?o0000oiV9`_nIRL80
2?nIRL800ol0003oY8noojB?_`09ojB?_`03o`000?n^UKgo[YFm00_o[YFm00?o0000okJK_?nfVk`0
3?nfVk`00ol0003obZ^jolZ[^P04olZ[^P03o`000?o:Zk[obZ^j00OobZ^j00?o0000om:a^OoB/KT0
2?oB/KT00ol0003ofkRfom^h]P05om^h]P03o`000?oP_KCoh;fd00Woh;fd00?o0000onK1/?oV`K00
2_oV`K000ol0003ojLB_onW4[`02onW4[`03o`000?o/aZcok<J/00cok<J/00?o0000onk7Zoo^aj/0
0oo^aj/00ol0003oooooooooo`1=ooooo`00:oooool00ol0003oooooooooo`0booooo`;o00000_lM
I]T00ol0003oAG3HodE`f003odE`f003o`000?mTN=;oI7SB00GoI7SB00?o0000ogYnc?mjO/`01omj
O/`00ol0003oRhC6oh^4aP07oh^4aP03o`000?nIRL;oVHW200SoVHW200?o0000ojB?_onTSkl02_nT
Skl00ol0003o[YFmojjE_@0:ojjE_@03o`000?nfVkco]Y^l00_o]Y^l0_l00006olZ[^P03o`000?o:
Zk[obZ^j00OobZ^j00?o0000om:a^OoB/KT01ooB/KT00ol0003ofkRfom^h]P07om^h]P03o`000?oP
_KCoh;fd00Soh;fd00?o0000onK1/?oV`K002_oV`K001Ol0003ojLB_onW4[ooYa:oo000000ook<J/
00?o0000onk7Zoo^aj/01?o^aj/00ol0003oooooooooo`1<ooooo`00:oooool00ol0003ooooooooo
o`0cooooo`;o00000_lMI]T00ol0003oAG3HodE`f003odE`f003o`000?mTN=;oI7SB00GoI7SB00?o
0000ogYnc?mjO/`01_mjO/`00ol0003oRhC6oh^4aP07oh^4aP03o`000?nIRL;oVHW200WoVHW200?o
0000ojB?_onTSkl02OnTSkl00ol0003o[YFmojjE_@0:ojjE_@03o`000?nfVkco]Y^l00[o]Y^l00Co
0000ol6T_?o1Y;co00001Oo:ZkX00ol0003obZ^jolZ[^P08olZ[^P03o`000?oB/KWod[6i00Kod[6i
00?o0000om^h]_oK^;H02?oK^;H00ol0003oh;fdon2m]006on2m]003o`000?oV`K3oi/6`00coi/6`
00Co0000onW4[ooYa:oo00003_o/aZ`00ol0003ok/N[onk7Z`05onk7Z`;o0000COooool0013ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0=?ooool2o`000003oaeVfOl0003oAG3H00CoAG3H00?o0000ofAhd_mT
N=801OmTN=800ol0003oNWk<ogYnc006ogYnc003o`000?n;Q<KoRhC600SoRhC600?o0000oiV9`_nI
RL802?nIRL800ol0003oY8noojB?_`09ojB?_`03o`000?n^UKgo[YFm00_o[YFm00?o0000okJK_?nf
Vk`02?nfVk`01Ol0003o`JBlol6T_?o1Y;co000000GobZ^j00?o0000olZ[^_o:ZkX02?o:ZkX00ol0
003od[6iom:a^@05om:a^@03o`000?oK^;KofkRf00WofkRf00?o0000on2m]?oP_K@01_oP_K@00ol0
003oi/6`onK1/00=onK1/003o`000?oYa:oo000000kok<J/00?o0000onk7Zoo^aj/01_o^aj/2o`00
04cooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0dooooo`05o`000?l07:Ko0000oaeVfOl000001Om5L=P0
0ol0003oI7SBofAhdP05ofAhdP03o`000?mjO/coNWk<00KoNWk<00?o0000oh^4a_n;Q<H01on;Q<H0
0ol0003oVHW2oiV9`P08oiV9`P03o`000?nTSkooY8no00[oY8no00?o0000ojjE_On^UKd02_n^UKd0
0ol0003o]Y^lokJK_007okJK_003o`000?o1Y;co`JBl00?o`JBl00?o0000olZ[^_o:ZkX00_o:ZkX0
0ol0003obZ^jolZ[^P09olZ[^P03o`000?oB/KWod[6i00Cod[6i00?o0000om^h]_oK^;H02_oK^;H0
0ol0003oh;fdon2m]004on2m]003o`000?oV`K3oi/6`00ooi/6`00?o0000onc6[?o/aZ`03?o/aZ`0
0ol0003ok/N[onk7Z`08onk7Z`03o`000?oooooooooo04[ooooo000@ooooo`05oa0@4?oooooooooo
ooooool@41002oooool5o`0000Kooooo00?o0000ooooooooool0=Oooool01?l0003o01bVo`000?l0
0005odE`f003o`000?mTN=;oI7SB00GoI7SB00?o0000ogYnc?mjO/`01_mjO/`00ol0003oRhC6oh^4
aP07oh^4aP03o`000?nIRL;oVHW200WoVHW200?o0000ojB?_onTSkl02OnTSkl00ol0003o[YFmojjE
_@0:ojjE_@03o`000?nfVkco]Y^l00Ko]Y^l00?o0000ol6T_?o1Y;`01?o1Y;`00ol0003obZ^jolZ[
^P02olZ[^P03o`000?o:Zk[obZ^j00WobZ^j00?o0000om:a^OoB/KT00ooB/KT00ol0003ofkRfom^h
]P0;om^h]P03o`000?oP_KCoh;fd00Coh;fd00?o0000onK1/?oV`K003ooV`K000ol0003ok<J/onc6
[00<onc6[003o`000?o^aj_ok/N[00Wok/N[00?o0000ooooooooool0BOooool0013ooooo00Go0000
ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0
=_ooool01?l0003o01bVo`000?l00005odE`f003o`000?mTN=;oI7SB00GoI7SB00?o0000ogYnc?mj
O/`01_mjO/`00ol0003oRhC6oh^4aP07oh^4aP03o`000?nIRL;oVHW200SoVHW200?o0000ojB?_onT
Skl02OnTSkl00ol0003o[YFmojjE_@0;ojjE_@03o`000?nfVkco]Y^l00Co]Y^l00?o0000ol6T_?o1
Y;`01Oo1Y;`00ol0003obZ^jolZ[^P02olZ[^P03o`000?o:Zk[obZ^j00[obZ^j00Go0000om:a^OoB
/KWod[6io`00000?om^h]P03o`000?oP_KCoh;fd00;oh;fd00?o0000onK1/?oV`K003ooV`K000ol0
003ojlF^o`00000=onc6[003o`000?o^aj_ok/N[00Wok/N[0_l0001:ooooo`004?ooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0g
ooooo`04o`000?l07:Ko0000o`0000CoAG3H00?o0000ofAhd_mTN=801OmTN=800ol0003oNWk<ogYn
c006ogYnc003o`000?n;Q<KoRhC600OoRhC600?o0000oiV9`_nIRL802?nIRL800ol0003oY8noojB?
_`0:ojB?_`03o`000?n^UKgo[YFm00[o[YFm00?o0000okJK_?nfVk`00onfVk`00ol0003o`JBlol6T
_007ol6T_005o`000?o:Zk[obZ^jolZ[^_l000003?o:ZkX01Ol0003od[6iom:a^OoB/KWo000000oo
fkRf00?o0000on2m]?oP_K@00_oP_K@00ol0003oi/6`onK1/00?onK1/004o`000?o[aJkojlF^o`00
00_ok<J/00?o0000onk7Zoo^aj/02oo^aj/2o`0004Wooooo000@ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00omgMgOoc<c<o`000006ooooo`;o0000>Oooool01?l0003o01bVo`0LY_l00005
odE`f003o`000?mTN=;oI7SB00GoI7SB00?o0000ogYnc?mjO/`01OmjO/`00ol0003oRhC6oh^4aP07
oh^4aP03o`000?nIRL;oVHW200WoVHW200?o0000ojB?_onTSkl02OnTSkl00ol0003o[YFmojjE_@0;
ojjE_@05o`000?nfVkco]Y^lokJK_?l000002_o1Y;`01Ol0003obZ^jolZ[^_o:Zk[o000000gobZ^j
00?o0000om:a^Ol000004OoK^;H01Ol0003oh;fdon2m]?oP_KCo0000013oi/6`00?o0000on_5[_o[
aJh00_o[aJh00ol0003ok<J/onc6[008onc6[003o`000?o^aj_ok/N[00cok/N[00?o0000oooooooo
ool0Aoooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oo
oooo00?o0000ooooooooool0>?ooool00ol0003o01bVo`0LYP02o`0000?oAG3H00?o0000ofAhd_mT
N=801OmTN=800ol0003oNWk<ogYnc006ogYnc003o`000?n;Q<KoRhC600OoRhC600?o0000oiV9`_nI
RL802?nIRL800ol0003oY8noojB?_`09ojB?_`03o`000?n^UKgo[YFm00_o[YFm00Co0000okJK_?nf
Vkco00003?o1Y;`01?l0003obZ^jolZ[^_l0000=olZ[^P03o`000?oB/KWo000001;ofkRf00?o0000
on2m]?l000004OoV`K000ol0003ojlF^on_5[P02on_5[P03o`000?o/aZcok<J/00Sok<J/00?o0000
onk7Zoo^aj/02oo^aj/00ol0003oklZ/o`000018ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00gooooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`0jooooo`05o`000?l07:Ko
0000o`0o`_l000000om5L=P00ol0003oI7SBofAhdP04ofAhdP03o`000?mjO/coNWk<00KoNWk<00?o
0000oh^4a_n;Q<H01on;Q<H00ol0003oVHW2oiV9`P09oiV9`P03o`000?nTSkooY8no00WoY8no00?o
0000ojjE_On^UKd02_n^UKd00ol0003o]Y^lo`00000=ol6T_004o`000?o:Zk[obZ^jo`0000kobZ^j
00?o0000om^h]_oK^;H04OoK^;H00ol0003oh;fdo`00000AonK1/003o`000?o[aJkojlF^00?ojlF^
00?o0000onc6[?o/aZ`01_o/aZ`00ol0003ok/N[onk7Z`0<onk7Z`04o`000?o_bZco0000o`0004Oo
oooo000Zooooo`03o`000?oooooooooo03[ooooo00Ko0000o`0LY_l07:Ko0000o`0o`_l00002odE`
f003o`000?mTN=;oI7SB00GoI7SB00?o0000ogYnc?mjO/`01_mjO/`00ol0003oRhC6oh^4aP07oh^4
aP03o`000?nIRL;oVHW200SoVHW200?o0000ojB?_onTSkl02OnTSkl00ol0003o[YFmojjE_@0:ojjE
_@;o00003oo1Y;`00ol0003obZ^jo`00000>olZ[^P03o`000?oK^;KofkRf01;ofkRf00?o0000onK1
/?oV`K003ooV`K000ol0003ojlF^on_5[P05on_5[P03o`000?o/aZcok<J/00Gok<J/00?o0000onk7
Zoo^aj/03?o^aj/01?l0003oklZ/ono:[?l00017ooooo`00:_ooool00ol0003oooooooooo`0koooo
o`05o`000?l07:Ko01bVo`000?l0?l800_l000000om5L=So0000ofAhdP05ofAhdP03o`000?mjO/co
NWk<00KoNWk<00?o0000oh^4a_n;Q<H01on;Q<H00ol0003oVHW2oiV9`P08oiV9`P03o`000?nTSkoo
Y8no00WoY8no00?o0000ojjE_On^UKd02On^UKd00ol0003o]Yfoo`00000?ol6T_003o`000?o:Zk[o
000000gobZ^j00?o0000om>c^Ol000004ooK^;H00ol0003oi/6`onK1/00?onK1/003o`000?o[aJko
jlF^00GojlF^00?o0000onc6[?o/aZ`01?o/aZ`00ol0003ok/N[onk7Z`0<onk7Z`03o`000?o_bZco
klZ/00;oklZ/00?o0000ooooooooool0A?ooool002[ooooo00?o0000ooooooooool0??ooool00ol0
003o01bVo`000003o`0o`P;o00001omTN=800ol0003oNWk<ogYnc005ogYnc003o`000?n;Q<KoRhC6
00OoRhC600?o0000oiV9`_nIRL802OnIRL800ol0003oY8noojB?_`09ojB?_`03o`000?n^UKgo[YFm
00Oo[YFm00Go0000okJM_onfWKoo]Yfoo`00000?ol6T_0;o00003?o:ZkX01?l0003odk>iom>c^Ol0
000Bom^h]P03o`000?oR_[?o000000ooi/6`00?o0000on_5[_o[aJh01oo[aJh00ol0003ok<J/onc6
[003onc6[003o`000?o^aj_ok/N[00cok/N[00?o0000ono:[?o_bZ`00oo_bZ`00ol0003ooooooooo
o`13ooooo`00:Oooool3o`0003kooooo00?o0000o`0LY_l000000ol0?l82o`0000KoI7SB00?o0000
ogYnc?mjO/`01_mjO/`00ol0003oRhC6oh^4aP07oh^4aP03o`000?nIRL;oVHW200SoVHW200?o0000
ojB?_onTSkl02OnTSkl00ol0003o[YFmojjE_@05ojjE_@;o00001?nfWKl00ol0003o`JBlol6T_00=
ol6T_0;o00002oo:ZkX00ol0003odk>iom>c^@02om>c^@03o`000?oK^;KofkRf00oofkRf00Co0000
on:n/ooR_[?o00003_oV`K000ol0003ojlF^on_5[P08on_5[P03o`000?o/aZcok<J/00;ok<J/00?o
0000onk7Zoo^aj/02oo^aj/00ol0003oklZ/ono:[004ono:[0;o0000A?ooool002[ooooo00?o0000
ooooooooool0?Oooool00ol0003o01bVo`000004o`0o`P03o`000?mTN=;oI7SB00GoI7SB00?o0000
ogYnc?mjO/`01OmjO/`00ol0003oRhC6oh^4aP07oh^4aP03o`000?nIRL;oVHW200SoVHW200?o0000
ojB?_onTSkl02OnTSkl00ol0003o[YFmojjE_@04ojjE_@03o`000?nfWKoo]Yfo00Go]Yfo00?o0000
ol6T_?o1Y;`03?o1Y;`2o`0000_obZ^j00?o0000om>c^OoC/kT00_oC/kT00ol0003ofkRfom^h]P0>
om^h]P05o`000?oR_[?oh[jcon:n/ol000003OoV`K000ol0003ojlF^on_5[P0:on_5[P04o`000?o/
aZcok<J/o`0000kok/N[00?o0000ono:[?o_bZ`01Oo_bZ`00ol0003oooooooooo`12ooooo`00:_oo
ool00ol0003oooooooooo`0nooooo`03o`000?l07:Ko000000Co03o20_l00005ofAhdP03o`000?mj
O/coNWk<00GoNWk<00?o0000oh^4a_n;Q<H01on;Q<H00ol0003oVHW2oiV9`P09oiV9`P03o`000?nT
SkooY8no00WoY8no00Co0000ojjE_On^UKgo[YFm0_l00008okJM_`03o`000?o1Y;co`JBl00go`JBl
00?o0000olZ[^_o:ZkX02?o:ZkX00ol0003odk>iom>c^@04om>c^@03o`000?oK^;KofkRf00gofkRf
00?o0000on:n/ooR_[<00_oR_[<00ol0003oi/6`onK1/00:onK1/003o`000?o[aJkojlF^00[ojlF^
00Co0000onc6[?o/aZco00003_o^aj/00ol0003oklZ/ono:[006ono:[003o`000?oooooooooo047o
oooo000Zooooo`03o`000?oooooooooo03oooooo00?o0000o`0LY_l000000ol0?l801?l0003o;eg?
o`000?l00004ofAhdP03o`000?mjO/coNWk<00GoNWk<00?o0000oh^4a_n;Q<H01on;Q<H00ol0003o
VHW2oiV9`P08oiV9`P03o`000?nTSkooY8no00WoY8no00Co0000ojjE_On^UKgo00002_nfWKl00ol0
003o`JBlol6T_00=ol6T_003o`000?o:Zk[obZ^j00OobZ^j00?o0000om>c^OoC/kT01_oC/kT00ol0
003ofkRfom^h]P0;om^h]P03o`000?oR_[?oh[jc00Coh[jc00?o0000onK1/?oV`K002OoV`K000ol0
003ojlF^on_5[P0;on_5[P03o`000?o/aZco000000gok/N[00?o0000ono:[?o_bZ`02?o_bZ`00ol0
003oooooooooo`10ooooo`00:Oooool00ol0003oooooooooo`10ooooo`03o`000?l07:Ko000000Co
03o200Co0000obmMcol_GLoo00000omTN=800ol0003oNWk<ogYnc005ogYnc003o`000?n;Q<KoRhC6
00OoRhC600?o0000oiV9`_nIRL802OnIRL800ol0003oY8noojB?_`08ojB?_`03o`000?n^UKgo0000
00co]Yfo00?o0000ol6T_?o1Y;`03?o1Y;`2o`0000OobZ^j00?o0000om>c^OoC/kT01ooC/kT00ol0
003ofkRfom^h]P0;om^h]P03o`000?oR_[?oh[jc00Coh[jc00?o0000onK1/?oV`K002?oV`K000ol0
003ojlF^on_5[P0=on_5[P03o`000?o^aj_ok/N[00cok/N[00?o0000ono:[?o_bZ`02?o_bZ`00ol0
003oooooooooo`10ooooo`00:Oooool00ol0003oooooooooo`11ooooo`03o`000?l07:Ko000000?o
03o200Co0000obmMcol_GLoo;eg?0_l000000omTN=;o0000ogYnc007ogYnc003o`000?n;Q<KoRhC6
00KoRhC600?o0000oiV9`_nIRL802OnIRL800ol0003oY8noojB?_`08ojB?_`;o00003OnfWKl00ol0
003o`JBlol6T_00<ol6T_0;o00001oo:ZkX00ol0003odk>iom>c^@08om>c^@03o`000?oK^;KofkRf
00WofkRf00?o0000on:n/ooR_[<01_oR_[<00ol0003oi/6`onK1/007onK1/003o`000?o[aJkojlF^
00gojlF^00?o0000onk7Zoo^aj/02oo^aj/00ol0003oklZ/ono:[00:ono:[003o`000?oooooooooo
03oooooo000Yooooo`03o`000?oooooooooo04;ooooo00?o0000o`0LY_l000000ol0?l800ol0003o
;eg?obmMc`02obmMc`?o00001omjO/`00ol0003oRhC6oh^4aP07oh^4aP03o`000?nIRL;oVHW200So
VHW200?o0000ojB?_onTSkl01_nTSkl2o`000003ojRF`ol0003o]Yfo00go]Yfo00?o0000ol6T_?o1
Y;`02oo1Y;`00ol0003o`JBlo`000005olZ[^P03o`000?oC/kWodk>i00Wodk>i00?o0000om^h]_oK
^;H02OoK^;H00ol0003oh[jcon:n/`07on:n/`03o`000?oV`K3oi/6`00Goi/6`00?o0000on_5[_o[
aJh03Oo[aJh00ol0003ok/V]o`00000<onk7Z`03o`000?o_bZcoklZ/00_oklZ/00?o0000oooooooo
ool0?_ooool002Wooooo0_l00014ooooo`;o00000ol0?l800ol0003o;eg?obmMc`04obmMc`03o`00
0?mjO/coNWk<00GoNWk<00?o0000oh^4a_n;Q<H01on;Q<H00ol0003oVHW2oiV9`P09oiV9`P03o`00
0?nTSkooY8no00?oY8no0_l00004ojRF``03o`000?nfWKoo]Yfo00_o]Yfo00?o0000ol6T_?o1Y;`0
2oo1Y;`00ol0003o`JBlo`000004olZ[^P03o`000?oC/kWodk>i00_odk>i00?o0000om^h]_oK^;H0
1ooK^;H00ol0003oh[jcon:n/`09on:n/`03o`000?oV`K3oi/6`00Coi/6`00?o0000on_5[_o[aJh0
3Oo[aJh01?l0003ok/V]onk9[Ol0000;onk7Z`03o`000?o_bZcoklZ/00_oklZ/0_l0000oooooo`00
:Oooool00ol0003oooooooooo`14ooooo`;o00000ol0?l800ol0003o;eg?obmMc`04obmMc`?o0000
1OmjO/`00ol0003oRhC6oh^4aP06oh^4aP03o`000?nIRL;oVHW200WoVHW200Co0000ojB?_onTSkoo
Y8no0_l00006ojRF``03o`000?nfWKoo]Yfo00co]Yfo00?o0000ol6T_?o1Y;`02_o1Y;`00ol0003o
`JBlo`000004olZ[^P03o`000?oC/kWodk>i00_odk>i00?o0000om^h]_oK^;H01_oK^;H00ol0003o
h[jcon:n/`0:on:n/`03o`000?oV`K3oi/6`00?oi/6`00?o0000on_5[_o[aJh03Oo[aJh00ol0003o
k/V]onk9[@02onk9[@03o`000?o^aj_ok/N[00Ook/N[00?o0000ono:[?o_bZ`02oo_bZ`00ol0003o
klf_o`00000oooooo`00:Oooool00ol0003oooooooooo`15ooooo`;o00000ol0?l800ol0003o;eg?
obmMc`03obmMc`03o`000?mMLm3oGG?@00?o00000_mjO/`00ol0003oRhC6oh^4aP07oh^4aP03o`00
0?nIRL;oVHW200SoVHW200Co0000ojB?_ol0003o00002OnXU/<00ol0003o]YfookJM_`0;okJM_`03
o`000?o1Y;co`JBl00[o`JBl00Co0000ol6T_?o1Y;co00000_o:ZkX00ol0003odk>iom>c^@0=om>c
^@03o`000?oK^;KofkRf00GofkRf00?o0000on:n/ooR_[<02ooR_[<00ol0003oi/6`onK1/002onK1
/003o`000?o[aJkojlF^00gojlF^00?o0000onk9[Oo^bJd00oo^bJd00ol0003ok/N[onk7Z`06onk7
Z`03o`000?o_bZcoklZ/00_oklZ/00Co0000ono=[oo_cJoo0000?_ooool002Wooooo00?o0000oooo
ooooool0AOooool2o`0000?o03o200?o0000obmMcol_GLl01?l_GLl00ol0003oGG?@oeecd002oeec
d0?o00002On;Q<H00ol0003oVHW2oiV9`P06oiV9`PCo00002onXU/<00ol0003o]YfookJM_`0<okJM
_`03o`000?o1Y;co`JBl00Wo`JBl00Ko0000ol6T_?o1Y;co0000olZ[^_l0000@om>c^@03o`000?oK
^;KofkRf00CofkRf00?o0000on:n/ooR_[<03OoR_[<01Ol0003oi/6`onK1/?oV`K3o000000kojlF^
00?o0000onk9[Oo^bJd01Oo^bJd00ol0003ok/N[onk7Z`05onk7Z`03o`000?o_bZcoklZ/00[oklZ/
00?o0000ono=[oo_cJl00_o_cJl00ol0003oooooooooo`0kooooo`00:Oooool00ol0003ooooooooo
o`16ooooo`;o00000ol0?l800ol0003o;eg?obmMc`03obmMc`03o`000?mMLm3oGG?@00GoGG?@1_l0
0003oh^4aP04o`000?nIRL;oVHW2oiV9`PGo00000onGSLL00ol0003oZ9K3ojRF``09ojRF``03o`00
0?nfWKoo]Yfo00co]Yfo00?o0000ol6T_?o1Y;`02Oo1Y;`01Ol0003o`JBlol6T_?o1Y;co000001;o
dk>i00?o0000om^h]_oK^;H00ooK^;H00ol0003oh[jcon:n/`0=on:n/`04o`000?oV`K3oi/6`o`00
00oojlF^00?o0000onk9[Oo^bJd01Oo^bJd00ol0003ok/N[onk7Z`04onk7Z`03o`000?o_bZcoklZ/
00_oklZ/00?o0000ono=[oo_cJl00_o_cJl2o`0003cooooo000Yooooo`03o`000?oooooooooo04Oo
oooo00Go0000o`0o`_l0?l;o03o2o`000006obmMc`03o`000?mMLm3oGG?@00CoGG?@00?o0000ogn2
cOmoP/d00omoP/d7o`0000WoUhg700?o0000ojRF`onXU/<02OnXU/<00ol0003o]YfookJM_`0;okJM
_`03o`000?o1Y;co`JBl00Wo`JBl00Go0000ol6T_?o1Y;co`JBlo`00000Com>c^@05o`000?oK^;Ko
fkRfom^h]_l000004OoR_[<00ol0003oi/6`o`00000?on_5[P03o`000?o^bJgok/V]00Kok/V]00?o
0000onk7Zoo^aj/00oo^aj/00ol0003oklZ/ono:[00;ono:[003o`000?o_cJooklf_00?oklf_00?o
0000ooooooooool0>_ooool002Sooooo0ol00019ooooo`05o`000?l0?l;o03o2o`0o`_l000001Ol_
GLl00ol0003oGG?@oeecd005oeecd003o`000?moP/goOh;=00KoOh;=00?o0000oiN=aonGSLL02OnG
SLL00ol0003oZ9K3ojRF``09ojRF``03o`000?nfWKoo]Yfo00co]Yfo00?o0000ol6T_?o1Y;`02?o1
Y;`01_l0003o`JBlol6T_?l0003objjmo`0001;odk>i00Go0000om^h]_oK^;KofkRfo`00000Bon:n
/`03o`000?o[aJkojlF^00gojlF^00?o0000onk9[Oo^bJd02?o^bJd01Ol0003ok/N[onk7Zoo^aj_o
000000goklZ/00?o0000ono=[oo_cJl01Oo_cJl00ol0003oooooooooo`0iooooo`00:?ooool00ol0
003oooooooooo`1:ooooo`04o`000?l0?l;o03o2o`0000Go;eg?00?o0000oeecd?mMLm001OmMLm00
0ol0003oOh;=ogn2c@07ogn2c@03o`000?nGSLOoUhg700SoUhg700?o0000ojRF`onXU/<02_nXU/<0
0ol0003o]YfookJM_`0;okJM_`03o`000?o1Y;co`JBl00So`JBl00?o0000ol6T_?l000000_o;[[d0
0ol0003odk>iom>c^@0Aom>c^@03o`000?oK^;Ko000001?oh[jc00?o0000on_5[_o[aJh03Oo[aJh0
0ol0003ok/V]onk9[@09onk9[@04o`000?o^aj_ok/N[o`0000goklZ/00?o0000ono=[oo_cJl01_o_
cJl00ol0003oooooooooo`0hooooo`003?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01oooool00ol0003oooooooooo`1:ooooo`05o`00
0?l0?l;o03o2o`0o`_l000001Ol_GLl00ol0003oGG?@oeecd005oeecd003o`000?moP/goOh;=00Ko
Oh;=00?o0000oiN=aonGSLL02OnGSLL00ol0003oZ9K3ojRF``09ojRF``03o`000?nfWKoo]Yfo00co
]Yfo00?o0000ol6T_?o1Y;`01oo1Y;`2o`0000Cobjjm00?o0000om>c^OoC/kT04?oC/kT00ol0003o
fkRfo`00000Bon:n/`03o`000?oXa;;o000000gojlF^00?o0000onk9[Oo^bJd02oo^bJd00ol0003o
k/N[o`00000<ono:[003o`000?o_cJooklf_00Ooklf_0_l0000iooooo`003?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401oooool00ol0
003oooooooooo`1;ooooo`04o`000?l0?l;o03o2o`0000Go;eg?00?o0000oeecd?mMLm001OmMLm00
0ol0003oOh;=ogn2c@07ogn2c@03o`000?nGSLOoUhg700SoUhg700?o0000ojRF`onXU/<02_nXU/<0
0ol0003o]YfookJM_`0;okJM_`03o`000?o1Y;co`JBl00Ko`JBl0ol00004ol^^_@03o`000?oC/kWo
dk>i017odk>i00?o0000on:n/ooR_[<04OoR_[<01?l0003oj<BbonS4/_l0000<on_5[P03o`000?o^
bJgok/V]00cok/V]00?o0000ono:[?o_bZ`02oo_bZ`00ol0003oklf_ono=[`08ono=[`03o`000?oo
oooooooo03Oooooo000<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooooooool0C?ooool01?l0003o03o2o`0o`_l00005obmMc`03
o`000?mMLm3oGG?@00CoGG?@00?o0000ogn2cOmoP/d01omoP/d00ol0003oUhg7oiN=a`08oiN=a`03
o`000?nXU/?oZ9K300[oZ9K300?o0000okJM_onfWKl03?nfWKl00ol0003o`JBlol6T_002ol6T_0?o
000000?o`JBlo`000?o;[[d01Oo;[[d00ol0003odk>iom>c^@0@om>c^@03o`000?oR_[?oh[jc013o
h[jc00?o0000onS4/_oXa;800_oXa;800ol0003ojlF^on_5[P08on_5[P03o`000?o^bJgok/V]00go
k/V]00?o0000ono:[?o_bZ`02_o_bZ`00ol0003oklf_ono=[`0:ono=[`03o`000?oooooooooo03Ko
oooo000<ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q
00Oooooo00?o0000ooooooooool0C?ooool2o`000003o`0o`_l0003o;eg?00Co;eg?00?o0000oeec
d?mMLm001OmMLm000ol0003oOh;=ogn2c@06ogn2c@03o`000?nGSLOoUhg700WoUhg700?o0000ojRF
`onXU/<02OnXU/<00ol0003o]YfookJM_`0<okJM_`03o`000?o1Y;co000000;o00000oo1Y;`00ol0
003objjmo`000005ol^^_@03o`000?oC/kWodk>i00oodk>i00?o0000ombk^?l000004OoR_[<00ol0
003oj<BbonS4/P02onS4/P03o`000?o[aJkojlF^00SojlF^00?o0000onk9[Oo^bJd03?o^bJd00ol0
003ol<j^o`00000;ono:[003o`000?o_cJooklf_00_oklf_00?o0000ooooooooool0=Oooool000co
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01oooool0
0ol0003oooooooooo`1=ooooo`;o000000?o03o2o`000?l_GLl01?l_GLl00ol0003oGG?@oeecd004
oeecd003o`000?moP/goOh;=00OoOh;=00?o0000oiN=aonGSLL02?nGSLL00ol0003oZ9K3ojRF``0:
ojRF``03o`000?nfWKoo]Yfo00[o]Yfo0ol00005ol6T_005o`000?o;[[gobjjmol^^_Ol000001Oo;
[[d00ol0003odk>iom>c^@0>om>c^@04o`000?oL^kSog;^ho`0000ooh[jc00?o0000onS4/_oXa;80
1?oXa;800ol0003ojlF^on_5[P06on_5[P03o`000?o^bJgok/V]00gok/V]00Co0000oo3>[_o`cZko
00002Oo_bZ`00ol0003oklf_ono=[`0<ono=[`;o0000=_ooool000cooooo00Go410@oooooooooooo
oooooa0@400;ooooo`03oeEEEOn7QhOooooo00Wooooo00?o0000ooooooooool0C_ooool2o`000003
o`0o`_l0003o;eg?00?o;eg?00?o0000oeecd?mMLm001OmMLm000ol0003oOh;=ogn2c@06ogn2c@03
o`000?nGSLOoUhg700WoUhg700?o0000ojRF`onXU/<02OnXU/<00ol0003o]YfookJM_`07okJM_`?o
00000_nfWKl00ol0003o`JBlol6T_002ol6T_003o`000?o;[[gobjjm00?objjm00?o0000ol^^_Oo;
[[d00_o;[[d00ol0003odk>iom>c^@0=om>c^@05o`000?oL^kSog;^hombk^?l000003ooR_[<00ol0
003oj<BbonS4/P05onS4/P03o`000?o[aJkojlF^00GojlF^00?o0000onk9[Oo^bJd03?o^bJd00ol0
003ol<j^oo3>[P02oo3>[P03o`000?o_bZcoklZ/00KoklZ/00?o0000ono=[oo_cJl02oo_cJl00ol0
003ok]6eo`00000fooooo`003?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@
4?nHV9P02?ooool2o`00057ooooo0ol00005obmMc`03o`000?mMLm3oGG?@00CoGG?@00?o0000ogn2
cOmoP/d01omoP/d00ol0003oUhg7oiN=a`08oiN=a`03o`000?nXU/?oZ9K300[oZ9K300?o0000okJM
_onfWKl00onfWKl3o`0000Go]Yfo00?o0000ol6T_?o1Y;`00_o1Y;`00ol0003objjmol^^_@04ol^^
_@03o`000?o;[[gobjjm00;objjm00?o0000om>c^OoC/kT02ooC/kT00ol0003og;^hombk^003ombk
^003o`000?oR_[?oh[jc00_oh[jc00?o0000onS4/_oXa;801ooXa;800ol0003ojlF^on_5[P03on_5
[P03o`000?o^bJgok/V]00gok/V]00?o0000oo3>[_o`cZh00oo`cZh00ol0003oklZ/ono:[004ono:
[003o`000?o_cJooklf_00coklf_00Co0000onkA]Oo^dKGo0000=Oooool000cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0D?oo
ool01?l0003o00FDo`000?l00004obmMc`03o`000?mMLm3oGG?@00GoGG?@00?o0000ogn2cOmoP/d0
1_moP/d00ol0003oUhg7oiN=a`08oiN=a`03o`000?nXU/?oZ9K300[oZ9K300?o0000okJM_onfWKl0
0ol00009okJM_`04o`000?o1Y;co`JBlo`0000Sobjjm00Go0000ol^^_Oo;[[gobjjmo`00000=om>c
^@03o`000?oL^kSog;^h00?og;^h00?o0000on:n/ooR_[<02ooR_[<00ol0003oj<BbonS4/P08onS4
/P03o`000?o[aJkojlF^00;ojlF^00?o0000onk9[Oo^bJd03?o^bJd00ol0003ol<j^oo3>[P05oo3>
[P03o`000?o_bZcoklZ/00?oklZ/00?o0000ono=[oo_cJl02oo_cJl00ol0003ok]6eonkA]@02onkA
]@03o`000?oooooooooo03;ooooo000Wooooo`03o`000?oooooooooo057ooooo00?o0000o`05U?l0
00001?l_GLl00ol0003oGG?@oeecd005oeecd003o`000?moP/goOh;=00OoOh;=00?o0000oiN=aonG
SLL02?nGSLL00ol0003oZ9K3ojRF``09ojRF``?o00003?nfWKl00ol0003o`JBlo`00000:ol^^_@05
o`000?o;[[gobjjmol^^_Ol000002ooC/kT00ol0003og;^hombk^005ombk^003o`000?oR_[?oh[jc
00Woh[jc00?o0000onS4/_oXa;802OoXa;800ol0003ojlF^on_5[P02on_5[P03o`000?o^bJgok/V]
00cok/V]00?o0000oo3>[_o`cZh01_o`cZh00ol0003oklZ/ono:[002ono:[003o`000?o_cJooklf_
00_oklf_00?o0000onkA]Oo^dKD00oo^dKD00ol0003oooooooooo`0aooooo`009oooool00ol0003o
ooooooooo`1Booooo`03o`000?l01ICo000000Co;eg?00?o0000oeecd?mMLm001OmMLm000ol0003o
Oh;=ogn2c@06ogn2c@03o`000?nGSLOoUhg700SoUhg700?o0000ojRF`onXU/<01_nXU/<3o`000003
ojRF`ol0003o]Yfo00co]Yfo0_l0000<ol^^_@05o`000?o;[[gobjjmol^^_Ol000002_oC/kT00ol0
003og;^hombk^006ombk^003o`000?oR_[?oh[jc00Soh[jc00?o0000onS4/_oXa;802_oXa;801?l0
003ojlF^on_5[_l0000?onk9[@03o`000?o`cZkol<j^00Ool<j^00Co0000ono:[?o_bZco00003Oo_
cJl00ol0003ok]6eonkA]@04onkA]@;o0000<_ooool002Oooooo00?o0000ooooooooool0D_ooool0
1?l0003o00FDo`000?l00003obmMc`03o`000?mMLm3oGG?@00GoGG?@00?o0000ogn2cOmoP/d01_mo
P/d00ol0003oUhg7oiN=a`09oiN=a`03o`000?nXU/?oZ9K300;oZ9K30ol00004ojRF``03o`000?nf
WKoo]Yfo00[o]Yfo00?o0000okjW`_l000003?o;[[d01Ol0003objjmol^^_Oo;[[go000000Wodk>i
00?o0000ombk^?oL^kP01ooL^kP00ol0003oh[jcon:n/`08on:n/`03o`000?oXa;;oj<Bb00_oj<Bb
00?o0000on_5[_l000003_o^bJd00ol0003ol<j^oo3>[P09oo3>[P03o`000?o_bZco000000goklf_
00?o0000onkA]Oo^dKD01Oo^dKD00ol0003oooooooooo`0`ooooo`009oooool00ol0003ooooooooo
o`1Cooooo`04o`000?l01ICo0000o`0000?o;eg?00?o0000oeecd?mMLm001?mMLm000ol0003oOh;=
ogn2c@07ogn2c@03o`000?nGSLOoUhg700SoUhg700?o0000ojRF`ol000000_l00008ojRF``03o`00
0?nfWKoo]Yfo00So]Yfo00Go0000okjW`_nnYl;o_ZO2o`00000<ol^^_@05o`000?o;[[gobjjmol^^
_Ol000002?oC/kT00ol0003og;^hombk^008ombk^003o`000?oR_[?oh[jc00Koh[jc00?o0000onS4
/_oXa;803OoXa;800ol0003ok/V]onk9[@0=onk9[@03o`000?o`cZkol<j^00[ol<j^00?o0000ono=
[oo_cJl02oo_cJl00ol0003ok]6eonkA]@07onkA]@03o`000?oooooooooo02oooooo000Wooooo`;o
0000EOooool01?l0003o00FDo`000?l00002obmMc`03o`000?mMLm3oGG?@00GoGG?@00?o0000ogn2
cOmoP/d01_moP/d00ol0003oUhg7oiN=a`07oiN=a`?o00002onXU/<00ol0003o]YfookJM_`07okJM
_`03o`000?nnYl;o_ZO200;o_ZO200?o0000ol^^_Oo;[[d02oo;[[d01?l0003objjmol^^_Ol00007
om>c^@03o`000?oL^kSog;^h00Wog;^h00?o0000on:n/ooR_[<01_oR_[<00ol0003oj<BbonS4/P0=
onS4/P03o`000?o^bJgok/V]00cok/V]00?o0000oo3>[_o`cZh02oo`cZh00ol0003oklf_ono=[`0;
ono=[`03o`000?o^dKGok]6e00Sok]6e00?o0000ooooooooool0;_ooool002Kooooo0_l0001Goooo
o`;o000000Go03Nmo`000?l_GLoo;eg?o`000006oeecd003o`000?moP/goOh;=00OoOh;=00?o0000
oiN=aonGSLL00onGSLL3o`0000;oUhg700?o0000ojRF`onXU/<02_nXU/<00ol0003o]YfookJM_`04
okJM_`;o00001_nnYl800ol0003objjmol^^_@0;ol^^_@04o`000?o;[[gobjjmo`0000Kodk>i00?o
0000ombk^?oL^kP02_oL^kP00ol0003oh[jcon:n/`04on:n/`03o`000?oXa;;oj<Bb00goj<Bb00?o
0000ong;/_l000003Oo^bJd00ol0003ol<j^oo3>[P0:oo3>[P03o`000?obe;7o000000_oklf_00?o
0000onkA]Oo^dKD02Oo^dKD2o`0002oooooo000Wooooo`03o`000?oooooooooo05Gooooo00Oo0000
o`05U?l0003o03Nmo`000?l_GLoo000000OoGG?@00?o0000ogn2cOmoP/d01_moP/d00ol0003oUhg7
oiN=a`03o`0000GoUhg700?o0000ojRF`onXU/<02_nXU/<00ol0003o]YfookJM_`03okJM_`03o`00
0?nnYl;o_ZO200Ko_ZO200?o0000ol^^_Oo;[[d03?o;[[d00ol0003objjmo`000005om>c^@03o`00
0?oL^kSog;^h00cog;^h00?o0000on:n/ooR_[<00ooR_[<00ol0003oj<BbonS4/P0=onS4/P04o`00
0?o]bk;okL^bo`0000_ok/V]00?o0000oo3>[_o`cZh02oo`cZh01?l0003ol]Baoo;D/Ol0000:ono=
[`03o`000?o^dKGok]6e00[ok]6e0_l0000^ooooo`009oooool00ol0003oooooooooo`1Fooooo`;o
00000_l0=kd2o`0000OoGG?@00?o0000ogn2cOmoP/d01_moP/d3o`0000SoUhg700?o0000ojRF`onX
U/<02onXU/<01Ol0003o]YfookJM_onfWKoo000000[o_ZO200?o0000ol^^_Oo;[[d03?o;[[d00ol0
003objjmo`000003om>c^@03o`000?oL^kSog;^h00gog;^h00?o0000on:n/ooR_[<00_oR_[<00ol0
003oj<BbonS4/P0>onS4/P05o`000?o]bk;okL^bong;/_l000002_o^bJd00ol0003ol<j^oo3>[P0:
oo3>[P03o`000?obe;7ol]Ba00;ol]Ba00?o0000ono=[oo_cJl01_o_cJl00ol0003ok]6eonkA]@0<
onkA]@03o`000?oooooooooo02cooooo000Vooooo`03o`000?oooooooooo05Sooooo0_l00002o`0g
_@;o00001omMLm000ol0003oOh;=ogn2c@02ogn2c@?o000000?oOh;=o`000?nGSLL02OnGSLL00ol0
003oZ9K3ojRF``0:ojRF``04o`000?nfWKoo]Yfoo`0000_o_ZO200?o0000ol^^_Oo;[[d03Oo;[[d2
o`0000?odk>i00?o0000ombk^?oL^kP03_oL^kP01Ol0003oh[jcon:n/ooR_[?o000000ooj<Bb00?o
0000ong;/_o]bk800oo]bk800ol0003ok/V]onk9[@06onk9[@03o`000?o`cZkol<j^00_ol<j^00?o
0000oo;D/Oobe;400oobe;400ol0003oklf_ono=[`05ono=[`03o`000?o^dKGok]6e00_ok]6e00?o
0000on_F_ol00000;Oooool002Kooooo00?o0000ooooooooool0F?ooool00ol0003o00FDo`000002
o`0g_@03o`000?mMLm3oGG?@00GoGG?@00?o0000ogn2cOl000000_l00004ogn2c@03o`000?nGSLOo
Uhg700SoUhg700?o0000ojRF`onXU/<02_nXU/<00ol0003o]Yfoo`00000<okjW`P03o`000?o;[[go
bjjm00kobjjm0_l000000ooC/kWo0000ombk^00@ombk^004o`000?oR_[?oh[jco`00013oj<Bb00?o
0000ong;/_o]bk801?o]bk800ol0003ok/V]onk9[@05onk9[@03o`000?o`cZkol<j^00_ol<j^00?o
0000oo;D/Oobe;401?obe;400ol0003oklf_ono=[`03ono=[`03o`000?o^dKGok]6e00_ok]6e00?o
0000on_F_oo[e[l00_l0000/ooooo`009_ooool00ol0003oooooooooo`1Iooooo`;o00000ol0=kd2
o`0000CoGG?@0ol00008ogn2c@03o`000?nGSLOoUhg700SoUhg700?o0000ojRF`onXU/<02OnXU/<2
o`0000ko_ZO200?o0000ol^^_Oo;[[d03Oo;[[d2o`000003om>c^Ol0003og;^h017og;^h00?o0000
on:n/ol000003ooXa;800ol0003okL^bong;/P05ong;/P03o`000?o^bJgok/V]00Cok/V]00?o0000
oo3>[_o`cZh02oo`cZh00ol0003ol]Baoo;D/@06oo;D/@03o`000?o_cJooklf_00;oklf_00?o0000
onkA]Oo^dKD02oo^dKD01Ol0003ojmJoon_F_oo[e[oo000002cooooo000Vooooo`;o0000Foooool2
o`0000;o03Nm00?o0000ocESd_l000000ol00002oeecd003o`000?moP/goOh;=00KoOh;=00?o0000
oiN=aonGSLL02?nGSLL00ol0003oZ9K3ojRF``07ojRF``;o000000?o[Io9o`000?nnYl803OnnYl80
0ol0003objjmol^^_@0>ol^^_@;o00005?oL^kP00ol0003oj<BbonS4/P0>onS4/P03o`000?o]bk;o
kL^b00KokL^b00?o0000onk9[Oo^bJd00oo^bJd00ol0003ol<j^oo3>[P0;oo3>[P03o`000?obe;7o
l]Ba00Ool]Ba00Co0000ono=[oo_cJoo00003Oo^dKD00ol0003ojmJoon_F_`03on_F_`03o`000?oo
oooooooo02Wooooo000Vooooo`03o`000?oooooooooo05[ooooo0_l00003o`0g_@Go00000_mMLm00
0ol0003oOh;=ogn2c@07ogn2c@03o`000?nGSLOoUhg700OoUhg700?o0000ojRF`onXU/<01OnXU/<2
o`0000Co[Io900?o0000okjW`_nnYl803?nnYl800ol0003objjmol^^_@0>ol^^_@03o`000?oL^kSo
g;^h01;og;^h00?o0000onS4/_oXa;803_oXa;800ol0003okL^bong;/P07ong;/P03o`000?o^bJgo
k/V]00;ok/V]00?o0000oo3>[_o`cZh02_o`cZh00ol0003ol]Baoo;D/@09oo;D/@03o`000?o_cJoo
000000gok]6e00?o0000on_F_oo[e[l01?o[e[l00ol0003oooooooooo`0Xooooo`009_ooool00ol0
003oooooooooo`1Kooooo`Go00001?leHm82o`000003oeecd?l0003oOh;=00OoOh;=00?o0000oiN=
aonGSLL02?nGSLL00ol0003oZ9K3ojRF``03ojRF``03o`000?n]WlWo[Io900Co[Io900?o0000okjW
`_nnYl803?nnYl800ol0003objjmol^^_@0=ol^^_@03o`000?oD^;ko000001;og;^h00?o0000on?4
^?l000003_oXa;800ol0003okL^bong;/P09ong;/P04o`000?o^bJgok/V]o`0000gol<j^00?o0000
oo;D/Oobe;402_obe;42o`0000cok]6e00?o0000on_F_oo[e[l01Oo[e[l00ol0003oooooooooo`0X
ooooo`009_ooool00ol0003oooooooooo`1Iooooo`Go00000_l0=kd00ol0003o=F?BocESdP03ocES
dP;o00002OmoP/d00ol0003oUhg7oiN=a`07oiN=a`04o`000?nXU/?oZ9K3ojRF``;o00002?n]WlT0
0ol0003o_ZO2okjW`P0<okjW`P03o`000?o;[[gobjjm00_objjm00Go0000omBh__oD^;koe;Rno`00
000Aombk^004o`000?oSa;SohlBho`0000goj<Bb00?o0000ong;/_o]bk802_o]bk800ol0003ok/V]
o`00000<oo3>[P03o`000?obe;7ol]Ba00_ol]Ba00?o0000oo;K]ol000002_o^dKD00ol0003ojmJo
on_F_`07on_F_`03o`000?oooooooooo02Oooooo000Vooooo`03o`000?oooooooooo05Kooooo0ol0
0004ooooo`05o`000?l0=kgo03Nmo`0g_Ol000001_leHm84o`0000GoOh;=00?o0000oiN=aonGSLL0
1onGSLL01?l0003oZ9K3o`000?l0000:ojfOb@03o`000?nnYl;o_ZO200co_ZO200?o0000ol^^_Oo;
[[d02_o;[[d00ol0003oe;RnomBh_P02omBh_P;o00003ooL^kP00ol0003ohlBhon?4^002on?4^003
o`000?oXa;;oj<Bb00Woj<Bb00?o0000ong;/_o]bk803?o]bk82o`0000col<j^00?o0000oo;D/Oob
e;402_obe;401Ol0003ol]^goo;K]oobfkOo000000Wok]6e00?o0000on_F_oo[e[l02?o[e[l00ol0
003oooooooooo`0Vooooo`009_ooool00ol0003oooooooooo`1Cooooo`?o00001oooool2o`0000;o
03Nm00?o0000ocESd_leHm801?leHm801?l0003oKX7Eofj1eOm^PMD6o`0000GoUhg71_l0000=ojfO
b@03o`000?nnYl;o_ZO200co_ZO200?o0000ol^^_Oo;[[d02?o;[[d00ol0003oe;RnomBh_P04omBh
_P;o00003OoL^kP00ol0003ohlBhon?4^004on?4^003o`000?oXa;;oj<Bb00Soj<Bb00?o0000ong;
/_o]bk803?o]bk800ol0003olM>co`00000;oo3>[P03o`000?obe;7ol]Ba00[ol]Ba00?o0000oo;K
]oobfkL00_obfkL00ol0003ok]6eonkA]@05onkA]@03o`000?o[e[oojmJo00WojmJo0_l0000Woooo
o`009Oooool00ol0003oooooooooo`1Aooooo`?o00002oooool01Ol0003o03Nmo`0g_Ol0=kgo0000
00Ko=F?B00?o0000ofj1eOm^PMD01Om^PMD6o`0000GoU9?@00?o0000ojfObOn]WlT02on]WlT00ol0
003o_ZO2okjW`P0<okjW`P03o`000?o;[[gobjjm00Sobjjm00?o0000omBh__oD^;h01?oD^;h2o`00
00gog;^h00?o0000on?4^?oSa;P01?oSa;P00ol0003oj<BbonS4/P07onS4/P03o`000?o]bk;okL^b
00cokL^b00Go0000oo7C/ooadk?olM>co`000009oo3>[P03o`000?obe;7ol]Ba00[ol]Ba00?o0000
oo;K]oobfkL01?obfkL00ol0003ok]6eonkA]@04onkA]@03o`000?o[e[oojmJo00[ojmJo00?o0000
ooooooooool09Oooool002Gooooo0ol0001>ooooo`?o00003oooool01?l0003o03Nmo`0g_Ol00006
ocESdP03o`000?m^PMGoKX7E00KoKX7E00?o0000oiBCd?nDTm002?nDTm000ol0003o[Io9ojfOb@0;
ojfOb@03o`000?nnYl;o_ZO200co_ZO200?o0000ol^^_Oo;[[d01_o;[[d00ol0003oe;RnomBh_P06
omBh_P;o00002ooL^kP00ol0003ohlBhon?4^006on?4^003o`000?oXa;;oj<Bb00Koj<Bb00?o0000
ong;/_o]bk803?o]bk800ol0003olM>coo7C/`02oo7C/`03o`000?o`cZkol<j^00Kol<j^00?o0000
oo;D/Oobe;402_obe;400ol0003ol]^goo;K]`05oo;K]`03o`000?o^dKGok]6e00;ok]6e00?o0000
on_F_oo[e[l03?o[e[l00ol0003oooooooooo`0Tooooo`009Oooool00ol0003oooooooooo`1;oooo
o`?o00004_ooool2o`0000;o03Nm00?o0000ocESd_leHm801?leHm800ol0003oKX7Eofj1e@06ofj1
e@03o`000?nDTm3oU9?@00OoU9?@00?o0000ojfObOn]WlT02on]WlT00ol0003o_ZO2okjW`P0<okjW
`P03o`000?o;[[gobjjm00Gobjjm00?o0000omBh__oD^;h02?oD^;h2o`0000[og;^h00?o0000on?4
^?oSa;P01ooSa;P00ol0003oj<BbonS4/P05onS4/P03o`000?o]bk;okL^b00_okL^b00?o0000oo7C
/ooadk<01?oadk<00ol0003ol<j^oo3>[P04oo3>[P03o`000?obe;7ol]Ba00[ol]Ba00?o0000oo;K
]oobfkL01oobfkL01?l0003ok]6eonkA]Ol0000?on_F_`;o00009Oooool000Wooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Oooooo00?o
0000ooooooooool0B?ooool3o`0001Kooooo00Co0000o`0g_Ol0=kgo00001_leHm800ol0003oKX7E
ofj1e@06ofj1e@03o`000?nDTm3oU9?@00SoU9?@00?o0000ojfObOn]WlT02on]WlT00ol0003o_ZO2
okjW`P0;okjW`P03o`000?o;[[gobjjm00Cobjjm00?o0000omBh__oD^;h02OoD^;h00ol0003og;^h
o`000008ombk^003o`000?oSa;SohlBh00WohlBh00?o0000onS4/_oXa;800ooXa;800ol0003okL^b
ong;/P0<ong;/P03o`000?oadk?olM>c00GolM>c00?o0000oo3>[_o`cZh00oo`cZh00ol0003ol]Ba
oo;D/@0:oo;D/@03o`000?obfkOol]^g00Sol]^g00?o0000onkA]Ol000003_o[e[l01?l0003ohm[=
o`000?l0000Tooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B401oooool00ol0003oooooooooo`15ooooo`?o00006_ooool01?l0
003o03Nmo`0g_Ol00006ocESdP03o`000?m^PMGoKX7E00KoKX7E00?o0000oiBCd?nDTm001onDTm00
0ol0003o[Io9ojfOb@0;ojfOb@03o`000?nnYl;o_ZO200co_ZO200?o0000ol^^_Oo;[[d00oo;[[d0
0ol0003oe;RnomBh_P0:omBh_P03o`000?oL^kSo000000Oog;^h00?o0000on?4^?oSa;P02OoSa;P0
0ol0003oj<BbonS4/P03onS4/P03o`000?o]bk;okL^b00cokL^b00?o0000oo7C/ooadk<01_oadk<0
1Ol0003ol<j^oo3>[_o`cZko000000col]Ba00?o0000oo;K]oobfkL02_obfkL00ol0003ojmJoon_F
_`0<on_F_`05o`000?oSf/gohm[=on?JcOl000009?ooool000Wooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`12ooooo`?o
00007Oooool01Ol0003o03Nmo`0g_Ol0=kgo000000Go=F?B00?o0000ofj1eOm^PMD01_m^PMD00ol0
003oU9?@oiBCd008oiBCd003o`000?n]WlWo[Io900_o[Io900?o0000okjW`_nnYl802onnYl800ol0
003objjmol^^_@02ol^^_@03o`000?oD^;koe;Rn00_oe;Rn00Co0000ombk^?oL^kSo00001OoL^kP0
0ol0003ohlBhon?4^00;on?4^005o`000?oXa;;oj<BbonS4/_l000003_o]bk800ol0003olM>coo7C
/`08oo7C/`04o`000?o`cZkol<j^o`0000col]Ba00?o0000oo;K]oobfkL02_obfkL2o`0000cojmJo
00?o0000on?JcOoSf/d00ooSf/d00ol0003oooooooooo`0Qooooo`002Oooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P07ooooo`03o`000?oooooooooo03oo
oooo0ol0000Qooooo`04o`000?l0=kgo03Nmo`0000Ko=F?B00?o0000ofj1eOm^PMD01_m^PMD00ol0
003oU9?@oiBCd007oiBCd003o`000?n]WlWo[Io900_o[Io900?o0000okjW`_nnYl803?nnYl801?l0
003objjmol^^_Ol0000?omBh_P04o`000?oL^kSog;^ho`0000Cog;^h00?o0000on?4^?oSa;P03?oS
a;P01?l0003oj<BbonS4/_l0000>ong;/P03o`000?oadk?olM>c00WolM>c00?o0000oo3>[_l00000
2oobe;400ol0003ol]^goo;K]`0:oo;K]`04o`000?o_i<;oknC2o`0000[ojmJo00?o0000on?JcOoS
f/d01?oSf/d2o`0002;ooooo0009ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co
0000o`000?l0003oc<c<00Oooooo00?o0000ooooooooool0??ooool3o`0002Gooooo00Co0000o`0g
_Ol0=kgo00001OleHm800ol0003oKX7Eofj1e@06ofj1e@03o`000?nDTm3oU9?@00SoU9?@00?o0000
ojfObOn]WlT02_n]WlT00ol0003o_ZO2okjW`P0<okjW`P03o`000?o;[[go0000017oe;Rn00Co0000
ombk^?oL^kSo00000_oL^kP00ol0003ohlBhon?4^00>on?4^003o`000?oXa;;o000000gokL^b00?o
0000oo7C/ooadk<02ooadk<2o`0000_ol]Ba00?o0000oo;K]oobfkL02OobfkL00ol0003oknC2onoT
`P02onoT`P03o`000?o[e[oojmJo00KojmJo00?o0000on?JcOoSf/d01_oSf/d2o`00027ooooo0009
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Oooooo
00?o0000ooooooooool0>Oooool3o`0002Sooooo0_l000000ol0=kgo0000ocESdP05ocESdP03o`00
0?m^PMGoKX7E00KoKX7E00?o0000oiBCd?nDTm001onDTm000ol0003o[Io9ojfOb@0;ojfOb@03o`00
0?nnYl;o_ZO200co_ZO200?o0000omBh__oD^;h04?oD^;h01_l0003og;^hombk^?l0003og;^ho`00
01;ohlBh00?o0000ong;/_o]bk803?o]bk800ol0003olM>coo7C/`0;oo7C/`03o`000?ocfkKo0000
00Wol]Ba00?o0000oo;K]oobfkL02_obfkL00ol0003oknC2onoT`P03onoT`P03o`000?o[e[oojmJo
00GojmJo00?o0000on?JcOoSf/d01ooSf/d00ol0003oooooooooo`0Oooooo`002Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooo
oooo03Oooooo0ol0000/ooooo`;o000000?o03Nmo`000?leHm801?leHm800ol0003oKX7Eofj1e@06
ofj1e@03o`000?nDTm3oU9?@00SoU9?@00?o0000ojfObOn]WlT02_n]WlT00ol0003o_ZO2okjW`P0;
okjW`P;o00004ooD^;h00ol0003og;^hombk^002o`0001;ohlBh0_l0000<ong;/P03o`000?oadk?o
lM>c00_olM>c00Go0000oo?K]_ocfkKolm^fo`000008oo;D/@03o`000?obfkOol]^g00Wol]^g00?o
0000onoT`_o_i<801Oo_i<800ol0003ojmJoon_F_`03on_F_`03o`000?oSf/gohm[=00Sohm[=0_l0
000Pooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@06ooooo`03o`000?oooooooooo03Cooooo0ol0000`ooooo`?o00001_leHm800ol0003oKX7E
ofj1e@06ofj1e@03o`000?nDTm3oU9?@00OoU9?@00?o0000ojfObOn]WlT02on]WlT00ol0003o_ZO2
okjW`P09okjW`P04o`000?o7/lOoak?7o`0001;oe;Rn00?o0000ombk^?oL^kP00_l0000Aon?4^004
o`000?oZc[Woj/jio`0000_okL^b00?o0000oo7C/ooadk<02ooadk<00ol0003olm^foo?K]P02oo?K
]P;o00001Oobe;400ol0003ol]^goo;K]`0:oo;K]`03o`000?o_i<;oknC200KoknC200Go0000on_F
_oo[e[oojmJoo`00000<on?Jc@;o00007oooool002Cooooo00?o0000ooooooooool0<Oooool3o`00
03?ooooo00Co0000o`0<V?l0003o00001_leHm800ol0003oKX7Eofj1e@05ofj1e@03o`000?nDTm3o
U9?@00SoU9?@00?o0000ojfObOn]WlT02_n]WlT00ol0003o_ZO2okjW`P08okjW`P05o`000?o7/lOo
ak?7olNcaol000004ooD^;h01Ol0003og;^ho`000?oSa;So0000013ohlBh00Go0000on[>^OoZc[Wo
j/jio`000009ong;/P03o`000?oadk?olM>c00_olM>c00?o0000oo?K]_ocfkH01OocfkH00ol0003o
l]Baoo;D/@02oo;D/@03o`000?obfkOol]^g00Wol]^g00?o0000onoT`_o_i<802?o_i<800ol0003o
jmJoo`00000>on?Jc@;o00007_ooool002Cooooo00?o0000ooooooooool0;oooool2o`0003Oooooo
00Co0000o`0<V?l0003o00001OleHm800ol0003oKX7Eofj1e@06ofj1e@03o`000?nDTm3oU9?@00Oo
U9?@00?o0000ojfObOn]WlT02on]WlT00ol0003o_ZO2okjW`P06okjW`P03o`000?o7/lOoak?700?o
ak?700?o0000omBh__oD^;h04OoD^;h01Ol0003ohlBhon?4^?oSa;So000000kohlBh00?o0000on[>
^OoZc[T00ooZc[T00ol0003okL^bong;/P06ong;/P03o`000?oadk?olM>c00_olM>c00?o0000oo?K
]_ocfkH01_ocfkH01?l0003ol]Baoo;D/Ol0000;oo;K]`03o`000?o_i<;oknC200[oknC20_l0000>
on?Jc@;o00007_ooool002Cooooo00?o0000ooooooooool0;?ooool3o`0003[ooooo00?o0000o`0<
V?l000001_leHm800ol0003oKX7Eofj1e@05ofj1e@03o`000?nDTm3oU9?@00SoU9?@00?o0000ojfO
bOn]WlT02_n]WlT00ol0003o_ZO2okjW`P05okjW`P03o`000?o7/lOoak?700Goak?700?o0000omBh
__oD^;h04?oD^;h00ol0003ohlBhon?4^002on?4^003o`000?oSa;SohlBh00[ohlBh00?o0000on[>
^OoZc[T01OoZc[T00ol0003okL^bong;/P04ong;/P03o`000?oadk?olM>c00_olM>c00?o0000oo?K
]_ocfkH02?ocfkH00ol0003ol]Bao`00000;oo;K]`03o`000?o_i<;oknC200[oknC200?o0000onO^
d_l000003?oSf/d01?l0003od=gRo`000?l0000Mooooo`009?ooool00ol0003oooooooooo`0Yoooo
o`?o0000?_ooool01?l0003o00bHo`000?l00004ocESdP03o`000?m^PMGoKX7E00KoKX7E00?o0000
oiBCd?nDTm001onDTm000ol0003o[Io9ojfOb@0;ojfOb@03o`000?nnYl;o_ZO200?o_ZO200?o0000
olNcaoo7/lL01_o7/lL00ol0003oe;RnomBh_P0?omBh_P03o`000?oLa<7o000000CohlBh00?o0000
on?4^?oSa;P02OoSa;P00ol0003oj/jion[>^@06on[>^@03o`000?o]bk;okL^b00?okL^b00?o0000
oo7C/ooadk<02ooadk<00ol0003olm^foo?K]P09oo?K]P;o00002_obfkL00ol0003oknC2onoT`P0:
onoT`P05o`000?oWk];oinkBonO^d_l000002_oSf/d01?l0003od=gRom3Mh_o@gN82o`0001cooooo
000Tooooo`03o`000?oooooooooo02Kooooo0ol00011ooooo`05o`000?l039So0000o`1<bol00000
1?leHm800ol0003oKX7Eofj1e@05ofj1e@03o`000?nDTm3oU9?@00SoU9?@00?o0000ojfObOn]WlT0
2_n]WlT00ol0003o_ZO2okjW`P02okjW`P03o`000?o7/lOoak?700Soak?700?o0000omBh__oD^;h0
3OoD^;h01Ol0003og<C1omc4`OoLa<7o000000CohlBh00?o0000on?4^?oSa;P01ooSa;P00ol0003o
j/jion[>^@08on[>^@03o`000?o]bk;okL^b00;okL^b00?o0000oo7C/ooadk<02_oadk<00ol0003o
lm^foo?K]P0:oo?K]P04o`000?odi[_o0000o`0000Sol]^g00?o0000onoT`_o_i<802Oo_i<800ol0
003oinkBonO^dP03onO^dP03o`000?oSf/gohm[=00Gohm[=0_l00005om3MhP;o00006oooool002?o
oooo0_l0000Uooooo`?o0000AOooool01?l0003o00bHo`000?l0C</2o`0000;o=F?B00?o0000ofj1
eOm^PMD01_m^PMD00ol0003oU9?@oiBCd007oiBCd003o`000?n]WlWo[Io900_o[Io900Co0000okjW
`_nnYl;o00002oo7/lL00ol0003oe;RnomBh_P0<omBh_P03o`000?oLa<7og<C100?og<C100Go0000
on?4^?oSa;SohlBho`000009on?4^003o`000?oZc[Woj/ji00Woj/ji00Co0000ong;/_o]bk;o0000
3Ooadk<00ol0003olm^foo?K]P09oo?K]P03o`000?odi[_om>Jk00;om>Jk0_l00005oo;K]`03o`00
0?o_i<;oknC200WoknC200?o0000onO^d_oWk]801OoWk]800ol0003ohm[=on?Jc@03on?Jc@03o`00
0?o@gN;od=gR00Kod=gR00?o0000ooooooooool06Oooool002Cooooo00?o0000ooooooooool08?oo
ool3o`0004Wooooo00?o0000o`0<V?l000000_l0C</01?l0003o=F?BocESd_l00007ofj1e@03o`00
0?nDTm3oU9?@00SoU9?@00?o0000ojfObOn]WlT02_n]WlT00ol0003o_ZO2o`00000=olNca`03o`00
0?oD^;koe;Rn00_oe;Rn00?o0000omc4`OoLa<401?oLa<401Ol0003ohlBhon?4^?oSa;So000000Oo
hlBh00?o0000on[>^OoZc[T02ooZc[T00ol0003okL^bo`00000<oo7C/`03o`000?ocfkKolm^f00[o
lm^f00?o0000ooCV^oodi[/01?odi[/01Ol0003ol]^goo;K]oobfkOo000000_oknC200?o0000onO^
d_oWk]801ooWk]801Ol0003ohm[=on?JcOoSf/go000000[od=gR00?o0000ooooooooool06?ooool0
02?ooooo00?o0000ooooooooool07_ooool3o`0004cooooo00?o0000o`0<V?l000000ol0C</00ol0
003o=F?Bo`000008ofj1e@03o`000?nDTm3oU9?@00OoU9?@00?o0000ojfObOn]WlT02_n]WlT2o`00
00ooak?700?o0000omBh__oD^;h02OoD^;h00ol0003og<C1omc4`@05omc4`@03o`000?oSa;SohlBh
00;ohlBh00?o0000on?4^?oSa;P01?oSa;P00ol0003oj/jion[>^@0<on[>^@;o00002ooadk<00ol0
003olm^foo?K]P0:oo?K]P03o`000?odi[_om>Jk00Kom>Jk0_l000000oobfkOo0000onoT`P09onoT
`P03o`000?oWk];oinkB00WoinkB00?o0000on?JcOl000003?o@gN800ol0003oooooooooo`0Goooo
o`008oooool00ol0003oooooooooo`0Kooooo`?o0000D?ooool00ol0003o00bHo`000003o`1<b`?o
00001om^PMD00ol0003oU9?@oiBCd008oiBCd003o`000?n]WlWo[Io900Oo[Io90_l000000onc[=7o
0000olNca`0>olNca`03o`000?oD^;koe;Rn00Soe;Rn00?o0000omc4`OoLa<401ooLa<400ol0003o
hlBhon?4^002on?4^003o`000?oSa;SohlBh00;ohlBh00?o0000on[>^OoZc[T03OoZc[T00ol0003o
kmVko`00000:oo7C/`03o`000?ocfkKolm^f00Wolm^f00?o0000ooCV^oodi[/02Oodi[/2o`0000[o
knC200?o0000onO^d_oWk]802OoWk]83o`0000cod=gR0_l0000Hooooo`008oooool00ol0003ooooo
ooooo`0Hooooo`?o0000E?ooool00ol0003o00bHo`000004o`1<b`03o`000?m^PMGoKX7E00KoKX7E
00?o0000oiBCd?nDTm001onDTm000ol0003o[Io9ojfOb@04ojfOb@?o00001?nc[=400ol0003oak?7
olNca`0=olNca`03o`000?oD^;koe;Rn00Koe;Rn00?o0000omc4`OoLa<402OoLa<400ol0003ohlBh
on?4^002on?4^005o`000?oSa;SohlBhon?4^?l000003_oZc[T01Ol0003okmVkonoI^oo_fK_o0000
00SolM>c00?o0000oo?K]_ocfkH02_ocfkH00ol0003om>JkooCV^`09ooCV^`04o`000?o_l/Co0000
o`0000OoknC200?o0000onO^d_oWk]802OoWk]801Ol0003oc_KYolkfjOo>m^Wo000000cod=gR00?o
0000ooooooooool05_ooool002?ooooo00?o0000ooooooooool05Oooool3o`0005Oooooo00?o0000
o`0<V?l000001Ol0C</3o`0000GoKX7E00?o0000oiBCd?nDTm002?nDTm001?l0003o[Io9ojfObOn]
WlT2o`0000Oo/jcA00?o0000olNcaoo7/lL03Oo7/lL00ol0003oe;RnomBh_P06omBh_P03o`000?oL
a<7og<C100[og<C100?o0000on?4^?oSa;P00_oSa;P00ol0003ohlBho`00000?on[>^@03o`000?o_
fK_okmVk00;okmVk00?o0000oo7C/ooadk<01Ooadk<00ol0003olm^foo?K]P09oo?K]P03o`000?od
i[_om>Jk00Wom>Jk00?o0000onoba?o_l/@00_o_l/@2o`0000CoknC200?o0000onO^d_oWk]802OoW
k]800ol0003oc_KYolkfj@03olkfj@03o`000?o@gN;od=gR00[od=gR00?o0000ooooooooool05Ooo
ool002?ooooo00?o0000ooooooooool04_ooool3o`0005_ooooo00?o0000o`0<V?l000001?l0C</0
0ol0003oEh3OoeN0g`03o`0000?oKX7E00?o0000oiBCd?nDTm001onDTm001?l0003o[Io9o`000?l0
000:ok>/d@03o`000?o7/lOoak?700goak?700?o0000omBh__oD^;h01?oD^;h00ol0003og<C1omc4
`@0;omc4`@03o`000?oSa;SohlBh00?ohlBh00?o0000on[>^OoZc[T03OoZc[T00ol0003okmVkonoI
^`04onoI^`03o`000?oadk?olM>c00?olM>c00?o0000oo?K]_ocfkH02_ocfkH00ol0003om>JkooCV
^`08ooCV^`03o`000?o_l/Coko;400Goko;40_l000000oo_i<;o0000onO^dP09onO^dP;o00001oo>
m^T2o`0000_od=gR00?o0000ooooooooool05?ooool002;ooooo0ol0000@ooooo`?o0000Goooool0
0ol0003o00bHo`000004o`1<b`03o`000?mGP=ooEh3O00;oEh3O1?l00005oiBCd0Ko00003Onc[=40
0ol0003oak?7olNca`0<olNca`03o`000?oD^;koe;Rn00?oe;Rn00?o0000omc4`OoLa<403OoLa<40
0ol0003ohlBhon?4^002on?4^0;o00003OoZc[T00ol0003okmVkonoI^`06onoI^`03o`000?oadk?o
lM>c00;olM>c00?o0000oo?K]_ocfkH02OocfkH00ol0003om>JkooCV^`09ooCV^`03o`000?o_l/Co
ko;400Ooko;40_l00009onO^dP03o`000?o>m^Woc_KY00Woc_KY00?o0000om3Mh_o@gN801oo@gN83
o`0001Gooooo000Sooooo`03o`000?oooooooooo00cooooo0ol0001Sooooo`;o00001?l0C</00ol0
003oEh3OoeN0g`05oeN0g`Ko00001OnAWM`00ol0003o/jcAok>/d@0;ok>/d@03o`000?o7/lOoak?7
00goak?700?o0000omBh__oD^;h00_oD^;h00ol0003og<C1omc4`@0>omc4`@06o`000?oSa;SohlBh
o`000?oZc[Wo00003OoZc[T00ol0003okmVkonoI^`07onoI^`04o`000?oadk?olM>co`0000colm^f
00?o0000ooCV^oodi[/02?odi[/00ol0003oko;4onoba008onoba003o`000?oNoM3o000000;o0000
1OoWk]800ol0003oc_KYolkfj@0;olkfj@04o`000?o@gN;od=gRom3MhPGo00000_ooool00ol0003o
ooooooooo`0Cooooo`008oooool00ol0003oooooooooo`09ooooo`?o0000Ioooool2o`0000Co04c;
00?o0000oeN0gomGP=l01OmGP=l00ol0003oTIgLoi6Mg008oi6Mg003o`000?nc[=7o/jcA00_o/jcA
00?o0000olNcaoo7/lL03Oo7/lL01?l0003oe;RnomBh__l0000Bomc4`@03o`000?oSa;So000000;o
j/ji00?o0000on[>^OoZc[T02OoZc[T00ol0003okmVkonoI^`09onoI^`03o`000?oadk?o000000_o
lm^f00?o0000ooCV^oodi[/02?odi[/00ol0003oko;4onoba008onoba003o`000?oNoM3og_g@00?o
g_g@0ol000000ooWk];o0000olkfj@0=olkfj@Ko00001Oooool00ol0003oooooooooo`0Cooooo`00
8oooool00ol0003oooooooooo`06ooooo`?o0000Joooool2o`0000Co04c;00?o0000oeN0gomGP=l0
1OmGP=l00ol0003oTIgLoi6Mg008oi6Mg003o`000?nc[=7o/jcA00[o/jcA00?o0000olNcaoo7/lL0
3Oo7/lL00ol0003oe;Rno`00000Domc4`@03o`000?oZc[Woj/ji00;oj/ji00?o0000on[>^OoZc[T0
2?oZc[T00ol0003okmVkonoI^`0:onoI^`;o00002oocfkH00ol0003om>JkooCV^`08ooCV^`03o`00
0?o_l/Coko;400Ooko;400?o0000omkmd?oNoM001_oNoM04o`0000[oc_KY1_l00008ooooo`03o`00
0?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo00Cooooo0ol0001^ooooo`;o00001?l0
C</00ol0003oEh3OoeN0g`05oeN0g`03o`000?nAWMcoTIgL00SoTIgL00?o0000ok>/dOnc[=402onc
[=400ol0003oak?7olNca`0=olNca`03o`000?oLa<7og<C101?og<C10_l00004on[>^@03o`000?oZ
c[Woj/ji00Koj/ji00?o0000onoI^oo_fK/02oo_fK/00ol0003ol^Fmo`000002o`0000Oolm^f00?o
0000ooCV^oodi[/02?odi[/00ol0003oko;4onoba007onoba003o`000?oNoM3og_g@00Kog_g@00?o
0000ojojf?n_n]P00_n_n]P4o`0000?oc_KY1Ol0000<ooooo`03o`000?oooooooooo01?ooooo000R
ooooo`04o`000?ooooooooooooooo`?o0000L_ooool2o`0000Co04c;00?o0000oeN0gomGP=l01OmG
P=l00ol0003oTIgLoi6Mg008oi6Mg003o`000?nc[=7o/jcA00_o/jcA00?o0000olNcaoo7/lL02oo7
/lL2o`0001Cog<C100Co0000onCAa?oTdLCo00001?oZc[T00ol0003oj/jion[>^@05on[>^@03o`00
0?o_fK_okmVk00[okmVk00?o0000oo;U_OobiKd00oobiKd2o`0000Colm^f00?o0000ooCV^oodi[/0
2Oodi[/00ol0003oko;4onoba006onoba003o`000?oNoM3og_g@00Gog_g@0_l00009ojojf0Go0000
3oooool00ol0003oooooooooo`0Cooooo`008_ooool4o`0007Kooooo0_l00003o`1<b`03o`000?mG
P=ooEh3O00GoEh3O00?o0000oi6Mg?nAWM`02?nAWM`00ol0003o/jcAok>/d@0;ok>/d@03o`000?o7
/lOoak?700[oak?700Co0000om32cOo@`/go00004_oLa<400ol0003oi=74onCAa002onCAa003o`00
0?oZc[Woj/ji00;oj/ji00?o0000on[>^OoZc[T00ooZc[T00ol0003okmVkonoI^`0;onoI^`03o`00
0?obiKgol^Fm00Gol^Fm0ol000000oocfkKo0000ooCV^`09ooCV^`03o`000?o_l/Coko;400Koko;4
00?o0000omkmd?oNoM001OoNoM000ol0003o[o[Hojojf006ojojf0Go00004_ooool00ol0003ooooo
ooooo`0Cooooo`008_ooool3o`0007Sooooo00?o0000o`1<bol0C</00_l0C</00ol0003oEh3OoeN0
g`05oeN0g`03o`000?nAWMcoTIgL00SoTIgL00?o0000ok>/dOnc[=402onc[=400ol0003oak?7olNc
a`08olNca`03o`000?o@`/god<;=00;od<;=00?o0000omc4`OoLa<403_oLa<400ol0003oi=74onCA
a004onCAa003o`000?oZc[Woj/ji00;oj/ji00?o0000on[>^OoZc[T00_oZc[T00ol0003okmVkonoI
^`0:onoI^`03o`000?obiKgol^Fm00Wol^Fm0ol00008ooCV^`03o`000?o_l/Coko;400Koko;400?o
0000omkmd?oNoM001?oNoM02o`0000Ko[o[H1?l0000Gooooo`03o`000?oooooooooo01;ooooo000T
ooooo`03o`000?oooooooooo07Oooooo00?o0000o`1<bol0C</00_l0C</00ol0003oEh3OoeN0g`05
oeN0g`03o`000?nAWMcoTIgL00SoTIgL00?o0000ok>/dOnc[=402_nc[=400ol0003oak?7olNca`07
olNca`03o`000?o@`/god<;=00Cod<;=00?o0000omc4`OoLa<403OoLa<400ol0003oi=74onCAa005
onCAa005o`000?oZc[Woj/jion[>^Ol000000ooZc[T00ol0003okmVkonoI^`0:onoI^`03o`000?ob
iKgol^Fm00[ol^Fm00?o0000oo3b`Oo`l/400ol00005ooCV^`03o`000?o_l/Coko;400Goko;400?o
0000omkmd?oNoM001?oNoM000ol0003o[o[Hojojf007o`0001[ooooo00?o0000ooooooooool04_oo
ool001Kooooo00?ok^k^o`000?l000000_l000000ol@413oooooooooo`07ooooo`03o`000?oooooo
oooo07Oooooo0_l00002o`1<b`03o`000?mGP=ooEh3O00GoEh3O00?o0000oi6Mg?nAWM`02?nAWM`0
0ol0003o/jcAok>/d@0;ok>/d@03o`000?o7/lOoak?700Goak?700?o0000om32cOo@`/d01_o@`/d0
0ol0003og<C1omc4`@0;omc4`@03o`000?oTdLCoi=7400Ooi=7400Oo0000on[>^OoZc[Woj/jio`00
0?oZc[Wo000000gokmVk00?o0000oo;U_OobiKd02OobiKd00ol0003ol?;1oo3b`@04oo3b`@?o0000
00?om>Jko`000?o_l/@01_o_l/@00ol0003og_g@omkmd00<o`0001gooooo00?o0000ooooooooool0
4_ooool001Kooooo00GoMgMgoiRHV?oooooo0000ogMgM`0;ooooo`03o`000?oooooooooo07Kooooo
00?o0000o`0^/_l000000_l0C</00ol0003oEh3OoeN0g`05oeN0g`03o`000?nAWMcoTIgL00SoTIgL
00?o0000ok>/dOnc[=402_nc[=400ol0003oak?7olNca`04olNca`03o`000?o@`/god<;=00Ood<;=
00?o0000omc4`OoLa<402_oLa<400ol0003oi=74onCAa009onCAa004o`000?oZc[Woj/jion[>^@;o
00003?o_fK/00ol0003ol^Fmoo;U_@09oo;U_@03o`000?o`l/7ol?;100Sol?;13?l00002ok_j_@03
o`000?m[e:?o000000?o00008Oooool00ol0003oooooooooo`0Booooo`005_ooool01Ol@413ooooo
ooooool0003o410@00cooooo00?o0000ooooooooool0M_ooool01Ol0003o02jbo`000?l0C<_o0000
00OoEh3O00?o0000oi6Mg?nAWM`02?nAWM`00ol0003o/jcAok>/d@0;ok>/d@03o`000?o7/lOoak?7
00;oak?700?o0000om32cOo@`/d02Oo@`/d00ol0003og<C1omc4`@08omc4`@03o`000?oTdLCoi=74
00_oi=7400?o0000on[>^OoZc[T00_l0000<onoI^`03o`000?obiKgol^Fm00Wol^Fm00?o0000oo3b
`Oo`l/402?o`l/400ol0003ohog3on?m``04on?m``03o`000?nkn[go^oZm00;o^oZm1Ol0000Toooo
o`03o`000?oooooooooo01;ooooo000Fooooo`03o`000?oooooooooo00;o00003Oooool00ol0003o
ooooooooo`1fooooo`05o`000?l0;[;o0000o`1<bol000001omGP=l00ol0003oTIgLoi6Mg008oi6M
g003o`000?nc[=7o/jcA00_o/jcA00Co0000olNcaoo7/lOo00003Oo@`/d00ol0003og<C1omc4`@07
omc4`@03o`000?oTdLCoi=7400coi=7400Go0000on[>^Ol0003okmVko`00000:onoI^`03o`000?ob
iKgol^Fm00Wol^Fm00?o0000oo3b`Oo`l/402?o`l/400ol0003ohog3on?m``04on?m``03o`000?nk
n[go^oZm00;o^oZm0ol0000Wooooo`03o`000?oooooooooo01;ooooo000Fooooo`03o`000?oooooo
oooo00;o00003_ooool00ol0003oooooooooo`1fooooo`04o`000?l0;[;o0000o`0000OoEh3O00?o
0000oi6Mg?nAWM`02OnAWM`00ol0003o/jcAok>/d@0:ok>/d@03o`000?o7/lOo000000ood<;=00?o
0000omc4`OoLa<401OoLa<400ol0003oi=74onCAa00>onCAa0;o00000_o_fK/00ol0003okmVkonoI
^`07onoI^`03o`000?obiKgol^Fm00Sol^Fm00?o0000oo3b`Oo`l/402?o`l/400ol0003ohog3on?m
``04on?m``04o`000?nkn[go^oZmok_j_@;o0000:_ooool00ol0003oooooooooo`0Booooo`005_oo
ool01Ol@413oooooooooool0003o410@00oooooo00?o0000ooooooooool0M_ooool01?l0003o02jb
o`000?l00007oeN0g`03o`000?nAWMcoTIgL00SoTIgL00?o0000ok>/dOnc[=402_nc[=42o`00013o
d<;=00?o0000omc4`OoLa<401?oLa<400ol0003oi=74onCAa00?onCAa006o`000?o[hLOo0000o`00
0?o_fK_o00001oo_fK/00ol0003ol^Fmoo;U_@09oo;U_@03o`000?o`l/7ol?;100Ool?;100?o0000
on?m`ooSoL<01?oSoL<01?l0003o^oZmok_j_Onkn[d2o`0002_ooooo00?o0000ooooooooool04_oo
ool001Kooooo00GoMgMgoiRHV?oooooo0000ogMgM`0@ooooo`;o0000Moooool01?l0003o02jbo`00
0?l00006oeN0g`03o`000?nAWMcoTIgL00WoTIgL00?o0000ok>/dOnc[=401onc[=42o`000003okVm
g?l0003od<;=013od<;=00?o0000omc4`OoLa<400ooLa<400ol0003oi=74onCAa00>onCAa003o`00
0?o[hLOojn7700;ojn7700?o0000onoI^ol000001_o_fK/00ol0003ol^Fmoo;U_@08oo;U_@03o`00
0?o`l/7ol?;100Ool?;100?o0000on?m`ooSoL<01?oSoL<00ol0003o^oZmok_j_@02o`0002gooooo
00?o0000ooooooooool04_ooool001Kooooo00Gok^k^o`<30ol0003o0000onk^kP0Booooo`03o`00
0?oooooooooo07Gooooo00?o0000o`0^/_l000001omGP=l00ol0003oTIgLoi6Mg008oi6Mg003o`00
0?nc[=7o/jcA00Ko/jcA00?o0000okVmg?ni_M`00_ni_M`00ol0003od<;=om32c@0?om32c@05o`00
0?oLa<7og<C1omc4`Ol000004?oTdL@00ol0003ojn77on_Qa`04on_Qa`;o00001Oo_fK/00ol0003o
l^Fmoo;U_@08oo;U_@03o`000?o`l/7ol?;100Ool?;100?o0000on?m`ooSoL<01?oSoL<01?l0003o
^oZmo`000?l0000_ooooo`03o`000?oooooooooo01;ooooo000/ooooo`03o`000?oooooo000007Ko
oooo00?o0000o`0^/_l0;[800_l00006oeN0g`03o`000?nAWMcoTIgL00SoTIgL00?o0000ok>/dOnc
[=400onc[=42o`0000Ko^KgL00?o0000om32cOo@`/d03oo@`/d00ol0003og<C1o`00000@onCAa003
o`000?o[hLOojn7700Oojn770_l00002onoI^`03o`000?obiKgol^Fm00Wol^Fm00?o0000oo3b`Oo`
l/401oo`l/400ol0003ohog3on?m``03on?m``?o0000<Oooool00ol0003oooooooooo`0Booooo`00
;oooool00ol0003oooooooooo`1dooooo`04o`000?l0;[;o0000oc9miP?o00000omGP=l00ol0003o
TIgLoi6Mg009oi6Mg003o`000?nc[=7o/jcA00;o00002Oni_M`00ol0003od<;=om32c@0?om32c@;o
00004?oTdL@00ol0003ojn77on_Qa`08on_Qa`;o000000?okmVko`000?obiKd02OobiKd00ol0003o
l?;1oo3b`@07oo3b`@03o`000?oSoL?ohog300?ohog30_l0000dooooo`03o`000?oooooooooo017o
oooo000`ooooo`03o`000?oooooooooo07Cooooo00?o0000o`0^/_l000000olbONH2o`0000;oEh3O
00?o0000oi6Mg?nAWM`02?nAWM`00ol0003o/jcAo`00000<okVmg003o`000?o@`/god<;=00god<;=
00Co0000omWDe?oIe=Co00003_oTdL@00ol0003ojn77on_Qa`0:on_Qa`Co00002?obiKd00ol0003o
l?;1oo3b`@07oo3b`@03o`000?oSoL?ohog300;ohog30ol0000eooooo`03o`000?oooooooooo017o
oooo000aooooo`03o`000?oooooooooo07Cooooo00?o0000o`0^/_l000001?lbONH3o`0000KoTIgL
1_l0000=okVmg003o`000?o@`/god<;=00cod<;=00?o0000omWDe?oIe=@00_oIe=@00ol0003oi=74
onCAa00:onCAa003o`000?o[hLOojn7700cojn7700?o0000oncab_o/lLX00ol00005oo;U_@03o`00
0?o`l/7ol?;100Kol?;100?o0000on?m`ooSoL<01?l0000gooooo`03o`000?oooooooooo017ooooo
000booooo`03o`000?oooooooooo07Cooooo00?o0000o`0^/_l000001_lbONH6o`0000GoRjc/00?o
0000okVmg?ni_M`03?ni_M`00ol0003od<;=om32c@0:om32c@03o`000?oIe=CofMCD00CofMCD00?o
0000onCAa?oTdL@02OoTdL@00ol0003ojn77on_Qa`0;on_Qa`03o`000?o/lL[o000000Cok?7:0ol0
00000oobiKgo0000oo3b`@07oo3b`@Co000000?o_OVho`000?ooool0>?ooool00ol0003ooooooooo
o`0Aooooo`00<oooool00ol0003oooooooooo`1dooooo`?o00001OlbONH00ol0003oRjc/oh^/k009
oh^/k003o`000?ni_Mco^KgL00co^KgL00?o0000om32cOo@`/d02?o@`/d00ol0003ofMCDomWDe006
omWDe0;o00002?oTdL@00ol0003ojn77on_Qa`0;on_Qa`05o`000?o/lL[ok?7:oncab_l000001_o/
lLX;o`0000?o_OVh00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Aooooo`00=?ooool2
o`0007Kooooo0_l00005oc9miP03o`000?n;[>coRjc/00WoRjc/00?o0000okVmg?ni_M`03?ni_M`0
0ol0003od<;=om32c@06om32c@03o`000?oIe=CofMCD00WofMCD00?o0000onCAa?oTdL@01?oTdL@0
0ol0003ojn77on_Qa`0;on_Qa`03o`000?o/lL[ok?7:00?ok?7:00?o0000oncab_o/lLX00oo/lLX0
0ol0003oh_g8on;mb005on;mb004o`000?nmnKSo_OVhokgi^0;o0000>oooool00ol0003ooooooooo
o`0Aooooo`00=_ooool00ol0003oooooooooo`1dooooo`;o00001OlbONH00ol0003oRjc/oh^/k009
oh^/k003o`000?ni_Mco^KgL00_o^KgL00?o0000om32cOo@`/d01Oo@`/d00ol0003ofMCDomWDe00;
omWDe003o`000?oTdLCoi=7400;oi=7400?o0000on_Qaoo[hLL03?o[hLL00ol0003ok?7:oncabP03
oncabP03o`000?o/lL[ok?7:00;ok?7:00?o0000on;mb?oRoLP01OoRoLP01Ol0003o_OVhokgi^?nm
nKSo000003gooooo00?o0000ooooooooool04Oooool003Oooooo0_l0001eooooo`03o`000?lbONKo
<WgV00Co<WgV00?o0000oh^/k?n;[>`02On;[>`00ol0003o^KgLokVmg00;okVmg003o`000?o@`/go
d<;=00?od<;=00?o0000omWDe?oIe=@03OoIe=@01Ol0003oi=74onCAa?oTdLCo000000gojn7700?o
0000oncab_o/lLX01Oo/lLX01?l0003ok?7:oncab_l00007on;mb005o`000?nmnKSo_OVhokgi^?l0
0000?_ooool00ol0003oooooooooo`0Aooooo`00=_ooool00ol0003oooooo`00001fooooo`03o`00
0?lbONKo<WgV00Co<WgV00?o0000oh^/k?n;[>`02?n;[>`00ol0003o^KgLokVmg00<okVmg005o`00
0?o@`/god<;=om32cOl000004OoIe=@00ol0003oi=74o`00000=on_Qa`03o`000?o/lL[ok?7:00Oo
k?7:0_l00007on;mb005o`000?nmnKSo_OVhokgi^?l00000?oooool00ol0003oooooooooo`0Aoooo
o`00>Oooool00ol0003oooooooooo`1dooooo`03o`000?lbONKo<WgV00Co<WgV00?o0000oh^/k?n;
[>`02?n;[>`00ol0003o^KgLokVmg00<okVmg003o`000?o@`/go000001?ofMCD0_l0000<on_Qa`03
o`000?o/lL[ok?7:00Sok?7:0_l00006on;mb003o`000?nmnKSo_OVh00;o0000@?ooool00ol0003o
ooooooooo`0Aooooo`00>_ooool00ol0003oooooooooo`1dooooo`03o`000?lbONKo<WgV00Co<WgV
00?o0000oh^/k?n;[>`02?n;[>`00ol0003o^KgLokVmg00;okVmg0?o00004ooIe=@01?l0003og^WK
o`000?l00009on_Qa`03o`000?o/lL[ok?7:00Sok?7:00Co0000on;mb?oRoLSo00001?oRoLP01?l0
003o_OVho`000?l00012ooooo`03o`000?oooooooooo017ooooo000kooooo`03o`000?oooooooooo
07Cooooo00?o0000oc9mi_lbONH00olbONH00ol0003oRjc/oh^/k009oh^/k003o`000?ni_Mco^KgL
00So^KgL0_l00003okkDjP03o`000?oIe=CofMCD00oofMCD00?o0000omkYfooNjM/00_oNjM/2o`00
00Oojn7700?o0000oncab_o/lLX02?o/lLX01Ol0003oh_g8on;mb?oRoLSo000000;oh_g80ol00015
ooooo`03o`000?oooooooooo013ooooo000looooo`03o`000?oooooooooo07Cooooo00?o0000oc9m
i_lbONH00olbONH00ol0003oRjc/oh^/k008oh^/k003o`000?ni_Mco^KgL00Oo^KgL00?o0000okkD
j_nne>X01?nne>X00ol0003ofMCDomWDe00=omWDe003o`000?oNjM_og^WK00Gog^WK0_l00004on_Q
a`03o`000?o/lL[ok?7:00Sok?7:00?o0000on;mb?oRoLP00ooRoLP3o`0004Oooooo00?o0000oooo
ooooool04?ooool003gooooo0_l0001eooooo`;o00001?lbONH00ol0003oRjc/oh^/k008oh^/k003
o`000?ni_Mco^KgL00Co^KgL0_l00008okkDjP03o`000?oIe=CofMCD00_ofMCD00?o0000omkYfooN
jM/02?oNjM/2o`000003on_Qaol0003ok?7:00Wok?7:00?o0000on;mb?oRoLP00_oRoLP4o`0004So
oooo00?o0000ooooooooool04?ooool003oooooo00?o0000ooooooooool0Loooool4o`0000;o<WgV
00?o0000oh^/k?n;[>`02?n;[>`01?l0003o^KgLokVmg?ni_M`2o`0000_o_]CZ00?o0000omWDe?oI
e=@02OoIe=@00ol0003og^WKomkYf`0;omkYf`Ko00001Oo/lLX8o`000003ooooool0003ooooo04Oo
oooo00?o0000ooooooooool04?ooool0043ooooo00?o0000ooooooooool0M?ooool01_l0003o077K
o`000?l0003o<WgVo`0000[oRjc/00?o0000okVmg?l000003_nne>X00ol0003ofMCDomWDe007omWD
e003o`000?oNjM_og^WK00_og^WK00?o0000omSlg?oHo=`01?oHo=`6o`0000?o]o_80_l00004oooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool04?ooool0047ooooo0_l0001eooooo`03
o`000?l0LM_o077K00?o00001On;[>`7o`0000oo_]CZ00?o0000omWDe?oIe=@01OoIe=@00ol0003o
g^WKomkYf`0;omkYf`03o`000?oHo=cof?cL00Oof?cL00?o0000okOkb?ngnlP00ongnlP2o`0000Ko
oooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0@ooooo`00@?ooool00ol0003ooooo
o`00001fooooo`;o00000ol0LM/5o`0000OoNkkl00?o0000okkDj_nne>X03Onne>X00ol0003ofMCD
omWDe003omWDe003o`000?oNjM_og^WK00_og^WK00?o0000omSlg?oHo=`01ooHo=`00ol0003o]o_8
okOkb003okOkb003o`000?oooooooooo00Oooooo00?o0000ooooooooool0@oooool00ol0003ooooo
ooooo`0@ooooo`00@oooool00ol0003oooooooooo`1dooooo`;o00001?l0LM/00ol0003oNkklog^n
o008og^no003o`000?nne>[o_]CZ00go_]CZ00Go0000omWDe?oIe=CofMCDo`00000=omkYf`03o`00
0?oHo=cof?cL00Oof?cL00?o0000okOkb?ngnlP00_ngnlP2o`0000_ooooo00?o0000ooooooooool0
@_ooool00ol0003oooooooooo`0@ooooo`00A?ooool00ol0003oooooooooo`1eooooo`03o`000?l0
LM_o077K00;o077K00?o0000og^no?mk__`02?mk__`00ol0003o_]CZokkDjP0=okkDjP03o`000?oI
e=Co000000gog^WK00?o0000omSlg?oHo=`01ooHo=`00ol0003o]o_8okOkb002okOkb003o`000?oo
oooooooo00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0@ooooo`00AOooool0
0ol0003oooooooooo`1eooooo`03o`000?l0LM_o077K00;o077K00?o0000og^no?mk__`02?mk__`2
o`0000go_]CZ0ol0000<omkYf`03o`000?oHo=cof?cL00Oof?cL00Co0000okOkb?ngnlSo]o_80_l0
000@ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool04?ooool004Kooooo0_l0001f
ooooo`03o`000?l0LM_o077K00;o077K0_l0000:og^no003o`000?nne>[o_]CZ00So_]CZ0_l00003
ok[/m0?o00002?oNjM/00ol0003of?cLomSlg007omSlg003o`000?ngnlSo]o_800;o00004oooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo013ooooo0018ooooo`03o`000?oooooooooo
07Cooooo0_l00004o`1af`03o`000?mk__coNkkl00SoNkkl00?o0000okkDj_nne>X01Onne>X2o`00
00So^^cd0_l00005omkYf`03o`000?oHo=cof?cL00Oof?cL1?l0000Eooooo`03o`000?oooooooooo
043ooooo00?o0000ooooooooool03oooool004Wooooo00?o0000ooooooooool0MOooool3o`0000;o
077K00?o0000og^no?mk__`02?mk__`00ol0003o_]CZokkDjP02okkDjP;o00003?njk?@3o`000003
omkYfol0003of?cL00Sof?cL0ol0000Hooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool03oooool004[ooooo00?o0000ooooooooool0Moooool2o`000003o`1afol0003oNkkl00WoNkkl
00Co0000okkDj_l0003o00004?njk?@>o`0001[ooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0?ooooo`00B_ooool2o`0007[ooooo0ol00005og^no0Oo00003onjk?@2o`0000SoW??W
1?l0000Mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool03oooool004cooooo00?o
0000ooooooooool0N_ooool5o`0000OoE/Gh0ol0000:ok[/m0;o00002?nLlnL4o`00023ooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`0?ooooo`00COooool00ol0003oooooooooo`1k
ooooo`?o00002_mFaOP2o`0000Ko^^cd0_l00008oicci`?o00009?ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo00oooooo001>ooooo`03o`000?oooooooooo07cooooo0ol0000:oeK5
n0?o000000?o^^cdo`000?l000002?nLlnL3o`0002Oooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`0?ooooo`00Coooool2o`0007cooooo00?o0000ooooooooool00ol00005oeK5n13o
0000:_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00oooooo001Aooooo`03o`00
0?oooooooooo07Wooooo00?o0000ooooooooool00oooool?o`00037ooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0?ooooo`00D_ooool00ol0003oooooooooo`1hooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0?ooooo`00Doooool0
0ol0003oooooooooo`1gooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0?ooooo`00E?ooool3o`0007Kooooo00?o0000ooooooooool0A_ooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo00oooooo001Dooooo`;o0000Moooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03_ooool003Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Sooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool03_ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`08ooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool0BOooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00kooooo000hooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`08ooooo`;o0000Loooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03_ooool003So
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00_ooooo00?o0000oooo
ooooool0L?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool03_ooool003Sooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`03Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`0>ooooo`00>?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo04cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0>ooooo`00>?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0>
ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`;o0000K_ooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03_ooool0
05oooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool03_ooool0063ooooo00?o0000ooooooooool0J_ooool00ol0003o
ooooooooo`1@ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03_ooool0067ooooo
0_l0001Zooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0=ooooo`00Hoooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo057ooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0=ooooo`00I?ooool00ol0003oooooooooo`1V
ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0=
ooooo`00IOooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo05?ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0=ooooo`00I_ooool00ol0003oooooooooo`1Tooooo`03
o`000?oooooooooo05Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0=ooooo`00
I_ooool3o`0006Cooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo00gooooo001Xooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0E_oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00gooooo001Yooooo`03o`000?oooooo
oooo067ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00gooooo001Zooooo`;o0000HOooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool03Oooool006cooooo00?o0000ooooooooool0G_ooool00ol0003o
ooooooooo`1Hooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03Oooool006gooooo
00?o0000ooooooooool0GOooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool03Oooool006kooooo00?o0000ooooooooool0G?ooool00ol0003ooooooooo
o`1Jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03?ooool006oooooo00?o0000
ooooooooool0Foooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool03?ooool006oooooo0ol0001Kooooo`03o`000?oooooooooo05cooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0<ooooo`00LOooool00ol0003oooooooooo`1Iooooo`03
o`000?oooooooooo05gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0<ooooo`00
L_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0<ooooo`00Loooool2o`0005Sooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00cooooo001eooooo`03o`000?oooooo
oooo05Gooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo00cooooo001fooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo00cooooo001gooooo`03o`000?oooooooooo05?o
oooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00co
oooo001hooooo`;o0000Doooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool03?ooool007Sooooo0_l0001Cooooo`03o`000?oooooooooo06?ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0<ooooo`00N_ooool00ol0003oooooooooo`1@
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0<
ooooo`00Noooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo06Cooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0;ooooo`00O?ooool2o`0004oooooo00?o0000oooooooo
ool0IOooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00_ooooo001nooooo`03o`00
0?oooooooooo04cooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00_ooooo001oooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0Iooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo0020ooooo`03o`000?oooooo
oooo04[ooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo00_ooooo0021ooooo`?o0000BOooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool02oooool007Kooooo1?l000000ol@413oooooooooo`05ooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00_ooooo001hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
2oooool007Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`16ooooo`03o`000?oo
oooooooo06_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0;ooooo`00N?ooool0
0ol0003oooooooooo`0:ooooo`;o0000A_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool02oooool005cooooo0ol000000ol@413oooooooooo`0Foooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool005kooooo00?o410@okZj^_oo
ool05oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool0K_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo001Nooooo`03oiRH
V?lb<S;ooooo01Oooooo00?o0000ooooooooool03_ooool2o`0004;ooooo00?o0000ooooooooool0
Koooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo001Nooooo`03omgMgOl0
003o^[Zj01Gooooo00?oEEEEofIVI_l000004?ooool2o`0004;ooooo00?o0000ooooooooool0L?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00[ooooo001Nooooo`03oeEEEOmgMgOo
A4A402[ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool02_ooool005gooooo00GogMgMoa0@4?oooooo8B4QomgMg@0Z
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00[ooooo001Mooooo`05ofIVI_n7QhOooooooiRHV?mEEED0:oooool0
0ol0003oooooooooo`0mooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0:ooooo`00G?ooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo
02[ooooo0_l0000mooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0:ooooo`00G?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo
02_ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02_ooool0097ooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooooooo`1eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool0097ooooo
0_l0000jooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0:ooooo`00Toooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo07Oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`00U?ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`00UOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo07Sooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`00U_ooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo07Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`00
Uoooool2o`0003Cooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo002Iooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0Nooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo002Iooooo`?o0000<Oooool0
0ol0003oooooooooo`1looooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool0
09_ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02Oooool009cooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool009gooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02Oooool009kooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool009oooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02Oooool00:3ooooo0_l0000[ooooo`03o`000?oooooooooo087ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`08ooooo`00XOooool2o`0002[ooooo00?o0000oooooooo
ool0P_ooool01Ol0003ooooooooooooooooo000000[ooooo002Sooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0Poooool01?l0003oooooooooool0000:ooooo`00Y?ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo08Cooooo00?o0000ooooool000002_ooool00:Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`25ooooo`;o00002_ooool00:Kooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`24ooooo`?o00002_ooool00:Oooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`20ooooo`Co00003Oooool00:Sooooo00Co0000oooo
ool0003o00008Oooool00ol0003oooooooooo`1looooo`Co00004Oooool008kooooo1?l000000ol@
413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Kooooo0_l0000R
ooooo`03o`000?oooooooooo07Sooooo1?l0000Eooooo`00T?ooool00ol0003oooooooooo`04oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`07ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0M?ooool4o`0001Wooooo002@ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo073ooooo1?l0000Mooooo`00
T?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Wooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`1]ooooo`?o00008Oooool0093ooooo00?o0000ooooooooool02ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00_ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1Yooooo`Co00009?ooool0093ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0IOooool4o`0002Sooooo002@
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool3o`0001[ooooo00?o0000
ooooooooool0HOooool4o`0002cooooo002>ooooo`03oeEEEOmVIVKo000000gooooo1?l0000>oooo
o`;o00006oooool00ol0003oooooooooo`1Mooooo`Co0000<?ooool00;;ooooo0_l0000Iooooo`03
o`000?oooooooooo05Wooooo1?l0000dooooo`00]?ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo05Gooooo1?l0000hooooo`00]Oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo057ooooo1?l0000looooo`00]_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo04gooooo1?l00010ooooo`00]oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
04Wooooo1?l00014ooooo`00^?ooool2o`0001?ooooo00?o0000ooooooooool0AOooool4o`0004So
oooo002iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0@Oooool4o`0004cooooo
002jooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0?_ooool3o`00053ooooo002k
ooooo`;o00004?ooool00ol0003oooooooooo`0jooooo`Co0000Doooool00;gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0fooooo`Co0000Eoooool00;kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0booooo`Co0000Foooool00;oooooo0_l0000<ooooo`03o`00
0?oooooooooo02kooooo1?l0001Oooooo`00_oooool2o`0000cooooo00?o0000ooooooooool0:_oo
ool4o`0006?ooooo0031ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09_ooool4
o`0006Oooooo0032ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08_ooool4o`00
06_ooooo0033ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07_ooool4o`0006oo
oooo0034ooooo`;o00001oooool00ol0003oooooooooo`0Jooooo`Co0000Loooool00<Kooooo0ol0
0004ooooo`03o`000?oooooooooo01Kooooo1?l0001gooooo`00a_ooool2o`0000Gooooo00?o0000
ooooooooool04oooool3o`0007_ooooo0038ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03oooool4o`0007kooooo0039ooooo`05o`000?ooooooooooooooool000003Oooool4o`00
08;ooooo003:ooooo`04o`000?ooooooooooo`0000Wooooo1?l00026ooooo`00boooool00ol0003o
ooooo`000005ooooo`Co0000R_ooool00<cooooo1ol0002>ooooo`00`_ooool5o`0000Kooooo0_l0
002Booooo`00`_ooool01OnHV9So8B4Qonk^k_ooooooA4A409[ooooo0033ooooo`03oiRHV?lQ8B7o
k^k^09_ooooo0034ooooo`03oiRHV?lQ8B7ok^k^09[ooooo0035ooooo`03ogMgMomVIVKooooo09Wo
oooo0036ooooo`03o`000?oooooooooo09Sooooo0032ooooo`05o`000?nj^[[ooooooiRHV?l@4100
V_ooool00<;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02Jooooo`00oooooomRooooo`00oooooomR
ooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00oooooomR
ooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00oooooomR
ooooo`00oooooomRooooo`00YOooool3o`000003oa0@4?oooooooooo0;Kooooo002Cooooo`;o0000
2oooool00ol0003o^[Zjooooo`04ooooo`03oa0@4?nj^[[ooooo00Gooooo00?o0000okZj^_ooool0
3?ooool2o`0000Gooooo00?o0000okZj^_ooool0VOooool009?ooooo00?o0000ooooooooool02_oo
ool2oc8b<PGooooo00?oV9RHoc8b<_ooool01Oooool2oc8b<Pkooooo00?o0000ooooooooool00ooo
ool2oc8b<Y[ooooo0028ooooo`05oa0@4?l0003o0000o`000?l@41001_ooool01?l0003ooooooooo
ooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00?ogMgMo`000?nj^[X0
1Oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003o
ooooooooo`03ooooo`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P09oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`1^
ooooo`00R_ooool00ol0003oooooooooo`06ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7
Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool00omEEEGoMgMgodA4A005ooooo`03
olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo
00?ooooo00?oc<c<o`000?l@41001Oooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00000_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo073ooooo
002:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@
4?o<c<`:ooooo`05omgMgOl@413oooooob4Q8OoMgMd02oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@
00kooooo00?o0000ooooooooool0L?ooool008[ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo00GoIVIVohN7QoooooooV9RHoeEEE@0;
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03
ooooo`Ko00000_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool0L?oo
ool008[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOo
MgMgoc8b<PWooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`09ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`05o`000?oo
ooooooooooooool000003_ooool00ol0003oooooooooo`1`ooooo`00Qoooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o
00002?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00Kooooo00?o410@o`00
0?l000000ol00005ooooo`03o`000?oooooooooo00Wooooo00?o410@o`000?l000000ol0000:oooo
o`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`1`ooooo`00Qoooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool0L?ooool008Oooooo1ol00005
ooooo`;o00008Oooool00ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003oooooooooo`0;
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`00001booooo`00oooooomR
ooooo`00oooooomRooooo`00oooooomRooooo`00\
\>"],
  ImageRangeCache->{{{0, 352.438}, {392.188, 0}} -> {-0.0365789, -0.0401404, \
0.00334761, 0.00334761}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11253 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.066106 1.21212 -1.11022e-16 1.21212 [
[.5 1.12503 -44 0 ]
[.5 1.12503 44 24.5 ]
[.03831 .17557 -5.85635 -9 ]
[.03831 .17557 .14365 0 ]
[.12814 .13981 -17.2021 -9 ]
[.12814 .13981 .79789 0 ]
[.22015 .10319 -16.8352 -9 ]
[.22015 .10319 1.16484 0 ]
[.31441 .06568 -16.4682 -9 ]
[.31441 .06568 1.53178 0 ]
[.411 .02725 -16.1013 -9 ]
[.411 .02725 1.89873 0 ]
[.51 -0.01213 -5.24477 -9 ]
[.51 -0.01213 .75523 0 ]
[.21792 .02683 -9.25094 -12 ]
[.21792 .02683 .74906 0 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[.1484 .76875 -18 -3.08128 ]
[.1484 .76875 0 5.91872 ]
[.29382 .89692 -6 -3.18183 ]
[.29382 .89692 0 5.81817 ]
[.42456 1.01215 -18 -3.26907 ]
[.42456 1.01215 0 5.73093 ]
[.54272 1.11629 -6 -3.34548 ]
[.54272 1.11629 0 5.65452 ]
[.22112 .91822 -10 -4.24244 ]
[.22112 .91822 0 7.75756 ]
[.03467 .19213 -6 -2.71522 ]
[.03467 .19213 0 6.28478 ]
[.02559 .27239 -18 -2.7611 ]
[.02559 .27239 0 6.2389 ]
[.01617 .35567 -18 -2.80881 ]
[.01617 .35567 0 6.19119 ]
[.00638 .44212 -18 -2.85847 ]
[.00638 .44212 0 6.14153 ]
[-0.00378 .53194 -18 -2.9102 ]
[-0.00378 .53194 0 6.0898 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 1.11253 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.12503 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
.04875 .18654 m
.0558 .18375 L
s
[(0)] .03467 .19213 1 -0.39662 Mshowa
.03972 .26693 m
.04679 .2642 L
s
[(0.2)] .02559 .27239 1 -0.38642 Mshowa
.03035 .35034 m
.03744 .34767 L
s
[(0.4)] .01617 .35567 1 -0.37582 Mshowa
.02062 .43693 m
.02774 .43433 L
s
[(0.6)] .00638 .44212 1 -0.36478 Mshowa
.01051 .52689 m
.01765 .52437 L
s
[(0.8)] -0.00378 .53194 1 -0.35329 Mshowa
0 .62042 m
.00717 .61797 L
s
[(1)] -0.01434 .62532 1 -0.3413 Mshowa
.125 Mabswid
.04653 .20636 m
.05076 .2047 L
s
.04428 .22637 m
.04851 .22471 L
s
.04201 .24656 m
.04625 .24491 L
s
.03741 .28749 m
.04165 .28587 L
s
.03508 .30825 m
.03933 .30663 L
s
.03272 .32919 m
.03698 .32759 L
s
.02795 .37168 m
.03221 .37009 L
s
.02553 .39322 m
.02979 .39164 L
s
.02309 .41497 m
.02735 .4134 L
s
.01813 .45909 m
.0224 .45755 L
s
.01561 .48147 m
.01989 .47994 L
s
.01307 .50407 m
.01736 .50255 L
s
.00792 .54993 m
.01221 .54843 L
s
.00531 .5732 m
.0096 .5717 L
s
.00267 .59669 m
.00696 .59521 L
s
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
.5561 .7194 m
.04875 .18654 L
s
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.5561 .7194 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
0 0 m
1 0 L
1 1.11253 L
0 1.11253 L
closepath
clip
newpath
.5 Mabswid
.49 .673 .946 r
.52593 .68772 .5561 .7194 .58394 .7109 .55405 .68887 Metetra
.428 .723 .987 r
.55405 .68887 .58394 .7109 .61197 .70234 .58248 .68952 Metetra
.329 .749 .976 r
.58248 .68952 .61197 .70234 .64019 .69372 .6112 .68922 Metetra
.207 .723 .877 r
.6112 .68922 .64019 .69372 .66861 .68504 .6402 .68749 Metetra
.11 .663 .732 r
.6402 .68749 .66861 .68504 .69723 .6763 .66945 .68397 Metetra
.66945 .68397 .69723 .6763 .72605 .6675 .69891 .67837 Metetra
.69891 .67837 .72605 .6675 .75507 .65863 .72853 .67049 Metetra
.72853 .67049 .75507 .65863 .7843 .6497 .75828 .66025 Metetra
.284 .764 .663 r
.75828 .66025 .7843 .6497 .81374 .64071 .78812 .64772 Metetra
.452 .878 .782 r
.78812 .64772 .81374 .64071 .84339 .63166 .81801 .63305 Metetra
.62 .958 .89 r
.81801 .63305 .84339 .63166 .87325 .62254 .84794 .61652 Metetra
.733 .963 .939 r
.84794 .61652 .87325 .62254 .90333 .61335 .8779 .5985 Metetra
.778 .909 .931 r
.8779 .5985 .90333 .61335 .93362 .6041 .90789 .57943 Metetra
.78 .837 .896 r
.90789 .57943 .93362 .6041 .96413 .59478 .93794 .55978 Metetra
.203 .523 .918 r
.49498 .6552 .52593 .68772 .55405 .68887 .52326 .66565 Metetra
.078 .518 .901 r
.52326 .66565 .55405 .68887 .58248 .68952 .55197 .67525 Metetra
0 .501 .828 r
.55197 .67525 .58248 .68952 .6112 .68922 .58109 .68307 Metetra
0 .487 .722 r
.58109 .68307 .6112 .68922 .6402 .68749 .61059 .6882 Metetra
.094 0 0 r
.61059 .6882 .6402 .68749 .66945 .68397 .6404 .68983 Metetra
.028 0 0 r
.6404 .68983 .66945 .68397 .69891 .67837 .67046 .6874 Metetra
.67046 .6874 .69891 .67837 .72853 .67049 .70068 .6805 Metetra
.268 .758 .678 r
.70068 .6805 .72853 .67049 .75828 .66025 .73096 .66894 Metetra
.47 .885 .77 r
.73096 .66894 .75828 .66025 .78812 .64772 .76124 .65287 Metetra
.658 .972 .848 r
.76124 .65287 .78812 .64772 .81801 .63305 .79145 .63263 Metetra
.786 .991 .885 r
.79145 .63263 .81801 .63305 .84794 .61652 .82154 .60878 Metetra
.845 .957 .883 r
.82154 .60878 .84794 .61652 .8779 .5985 .85149 .58208 Metetra
.858 .899 .863 r
.85149 .58208 .8779 .5985 .90789 .57943 .88131 .55345 Metetra
.847 .838 .837 r
.88131 .55345 .90789 .57943 .93794 .55978 .91103 .52381 Metetra
0 .293 .776 r
.4632 .62183 .49498 .6552 .52326 .66565 .49153 .64075 Metetra
0 .255 .705 r
.49153 .64075 .52326 .66565 .55197 .67525 .52041 .65856 Metetra
0 .248 .632 r
.52041 .65856 .55197 .67525 .58109 .68307 .54981 .67389 Metetra
.31 0 0 r
.54981 .67389 .58109 .68307 .61059 .6882 .57971 .68538 Metetra
.226 0 0 r
.57971 .68538 .61059 .6882 .6404 .68983 .61001 .69182 Metetra
.069 0 0 r
.61001 .69182 .6404 .68983 .67046 .6874 .64062 .69235 Metetra
.156 .694 .719 r
.64062 .69235 .67046 .6874 .70068 .6805 .6714 .68635 Metetra
.419 .864 .809 r
.6714 .68635 .70068 .6805 .73096 .66894 .70223 .67352 Metetra
.647 .968 .863 r
.70223 .67352 .73096 .66894 .76124 .65287 .733 .65409 Metetra
.795 .994 .873 r
.733 .65409 .76124 .65287 .79145 .63263 .76359 .6286 Metetra
.869 .969 .855 r
.76359 .6286 .79145 .63263 .82154 .60878 .79394 .59789 Metetra
.896 .924 .831 r
.79394 .59789 .82154 .60878 .85149 .58208 .82401 .56311 Metetra
.896 .876 .808 r
.82401 .56311 .85149 .58208 .88131 .55345 .8538 .52564 Metetra
.882 .829 .79 r
.8538 .52564 .88131 .55345 .91103 .52381 .88337 .48685 Metetra
0 .076 .586 r
.43058 .58756 .4632 .62183 .49153 .64075 .45885 .61365 Metetra
.475 0 0 r
.45885 .61365 .49153 .64075 .52041 .65856 .48778 .63844 Metetra
.483 0 0 r
.48778 .63844 .52041 .65856 .54981 .67389 .51737 .66022 Metetra
.425 0 0 r
.51737 .66022 .54981 .67389 .57971 .68538 .54755 .67718 Metetra
.287 0 0 r
.54755 .67718 .57971 .68538 .61001 .69182 .57825 .68778 Metetra
0 .533 .727 r
.57825 .68778 .61001 .69182 .64062 .69235 .60933 .69085 Metetra
.27 .774 .861 r
.60933 .69085 .64062 .69235 .6714 .68635 .64064 .68559 Metetra
.574 .935 .924 r
.64064 .68559 .6714 .68635 .70223 .67352 .67202 .67161 Metetra
.766 .982 .909 r
.67202 .67161 .70223 .67352 .733 .65409 .7033 .6492 Metetra
.862 .965 .865 r
.7033 .6492 .733 .65409 .76359 .6286 .73434 .61908 Metetra
.902 .928 .824 r
.73434 .61908 .76359 .6286 .79394 .59789 .76506 .58237 Metetra
.914 .888 .792 r
.76506 .58237 .79394 .59789 .82401 .56311 .79538 .54057 Metetra
.911 .851 .77 r
.79538 .54057 .82401 .56311 .8538 .52564 .82533 .49547 Metetra
.9 .817 .756 r
.82533 .49547 .8538 .52564 .88337 .48685 .85493 .44884 Metetra
.561 .067 0 r
.39706 .55236 .43058 .58756 .45885 .61365 .42522 .5839 Metetra
.584 .066 0 r
.42522 .5839 .45885 .61365 .48778 .63844 .45412 .61405 Metetra
.558 .015 0 r
.45412 .61405 .48778 .63844 .51737 .66022 .48378 .64076 Metetra
.467 0 0 r
.48378 .64076 .51737 .66022 .54755 .67718 .51416 .66194 Metetra
0 .297 .654 r
.51416 .66194 .54755 .67718 .57825 .68778 .54516 .67574 Metetra
.03 .571 .844 r
.54516 .67574 .57825 .68778 .60933 .69085 .57664 .68075 Metetra
.4 .819 .971 r
.57664 .68075 .60933 .69085 .64064 .68559 .60842 .676 Metetra
.677 .931 .969 r
.60842 .676 .64064 .68559 .67202 .67161 .64031 .66104 Metetra
.818 .941 .907 r
.64031 .66104 .67202 .67161 .7033 .6492 .67212 .63622 Metetra
.881 .915 .845 r
.67212 .63622 .7033 .6492 .73434 .61908 .70368 .6024 Metetra
.908 .884 .798 r
.70368 .6024 .73434 .61908 .76506 .58237 .73485 .56091 Metetra
.917 .854 .765 r
.73485 .56091 .76506 .58237 .79538 .54057 .76558 .51357 Metetra
.916 .829 .745 r
.76558 .51357 .79538 .54057 .82533 .49547 .79584 .46249 Metetra
.909 .806 .734 r
.79584 .46249 .82533 .49547 .85493 .44884 .82567 .40974 Metetra
.635 .142 0 r
.36263 .5162 .39706 .55236 .42522 .5839 .39063 .55115 Metetra
.628 .121 0 r
.39063 .55115 .42522 .5839 .45412 .61405 .41945 .58467 Metetra
.574 .05 0 r
.41945 .58467 .45412 .61405 .48378 .64076 .44912 .61452 Metetra
.449 0 0 r
.44912 .61452 .48378 .64076 .51416 .66194 .47961 .63836 Metetra
0 .32 .737 r
.47961 .63836 .51416 .66194 .54516 .67574 .51082 .65415 Metetra
.148 .601 .93 r
.51082 .65415 .54516 .67574 .57664 .68075 .54262 .66032 Metetra
.499 .802 .999 r
.54262 .66032 .57664 .68075 .60842 .676 .57481 .65581 Metetra
.718 .875 .954 r
.57481 .65581 .60842 .676 .64031 .66104 .60718 .6401 Metetra
.825 .878 .883 r
.60718 .6401 .64031 .66104 .67212 .63622 .63951 .61357 Metetra
.876 .862 .823 r
.63951 .61357 .67212 .63622 .70368 .6024 .67162 .5772 Metetra
.9 .843 .779 r
.67162 .5772 .70368 .6024 .73485 .56091 .70333 .53247 Metetra
.911 .825 .749 r
.70333 .53247 .73485 .56091 .76558 .51357 .73457 .4814 Metetra
.913 .81 .731 r
.73457 .4814 .76558 .51357 .79584 .46249 .76531 .42632 Metetra
.911 .796 .721 r
.76531 .42632 .79584 .46249 .82567 .40974 .79557 .36951 Metetra
.657 .165 0 r
.32723 .47902 .36263 .5162 .39063 .55115 .3551 .51515 Metetra
.624 .126 0 r
.3551 .51515 .39063 .55115 .41945 .58467 .38384 .54983 Metetra
.54 .035 0 r
.38384 .54983 .41945 .58467 .44912 .61452 .41348 .58073 Metetra
0 .129 .619 r
.41348 .58073 .44912 .61452 .47961 .63836 .44402 .60546 Metetra
0 .367 .818 r
.44402 .60546 .47961 .63836 .51082 .65415 .47539 .62186 Metetra
.27 .606 .954 r
.47539 .62186 .51082 .65415 .54262 .66032 .50743 .62832 Metetra
.554 .75 .968 r
.50743 .62832 .54262 .66032 .57481 .65581 .53995 .62372 Metetra
.723 .804 .915 r
.53995 .62372 .57481 .65581 .60718 .6401 .57275 .6075 Metetra
.811 .816 .854 r
.57275 .6075 .60718 .6401 .63951 .61357 .60558 .5801 Metetra
.858 .813 .804 r
.60558 .5801 .63951 .61357 .67162 .5772 .63823 .54251 Metetra
.884 .806 .766 r
.63823 .54251 .67162 .5772 .70333 .53247 .67054 .49629 Metetra
.899 .799 .741 r
.67054 .49629 .70333 .53247 .73457 .4814 .70239 .44355 Metetra
.906 .793 .725 r
.70239 .44355 .73457 .4814 .76531 .42632 .73372 .38669 Metetra
.908 .788 .716 r
.73372 .38669 .76531 .42632 .79557 .36951 .76458 .32809 Metetra
.635 .142 0 r
.29083 .44079 .32723 .47902 .3551 .51515 .31865 .47571 Metetra
.574 .085 0 r
.31865 .47571 .3551 .51515 .38384 .54983 .34734 .50919 Metetra
0 .028 .547 r
.34734 .50919 .38384 .54983 .41348 .58073 .37698 .53896 Metetra
0 .207 .715 r
.37698 .53896 .41348 .58073 .44402 .60546 .40756 .56266 Metetra
.074 .421 .867 r
.40756 .56266 .44402 .60546 .47539 .62186 .43902 .5782 Metetra
.369 .594 .933 r
.43902 .5782 .47539 .62186 .50743 .62832 .47124 .58399 Metetra
.581 .694 .919 r
.47124 .58399 .50743 .62832 .53995 .62372 .50403 .57894 Metetra
.712 .74 .874 r
.50403 .57894 .53995 .62372 .57275 .6075 .53718 .56251 Metetra
.788 .76 .827 r
.53718 .56251 .57275 .6075 .60558 .5801 .57046 .53513 Metetra
.834 .768 .789 r
.57046 .53513 .60558 .5801 .63823 .54251 .60364 .49776 Metetra
.863 .772 .759 r
.60364 .49776 .63823 .54251 .67054 .49629 .63655 .45193 Metetra
.882 .775 .738 r
.63655 .45193 .67054 .49629 .70239 .44355 .66905 .39969 Metetra
.894 .777 .725 r
.66905 .39969 .70239 .44355 .73372 .38669 .70109 .34342 Metetra
.901 .78 .719 r
.70109 .34342 .73372 .38669 .76458 .32809 .73265 .28543 Metetra
.561 .067 0 r
.25338 .40146 .29083 .44079 .31865 .47571 .28128 .43284 Metetra
0 .011 .534 r
.28128 .43284 .31865 .47571 .34734 .50919 .31003 .46282 Metetra
0 .14 .667 r
.31003 .46282 .34734 .50919 .37698 .53896 .33972 .4893 Metetra
0 .307 .799 r
.33972 .4893 .37698 .53896 .40756 .56266 .37037 .51011 Metetra
.223 .466 .88 r
.37037 .51011 .40756 .56266 .43902 .5782 .40192 .52334 Metetra
.441 .58 .896 r
.40192 .52334 .43902 .5782 .47124 .58399 .43427 .52753 Metetra
.594 .649 .874 r
.43427 .52753 .47124 .58399 .50403 .57894 .46726 .52168 Metetra
.696 .689 .839 r
.46726 .52168 .50403 .57894 .53718 .56251 .50069 .50532 Metetra
.762 .713 .806 r
.50069 .50532 .53718 .56251 .57046 .53513 .53434 .47882 Metetra
.807 .729 .778 r
.53434 .47882 .57046 .53513 .60364 .49776 .56799 .44307 Metetra
.839 .741 .757 r
.56799 .44307 .60364 .49776 .63655 .45193 .60147 .39946 Metetra
.861 .752 .741 r
.60147 .39946 .63655 .45193 .66905 .39969 .63463 .34988 Metetra
.878 .763 .731 r
.63463 .34988 .66905 .39969 .70109 .34342 .6674 .2965 Metetra
.889 .773 .728 r
.6674 .2965 .70109 .34342 .73265 .28543 .69976 .24147 Metetra
0 .076 .586 r
.21484 .36098 .25338 .40146 .28128 .43284 .243 .38663 Metetra
0 .166 .687 r
.243 .38663 .28128 .43284 .31003 .46282 .27197 .41096 Metetra
0 .284 .785 r
.27197 .41096 .31003 .46282 .33972 .4893 .30183 .43216 Metetra
.154 .404 .849 r
.30183 .43216 .33972 .4893 .37037 .51011 .3326 .44837 Metetra
.348 .501 .869 r
.3326 .44837 .37037 .51011 .40192 .52334 .36426 .45796 Metetra
.495 .569 .86 r
.36426 .45796 .40192 .52334 .43427 .52753 .39673 .4597 Metetra
.602 .615 .837 r
.39673 .4597 .43427 .52753 .46726 .52168 .42986 .45275 Metetra
.679 .648 .812 r
.42986 .45275 .46726 .52168 .50069 .50532 .46349 .4367 Metetra
.735 .673 .79 r
.46349 .4367 .50069 .50532 .53434 .47882 .49741 .41187 Metetra
.777 .694 .772 r
.49741 .41187 .53434 .47882 .56799 .44307 .53145 .37902 Metetra
.81 .712 .758 r
.53145 .37902 .56799 .44307 .60147 .39946 .56542 .33931 Metetra
.835 .73 .748 r
.56542 .33931 .60147 .39946 .63463 .34988 .59919 .29436 Metetra
.856 .748 .743 r
.59919 .29436 .63463 .34988 .6674 .2965 .63268 .24603 Metetra
.872 .766 .743 r
.63268 .24603 .6674 .2965 .69976 .24147 .66586 .19616 Metetra
0 .293 .776 r
.17516 .3193 .21484 .36098 .243 .38663 .20382 .33728 Metetra
.017 .36 .832 r
.20382 .33728 .243 .38663 .27197 .41096 .2332 .35408 Metetra
.181 .427 .86 r
.2332 .35408 .27197 .41096 .30183 .43216 .26337 .3683 Metetra
.328 .484 .863 r
.26337 .3683 .30183 .43216 .3326 .44837 .29438 .37845 Metetra
.447 .529 .849 r
.29438 .37845 .3326 .44837 .36426 .45796 .3262 .3833 Metetra
.538 .564 .829 r
.3262 .3833 .36426 .45796 .39673 .4597 .35878 .38188 Metetra
.608 .592 .809 r
.35878 .38188 .39673 .4597 .42986 .45275 .39201 .37356 Metetra
.664 .617 .792 r
.39201 .37356 .42986 .45275 .46349 .4367 .42576 .35803 Metetra
.708 .64 .778 r
.42576 .35803 .46349 .4367 .49741 .41187 .45986 .33553 Metetra
.745 .662 .768 r
.45986 .33553 .49741 .41187 .53145 .37902 .49416 .30664 Metetra
.776 .684 .762 r
.49416 .30664 .53145 .37902 .56542 .33931 .52851 .27226 Metetra
.803 .707 .759 r
.52851 .27226 .56542 .33931 .59919 .29436 .5628 .23362 Metetra
.826 .731 .76 r
.5628 .23362 .59919 .29436 .63268 .24603 .59694 .1922 Metetra
.845 .758 .766 r
.59694 .1922 .63268 .24603 .66586 .19616 .63089 .14942 Metetra
.203 .523 .918 r
.13429 .27638 .17516 .3193 .20382 .33728 .16371 .28511 Metetra
.304 .529 .906 r
.16371 .28511 .20382 .33728 .2332 .35408 .19372 .29291 Metetra
.392 .535 .88 r
.19372 .29291 .2332 .35408 .26337 .3683 .2244 .29881 Metetra
.465 .543 .852 r
.2244 .29881 .26337 .3683 .29438 .37845 .25578 .30182 Metetra
.524 .553 .827 r
.25578 .30182 .29438 .37845 .3262 .3833 .28784 .30109 Metetra
.573 .564 .806 r
.28784 .30109 .3262 .3833 .35878 .38188 .32056 .296 Metetra
.614 .578 .79 r
.32056 .296 .35878 .38188 .39201 .37356 .35386 .28612 Metetra
.65 .594 .778 r
.35386 .28612 .39201 .37356 .42576 .35803 .38765 .27126 Metetra
.682 .612 .771 r
.38765 .27126 .42576 .35803 .45986 .33553 .42181 .25156 Metetra
.711 .632 .768 r
.42181 .25156 .45986 .33553 .49416 .30664 .45625 .22742 Metetra
.737 .656 .769 r
.45625 .22742 .49416 .30664 .52851 .27226 .49084 .19942 Metetra
.762 .682 .774 r
.49084 .19942 .52851 .27226 .5628 .23362 .52551 .16839 Metetra
.785 .712 .783 r
.52551 .16839 .5628 .23362 .59694 .1922 .56017 .13532 Metetra
.806 .745 .796 r
.56017 .13532 .59694 .1922 .63089 .14942 .59481 .1012 Metetra
.49 .673 .946 r
.09217 .23214 .13429 .27638 .16371 .28511 .12262 .23052 Metetra
.521 .635 .904 r
.12262 .23052 .16371 .28511 .19372 .29291 .15352 .22833 Metetra
.545 .606 .865 r
.15352 .22833 .19372 .29291 .2244 .29881 .18491 .22507 Metetra
.567 .586 .832 r
.18491 .22507 .2244 .29881 .25578 .30182 .2168 .22024 Metetra
.586 .574 .807 r
.2168 .22024 .25578 .30182 .28784 .30109 .24921 .21345 Metetra
.603 .569 .789 r
.24921 .21345 .28784 .30109 .32056 .296 .2821 .20438 Metetra
.621 .571 .777 r
.2821 .20438 .32056 .296 .35386 .28612 .31546 .19284 Metetra
.638 .577 .77 r
.31546 .19284 .35386 .28612 .38765 .27126 .34923 .17871 Metetra
.655 .589 .768 r
.34923 .17871 .38765 .27126 .42181 .25156 .38336 .16209 Metetra
.673 .605 .771 r
.38336 .16209 .42181 .25156 .45625 .22742 .4178 .14314 Metetra
.691 .626 .779 r
.4178 .14314 .45625 .22742 .49084 .19942 .45247 .12217 Metetra
.71 .653 .791 r
.45247 .12217 .49084 .19942 .52551 .16839 .48735 .09956 Metetra
.729 .686 .808 r
.48735 .09956 .52551 .16839 .56017 .13532 .52239 .07581 Metetra
.747 .725 .831 r
.52239 .07581 .56017 .13532 .59481 .1012 .55756 .05142 Metetra
.666 .738 .904 r
.04875 .18654 .09217 .23214 .12262 .23052 .08051 .17394 Metetra
.659 .689 .867 r
.08051 .17394 .12262 .23052 .15352 .22833 .11254 .16124 Metetra
.65 .649 .835 r
.11254 .16124 .15352 .22833 .18491 .22507 .14483 .14843 Metetra
.642 .617 .81 r
.14483 .14843 .18491 .22507 .2168 .22024 .1774 .13551 Metetra
.636 .594 .791 r
.1774 .13551 .2168 .22024 .24921 .21345 .21025 .12249 Metetra
.631 .579 .777 r
.21025 .12249 .24921 .21345 .2821 .20438 .24339 .10934 Metetra
.628 .57 .769 r
.24339 .10934 .2821 .20438 .31546 .19284 .27681 .09609 Metetra
.627 .567 .767 r
.27681 .09609 .31546 .19284 .34923 .17871 .31052 .08272 Metetra
.628 .57 .769 r
.31052 .08272 .34923 .17871 .38336 .16209 .34452 .06923 Metetra
.631 .579 .777 r
.34452 .06923 .38336 .16209 .4178 .14314 .37882 .05563 Metetra
.636 .594 .791 r
.37882 .05563 .4178 .14314 .45247 .12217 .41342 .04191 Metetra
.642 .617 .81 r
.41342 .04191 .45247 .12217 .48735 .09956 .44833 .02806 Metetra
.65 .649 .835 r
.44833 .02806 .48735 .09956 .52239 .07581 .48355 .01409 Metetra
.659 .689 .867 r
.48355 .01409 .52239 .07581 .55756 .05142 .51908 0 Metetra
0 g
.25 Mabswid
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282.75, 314.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11253 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.066106 1.21212 -1.11022e-16 1.21212 [
[.5 1.12503 -44 0 ]
[.5 1.12503 44 24.5 ]
[.03831 .17557 -5.85635 -9 ]
[.03831 .17557 .14365 0 ]
[.12814 .13981 -17.2021 -9 ]
[.12814 .13981 .79789 0 ]
[.22015 .10319 -16.8352 -9 ]
[.22015 .10319 1.16484 0 ]
[.31441 .06568 -16.4682 -9 ]
[.31441 .06568 1.53178 0 ]
[.411 .02725 -16.1013 -9 ]
[.411 .02725 1.89873 0 ]
[.51 -0.01213 -5.24477 -9 ]
[.51 -0.01213 .75523 0 ]
[.21792 .02683 -9.25094 -12 ]
[.21792 .02683 .74906 0 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[.1484 .76875 -18 -3.08128 ]
[.1484 .76875 0 5.91872 ]
[.29382 .89692 -6 -3.18183 ]
[.29382 .89692 0 5.81817 ]
[.42456 1.01215 -18 -3.26907 ]
[.42456 1.01215 0 5.73093 ]
[.54272 1.11629 -6 -3.34548 ]
[.54272 1.11629 0 5.65452 ]
[.22112 .91822 -10 -4.24244 ]
[.22112 .91822 0 7.75756 ]
[.03467 .19213 -6 -2.71522 ]
[.03467 .19213 0 6.28478 ]
[.02559 .27239 -18 -2.7611 ]
[.02559 .27239 0 6.2389 ]
[.01617 .35567 -18 -2.80881 ]
[.01617 .35567 0 6.19119 ]
[.00638 .44212 -18 -2.85847 ]
[.00638 .44212 0 6.14153 ]
[-0.00378 .53194 -18 -2.9102 ]
[-0.00378 .53194 0 6.0898 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 1.11253 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.12503 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
.04875 .18654 m
.0558 .18375 L
s
[(0)] .03467 .19213 1 -0.39662 Mshowa
.03972 .26693 m
.04679 .2642 L
s
[(0.2)] .02559 .27239 1 -0.38642 Mshowa
.03035 .35034 m
.03744 .34767 L
s
[(0.4)] .01617 .35567 1 -0.37582 Mshowa
.02062 .43693 m
.02774 .43433 L
s
[(0.6)] .00638 .44212 1 -0.36478 Mshowa
.01051 .52689 m
.01765 .52437 L
s
[(0.8)] -0.00378 .53194 1 -0.35329 Mshowa
0 .62042 m
.00717 .61797 L
s
[(1)] -0.01434 .62532 1 -0.3413 Mshowa
.125 Mabswid
.04653 .20636 m
.05076 .2047 L
s
.04428 .22637 m
.04851 .22471 L
s
.04201 .24656 m
.04625 .24491 L
s
.03741 .28749 m
.04165 .28587 L
s
.03508 .30825 m
.03933 .30663 L
s
.03272 .32919 m
.03698 .32759 L
s
.02795 .37168 m
.03221 .37009 L
s
.02553 .39322 m
.02979 .39164 L
s
.02309 .41497 m
.02735 .4134 L
s
.01813 .45909 m
.0224 .45755 L
s
.01561 .48147 m
.01989 .47994 L
s
.01307 .50407 m
.01736 .50255 L
s
.00792 .54993 m
.01221 .54843 L
s
.00531 .5732 m
.0096 .5717 L
s
.00267 .59669 m
.00696 .59521 L
s
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
.5561 .7194 m
.04875 .18654 L
s
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.5561 .7194 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
0 0 m
1 0 L
1 1.11253 L
0 1.11253 L
closepath
clip
newpath
.5 Mabswid
.547 .697 .938 r
.52593 .68772 .5561 .7194 .58394 .7109 .55404 .68626 Metetra
.522 .741 .975 r
.55404 .68626 .58394 .7109 .61197 .70234 .58243 .68442 Metetra
.487 .784 .997 r
.58243 .68442 .61197 .70234 .64019 .69372 .6111 .68184 Metetra
.445 .816 .993 r
.6111 .68184 .64019 .69372 .66861 .68504 .64001 .6782 Metetra
.407 .832 .962 r
.64001 .6782 .66861 .68504 .69723 .6763 .66917 .67323 Metetra
.39 .84 .923 r
.66917 .67323 .69723 .6763 .72605 .6675 .69853 .6667 Metetra
.404 .854 .898 r
.69853 .6667 .72605 .6675 .75507 .65863 .72807 .6585 Metetra
.454 .882 .899 r
.72807 .6585 .75507 .65863 .7843 .6497 .75775 .64855 Metetra
.529 .916 .922 r
.75775 .64855 .7843 .6497 .81374 .64071 .78756 .6369 Metetra
.614 .941 .95 r
.78756 .6369 .81374 .64071 .84339 .63166 .81747 .62366 Metetra
.686 .94 .964 r
.81747 .62366 .84339 .63166 .87325 .62254 .84746 .60904 Metetra
.731 .911 .956 r
.84746 .60904 .87325 .62254 .90333 .61335 .87753 .5933 Metetra
.75 .865 .932 r
.87753 .5933 .90333 .61335 .93362 .6041 .90768 .57676 Metetra
.751 .813 .901 r
.90768 .57676 .93362 .6041 .96413 .59478 .93794 .55978 Metetra
.375 .618 .946 r
.49498 .6552 .52593 .68772 .55404 .68626 .52328 .66052 Metetra
.323 .645 .967 r
.52328 .66052 .55404 .68626 .58243 .68442 .55194 .66517 Metetra
.279 .675 .971 r
.55194 .66517 .58243 .68442 .6111 .68184 .58097 .66847 Metetra
.257 .708 .956 r
.58097 .66847 .6111 .68184 .64001 .6782 .61032 .66976 Metetra
.269 .747 .934 r
.61032 .66976 .64001 .6782 .66917 .67323 .63996 .66846 Metetra
.321 .795 .919 r
.63996 .66846 .66917 .67323 .69853 .6667 .66984 .66418 Metetra
.407 .852 .919 r
.66984 .66418 .69853 .6667 .72807 .6585 .69989 .65662 Metetra
.517 .908 .931 r
.69989 .65662 .72807 .6585 .75775 .64855 .73005 .64564 Metetra
.627 .948 .943 r
.73005 .64564 .75775 .64855 .78756 .6369 .76026 .63135 Metetra
.718 .96 .944 r
.76026 .63135 .78756 .6369 .81747 .62366 .79048 .61399 Metetra
.778 .945 .932 r
.79048 .61399 .81747 .62366 .84746 .60904 .82067 .59397 Metetra
.808 .91 .91 r
.82067 .59397 .84746 .60904 .87753 .5933 .85082 .57182 Metetra
.816 .866 .884 r
.85082 .57182 .87753 .5933 .90768 .57676 .88093 .54821 Metetra
.809 .82 .859 r
.88093 .54821 .90768 .57676 .93794 .55978 .91103 .52381 Metetra
.16 .497 .907 r
.4632 .62183 .49498 .6552 .52328 .66052 .49161 .6333 Metetra
.098 .505 .904 r
.49161 .6333 .52328 .66052 .55194 .66517 .52046 .64388 Metetra
.069 .532 .898 r
.52046 .64388 .55194 .66517 .58097 .66847 .54977 .65258 Metetra
.09 .586 .898 r
.54977 .65258 .58097 .66847 .61032 .66976 .57949 .6584 Metetra
.166 .666 .911 r
.57949 .6584 .61032 .66976 .63996 .66846 .60956 .66051 Metetra
.289 .763 .934 r
.60956 .66051 .63996 .66846 .66984 .66418 .63991 .65828 Metetra
.44 .857 .956 r
.63991 .65828 .66984 .66418 .69989 .65662 .67045 .65129 Metetra
.589 .925 .963 r
.67045 .65129 .69989 .65662 .73005 .64564 .70109 .63933 Metetra
.708 .954 .951 r
.70109 .63933 .73005 .64564 .76026 .63135 .73174 .62255 Metetra
.787 .95 .926 r
.73174 .62255 .76026 .63135 .79048 .61399 .76232 .60134 Metetra
.831 .926 .896 r
.76232 .60134 .79048 .61399 .82067 .59397 .79279 .57627 Metetra
.85 .892 .867 r
.79279 .57627 .82067 .59397 .85082 .57182 .82311 .54818 Metetra
.853 .855 .843 r
.82311 .54818 .85082 .57182 .88093 .54821 .8533 .51804 Metetra
.845 .818 .823 r
.8533 .51804 .88093 .54821 .91103 .52381 .88337 .48685 Metetra
0 .357 .824 r
.43058 .58756 .4632 .62183 .49161 .6333 .45901 .60423 Metetra
0 .36 .81 r
.45901 .60423 .49161 .6333 .52046 .64388 .48798 .61983 Metetra
0 .4 .816 r
.48798 .61983 .52046 .64388 .54977 .65258 .51749 .63311 Metetra
0 .484 .85 r
.51749 .63311 .54977 .65258 .57949 .6584 .5475 .64281 Metetra
.112 .606 .905 r
.5475 .64281 .57949 .6584 .60956 .66051 .57794 .64782 Metetra
.295 .742 .961 r
.57794 .64782 .60956 .66051 .63991 .65828 .60871 .64733 Metetra
.489 .854 .989 r
.60871 .64733 .63991 .65828 .67045 .65129 .63972 .64079 Metetra
.651 .917 .978 r
.63972 .64079 .67045 .65129 .70109 .63933 .67083 .62793 Metetra
.76 .932 .943 r
.67083 .62793 .70109 .63933 .73174 .62255 .70194 .60895 Metetra
.824 .92 .901 r
.70194 .60895 .73174 .62255 .76232 .60134 .73294 .58434 Metetra
.857 .896 .863 r
.73294 .58434 .76232 .60134 .79279 .57627 .76376 .55488 Metetra
.871 .868 .832 r
.76376 .55488 .79279 .57627 .82311 .54818 .79436 .52163 Metetra
.872 .839 .81 r
.79436 .52163 .82311 .54818 .8533 .51804 .82474 .48586 Metetra
.865 .812 .795 r
.82474 .48586 .8533 .51804 .88337 .48685 .85493 .44884 Metetra
0 .238 .732 r
.39706 .55236 .43058 .58756 .45901 .60423 .42548 .57295 Metetra
0 .251 .728 r
.42548 .57295 .45901 .60423 .48798 .61983 .45451 .59237 Metetra
0 .31 .759 r
.45451 .59237 .48798 .61983 .51749 .63311 .48415 .60915 Metetra
0 .421 .827 r
.48415 .60915 .51749 .63311 .5475 .64281 .51437 .62179 Metetra
.108 .571 .914 r
.51437 .62179 .5475 .64281 .57794 .64782 .54511 .62899 Metetra
.329 .723 .982 r
.54511 .62899 .57794 .64782 .60871 .64733 .57625 .6298 Metetra
.537 .832 .999 r
.57625 .6298 .60871 .64733 .63972 .64079 .60768 .62355 Metetra
.69 .883 .97 r
.60768 .62355 .63972 .64079 .67083 .62793 .63925 .60991 Metetra
.784 .893 .922 r
.63925 .60991 .67083 .62793 .70194 .60895 .67083 .58913 Metetra
.837 .881 .875 r
.67083 .58913 .70194 .60895 .73294 .58434 .70229 .5618 Metetra
.865 .863 .836 r
.70229 .5618 .73294 .58434 .76376 .55488 .73354 .52884 Metetra
.877 .843 .807 r
.73354 .52884 .76376 .55488 .79436 .52163 .76452 .49152 Metetra
.88 .823 .788 r
.76452 .49152 .79436 .52163 .82474 .48586 .79522 .45132 Metetra
.876 .805 .775 r
.79522 .45132 .82474 .48586 .85493 .44884 .82567 .40974 Metetra
0 .162 .667 r
.36263 .5162 .39706 .55236 .42548 .57295 .39101 .53922 Metetra
0 .191 .682 r
.39101 .53922 .42548 .57295 .45451 .59237 .42005 .56101 Metetra
0 .269 .739 r
.42005 .56101 .45451 .59237 .48415 .60915 .44977 .57995 Metetra
0 .397 .83 r
.44977 .57995 .48415 .60915 .51437 .62179 .48016 .59441 Metetra
.146 .556 .927 r
.48016 .59441 .51437 .62179 .54511 .62899 .51113 .60295 Metetra
.377 .701 .984 r
.51113 .60295 .54511 .62899 .57625 .6298 .54259 .60449 Metetra
.572 .794 .983 r
.54259 .60449 .57625 .6298 .60768 .62355 .5744 .59832 Metetra
.706 .836 .945 r
.5744 .59832 .60768 .62355 .63925 .60991 .6064 .58406 Metetra
.787 .846 .896 r
.6064 .58406 .63925 .60991 .67083 .58913 .63844 .56199 Metetra
.834 .841 .851 r
.63844 .56199 .67083 .58913 .70229 .5618 .67039 .53277 Metetra
.861 .831 .816 r
.67039 .53277 .70229 .5618 .73354 .52884 .70212 .49742 Metetra
.875 .819 .79 r
.70212 .49742 .73354 .52884 .76452 .49152 .73357 .45733 Metetra
.881 .808 .773 r
.73357 .45733 .76452 .49152 .79522 .45132 .76471 .41415 Metetra
.88 .797 .763 r
.76471 .41415 .79522 .45132 .82567 .40974 .79557 .36951 Metetra
0 .137 .644 r
.32723 .47902 .36263 .5162 .39101 .53922 .35559 .50282 Metetra
0 .181 .681 r
.35559 .50282 .39101 .53922 .42005 .56101 .38464 .52537 Metetra
0 .273 .755 r
.38464 .52537 .42005 .56101 .44977 .57995 .41443 .545 Metetra
0 .407 .852 r
.41443 .545 .44977 .57995 .48016 .59441 .44493 .55999 Metetra
.213 .554 .933 r
.44493 .55999 .48016 .59441 .51113 .60295 .4761 .56888 Metetra
.426 .675 .966 r
.4761 .56888 .51113 .60295 .54259 .60449 .50782 .57053 Metetra
.593 .75 .952 r
.50782 .57053 .54259 .60449 .5744 .59832 .53995 .5642 Metetra
.707 .787 .913 r
.53995 .5642 .5744 .59832 .6064 .58406 .57235 .5495 Metetra
.779 .8 .87 r
.57235 .5495 .6064 .58406 .63844 .56199 .60484 .52673 Metetra
.823 .803 .832 r
.60484 .52673 .63844 .56199 .67039 .53277 .63728 .49656 Metetra
.851 .801 .802 r
.63728 .49656 .67039 .53277 .70212 .49742 .66953 .46006 Metetra
.867 .797 .78 r
.66953 .46006 .70212 .49742 .73357 .45733 .70151 .41868 Metetra
.876 .794 .766 r
.70151 .41868 .73357 .45733 .76471 .41415 .73319 .37413 Metetra
.879 .79 .758 r
.73319 .37413 .76471 .41415 .79557 .36951 .76458 .32809 Metetra
0 .162 .667 r
.29083 .44079 .32723 .47902 .35559 .50282 .31922 .46363 Metetra
0 .219 .719 r
.31922 .46363 .35559 .50282 .38464 .52537 .34832 .48523 Metetra
0 .316 .797 r
.34832 .48523 .38464 .52537 .41443 .545 .37818 .50395 Metetra
.091 .439 .877 r
.37818 .50395 .41443 .545 .44493 .55999 .4088 .51813 Metetra
.293 .559 .928 r
.4088 .51813 .44493 .55999 .4761 .56888 .44012 .52631 Metetra
.471 .65 .937 r
.44012 .52631 .4761 .56888 .50782 .57053 .47206 .52739 Metetra
.606 .708 .916 r
.47206 .52739 .50782 .57053 .53995 .5642 .50447 .52065 Metetra
.701 .74 .882 r
.50447 .52065 .53995 .5642 .57235 .5495 .53722 .50571 Metetra
.763 .758 .847 r
.53722 .50571 .57235 .5495 .60484 .52673 .57012 .48286 Metetra
.806 .767 .817 r
.57012 .48286 .60484 .52673 .63728 .49656 .60303 .45275 Metetra
.834 .773 .793 r
.60303 .45275 .63728 .49656 .66953 .46006 .63581 .41644 Metetra
.854 .777 .776 r
.63581 .41644 .66953 .46006 .70151 .41868 .66837 .37533 Metetra
.866 .78 .764 r
.66837 .37533 .70151 .41868 .73319 .37413 .70065 .33111 Metetra
.873 .783 .759 r
.70065 .33111 .73319 .37413 .76458 .32809 .73265 .28543 Metetra
0 .238 .732 r
.25338 .40146 .29083 .44079 .31922 .46363 .28191 .42162 Metetra
0 .298 .786 r
.28191 .42162 .31922 .46363 .34832 .48523 .31113 .4406 Metetra
.035 .386 .847 r
.31113 .4406 .34832 .48523 .37818 .50395 .34111 .45686 Metetra
.206 .482 .894 r
.34111 .45686 .37818 .50395 .4088 .51813 .37185 .46889 Metetra
.372 .567 .913 r
.37185 .46889 .4088 .51813 .44012 .52631 .40333 .47533 Metetra
.509 .63 .905 r
.40333 .47533 .44012 .52631 .47206 .52739 .43545 .47519 Metetra
.613 .672 .883 r
.43545 .47519 .47206 .52739 .50447 .52065 .4681 .46779 Metetra
.69 .701 .855 r
.4681 .46779 .50447 .52065 .53722 .50571 .50113 .4528 Metetra
.745 .721 .829 r
.50113 .4528 .53722 .50571 .57012 .48286 .5344 .43047 Metetra
.785 .735 .807 r
.5344 .43047 .57012 .48286 .60303 .45275 .56774 .40142 Metetra
.814 .746 .789 r
.56774 .40142 .60303 .45275 .63581 .41644 .60103 .36659 Metetra
.836 .757 .776 r
.60103 .36659 .63581 .41644 .66837 .37533 .63416 .3273 Metetra
.851 .767 .769 r
.63416 .3273 .66837 .37533 .70065 .33111 .66708 .28508 Metetra
.861 .776 .766 r
.66708 .28508 .70065 .33111 .73265 .28543 .69976 .24147 Metetra
0 .357 .824 r
.21484 .36098 .25338 .40146 .28191 .42162 .24364 .37686 Metetra
.057 .406 .859 r
.24364 .37686 .28191 .42162 .31113 .4406 .2731 .39164 Metetra
.189 .466 .886 r
.2731 .39164 .31113 .4406 .34111 .45686 .30328 .40401 Metetra
.323 .526 .898 r
.30328 .40401 .34111 .45686 .37185 .46889 .3342 .41264 Metetra
.444 .576 .892 r
.3342 .41264 .37185 .46889 .40333 .47533 .36584 .41641 Metetra
.541 .615 .876 r
.36584 .41641 .40333 .47533 .43545 .47519 .39812 .41443 Metetra
.618 .645 .855 r
.39812 .41443 .43545 .47519 .4681 .46779 .43097 .40615 Metetra
.678 .669 .834 r
.43097 .40615 .4681 .46779 .50113 .4528 .46424 .39128 Metetra
.725 .688 .815 r
.46424 .39128 .50113 .4528 .5344 .43047 .4978 .37004 Metetra
.761 .706 .8 r
.4978 .37004 .5344 .43047 .56774 .40142 .53152 .34294 Metetra
.79 .722 .788 r
.53152 .34294 .56774 .40142 .60103 .36659 .56526 .3108 Metetra
.813 .737 .781 r
.56526 .3108 .60103 .36659 .63416 .3273 .59893 .27474 Metetra
.83 .753 .778 r
.59893 .27474 .63416 .3273 .66708 .28508 .63247 .23609 Metetra
.844 .769 .779 r
.63247 .23609 .66708 .28508 .69976 .24147 .66586 .19616 Metetra
.16 .497 .907 r
.17516 .3193 .21484 .36098 .24364 .37686 .2044 .32946 Metetra
.249 .517 .909 r
.2044 .32946 .24364 .37686 .2731 .39164 .23424 .33867 Metetra
.342 .54 .903 r
.23424 .33867 .2731 .39164 .30328 .40401 .26473 .3459 Metetra
.43 .564 .888 r
.26473 .3459 .30328 .40401 .3342 .41264 .29591 .35009 Metetra
.506 .587 .87 r
.29591 .35009 .3342 .41264 .36584 .41641 .32775 .35035 Metetra
.57 .607 .85 r
.32775 .35035 .36584 .41641 .39812 .41443 .36021 .34603 Metetra
.623 .625 .832 r
.36021 .34603 .39812 .41443 .43097 .40615 .39321 .33668 Metetra
.667 .643 .817 r
.39321 .33668 .43097 .40615 .46424 .39128 .42666 .32207 Metetra
.704 .661 .805 r
.42666 .32207 .46424 .39128 .4978 .37004 .46045 .30238 Metetra
.735 .679 .796 r
.46045 .30238 .4978 .37004 .53152 .34294 .49445 .27801 Metetra
.761 .697 .791 r
.49445 .27801 .53152 .34294 .56526 .3108 .52857 .24958 Metetra
.784 .717 .789 r
.52857 .24958 .56526 .3108 .59893 .27474 .56272 .21799 Metetra
.803 .738 .792 r
.56272 .21799 .59893 .27474 .63247 .23609 .59683 .18425 Metetra
.818 .76 .798 r
.59683 .18425 .63247 .23609 .66586 .19616 .63089 .14942 Metetra
.375 .618 .946 r
.13429 .27638 .17516 .3193 .2044 .32946 .16417 .27966 Metetra
.425 .606 .923 r
.16417 .27966 .2044 .32946 .23424 .33867 .19455 .2822 Metetra
.474 .599 .897 r
.19455 .2822 .23424 .33867 .26473 .3459 .2255 .28329 Metetra
.519 .596 .871 r
.2255 .28329 .26473 .3459 .29591 .35009 .25702 .28222 Metetra
.559 .598 .849 r
.25702 .28222 .29591 .35009 .32775 .35035 .28912 .27837 Metetra
.595 .604 .83 r
.28912 .27837 .32775 .35035 .36021 .34603 .32177 .27131 Metetra
.627 .612 .816 r
.32177 .27131 .36021 .34603 .39321 .33668 .35491 .26073 Metetra
.656 .624 .805 r
.35491 .26073 .39321 .33668 .42666 .32207 .38849 .24649 Metetra
.682 .638 .799 r
.38849 .24649 .42666 .32207 .46045 .30238 .42242 .22871 Metetra
.706 .654 .796 r
.42242 .22871 .46045 .30238 .49445 .27801 .45662 .20764 Metetra
.728 .674 .797 r
.45662 .20764 .49445 .27801 .52857 .24958 .49102 .18372 Metetra
.748 .696 .801 r
.49102 .18372 .52857 .24958 .56272 .21799 .52554 .15753 Metetra
.766 .72 .81 r
.52554 .15753 .56272 .21799 .59683 .18425 .56015 .12979 Metetra
.782 .748 .822 r
.56015 .12979 .59683 .18425 .63089 .14942 .59481 .1012 Metetra
.547 .697 .938 r
.09217 .23214 .13429 .27638 .16417 .27966 .12289 .22772 Metetra
.563 .666 .907 r
.12289 .22772 .16417 .27966 .19455 .2822 .154 .22284 Metetra
.577 .641 .877 r
.154 .22284 .19455 .2822 .2255 .28329 .18555 .21715 Metetra
.591 .623 .852 r
.18555 .21715 .2255 .28329 .25702 .28222 .21753 .21027 Metetra
.605 .611 .831 r
.21753 .21027 .25702 .28222 .28912 .27837 .24997 .20192 Metetra
.619 .605 .815 r
.24997 .20192 .28912 .27837 .32177 .27131 .28284 .19187 Metetra
.632 .605 .805 r
.28284 .19187 .32177 .27131 .35491 .26073 .31612 .17998 Metetra
.646 .61 .799 r
.31612 .17998 .35491 .26073 .38849 .24649 .34978 .16616 Metetra
.66 .619 .797 r
.34978 .16616 .38849 .24649 .42242 .22871 .38378 .15049 Metetra
.675 .632 .799 r
.38378 .15049 .42242 .22871 .45662 .20764 .41808 .13309 Metetra
.689 .65 .805 r
.41808 .13309 .45662 .20764 .49102 .18372 .45264 .11417 Metetra
.704 .672 .816 r
.45264 .11417 .49102 .18372 .52554 .15753 .48742 .09401 Metetra
.718 .698 .83 r
.48742 .09401 .52554 .15753 .56015 .12979 .5224 .07297 Metetra
.731 .729 .849 r
.5224 .07297 .56015 .12979 .59481 .1012 .55756 .05142 Metetra
.666 .738 .904 r
.04875 .18654 .09217 .23214 .12289 .22772 .08051 .17394 Metetra
.661 .701 .877 r
.08051 .17394 .12289 .22772 .154 .22284 .11254 .16124 Metetra
.655 .67 .852 r
.11254 .16124 .154 .22284 .18555 .21715 .14483 .14843 Metetra
.649 .644 .832 r
.14483 .14843 .18555 .21715 .21753 .21027 .1774 .13551 Metetra
.644 .625 .816 r
.1774 .13551 .21753 .21027 .24997 .20192 .21025 .12249 Metetra
.64 .611 .805 r
.21025 .12249 .24997 .20192 .28284 .19187 .24339 .10934 Metetra
.638 .603 .798 r
.24339 .10934 .28284 .19187 .31612 .17998 .27681 .09609 Metetra
.637 .601 .796 r
.27681 .09609 .31612 .17998 .34978 .16616 .31052 .08272 Metetra
.638 .603 .798 r
.31052 .08272 .34978 .16616 .38378 .15049 .34452 .06923 Metetra
.64 .611 .805 r
.34452 .06923 .38378 .15049 .41808 .13309 .37882 .05563 Metetra
.644 .625 .816 r
.37882 .05563 .41808 .13309 .45264 .11417 .41342 .04191 Metetra
.649 .644 .832 r
.41342 .04191 .45264 .11417 .48742 .09401 .44833 .02806 Metetra
.655 .67 .852 r
.44833 .02806 .48742 .09401 .5224 .07297 .48355 .01409 Metetra
.661 .701 .877 r
.48355 .01409 .5224 .07297 .55756 .05142 .51908 0 Metetra
0 g
.25 Mabswid
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282.75, 314.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11253 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.066106 1.21212 -1.11022e-16 1.21212 [
[.5 1.12503 -44 0 ]
[.5 1.12503 44 24.5 ]
[.03831 .17557 -5.85635 -9 ]
[.03831 .17557 .14365 0 ]
[.12814 .13981 -17.2021 -9 ]
[.12814 .13981 .79789 0 ]
[.22015 .10319 -16.8352 -9 ]
[.22015 .10319 1.16484 0 ]
[.31441 .06568 -16.4682 -9 ]
[.31441 .06568 1.53178 0 ]
[.411 .02725 -16.1013 -9 ]
[.411 .02725 1.89873 0 ]
[.51 -0.01213 -5.24477 -9 ]
[.51 -0.01213 .75523 0 ]
[.21792 .02683 -9.25094 -12 ]
[.21792 .02683 .74906 0 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[.1484 .76875 -18 -3.08128 ]
[.1484 .76875 0 5.91872 ]
[.29382 .89692 -6 -3.18183 ]
[.29382 .89692 0 5.81817 ]
[.42456 1.01215 -18 -3.26907 ]
[.42456 1.01215 0 5.73093 ]
[.54272 1.11629 -6 -3.34548 ]
[.54272 1.11629 0 5.65452 ]
[.22112 .91822 -10 -4.24244 ]
[.22112 .91822 0 7.75756 ]
[.03467 .19213 -6 -2.71522 ]
[.03467 .19213 0 6.28478 ]
[.02559 .27239 -18 -2.7611 ]
[.02559 .27239 0 6.2389 ]
[.01617 .35567 -18 -2.80881 ]
[.01617 .35567 0 6.19119 ]
[.00638 .44212 -18 -2.85847 ]
[.00638 .44212 0 6.14153 ]
[-0.00378 .53194 -18 -2.9102 ]
[-0.00378 .53194 0 6.0898 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 1.11253 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.12503 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
.04875 .18654 m
.0558 .18375 L
s
[(0)] .03467 .19213 1 -0.39662 Mshowa
.03972 .26693 m
.04679 .2642 L
s
[(0.2)] .02559 .27239 1 -0.38642 Mshowa
.03035 .35034 m
.03744 .34767 L
s
[(0.4)] .01617 .35567 1 -0.37582 Mshowa
.02062 .43693 m
.02774 .43433 L
s
[(0.6)] .00638 .44212 1 -0.36478 Mshowa
.01051 .52689 m
.01765 .52437 L
s
[(0.8)] -0.00378 .53194 1 -0.35329 Mshowa
0 .62042 m
.00717 .61797 L
s
[(1)] -0.01434 .62532 1 -0.3413 Mshowa
.125 Mabswid
.04653 .20636 m
.05076 .2047 L
s
.04428 .22637 m
.04851 .22471 L
s
.04201 .24656 m
.04625 .24491 L
s
.03741 .28749 m
.04165 .28587 L
s
.03508 .30825 m
.03933 .30663 L
s
.03272 .32919 m
.03698 .32759 L
s
.02795 .37168 m
.03221 .37009 L
s
.02553 .39322 m
.02979 .39164 L
s
.02309 .41497 m
.02735 .4134 L
s
.01813 .45909 m
.0224 .45755 L
s
.01561 .48147 m
.01989 .47994 L
s
.01307 .50407 m
.01736 .50255 L
s
.00792 .54993 m
.01221 .54843 L
s
.00531 .5732 m
.0096 .5717 L
s
.00267 .59669 m
.00696 .59521 L
s
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
.5561 .7194 m
.04875 .18654 L
s
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.5561 .7194 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
0 0 m
1 0 L
1 1.11253 L
0 1.11253 L
closepath
clip
newpath
.5 Mabswid
.584 .711 .931 r
.52593 .68772 .5561 .7194 .58394 .7109 .55404 .68434 Metetra
.573 .746 .958 r
.55404 .68434 .58394 .7109 .61197 .70234 .5824 .68066 Metetra
.561 .782 .981 r
.5824 .68066 .61197 .70234 .64019 .69372 .61102 .67642 Metetra
.55 .816 .995 r
.61102 .67642 .64019 .69372 .66861 .68504 .63987 .67139 Metetra
.544 .845 .999 r
.63987 .67139 .66861 .68504 .69723 .6763 .66896 .66535 Metetra
.546 .868 .995 r
.66896 .66535 .69723 .6763 .72605 .6675 .69825 .65816 Metetra
.561 .886 .989 r
.69825 .65816 .72605 .6675 .75507 .65863 .72772 .64971 Metetra
.589 .901 .985 r
.72772 .64971 .75507 .65863 .7843 .6497 .75737 .63997 Metetra
.626 .909 .983 r
.75737 .63997 .7843 .6497 .81374 .64071 .78715 .62896 Metetra
.665 .906 .979 r
.78715 .62896 .81374 .64071 .84339 .63166 .81707 .61678 Metetra
.697 .891 .968 r
.81707 .61678 .84339 .63166 .87325 .62254 .84711 .60355 Metetra
.719 .865 .951 r
.84711 .60355 .87325 .62254 .90333 .61335 .87726 .58948 Metetra
.729 .831 .928 r
.87726 .58948 .90333 .61335 .93362 .6041 .90753 .57481 Metetra
.729 .794 .904 r
.90753 .57481 .93362 .6041 .96413 .59478 .93794 .55978 Metetra
.476 .667 .947 r
.49498 .6552 .52593 .68772 .55404 .68434 .52329 .65675 Metetra
.457 .696 .97 r
.52329 .65675 .55404 .68434 .5824 .68066 .55193 .65777 Metetra
.446 .73 .987 r
.55193 .65777 .5824 .68066 .61102 .67642 .58088 .65777 Metetra
.448 .767 .997 r
.58088 .65777 .61102 .67642 .63987 .67139 .61013 .65627 Metetra
.468 .806 .999 r
.61013 .65627 .63987 .67139 .66896 .66535 .63964 .65285 Metetra
.505 .843 .997 r
.63964 .65285 .66896 .66535 .69825 .65816 .66938 .64722 Metetra
.557 .876 .993 r
.66938 .64722 .69825 .65816 .72772 .64971 .69931 .63918 Metetra
.617 .901 .986 r
.69931 .63918 .72772 .64971 .75737 .63997 .72938 .62862 Metetra
.674 .913 .975 r
.72938 .62862 .75737 .63997 .78715 .62896 .75954 .61563 Metetra
.722 .91 .96 r
.75954 .61563 .78715 .62896 .81707 .61678 .78977 .60037 Metetra
.755 .893 .94 r
.78977 .60037 .81707 .61678 .84711 .60355 .82003 .58312 Metetra
.774 .868 .918 r
.82003 .58312 .84711 .60355 .87726 .58948 .85032 .56429 Metetra
.78 .836 .895 r
.85032 .56429 .87726 .58948 .90753 .57481 .88065 .54436 Metetra
.777 .803 .874 r
.88065 .54436 .90753 .57481 .93794 .55978 .91103 .52381 Metetra
.349 .605 .944 r
.4632 .62183 .49498 .6552 .52329 .65675 .49166 .62784 Metetra
.326 .627 .96 r
.49166 .62784 .52329 .65675 .55193 .65777 .52051 .63313 Metetra
.325 .661 .973 r
.52051 .63313 .55193 .65777 .58088 .65777 .54974 .637 Metetra
.351 .707 .985 r
.54974 .637 .58088 .65777 .61013 .65627 .57933 .63873 Metetra
.405 .761 .994 r
.57933 .63873 .61013 .65627 .63964 .65285 .60923 .63772 Metetra
.48 .816 .999 r
.60923 .63772 .63964 .65285 .66938 .64722 .6394 .63351 Metetra
.565 .862 .996 r
.6394 .63351 .66938 .64722 .69931 .63918 .66976 .62581 Metetra
.647 .892 .984 r
.66976 .62581 .69931 .63918 .72938 .62862 .70026 .61447 Metetra
.714 .904 .963 r
.70026 .61447 .72938 .62862 .75954 .61563 .73082 .5996 Metetra
.762 .899 .937 r
.73082 .5996 .75954 .61563 .78977 .60037 .7614 .58146 Metetra
.793 .882 .911 r
.7614 .58146 .78977 .60037 .82003 .58312 .79195 .56048 Metetra
.809 .859 .886 r
.79195 .56048 .82003 .58312 .85032 .56429 .82246 .53725 Metetra
.813 .833 .865 r
.82246 .53725 .85032 .56429 .88065 .54436 .85292 .51246 Metetra
.809 .805 .847 r
.85292 .51246 .88065 .54436 .91103 .52381 .88337 .48685 Metetra
.219 .532 .922 r
.43058 .58756 .4632 .62183 .49166 .62784 .45913 .59731 Metetra
.203 .551 .932 r
.45913 .59731 .49166 .62784 .52051 .63313 .48813 .60621 Metetra
.22 .59 .947 r
.48813 .60621 .52051 .63313 .54974 .637 .51758 .61335 Metetra
.276 .649 .967 r
.51758 .61335 .54974 .637 .57933 .63873 .54746 .61781 Metetra
.365 .72 .988 r
.54746 .61781 .57933 .63873 .60923 .63772 .57771 .61881 Metetra
.473 .788 .999 r
.57771 .61881 .60923 .63772 .6394 .63351 .60826 .61579 Metetra
.58 .841 .994 r
.60826 .61579 .6394 .63351 .66976 .62581 .63905 .60834 Metetra
.672 .872 .974 r
.63905 .60834 .66976 .62581 .70026 .61447 .66997 .59627 Metetra
.74 .882 .945 r
.66997 .59627 .70026 .61447 .73082 .5996 .70095 .57974 Metetra
.786 .877 .913 r
.70095 .57974 .73082 .5996 .7614 .58146 .73191 .55908 Metetra
.815 .863 .884 r
.73191 .55908 .7614 .58146 .79195 .56048 .76281 .53484 Metetra
.829 .845 .859 r
.76281 .53484 .79195 .56048 .82246 .53725 .79361 .50778 Metetra
.833 .824 .84 r
.79361 .50778 .82246 .53725 .85292 .51246 .82431 .47881 Metetra
.83 .803 .825 r
.82431 .47881 .85292 .51246 .88337 .48685 .85493 .44884 Metetra
.109 .465 .89 r
.39706 .55236 .43058 .58756 .45913 .59731 .42567 .56493 Metetra
.108 .485 .899 r
.42567 .56493 .45913 .59731 .48813 .60621 .45479 .57654 Metetra
.15 .533 .921 r
.45479 .57654 .48813 .60621 .51758 .61335 .48441 .58613 Metetra
.235 .604 .952 r
.48441 .58613 .51758 .61335 .54746 .61781 .51453 .59264 Metetra
.352 .686 .98 r
.51453 .59264 .54746 .61781 .57771 .61881 .54507 .59515 Metetra
.479 .76 .992 r
.54507 .59515 .57771 .61881 .60826 .61579 .57598 .59297 Metetra
.595 .814 .983 r
.57598 .59297 .60826 .61579 .63905 .60834 .60715 .58564 Metetra
.689 .843 .957 r
.60715 .58564 .63905 .60834 .66997 .59627 .63849 .57294 Metetra
.754 .853 .924 r
.63849 .57294 .66997 .59627 .70095 .57974 .66989 .55504 Metetra
.797 .85 .89 r
.66989 .55504 .70095 .57974 .73191 .55908 .70128 .53235 Metetra
.824 .841 .861 r
.70128 .53235 .73191 .55908 .76281 .53484 .73258 .50551 Metetra
.838 .828 .838 r
.73258 .50551 .76281 .53484 .79361 .50778 .76375 .47542 Metetra
.844 .814 .82 r
.76375 .47542 .79361 .50778 .82431 .47881 .79477 .44314 Metetra
.843 .799 .809 r
.79477 .44314 .82431 .47881 .85493 .44884 .82567 .40974 Metetra
.037 .417 .863 r
.36263 .5162 .39706 .55236 .42567 .56493 .39128 .53047 Metetra
.057 .444 .877 r
.39128 .53047 .42567 .56493 .45479 .57654 .42048 .54374 Metetra
.122 .499 .906 r
.42048 .54374 .45479 .57654 .48441 .58613 .45025 .55483 Metetra
.229 .576 .942 r
.45025 .55483 .48441 .58613 .51453 .59264 .48056 .56256 Metetra
.361 .66 .97 r
.48056 .56256 .51453 .59264 .54507 .59515 .51135 .56594 Metetra
.494 .732 .978 r
.51135 .56594 .54507 .59515 .57598 .59297 .54257 .5642 Metetra
.608 .781 .964 r
.54257 .5642 .57598 .59297 .60715 .58564 .5741 .55685 Metetra
.696 .809 .935 r
.5741 .55685 .60715 .58564 .63849 .57294 .60584 .54362 Metetra
.757 .82 .902 r
.60584 .54362 .63849 .57294 .66989 .55504 .63767 .52472 Metetra
.798 .821 .87 r
.63767 .52472 .66989 .55504 .70128 .53235 .6695 .50059 Metetra
.824 .817 .843 r
.6695 .50059 .70128 .53235 .73258 .50551 .70124 .47194 Metetra
.839 .81 .822 r
.70124 .47194 .73258 .50551 .76375 .47542 .73284 .43977 Metetra
.847 .802 .807 r
.73284 .43977 .76375 .47542 .79477 .44314 .76428 .40523 Metetra
.848 .794 .798 r
.76428 .40523 .79477 .44314 .82567 .40974 .79557 .36951 Metetra
.011 .4 .852 r
.32723 .47902 .36263 .5162 .39128 .53047 .35594 .49379 Metetra
.052 .432 .871 r
.35594 .49379 .39128 .53047 .42048 .54374 .38523 .50753 Metetra
.136 .491 .904 r
.38523 .50753 .42048 .54374 .45025 .55483 .41512 .51903 Metetra
.255 .567 .937 r
.41512 .51903 .45025 .55483 .48056 .56256 .44559 .52707 Metetra
.388 .643 .958 r
.44559 .52707 .48056 .56256 .51135 .56594 .47661 .53061 Metetra
.513 .705 .957 r
.47661 .53061 .51135 .56594 .54257 .5642 .5081 .52887 Metetra
.617 .748 .939 r
.5081 .52887 .54257 .5642 .5741 .55685 .53995 .52131 Metetra
.696 .774 .911 r
.53995 .52131 .5741 .55685 .60584 .54362 .57206 .50769 Metetra
.752 .787 .881 r
.57206 .50769 .60584 .54362 .63767 .52472 .60431 .48819 Metetra
.791 .792 .853 r
.60431 .48819 .63767 .52472 .6695 .50059 .63659 .4633 Metetra
.817 .794 .83 r
.63659 .4633 .6695 .50059 .70124 .47194 .6688 .43374 Metetra
.834 .793 .812 r
.6688 .43374 .70124 .47194 .73284 .43977 .70088 .40055 Metetra
.844 .791 .8 r
.70088 .40055 .73284 .43977 .76428 .40523 .7328 .36492 Metetra
.848 .788 .793 r
.7328 .36492 .76428 .40523 .79557 .36951 .76458 .32809 Metetra
.037 .417 .863 r
.29083 .44079 .32723 .47902 .35594 .49379 .31964 .45478 Metetra
.094 .451 .883 r
.31964 .45478 .35594 .49379 .38523 .50753 .34904 .46774 Metetra
.187 .506 .91 r
.34904 .46774 .38523 .50753 .41512 .51903 .37906 .47851 Metetra
.304 .571 .933 r
.37906 .47851 .41512 .51903 .44559 .52707 .4097 .48587 Metetra
.426 .632 .941 r
.4097 .48587 .44559 .52707 .47661 .53061 .44092 .48881 Metetra
.534 .682 .933 r
.44092 .48881 .47661 .53061 .5081 .52887 .47264 .48657 Metetra
.623 .717 .913 r
.47264 .48657 .5081 .52887 .53995 .52131 .50479 .47864 Metetra
.692 .74 .888 r
.50479 .47864 .53995 .52131 .57206 .50769 .53724 .46475 Metetra
.742 .755 .863 r
.53724 .46475 .57206 .50769 .60431 .48819 .56988 .44511 Metetra
.779 .764 .84 r
.56988 .44511 .60431 .48819 .63659 .4633 .60259 .42016 Metetra
.805 .771 .821 r
.60259 .42016 .63659 .4633 .6688 .43374 .63527 .39065 Metetra
.824 .775 .807 r
.63527 .39065 .6688 .43374 .70088 .40055 .66787 .35756 Metetra
.836 .779 .798 r
.66787 .35756 .70088 .40055 .7328 .36492 .70033 .32209 Metetra
.842 .782 .794 r
.70033 .32209 .7328 .36492 .76458 .32809 .73265 .28543 Metetra
.109 .465 .89 r
.25338 .40146 .29083 .44079 .31964 .45478 .28237 .4134 Metetra
.174 .493 .904 r
.28237 .4134 .31964 .45478 .34904 .46774 .31194 .42437 Metetra
.264 .536 .919 r
.31194 .42437 .34904 .46774 .37906 .47851 .34212 .43327 Metetra
.367 .583 .926 r
.34212 .43327 .37906 .47851 .4097 .48587 .37293 .43899 Metetra
.467 .627 .922 r
.37293 .43899 .4097 .48587 .44092 .48881 .40435 .4406 Metetra
.555 .663 .908 r
.40435 .4406 .44092 .48881 .47264 .48657 .43629 .4374 Metetra
.627 .69 .889 r
.43629 .4374 .47264 .48657 .50479 .47864 .4687 .4289 Metetra
.685 .711 .868 r
.4687 .4289 .50479 .47864 .53724 .46475 .50145 .41488 Metetra
.729 .726 .848 r
.50145 .41488 .53724 .46475 .56988 .44511 .53444 .39551 Metetra
.763 .739 .83 r
.53444 .39551 .56988 .44511 .60259 .42016 .56756 .37123 Metetra
.789 .749 .816 r
.56756 .37123 .60259 .42016 .63527 .39065 .60071 .34269 Metetra
.809 .759 .806 r
.60071 .34269 .63527 .39065 .66787 .35756 .63382 .31082 Metetra
.823 .767 .8 r
.63382 .31082 .66787 .35756 .70033 .32209 .66684 .27671 Metetra
.832 .776 .799 r
.66684 .27671 .70033 .32209 .73265 .28543 .69976 .24147 Metetra
.219 .532 .922 r
.21484 .36098 .25338 .40146 .28237 .4134 .2441 .36969 Metetra
.28 .549 .924 r
.2441 .36969 .28237 .4134 .31194 .42437 .27392 .37752 Metetra
.355 .573 .922 r
.27392 .37752 .31194 .42437 .34212 .43327 .30434 .3835 Metetra
.434 .6 .915 r
.30434 .3835 .34212 .43327 .37293 .43899 .33536 .38669 Metetra
.509 .626 .902 r
.33536 .38669 .37293 .43899 .40435 .4406 .36698 .38628 Metetra
.575 .649 .886 r
.36698 .38628 .40435 .4406 .43629 .4374 .39913 .38167 Metetra
.631 .668 .868 r
.39913 .38167 .43629 .4374 .4687 .4289 .43177 .37244 Metetra
.677 .686 .851 r
.43177 .37244 .4687 .4289 .50145 .41488 .46478 .35841 Metetra
.714 .701 .836 r
.46478 .35841 .50145 .41488 .53444 .39551 .49808 .33972 Metetra
.745 .715 .824 r
.49808 .33972 .53444 .39551 .56756 .37123 .53157 .31674 Metetra
.77 .728 .815 r
.53157 .31674 .56756 .37123 .60071 .34269 .56514 .29003 Metetra
.789 .742 .809 r
.56514 .29003 .60071 .34269 .63382 .31082 .59874 .26041 Metetra
.804 .755 .807 r
.59874 .26041 .63382 .31082 .66684 .27671 .63232 .22879 Metetra
.815 .769 .809 r
.63232 .22879 .66684 .27671 .69976 .24147 .66586 .19616 Metetra
.349 .605 .944 r
.17516 .3193 .21484 .36098 .2441 .36969 .20483 .32373 Metetra
.395 .605 .932 r
.20483 .32373 .2441 .36969 .27392 .37752 .235 .3274 Metetra
.447 .61 .917 r
.235 .3274 .27392 .37752 .30434 .3835 .26573 .32955 Metetra
.5 .618 .9 r
.26573 .32955 .30434 .3835 .33536 .38669 .29702 .32943 Metetra
.55 .629 .883 r
.29702 .32943 .33536 .38669 .36698 .38628 .32887 .3264 Metetra
.594 .64 .866 r
.32887 .3264 .36698 .38628 .39913 .38167 .36124 .32 Metetra
.634 .652 .85 r
.36124 .32 .39913 .38167 .43177 .37244 .39408 .3099 Metetra
.668 .665 .838 r
.39408 .3099 .43177 .37244 .46478 .35841 .42732 .29595 Metetra
.698 .679 .827 r
.42732 .29595 .46478 .35841 .49808 .33972 .46087 .27828 Metetra
.724 .693 .82 r
.46087 .27828 .49808 .33972 .53157 .31674 .49466 .25716 Metetra
.746 .708 .816 r
.49466 .25716 .53157 .31674 .56514 .29003 .52861 .23304 Metetra
.765 .724 .815 r
.52861 .23304 .56514 .29003 .59874 .26041 .56266 .20654 Metetra
.78 .742 .818 r
.56266 .20654 .59874 .26041 .63232 .22879 .59676 .17842 Metetra
.792 .76 .824 r
.59676 .17842 .63232 .22879 .66586 .19616 .63089 .14942 Metetra
.476 .667 .947 r
.13429 .27638 .17516 .3193 .20483 .32373 .1645 .27566 Metetra
.502 .652 .926 r
.1645 .27566 .20483 .32373 .235 .3274 .19516 .27435 Metetra
.53 .641 .904 r
.19516 .27435 .235 .3274 .26573 .32955 .22629 .27194 Metetra
.559 .635 .883 r
.22629 .27194 .26573 .32955 .29702 .32943 .25793 .26789 Metetra
.587 .634 .865 r
.25793 .26789 .29702 .32943 .32887 .3264 .29005 .26179 Metetra
.613 .636 .849 r
.29005 .26179 .32887 .3264 .36124 .32 .32265 .2533 Metetra
.637 .641 .837 r
.32265 .2533 .36124 .32 .39408 .3099 .35569 .24222 Metetra
.66 .649 .828 r
.35569 .24222 .39408 .3099 .42732 .29595 .38911 .22843 Metetra
.681 .66 .822 r
.38911 .22843 .42732 .29595 .46087 .27828 .42287 .21203 Metetra
.7 .673 .82 r
.42287 .21203 .46087 .27828 .49466 .25716 .4569 .1932 Metetra
.718 .689 .821 r
.4569 .1932 .49466 .25716 .52861 .23304 .49115 .17224 Metetra
.734 .707 .825 r
.49115 .17224 .52861 .23304 .56266 .20654 .52557 .14957 Metetra
.748 .726 .832 r
.52557 .14957 .56266 .20654 .59676 .17842 .56013 .12572 Metetra
.76 .748 .842 r
.56013 .12572 .59676 .17842 .63089 .14942 .59481 .1012 Metetra
.584 .711 .931 r
.09217 .23214 .13429 .27638 .1645 .27566 .12308 .22566 Metetra
.592 .687 .908 r
.12308 .22566 .1645 .27566 .19516 .27435 .15436 .21882 Metetra
.601 .667 .886 r
.15436 .21882 .19516 .27435 .22629 .27194 .18601 .21134 Metetra
.61 .651 .866 r
.18601 .21134 .22629 .27194 .25793 .26789 .21807 .20296 Metetra
.62 .641 .85 r
.21807 .20296 .25793 .26789 .29005 .26179 .25053 .19347 Metetra
.631 .636 .837 r
.25053 .19347 .29005 .26179 .32265 .2533 .28338 .1827 Metetra
.641 .634 .828 r
.28338 .1827 .32265 .2533 .35569 .24222 .3166 .17055 Metetra
.652 .638 .823 r
.3166 .17055 .35569 .24222 .38911 .22843 .35018 .15697 Metetra
.664 .645 .821 r
.35018 .15697 .38911 .22843 .42287 .21203 .38409 .142 Metetra
.675 .655 .823 r
.38409 .142 .42287 .21203 .4569 .1932 .41829 .12572 Metetra
.687 .67 .828 r
.41829 .12572 .4569 .1932 .49115 .17224 .45276 .10829 Metetra
.698 .687 .836 r
.45276 .10829 .49115 .17224 .52557 .14957 .48747 .08993 Metetra
.708 .708 .848 r
.48747 .08993 .52557 .14957 .56013 .12572 .52241 .07088 Metetra
.717 .732 .863 r
.52241 .07088 .56013 .12572 .59481 .1012 .55756 .05142 Metetra
.666 .738 .904 r
.04875 .18654 .09217 .23214 .12308 .22566 .08051 .17394 Metetra
.662 .711 .884 r
.08051 .17394 .12308 .22566 .15436 .21882 .11254 .16124 Metetra
.658 .687 .865 r
.11254 .16124 .15436 .21882 .18601 .21134 .14483 .14843 Metetra
.654 .666 .85 r
.14483 .14843 .18601 .21134 .21807 .20296 .1774 .13551 Metetra
.65 .651 .837 r
.1774 .13551 .21807 .20296 .25053 .19347 .21025 .12249 Metetra
.648 .639 .828 r
.21025 .12249 .25053 .19347 .28338 .1827 .24339 .10934 Metetra
.646 .633 .822 r
.24339 .10934 .28338 .1827 .3166 .17055 .27681 .09609 Metetra
.645 .63 .821 r
.27681 .09609 .3166 .17055 .35018 .15697 .31052 .08272 Metetra
.646 .633 .822 r
.31052 .08272 .35018 .15697 .38409 .142 .34452 .06923 Metetra
.648 .639 .828 r
.34452 .06923 .38409 .142 .41829 .12572 .37882 .05563 Metetra
.65 .651 .837 r
.37882 .05563 .41829 .12572 .45276 .10829 .41342 .04191 Metetra
.654 .666 .85 r
.41342 .04191 .45276 .10829 .48747 .08993 .44833 .02806 Metetra
.658 .687 .865 r
.44833 .02806 .48747 .08993 .52241 .07088 .48355 .01409 Metetra
.662 .711 .884 r
.48355 .01409 .52241 .07088 .55756 .05142 .51908 0 Metetra
0 g
.25 Mabswid
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282.75, 314.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005Q0001RB000`400?l00000o`00003ooooooomR
ooooo`00oooooomRooooo`00oooooomRooooo`00^_ooool4o`000003oa0@4?oooooooooo0:3ooooo
002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002loooo
o`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`00
0?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002jooooo`03oeEEEOmVIVKo
00000:Cooooo003oooooof;ooooo003oooooof;ooooo001Mooooo`;o00000_ooool2o`000?kooooo
001Mooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgMo_ooool005kooooo00CogMgMo`000?l@413o
c<c<:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`07oooool2o`0009oooooo001Nooooo`04onk^k_lQ8B7o410@onk^kR[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01cooooo
0ol000000onY]^;o0000o`00002Nooooo`00G_ooool01?lQ8B7oMgMgogMgMolb<S8Zooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001[ooooo0ol00003ojVf
hP?o0000WOooool005gooooo0_l00002ooooo`;o0000:Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`?o00001_nY]^800ol0003oZKKRo`00002M
ooooo`00S?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00Eooooo`?o00000_nY]^800ol0003oZKKRojVfhP03ojVfhP04o`000?nY]^;oZKKRo`0009cooooo
002<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@01;o
oooo1?l0000:ojVfhP04o`000?nY]^;oZKKRo`0009cooooo002<ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000013ooooo1?l000000onX[mgo0000ojVfhP09
ojVfhP05o`000?nY]^;oZKKRojVfh_l00000Voooool008cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT03Oooool4o`000003ojR_gOl0003oZ:oM00;oZ:oM
00?o0000ojVfh_nY]^801onY]^800ol0003oZKKRojVfhP02ojVfhP03o`000?oooooooooo09Sooooo
002/ooooo`Co00002?nX[md00ol0003oZKKRojVfhP06ojVfhP03o`000?nY]^;oZKKR00?oZKKR00?o
0000ooooooooool0Uoooool00:Wooooo1?l0000;ojR_g@03o`000?nY]^;oZKKR00KoZKKR00?o0000
ojVfh_nY]^800onY]^800ol0003oooooooooo`2Gooooo`00Yoooool6o`0000coZ:oM00?o0000ojVf
h_nY]^801OnY]^800ol0003oZKKRojVfhP04ojVfhP03o`000?oooooooooo09Kooooo002Tooooo`Co
00001OnWZ]T00ol0003oZ:oMojR_g@0:ojR_g@03o`000?nY]^;oZKKR00CoZKKR00?o0000ojVfh_nY
]^801OnY]^800ol0003oooooooooo`2Eooooo`00KOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`08?ooool3o`0000WoYj[I00?o0000ojR_
gOnX[md02_nX[md00ol0003oZKKRojVfhP03ojVfhP03o`000?nY]^;oZKKR00KoZKKR00?o0000oooo
ooooool0U?ooool006gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q01gooooo0ol000000onWZ]Wo0000ojNZf@09ojNZf@03o`000?nX[mgo
Z:oM00[oZ:oM00?o0000ojVfh_nY]^800onY]^800ol0003oZKKRojVfhP06ojVfhP03o`000?oooooo
oooo09Cooooo001]ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000001_ooooo0ol000001OnVY]Ko0000ojNZfOnWZ]Wo000000[oYj[I00?o0000ojR_gOnX[md0
2_nX[md00ol0003oZKKRojVfhP02ojVfhP03o`000?nY]^;oZKKR00OoZKKR00?o0000ooooooooool0
Toooool006gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B406?ooool3o`0000GoYZKF00?o0000ojNZfOnWZ]T02_nWZ]T00ol0003oZ:oMojR_g@0;ojR_g@05
o`000?nY]^;oZKKRojVfh_l000002_nY]^800ol0003oooooooooo`2Booooo`00KOooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Eooooo`Co000000?oYZKF
o`000?nVY]H01?nVY]H00ol0003oYj[IojNZf@0;ojNZf@03o`000?nX[mgoZ:oM00[oZ:oM00Go0000
ojVfh_nY]^;oZKKRo`00000:ojVfhP;o0000Toooool006gooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo01Gooooo0ol0000;ojJVeP03o`000?nWZ]WoYj[I00_oYj[I00?o
0000ojR_gOnX[md02_nX[md01?l0003oZKKRojVfh_l00008ojVfhP;o000000?o]k_Lo`000?ooool0
T_ooool006gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo
1?l0000=ojJVeP03o`000?nWZ]WoYj[I00[oYj[I00?o0000ojR_gOnX[md02onX[md00ol0003oZKKR
o`000006ojVfhP;o00001?ng^m`00ol0003oooooooooo`2@ooooo`00KOooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@3oooool2o`0000;oYJ?C00?o0000ojFSdol0
00003?nVY]H00ol0003oYj[IojNZf@0;ojNZf@03o`000?nX[mgoZ:oM00_oZ:oM0_l00005ojVfhP03
o`000?ng^mco]k_L00Go]k_L00?o0000ooooooooool0Soooool008kooooo0ol00006ojFSd`03o`00
0?nVY]KoYZKF00_oYZKF00?o0000ojNZfOnWZ]T02onWZ]T00ol0003oZ:oMojR_g@0:ojR_g@;o0000
0onY]^82o`0000Wo]k_L00?o0000ooooooooool0S_ooool008cooooo0ol00009ojFSd`03o`000?nV
Y]KoYZKF00[oYZKF00?o0000ojNZfOnWZ]T02onWZ]T00ol0003oZ:oMojR_g@0;ojR_g@04o`000?nY
]^;o0000o`0000_o]k_L0_l0002?ooooo`00ROooool4o`000003ojFSdol0003oYJ?C00SoYJ?C00?o
0000ojJVe_nVY]H02onVY]H00ol0003oYj[IojNZf@0;ojNZf@03o`000?nX[mgoZ:oM00[oZ:oM0_l0
000>okNkg003o`000?oooooooooo08gooooo001@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`0Pooooo`Co000000?oYJ;Bo`000?nUXm<02onU
Xm<00ol0003oYZKFojJVeP0:ojJVeP03o`000?nWZ]WoYj[I00coYj[I00?o0000ojR_gOnX[md01onX
[md4o`0000oo]k_L00?o0000ooooooooool0S?ooool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Nooooo`Co00001OnUX]800ol0003oYJ?CojFS
d`0:ojFSd`03o`000?nVY]KoYZKF00[oYZKF00?o0000ojNZfOnWZ]T02onWZ]T00ol0003oZ:oMojR_
g@06ojR_g@06o`000?ne]MWo]KGIo`000?ne]MWo00003ong^m`00ol0003oooooooooo`2;ooooo`00
D?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Mooooo`?o000000?oYJ;Bo`000?nU
X]801OnUX]800ol0003oYJ?CojFSd`0:ojFSd`03o`000?nVY]KoYZKF00_oYZKF00?o0000ojNZfOnW
Z]T02onWZ]T00ol0003oZ:oMojR_g@03ojR_g@;o00000one]MT01?l0003o]KGIokFefOl0000>okNk
g0;o0000S?ooool0053ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgooooo
o`0001_ooooo0ol00005ojFRdP03o`000?nUX];oYJ;B00CoYJ;B00?o0000ojFSdonUXm<02_nUXm<0
0ol0003oYZKFojJVeP0:ojJVeP03o`000?nWZ]WoYj[I00_oYj[I00Co0000ojR_gOnX[mgoZ:oM0_l0
0005okFef@04o`000?ne]MWo]KGIo`0000oo]k_L0_l0002;ooooo`00D?ooool01Ol0003ooooooooo
oooooooo000000_ooooo00CogMgMoeEEEOoooooo00006Oooool3o`000003ojFQd_l0003oYJ;B00_o
YJ;B00?o0000ojFSdonUXm<02_nUXm<00ol0003oYZKFojJVeP0;ojJVeP03o`000?nWZ]WoYj[I00_o
Yj[I00?o0000ojR_gOl000001one]MT01Ol0003o]KGIokFefOne]MWo000000oo]k_L00?o0000oooo
ooooool0ROooool0053ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co0000
01Kooooo0ol00002ojFQdP04o`000?nUXM;oYJ7Bo`0000coYJ;B00?o0000ojFSdonUXm<02_nUXm<0
0ol0003oYZKFojJVeP0:ojJVeP03o`000?nWZ]WoYj[I00_oYj[I0_l00008okFef@03o`000?ne]MWo
]KGI00;o]KGI00?o0000okNkg?ng^m`03Ong^m`00ol0003oooooooooo`28ooooo`00D?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000005?ooool3o`0000OoYJ7B00?o0000
ojFRd_nUX]802onUX]800ol0003oYJ?CojFSd`09ojFSd`03o`000?nVY]KoYZKF00_oYZKF00?o0000
ojNZfOnWZ]T02?nWZ]T2o`000003ok:_e_l0003o]KGI00Oo]KGI00?o0000okFefOne]MT00one]MT0
0ol0003o]k_LokNkg00<okNkg0;o0000ROooool0053ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=
ooooo`03ogMgMol0003ooooo013ooooo0ol0000;ojFQdP03o`000?nUX];oYJ;B00[oYJ;B00?o0000
ojFSdonUXm<02_nUXm<00ol0003oYZKFojJVeP0:ojJVeP03o`000?nWZ]WoYj[I00KoYj[I0_l00004
ok:_eP03o`000?ne]MWo]KGI00Go]KGI00?o0000okFefOne]MT00one]MT00ol0003o]k_LokNkg00=
okNkg0;o0000R?ooool007?ooooo0ol000000onUX];o0000o`00000:ojFQdP03o`000?nUX];oYJ;B
00_oYJ;B00?o0000ojFSdonUXm<02OnUXm<00ol0003oYZKFojJVeP0;ojJVeP03o`000?nWZ]WoYj[I
00CoYj[I00?o0000ok:_e_nb[mH01Onb[mH00ol0003o]KGIokFef@04okFef@03o`000?ne]MWo]KGI
00Co]KGI00?o0000okNkg?ng^m`03Ong^m`2o`0008Oooooo001`ooooo`?o00001OnUX]800ol0003o
YJ7BojFQdP09ojFQdP03o`000?nUX];oYJ;B00[oYJ;B00?o0000ojFSdonUXm<02_nUXm<00ol0003o
YZKFojJVeP0;ojJVeP04o`000?nWZ]WoYj[IojNZf@;o00002?nb[mH00ol0003o]KGIokFef@04okFe
f@03o`000?ne]MWo]KGI00Go]KGI00?o0000okNkg?ng^m`02ong^m`00ol0003o`[oGo`000027oooo
o`00K_ooool3o`0000OoYJ;B00?o0000ojFQd_nUXM802OnUXM800ol0003oYJ;BojFRdP0;ojFRdP03
o`000?nUXm?oYJ?C00WoYJ?C00?o0000ojJVe_nVY]H02onVY]H01?l0003oYj[Io`000?l0000;ok:_
eP03o`000?ne]MWo]KGI00?o]KGI00?o0000okFefOne]MT01One]MT00ol0003o]k_LokNkg00:okNk
g003o`000?o2_mOo`[oG00;o0000Q_ooool003?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0002?ooooo0ol00002ojFRdP03o`000?nUX];oYJ;B00KoYJ;B00?o0000ojFQ
d_nUXM802OnUXM800ol0003oYJ;BojFRdP0:ojFRdP03o`000?nUXm?oYJ?C00[oYJ?C00?o0000ojJV
e_nVY]H02_nVY]H2o`0000go/ZoF00?o0000okFefOne]MT00one]MT00ol0003o]KGIokFef@06okFe
f@03o`000?ng^mco]k_L00Oo]k_L0_l00004ol:oe`;o0000QOooool003?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4027ooooo0ol00000
0onUXm?o0000ojFRdP0:ojFRdP03o`000?nUXM;oYJ7B00WoYJ7B00?o0000ojFRd_nUX]802onUX]80
0ol0003oYJ?CojFSd`0:ojFSd`03o`000?nVY]KoYZKF00OoYZKF0_l000000on_Zm?o0000ok:_eP0=
ok:_eP03o`000?ne]MWo]KGI00;o]KGI00?o0000okFefOne]MT01one]MT00ol0003o]k_LokNkg005
okNkg003o`000?o2_mOo`[oG00Go`[oG0_l00024ooooo`00<oooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h07oooool4o`0000CoYJ?C00?o0000ojFRd_nUX]802OnUX]80
0ol0003oYJ7BojFQdP09ojFQdP03o`000?nUX];oYJ;B00[oYJ;B00?o0000ojFSdonUXm<02_nUXm<0
0ol0003oYZKFojJVeP04ojJVeP?o00001?n_Zm<00ol0003o/ZoFok:_eP0<ok:_eP05o`000?ne]MWo
]KGIokFefOl000002_ne]MT00ol0003o]k_LokNkg002okNkg0;o00002Oo2_mL00ol0003ooooooooo
o`22ooooo`00<oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h06ooo
ool3o`0000CoYJ?C00Go0000ojFSdonUXm?oYJ?Co`00000;ojFRdP03o`000?nUXM;oYJ7B00WoYJ7B
00?o0000ojFRd_nUX]802onUX]800ol0003oYJ?CojFSd`0:ojFSd`04o`000?nVY]KoYZKFojJVeP;o
00002?n_Zm<00ol0003o/ZoFok:_eP0;ok:_eP05o`000?ne]MWo]KGIokFefOl000002_ne]MT01Ol0
003o]k_LokNkg?ng^mco000000_o`[oG0_l00023ooooo`00<oooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool06?ooool3o`0000_oYJ?C00?o0000ojFRd_nUX]802OnUX]80
0ol0003oYJ7BojFQdP09ojFQdP03o`000?nUX];oYJ;B00[oYJ;B00?o0000ojFSdonUXm<02_nUXm<0
1?l0003oYZKFo`000?l0000:ojn[d`03o`000?nb[mKo/ZoF00co/ZoF00Co0000okFefOne]MWo0000
2one]MT00ol0003o]k_Lo`00000=ol:oe`;o0000P_ooool003?ooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo01Cooooo0ol000000onVY]Ko0000ojFSd`0;ojFSd`03o`00
0?nUX];oYJ;B00WoYJ;B00?o0000ojFQd_nUXM802_nUXM800ol0003oYJ;BojFRdP0:ojFRdP03o`00
0?nUXm?oYJ?C00WoYJ?C0_l0000=ojn[d`03o`000?nb[mKo/ZoF00_o/ZoF00Co0000okFefOne]MWo
00002one]MT2o`0000oo`[oG0_l00021ooooo`00<oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@400Dooooo`?o00001?nVY]H00ol0003oYJ?CojFSd`0:ojFS
d`03o`000?nUX];oYJ;B00WoYJ;B00?o0000ojFQd_nUXM802OnUXM800ol0003oYJ;BojFRdP0;ojFR
dP03o`000?nUXm?oYJ?C00KoYJ?C0_l000000on/Ym;o0000ojn[d`0<ojn[d`03o`000?nb[mKo/ZoF
00co/ZoF00?o0000okFefOl000002_ne]MT00ol0003o_kWDo`00000@ol:oe`03o`000?oooooooooo
07oooooo000cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<017ooooo0ol00007ojJVeP03o`000?nUXm?oYJ?C00[oYJ?C00?o0000ojFRd_nUX]802OnUX]80
0ol0003oYJ7BojFQdP0:ojFQdP03o`000?nUX];oYJ;B00[oYJ;B00?o0000ojFSdonUXm<01?nUXm<2
o`0000Co[:OB00?o0000ojn[don_Zm<02on_Zm<00ol0003o/ZoFok:_eP0<ok:_eP;o00002?ne]MT2
o`0000?o_kWD00?o0000ol:oeoo2_mL03Oo2_mL2o`00083ooooo001Gooooo`?o000000?oYZKFo`00
0?nVY]H01onVY]H00ol0003oYJ?CojFSd`0:ojFSd`03o`000?nUX];oYJ;B00WoYJ;B00?o0000ojFQ
d_nUXM802OnUXM800ol0003oYJ;BojFRdP0;ojFRdP04o`000?nUXm?oYJ?CojFSd`;o00001_n/Ym80
0ol0003o[j_Cojn[d`0<ojn[d`03o`000?nb[mKo/ZoF00_o/ZoF0_l00006okFef@;o00001_no^M@0
0ol0003o`[oGol:oe`0=ol:oe`;o0000Ooooool005Cooooo0ol000000onWZ]Wo0000ojJVeP0;ojJV
eP03o`000?nUXm?oYJ?C00WoYJ?C00?o0000ojFRd_nUX]802_nUX]800ol0003oYJ7BojFQdP09ojFQ
dP03o`000?nUX];oYJ;B00[oYJ;B00Co0000ojFSdol0003o00002On/Ym800ol0003o[j_Cojn[d`0;
ojn[d`03o`000?nb[mKo/ZoF00co/ZoF00?o0000okFefOne]MT00one]MT00ol0003o_kWDoknie006
oknie003o`000?o2_mOo`[oG00ko`[oG00?o0000ooooooooool0OOooool005;ooooo0ol00004ojNZ
f@03o`000?nVY]KoYZKF00WoYZKF00?o0000ojFSdonUXm<02_nUXm<00ol0003oYJ;BojFRdP09ojFR
dP03o`000?nUXM;oYJ7B00WoYJ7B00?o0000ojFRd_nUX]802_nUX]82o`0000co[:OB00?o0000ojn[
don_Zm<02on_Zm<00ol0003o/ZoFok:_eP0;ok:_eP04o`000?ne]MWo]KGIokFef@;o00002_no^M@0
0ol0003o`[oGol:oe`0>ol:oe`03o`000?oooooooooo07cooooo000Wooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h08oooool4o`000003ojNZfOl0003oYj[I00CoYj[I00?o0000ojJVe_nVY]H02OnVY]H0
0ol0003oYJ?CojFSd`09ojFSd`03o`000?nUX];oYJ;B00[oYJ;B00?o0000ojFQd_nUXM802OnUXM80
0ol0003oYJ;BojFRdP07ojFRdP;o000000?oZJGBo`000?n/Ym802on/Ym800ol0003o[j_Cojn[d`0<
ojn[d`03o`000?nb[mKo/ZoF00[o/ZoF0_l000000one]MWo0000oknie00<oknie003o`000?o2_mOo
`[oG00go`[oG0_l0001mooooo`009oooool01OmgMgOoV9RHoooooonHV9SoMgMg027ooooo0ol0000:
ojNZf@03o`000?nVY]KoYZKF00WoYZKF00?o0000ojFSdonUXm<02_nUXm<00ol0003oYJ;BojFRdP09
ojFRdP03o`000?nUXM;oYJ7B00WoYJ7B00?o0000ojFRd_nUX]801?nUX]83o`0000CoZJGB00?o0000
ojbWd_n/Ym802_n/Ym800ol0003o[j_Cojn[d`0;ojn[d`03o`000?nb[mKo/ZoF00[o/ZoF0ol0000>
oknie003o`000?o2_mOo`[oG00ko`[oG0_l0001looooo`009oooool01Ol@413ooooooooooooooooo
410@01kooooo1Ol0000<ojNZf@03o`000?nVY]KoYZKF00WoYZKF00?o0000ojFSdonUXm<02_nUXm<0
0ol0003oYJ;BojFRdP09ojFRdP03o`000?nUXM;oYJ7B00WoYJ7B00Co0000ojFRd_nUX];oYJ;B0_l0
0007ojVUdP03o`000?n/Ym;o[:OB00[o[:OB00?o0000ojn[don_Zm<03?n_Zm<00ol0003o/ZoFok:_
eP09ok:_eP03o`000?nk]=?o000000oo_kWD00?o0000ol:oeoo2_mL03?o2_mL00ol0003ob/;Bo`00
001looooo`009oooool01Ol0003ooooooooooooooooo000001cooooo0ol00002ojR_g@03o`000?nX
[mgo000000_oYj[I00?o0000ojJVe_nVY]H02_nVY]H00ol0003oYJ?CojFSd`09ojFSd`03o`000?nU
X];oYJ;B00WoYJ;B00?o0000ojFQd_nUXM802OnUXM801?l0003oYJ;Bo`000?l0000:ojVUdP03o`00
0?n/Ym;o[:OB00[o[:OB00?o0000ojn[don_Zm<03?n_Zm<00ol0003o/ZoFok:_eP06ok:_eP?o0000
0_nk]=<00ol0003o_kWDoknie00=oknie003o`000?o2_mOo`[oG00[o`[oG00Go0000ol[2d_o:`];o
b/;Bo`00001kooooo`009oooool01Ol0003ooooooooooooooooo000001Wooooo1?l00005ojR_g@03
o`000?nX[mgo000000_oYj[I00?o0000ojJVe_nVY]H02OnVY]H00ol0003oYJ?CojFSd`0:ojFSd`03
o`000?nUX];oYJ;B00WoYJ;B00?o0000ojFQd_nUXM802?nUXM82o`0000coZJGB00?o0000ojbWd_n/
Ym802_n/Ym800ol0003o[j_Cojn[d`0<ojn[d`03o`000?nb[mKo/ZoF00Go/ZoF00Co0000ok^ddonk
]=?o00000onk]=<00ol0003o_kWDoknie00=oknie003o`000?o2_mOo`[oG00So`[oG00?o0000ol[2
d_o:`]800_o:`]82o`0007[ooooo000Wooooo`05oa0@4?ooooooooooooooool@41005oooool3o`00
00[oZ:oM00?o0000ojNZfOnWZ]T02_nWZ]T00ol0003oYZKFojJVeP09ojJVeP03o`000?nUXm?oYJ?C
00WoYJ?C00?o0000ojFRd_nUX]802OnUX]800ol0003oYJ7BojFQdP05ojFQdP?o000000?oYZ?Bo`00
0?nYYM803?nYYM800ol0003o[:OBojbWdP0:ojbWdP03o`000?n_Zm?o[j_C00co[j_C00?o0000ok:_
e_nb[mH00onb[mH01Ol0003o^kCCok^ddonk]=?o000000?o^kCC00?o0000oknie?no^M@03Ono^M@0
0ol0003o`[oGol:oe`06ol:oe`;o00001_o:`]82o`0007Wooooo000Wooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool5o`000003ojR_gOl0003oZ:oM00WoZ:oM00?o0000ojNZfOnWZ]T02OnWZ]T0
0ol0003oYZKFojJVeP09ojJVeP03o`000?nUXm?oYJ?C00[oYJ?C00?o0000ojFRd_nUX]802OnUX]80
0ol0003oYJ7BojFQdP02ojFQdP;o00001OnVXm800ol0003oZJGBojVUdP0;ojVUdP03o`000?n/Ym;o
[:OB00[o[:OB00?o0000ojn[don_Zm<02on_Zm<01?l0003o/ZoFok:_e_nb[mH2o`0000Co^kCC00?o
0000ok^ddonk]=<00_nk]=<00ol0003o_kWDoknie00=oknie003o`000?o2_mOo`[oG00Co`[oG00?o
0000ol[2d_o:`]801oo:`]800ol0003oooooooooo`1gooooo`009oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^01;ooooo0ol00004ojVfhP03o`000?nX[mgoZ:oM00[oZ:oM00?o0000ojNZfOnWZ]T02OnW
Z]T00ol0003oYZKFojJVeP09ojJVeP03o`000?nUXm?oYJ?C00WoYJ?C00?o0000ojFRd_nUX]802OnU
X]800ol0003oYJ7Bo`000002o`0000OoYZ?B00?o0000ojVUd_nYYM802onYYM800ol0003o[:OBojbW
dP0:ojbWdP03o`000?n_Zm?o[j_C00co[j_C00?o0000ok:_e_l000001_nk]=<00ol0003o^kCCok^d
d`03ok^dd`03o`000?no^MCo_kWD00go_kWD00?o0000ol:oeoo2_mL00_o2_mL00ol0003ob/;Bol[2
dP09ol[2dP03o`000?oooooooooo07Kooooo000kooooo`Go00001_nY]^800ol0003oZ:oMojR_g@09
ojR_g@03o`000?nWZ]WoYj[I00[oYj[I00?o0000ojJVe_nVY]H02OnVY]H00ol0003oYJ?CojFSd`09
ojFSd`03o`000?nUX];oYJ;B00SoYJ;B0_l0000;ojJSdP03o`000?nYYM;oZJGB00_oZJGB00?o0000
ojbWd_n/Ym802_n/Ym800ol0003o[j_Cojn[d`0;ojn[d`;o00001onk]=<00ol0003o^kCCok^dd`03
ok^dd`03o`000?no^MCo_kWD00go_kWD00Go0000ol:oeoo2_mOo`[oGo`00000<ol[2dP;o0000Mooo
ool003Wooooo0ol0000;ojVfhP03o`000?nX[mgoZ:oM00WoZ:oM00?o0000ojNZfOnWZ]T02OnWZ]T0
0ol0003oYZKFojJVeP09ojJVeP03o`000?nUXm?oYJ?C00WoYJ?C00?o0000ojFRd_nUX]801OnUX]83
o`000003ojBRdol0003oYZ?B00[oYZ?B00?o0000ojVUd_nYYM802onYYM800ol0003o[:OBojbWdP0:
ojbWdP03o`000?n_Zm?o[j_C00[o[j_C00?o0000okN`d_l000001onk]=<00ol0003o^kCCok^dd`04
ok^dd`03o`000?no^MCo_kWD00go_kWD00?o0000ol:oeol000003_o:`]82o`0007Kooooo000goooo
o`Co00003?nY]^800ol0003oZ:oMojR_g@0:ojR_g@03o`000?nWZ]WoYj[I00WoYj[I00?o0000ojJV
e_nVY]H02OnVY]H00ol0003oYJ?CojFSd`09ojFSd`03o`000?nUX];oYJ;B00;oYJ;B0_l00005ojBR
d`03o`000?nVXm;oYZ?B00WoYZ?B00?o0000ojVUd_nYYM802onYYM800ol0003o[:OBojbWdP0:ojbW
dP03o`000?n_Zm?o[j_C00Oo[j_C0_l00003okN`dP03o`000?nk]=?o^kCC00Co^kCC00?o0000ok^d
donk]=<01Onk]=<00ol0003o_kWDoknie00<oknie0;o00004?o:`]800ol0003oooooooooo`1doooo
o`00=?ooool3o`000005ojZliol0003oZ[cWojZliol000003?nY]^800ol0003oZ:oMojR_g@0:ojR_
g@03o`000?nWZ]WoYj[I00SoYj[I00?o0000ojJVe_nVY]H02OnVY]H00ol0003oYJ?CojFSd`09ojFS
d`03o`000?nUX];o000000;o00001onTX]<00ol0003oYZ?BojJSdP0:ojJSdP03o`000?nYYM;oZJGB
00[oZJGB00?o0000ojbWd_n/Ym802_n/Ym800ol0003o[j_Cojn[d`05ojn[d`;o00001Ong/=800ol0
003o^kCCok^dd`04ok^dd`03o`000?nk]=?o^kCC00Go^kCC00?o0000oknie?no^M@02ono^M@00ol0
003oakgAo`00000Aol[2dP03o`000?oooooooooo07?ooooo000booooo`?o00001onZ_>L00ol0003o
ZKKRojVfhP0:ojVfhP03o`000?nX[mgoZ:oM00WoZ:oM00?o0000ojNZfOnWZ]T02OnWZ]T00ol0003o
YZKFojJVeP09ojJVeP03o`000?nUXm?oYJ?C00OoYJ?C0ol0000;ojBRd`03o`000?nVXm;oYZ?B00Wo
YZ?B00?o0000ojVUd_nYYM802onYYM800ol0003o[:OBojbWdP0:ojbWdP03o`000?n_Zm?o[j_C00?o
[j_C00?o0000okN`d_ng/=801_ng/=800ol0003o^kCCok^dd`03ok^dd`03o`000?nk]=?o^kCC00Ko
^kCC00?o0000oknie?no^M@02Ono^M@01Ol0003oakgAolNmdOo7_M7o0000013ob/;B0_l0001doooo
o`00<Oooool00ol0003oZ[cWojZli`09ojZli`03o`000?nY]^;oZKKR00WoZKKR00?o0000ojR_gOnX
[md02_nX[md00ol0003oYj[IojNZf@09ojNZf@03o`000?nVY]KoYZKF00WoYZKF00?o0000ojFSdonU
Xm<00onUXm<3o`0000;oXJ;F00?o0000ojBRdonTX]<02OnTX]<00ol0003oYZ?BojJSdP0:ojJSdP03
o`000?nYYM;oZJGB00[oZJGB00?o0000ojbWd_n/Ym802on/Ym800ol0003o[j_Cojn[d`02o`0000[o
]k3B00?o0000ok^ddonk]=<00_nk]=<00ol0003o^kCCok^dd`07ok^dd`03o`000?no^MCo_kWD00Oo
_kWD00?o0000olNmdOo7_M400oo7_M400ol0003ob/;Bol[2dP0>ol[2dP03o`000?oooooooooo07;o
oooo000aooooo`;o00002onZ_>L00ol0003oZKKRojVfhP09ojVfhP03o`000?nX[mgoZ:oM00[oZ:oM
00?o0000ojNZfOnWZ]T02?nWZ]T00ol0003oYZKFojJVeP09ojJVeP03o`000?nUXm?oYJ?C00?o0000
1_nQX]H00ol0003oY:;CojBRd`09ojBRd`03o`000?nVXm;oYZ?B00WoYZ?B00?o0000ojVUd_nYYM80
2onYYM800ol0003o[:OBojbWdP0:ojbWdP03o`000?n_Zm?o000000co]k3B00?o0000ok^ddonk]=<0
0_nk]=<00ol0003o^kCCok^dd`07ok^dd`03o`000?no^MCo_kWD00Ko_kWD00?o0000olNmdOo7_M40
1?o7_M400ol0003ob/;Bol[2dP0?ol[2dP03o`000?oooooooooo077ooooo000Uooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01oooool2o`0000_oZ[cW00?o0000ojVfh_nY]^802_nY]^800ol0003oZ:oM
ojR_g@09ojR_g@03o`000?nWZ]WoYj[I00WoYj[I00?o0000ojJVe_nVY]H01onVY]H4o`0000WoXJ;F
00?o0000ojBRdonTX]<02_nTX]<00ol0003oYZ?BojJSdP09ojJSdP03o`000?nYYM;oZJGB00[oZJGB
00?o0000ojbWd_n/Ym802_n/Ym82o`0000ko]k3B00Go0000ok^ddonk]=?o^kCCo`00000:ok^dd`03
o`000?no^MCo_kWD00Co_kWD00?o0000olNmdOo7_M401_o7_M400ol0003ob/;Bol[2dP0?ol[2dP03
o`000?oooooooooo073ooooo000Uooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool00ol0003o
ooooo`00000;ojZli`03o`000?nY]^;oZKKR00[oZKKR00?o0000ojR_gOnX[md02OnX[md00ol0003o
Yj[IojNZf@08ojNZf@03o`000?nVY]KoYZKF00CoYZKF0ol00002oijTf@03o`000?nQX]KoXJ;F00Wo
XJ;F00?o0000ojBRdonTX]<02OnTX]<00ol0003oYZ?BojJSdP09ojJSdP03o`000?nYYM;oZJGB00_o
ZJGB00?o0000ojbWd_n/Ym801on/Ym82o`000003ok>/dOl0003o]k3B00go]k3B00Go0000ok^ddonk
]=?o^kCCo`00000;ok^dd`03o`000?no^MCo_kWD00;o_kWD00?o0000olNmdOo7_M402?o7_M400ol0
003ob/;Bol[2dP0>ol[2dP;o0000LOooool002Gooooo00Go410@oooooooooooooooooa0@4007oooo
o`04o`000?ooooooooooo`0000_oZ[cW00?o0000ojVfh_nY]^802OnY]^800ol0003oZ:oMojR_g@0:
ojR_g@03o`000?nWZ]WoYj[I00SoYj[I00?o0000ojJVe_nVY]H00ol00006oijTf@03o`000?nQX]Ko
XJ;F00WoXJ;F00?o0000ojBRdonTX]<02OnTX]<00ol0003oYZ?BojJSdP09ojJSdP03o`000?nYYM;o
ZJGB00_oZJGB00?o0000ojbWd_n/Ym801On/Ym800ol0003o/jcAok>/d@02ok>/d@03o`000?ng/=;o
]k3B00co]k3B00Co0000ok^ddonk]=?o00002onk]=<01Ol0003o_kWDoknie?no^MCo000000_oakgA
00?o0000ol[2d_o:`]803Oo:`]800ol0003od<C?o`00001aooooo`009Oooool01Ol0003ooooooooo
oooooooo000000Kooooo0_l00003ooooo`03o`000?nZ_>OoZ[cW00WoZ[cW00?o0000ojVfh_nY]^80
2OnY]^800ol0003oZ:oMojR_g@09ojR_g@03o`000?nWZ]WoYj[I00OoYj[I1?l00009oijTf@03o`00
0?nQX]KoXJ;F00WoXJ;F00?o0000ojBRdonTX]<02OnTX]<00ol0003oYZ?BojJSdP09ojJSdP03o`00
0?nYYM;oZJGB00_oZJGB00?o0000ojbWd_n/Ym800on/Ym82o`0000Ko/jcA00?o0000okN`d_ng/=80
3?ng/=800ol0003o^kCCo`00000<ok^dd`03o`000?no^MCo000000goakgA00?o0000ol[2d_o:`]80
2oo:`]801Ol0003od<C?om34coo@a<oo0000073ooooo000Uooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`03ooooo`03o`000?nZ_>OoZ[cW00WoZ[cW00?o0000ojVfh_nY
]^802OnY]^800ol0003oZ:oMojR_g@09ojR_g@04o`000?nWZ]WoYj[IojNZf@Go00000_nLY]d00ol0
003oWZCIoijTf@09oijTf@03o`000?nQX]KoXJ;F00WoXJ;F00?o0000ojBRdonTX]<02OnTX]<00ol0
003oYZ?BojJSdP09ojJSdP03o`000?nYYM;oZJGB00_oZJGB00?o0000ojbWd_n/Ym800_l00008ok>/
d@03o`000?ng/=;o]k3B00co]k3B00?o0000ok^ddol000003?nk]=<2o`0000ooakgA00?o0000ol[2
d_o:`]802Oo:`]800ol0003od<C?om34c`03om34c`03o`000?oooooooooo06gooooo000Uooooo`05
oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04ooooo`03o`000?nZ_>OoZ[cW
00WoZ[cW00?o0000ojVfh_nY]^802?nY]^800ol0003oZ:oMojR_g@08ojR_g@Go00002?nLY]d00ol0
003oWZCIoijTf@09oijTf@03o`000?nQX]KoXJ;F00SoXJ;F00?o0000ojBRdonTX]<02OnTX]<00ol0
003oYZ?BojJSdP09ojJSdP03o`000?nYYM;oZJGB00_oZJGB00?o0000ojbWd_l000002onc[=400ol0
003o]k3BokN`dP0<okN`dP;o00002onk]=<00ol0003o`kW@o`00000@olNmd@03o`000?o:`];ob/;B
00Oob/;B00?o0000om34coo@a<l01?o@a<l2o`0006kooooo000Uooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`05ooooo`03o`000?nZ_>OoZ[cW00SoZ[cW00?o0000ojVf
h_nY]^802OnY]^800ol0003oZ:oMojR_g@04ojR_g@?o00000_nIZ^800ol0003oW:KMoibVg@09oibV
g@03o`000?nNY=WoWZCI00SoWZCI00?o0000oj6Re_nQX]H02OnQX]H00ol0003oY:;CojBRd`09ojBR
d`03o`000?nVXm;oYZ?B00WoYZ?B00?o0000ojVUd_nYYM802_nYYM82o`0000co/jcA00?o0000okN`
d_ng/=803?ng/=82o`0000[o^kCC00Go0000ol>id?o3^M3o`kW@o`00000?olNmd@03o`000?o:`];o
b/;B00Kob/;B00?o0000om34coo@a<l01_o@a<l00ol0003oooooooooo`1/ooooo`009Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01_ooool00ol0003oZ[cWojZli`08
ojZli`03o`000?nY]^;oZKKR00WoZKKR00?o0000ojR_gOnX[md00ol00006oiVZhP03o`000?nLY]go
W:KM00SoW:KM00?o0000oijTfOnNY=T02OnNY=T00ol0003oXJ;Foj6ReP08oj6ReP03o`000?nTX]?o
Y:;C00WoY:;C00?o0000ojJSd_nVXm802_nVXm800ol0003oZJGBojVUdP07ojVUdP;o000000?o[ZSB
o`000?nc[=403?nc[=400ol0003o]k3BokN`dP0<okN`dP03o`000?nk]=?o^kCC00Ko^kCC0_l00005
ol>id003o`000?o7_M7oakgA00goakgA00?o0000ol[2d_o:`]801?o:`]800ol0003od<C?om34c`08
om34c`03o`000?oooooooooo06_ooooo000`ooooo`03o`000?oooooooooo00Oooooo00?o0000ojZl
ionZ_>L02?nZ_>L00ol0003oZKKRojVfhP07ojVfhPCo00002_nIZ^800ol0003oW:KMoibVg@08oibV
g@03o`000?nNY=WoWZCI00SoWZCI00?o0000oj6Re_nQX]H02OnQX]H00ol0003oY:;CojBRd`09ojBR
d`03o`000?nVXm;oYZ?B00WoYZ?B00?o0000ojVUd_nYYM801?nYYM83o`0000Co[ZSB00?o0000ok>/
dOnc[=402onc[=400ol0003o]k3BokN`dP0;okN`dP03o`000?nk]=?o^kCC00Go^kCC00?o0000ol>i
d?o3^M001Oo3^M000ol0003oakgAolNmd@0>olNmd@03o`000?o:`];ob/;B00;ob/;B00?o0000om34
coo@a<l02_o@a<l00ol0003oooooooooo`1Zooooo`00<?ooool00ol0003oooooooooo`08ooooo`03
o`000?nZ_>OoZ[cW00SoZ[cW00Co0000ojVfh_nY]^;oZKKR1Ol00002oiN_j003o`000?nIZ^;oVJ[R
00WoVJ[R00?o0000oibVgOnLY]d02?nLY]d00ol0003oWZCIoijTf@09oijTf@03o`000?nQX]KoXJ;F
00WoXJ;F00?o0000ojBRdonTX]<02?nTX]<00ol0003oYZ?BojJSdP0:ojJSdP04o`000?nYYM;oZJGB
ojVUdP;o00001on^Z=800ol0003o/jcAok>/d@0;ok>/d@03o`000?ng/=;o]k3B00_o]k3B0_l00004
ok^dd`;o00002Oo3^M000ol0003oakgAolNmd@0=olNmd@05o`000?o:`];ob/;Bol[2d_l000003Oo@
a<l00ol0003oooooooooo`1Zooooo`00;oooool2o`0000_ooooo00?o0000ojZlionZ_>L01_nZ_>L5
o`0000SoUjoX00?o0000oiVZh_nIZ^802OnIZ^800ol0003oW:KMoibVg@08oibVg@03o`000?nNY=Wo
WZCI00SoWZCI00?o0000oj6Re_nQX]H02OnQX]H00ol0003oY:;CojBRd`09ojBRd`03o`000?nVXm;o
YZ?B00WoYZ?B00Co0000ojVUd_l0003o00002_n^Z=800ol0003o/jcAok>/d@0;ok>/d@03o`000?ng
/=;o]k3B00[o]k3B00?o0000okN`d_l000000_nk]=<00ol0003o`kW@ol>id00:ol>id003o`000?o7
_M7oakgA00goakgA00?o0000ol[2d_l000003oo@a<l00ol0003oooooooooo`1Yooooo`00<?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?nZ_>OoZ[cW00Go00000_nE]^h00ol0003oUjoXoiN_j009
oiN_j003o`000?nIZ^;oVJ[R00SoVJ[R00?o0000oibVgOnLY]d02OnLY]d00ol0003oWZCIoijTf@08
oijTf@03o`000?nQX]KoXJ;F00WoXJ;F00?o0000ojBRdonTX]<02OnTX]<00ol0003oYZ?BojJSdP08
ojJSdP;o00003?n^Z=800ol0003o/jcAok>/d@0;ok>/d@03o`000?ng/=;o]k3B00[o]k3B00Go0000
okN`d_l0003o^kCCo`00000=ol>id003o`000?o7_M7oakgA00koakgA00?o0000om34coo@a<l03oo@
a<l00ol0003oooooooooo`1Xooooo`00;oooool00ol0003oooooooooo`0<ooooo`;o00002?nE]^h0
0ol0003oUjoXoiN_j009oiN_j003o`000?nIZ^;oVJ[R00SoVJ[R00?o0000oibVgOnLY]d02?nLY]d0
0ol0003oWZCIoijTf@09oijTf@03o`000?nQX]KoXJ;F00SoXJ;F00?o0000ojBRdonTX]<02OnTX]<0
0ol0003oYZ?BojJSdP05ojJSdP?o000000?oZ:KCo`000?n^Z=803?n^Z=800ol0003o/jcAok>/d@0;
ok>/d@03o`000?ng/=;o]k3B00Wo]k3B00Co0000okN`d_l0003o00003oo3^M000ol0003oakgAolNm
d@0<olNmd@;o00004_o@a<l00ol0003oooooooooo`1Wooooo`00;oooool00ol0003oooooooooo`0=
ooooo`03o`000?nE]^koUKK^00OoUKK^00?o0000oiN_j?nG[nP02?nG[nP00ol0003oVJ[RoiVZhP09
oiVZhP03o`000?nLY]goW:KM00SoW:KM00?o0000oijTfOnNY=T02?nNY=T00ol0003oXJ;Foj6ReP09
oj6ReP03o`000?nTX]?oY:;C00WoY:;C00?o0000ojJSd_nVXm800_nVXm82o`0000GoZ:KC00?o0000
ojjXd_n^Z=802on^Z=800ol0003o/jcAok>/d@0;ok>/d@03o`000?ng/=;o]k3B00So]k3B0_l00000
0onn]M3o0000ol>id00?ol>id003o`000?o7_M7oakgA00[oakgA00Co0000olg1c_o=`Lko00004Oo@
a<l00ol0003oooooooooo`1Wooooo`00;oooool00ol0003oooooooooo`0>ooooo`03o`000?nE]^ko
UKK^00OoUKK^00?o0000oiN_j?nG[nP02?nG[nP00ol0003oVJ[RoiVZhP08oiVZhP03o`000?nLY]go
W:KM00SoW:KM00?o0000oijTfOnNY=T02OnNY=T00ol0003oXJ;Foj6ReP08oj6ReP03o`000?nTX]?o
Y:;C00WoY:;C00?o0000ojJSd_l000000_l00008ojRVd`03o`000?n^Z=;o[ZSB00[o[ZSB00?o0000
ok>/dOnc[=402onc[=400ol0003o]k3BokN`dP08okN`dP05o`000?nn]M3o_[G@okjed?l000003oo3
^M000ol0003oakgAolNmd@09olNmd@03o`000?o=`LkocL7>00;ocL7>00?o0000om34coo@a<l03oo@
a<l00ol0003oooooooooo`1Vooooo`00;oooool00ol0003oooooooooo`0?ooooo`03o`000?nE]^ko
UKK^00OoUKK^00?o0000oiN_j?nG[nP02?nG[nP00ol0003oVJ[RoiVZhP08oiVZhP03o`000?nLY]go
W:KM00SoW:KM00?o0000oijTfOnNY=T02?nNY=T00ol0003oXJ;Foj6ReP09oj6ReP03o`000?nTX]?o
Y:;C00OoY:;C0ol0000;ojRVd`03o`000?n^Z=;o[ZSB00_o[ZSB00?o0000ok>/dOnc[=402onc[=40
0ol0003o]k3BokN`dP06okN`dP;o00001?nn]M000ol0003o`kW@ol>id00=ol>id003o`000?o7_M7o
akgA00OoakgA00?o0000olg1c_o=`Lh01?o=`Lh00ol0003od<C?om34c`0?om34c`03o`000?oooooo
oooo06Gooooo000^ooooo`?o00004Oooool00ol0003oUKK^oiFfkP07oiFfkP03o`000?nG[nSoUjoX
00SoUjoX00?o0000oiVZh_nIZ^802?nIZ^800ol0003oW:KMoibVg@08oibVg@03o`000?nNY=WoWZCI
00SoWZCI00?o0000oj6Re_nQX]H02OnQX]H00ol0003oY:;CojBRd`03ojBRd`?o00000_nSY=H00ol0
003oZ:KCojRVd`0:ojRVd`03o`000?n^Z=;o[ZSB00[o[ZSB00?o0000ok>/dOnc[=402onc[=400ol0
003o]k3BokN`dP04okN`dP;o000000?o_[G@o`000?nn]M000onn]M000ol0003o`kW@ol>id00=ol>i
d003o`000?o7_M7oakgA00KoakgA00?o0000olg1c_o=`Lh01Oo=`Lh00ol0003od<C?om34c`0?om34
c`;o0000I_ooool002oooooo00?o0000ooooooooool04Oooool00ol0003oUKK^oiFfkP07oiFfkP03
o`000?nG[nSoUjoX00SoUjoX00?o0000oiVZh_nIZ^801onIZ^800ol0003oW:KMoibVg@08oibVg@03
o`000?nNY=WoWZCI00SoWZCI00?o0000oj6Re_nQX]H02OnQX]H00ol0003oY:;CojBRd`03o`0000Ko
XjCF00?o0000ojRVdonXY]<02OnXY]<00ol0003o[ZSBojjXdP0;ojjXdP03o`000?nc[=7o/jcA00_o
/jcA00?o0000okN`d_ng/=800_ng/=801Ol0003o_[G@okjed?nn]M3o000000Go_[G@00?o0000ol>i
d?o3^M003Oo3^M000ol0003oakgAolNmd@04olNmd@03o`000?o=`LkocL7>00OocL7>00?o0000om34
coo@a<l03Oo@a<l00ol0003oe<K<o`00001Vooooo`00;oooool00ol0003oooooooooo`0Booooo`03
o`000?nE]^koUKK^00OoUKK^00?o0000oiN_j?nG[nP01onG[nP00ol0003oVJ[RoiVZhP08oiVZhP03
o`000?nLY]goW:KM00SoW:KM00?o0000oijTfOnNY=T02?nNY=T00ol0003oXJ;Foj6ReP07oj6RePCo
00002OnSY=H00ol0003oZ:KCojRVd`0:ojRVd`03o`000?n^Z=;o[ZSB00[o[ZSB00?o0000ok>/dOnc
[=403?nc[=401?l0003o]k3BokN`d_l00004okjed003o`000?nn]M3o_[G@00Co_[G@00?o0000ol>i
d?o3^M003Oo3^M000ol0003oakgAolNmd@02olNmd@03o`000?o=`LkocL7>00WocL7>00?o0000om34
coo@a<l02oo@a<l01Ol0003oe<K<omC6c?oDa/co000006Gooooo000_ooooo`03o`000?oooooooooo
01?ooooo00?o0000oiFfk_nE]^h01_nE]^h00ol0003oUjoXoiN_j008oiN_j003o`000?nIZ^;oVJ[R
00SoVJ[R00?o0000oibVgOnLY]d01onLY]d00ol0003oWZCIoijTf@09oijTf@03o`000?nQX]KoXJ;F
00?oXJ;F0ol00002oibRf@03o`000?nSY=KoXjCF00WoXjCF00?o0000ojRVdonXY]<02_nXY]<00ol0
003o[ZSBojjXdP0:ojjXdP03o`000?nc[=7o/jcA00_o/jcA00?o0000okN`d_l000001Onn]M000ol0
003o_[G@okjed004okjed003o`000?o3^M3o`kW@00go`kW@00Go0000olNmdOo7_M7oakgAo`00000=
olg1cP03o`000?o@a<ood<C?00Wod<C?00?o0000omC6c?oDa/`00ooDa/`00ol0003oooooooooo`1R
ooooo`00;oooool00ol0003oooooooooo`0Cooooo`;o00002?nE]^h00ol0003oUjoXoiN_j008oiN_
j003o`000?nIZ^;oVJ[R00OoVJ[R00?o0000oibVgOnLY]d02?nLY]d00ol0003oWZCIoijTf@08oijT
f@03o`000?nQX]KoXJ;F00?o00001_nLX]T00ol0003oXjCFoj>TeP09oj>TeP03o`000?nXY]?oZ:KC
00WoZ:KC00?o0000ojjXd_n^Z=802_n^Z=800ol0003o/jcAok>/d@0;ok>/d@;o00001_nn]M000ol0
003o_[G@okjed005okjed003o`000?o3^M3o`kW@00go`kW@00?o0000olNmdOl000003_o=`Lh00ol0
003od<C?om34c`08om34c`03o`000?oDa/coe<K<00Coe<K<0_l0001Sooooo`00;_ooool00ol0003o
ooooooooo`0Eooooo`;o00002?nE]^h00ol0003oUjoXoiN_j008oiN_j003o`000?nIZ^;oVJ[R00Oo
VJ[R00?o0000oibVgOnLY]d02?nLY]d00ol0003oWZCIoijTf@06oijTf@Co00002OnLX]T00ol0003o
XjCFoj>TeP09oj>TeP03o`000?nXY]?oZ:KC00[oZ:KC00?o0000ojjXd_n^Z=802_n^Z=800ol0003o
/jcAok>/d@08ok>/d@;o000000?o^K7Ao`000?nn]M001Onn]M000ol0003o_[G@okjed006okjed003
o`000?o3^M3o`kW@00co`kW@0_l0000@olg1cP03o`000?o@a<ood<C?00Kod<C?00?o0000omC6c?oD
a/`01_oDa/`00ol0003oooooooooo`1Qooooo`00;_ooool3o`0001Kooooo0_l00008oiFfkP03o`00
0?nG[nSoUjoX00OoUjoX00?o0000oiVZh_nIZ^801onIZ^800ol0003oW:KMoibVg@08oibVg@04o`00
0?nNY=WoWZCIoijTf@Go00000_nFX]d00ol0003oW:;IoibRf@09oibRf@03o`000?nSY=KoXjCF00Wo
XjCF00?o0000ojRVdonXY]<02OnXY]<00ol0003o[ZSBojjXdP0;ojjXdP03o`000?nc[=7o/jcA00Go
/jcA0_l00004okVad@03o`000?nn]M3o_[G@00?o_[G@00?o0000okjed?nn]M001_nn]M000ol0003o
`kW@ol>id00;ol>id003o`000?o9_Loo0000017ocL7>00?o0000om34coo@a<l01?o@a<l00ol0003o
e<K<omC6c008omC6c003o`000?oooooooooo063ooooo000^ooooo`03o`000?oooooooooo01Oooooo
0_l00008oiFfkP03o`000?nG[nSoUjoX00OoUjoX00?o0000oiVZh_nIZ^801onIZ^800ol0003oW:KM
oibVg@03oibVg@So00002?nFX]d00ol0003oW:;IoibRf@09oibRf@03o`000?nSY=KoXjCF00SoXjCF
00?o0000ojRVdonXY]<02_nXY]<00ol0003o[ZSBojjXdP0:ojjXdP03o`000?nc[=7o/jcA00Co/jcA
00?o0000okVadOni/M401Oni/M400ol0003o_[G@okjed002okjed003o`000?nn]M3o_[G@00Oo_[G@
00?o0000ol>id?o3^M002Oo3^M001Ol0003obKg?olVmcoo9_Loo0000013ocL7>00?o0000om34coo@
a<l00oo@a<l00ol0003oe<K<omC6c00:omC6c003o`000?oooooooooo05oooooo000Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00007ooooo`03o`000?oooooooooo01So
oooo0_l00008oiFfkP03o`000?nG[nSoUjoX00OoUjoX00?o0000oiVZh_nIZ^800onIZ^89o`0000Go
Sj;R00?o0000oiJRgOnFX]d02OnFX]d00ol0003oW:;IoibRf@08oibRf@03o`000?nSY=KoXjCF00Wo
XjCF00?o0000ojRVdonXY]<02_nXY]<00ol0003o[ZSBojjXdP0:ojjXdP04o`000?nc[=7o/jcAok>/
d@;o00002?ni/M400ol0003o_[G@okjed002okjed003o`000?nn]M3o_[G@00So_[G@00?o0000ol>i
d?o3^M001oo3^M000ol0003obKg?olVmc`03olVmc`03o`000?o=`LkocL7>00kocL7>00Go0000om34
coo@a<ood<C?o`00000>omC6c003o`000?oooooooooo05kooooo000Booooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03o`000?oo
oooooooo01Wooooo6Ol00004ohNTi`03o`000?n?X^;oSj;R00SoSj;R00?o0000oiJRgOnFX]d02?nF
X]d00ol0003oW:;IoibRf@09oibRf@03o`000?nSY=KoXjCF00SoXjCF00?o0000ojRVdonXY]<02_nX
Y]<00ol0003o[ZSBojjXdP0:ojjXdP04o`000?nc[=7o0000o`0000_o^K7A00Go0000okjed?nn]M3o
_[G@o`00000:okjed003o`000?o3^M3o`kW@00Ko`kW@00?o0000olVmcoo9_Ll01Oo9_Ll00ol0003o
cL7>olg1cP0>olg1cP03o`000?o@a<oo000000ooe<K<00?o0000ooooooooool0G_ooool001;ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Sooooo00?o0000oooooooo
ool06_ooool00ol0003oNJ[bogVZlP06ogVZlP03o`000?n0Y^goP:K]00OoP:K]00?o0000ohNTion7
Y>L01on7Y>L00ol0003oSj;RohnRhP08ohnRhP03o`000?nFX]goUZ;M00SoUZ;M00?o0000oibRfOnL
X]T02?nLX]T00ol0003oXjCFoj>TeP09oj>TeP03o`000?nXY]?oZ:KC00[oZ:KC00?o0000ojjXd_n^
Z=802On^Z=82o`0000go^K7A00Go0000okjed?nn]M3o_[G@o`00000;okjed003o`000?o3^M3o`kW@
00Co`kW@00?o0000olVmcoo9_Ll01_o9_Ll00ol0003ocL7>olg1cP0?olg1cP03o`000?oDa/coe<K<
00ooe<K<00?o0000ooooooooool0GOooool001;ooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool06oooool00ol0003oNJ[bogVZlP06ogVZ
lP03o`000?n0Y^goP:K]00OoP:K]00?o0000ohNTion7Y>L01on7Y>L00ol0003oSj;RohnRhP07ohnR
hP03o`000?nFX]goUZ;M00SoUZ;M00?o0000oibRfOnLX]T02OnLX]T00ol0003oXjCFoj>TeP09oj>T
eP03o`000?nXY]?oZ:KC00WoZ:KC00?o0000ojjXd_n^Z=801on^Z=82o`000003ok:]dol0003o^K7A
00go^K7A00Co0000okjed?nn]M3o00003?nn]M000ol0003o`kW@ol>id002ol>id003o`000?o9_Loo
bKg?00SobKg?00?o0000olg1c_o=`Lh03Oo=`Lh2o`0001;oe<K<00?o0000ooooooooool0G?ooool0
01;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Kooooo00?o0000
ooooooooool07?ooool00ol0003oNJ[bogVZlP06ogVZlP03o`000?n0Y^goP:K]00OoP:K]00?o0000
ohNTion7Y>L01_n7Y>L00ol0003oSj;RohnRhP08ohnRhP03o`000?nFX]goUZ;M00SoUZ;M00?o0000
oibRfOnLX]T02?nLX]T00ol0003oXjCFoj>TeP09oj>TeP03o`000?nXY]?oZ:KC00[oZ:KC00?o0000
ojjXd_n^Z=801?n^Z=82o`0000Co/ZgC00?o0000okVadOni/M403?ni/M400ol0003o_[G@o`00000<
okjed005o`000?o3^M3o`kW@ol>id?l000003?o9_Ll00ol0003ocL7>olg1cP0;olg1cP04o`000?oB
a<cod/C<o`0001;oe<K<00?o0000ooooooooool0Foooool001;ooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00Cooooo0_l0000Oooooo`03o`000?miZ_;oNJ[b00KoNJ[b
00?o0000oh2VkOn0Y^d01on0Y^d00ol0003oQjCWohNTi`06ohNTi`03o`000?n?X^;oSj;R00OoSj;R
00?o0000oiJRgOnFX]d02OnFX]d00ol0003oW:;IoibRf@08oibRf@03o`000?nSY=KoXjCF00WoXjCF
00?o0000ojRVdonXY]<02_nXY]<01?l0003o[ZSBojjXd_n^Z=82o`0000Oo/ZgC00?o0000okVadOni
/M402oni/M400ol0003o_[G@o`00000=okjed003o`000?o3^M3o000000kobKg?00?o0000olg1c_o=
`Lh02Oo=`Lh00ol0003od/C<om;4c002om;4c003o`000?oDa/coe<K<00ooe<K<00?o0000oooooooo
ool0Foooool001;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001_ooool00ol0003oooooooooo`0Oooooo`03o`000?miZ_;oNJ[b00KoNJ[b00?o0000oh2V
kOn0Y^d01_n0Y^d00ol0003oQjCWohNTi`07ohNTi`03o`000?n?X^;oSj;R00OoSj;R00?o0000oiJR
gOnFX]d02?nFX]d00ol0003oW:;IoibRf@09oibRf@03o`000?nSY=KoXjCF00SoXjCF00?o0000ojRV
donXY]<02_nXY]<01?l0003o[ZSBo`000?l00009ok:]d`03o`000?ni/M7o^K7A00co^K7A0_l0000=
okjed0;o00003oo9_Ll00ol0003ocL7>olg1cP08olg1cP03o`000?oBa<cod/C<00Cod/C<00?o0000
omC6c?oDa/`03OoDa/`00ol0003oelS;o`00001Looooo`004_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo023ooooo00?o
0000ogVZl_miZ_801_miZ_800ol0003oP:K]oh2Vk@06oh2Vk@03o`000?n7Y>OoQjCW00KoQjCW00?o
0000ohnRh_n?X^802?n?X^800ol0003oUZ;MoiJRg@08oiJRg@03o`000?nLX]WoW:;I00SoW:;I00?o
0000oj>Te_nSY=H02OnSY=H00ol0003oZ:KCojRVd`09ojRVd`;o00003?nb[M<00ol0003o^K7AokVa
d@0;okVad@;o00003?nn]M000ol0003oaK[@o`00000@olVmc`03o`000?o=`LkocL7>00KocL7>00?o
0000om;4c?oBa<`01OoBa<`00ol0003oe<K<omC6c00<omC6c005o`000?oGb<_oelS;omO8bol00000
Foooool002gooooo00?o0000ooooooooool08Oooool00ol0003oNJ[bogVZlP06ogVZlP03o`000?n0
Y^goP:K]00KoP:K]00?o0000ohNTion7Y>L01_n7Y>L00ol0003oSj;RohnRhP07ohnRhP03o`000?nF
X]goUZ;M00SoUZ;M00?o0000oibRfOnLX]T02OnLX]T00ol0003oXjCFoj>TeP08oj>TeP03o`000?nX
Y]?oZ:KC00OoZ:KC0_l000000on[Z]Ko0000ok:]d`0;ok:]d`03o`000?ni/M7o^K7A00co^K7A00?o
0000okjed?nn]M002Onn]M001Ol0003oaK[@olFjd?o5^]3o0000013obKg?00?o0000olg1c_o=`Lh0
1?o=`Lh00ol0003od/C<om;4c007om;4c003o`000?oDa/coe<K<00[oe<K<00?o0000omO8booGb</0
0ooGb</00ol0003oooooooooo`1Hooooo`00;Oooool00ol0003oooooooooo`0Qooooo`03o`000?mi
Z_;oNJ[b00OoNJ[b00?o0000oh2VkOn0Y^d01_n0Y^d00ol0003oQjCWohNTi`06ohNTi`03o`000?n?
X^;oSj;R00OoSj;R00?o0000oiJRgOnFX]d02?nFX]d00ol0003oW:;IoibRf@08oibRf@03o`000?nS
Y=KoXjCF00WoXjCF00?o0000ojRVdonXY]<01?nXY]<2o`0000CoZj[F00?o0000ok:]donb[M<02_nb
[M<00ol0003o^K7AokVad@0;okVad@;o00002?nn]M02o`0000GoaK[@00?o0000olVmcoo9_Ll03Oo9
_Ll00ol0003ocL7>olg1cP03olg1cP03o`000?oBa<cod/C<00Wod/C<00?o0000omC6c?oDa/`02?oD
a/`00ol0003oelS;omO8b`04omO8b`03o`000?oooooooooo05Sooooo000]ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ogVZl_miZ_801_miZ_800ol0003oP:K]oh2Vk@06oh2Vk@03o`000?n7Y>Oo
QjCW00KoQjCW00?o0000ohnRh_n?X^802?n?X^800ol0003oUZ;MoiJRg@08oiJRg@03o`000?nLX]Wo
W:;I00SoW:;I00?o0000oj>Te_nSY=H02OnSY=H01?l0003oZ:KCojRVdonXY]<2o`0000OoZj[F00?o
0000ok:]donb[M<02_nb[M<00ol0003o^K7AokVad@0:okVad@;o00001onn]M000ol0003oaK[@olFj
d005olFjd003o`000?o9_LoobKg?00kobKg?00Go0000olg1c_o=`LkocL7>o`00000<om;4c003o`00
0?oDa/coe<K<00Ooe<K<00?o0000omO8booGb</01_oGb</00ol0003oooooooooo`1Gooooo`00;?oo
ool3o`0002Cooooo00?o0000ogVZl_miZ_801_miZ_800ol0003oP:K]oh2Vk@06oh2Vk@03o`000?n7
Y>OoQjCW00KoQjCW00?o0000ohnRh_n?X^801on?X^800ol0003oUZ;MoiJRg@08oiJRg@03o`000?nL
X]WoW:;I00SoW:;I00?o0000oj>Te_nSY=H02OnSY=H01?l0003oZ:KCo`000?l00009oj^ZeP03o`00
0?nb[M?o/ZgC00[o/ZgC00?o0000okVadOni/M402_ni/M400ol0003o^K7Ao`000004okjed0;o0000
2Oo5^]000ol0003obKg?olVmc`0>olVmc`03o`000?o=`Lko000000kod/C<00?o0000omC6c?oDa/`0
1_oDa/`00ol0003oelS;omO8b`07omO8b`03o`000?oooooooooo05Kooooo000]ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ogVZl_miZ_801_miZ_800ol0003oP:K]oh2Vk@06oh2Vk@03o`000?n7
Y>OoQjCW00KoQjCW00?o0000ohnRh_n?X^801on?X^800ol0003oUZ;MoiJRg@08oiJRg@03o`000?nL
X]WoW:;I00SoW:;I00?o0000oj>Te_nSY=H01onSY=H3o`0000coZj[F00?o0000ok:]donb[M<02_nb
[M<00ol0003o^K7AokVad@09okVad@03o`000?ni/M7o000000?o_[G@00?o0000olFjd?o5^]002_o5
^]000ol0003obKg?olVmc`0>olVmc`03o`000?oBa<cod/C<00kod/C<00?o0000omC6c?oDa/`01?oD
a/`00ol0003oelS;omO8b`09omO8b`03o`000?oooooooooo05Gooooo000]ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ogVZl_miZ_801_miZ_800ol0003oP:K]oh2Vk@06oh2Vk@03o`000?n7Y>Oo
QjCW00GoQjCW00?o0000ohnRh_n?X^802?n?X^800ol0003oUZ;MoiJRg@07oiJRg@03o`000?nLX]Wo
W:;I00WoW:;I00?o0000oj>Te_nSY=H00onSY=H3o`0000;oXZKI00?o0000oj^Ze_n[Z]H02_n[Z]H0
0ol0003o/ZgCok:]d`0;ok:]d`03o`000?ni/M7o^K7A00So^K7A00Ko0000okVadOni/M7o0000okje
d?l0000=olFjd003o`000?o9_LoobKg?00gobKg?0_l0000Aom;4c003o`000?oDa/coe<K<00;oe<K<
00?o0000omO8booGb</02_oGb</2o`0005Kooooo000]ooooo`03o`000?oooooooooo02Kooooo00?o
0000ogVZl_miZ_801_miZ_800ol0003oP:K]oh2Vk@05oh2Vk@03o`000?n7Y>OoQjCW00KoQjCW00?o
0000ohnRh_n?X^801on?X^800ol0003oUZ;MoiJRg@08oiJRg@03o`000?nLX]WoW:;I00SoW:;I00?o
0000oj>Te_nSY=H00ol00006oj:Vf@03o`000?n[Z]KoZj[F00[oZj[F00?o0000ok:]donb[M<02_nb
[M<00ol0003o^K7AokVad@08okVad@03o`000?ni/M7o^K7A00;o00003oo5^]000ol0003obKg?olVm
c`0;olVmc`04o`000?o?`/kocl;>o`00013od/C<00Go0000omC6c?oDa/coe<K<o`00000>omO8b`03
o`000?oooooooooo05Cooooo000/ooooo`03o`000?oooooooooo02Sooooo1_l00003ogVZlP03o`00
0?n0Y^goP:K]00GoP:K]00?o0000ohNTion7Y>L01_n7Y>L00ol0003oSj;RohnRhP07ohnRhP03o`00
0?nFX]goUZ;M00SoUZ;M00?o0000oibRfOnLX]T01_nLX]T4o`0000[oXZKI00?o0000oj^Ze_n[Z]H0
2_n[Z]H00ol0003o/ZgCok:]d`0:ok:]d`03o`000?ni/M7o^K7A00Oo^K7A00Go0000okVadOl0003o
_[OBo`00000@olFjd003o`000?o9_LoobKg?00WobKg?00?o0000olo2c_o?`/h00_o?`/h00ol0003o
d/C<om;4c00>om;4c003o`000?oDa/co0000013oelS;00?o0000ooooooooool0Doooool002cooooo
00?o0000ooooooooool0:Oooool00ol0003oFI[aoeVJl@02oeVJl@[o00000_n0Y^d00ol0003oQjCW
ohNTi`05ohNTi`03o`000?n?X^;oSj;R00OoSj;R00?o0000oiJRgOnFX]d02?nFX]d01?l0003oW:;I
oibRfOnLX]T5o`0000;oV:?M00?o0000oj:VfOnRY]T02OnRY]T00ol0003oZj[Foj^ZeP0:oj^ZeP03
o`000?nb[M?o/ZgC00_o/ZgC00?o0000okVadOni/M401_ni/M42o`0000?o_[OB00?o0000olFjd?o5
^]003_o5^]000ol0003obKg?olVmc`07olVmc`03o`000?o?`/kocl;>00Cocl;>00?o0000om;4c?oB
a<`03_oBa<`00ol0003oelS;omO8b`0@omO8b`03o`000?oooooooooo05;ooooo000/ooooo`;o0000
:oooool00ol0003oFI[aoeVJl@05oeVJl@03o`000?mUV^koII[^00?oII[^2Ol00002ohNTi`03o`00
0?n?X^;oSj;R00OoSj;R00?o0000oiJRgOnFX]d00onFX]d8o`0000SoV:?M00?o0000oj:VfOnRY]T0
2OnRY]T00ol0003oZj[Foj^ZeP0:oj^ZeP03o`000?nb[M?o/ZgC00[o/ZgC00?o0000okVadOni/M40
1Oni/M42o`0000Go_[OB00?o0000olFjd?o5^]003Oo5^]000ol0003obKg?olVmc`06olVmc`03o`00
0?o?`/kocl;>00Gocl;>00?o0000om;4c?oBa<`03OoBa<`2o`0001;oelS;0_l0001Cooooo`00;?oo
ool00ol0003oooooooooo`0[ooooo`03o`000?mIV_7oFI[a00GoFI[a00?o0000ofFJk_mUV^h01OmU
V^h00ol0003oLYcZog:LjP03og:LjQ;o00001On<XN800ol0003oV:?MoiRSg@08oiRSg@03o`000?nR
Y]WoXZKI00WoXZKI00?o0000oj^Ze_n[Z]H02_n[Z]H00ol0003o/ZgCok:]d`0;ok:]d`03o`000?ni
/M7o^K7A00?o^K7A00?o0000okjgd_l000001Onn]m800ol0003oaK[@olFjd00>olFjd003o`000?o9
_LoobKg?00CobKg?00?o0000olo2c_o?`/h01oo?`/h00ol0003od/C<om;4c00;om;4c004o`000?oF
alcoe/O<o`0001;oelS;00?o0000ooooooooool0DOooool002cooooo00?o0000ooooooooool0;?oo
ool00ol0003oFI[aoeVJl@05oeVJl@03o`000?mUV^koII[^00GoII[^00?o0000og:Lj_mbW>X01Omb
W>X00ol0003oOikVognNiP07ognNiP03o`000?n<XN;oS:7R00SoS:7R00?o0000oiRSgOnHXmd02?nH
Xmd00ol0003oXZKIoj:Vf@09oj:Vf@03o`000?n[Z]KoZj[F00[oZj[F00?o0000ok:]donb[M<02_nb
[M<01?l0003o^K7AokVadOni/M42o`0000;o_[OB00?o0000okjgd_nn]m801?nn]m800ol0003oaK[@
olFjd00>olFjd003o`000?o9_LoobKg?00;obKg?00?o0000olo2c_o?`/h02Oo?`/h00ol0003od/C<
om;4c009om;4c003o`000?oFalcoe/O<00;oe/O<00?o0000omO8booGb</03_oGb</00ol0003ofLW;
o`00001Booooo`00;?ooool00ol0003oooooooooo`0]ooooo`03o`000?mIV_7oFI[a00GoFI[a00?o
0000ofFJk_mUV^h01OmUV^h00ol0003oLYcZog:LjP05og:LjP03o`000?moW^KoOikV00OoOikV00?o
0000ohbQh_n<XN802?n<XN800ol0003oV:?MoiRSg@08oiRSg@03o`000?nRY]WoXZKI00WoXZKI00?o
0000oj^Ze_n[Z]H02_n[Z]H00ol0003o/ZgCok:]d`0:ok:]d`03o`000?ni/M7o000000Co_[OB00?o
0000okjgd_nn]m801Onn]m800ol0003oaK[@olFjd00=olFjd005o`000?o9_LoobKg?olVmcol00000
3?o?`/h00ol0003od/C<om;4c008om;4c003o`000?oFalcoe/O<00Coe/O<00?o0000omO8booGb</0
3?oGb</01Ol0003ofLW;omW9booIbL_o0000057ooooo000/ooooo`03o`000?oooooooooo02kooooo
00?o0000oeVJlOmIV_401OmIV_400ol0003oII[^ofFJkP05ofFJkP03o`000?mbW>[oLYcZ00GoLYcZ
00?o0000ognNi_moW^H01omoW^H00ol0003oS:7RohbQhP07ohbQhP03o`000?nHXmgoV:?M00SoV:?M
00?o0000oj:VfOnRY]T02OnRY]T00ol0003oZj[Foj^ZeP0:oj^ZeP03o`000?nb[M?o/ZgC00[o/ZgC
0_l00005okjgdP03o`000?nn]m;o_[OB00Go_[OB00?o0000olFjd?o5^]003_o5^]000ol0003obKg?
o`00000>olo2cP03o`000?oBa<cod/C<00Kod/C<00?o0000omK7c?oFal`01OoFal`00ol0003oelS;
omO8b`0;omO8b`03o`000?oIbL_ofLW;00;ofLW;0_l0001@ooooo`00;?ooool00ol0003ooooooooo
o`0_ooooo`03o`000?mIV_7oFI[a00GoFI[a00?o0000ofFJk_mUV^h01?mUV^h00ol0003oLYcZog:L
jP06og:LjP03o`000?moW^KoOikV00KoOikV00?o0000ohbQh_n<XN802?n<XN800ol0003oV:?MoiRS
g@08oiRSg@03o`000?nRY]WoXZKI00WoXZKI00?o0000oj^Ze_n[Z]H02_n[Z]H00ol0003o/ZgCok:]
d`07ok:]d`;o000000?o][?Fo`000?nn]m801?nn]m800ol0003o_[OBokjgdP06okjgdP03o`000?o5
^]3oaK[@00goaK[@0_l0000@olo2cP03o`000?oBa<cod/C<00Cod/C<00?o0000omK7c?oFal`01ooF
al`00ol0003oelS;omO8b`09omO8b`03o`000?oIbL_ofLW;00CofLW;00?o0000ooooooooool0C_oo
ool002cooooo0_l0000aooooo`03o`000?mIV_7oFI[a00GoFI[a00?o0000ofFJk_mUV^h01?mUV^h0
0ol0003oLYcZog:LjP05og:LjP03o`000?moW^KoOikV00OoOikV00?o0000ohbQh_n<XN802?n<XN80
0ol0003oV:?MoiRSg@07oiRSg@03o`000?nRY]WoXZKI00[oXZKI00?o0000oj^Ze_n[Z]H02On[Z]H0
0ol0003o/ZgCok:]d`06ok:]d`03o`000?nf/mKo][?F00;o][?F00?o0000okjgd_nn]m800_nn]m80
0ol0003o_[OBokjgdP07okjgdP03o`000?o5^]3oaK[@00_oaK[@00?o0000olVod?l000004Oo?`/h0
0ol0003od/C<om;4c002om;4c003o`000?oFalcoe/O<00Woe/O<00?o0000omO8booGb</01ooGb</0
0ol0003ofLW;omW9b`06omW9b`03o`000?oooooooooo04gooooo000[ooooo`03o`000?oooooooooo
03;ooooo00?o0000oeVJlOmIV_401?mIV_400ol0003oII[^ofFJkP05ofFJkP03o`000?mbW>[oLYcZ
00GoLYcZ00?o0000ognNi_moW^H01omoW^H00ol0003oS:7RohbQhP07ohbQhP03o`000?nHXmgoV:?M
00SoV:?M00?o0000oj:VfOnRY]T02OnRY]T00ol0003oZj[Foj^ZeP0:oj^ZeP03o`000?nb[M?o/ZgC
00?o/ZgC0_l00006okJceP05o`000?nn]m;o_[OBokjgd_l000002Onn]m800ol0003oaK[@olFjd00:
olFjd005o`000?o9_m3obKo@olVod?l000004?o?`/h01Ol0003od/C<om;4c?oBa<co000000goe/O<
00?o0000omO8booGb</01_oGb</00ol0003ofLW;omW9b`07omW9b`03o`000?oooooooooo04cooooo
000[ooooo`03o`000?oooooooooo03?ooooo00?o0000oeVJlOmIV_401?mIV_400ol0003oII[^ofFJ
kP05ofFJkP03o`000?mbW>[oLYcZ00GoLYcZ00?o0000ognNi_moW^H01omoW^H00ol0003oS:7RohbQ
hP07ohbQhP03o`000?nHXmgoV:?M00SoV:?M00?o0000oj:VfOnRY]T02OnRY]T00ol0003oZj[Foj^Z
eP0:oj^ZeP03o`000?nb[M?o/ZgC00;o00002?nf/mH01Ol0003o_[OBokjgd_nn]m;o000000[o_[OB
00?o0000olFjd?o5^]002?o5^]000ol0003obKo@olVod003olVod003o`000?o?`/kocl;>00kocl;>
00?o0000om;4c?l000003ooFal`00ol0003oelS;omO8b`04omO8b`03o`000?oIbL_ofLW;00SofLW;
0_l0001=ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o0000
00?o410@ooooooooool01?ooool00ol0003oooooooooo`0dooooo`03o`000?mIV_7oFI[a00CoFI[a
00?o0000ofFJk_mUV^h01?mUV^h00ol0003oLYcZog:LjP06og:LjP03o`000?moW^KoOikV00KoOikV
00?o0000ohbQh_n<XN802?n<XN800ol0003oV:?MoiRSg@07oiRSg@03o`000?nRY]WoXZKI00[oXZKI
00?o0000oj^Ze_n[Z]H02On[Z]H00ol0003o/ZgCo`00000;okJceP04o`000?nn]m;o_[OBo`0000[o
_[OB00?o0000olFjd?o5^]001_o5^]02o`0000KobKo@00?o0000olo2c_o?`/h03oo?`/h00ol0003o
e/O<omK7c00>omK7c003o`000?oGb<_oelS;00?oelS;00?o0000omW9booIbL/02_oIbL/2o`0004co
oooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0eooooo`03o`000?mIV_7oFI[a00CoFI[a00?o0000ofFJk_mU
V^h01?mUV^h00ol0003oLYcZog:LjP05og:LjP03o`000?moW^KoOikV00OoOikV00?o0000ohbQh_n<
XN801on<XN800ol0003oV:?MoiRSg@08oiRSg@03o`000?nRY]WoXZKI00WoXZKI00?o0000oj^Ze_n[
Z]H02On[Z]H2o`0000go][?F00?o0000okjgd_l000002onn]m800ol0003oaK[@olFjd004olFjd003
o`000?o9_m3obKo@00OobKo@00?o0000olo2c_o?`/h03_o?`/h00ol0003oe/O<omK7c00?omK7c005
o`000?oGb<_oelS;omO8bol000003_oIbL/00ol0003oooooooooo`1:ooooo`004?ooool01Ol@413o
oooooooooooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo03Kooooo0ol00004oeVJ
l@03o`000?mUV^koII[^00CoII[^00?o0000og:Lj_mbW>X01OmbW>X00ol0003oOikVognNiP07ognN
iP03o`000?n<XN;oS:7R00OoS:7R00?o0000oiRSgOnHXmd01onHXmd00ol0003oXZKIoj:Vf@0:oj:V
f@03o`000?n[Z]KoZj[F00GoZj[F0ol000000on][mWo0000okJceP0<okJceP03o`000?nn]m;o0000
00co_[OB00?o0000olFjd?o5^]000_o5^]000ol0003obKo@olVod009olVod003o`000?o?`/kocl;>
00cocl;>00?o0000om;6c_l000004OoFal`00ol0003oelS;o`00000@omW9b`03o`000?oooooooooo
04Wooooo000@ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007
ooooo`03o`000?oooooooooo03Oooooo00?o0000ocR8k?l000001Ol00006ofFJkP03o`000?mbW>[o
LYcZ00GoLYcZ00?o0000ognNi_moW^H01_moW^H00ol0003oS:7RohbQhP08ohbQhP03o`000?nHXmgo
V:?M00OoV:?M00?o0000oj:VfOnRY]T02OnRY]T00ol0003oZj[Foj^ZeP03oj^ZeP;o00001On][mT0
0ol0003o][?FokJceP0;okJceP;o00003?nn]m801Ol0003oaK[@olFjd?o5^]3o000000cobKo@00?o
0000olo2c_o?`/h02oo?`/h01Ol0003od/K>om;6c_oBa/ko0000017oe/O<00?o0000omW9booIbL/0
3ooIbL/2o`0004[ooooo000@ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEE
ooooool00007ooooo`03o`000?oooooooooo03Sooooo00?o0000ocR8k?lhR>`00olhR>`4o`0000?o
II[^00?o0000og:Lj_mbW>X01_mbW>X00ol0003oOikVognNiP06ognNiP03o`000?n<XN;oS:7R00Oo
S:7R00?o0000oiRSgOnHXmd01onHXmd00ol0003oXZKIoj:Vf@0:oj:Vf@03o`000?n[Z]Ko000000;o
00002?n][mT00ol0003o][?FokJceP0;okJceP03o`000?nn]m;o_[OB00_o_[OB00?o0000olFjd?l0
00003_o9_m000ol0003ocl;>olo2cP09olo2cP03o`000?oBa/kod/K>00?od/K>00?o0000omK7c?oF
al`03_oFal`00ol0003ofLW;omW9b`0@omW9b`;o0000BOooool0013ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo0_l0000kooooo`03o`000?lhR>co>8S/00?o
>8S/00?o0000odN<k?m7S>`00ol000000omUV^ko0000og:LjP06og:LjP03o`000?moW^KoOikV00Oo
OikV00?o0000ohbQh_n<XN801on<XN800ol0003oV:?MoiRSg@07oiRSg@03o`000?nRY]WoXZKI00So
XZKI0ol0000;ojf_f@03o`000?nf/mKo][?F00_o][?F00?o0000okjgd_nn]m802onn]m82o`00013o
bKo@00?o0000olo2c_o?`/h01oo?`/h00ol0003od/K>om;6cP04om;6cP03o`000?oFalcoe/O<00go
e/O<00?o0000omS:c?l000004_oIbL/00ol0003oooooooooo`17ooooo`004?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0jooooo`03
o`000?lhR>co>8S/00?o>8S/00?o0000odN<k?m7S>`00_m7S>`3o`0000OoLYcZ00?o0000ognNi_mo
W^H01omoW^H00ol0003oS:7RohbQhP07ohbQhP03o`000?nHXmgoV:?M00OoV:?M00?o0000oj:VfOnR
Y]T00onRY]T4o`0000;oXJ_N00?o0000ojf_fOn][mT02_n][mT00ol0003o][?FokJceP0:okJceP;o
00002onn]m800ol0003o`kgDo`00000@olVod003o`000?o?`/kocl;>00Kocl;>00?o0000om;6c_oB
a/h01_oBa/h00ol0003oe/O<omK7c00;omK7c005o`000?oHb/cof<[<omS:c?l000004?oIbL/00ol0
003ofL_<o`000018ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`00
0?ooool01Oooool00ol0003oooooooooo`0looooo`03o`000?lhR>co>8S/00?o>8S/00?o0000odN<
k?m7S>`01?m7S>`6o`0000;oLYcZ00?o0000ognNi_moW^H01_moW^H00ol0003oS:7RohbQhP07ohbQ
hP03o`000?nHXmgoV:?M00OoV:?M00?o0000oj:VfOnRY]T00ol00007oj6[gP03o`000?n][mWo[JoI
00[o[JoI00?o0000okJce_nf/mH02Onf/mH2o`0000Wo_[OB0_l00003ol>me003o`000?o9_m3obKo@
00kobKo@00?o0000olo2c_o?`/h01?o?`/h00ol0003od/K>om;6cP08om;6cP03o`000?oFalcoe/O<
00Woe/O<00?o0000omS:c?oHb/`00ooHb/`00ol0003ofLW;omW9b`0<omW9b`03o`000?oIblcofL_<
00;o0000Aoooool002[ooooo00?o0000ooooooooool0?Oooool00ol0003o>8S/ocR8k003ocR8k003
o`000?m7S>coAhc/00?oAhc/00?o0000oeZBk?mJT^`00omJT^`9o`0000?oOikV00?o0000ohbQh_n<
XN801on<XN800ol0003oV:?MoiRSg@03oiRSg@Ko00002onQZmh00ol0003o[JoIojf_f@09ojf_f@03
o`000?nf/mKo][?F00Wo][?F00?o0000okJce_l000001onn]m800ol0003o`kgDol>me004ol>me003
o`000?o9_m3obKo@00kobKo@00?o0000olo2c_o?`/h00_o?`/h00ol0003od/K>om;6cP09om;6cP03
o`000?oFalcoe/O<00Soe/O<00?o0000omS:c?oHb/`01OoHb/`00ol0003ofLW;omW9b`0:omW9b`03
o`000?oIblcofL_<00;ofL_<00?o0000ooooooooool0AOooool002[ooooo00?o0000ooooooooool0
?_ooool00ol0003o>8S/ocR8k003ocR8k003o`000?m7S>coAhc/00?oAhc/00?o0000oeZBk?mJT^`0
1OmJT^`00ol0003oKiWZofnIjP03ofnIjQ?o00001?nCY^800ol0003oXJ_Noj6[gP0:oj6[gP03o`00
0?n][mWo[JoI00[o[JoI00?o0000okJce_nf/mH02?nf/mH01?l0003o][?FokJce_l00005okjgdP03
o`000?o3_MCo`kgD00Ko`kgD00?o0000olVod?o9_m003Oo9_m001Ol0003ocl;>olo2c_o?`/ko0000
00god/K>00?o0000omK7c?oFal`01_oFal`00ol0003of<[<omS:c007omS:c003o`000?oIbL_ofLW;
00SofLW;00?o0000omW;c?oIbl`01?oIbl`00ol0003oooooooooo`14ooooo`00:_ooool00ol0003o
ooooooooo`0oooooo`03o`000?lhR>co>8S/00?o>8S/00?o0000odN<k?m7S>`00om7S>`00ol0003o
FY;/oeZBk005oeZBk003o`000?m_VN[oKiWZ00KoKiWZ00?o0000oh:Pi_n2X>H01on2X>H00ol0003o
TjKRoi>VhP07oi>VhP03o`000?nQZmkoXJ_N00[oXJ_N00?o0000ojf_fOn][mT02_n][mT00ol0003o
][?FokJceP07okJceP04o`000?nf/mKo][?Fo`0000?o_[OB0_l00009ol>me003o`000?o9_m3obKo@
00kobKo@00?o0000olo2c_l000003ooBa/h00ol0003oe/O<omK7c004omK7c003o`000?oHb/cof<[<
00Sof<[<00?o0000omW9booIbL/01ooIbL/00ol0003ofL_<omW;c006omW;c003o`000?oooooooooo
04?ooooo000Yooooo`?o0000@?ooool2o`0000Go>8S/00?o0000odN<k?m7S>`00om7S>`00ol0003o
FY;/oeZBk005oeZBk003o`000?m_VN[oKiWZ00KoKiWZ00?o0000oh:Pi_n2X>H01on2X>H00ol0003o
TjKRoi>VhP07oi>VhP03o`000?nQZmkoXJ_N00[oXJ_N00?o0000ojf_fOn][mT02On][mT00ol0003o
][?FokJceP07okJceP07o`000?nf/mKo][?FokJce_l0003o_[OBo`00000<ol>me003o`000?o9_m3o
bKo@00gobKo@0_l0000Aom;6cP03o`000?oFalcoe/O<00;oe/O<00?o0000omS:c?oHb/`02_oHb/`0
0ol0003ofLW;omW9b`05omW9b`03o`000?oIblcofL_<00OofL_<0_l00014ooooo`00:_ooool00ol0
003oooooooooo`10ooooo`;o00001?lhR>`00ol0003oAhc/odN<k004odN<k003o`000?mJT^coFY;/
00GoFY;/00?o0000ofnIj_m_VNX01_m_VNX00ol0003oPZ3Voh:PiP07oh:PiP03o`000?nCY^;oTjKR
00KoTjKR00?o0000oj6[g_nQZmh02_nQZmh00ol0003o[JoIojf_f@0:ojf_f@03o`000?nf/mKo][?F
00Ko][?F00Co0000okJce_nf/mKo][?F0_l0000>ol>me003o`000?o9_m3obKo@00_obKo@00?o0000
olk5d_l000004OoBa/h01Ol0003oe/O<omK7c?oFalco000000kof<[<00?o0000omW9booIbL/00ooI
bL/00ol0003ofL_<omW;c009omW;c003o`000?oooooooooo04;ooooo000Zooooo`03o`000?oooooo
oooo047ooooo0_l00004ocR8k003o`000?m7S>coAhc/00CoAhc/00?o0000oeZBk?mJT^`01?mJT^`0
0ol0003oKiWZofnIjP06ofnIjP03o`000?n2X>KoPZ3V00OoPZ3V00?o0000oi>Vh_nCY^801onCY^80
0ol0003oXJ_Noj6[gP0:oj6[gP03o`000?n][mWo[JoI00Wo[JoI00?o0000okJce_nf/mH01_nf/mH0
1_l0003o][?Fo`000?l0003o^[WIo`0000oo`kgD00?o0000olVod?o9_m002Oo9_m001Ol0003oc/GB
olk5d_o>aM;o0000017od/K>00?o0000omK7c?l000004?oHb/`01Ol0003ofLW;omW9booIbL_o0000
00gofL_<00?o0000ooooooooool0@Oooool002[ooooo00?o0000ooooooooool0@_ooool3o`0000?o
>8S/00?o0000odN<k?m7S>`01?m7S>`00ol0003oFY;/oeZBk004oeZBk003o`000?m_VN[oKiWZ00Ko
KiWZ00?o0000oh:Pi_n2X>H01on2X>H00ol0003oTjKRoi>VhP07oi>VhP03o`000?nQZmkoXJ_N00[o
XJ_N00?o0000ojf_fOn][mT02On][mT00ol0003o][?FokJceP05okJceP;o00001?nj^MT00ol0003o
`kgDol>me00<ol>me003o`000?o9_m3obKo@00SobKo@00?o0000olk5d_o>aM800oo>aM800ol0003o
d/K>om;6cP0?om;6cP03o`000?oHb/cof<[<013of<[<00?o0000omW9bol000003ooIbl`00ol0003o
ooooooooo`10ooooo`00:Oooool00ol0003oooooooooo`14ooooo`04o`000?lKMn?o0000o`0000;o
>8S/00?o0000odN<k?m7S>`00om7S>`00ol0003oFY;/oeZBk005oeZBk003o`000?m_VN[oKiWZ00Ko
KiWZ00?o0000oh:Pi_n2X>H01on2X>H00ol0003oTjKRoi>VhP07oi>VhP03o`000?nQZmkoXJ_N00Wo
XJ_N00?o0000ojf_fOn][mT02_n][mT00ol0003o][?FokJceP03okJceP;o00001_nj^MT00ol0003o
`kgDol>me00<ol>me003o`000?o9_m3obKo@00KobKo@00?o0000olk5d_o>aM801Oo>aM800ol0003o
d/K>om;6cP0>om;6cP03o`000?oHb/cof<[<017of<[<00?o0000omW;c?oIbl`03_oIbl`00ol0003o
ooooooooo`10ooooo`00:Oooool00ol0003oooooooooo`15ooooo`03o`000?lKMn?o6gOS00Co0000
1Om7S>`00ol0003oFY;/oeZBk005oeZBk003o`000?m_VN[oKiWZ00GoKiWZ00?o0000oh:Pi_n2X>H0
1on2X>H00ol0003oTjKRoi>VhP07oi>VhP03o`000?nQZmkoXJ_N00[oXJ_N00?o0000ojf_fOn][mT0
2On][mT01?l0003o][?FokJce_nf/mH2o`000003okZifOl0003o^[WI00Ko^[WI00?o0000ol>me?o3
_M@03?o3_M@00ol0003obKo@olVod004olVod003o`000?o>aM;oc/GB00Ooc/GB00?o0000om;6c_oB
a/h03?oBa/h00ol0003oeL_?o`00000BomS:c003o`000?oIblcofL_<00oofL_<00?o0000oooooooo
ool0?oooool002Wooooo00?o0000ooooooooool0A_ooool00ol0003o6gOSoa]gh`02oa]gh`;o0000
1Om7S>`00ol0003oFY;/oeZBk004oeZBk003o`000?m_VN[oKiWZ00KoKiWZ00?o0000oh:Pi_n2X>H0
1on2X>H00ol0003oTjKRoi>VhP07oi>VhP03o`000?nQZmkoXJ_N00WoXJ_N00?o0000ojf_fOn][mT0
2_n][mT00ol0003o][?Fo`000003okZif@03o`000?nj^MWo^[WI00Go^[WI00?o0000ol>me?o3_M@0
3?o3_M@00ol0003obKo@olVod003olVod003o`000?o>aM;oc/GB00Woc/GB00?o0000om;6c_oBa/h0
2_oBa/h01Ol0003oeL_?omG;cooEbloo0000013of<[<00?o0000omS=c_l000004OoIbl`00ol0003o
ooooooooo`0nooooo`00:Oooool2o`0004Sooooo00?o0000oa]gholKMn<00olKMn<3o`0000?oAhc/
00?o0000oeZBk?mJT^`01?mJT^`00ol0003oKiWZofnIjP06ofnIjP03o`000?n2X>KoPZ3V00OoPZ3V
00?o0000oi>Vh_nCY^801onCY^800ol0003oXJ_Noj6[gP09oj6[gP03o`000?n][mWo[JoI00Wo[JoI
0_l00004okZif@03o`000?nj^MWo^[WI00Ko^[WI00?o0000ol>me?o3_M@03?o3_M@01Ol0003obKo@
olVod?o9_m3o000000goc/GB00?o0000om;6c_oBa/h02?oBa/h00ol0003oeL_?omG;c`03omG;c`03
o`000?oHb/cof<[<00cof<[<00Go0000omS=c_oHcLkof<g>o`00000?omW;c0?o0000?oooool002Wo
oooo00?o0000ooooooooool0B?ooool00ol0003o6gOSoa]gh`02oa]gh`03o`000?l/O^Oo;7kW00?o
000000?oAhc/o`000?mJT^`01OmJT^`00ol0003oKiWZofnIjP05ofnIjP03o`000?n2X>KoPZ3V00Oo
PZ3V00?o0000oi>Vh_nCY^801onCY^800ol0003oXJ_Noj6[gP0:oj6[gP03o`000?n][mWo[JoI00Go
[JoI0ol000000on_]]ko0000okZif@03okZif@03o`000?nj^MWo^[WI00Oo^[WI00?o0000ol>me?o3
_M@03?o3_M@00ol0003obKo@o`00000>olk5dP03o`000?oBa/kod/K>00Ood/K>00?o0000omG;cooE
bll01OoEbll00ol0003of<[<omS:c00:omS:c003o`000?oHcLkof<g>00?of<g>00?o0000omW;c?oI
bl`02ooIbl`01?l0003oelc?omO<col0000oooooo`00:Oooool00ol0003oooooooooo`19ooooo`03
o`000?lKMn?o6gOS00;o6gOS00?o0000obaniol/O^L00_l/O^L3o`0000KoFY;/00?o0000ofnIj_m_
VNX01Om_VNX00ol0003oPZ3Voh:PiP07oh:PiP03o`000?nCY^;oTjKR00OoTjKR00?o0000oj6[g_nQ
Zmh02OnQZmh00ol0003o[JoIojf_f@03ojf_f@;o00001On_]]h01Ol0003o^[WIokZifOnj^MWo0000
00[o^[WI00?o0000ol>me?o3_M@02oo3_M@2o`00013oc/GB00?o0000om;6c_oBa/h01OoBa/h00ol0
003oeL_?omG;c`07omG;c`03o`000?oHb/cof<[<00Sof<[<00?o0000omS=c_oHcLh01?oHcLh00ol0
003ofL_<omW;c00:omW;c003o`000?oGc<ooelc?00;oelc?00?o0000ooooooooool0??ooool002Wo
oooo00?o0000ooooooooool0B_ooool00ol0003o6gOSoa]gh`02oa]gh`03o`000?l/O^Oo;7kW00Co
;7kW0ol00003oeZBk003o`000?m_VN[oKiWZ00GoKiWZ00?o0000oh:Pi_n2X>H01on2X>H00ol0003o
TjKRoi>VhP08oi>VhP03o`000?nQZmkoXJ_N00WoXJ_N00?o0000ojf_fOl000000_l00008ojnfgP04
o`000?nj^MWo^[WIo`0000[o^[WI00?o0000ol>me?o3_M@02_o3_M@00ol0003oal?Go`00000Aolk5
dP03o`000?oBa/kod/K>00?od/K>00?o0000omG;cooEbll02?oEbll00ol0003of<[<omS:c007omS:
c003o`000?oHcLkof<g>00Kof<g>00?o0000omW;c?oIbl`02?oIbl`00ol0003oelc?omO<c`04omO<
c`03o`000?oooooooooo03_ooooo000Yooooo`03o`000?oooooooooo04_ooooo00?o0000oa]gholK
Mn<00_lKMn<00ol0003o;7kWobani`03obani`03o`000?m3RN_o@hW[00?o000000?oFY;/o`000?m_
VNX01_m_VNX00ol0003oPZ3Voh:PiP07oh:PiP03o`000?nCY^;oTjKR00SoTjKR00?o0000oj6[g_nQ
Zmh01onQZmh3o`0000co[kKN00?o0000okZifOl000002onj^MT00ol0003o`kgDol>me007ol>me0;o
00000oo7`mL00ol0003oc/GBolk5dP0?olk5dP05o`000?oBa/kod/K>om;6c_l000003?oEbll00ol0
003of<[<omS:c005omS:c003o`000?oHcLkof<g>00Sof<g>00?o0000omW;c?oIbl`01_oIbl`00ol0
003oelc?omO<c`05omO<c`;o0000??ooool002Wooooo00?o0000ooooooooool0C?ooool00ol0003o
6gOSoa]gh`02oa]gh`03o`000?l/O^Oo;7kW00?o;7kW00?o0000od>9jom3RN/00_m3RN/3o`0000Oo
KiWZ00?o0000oh:Pi_n2X>H01on2X>H00ol0003oTjKRoi>VhP07oi>VhP03o`000?nQZmkoXJ_N00Co
XJ_N0ol00002oj2`h`03o`000?n_]]ko[kKN00[o[kKN00?o0000okZifOl000003?nj^MT00ol0003o
`kgDol>me005ol>me003o`000?o7`mOoal?G00Coal?G00?o0000olk5d_o>aM803oo>aM800ol0003o
d/K>o`00000>omG;c`03o`000?oHb/cof<[<00?of<[<00?o0000omS=c_oHcLh02_oHcLh00ol0003o
fL_<omW;c004omW;c003o`000?oGc<ooelc?00Ooelc?00?o0000ooooooooool0>_ooool002Sooooo
0ol0001>ooooo`03o`000?lKMn?o6gOS00;o6gOS00?o0000obaniol/O^L00ol/O^L00ol0003o@hW[
od>9j`04od>9j`?o00001?m_VNX00ol0003oPZ3Voh:PiP07oh:PiP03o`000?nCY^;oTjKR00SoTjKR
00?o0000oj6[g_nQZmh00ol00006oj2`h`03o`000?n_]]ko[kKN00[o[kKN0_l0000<okZif@03o`00
0?o3_MCo`kgD00Co`kgD00?o0000olO3eoo7`mL01_o7`mL00ol0003oc/GBolk5dP0>olk5dP;o0000
4?oEbll01Ol0003of<[<omS:c?oHb/co000000gof<g>00?o0000omW;c?oIbl`00ooIbl`00ol0003o
elc?omO<c`09omO<c`03o`000?oooooooooo03Wooooo000Xooooo`03o`000?oooooooooo04oooooo
00?o0000oa]gholKMn<00_lKMn<00ol0003o;7kWobani`03obani`03o`000?m3RN_o@hW[00?o@hW[
00?o0000oefEkOmMUNd01_l00009oh:PiP03o`000?nCY^;oTjKR00?oTjKR1ol0000:oj2`h`03o`00
0?n_]]ko[kKN00[o[kKN00?o0000okZifOnj^MT02onj^MT01?l0003o`kgDol>me?o3_M@2o`0000[o
al?G00?o0000olk5d_o>aM803?o>aM800ol0003odL_Do`00000AomG;c`03o`000?oHb/co000000oo
f<g>00Go0000omW;c?oIblcofL_<o`00000=omO<c`03o`000?oooooooooo03Sooooo000<ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c007
ooooo`03o`000?oooooooooo053ooooo0_l00003oa]gh`03o`000?l/O^Oo;7kW00?o;7kW00?o0000
od>9jom3RN/00om3RN/00ol0003oGIG]oefEk@04oefEkA3o00001On>ZNP00ol0003oX;3Soj2`h`09
oj2`h`03o`000?n_]]ko[kKN00[o[kKN0_l0000=okZif@03o`000?o3_MCo000000goal?G00?o0000
olk5d_o>aM802_o>aM801Ol0003odL_Dom7;e?oAbmCo0000017oeL_?00?o0000omS=c_oHcLh03ooH
cLh00ol0003ofL_<o`00000>omO<c`;o0000>Oooool000cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Oooooo00?o0000ooooooooool0
D?ooool01?l0003o2F[Lo`000?l00002oa]gh`03o`000?l/O^Oo;7kW00?o;7kW00?o0000od>9jom3
RN/00om3RN/00ol0003oGIG]oefEk@04oefEk@03o`000?mgX>coMj3/00OoMj3/00?o0000ohjYj?n>
ZNP02?n>ZNP00ol0003oX;3Soj2`h`09oj2`h`03o`000?n_]]ko[kKN00So[kKN0ol0000=okZif@;o
00003oo7`mL00ol0003oc/GBolk5dP08olk5dP03o`000?oAbmCodL_D00?odL_D00?o0000omG;cooE
bll03_oEbll00ol0003of<g>omS=cP0@omS=cP03o`000?oGc<ooelc?00koelc?00?o0000oooooooo
ool0=oooool000cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`1Aooooo`03o`000?l9J]co2F[L00Co00001Ol/O^L00ol0
003o@hW[od>9j`03od>9j`03o`000?mMUNgoGIG]00CoGIG]00?o0000ogNPk?mgX>`01omgX>`00ol0
003oSZWXohjYj008ohjYj003o`000?nP/>?oX;3S00WoX;3S00?o0000ojnfg_n_]]h01?n_]]h3o`00
0004ojnfg_l0003o[kKNo`0000[o^[WI0_l000000onm`Mco0000olO3e`0>olO3e`03o`000?o>aM;o
c/GB00Ooc/GB00?o0000om7;e?oAbm@01OoAbm@00ol0003oeL_?omG;c`0<omG;c`03o`000?oFcm;o
0000017of<g>00?o0000omO<cooGc<l03ooGc<l00ol0003oooooooooo`0fooooo`003?ooool01Ol0
003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@07ooooo`03o`000?oo
oooooooo05;ooooo00?o0000o`UZg?l9J]`00_l9J]`2o`0000Co;7kW00?o0000od>9jom3RN/01?m3
RN/00ol0003oGIG]oefEk@04oefEk@03o`000?mgX>coMj3/00OoMj3/00?o0000ohjYj?n>ZNP02?n>
ZNP00ol0003oX;3Soj2`h`08oj2`h`04o`000?n_]]ko[kKNojnfgP?o00001On_]]h00ol0003o[kKN
o`000008okZif@03o`000?nm`Mco_L7L00;o_L7L00?o0000olO3eoo7`mL03Oo7`mL00ol0003oc/GB
olk5dP05olk5dP03o`000?oAbmCodL_D00OodL_D00?o0000omG;cooEbll02_oEbll01Ol0003oe/oB
omK?d_oFcm;o000000oof<g>00?o0000omS@dOl000004?oGc<l2o`0003Oooooo000<ooooo`05o`00
0?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Oooooo00?o0000oooo
ooooool0Doooool00ol0003o2F[Lo`UZg003o`UZg0;o00000ol/O^L00ol0003o@hW[od>9j`03od>9
j`03o`000?mMUNgoGIG]00GoGIG]00?o0000ogNPk?mgX>`01omgX>`00ol0003oSZWXohjYj007ohjY
j003o`000?nP/>?oX;3S00WoX;3S0ol00009ojnfgP;o00001_nj^MT2o`0000Ko_L7L00?o0000olO3
eoo7`mL03Oo7`mL00ol0003oc/GBolk5dP03olk5dP03o`000?oAbmCodL_D00WodL_D00?o0000omG;
cooEbll02?oEbll00ol0003oe/oBomK?dP03omK?dP03o`000?oHcLkof<g>00_of<g>00Go0000omS@
dOoHd=7of=3Ao`00000>omO<c`04o`000?oDcM?o0000o`0003Kooooo000<ooooo`05oa0@4?oooooo
ooooooooool@41002oooool00omEEEGoQhN7ooooo`09ooooo`03o`000?oooooooooo05Cooooo00?o
0000o`UZg?l9J]`00_l9J]`01?l0003o67?Ro`000?l00002obani`03o`000?m3RN_o@hW[00?o@hW[
00?o0000oefEkOmMUNd01OmMUNd00ol0003oMj3/ogNPk006ogNPk003o`000?n>ZNSoSZWX00SoSZWX
00?o0000oj2`honP/><01OnP/><3o`000003oj2`hol0003o[kKN00[o[kKN0_l00003okZif@;o0000
2Onm`M`00ol0003oal?GolO3e`0=olO3e`05o`000?o>aM;oc/GBolk5d_l000003?oAbm@00ol0003o
eL_?omG;c`07omG;c`03o`000?oFcm;oe/oB00Goe/oB00?o0000omS=c_oHcLh02OoHcLh00ol0003o
f=3AomS@d@03omS@d@03o`000?oGc<ooelc?00[oelc?00Go0000omC=dooDcM?oe<gCo`00000foooo
o`003?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool2o`00
05Oooooo00?o0000o`UZg?l9J]`00_l9J]`00ol0003o67?RoaQchP04o`0000Go@hW[00?o0000oefE
kOmMUNd01OmMUNd00ol0003oMj3/ogNPk006ogNPk003o`000?n>ZNSoSZWX00SoSZWX00Co0000oj2`
honP/>?oX;3S0ol00005oj2`h`03o`000?n_]]ko[kKN00Wo[kKN0_l000000onj^MWo0000okg1g00;
okg1g003o`000?o7`mOoal?G00goal?G00?o0000olk5d_l000003_oAbm@00ol0003oeL_?omG;c`05
omG;c`03o`000?oFcm;oe/oB00Ooe/oB00?o0000omS=c_oHcLh01ooHcLh00ol0003of=3AomS@d@05
omS@d@03o`000?oGc<ooelc?00Soelc?00?o0000omC=dooDcM<00ooDcM<00ol0003oooooooooo`0c
ooooo`003?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_oo
ool00ol0003oooooooooo`1Gooooo`03o`000?l9J]co2F[L00;o2F[L00?o0000oaQch_lHLn800_lH
Ln82o`0000Go@hW[00?o0000oefEkOmMUNd01OmMUNd00ol0003oMj3/ogNPk006ogNPk003o`000?n>
ZNSoSZWX00SoSZWX0ol00008oj2`h`03o`000?n_]]ko[kKN00[o[kKN0_l0000=okg1g003o`000?o7
`mOoal?G00goal?G0_l0000@om7;e003o`000?oEblooeL_?00?oeL_?00?o0000omK?d_oFcm802OoF
cm800ol0003of<g>omS=cP05omS=cP03o`000?oHd=7of=3A00Oof=3A00?o0000omO<cooGc<l01_oG
c<l00ol0003oe<gComC=d`05omC=d`03o`000?oooooooooo03;ooooo000Wooooo`03o`000?oooooo
oooo05Sooooo00?o0000o`UZg?l9J]`00_l9J]`00ol0003o67?RoaQchP03oaQchP;o00000om3RN/0
0ol0003oGIG]oefEk@05oefEk@03o`000?mgX>coMj3/00OoMj3/00?o0000ohjYj?n>ZNP01?n>ZNP4
o`0000_oX;3S00?o0000ojnfg_n_]]h01on_]]h2o`000003ok6mhol0003o_L7L00go_L7L00?o0000
olO3eoo7`mL02oo7`mL00ol0003ob/[Jo`00000Aom7;e005o`000?oEblooeL_?omG;col000003OoF
cm800ol0003of<g>omS=cP03omS=cP03o`000?oHd=7of=3A00Sof=3A00?o0000omO<cooGc<l01OoG
c<l00ol0003oe<gComC=d`07omC=d`03o`000?oooooooooo037ooooo000Wooooo`03o`000?oooooo
oooo05Wooooo00?o0000o`UZg?l9J]`00_l9J]`00ol0003o67?RoaQchP02oaQchP04o`000?l_PNSo
0000o`0000;o@hW[00?o0000oefEkOmMUNd01OmMUNd00ol0003oMj3/ogNPk006ogNPk004o`000?n>
ZNSoSZWXohjYj0?o00001?n>ZNP00ol0003oX;3Soj2`h`09oj2`h`03o`000?n_]]ko[kKN00Co[kKN
0_l00004ok6mh`03o`000?nm`Mco_L7L00co_L7L00?o0000olO3eoo7`mL02Oo7`mL01Ol0003ob/[J
ol[:f_o:b][o0000017odL_D00?o0000omG;col000003ooFcm801Ol0003of<g>omS=c_oHcLko0000
00cof=3A00?o0000omO<cooGc<l00ooGc<l00ol0003oe<gComC=d`08omC=d`;o0000<_ooool002Oo
oooo00?o0000ooooooooool0F_ooool00ol0003o2F[Lo`UZg002o`UZg003o`000?lHLn;o67?R00;o
67?R00?o0000obn1j?l_PNP01?l00007oefEk@03o`000?mgX>coMj3/00KoMj3/0ol00008ohjYj003
o`000?nP/>?oX;3S00SoX;3S00?o0000ojnfg_n_]]h00_n_]]h2o`0000Ko/KgS0_l0000>okg1g003
o`000?o7`mOoal?G00Ooal?G00?o0000ol[:f_o:b]X00oo:b]X00ol0003odL_Dom7;e00>om7;e0;o
00004OoFcm800ol0003of<g>o`00000>omS@d@05o`000?oGc<ooelc?omO<col000003?oDcM<00ol0
003oooooooooo`0`ooooo`009oooool00ol0003oooooooooo`1Kooooo`03o`000?l9J]co2F[L00;o
2F[L00?o0000oaQch_lHLn800_lHLn800ol0003o;h7Xobn1j002obn1j0;o00001omMUNd00ol0003o
Mj3/ogNPk002ogNPk0?o000000?oMj3/o`000?n>ZNP02?n>ZNP00ol0003oX;3Soj2`h`09oj2`h`04
o`000?n_]]ko0000o`0000Wo/KgS0_l0000=okg1g003o`000?o7`mOoal?G00Goal?G0_l00007ol[:
fP03o`000?oAbmCodL_D00codL_D00?o0000om;Aeol000004OoFcm82o`00013of=3A00?o0000omO<
col000003_oDcM<00ol0003oooooooooo`0_ooooo`009oooool2o`0005gooooo0_l00003o`UZg003
o`000?lHLn;o67?R00;o67?R00?o0000obn1j?l_PNP00ol_PNP4o`0000CoGIG]1?l00004ogNPk003
o`000?n>ZNSoSZWX00SoSZWX00?o0000oj2`honP/><01onP/><3o`0000co/KgS0_l0000=okg1g003
o`000?o7`mOoal?G00?oal?G00?o0000ol[:f_o:b]X02?o:b]X00ol0003odL_Dom7;e00:om7;e005
o`000?oBdMOod]7Gom;Aeol000003ooFcm800ol0003oe]?Fo`00000AomS@d@03o`000?oDcM?oe<gC
00koe<gC00?o0000ooooooooool0;_ooool002Kooooo0_l0001Oooooo`?o00000_l9J]`00ol0003o
67?RoaQchP02oaQchP03o`000?l_PNSo;h7X00;o;h7X00Co0000odfBk_m=T^koCI;^1_l00007ogNP
k003o`000?n>ZNSoSZWX00SoSZWX00Co0000oj2`honP/>?oX;3S1Ol00002oingj@03o`000?na_N?o
/KgS00_o/KgS00?o0000okg1g?nm`M`03?nm`M`01Ol0003oal?GolO3eoo7`mOo000000cob/[J00?o
0000om7;e?oAbm@02?oAbm@00ol0003od]7Gom;Ae`03om;Ae`03o`000?oFcm;oe/oB00_oe/oB00Go
0000omKCe_oFdmKoe]?Fo`00000?omS@d@;o00004?oDcM<2o`0002oooooo000Wooooo`03o`000?oo
oooooooo05kooooo00?o0000o`9Vf_l000000ol00004oaQchP03o`000?l_PNSo;h7X00;o;h7X00?o
0000odfBk_l000000_l00003odfBkPOo00000_mgX>`00ol0003oSZWXohjYj003ohjYj0So00002?nO
]nT00ol0003o/KgSok6mh`0;ok6mh`03o`000?nm`Mco_L7L00co_L7L00?o0000olO3eol000003Oo:
b]X00ol0003odL_Dom7;e007om7;e003o`000?oBdMOod]7G00God]7G00?o0000omK?d_oFcm802OoF
cm800ol0003oe]?FomKCeP03omKCeP03o`000?oHd=7of=3A00_of=3A00Co0000omGBeooEd]Oo0000
4?oDcM<2o`0002kooooo000Wooooo`03o`000?oooooooooo05oooooo00Co0000o`9Vf_l2I][o0VKJ
0_l00004oaQchP03o`000?l_PNSo;h7X00?o00001om=T^h00ol0003oKJ7`offQl003offQl0So0000
1On8[^h00ol0003oWkOYoingj@09oingj@03o`000?na_N?o/KgS00_o/KgS00?o0000okg1g?nm`M`0
2onm`M`2o`0000oob/[J00?o0000om7;e?oAbm@01OoAbm@00ol0003od]7Gom;Ae`07om;Ae`03o`00
0?oFcm;oe/oB00Ooe/oB00?o0000omKCe_oFdmH01OoFdmH00ol0003of=3AomS@d@09omS@d@03o`00
0?oEd]OoeM;G00;oeM;G00?o0000omC=dooDcM<03?oDcM<00ol0003oclkHo`00000^ooooo`009_oo
ool00ol0003oooooooooo`1Qooooo`03o`000?l2I][o0VKJ00;o0VKJ0_l00002oaQchP?o00000ol_
PNP00ol0003oCI;^odfBkP05odfBkP03o`000?m]XO3oKJ7`00GoKJ7`00?o0000ohR^k_n8[^h02?n8
[^h00ol0003oWkOYoingj@09oingj@03o`000?na_N?o/KgS00_o/KgS00?o0000okg1g?nm`M`02?nm
`M`2o`000003ol39hOl0003ob/[J00oob/[J00?o0000om7;e?oAbm@00ooAbm@00ol0003od]7Gom;A
e`09om;Ae`03o`000?oFcm;oe/oB00Goe/oB00?o0000omKCe_oFdmH01ooFdmH00ol0003of=3AomS@
d@07omS@d@03o`000?oEd]OoeM;G00CoeM;G00?o0000omC=dooDcM<02_oDcM<01Ol0003oclkHolo>
f?o?c]So000002gooooo000Vooooo`03o`000?oooooooooo06;ooooo00Co0000o`9Vf_l2I][o0VKJ
1?l000000olHLn;o0000obn1j004obn1j003o`000?m=T^koCI;^00GoCI;^00?o0000offQl?m]XO00
1Om]XO000ol0003oR:k^ohR^kP08ohR^kP03o`000?nO]nWoWkOY00WoWkOY00?o0000ok6mhona_N<0
2_na_N<2o`0000So_L7L00?o0000ol39hOo0bN400_o0bN400ol0003ob/[Jol[:fP0>ol[:fP05o`00
0?oAbmCodL_Dom7;e?l000003OoBdML00ol0003oe/oBomK?dP03omK?dP03o`000?oFdmKoe]?F00Wo
e]?F00?o0000omS@dOoHd=401OoHd=400ol0003oeM;GomGBe`06omGBe`03o`000?oDcM?oe<gC00So
e<gC00?o0000olo>f?o?c]P00_o?c]P2o`0002cooooo000Vooooo`03o`000?oooooooooo06?ooooo
1Ol00002o`e^gP?o00001Ol_PNP00ol0003oCI;^odfBkP05odfBkP03o`000?m]XO3oKJ7`00GoKJ7`
00?o0000ohR^k_n8[^h02?n8[^h00ol0003oWkOYoingj@09oingj@03o`000?na_N?o/KgS00[o/KgS
00?o0000okg1g?nm`M`01?nm`M`2o`0000Ko`<WQ00?o0000ol[:f_o:b]X03_o:b]X00ol0003odL_D
o`00000?om;Ae`05o`000?oFcm;oe/oBomK?d_l000003OoFdmH00ol0003of=3AomS@d@03omS@d@03
o`000?oEd]OoeM;G00SoeM;G00?o0000omC=dooDcM<01OoDcM<2o`0000KoclkH00?o0000oooooooo
ool0:_ooool002Kooooo0_l0001Sooooo`?o00000ol2I]X01?l0003o3FkNo`e^g_l=K]h2o`0000Go
;h7X00?o0000odfBk_m=T^h01Om=T^h00ol0003oKJ7`offQl005offQl003o`000?n8[^koR:k^00So
R:k^00?o0000oingjOnO]nT02OnO]nT00ol0003o/KgSok6mh`0:ok6mh`04o`000?nm`Mco_L7Lokg1
g0;o00002Oo0bN400ol0003ob/[Jol[:fP0=ol[:fP?o00004?oBdML00ol0003oe/oBo`00000?omKC
eP05o`000?oHd=7of=3AomS@dOl000003?oEd]L00ol0003oe<gComC=d`03omC=d`03o`000?o?c]So
clkH00OoclkH00?o0000ooooooooool0:Oooool002Kooooo00?o0000ooooooooool0Goooool3o`00
00?ooooo00Go0000o`9Vf_l2I][o0VKJo`000003o`e^gP;o00001Ol_PNP00ol0003oCI;^odfBkP05
odfBkP03o`000?m]XO3oKJ7`00GoKJ7`00?o0000ohR^k_n8[^h02?n8[^h00ol0003oWkOYoingj@08
oingj@03o`000?na_N?o/KgS00_o/KgS00?o0000okg1g?l000003?o0bN400ol0003ob/[Jol[:fP0;
ol[:fP05o`000?o<d]koc=;NolcBg_l000003ooBdML3o`00013oe]?F00?o0000omS@dOl000003_oE
d]L01Ol0003oe<gComC=dooDcM?o000000_oclkH00?o0000ooooooooool0:?ooool002Kooooo00?o
0000ooooooooool0G?ooool3o`0000Oooooo00Go0000o`9Vf_l2I][o0VKJo`000004o`e^gP?o0000
0ol_PNP00ol0003oCI;^odfBkP05odfBkP03o`000?m]XO3oKJ7`00GoKJ7`00?o0000ohR^k_n8[^h0
2?n8[^h00ol0003oWkOYoingj@08oingj@03o`000?na_N?o/KgS00[o/KgS0_l0000>ol39h@03o`00
0?o:b][ob/[J00Sob/[J0_l00005olcBgP03o`000?oBdMOod]7G00_od]7G00Go0000om;Gg?oBemco
d]OLo`00000?omKCeP;o00004?oEd]L00ol0003oe<gCo`00000<olo>f003o`000?oooooooooo02So
oooo000Vooooo`03o`000?oooooooooo05Wooooo0ol0000;ooooo`05o`000?l2I][o0VKJo`9Vf_l0
00001?l=K]h00ol0003o8WgWo`000002o`000003obn1j?l0003oCI;^00GoCI;^00?o0000offQl?m]
XO001_m]XO000ol0003oR:k^ohR^kP07ohR^kP03o`000?nO]nWoWkOY00WoWkOY00?o0000ok6mhona
_N<01_na_N<3o`000003ok;6jOl0003o000000ko`<WQ00?o0000ol[:f_o:b]X01_o:b]X00ol0003o
c=;NolcBgP06olcBgP03o`000?oBdMOod]7G00Wod]7G00?o0000om;Gg?oBem`00ooBem`00ol0003o
e]?FomKCeP0;omKCeP04o`000?oDf=_oe=SKo`0000ooeM;G0_l0000>olo>f003o`000?oooooooooo
02Oooooo000Vooooo`03o`000?oooooooooo05Kooooo0ol0000?ooooo`;o00000_l2I]X00ol0003o
3FkNo`e^gP02o`e^gP04o`000?lRONOo8WgWob9mi`?o00001_m=T^h00ol0003oKJ7`offQl005offQ
l003o`000?n8[^koR:k^00SoR:k^00?o0000oingjOnO]nT02OnO]nT00ol0003o/KgSok6mh`03ok6m
h`;o00001Onba^T2o`0000ko`<WQ00?o0000ol[:f_o:b]X01?o:b]X00ol0003oc=;NolcBgP08olcB
gP03o`000?oBdMOod]7G00Ood]7G00?o0000om;Gg?oBem`01OoBem`00ol0003oe]?FomKCeP09omKC
eP03o`000?oDf=_oe=SK00;oe=SK00?o0000omGBeooEd]L02ooEd]L00ol0003od=GMo`00000?olo>
f003o`000?oooooooooo02Kooooo000Vooooo`03o`000?oooooooooo05?ooooo0ol0000Cooooo`?o
000000?o0VKJo`000?l=K]h00ol=K]h00ol0003o8WgWob9mi`03ob9mi`?o00001?m=T^h00ol0003o
KJ7`offQl005offQl003o`000?n8[^koR:k^00SoR:k^00?o0000oingjOnO]nT02OnO]nT00ol0003o
/KgSo`000002o`0000So//KY0_l0000>ol39h@04o`000?o:b][ob/[Jol[:fP;o00003?o<d]h00ol0
003od]7Gom;Ae`05om;Ae`03o`000?oBemcod]OL00Ood]OL00?o0000omKCe_oFdmH01ooFdmH00ol0
003oe=SKomCHf`04omCHf`03o`000?oEd]OoeM;G00WoeM;G00Go0000om3EgOo@eMgod=GMo`00000>
olo>f0;o00009oooool002Gooooo00?o0000ooooooooool0DOooool3o`0001Oooooo00?o0000o`UZ
g?l000000_l00004o`e^gP03o`000?lRONOo8WgW00?o8WgW00?o0000od6Akol000000_l00002odfB
kP03o`000?m]XO3oKJ7`00GoKJ7`00?o0000ohR^k_n8[^h02?n8[^h00ol0003oWkOYoingj@07oing
j@?o00003?nba^T00ol0003o`<WQol39h@0=ol39h@03o`000?o:b][o000000ooc=;N00?o0000om;A
eooBdML00ooBdML00ol0003od]OLom;Gg009om;Gg003o`000?oFdmKoe]?F00Goe]?F00?o0000omCH
fooDf=/01_oDf=/00ol0003oeM;GomGBe`07omGBe`03o`000?o@eMgod=GM00?od=GM00?o0000olo>
f?o?c]P03?o?c]P00ol0003oooooooooo`0Uooooo`009Oooool3o`0004kooooo0ol0000Jooooo`;o
00000_l9J]`2o`0000Co3FkN00?o0000ob9miolRONL00olRONL01?l0003o@I7_od6Akom1TNl4o`00
00OoKJ7`00?o0000ohR^k_n8[^h02?n8[^h01?l0003oWkOYoingjOnO]nT5o`0000;oWKo`00?o0000
ok;6jOnba^T02onba^T00ol0003o`<WQol39h@0<ol39h@?o00004?o<d]h01Ol0003od]7Gom;AeooB
dMOo000000god]OL00?o0000omKCe_oFdmH00ooFdmH00ol0003oe=SKomCHf`08omCHf`03o`000?oE
d]OoeM;G00GoeM;G00?o0000om3EgOo@eMd01Oo@eMd00ol0003oclkHolo>f00;olo>f0;o00009_oo
ool002Gooooo00?o0000ooooooooool0Boooool3o`0001kooooo0_l00002o`UZg0;o00001?l=K]h0
0ol0003o8WgWob9mi`03ob9mi`03o`000?m1TNoo@I7_00?o@I7_1ol00002offQl003o`000?n8[^ko
R:k^00?oR:k^2?l00008oifol003o`000?nba^Wo//KY00_o//KY00?o0000ol39hOo0bN402Oo0bN42
o`0000?o`M7V00?o0000olcBg_o<d]h03_o<d]h00ol0003od]7Go`00000?om;Gg005o`000?oFdmKo
e]?FomKCe_l000003?oDf=/00ol0003oeM;GomGBe`03omGBe`03o`000?o@eMgod=GM00Ood=GM00?o
0000olo>f?o?c]P02Oo?c]P01?l0003oa/gOo`000?l0000Uooooo`002Oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01oooool00ol0003o
ooooooooo`18ooooo`?o00008_ooool2o`0000?o2F[L0_l00003o`e^gP03o`000?lRONOo8WgW00?o
8WgW00?o0000od6Akom1TNl01?m1TNl00ol0003oHjCeof>Tm@02of>Tm@So00001_n3]?@00ol0003o
WKo`oifol008oifol003o`000?nba^Wo//KY00_o//KY00?o0000ol39hOo0bN401oo0bN400ol0003o
`M7Vol7AiP04ol7AiP03o`000?o<d]koc=;N00goc=;N0_l0000Aom;Gg003o`000?oFdmKo000000ko
e=SK00Go0000omGBeooEd]OoeM;Go`00000;om3Eg@03o`000?o?c]SoclkH00KoclkH0_l00003olK=
g`;o00009?ooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ
8B7oV9RHoooooonHV9So8B4Q00Oooooo00?o0000ooooooooool0AOooool3o`0002Kooooo0_l00004
o`UZg0;o00000_l=K]h00ol0003o8WgWob9mi`03ob9mi`03o`000?m1TNoo@I7_00Co@I7_00?o0000
of>TmOmSY?D01OmSY?D00ol0003oPkCdoh>dm008oh>dm003o`000?nM_o3oWKo`00SoWKo`00?o0000
ok;6jOnba^T02onba^T00ol0003o`<WQol39h@04ol39h@;o00002?o1dNH00ol0003oc=;NolcBgP0;
olcBgP04o`000?o<fN?oc=WSo`00013od]OL0_l0000@omCHf`03o`000?oEd]Oo000000god=GM00?o
0000olo>f?o?c]P01?o?c]P00ol0003oa/gOolK=g`04olK=g`03o`000?oooooooooo02;ooooo0009
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool0@_ooool3o`0002[ooooo0_l00004o`UZg0Go00001OlRONL00ol0003o@I7_
od6Ak`04od6Ak`03o`000?mSY?GoHjCe00GoHjCe00?o0000oh>dm?n3]?@02?n3]?@00ol0003oWKo`
oifol008oifol003o`000?nba^Wo//KY00_o//KY00Co0000ol39hOo0bN7o`<WQ0_l0000;ol7AiP03
o`000?o<d]koc=;N00Soc=;N0_l00004olcIh`03o`000?oBemcod]OL00cod]OL00Co0000om3Lh_o@
g>;o00003ooDf=/2o`0000ood=GM00Co0000olo>f?o?c]SoclkH0_l00008olK=g`03o`000?oooooo
oooo027ooooo0009ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonH
V9So<S8b00Oooooo00?o0000ooooooooool0?oooool3o`0002kooooo0_l00004o`UZg003o`000?l>
LN3o3W7P00;o00001OlRONL00ol0003o@I7_od6Ak`04od6Ak`03o`000?mSY?GoHjCe00GoHjCe00?o
0000oh>dm?n3]?@02?n3]?@00ol0003oWKo`oifol008oifol003o`000?nba^Wo//KY00_o//KY00?o
0000ol39hOl000003_o1dNH00ol0003oc=;NolcBgP06olcBgP03o`000?o<fN?oc=WS00Goc=WS00?o
0000om;Gg?oBem`02_oBem`00ol0003od=cRom3LhP02om3LhP03o`000?oDf=_oe=SK00_oe=SK00Co
0000oloKh_o?fn;o00003oo@eMd00ol0003oclkHo`00000:olK=g`;o00008_ooool000Wooooo00Go
0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01oooool00ol0003o
ooooooooo`0looooo`?o0000<_ooool2o`0000Co2F[L00Co0000o`iah?l>LN3o3W7P0ol00003ob9m
i`03o`000?m1TNoo@I7_00Co@I7_00?o0000of>TmOmSY?D01OmSY?D00ol0003oPkCdoh>dm008oh>d
m003o`000?nM_o3oWKo`00SoWKo`00?o0000ok;6jOnba^T02_nba^T3o`0000oo`M7V00?o0000olcB
g_o<d]h01?o<d]h00ol0003oc=WSolcIh`07olcIh`03o`000?oBemcod]OL00Sod]OL00?o0000om3L
h_o@g>801?o@g>800ol0003oe=SKomCHf`08omCHf`;o00001?o?fn800ol0003od=GMom3Eg@0<om3E
g@;o00003?o6cMl2o`00027ooooo0009ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@
413o^[Zjoooooonj^[[o410@00Oooooo00?o0000ooooooooool0>Oooool3o`0003Kooooo0_l00004
o`UZg003o`000?l>LN3o3W7P00;o3W7P1?l000000olRONOo0000od6Ak`05od6Ak`03o`000?mSY?Go
HjCe00GoHjCe00?o0000oh>dm?n3]?@02?n3]?@00ol0003oWKo`oifol008oifol003o`000?nba^Wo
//KY00Ko//KY0ol000001?nbcnoo0000ok;?kol0000?ol7AiP04o`000?o<d]koc=;NolcBgP;o0000
2oo<fN<00ol0003od]OLom;Gg005om;Gg0;o00002?o@g>800ol0003oe=SKomCHf`06omCHf`03o`00
0?o?fn;ocm_R00Gocm_R00?o0000om3EgOo@eMd02Oo@eMd2o`000003olOFiOl0003oa/gO00coa/gO
00?o0000ooooooooool07oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`0gooooo`?o0000>_ooool3o`0000?o
2F[L00?o0000o`iah?l>LN000_l>LN000ol0003o7goWoamoi`03o`0000Ko@I7_00?o0000of>TmOmS
Y?D01OmSY?D00ol0003oPkCdoh>dm008oh>dm003o`000?nM_o3oWKo`00SoWKo`00?o0000ok;6jOnb
a^T00onba^T2o`0000Go//o_00?o0000ok;?kol000003oo1dNH00ol0003oc=;No`00000>olcIh`03
o`000?oBemcod]OL00?od]OL00?o0000om3Lh_o@g>802Oo@g>800ol0003oe=SKomCHf`04omCHf`03
o`000?o?fn;ocm_R00Oocm_R00?o0000om3EgOo@eMd01oo@eMd00ol0003oamKUolOFi@02olOFi@03
o`000?o6cMooa/gO00[oa/gO0_l0000Pooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo03Cooooo0ol0000noooo
o`04o`000?lKMn?o0000o`0000;o2F[L00?o0000o`iah?l>LN000_l>LN000ol0003o7goWoamoi`02
oamoi`?o00001?m1TNl00ol0003oHjCeof>Tm@05of>Tm@03o`000?n3]?CoPkCd00SoPkCd00?o0000
oifol?nM_o002?nM_o000ol0003o//KYo`000002o`0000So//o_00?o0000ok;?kol000003_o1dNH3
o`0000ooc=WS00Go0000om;Gg?oBemcod]OLo`00000=om3LhP04o`000?oDf=_oe=SKomCHf`;o0000
2oo?fn800ol0003od=GMom3Eg@04om3Eg@;o00001_o7e^D00ol0003oa/gOolK=g`0:olK=g`;o0000
7oooool002Cooooo00?o0000ooooooooool0<Oooool3o`0004;ooooo00?o0000oa]gholKMn<01?l0
0004o`iah003o`000?lOOnOo7goW00?o7goW1?l00002od6Ak`03o`000?mSY?GoHjCe00GoHjCe00?o
0000oh>dm?n3]?@02?n3]?@00ol0003oWKo`oifol006oifol0Co00002onbcnl00ol0003o//o_o`00
000;ol7AiP;o00000oo1f^`00ol0003oc=WSolcIh`0=olcIh`03o`000?oBemco000000ood=cR00?o
0000omCHfol000003_o?fn801?l0003od=GMom3EgOo@eMd2o`0000WoamKU00?o0000olK=goo6cMl0
2_o6cMl2o`0001kooooo000Tooooo`03o`000?oooooooooo02oooooo0_l00016ooooo`03o`000?lK
Mn?o6gOS00;o6gOS0_l00004o`iah003o`000?lOOnOo7goW00?o7goW00?o0000ocZClOljTo401?l0
0007of>Tm@03o`000?n3]?CoPkCd00SoPkCd00?o0000oifol?nM_o001Ol00004oi_7mP03o`000?nb
cnoo//o_00Wo//o_00?o0000ok;?kol000002Oo1dNH00ol0003o`M[/ol7Jk004ol7Jk003o`000?o<
fN?oc=WS00coc=WS0ol0000?om3LhP?o00003oo?fn800ol0003od=GMo`00000<olOFi@03o`000?o6
cMooa/gO00Woa/gO0_l0000Nooooo`009?ooool00ol0003oooooooooo`0/ooooo`?o0000BOooool0
0ol0003o6gOSoa]gh`03oa]gh`;o00000ol>LN000ol0003o7goWoamoi`03oamoi`03o`000?ljTo7o
>Y?a00;o>Y?a1ol00002of>Tm@03o`000?n3]?CoPkCd00?oPkCd1ol0000:oi_7mP03o`000?nbcnoo
//o_00Wo//o_00?o0000ok;?kol000001_o1dNH2o`0000So`M[/00?o0000olcIhoo<fN<02Oo<fN<2
o`0000?obN3Y00?o0000om3Lh_o@g>802oo@g>801Ol0003obn7Yol_QjOo;hNWo000000kocm_R0ol0
000=olOFi@03o`000?o6cMooa/gO00Koa/gO0_l000000onjbnOo0000o`00000Mooooo`009?ooool0
0ol0003oooooooooo`0Yooooo`?o0000COooool00ol0003o6gOSoa]gh`03oa]gh`?o00000_l>LN00
0ol0003o7goWoamoi`03oamoi`03o`000?ljTo7o>Y?a00Co>Y?a00Co0000oebXn?mLZ?SoG:Sh2?l0
0007ogjknP03o`000?nKaoKoVlOf00SoVlOf00?o0000ok;?konbcnl02Onbcnl00ol0003o//o_o`00
0003ol7AiP;o00002oo1f^`00ol0003oc=WSolcIh`07olcIh`03o`000?o9h>WobN3Y00CobN3Y0_l0
0009om3LhP;o00001Oo;hNT00ol0003ocm_RoloKhP0:oloKhP05o`000?o6g^_oa]k[olKNjol00000
3Oo7e^D00ol0003oa/gOolK=g`02olK=g`?o00001?njbnL2o`0001cooooo000Tooooo`03o`000?oo
oooooooo02Kooooo0ol0001Aooooo`03o`000?lKMn?o6gOS00?o6gOS00?o0000oa]li_l000000ol0
0005oamoi`03o`000?ljTo7o>Y?a00Co>Y?a00?o0000oebXn?mLZ?P01OmLZ?P00ol0003oO[_jogjk
nP08ogjknP03o`000?nKaoKoVlOf00SoVlOf0_l0000:ok;?k`05o`000?nbcnoo0000ol7Ai_l00000
3_o1f^`00ol0003oc=WSolcIh`04olcIh`;o00002Oo9h>T00ol0003od=cRom3LhP05om3LhP03o`00
0?o;hNWobn7Y00Kobn7Y0_l00008oloKhP;o00001Oo6g^/00ol0003oamKUolOFi@0;olOFi@04o`00
0?o6cMoo0000o`0000So^/_W0_l0000Kooooo`008oooool2o`0002Gooooo0ol0001Eooooo`03o`00
0?lKMn?o6gOS00?o6gOS00Co0000oa]li_lKO>Ko6gcV0_l00005oamoi`03o`000?ljTo7o>Y?a00Co
>Y?a00?o0000oebXn?mLZ?P01OmLZ?P00ol0003oO[_jogjknP08ogjknP03o`000?nKaoKoVlOf00Wo
VlOf00?o0000ok;?konbcnl01onbcnl00ol0003o//o_o`000002o`0000oo`M[/00Co0000olcIhoo<
fN?oc=WS0_l0000<olWPj@;o00000oo@g>82o`0000_obn7Y00?o0000oloKh_o?fn801?o?fn800ol0
003oa]k[olKNj`06olKNj`03o`000?o7e^GoamKU00[oamKU0_l0000;ok[;i`03o`000?oooooooooo
01Wooooo000Tooooo`03o`000?oooooooooo023ooooo0ol0001Iooooo`03o`000?lKMn?o6gOS00?o
6gOS00?o0000oa]li_lKO>H00_lKO>H3o`0000?o7goW00?o0000ocZClOljTo401?ljTo400ol0003o
G:ShoebXn005oebXn003o`000?mn^o[oO[_j00SoO[_j00?o0000oi_7m_nKaoH02OnKaoH00ol0003o
//o_ok;?k`06ok;?k`;o00000on`eo@00ol0003o`M[/ol7Jk00=ol7Jk003o`000?o<fN?o0000013o
bN3Y00?o0000om3Lh_l000003_o;hNT01?l0003ocm_RoloKh_o?fn82o`0000[oa]k[00?o0000olOF
iOo7e^D01oo7e^D2o`000003ok[DkOl0003o^/_W00_o^/_W00?o0000ooooooooool06?ooool002?o
oooo00?o0000ooooooooool07_ooool3o`0005gooooo00?o0000oa]gholKMn<00olKMn<00ol0003o
6gcVoa]liP03oa]liPCo000000?o7goWo`000?ljTo401OljTo400ol0003oG:ShoebXn005oebXn003
o`000?mn^o[oO[_j00SoO[_j00?o0000oi_7m_nKaoH02OnKaoH00ol0003o//o_ok;?k`02ok;?k`?o
00000_n`eo@01?l0003o/=Odok3Gm?n`eo@2o`0000go`M[/0ol0000@olWPj@?o00003oo;hNT00ol0
003ocm_Ro`00000=olKNj`03o`000?o7e^GoamKU00CoamKU0_l00004ok[Dk@03o`000?njbnOo^/_W
00[o^/_W00?o0000ooooooooool05oooool002?ooooo00?o0000ooooooooool06oooool3o`00067o
oooo00?o0000oa]gholKMn<00olKMn<00ol0003o6gcVoa]liP03oa]liP03o`000?lVR>_o9XS[00?o
00001_ljTo400ol0003oG:ShoebXn005oebXn003o`000?mn^o[oO[_j00SoO[_j00?o0000oi_7m_nK
aoH02OnKaoH01?l0003o//o_o`000?l00006ok3Gm003o`000?n`eoCo/=Od00;o/=Od00?o0000ol7J
k?o1f^`02?o1f^`2o`0000?o_N7a0_l0000=olWPj@05o`000?o3i^oo`nK_ol?Vkol000003_o;hNT3
o`0000koa]k[00?o0000olOFiOo7e^D00_o7e^D00ol0003o^]C]ok[Dk@05ok[Dk@03o`000?njbnOo
^/_W00Wo^/_W0_l0000Hooooo`008oooool00ol0003oooooooooo`0Hooooo`?o0000IOooool3o`00
00?o6gOS00?o0000oa]li_lKO>H00olKO>H00ol0003o9XS[obJ8j`02obJ8j`?o00001?ljTo400ol0
003oG:ShoebXn005oebXn003o`000?mn^o[oO[_j00SoO[_j00?o0000oi_7m_nKaoH01onKaoH4o`00
00So/=Od00?o0000ok3Gm?n`eo@00_n`eo@00ol0003o`M[/ol7Jk005ol7Jk0;o00001onmhO400ol0
003obN3YolWPj@08olWPj@;o00001Oo3i^l2o`0000[obn7Y0_l00003ol7Tl003o`000?o6g^_oa]k[
00coa]k[00Co0000olOFiOl0003o00002Onje>d00ol0003o^/_Wok[;i`09ok[;i`03o`000?oooooo
oooo01Kooooo000Sooooo`03o`000?oooooooooo01Gooooo0ol0001Xooooo`03o`000?lhR>co>8S/
00?o000000?o6gOSo`000?lKO>H01?lKO>H00ol0003o9XS[obJ8j`03obJ8j`Oo00001omLZ?P00ol0
003oO[_jogjknP08ogjknP04o`000?nKaoKoVlOfoi_7mPGo00001?nHd?/00ol0003o/=Odok3Gm006
ok3Gm003o`000?n`eoCo/=Od00;o/=Od0_l00004ol7Jk003o`000?nmhO7o_N7a00So_N7a0_l00007
olWPj@03o`000?o3i^oo`nK_00Oo`nK_00?o0000ol_QjOo;hNT01Oo;hNT2o`0000Ko`NC`00?o0000
olKNjoo6g^/02oo6g^/3o`0000_o^]C]00?o0000ok[;ionjbnL02OnjbnL00ol0003oooooooooo`0E
ooooo`008oooool00ol0003oooooooooo`0Booooo`?o0000K?ooool00ol0003o>8S/ocR8k002ocR8
k0?o00001OlKO>H00ol0003o9XS[obJ8j`03obJ8j`03o`000?llV_?o?9[c00;o?9[c1ol00002oebX
n003o`000?mn^o[oO[_j00?oO[_j2?l0000:oiS@n`03o`000?n`eoCo/=Od00Ko/=Od00?o0000ok3G
m?n`eo@00on`eo@01?l0003o`M[/o`000?l0000=okgQl@;o00000oo9h>T2o`0000_o`nK_0_l00004
ol_Qj@03o`000?o1i?3o`NC`00Oo`NC`0_l00008olKNj`?o00000onhgO<00ol0003o^]C]ok[Dk@09
ok[Dk@03o`000?njbnOo^/_W00Wo^/_W00?o0000ooooooooool05?ooool002;ooooo0ol0000@oooo
o`?o0000L?ooool00ol0003o>8S/ocR8k004ocR8k0?o00000olKO>H00ol0003o9XS[obJ8j`03obJ8
j`03o`000?llV_?o?9[c00Co?9[c00Co0000oeZ_n_mJ[o[oFZoj2?l00007og[2o@03o`000?nHd?_o
V=3k00WoV=3k0_l00007ok3Gm003o`000?n`eoCo/=Od00;o/=Od0ol0000@okgQl@03o`000?o9h>Wo
000000oo`nK_00Co0000ol_QjOl0003o00003?o1i?000ol0003oa]k[olKNj`03olKNj`;o00001onh
gO<00ol0003o^]C]ok[Dk@09ok[Dk@03o`000?njbnOo^/_W00Oo^/_W0ol0000Eooooo`008oooool0
0ol0003oooooooooo`0<ooooo`?o0000M?ooool00ol0003o>8S/ocR8k004ocR8k003o`000?lcSNko
000000;o000000?o6gcVo`000?lVR>/01?lVR>/2o`0000Go?9[c00?o0000oeZ_n_mJ[oX01OmJ[oX0
0ol0003oN/;mog[2o@08og[2o@;o00002onHd?/00ol0003o/=Odok3Gm004ok3Gm003o`000?n`eoCo
000000;o00000on/goT00ol0003o_N7aokgQl@0=okgQl@?o00003oo3i^l3o`0000ko`NC`00?o0000
olKNjol000000_l0000:okSMl`03o`000?nje>go^]C]00Wo^]C]00Co0000ok[;ionjbnOo^/_W1Ol0
0002ooooo`03o`000?oooooooooo01?ooooo000Sooooo`03o`000?oooooooooo00Wooooo0ol0001h
ooooo`03o`000?lhR>co>8S/00Co>8S/00Co0000oc>=k_lcSNko<hg^0ol00006obJ8j`03o`000?ll
V_?o?9[c00?o?9[c00?o0000oeZ_n_mJ[oX01OmJ[oX2o`0000[oN/;m00?o0000oiS@nonHd?/02OnH
d?/00ol0003o/=Odok3Gm003ok3Gm0;o00001on/goT2o`0000_o_N7a0_l00003okKWmP;o00002oo3
i^l2o`0000?o^>Se00?o0000ol7Tl?o1i?002oo1i?03o`0000go^=gc00?o0000ok[DkOnje>d02?nj
e>d6o`0000Gooooo00?o0000ooooooooool04oooool002?ooooo00?o0000ooooooooool01_ooool3
o`0007cooooo00?o0000ocR8k?lhR>`01?lhR>`00ol0003o<hg^oc>=kP03oc>=kP?o00001?lVR>/0
0ol0003o?9[cocbJl`03ocbJl`;o00001omJ[oX00ol0003oN/;mog[2o@08og[2o@03o`000?nHd?_o
V=3k00WoV=3k00?o0000ok3Gm?l000000_l00002ojcOn@03o`000?n/goWo[=oi00Ko[=oi00?o0000
okgQlOnmhO401_nmhO42o`0000Oo]^Of0_l00007ol?Vk`;o00001_nhj?D2o`0000Wo`NC`0_l00003
ok;Tm`03o`000?nhgO?o^=gc00_o^=gc00?o0000ok[DkOnje>d01?nje>d6o`0000Sooooo00?o0000
ooooooooool04oooool002;ooooo00?o0000ooooooooool01?ooool3o`00083ooooo00?o0000ocR8
k?lhR>`01?lhR>`00ol0003o<hg^oc>=kP04oc>=kPOo00001_llV_<00ol0003oFZojoeZ_nP05oeZ_
nP03o`000?mj`_goN/;m00SoN/;m0_l00008oiS@n`Co00001On/goT00ol0003o[=oiojcOn@06ojcO
n@;o00001?nmhO42o`0000_o]^Of00?o0000ol?Vkoo3i^l00oo3i^l00ol0003o^>SeokSXm@08okSX
m@;o00001?o1i?03o`0000Ko/^Cg0_l0000<okSMl`03o`000?nje>go^]C]00Go00003?ooool00ol0
003oooooooooo`0Cooooo`008_ooool01?l0003oooooooooooooool3o`0008Cooooo00?o0000ocR8
k?lhR>`01?lhR>`00ol0003o<hg^oc>=kP04oc>=kP03o`000?lhUo;o>9Ob00;o>9Ob1?l00004ocbJ
l`03o`000?mJ[o[oFZoj00GoFZoj0_l0000:og[2o@03o`000?nHd?_oV=3k00Go00001?nDeoh2o`00
00Co[=oi00?o0000ojcOnOn/goT01on/goT01?l0003o_N7ao`000?l0000>okKWmP;o000000?o`nK_
o`000?l000003Onhj?D01?l0003o`NC`o`000?l0000;ok;Tm`03o`000?nhgO?o^=gc00Wo^=gc1Ol0
000?ooooo`03o`000?oooooooooo01?ooooo000Rooooo`Co0000R?ooool00ol0003o>8S/ocR8k004
ocR8k003o`000?lcSNko<hg^00Co<hg^00?o0000ocRGl_lhUo801?lhUo87o`0000SoFZoj00?o0000
og[2oOmj`_d00omj`_d7o`0000_oU=On0_l00003ojcOn@03o`000?n/goWo[=oi00Ko[=oi0ol0000@
okKWmP?o00003_nhj?D3o`0000go/^Cg0_l00006okSMl`Go00004_ooool00ol0003oooooooooo`0C
ooooo`008_ooool3o`0008[ooooo00?o0000ocR8k?lhR>`01?lhR>`00ol0003o<hg^oc>=kP04oc>=
kP;o00001OlhUo800ol0003oAZKgodJVm`02odJVm`oo00001omibOl2o`0000_oU=On0_l00002ojcO
n@03o`000?n/goWo[=oi00;o[=oi0ol00003ojGTn`;o00002onfioH3o`0000?o[>Wi0_l0000:okSX
m@;o00000onZioX00ol0003o/^Cgok;Tm`0<ok;Tm`03o`000?nhgO?o^=gc00Co00005oooool00ol0
003oooooooooo`0Booooo`009?ooool00ol0003oooooooooo`29ooooo`?o00001?lhR>`00ol0003o
<hg^oc>=kP05oc>=kP03o`000?lhUo;o>9Ob00?o>9Ob00?o0000odJVmom6Y_L01?m6Y_L2o`0000Oo
GKSl0_l0000:ogW9o`;o00002onDeoh3o`000004ojcOnOl0003o0000o`0000SoYNCk0ol00006okKW
mP;o00002?n/jOT2o`0000Go^>Se0ol00006oj[WnP;o00002onbi?L5o`0001[ooooo00?o0000oooo
ooooool04_ooool001Kooooo00?ok^k^o`000?l000000_l000000ol@413oooooooooo`07ooooo`03
o`000?oooooooooo08Wooooo00?o0000oeVJlOl000001Ol00007oc>=kP03o`000?lhUo;o>9Ob00?o
>9Ob0_l00006odJVm`03o`000?mM^?coGKSl00KoGKSl00?o0000ogW9oomibOl02OmibOl00ol0003o
U=OnoiCGoP08oiCGoPCo00003_nUi?/2o`000004okKWm_l0003o0000o`0000co[>Wi0_l000000onh
j?Go0000o`00000;oj[WnP;o00001_nbi?L5o`0001gooooo00?o0000ooooooooool04_ooool001Ko
oooo00GoMgMgoiRHV?oooooo0000ogMgM`0;ooooo`03o`000?oooooooooo08Wooooo00?o0000oeVJ
lOmIV_400omIV_47o`0000;o<hg^00?o0000ocRGl_lhUo801?lhUo800ol0003oAZKgodJVm`04odJV
m`;o00001omM^?`2o`0000[oNLWo0_l00003oiCGoPGo00001?n@g?h2o`0000goYNCk1?l0000>ojcY
n@?o00003_nZioX00ol0003o/^Cgok;Tm`04o`00027ooooo00?o0000ooooooooool04_ooool001Ko
oooo00Go410@oooooooooooo0000oa0@400<ooooo`03o`000?oooooooooo08Wooooo00?o0000oeVJ
lOmIV_401OmIV_401?l0003oDj3eoe>PmOmCX?D6o`0000Co>9Ob00?o0000odJVmom6Y_L01Om6Y_L2
o`0000OoGKSl0_l00008ogW9o`Go00002_n@g?h4o`0000OoYNCk0ol00004oigVo0?o00002?n/jOT3
o`0000?oX>Sk0_l0000<oj[WnPCo00009?ooool00ol0003oooooooooo`0Booooo`005_ooool00ol0
003oooooooooo`02o`0000gooooo00?o0000ooooooooool0ROooool00ol0003oFI[aoeVJl@05oeVJ
l@03o`000?mCX?GoDj3e00GoDj3e1ol00008odJVm`03o`000?mM^?coGKSl00KoGKSl00?o0000ogW9
oomibOl01Ol00004og[@o`;o00002_n@g?h00ol0003oT=cnoi3LoP02o`0000;oYNCk0ol0000:oigV
o0?o00000_n/jOT3o`0000SoX>Sk0_l00007oj[WnPCo00009oooool00ol0003oooooooooo`0Boooo
o`005_ooool00ol0003oooooooooo`02o`0000kooooo00?o0000ooooooooool0ROooool00ol0003o
FI[aoeVJl@05oeVJl@03o`000?mCX?GoDj3e00GoDj3e00?o0000oe>YnOmCZOT00_mCZOTEo`0000_o
N]3o0_l00009oi3LoP03o`000?n@g?koT=cn00Co00003_nMi_`3o`0000goX>Sk0_l00002oj[WnPCo
0000:_ooool00ol0003oooooooooo`0Booooo`005_ooool01Ol@413oooooooooool0003o410@00oo
oooo00?o0000ooooooooool0ROooool00ol0003oFI[aoeVJl@05oeVJl@03o`000?mCX?GoDj3e00Go
Dj3e00?o0000oe>YnOmCZOT01?mCZOT00ol0003oFKCloeVdo006oeVdo0;o00001omW`_h3o`0000[o
N]3o0_l00007oi3LoP?o00001?n>h?h3o`0000SoWNKl0ol00003oiKVo0?o00002_nPj?/4o`0002ko
oooo00?o0000ooooooooool04_ooool001Kooooo00GoMgMgoiRHV?oooooo0000ogMgM`0@ooooo`;o
0000R_ooool00ol0003oFI[aoeVJl@05oeVJl@03o`000?mCX?GoDj3e00GoDj3e0_l00005oe>Yn@;o
00002?mI]?`2o`0000SoIl;n0_l0000:og[@o`;o00000_n@g?h3o`0000;oS^3n00?o0000ohkPo_n>
h?h01On>h?h3o`0000;oWNKl0ol00009oiKVo0?o00000_nPj?/6o`00037ooooo00?o0000oooooooo
ool04_ooool001Kooooo00Gok^k^o`<30ol0003o0000onk^kP0Booooo`03o`000?oooooooooo08So
oooo00?o0000oeVJlOmIV_401OmIV_400ol0003oDj3eoe>Pm@06oe>Pm@03o`000?mCZOWoDjWi00Co
DjWi00?o0000oeVdo?mI]?`01omI]?`00ol0003oIl;nofO2oP07ofO2oP?o00001Omjd?l7o`0000Co
S^3n00?o0000ohkPo_n>h?h01on>h?h3o`0000koU^Kl1_l0000dooooo`03o`000?oooooooooo01;o
oooo000/ooooo`03o`000?oooooo000008[ooooo00?o0000oeVJlOmIV_401OmIV_400ol0003oDj3e
oe>Pm@06oe>Pm@03o`000?mCZOWoDjWi00CoDjWi0_l00008oeVdo0;o00001OmW`_h:o`0000OoPMOo
0ol00002ohkPoP03o`000?n>h?koS^3n00?oS^3n0ol00003ohoRo@?o00002?nFi_`5o`0003Sooooo
00?o0000ooooooooool04_ooool002oooooo00?o0000ooooooooool0R?ooool6o`0000;oFI[a00?o
0000oe>PmOmCX?D01_mCX?D00ol0003oDjWioe>Yn@05oe>Yn@03o`000?mI]?coFKCl00?oFKCl2Ol0
0007ogO>o`;o00002on1eol4o`000004ohkPo_l0003o0000o`0000WoSn;m0ol00002oiKVo0Go0000
??ooool00ol0003oooooooooo`0Aooooo`00<?ooool00ol0003oooooooooo`27ooooo`;o00001?mi
Z_8Io`0000KoL/Co0_l0000:ogO>o`?o00002On1eol4o`0000koSn;m1Ol0000oooooo`03o`000?oo
oooooooo017ooooo000aooooo`03o`000?oooooooooo08Oooooo0_l00008ogVZlP03o`000?md/_So
M;;h00KoM;;h00?o0000og:jo?mb^_`01Omb^_`2o`0000WoL/Co0_l0000;ogO>o`;o00000_n1eol5
o`0000CoRmkn0ol00008ohoRo@Co0000@oooool00ol0003oooooooooo`0Aooooo`00<_ooool00ol0
003oooooooooo`27ooooo`;o00002?miZ_800ol0003oM;;hogBbn006ogBbn003o`000?mb^_coL[[l
00KoL[[l00?o0000og;4oomba?l02?mba?l2o`0000WoMlko1?l0000:oh_NoP03o`000?n;g_ko0000
00;o00000_n?h_d4o`0004Kooooo00?o0000ooooooooool04Oooool003?ooooo00?o0000oooooooo
ool0Qoooool2o`0000SoNJ[b00?o0000ogBbn?md/_P01_md/_P2o`0000OoL[[l0_l0000:og;4o`;o
00000_mgc_l5o`0000CoRmSo0_l00009oh_NoP03o`000?n;g_koRmkn00Co0000BOooool00ol0003o
ooooooooo`0Aooooo`00=?ooool2o`0008Sooooo0_l00008ogVZlP03o`000?md/_SoM;;h00OoM;;h
00?o0000og:jo?mb^_`01_mb^_`2o`0000SoL/Co1?l0000;oh_Ho`;o00001on;g_h3o`0004gooooo
00?o0000ooooooooool04Oooool003Kooooo00?o0000ooooooooool0Q_ooool2o`0000SoNJ[b00?o
0000ogBbn?md/_P01omd/_P00ol0003oL[[log:jo007og:jo003o`000?mba?ooL/Co00Go00001?n<
d?h2o`0000_oRmSo0_l00002oh_NoP?o000000?oooooo`000?ooool0COooool00ol0003ooooooooo
o`0Aooooo`00=oooool2o`0008Oooooo0_l00008ogVZlP03o`000?md/_SoM;;h00OoM;;h00?o0000
og:jo?mb^_`00omb^_`6o`0000_oS=3n0_l00009oh_Ho`Co00001Oooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo017ooooo000fooooo`03o`000?oooooo000008Sooooo0_l00008ogVZ
lP03o`000?md/_SoM;;h00?oM;;h2Ol00006oho8n`;o00002on<d?h2o`0000;oRmSo1Ol0000:oooo
o`03o`000?oooooooooo04[ooooo00?o0000ooooooooool04Oooool003Wooooo00?o0000oooooooo
ool0Q_ooool2o`0000CoNJ[b2Ol00006oi:nm@03o`000?n?b?_oSlSk00SoSlSk0_l0000:ohc@oPGo
00003_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo017ooooo000jooooo`03o`00
0?oooooooooo08Kooooo1Ol00006oiFfkP03o`000?nB__GoT[ke00OoT[ke00?o0000oho8non?b?/0
2On?b?/00ol0003oS=3nohc@oP04ohc@oPGo00004_ooool00ol0003oooooooooo`18ooooo`03o`00
0?oooooooooo017ooooo000kooooo`03o`000?oooooooooo08Kooooo00?o0000oiFfk_nE]^h02?nE
]^h00ol0003oT[keoi:nm@07oi:nm@;o00002_n?b?/2o`000003ohc@o_l0003o000000;o00005ooo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo013ooooo000looooo`03o`000?oooooo
oooo08Kooooo00?o0000oiFfk_nE]^h02?nE]^h00ol0003oT[keoi:nm@08oi:nm@03o`000?n?b?_o
SlSk00SoSlSk0ol0000Kooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04?ooool0
03gooooo0_l00027ooooo`03o`000?nE]^koUKK^00SoUKK^00?o0000oi:nmOnB__D02?nB__D00ol0
003oSlSkoho8n`04oho8n`?o00007oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo
013ooooo000oooooo`03o`000?oooooooooo08Gooooo00?o0000oiFfk_nE]^h02?nE]^h00ol0003o
T[keoi:nm@08oi:nm@03o`000?n?b?_oSlSk00?o00008_ooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo013ooooo0010ooooo`03o`000?oooooooooo08Gooooo00?o0000oiFfk_nE]^h0
2?nE]^h00ol0003oT[keoi:nm@06oi:nm@Co00009_ooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo013ooooo0011ooooo`;o0000Q_ooool00ol0003oUKK^oiFfkP08oiFfkP03o`000?nB
__GoT[ke00Go0000:oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo013ooooo0010
ooooo`03o`000?oooooo000008Oooooo00?o0000oiFfk_nE]^h01onE]^h5o`0002oooooo00?o0000
ooooooooool0@oooool00ol0003oooooooooo`0@ooooo`00@oooool00ol0003oooooooooo`25oooo
o`03o`000?nE]^koUKK^00?oUKK^1?l0000dooooo`03o`000?oooooooooo04;ooooo00?o0000oooo
ooooool04?ooool004Cooooo00?o0000ooooooooool0QOooool00ol0003oUKK^o`000003o`0003So
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0@ooooo`00AOooool00ol0003ooooo
ooooo`25ooooo`;o0000??ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo013ooooo
0016ooooo`;o0000QOooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool04?ooool004Sooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool03oooool004Wooooo00?o0000oooo
ooooool0POooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool03oooool004[ooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool03oooool004[ooooo0_l00021ooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0?ooooo`00C?oo
ool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`0?ooooo`00COooool00ol0003oooooooooo`1mooooo`03o`000?oooooo
oooo047ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0?ooooo`00C_ooool00ol0
003oooooooooo`1looooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`0?ooooo`00Coooool2o`0007cooooo00?o0000ooooooooool0@_ooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo00oooooo001Aooooo`03o`000?oooooooooo07Wooooo
00?o0000ooooooooool0@oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00oooooo
001Booooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0A?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo00oooooo001Cooooo`03o`000?oooooooooo07Oooooo00?o0000
ooooooooool0AOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00oooooo001Doooo
o`?o0000M_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool03oooool005Cooooo0_l0001gooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`0>ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd02?ooool00ol0003oooooooooo`1doooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0>oooo
o`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Sooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool03_ooool003Sooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00Sooooo0_l0001cooooo`03o`000?oooooooooo04Wooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0>ooooo`00>?ooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool02oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
04[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0>ooooo`00>?ooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00=ooooo`03o`000?oooooo
oooo06oooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo00kooooo000hooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00kooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0COooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00kooooo000hooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`00013ooooo0_l0001^ooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0>ooooo`00Goooool00ol0003oooooooooo`1[oooo
o`03o`000?oooooooooo04oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0>oooo
o`00H?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0>ooooo`00HOooool2o`0006[ooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00gooooo001Sooooo`03o`000?oo
oooooooo06Oooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo00gooooo001Tooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0D_ooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00gooooo001Uooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00gooooo001Vooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0E?ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo00gooooo001Vooooo`?o0000I?ooool00ol0003ooooo
ooooo`1Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03Oooool006Sooooo00?o
0000ooooooooool0H_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool03Oooool006Wooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1G
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03Oooool006[ooooo0_l0001Qoooo
o`03o`000?oooooooooo05Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0=oooo
o`00K?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo05Sooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0=ooooo`00KOooool00ol0003oooooooooo`1Mooooo`03o`00
0?oooooooooo05Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0=ooooo`00K_oo
ool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0<ooooo`00Koooool00ol0003oooooooooo`1Kooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0<ooooo`00Koooool3o`00
05_ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
00cooooo001aooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0GOooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo00cooooo001booooo`03o`000?oooooooooo05Sooooo
00?o0000ooooooooool0GOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00cooooo
001cooooo`;o0000F?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool03?ooool007Gooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03?ooool007Kooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool03?ooool007Oooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`1Qooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool03?ooool007Sooooo0_l0001Cooooo`03o`00
0?oooooooooo06;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0<ooooo`00N?oo
ool2o`0005?ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo00cooooo001jooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0I?ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00cooooo001kooooo`03o`000?oooooooooo
04oooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
00_ooooo001looooo`;o0000Coooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool02oooool007kooooo00?o0000ooooooooool0C?ooool00ol0003ooooo
ooooo`1Vooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02oooool007oooooo00?o
0000ooooooooool0Boooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool02oooool0083ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1X
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool0087ooooo0ol00019oooo
o`03o`000?oooooooooo06Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0;oooo
o`00M_ooool4o`000003oa0@4?oooooooooo00Gooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`1Zooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool007Sooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo06_ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0;ooooo`00N?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0Joooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00_ooooo001hooooo`03o`000?oooooooooo00[ooooo0_l00016
ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;
ooooo`00G?ooool3o`000003oa0@4?oooooooooo01Kooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0;ooooo`00G_ooool00ol@413o^[Zjooooo`0Gooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool02_ooool005kooooo00?oV9RHoc8b<_ooool05oooool00ol0003ooooo
ooooo`0>ooooo`;o0000@_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool02_ooool005kooooo00?ogMgMo`000?nj^[X05Oooool00omEEEGoIVIVo`00
000@ooooo`;o0000@_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool02_ooool005kooooo00?oEEEEogMgMom4A4@0:_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0:
ooooo`00GOooool01OoMgMgo410@oooooolQ8B7ogMgM02[ooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool0
05gooooo00GoIVIVohN7QoooooooV9RHoeEEE@0[ooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo001Loooo
o`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool0:_ooool2o`0003gooooo00?o0000oooo
ooooool0Loooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo001Looooo`04
oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool0:oooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo07Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:oooo
o`00TOooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo07Gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0:ooooo`00TOooool2o`0003[ooooo00?o0000ooooooooool0
M_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo002Cooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo002Dooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0N?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo002Eooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Wooooo002Fooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0NOooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo002Gooooo`;o0000=?ooool00ol0003ooooo
ooooo`1jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool009Wooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02Oooool009Wooooo0ol0000aooooo`03o`000?oooooooooo07cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`09ooooo`00Voooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo07gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09oooo
o`00W?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo07kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`09ooooo`00WOooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`00W_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`09ooooo`00Woooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo083ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`00X?ooool2o`00
02_ooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Sooooo002Qooooo`;o0000:_ooool00ol0003oooooooooo`22ooooo`05o`000?oooooooooooooo
ool000002_ooool00:?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`23ooooo`04
o`000?ooooooooooo`0000[ooooo002Tooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0Q?ooool00ol0003oooooo`00000:ooooo`00YOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo08Gooooo0_l0000:ooooo`00Y_ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo08Cooooo0ol0000:ooooo`00Yoooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo083ooooo1?l0000=ooooo`00Z?ooool01?l0003oooooo`000?l0000Qooooo`03o`000?oooooo
oooo07cooooo1?l0000Aooooo`00S_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01_ooool2o`0002;ooooo00?o0000ooooooooool0N?ooool4
o`0001Gooooo002@ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1dooooo`Co00006Oooool0093o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0L?ooool4o`0001gooooo002@ooooo`03o`000?oooooooooo00kooooo
00?oMgMgoc8b<_ooool02Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo06gooooo
0ol0000Qooooo`00T?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
2oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo06Wooooo1?l0000Tooooo`00T?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`1Uooooo`Co0000:?ooool0093ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0?ooooo`?o00006_ooool00ol0003oooooooooo`1Qooooo`Co0000;?ooool0
08kooooo00?oEEEEofIVI_l000003Oooool4o`0000kooooo0_l0000Kooooo`03o`000?oooooooooo
05gooooo1?l0000`ooooo`00/_ooool2o`0001Wooooo00?o0000ooooooooool0FOooool4o`0003Co
oooo002dooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0EOooool4o`0003Sooooo
002eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0DOooool4o`0003cooooo002f
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0COooool4o`00043ooooo002goooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0BOooool4o`0004Cooooo002hooooo`;o
00004oooool00ol0003oooooooooo`15ooooo`Co0000B?ooool00;Wooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`11ooooo`Co0000C?ooool00;[ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0nooooo`?o0000D?ooool00;_ooooo0_l0000@ooooo`03o`000?oooooo
oooo03[ooooo1?l0001Cooooo`00_Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
03Kooooo1?l0001Gooooo`00__ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03;o
oooo1?l0001Kooooo`00_oooool2o`0000cooooo00?o0000ooooooooool0;_ooool4o`0005oooooo
002oooooo`;o00003?ooool00ol0003oooooooooo`0Zooooo`Co0000Hoooool00<7ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Vooooo`Co0000Ioooool00<;ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Rooooo`Co0000Joooool00<?ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Nooooo`Co0000Koooool00<Cooooo0_l00007ooooo`03o`00
0?oooooooooo01[ooooo1?l0001cooooo`00a_ooool3o`0000Cooooo00?o0000ooooooooool05_oo
ool4o`0007Oooooo0036ooooo`;o00001Oooool00ol0003oooooooooo`0Cooooo`?o0000Noooool0
0<Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`Co0000O_ooool00<Wo
oooo00Go0000ooooooooooooooooo`00000=ooooo`Co0000P_ooool00<[ooooo00Co0000oooooooo
oooo00002Oooool4o`0008Kooooo003;ooooo`03o`000?oooooo000000Gooooo1?l0002:ooooo`00
c?ooool7o`0008kooooo0032ooooo`Go00001_ooool2o`0009;ooooo0032ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@0V_ooool00<?ooooo00?oV9RHob4Q8Oo^k^h0Voooool00<Cooooo00?oV9RHob4Q
8Oo^k^h0V_ooool00<Gooooo00?oMgMgofIVI_ooool0VOooool00<Kooooo00?o0000ooooooooool0
V?ooool00<;ooooo00Go0000okZj^_ooooooV9RHoa0@402Jooooo`00`_ooool01OnHV9So410@o`00
0?lQ8B7oc<c<09[ooooo003oooooof;ooooo003oooooof;ooooo003oooooof;ooooo003oooooof;o
oooo003oooooof;ooooo003oooooof;ooooo003oooooof;ooooo003oooooof;ooooo003oooooof;o
oooo003oooooof;ooooo003oooooof;ooooo003oooooof;ooooo003oooooof;ooooo002Uooooo`?o
000000?o410@ooooooooool0]_ooool009?ooooo0_l0000;ooooo`03o`000?nj^[[ooooo00Cooooo
00?o410@okZj^_ooool01Oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zj
ooooo`2Iooooo`00Toooool00ol0003oooooooooo`0:ooooo`;o<S8b1Oooool00onHV9So<S8boooo
o`05ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8bV_ooool008Sooooo00Go410@
o`000?l0003o0000oa0@4006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo
00?oQhN7o`000?nj^[X01?ooool00ooMgMgo0000okZj^P05ooooo`03ohN7Qol0003o^[Zj00Cooooo
00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj
^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo06oooooo002:ooooo`03o`000?oooooooooo
00Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co
0000oa0@4004ooooo`03oeEEEOmgMgOoA4A400Gooooo00?oc<c<o`000?l@41001?ooool01Ol@413o
^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool00oooool00oo<c<co0000oa0@4005oooo
o`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool0L?ooool008[ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0[ooooo00GogMgMoa0@4?oooooo
8B4QomgMg@0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`00077ooooo002:ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h:oooo
o`05ofIVI_n7QhOooooooiRHV?mEEED02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00oooool6o`0000;ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0007;ooooo002:ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S89ooooo`03onk^k_l0003ok^k^00;ooooo
00?o0000omgMgOooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoo
oooo0000L_ooool008Oooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00Co410@o`000?l0003ooooo0_l0
00000ol@413oooooooooo`06ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003ooooooooo
o`09ooooo`03oa0@4?l0003o000000?o00002_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oMgMgolc<c?l00000L_ooool008Oooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
onk^k_m4A4Co000007;ooooo0027ooooo`Oo00001Oooool2o`00027ooooo00?o0000ooooooooool0
1Oooool2o`0000gooooo00?o0000ooooooooool02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00go
oooo00?oMgMgo`000?ooool0LOooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool0
0001\
\>"],
  ImageRangeCache->{{{0, 352.438}, {392.188, 0}} -> {-0.0365789, -0.0401404, \
0.00334761, 0.00334761}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11253 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.066106 1.21212 -1.11022e-16 1.21212 [
[.5 1.12503 -44 0 ]
[.5 1.12503 44 24.5 ]
[.03831 .17557 -5.85635 -9 ]
[.03831 .17557 .14365 0 ]
[.12814 .13981 -17.2021 -9 ]
[.12814 .13981 .79789 0 ]
[.22015 .10319 -16.8352 -9 ]
[.22015 .10319 1.16484 0 ]
[.31441 .06568 -16.4682 -9 ]
[.31441 .06568 1.53178 0 ]
[.411 .02725 -16.1013 -9 ]
[.411 .02725 1.89873 0 ]
[.51 -0.01213 -5.24477 -9 ]
[.51 -0.01213 .75523 0 ]
[.21792 .02683 -9.25094 -12 ]
[.21792 .02683 .74906 0 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[.1484 .76875 -18 -3.08128 ]
[.1484 .76875 0 5.91872 ]
[.29382 .89692 -6 -3.18183 ]
[.29382 .89692 0 5.81817 ]
[.42456 1.01215 -18 -3.26907 ]
[.42456 1.01215 0 5.73093 ]
[.54272 1.11629 -6 -3.34548 ]
[.54272 1.11629 0 5.65452 ]
[.22112 .91822 -10 -4.24244 ]
[.22112 .91822 0 7.75756 ]
[.03467 .19213 -6 -2.71522 ]
[.03467 .19213 0 6.28478 ]
[.02559 .27239 -18 -2.7611 ]
[.02559 .27239 0 6.2389 ]
[.01617 .35567 -18 -2.80881 ]
[.01617 .35567 0 6.19119 ]
[.00638 .44212 -18 -2.85847 ]
[.00638 .44212 0 6.14153 ]
[-0.00378 .53194 -18 -2.9102 ]
[-0.00378 .53194 0 6.0898 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 1.11253 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.12503 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
.04875 .18654 m
.0558 .18375 L
s
[(0)] .03467 .19213 1 -0.39662 Mshowa
.03972 .26693 m
.04679 .2642 L
s
[(0.2)] .02559 .27239 1 -0.38642 Mshowa
.03035 .35034 m
.03744 .34767 L
s
[(0.4)] .01617 .35567 1 -0.37582 Mshowa
.02062 .43693 m
.02774 .43433 L
s
[(0.6)] .00638 .44212 1 -0.36478 Mshowa
.01051 .52689 m
.01765 .52437 L
s
[(0.8)] -0.00378 .53194 1 -0.35329 Mshowa
0 .62042 m
.00717 .61797 L
s
[(1)] -0.01434 .62532 1 -0.3413 Mshowa
.125 Mabswid
.04653 .20636 m
.05076 .2047 L
s
.04428 .22637 m
.04851 .22471 L
s
.04201 .24656 m
.04625 .24491 L
s
.03741 .28749 m
.04165 .28587 L
s
.03508 .30825 m
.03933 .30663 L
s
.03272 .32919 m
.03698 .32759 L
s
.02795 .37168 m
.03221 .37009 L
s
.02553 .39322 m
.02979 .39164 L
s
.02309 .41497 m
.02735 .4134 L
s
.01813 .45909 m
.0224 .45755 L
s
.01561 .48147 m
.01989 .47994 L
s
.01307 .50407 m
.01736 .50255 L
s
.00792 .54993 m
.01221 .54843 L
s
.00531 .5732 m
.0096 .5717 L
s
.00267 .59669 m
.00696 .59521 L
s
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
.5561 .7194 m
.04875 .18654 L
s
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.5561 .7194 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
0 0 m
1 0 L
1 1.11253 L
0 1.11253 L
closepath
clip
newpath
.5 Mabswid
.608 .72 .924 r
.52593 .68772 .5561 .7194 .58394 .7109 .55403 .68293 Metetra
.604 .746 .945 r
.55403 .68293 .58394 .7109 .61197 .70234 .58238 .6779 Metetra
.6 .773 .962 r
.58238 .6779 .61197 .70234 .64019 .69372 .61096 .67244 Metetra
.599 .799 .976 r
.61096 .67244 .64019 .69372 .66861 .68504 .63977 .66638 Metetra
.601 .823 .985 r
.63977 .66638 .66861 .68504 .69723 .6763 .6688 .65956 Metetra
.608 .843 .988 r
.6688 .65956 .69723 .6763 .72605 .6675 .69804 .65188 Metetra
.62 .857 .988 r
.69804 .65188 .72605 .6675 .75507 .65863 .72747 .64326 Metetra
.637 .866 .985 r
.72747 .64326 .75507 .65863 .7843 .6497 .75708 .63367 Metetra
.657 .868 .979 r
.75708 .63367 .7843 .6497 .81374 .64071 .78685 .62314 Metetra
.677 .862 .97 r
.78685 .62314 .81374 .64071 .84339 .63166 .81678 .61172 Metetra
.694 .849 .957 r
.81678 .61172 .84339 .63166 .87325 .62254 .84685 .59951 Metetra
.706 .83 .941 r
.84685 .59951 .87325 .62254 .90333 .61335 .87706 .58667 Metetra
.712 .806 .923 r
.87706 .58667 .90333 .61335 .93362 .6041 .90742 .57337 Metetra
.713 .78 .905 r
.90742 .57337 .93362 .6041 .96413 .59478 .93794 .55978 Metetra
.539 .694 .94 r
.49498 .6552 .52593 .68772 .55403 .68293 .5233 .65398 Metetra
.532 .718 .958 r
.5233 .65398 .55403 .68293 .58238 .6779 .55191 .65234 Metetra
.532 .745 .973 r
.55191 .65234 .58238 .6779 .61096 .67244 .58081 .64992 Metetra
.54 .773 .984 r
.58081 .64992 .61096 .67244 .63977 .66638 .60998 .64638 Metetra
.557 .802 .99 r
.60998 .64638 .63977 .66638 .6688 .65956 .63941 .64142 Metetra
.583 .828 .991 r
.63941 .64142 .6688 .65956 .69804 .65188 .66905 .63482 Metetra
.615 .848 .987 r
.66905 .63482 .69804 .65188 .72747 .64326 .69889 .62643 Metetra
.651 .862 .98 r
.69889 .62643 .72747 .64326 .75708 .63367 .72889 .61617 Metetra
.684 .867 .968 r
.72889 .61617 .75708 .63367 .78685 .62314 .75901 .60412 Metetra
.712 .864 .954 r
.75901 .60412 .78685 .62314 .81678 .61172 .78924 .59038 Metetra
.733 .852 .937 r
.78924 .59038 .81678 .61172 .84685 .59951 .81956 .57517 Metetra
.746 .834 .919 r
.81956 .57517 .84685 .59951 .87706 .58667 .84996 .55877 Metetra
.751 .813 .901 r
.84996 .55877 .87706 .58667 .90742 .57337 .88045 .54153 Metetra
.751 .789 .884 r
.88045 .54153 .90742 .57337 .93794 .55978 .91103 .52381 Metetra
.461 .66 .947 r
.4632 .62183 .49498 .6552 .5233 .65398 .4917 .62382 Metetra
.455 .682 .962 r
.4917 .62382 .5233 .65398 .55191 .65234 .52054 .62525 Metetra
.461 .709 .975 r
.52054 .62525 .55191 .65234 .58081 .64992 .54972 .6256 Metetra
.483 .742 .985 r
.54972 .6256 .58081 .64992 .60998 .64638 .57921 .62435 Metetra
.519 .776 .99 r
.57921 .62435 .60998 .64638 .63941 .64142 .609 .62107 Metetra
.565 .809 .99 r
.609 .62107 .63941 .64142 .66905 .63482 .63903 .61543 Metetra
.615 .835 .984 r
.63903 .61543 .66905 .63482 .69889 .62643 .66926 .60722 Metetra
.664 .852 .972 r
.66926 .60722 .69889 .62643 .72889 .61617 .69965 .59633 Metetra
.706 .859 .955 r
.69965 .59633 .72889 .61617 .75901 .60412 .73015 .58283 Metetra
.739 .856 .935 r
.73015 .58283 .75901 .60412 .78924 .59038 .76072 .56693 Metetra
.761 .846 .915 r
.76072 .56693 .78924 .59038 .81956 .57517 .79134 .54892 Metetra
.774 .831 .896 r
.79134 .54892 .81956 .57517 .84996 .55877 .82198 .52923 Metetra
.78 .813 .879 r
.82198 .52923 .84996 .55877 .88045 .54153 .85265 .50836 Metetra
.779 .793 .864 r
.85265 .50836 .88045 .54153 .91103 .52381 .88337 .48685 Metetra
.384 .623 .947 r
.43058 .58756 .4632 .62183 .4917 .62382 .45921 .59224 Metetra
.382 .642 .958 r
.45921 .59224 .4917 .62382 .52054 .62525 .48824 .59624 Metetra
.399 .671 .97 r
.48824 .59624 .52054 .62525 .54972 .6256 .51765 .5989 Metetra
.438 .708 .98 r
.51765 .5989 .54972 .6256 .57921 .62435 .54743 .59957 Metetra
.492 .749 .986 r
.54743 .59957 .57921 .62435 .609 .62107 .57754 .59768 Metetra
.556 .787 .985 r
.57754 .59768 .609 .62107 .63903 .61543 .60794 .59282 Metetra
.619 .816 .976 r
.60794 .59282 .63903 .61543 .66926 .60722 .63856 .58472 Metetra
.676 .835 .96 r
.63856 .58472 .66926 .60722 .69965 .59633 .66934 .57323 Metetra
.722 .843 .939 r
.66934 .57323 .69965 .59633 .73015 .58283 .70023 .55846 Metetra
.756 .842 .916 r
.70023 .55846 .73015 .58283 .76072 .56693 .73117 .54065 Metetra
.779 .835 .895 r
.73117 .54065 .76072 .56693 .79134 .54892 .76212 .5202 Metetra
.793 .823 .876 r
.76212 .5202 .79134 .54892 .82198 .52923 .79306 .49764 Metetra
.798 .809 .86 r
.79306 .49764 .82198 .52923 .85265 .50836 .82399 .47363 Metetra
.798 .793 .848 r
.82399 .47363 .85265 .50836 .88337 .48685 .85493 .44884 Metetra
.319 .589 .941 r
.39706 .55236 .43058 .58756 .45921 .59224 .42581 .55903 Metetra
.325 .607 .95 r
.42581 .55903 .45921 .59224 .48824 .59624 .455 .56495 Metetra
.355 .638 .961 r
.455 .56495 .48824 .59624 .51765 .5989 .48461 .56933 Metetra
.409 .679 .972 r
.48461 .56933 .51765 .5989 .54743 .59957 .51464 .57141 Metetra
.479 .724 .978 r
.51464 .57141 .54743 .59957 .57754 .59768 .54505 .57053 Metetra
.553 .764 .976 r
.54505 .57053 .57754 .59768 .60794 .59282 .57578 .56621 Metetra
.624 .794 .964 r
.57578 .56621 .60794 .59282 .63856 .58472 .60676 .55812 Metetra
.684 .814 .945 r
.60676 .55812 .63856 .58472 .66934 .57323 .63793 .54609 Metetra
.731 .822 .922 r
.63793 .54609 .66934 .57323 .70023 .55846 .66922 .53026 Metetra
.765 .824 .898 r
.66922 .53026 .70023 .55846 .73117 .54065 .70055 .5109 Metetra
.788 .819 .877 r
.70055 .5109 .73117 .54065 .76212 .5202 .73188 .48848 Metetra
.802 .812 .859 r
.73188 .48848 .76212 .5202 .79306 .49764 .76318 .46363 Metetra
.809 .802 .845 r
.76318 .46363 .79306 .49764 .82399 .47363 .79444 .43713 Metetra
.81 .791 .835 r
.79444 .43713 .82399 .47363 .85493 .44884 .82567 .40974 Metetra
.275 .564 .934 r
.36263 .5162 .39706 .55236 .42581 .55903 .39148 .52405 Metetra
.291 .583 .942 r
.39148 .52405 .42581 .55903 .455 .56495 .4208 .5311 Metetra
.334 .616 .953 r
.4208 .5311 .455 .56495 .48461 .56933 .4506 .53649 Metetra
.4 .658 .963 r
.4506 .53649 .48461 .56933 .51464 .57141 .48085 .53938 Metetra
.478 .702 .967 r
.48085 .53938 .51464 .57141 .54505 .57053 .51152 .53905 Metetra
.557 .741 .962 r
.51152 .53905 .54505 .57053 .57578 .56621 .54255 .53497 Metetra
.628 .77 .948 r
.54255 .53497 .57578 .56621 .60676 .55812 .57388 .52678 Metetra
.688 .789 .927 r
.57388 .52678 .60676 .55812 .63793 .54609 .60543 .51429 Metetra
.734 .799 .904 r
.60543 .51429 .63793 .54609 .66922 .53026 .63711 .49765 Metetra
.767 .803 .882 r
.63711 .49765 .66922 .53026 .70055 .5109 .66885 .47718 Metetra
.79 .802 .862 r
.66885 .47718 .70055 .5109 .73188 .48848 .70059 .45337 Metetra
.805 .799 .846 r
.70059 .45337 .73188 .48848 .76318 .46363 .7323 .42692 Metetra
.813 .794 .834 r
.7323 .42692 .76318 .46363 .79444 .43713 .76396 .39869 Metetra
.816 .788 .826 r
.76396 .39869 .79444 .43713 .82567 .40974 .79557 .36951 Metetra
.259 .555 .931 r
.32723 .47902 .36263 .5162 .39148 .52405 .3562 .48717 Metetra
.286 .574 .938 r
.3562 .48717 .39148 .52405 .4208 .5311 .38566 .49448 Metetra
.338 .605 .947 r
.38566 .49448 .4208 .5311 .4506 .53649 .41562 .5001 Metetra
.409 .645 .954 r
.41562 .5001 .4506 .53649 .48085 .53938 .44607 .50312 Metetra
.488 .685 .954 r
.44607 .50312 .48085 .53938 .51152 .53905 .47698 .50283 Metetra
.564 .719 .946 r
.47698 .50283 .51152 .53905 .54255 .53497 .5083 .49865 Metetra
.632 .746 .93 r
.5083 .49865 .54255 .53497 .57388 .52678 .53995 .49023 Metetra
.688 .764 .91 r
.53995 .49023 .57388 .52678 .60543 .51429 .57186 .47737 Metetra
.731 .775 .888 r
.57186 .47737 .60543 .51429 .63711 .49765 .60393 .46022 Metetra
.763 .782 .868 r
.60393 .46022 .63711 .49765 .66885 .47718 .63608 .43911 Metetra
.787 .785 .851 r
.63608 .43911 .66885 .47718 .70059 .45337 .66826 .41456 Metetra
.803 .786 .837 r
.66826 .41456 .70059 .45337 .7323 .42692 .70041 .38729 Metetra
.812 .785 .827 r
.70041 .38729 .7323 .42692 .76396 .39869 .73252 .35817 Metetra
.816 .784 .822 r
.73252 .35817 .76396 .39869 .79557 .36951 .76458 .32809 Metetra
.275 .564 .934 r
.29083 .44079 .32723 .47902 .3562 .48717 .31995 .44828 Metetra
.309 .58 .938 r
.31995 .44828 .3562 .48717 .38566 .49448 .34957 .45495 Metetra
.364 .607 .942 r
.34957 .45495 .38566 .49448 .41562 .5001 .3797 .45995 Metetra
.433 .64 .943 r
.3797 .45995 .41562 .5001 .44607 .50312 .41035 .4624 Metetra
.506 .672 .939 r
.41035 .4624 .44607 .50312 .47698 .50283 .44149 .46159 Metetra
.575 .7 .927 r
.44149 .46159 .47698 .50283 .5083 .49865 .47307 .45697 Metetra
.635 .723 .911 r
.47307 .45697 .5083 .49865 .53995 .49023 .50502 .44819 Metetra
.685 .74 .892 r
.50502 .44819 .53995 .49023 .57186 .47737 .53726 .43505 Metetra
.725 .752 .874 r
.53726 .43505 .57186 .47737 .60393 .46022 .5697 .4177 Metetra
.755 .761 .857 r
.5697 .4177 .60393 .46022 .63608 .43911 .60226 .39646 Metetra
.779 .767 .843 r
.60226 .39646 .63608 .43911 .66826 .41456 .63488 .37185 Metetra
.795 .772 .832 r
.63488 .37185 .66826 .41456 .70041 .38729 .6675 .34457 Metetra
.806 .776 .825 r
.6675 .34457 .70041 .38729 .73252 .35817 .70009 .31548 Metetra
.812 .779 .822 r
.70009 .31548 .73252 .35817 .76458 .32809 .73265 .28543 Metetra
.319 .589 .941 r
.25338 .40146 .29083 .44079 .31995 .44828 .28271 .40737 Metetra
.355 .599 .939 r
.28271 .40737 .31995 .44828 .34957 .45495 .31252 .4125 Metetra
.406 .618 .937 r
.31252 .4125 .34957 .45495 .3797 .45995 .34286 .41605 Metetra
.467 .641 .932 r
.34286 .41605 .3797 .45995 .41035 .4624 .37372 .41723 Metetra
.529 .664 .922 r
.37372 .41723 .41035 .4624 .44149 .46159 .40509 .41537 Metetra
.587 .685 .909 r
.40509 .41537 .44149 .46159 .47307 .45697 .43691 .40996 Metetra
.637 .703 .893 r
.43691 .40996 .47307 .45697 .50502 .44819 .46913 .40068 Metetra
.681 .718 .877 r
.46913 .40068 .50502 .44819 .53726 .43505 .50168 .38735 Metetra
.716 .73 .862 r
.50168 .38735 .53726 .43505 .5697 .4177 .53447 .37011 Metetra
.744 .74 .849 r
.53447 .37011 .5697 .4177 .60226 .39646 .56743 .34925 Metetra
.766 .75 .838 r
.56743 .34925 .60226 .39646 .63488 .37185 .60048 .32525 Metetra
.783 .758 .83 r
.60048 .32525 .63488 .37185 .6675 .34457 .63357 .29876 Metetra
.795 .766 .826 r
.63357 .29876 .6675 .34457 .70009 .31548 .66666 .27057 Metetra
.802 .773 .826 r
.66666 .27057 .70009 .31548 .73265 .28543 .69976 .24147 Metetra
.384 .623 .947 r
.21484 .36098 .25338 .40146 .28271 .40737 .24445 .36443 Metetra
.416 .626 .939 r
.24445 .36443 .28271 .40737 .31252 .4125 .27453 .36717 Metetra
.459 .634 .93 r
.27453 .36717 .31252 .4125 .34286 .41605 .30511 .36852 Metetra
.507 .646 .919 r
.30511 .36852 .34286 .41605 .37372 .41723 .33621 .36777 Metetra
.555 .66 .906 r
.33621 .36777 .37372 .41723 .40509 .41537 .3678 .36435 Metetra
.6 .673 .892 r
.3678 .36435 .40509 .41537 .43691 .40996 .39987 .35784 Metetra
.64 .686 .878 r
.39987 .35784 .43691 .40996 .46913 .40068 .43235 .34794 Metetra
.675 .698 .864 r
.43235 .34794 .46913 .40068 .50168 .38735 .46518 .3345 Metetra
.705 .71 .852 r
.46518 .3345 .50168 .38735 .53447 .37011 .49829 .31765 Metetra
.73 .722 .843 r
.49829 .31765 .53447 .37011 .56743 .34925 .5316 .29764 Metetra
.75 .733 .836 r
.5316 .29764 .56743 .34925 .60048 .32525 .56506 .27487 Metetra
.767 .744 .832 r
.56506 .27487 .60048 .32525 .63357 .29876 .59861 .24991 Metetra
.779 .755 .831 r
.59861 .24991 .63357 .29876 .66666 .27057 .63221 .22344 Metetra
.788 .766 .833 r
.63221 .22344 .66666 .27057 .69976 .24147 .66586 .19616 Metetra
.461 .66 .947 r
.17516 .3193 .21484 .36098 .24445 .36443 .20514 .31952 Metetra
.485 .654 .934 r
.20514 .31952 .24445 .36443 .27453 .36717 .23556 .31913 Metetra
.515 .652 .92 r
.23556 .31913 .27453 .36717 .30511 .36852 .26645 .31758 Metetra
.548 .654 .905 r
.26645 .31758 .30511 .36852 .33621 .36777 .29783 .31434 Metetra
.581 .659 .89 r
.29783 .31434 .33621 .36777 .3678 .36435 .32968 .30893 Metetra
.613 .665 .877 r
.32968 .30893 .3678 .36435 .39987 .35784 .36199 .30102 Metetra
.642 .673 .864 r
.36199 .30102 .39987 .35784 .43235 .34794 .39471 .29039 Metetra
.669 .682 .854 r
.39471 .29039 .43235 .34794 .46518 .3345 .4278 .27692 Metetra
.692 .693 .846 r
.4278 .27692 .46518 .3345 .49829 .31765 .46118 .2607 Metetra
.713 .704 .84 r
.46118 .2607 .49829 .31765 .5316 .29764 .49482 .24193 Metetra
.731 .717 .837 r
.49482 .24193 .5316 .29764 .56506 .27487 .52864 .22094 Metetra
.746 .73 .837 r
.52864 .22094 .56506 .27487 .59861 .24991 .56262 .19816 Metetra
.758 .744 .839 r
.56262 .19816 .59861 .24991 .63221 .22344 .5967 .17414 Metetra
.767 .758 .844 r
.5967 .17414 .63221 .22344 .66586 .19616 .63089 .14942 Metetra
.539 .694 .94 r
.13429 .27638 .17516 .3193 .20514 .31952 .16475 .27272 Metetra
.552 .68 .923 r
.16475 .27272 .20514 .31952 .23556 .31913 .1956 .26859 Metetra
.569 .67 .907 r
.1956 .26859 .23556 .31913 .26645 .31758 .22688 .26361 Metetra
.588 .663 .891 r
.22688 .26361 .26645 .31758 .29783 .31434 .25859 .25741 Metetra
.607 .661 .876 r
.25859 .25741 .29783 .31434 .32968 .30893 .29073 .24966 Metetra
.626 .661 .864 r
.29073 .24966 .32968 .30893 .36199 .30102 .32329 .24014 Metetra
.645 .664 .854 r
.32329 .24014 .36199 .30102 .39471 .29039 .35625 .22869 Metetra
.663 .67 .846 r
.35625 .22869 .39471 .29039 .4278 .27692 .38956 .21523 Metetra
.679 .678 .842 r
.38956 .21523 .4278 .27692 .46118 .2607 .42319 .19983 Metetra
.695 .688 .84 r
.42319 .19983 .46118 .2607 .49482 .24193 .4571 .18262 Metetra
.709 .701 .84 r
.4571 .18262 .49482 .24193 .52864 .22094 .49124 .16382 Metetra
.721 .715 .844 r
.49124 .16382 .52864 .22094 .56262 .19816 .52559 .14373 Metetra
.732 .731 .85 r
.52559 .14373 .56262 .19816 .5967 .17414 .56011 .12273 Metetra
.74 .748 .858 r
.56011 .12273 .5967 .17414 .63089 .14942 .59481 .1012 Metetra
.608 .72 .924 r
.09217 .23214 .13429 .27638 .16475 .27272 .12323 .22415 Metetra
.612 .701 .908 r
.12323 .22415 .16475 .27272 .1956 .26859 .15462 .21586 Metetra
.618 .686 .891 r
.15462 .21586 .1956 .26859 .22688 .26361 .18636 .20707 Metetra
.625 .674 .877 r
.18636 .20707 .22688 .26361 .25859 .25741 .21847 .19759 Metetra
.632 .665 .864 r
.21847 .19759 .25859 .25741 .29073 .24966 .25094 .18727 Metetra
.64 .66 .854 r
.25094 .18727 .29073 .24966 .32329 .24014 .28377 .17598 Metetra
.648 .659 .846 r
.28377 .17598 .32329 .24014 .35625 .22869 .31696 .16364 Metetra
.657 .661 .842 r
.31696 .16364 .35625 .22869 .38956 .21523 .35048 .15023 Metetra
.666 .666 .841 r
.35048 .15023 .38956 .21523 .42319 .19983 .38431 .13576 Metetra
.675 .674 .842 r
.38431 .13576 .42319 .19983 .4571 .18262 .41844 .12031 Metetra
.683 .686 .846 r
.41844 .12031 .4571 .18262 .49124 .16382 .45284 .10398 Metetra
.692 .7 .853 r
.45284 .10398 .49124 .16382 .52559 .14373 .48751 .08693 Metetra
.699 .716 .862 r
.48751 .08693 .52559 .14373 .56011 .12273 .52241 .06935 Metetra
.706 .735 .873 r
.52241 .06935 .56011 .12273 .59481 .1012 .55756 .05142 Metetra
.666 .738 .904 r
.04875 .18654 .09217 .23214 .12323 .22415 .08051 .17394 Metetra
.663 .718 .889 r
.08051 .17394 .12323 .22415 .15462 .21586 .11254 .16124 Metetra
.66 .699 .875 r
.11254 .16124 .15462 .21586 .18636 .20707 .14483 .14843 Metetra
.658 .684 .863 r
.14483 .14843 .18636 .20707 .21847 .19759 .1774 .13551 Metetra
.655 .671 .853 r
.1774 .13551 .21847 .19759 .25094 .18727 .21025 .12249 Metetra
.653 .662 .846 r
.21025 .12249 .25094 .18727 .28377 .17598 .24339 .10934 Metetra
.652 .657 .842 r
.24339 .10934 .28377 .17598 .31696 .16364 .27681 .09609 Metetra
.651 .655 .84 r
.27681 .09609 .31696 .16364 .35048 .15023 .31052 .08272 Metetra
.652 .657 .842 r
.31052 .08272 .35048 .15023 .38431 .13576 .34452 .06923 Metetra
.653 .662 .846 r
.34452 .06923 .38431 .13576 .41844 .12031 .37882 .05563 Metetra
.655 .671 .853 r
.37882 .05563 .41844 .12031 .45284 .10398 .41342 .04191 Metetra
.658 .684 .863 r
.41342 .04191 .45284 .10398 .48751 .08693 .44833 .02806 Metetra
.66 .699 .875 r
.44833 .02806 .48751 .08693 .52241 .06935 .48355 .01409 Metetra
.663 .718 .889 r
.48355 .01409 .52241 .06935 .55756 .05142 .51908 0 Metetra
0 g
.25 Mabswid
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282.75, 314.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005Q0001RB000`400?l00000o`00003ooooooomR
ooooo`00oooooomRooooo`00oooooomRooooo`00^_ooool4o`000003oa0@4?oooooooooo0:3ooooo
002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002loooo
o`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`00
0?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002jooooo`03oeEEEOmVIVKo
00000:Cooooo003oooooof;ooooo003oooooof;ooooo001Mooooo`;o00000_ooool2o`000?kooooo
001Mooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgMo_ooool005kooooo00CogMgMo`000?l@413o
c<c<:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`07oooool2o`0009oooooo001Nooooo`04onk^k_lQ8B7o410@onk^kR[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01cooooo
0ol000000onY]n?o0000o`00002Nooooo`00G_ooool01?lQ8B7oMgMgogMgMolb<S8Zooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001[ooooo0ol00003ojVg
h`?o0000WOooool005gooooo0_l00002ooooo`;o0000:Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`?o00001_nY]n<00ol0003oZKOSo`00002M
ooooo`00S?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00Eooooo`?o00000_nY]n<00ol0003oZKOSojVgh`03ojVgh`04o`000?nY]n?oZKOSo`0009cooooo
002<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@01;o
oooo1?l0000:ojVgh`04o`000?nY]n?oZKOSo`0009cooooo002<ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000013ooooo1?l000000onX/]oo0000ojVgh`09
ojVgh`05o`000?nY]n?oZKOSojVghol00000Voooool008cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT03Oooool4o`000003ojRbgol0003oZ;;O00;oZ;;O
00?o0000ojVghonY]n<01onY]n<00ol0003oZKOSojVgh`02ojVgh`03o`000?oooooooooo09Sooooo
002/ooooo`Co00002?nX/]l00ol0003oZKOSojVgh`06ojVgh`03o`000?nY]n?oZKOS00?oZKOS00?o
0000ooooooooool0Uoooool00:Wooooo1?l0000;ojRbg`03o`000?nY]n?oZKOS00KoZKOS00?o0000
ojVghonY]n<00onY]n<00ol0003oooooooooo`2Gooooo`00Yoooool6o`0000coZ;;O00?o0000ojVg
honY]n<01OnY]n<00ol0003oZKOSojVgh`04ojVgh`03o`000?oooooooooo09Kooooo002Tooooo`Co
00001OnX[m`00ol0003oZ;;OojRbg`0:ojRbg`03o`000?nY]n?oZKOS00CoZKOS00?o0000ojVghonY
]n<01OnY]n<00ol0003oooooooooo`2Eooooo`00KOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`08?ooool3o`0000WoZ:oL00?o0000ojRb
gonX/]l02_nX/]l00ol0003oZKOSojVgh`03ojVgh`03o`000?nY]n?oZKOS00KoZKOS00?o0000oooo
ooooool0U?ooool006gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q01gooooo0ol000000onX[mco0000ojR_g009ojR_g003o`000?nX/]oo
Z;;O00[oZ;;O00?o0000ojVghonY]n<00onY]n<00ol0003oZKOSojVgh`06ojVgh`03o`000?oooooo
oooo09Cooooo001]ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000001_ooooo0ol000001OnWZm[o0000ojR_g?nX[mco000000[oZ:oL00?o0000ojRbgonX/]l0
2_nX/]l00ol0003oZKOSojVgh`02ojVgh`03o`000?nY]n?oZKOS00OoZKOS00?o0000ooooooooool0
Toooool006gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B406?ooool3o`0000GoYj_J00?o0000ojR_g?nX[m`02onX[m`00ol0003oZ;;OojRbg`0:ojRbg`05
o`000?nY]n?oZKOSojVghol000002_nY]n<00ol0003oooooooooo`2Booooo`00KOooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Eooooo`Co000000?oYj_J
o`000?nWZmX01OnWZmX00ol0003oZ:oLojR_g00:ojR_g003o`000?nX/]ooZ;;O00[oZ;;O00Go0000
ojVghonY]n?oZKOSo`00000:ojVgh`;o0000Toooool006gooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo01Gooooo0ol0000;ojN[fP03o`000?nX[mcoZ:oL00_oZ:oL00?o
0000ojRbgonX/]l02_nX/]l01?l0003oZKOSojVghol00008ojVgh`;o000000?o];cOo`000?ooool0
T_ooool006gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo
1?l0000=ojN[fP03o`000?nX[mcoZ:oL00_oZ:oL00?o0000ojRbgonX/]l02_nX/]l00ol0003oZKOS
o`000006ojVgh`;o00001?nd_=l00ol0003oooooooooo`2@ooooo`00KOooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@3oooool2o`0000;oYjWH00?o0000ojNYf?l0
00003?nWZmX00ol0003oZ:oLojR_g00;ojR_g003o`000?nX/]ooZ;;O00_oZ;;O0_l00005ojVgh`03
o`000?nd_=oo];cO00Go];cO00?o0000ooooooooool0Soooool008kooooo0ol00007ojNYf003o`00
0?nWZm[oYj_J00[oYj_J00?o0000ojR_g?nX[m`02onX[m`00ol0003oZ;;OojRbg`0:ojRbg`;o0000
0onY]n<2o`0000Wo];cO00?o0000ooooooooool0S_ooool008cooooo0ol00009ojNYf003o`000?nW
Zm[oYj_J00_oYj_J00?o0000ojR_g?nX[m`02onX[m`00ol0003oZ;;OojRbg`0:ojRbg`04o`000?nY
]n?o0000o`0000_o];cO0_l0002?ooooo`00ROooool4o`000003ojNYf?l0003oYjWH00WoYjWH00?o
0000ojN[f_nWZmX02_nWZmX00ol0003oZ:oLojR_g00;ojR_g003o`000?nX/]ooZ;;O00[oZ;;O0_l0
000>okBlg`03o`000?oooooooooo08gooooo001@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`0Pooooo`Co000000?oYZSGo`000?nWZMP02onW
ZMP00ol0003oYj_JojN[fP0;ojN[fP03o`000?nX[mcoZ:oL00_oZ:oL00?o0000ojRbgonX/]l01onX
/]l4o`0000oo];cO00?o0000ooooooooool0S?ooool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Nooooo`Co00001OnVZ=L00ol0003oYjWHojNY
f00:ojNYf003o`000?nWZm[oYj_J00_oYj_J00?o0000ojR_g?nX[m`02onX[m`00ol0003oZ;;OojRb
g`04ojRbg`;o00000_nb]m`00ol0003o/[OLo`00000?okBlg`03o`000?oooooooooo08_ooooo001@
ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0001gooooo0ol000000onVZ=Oo0000ojJX
e`06ojJXe`03o`000?nWZMSoYjWH00[oYjWH00?o0000ojN[f_nWZmX02_nWZmX00ol0003oZ:oLojR_
g00;ojR_g003o`000?nX/]ooZ;;O00;oZ;;O0_l00004ok:gg004o`000?nb]mco/[OLo`0000ko];cO
0_l0002<ooooo`00D?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo
00006oooool3o`0000GoYZSG00?o0000ojJXeonVZ=L01?nVZ=L00ol0003oYjWHojNYf00:ojNYf003
o`000?nWZm[oYj_J00_oYj_J00?o0000ojR_g?nX[m`02onX[m`01?l0003oZ;;Oo`000?l00006ok:g
g005o`000?nb]mco/[OLok:gg?l000003_nd_=l2o`0008_ooooo001@ooooo`05o`000?oooooooooo
ooooool000002oooool01?oMgMgoEEEEooooool0000Iooooo`?o000000?oYZOGo`000?nVZ=L03?nV
Z=L00ol0003oYjWHojNYf00:ojNYf003o`000?nWZm[oYj_J00_oYj_J00?o0000ojR_g?nX[m`02_nX
[m`2o`0000So/[OL00Go0000ok:gg?nb]mco/[OLo`00000?okBlg`03o`000?oooooooooo08Wooooo
001@ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Fooooo`?o0000
0_nVYmL01?l0003oYZOGojJWeol0000<ojJXe`03o`000?nWZMSoYjWH00[oYjWH00?o0000ojN[f_nW
ZmX02onWZmX00ol0003oZ:oLojR_g008ojR_g0;o000000?o/K?Jo`000?nb]m`01onb]m`00ol0003o
/[OLok:gg002ok:gg003o`000?nd_=oo];cO00go];cO00?o0000ooooooooool0R?ooool0053ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000001Cooooo0ol00007ojJWe`03
o`000?nVZ=OoYZSG00_oYZSG00?o0000ojNYf?nWZMP02_nWZMP00ol0003oYj_JojN[fP0;ojN[fP03
o`000?nX[mcoZ:oL00CoZ:oL0ol00004ok6cfP03o`000?nb]mco/[OL00Go/[OL00?o0000ok:gg?nb
]m`00onb]m`00ol0003o];cOokBlg`0<okBlg`;o0000ROooool0053ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo013ooooo0ol0000;ojJWe`03o`000?nVZ=OoYZSG00_o
YZSG00?o0000ojNYf?nWZMP02_nWZMP00ol0003oYj_JojN[fP0:ojN[fP03o`000?nX[mcoZ:oL00;o
Z:oL0_l00008ok6cfP03o`000?nb]mco/[OL00Co/[OL00?o0000ok:gg?nb]m`01?nb]m`00ol0003o
];cOokBlg`0<okBlg`;o0000R?ooool007?ooooo0ol000000onVZ=Oo0000o`00000;ojJWe`03o`00
0?nVZ=OoYZSG00[oYZSG00?o0000ojNYf?nWZMP02_nWZMP00ol0003oYj_JojN[fP0;ojN[fP04o`00
0?nX[mco0000o`0000[o/K?J00?o0000ok:gg?nb]m`01?nb]m`00ol0003o/[OLok:gg004ok:gg003
o`000?nd_=oo];cO00go];cO0_l00027ooooo`00L?ooool3o`0000GoYZSG00?o0000ojJWeonVYmL0
2OnVYmL00ol0003oYZSGojJXe`0;ojJXe`03o`000?nWZMSoYjWH00[oYjWH00?o0000ojN[f_nWZmX0
2_nWZmX2o`0000go/K?J00?o0000ok:gg?nb]m`00onb]m`00ol0003o/[OLok:gg005ok:gg003o`00
0?nd_=oo];cO00_o];cO00?o0000okfofol00000Qoooool006kooooo0ol00007ojJXe`03o`000?nV
YmOoYZOG00[oYZOG00?o0000ojJXeonVZ=L02_nVZ=L00ol0003oYjWHojNYf00:ojNYf003o`000?nW
Zm[oYj_J00SoYj_J0_l000000on^[mSo0000ok6cfP0<ok6cfP03o`000?nb]mco/[OL00?o/[OL00?o
0000ok:gg?nb]m`01_nb]m`00ol0003o];cOokBlg`08okBlg`;o00000_nm_m/2o`0008Kooooo000c
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000Sooooo`?o00000_nV
Z=L00ol0003oYZSGojJXe`06ojJXe`03o`000?nVYmOoYZOG00WoYZOG00?o0000ojJXeonVZ=L02onV
Z=L00ol0003oYjWHojNYf00:ojNYf003o`000?nWZm[oYj_J00CoYj_J0ol00004ojj_f003o`000?na
/m[o/K?J00_o/K?J00?o0000ok:gg?nb]m`00_nb]m`00ol0003o/[OLok:gg007ok:gg003o`000?nd
_=oo];cO00Go];cO0_l00005okfof`;o0000QOooool003?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4027ooooo0ol000000onWZMSo0000
ojJXe`0;ojJXe`03o`000?nVYmOoYZOG00WoYZOG00?o0000ojJXeonVZ=L02onVZ=L00ol0003oYjWH
ojNYf00:ojNYf004o`000?nWZm[oYj_JojN[fP;o00002?n^[mP00ol0003o/K?Jok6cfP0;ok6cfP05
o`000?nb]mco/[OLok:gg?l000002Onb]m`00ol0003o];cOokBlg`04okBlg`03o`000?nm_m_o_KoK
00Ko_KoK0_l00024ooooo`00<oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h07oooool4o`0000CoYjWH00?o0000ojJXeonVZ=L02OnVZ=L00ol0003oYZOGojJWe`09ojJW
e`03o`000?nVZ=OoYZSG00_oYZSG00?o0000ojNYf?nWZMP02_nWZMP01?l0003oYj_Jo`000?l0000:
ojj_f003o`000?na/m[o/K?J00_o/K?J00Go0000ok:gg?nb]mco/[OLo`00000:ok:gg004o`000?nd
_=oo];cOokBlg`;o00002_nm_m/00ol0003oooooooooo`22ooooo`00<oooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h06oooool3o`0000CoYjWH00Go0000ojNYf?nWZMSo
YjWHo`00000<ojJXe`03o`000?nVYmOoYZOG00WoYZOG00?o0000ojJXeonVZ=L02onVZ=L00ol0003o
YjWHojNYf009ojNYf0;o00003On^[mP00ol0003o/K?Jok6cfP0;ok6cfP04o`000?nb]mco/[OLo`00
00_o/[OL00?o0000okBlgol000003?nm_m/2o`0008?ooooo000cooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0Hooooo`?o00002onWZMP00ol0003oYZSGojJXe`09ojJX
e`03o`000?nVYmOoYZOG00[oYZOG00?o0000ojJXeonVZ=L02_nVZ=L00ol0003oYjWHojNYf007ojNY
f0;o000000?o[:cGo`000?n^[mP03?n^[mP00ol0003o/K?Jok6cfP0;ok6cfP04o`000?nb]mco/[OL
o`0000_o/[OL0_l0000>okfof`;o0000P_ooool003?ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo01Cooooo0ol000000onWZm[o0000ojNYf00<ojNYf003o`000?nVZ=Oo
YZSG00WoYZSG00?o0000ojJWeonVYmL02OnVYmL00ol0003oYZSGojJXe`0;ojJXe`03o`000?nWZMSo
YjWH00CoYjWH0_l00004ojb/e`03o`000?n^[mSo[ZoH00_o[ZoH00?o0000ok6cf_na/mX02ona/mX0
0ol0003o/[OLo`00000:ok:gg003o`000?nk^mWo000000oo_KoK0_l00021ooooo`00<oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Dooooo`?o00001?nW
ZmX00ol0003oYjWHojNYf00:ojNYf003o`000?nVZ=OoYZSG00WoYZSG00?o0000ojJWeonVYmL02_nV
YmL00ol0003oYZSGojJXe`0;ojJXe`04o`000?nWZMSoYjWHojNYf0;o00001on/[=L00ol0003o[ZoH
ojj_f00;ojj_f003o`000?na/m[o/K?J00_o/K?J0_l00008ok:gg0;o00000onk^mT00ol0003o_KoK
okfof`0=okfof`03o`000?oooooooooo07oooooo000cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<017ooooo0ol00008ojN[fP03o`000?nWZMSoYjWH00[o
YjWH00?o0000ojJXeonVZ=L02OnVZ=L00ol0003oYZOGojJWe`09ojJWe`03o`000?nVZ=OoYZSG00_o
YZSG00Co0000ojNYf?l0003o00002On/[=L00ol0003o[ZoHojj_f00;ojj_f003o`000?na/m[o/K?J
00_o/K?J0_l00006ok:gg0;o00001_nk^mT00ol0003o_KoKokfof`0<okfof`;o0000P?ooool005Oo
oooo0ol000000onWZm[o0000ojN[fP07ojN[fP03o`000?nWZMSoYjWH00[oYjWH00?o0000ojJXeonV
Z=L02_nVZ=L00ol0003oYZOGojJWe`09ojJWe`03o`000?nVZ=OoYZSG00[oYZSG0_l0000<ojb/e`03
o`000?n^[mSo[ZoH00_o[ZoH00?o0000ok6cf_na/mX02ona/mX00ol0003o/[OLok:gg003ok:gg003
o`000?nk^mWo^k_I00Ko^k_I00?o0000okfofonm_m/03Onm_m/2o`0007oooooo001Dooooo`?o0000
00?oZ:oLo`000?nWZmX02onWZmX00ol0003oYjWHojNYf00:ojNYf003o`000?nVZ=OoYZSG00WoYZSG
00?o0000ojJWeonVYmL02OnVYmL00ol0003oYZSGojJXe`08ojJXe`;o000000?oZZ[Go`000?n/[=L0
2on/[=L00ol0003o[ZoHojj_f00<ojj_f003o`000?na/m[o/K?J00[o/K?J00Co0000ok:gg?nb]mco
/[OL0_l0000:ok^kf@03o`000?nm_m_o_KoK00go_KoK00?o0000ooooooooool0OOooool005;ooooo
0ol00004ojR_g003o`000?nWZm[oYj_J00[oYj_J00?o0000ojNYf?nWZMP02OnWZMP00ol0003oYZSG
ojJXe`0:ojJXe`03o`000?nVYmOoYZOG00WoYZOG00?o0000ojJXeonVZ=L01?nVZ=L3o`0000CoZZ[G
00?o0000ojb/eon/[=L02_n/[=L00ol0003o[ZoHojj_f00;ojj_f003o`000?na/m[o/K?J00[o/K?J
0_l000000onb]mco0000ok^kf@0<ok^kf@03o`000?nm_m_o_KoK00go_KoK00?o0000ooooooooool0
O?ooool002Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Sooooo`Co000000?oZ:oLo`000?nX[m`0
1?nX[m`00ol0003oYj_JojN[fP09ojN[fP03o`000?nWZMSoYjWH00[oYjWH00?o0000ojJXeonVZ=L0
2OnVZ=L00ol0003oYZOGojJWe`0:ojJWe`04o`000?nVZ=OoYZSGojJXe`;o00002?nZZ]L00ol0003o
[:cGojb/e`0:ojb/e`03o`000?n^[mSo[ZoH00_o[ZoH00?o0000ok6cf_na/mX02Ona/mX3o`0000ko
^k_I00?o0000okfofonm_m/03Onm_m/2o`0007gooooo000Wooooo`05ogMgMonHV9SooooooiRHV?mg
MgL08Oooool3o`0000[oZ:oL00?o0000ojN[f_nWZmX02_nWZmX00ol0003oYjWHojNYf00:ojNYf003
o`000?nVZ=OoYZSG00WoYZSG00?o0000ojJWeonVYmL02OnVYmL01?l0003oYZSGo`000?l0000:ojZZ
e`03o`000?n/[=Oo[:cG00[o[:cG00?o0000ojj_f?n^[mP03?n^[mP00ol0003o/K?Jok6cfP07ok6c
fP;o000000?o^;OHo`000?nk^mT03_nk^mT00ol0003o_KoKokfof`0=okfof`;o0000O?ooool002Oo
oooo00Go410@oooooooooooooooooa0@400Nooooo`Go00003?nX[m`00ol0003oYj_JojN[fP0:ojN[
fP03o`000?nWZMSoYjWH00WoYjWH00?o0000ojJXeonVZ=L02OnVZ=L00ol0003oYZOGojJWe`09ojJW
e`;o00003OnZZ]L00ol0003o[:cGojb/e`0:ojb/e`03o`000?n^[mSo[ZoH00_o[ZoH00?o0000ok6c
f_na/mX01_na/mX00ol0003o^;OHo`000002okRgf003o`000?nk^mWo^k_I00go^k_I00?o0000okfo
fonm_m/02onm_m/00ol0003oa<;Ho`00001looooo`009oooool01Ol0003ooooooooooooooooo0000
01cooooo0ol00002ojRbg`03o`000?nX/]oo000000coZ:oL00?o0000ojN[f_nWZmX02OnWZmX00ol0
003oYjWHojNYf00:ojNYf003o`000?nVZ=OoYZSG00WoYZSG00?o0000ojJWeonVYmL01OnVYmL3o`00
0003ojRYeol0003oZZ[G00coZZ[G00?o0000ojb/eon/[=L02_n/[=L00ol0003o[ZoHojj_f00<ojj_
f003o`000?na/m[o/K?J00?o/K?J0_l00002okRgf005o`000?nh]mSo^;OHokRgf?l000003onk^mT0
0ol0003o_KoKokfof`09okfof`05o`000?o4`]Soa<;HolC2f?l00000Noooool002Oooooo00Go0000
ooooooooooooooooo`00000Iooooo`Co00001OnX/]l00ol0003oZ;;Oo`00000;ojR_g003o`000?nW
Zm[oYj_J00[oYj_J00?o0000ojNYf?nWZMP02OnWZMP00ol0003oYZSGojJXe`0:ojJXe`03o`000?nV
YmOoYZOG00;oYZOG0_l00005ojRYe`03o`000?nZZ]OoZZ[G00_oZZ[G00?o0000ojb/eon/[=L02_n/
[=L00ol0003o[ZoHojj_f00;ojj_f004o`000?na/m[o/K?Jok6cfP;o00001?nh]mP00ol0003o^;OH
okRgf002okRgf003o`000?nk^mWo^k_I00co^k_I00?o0000okfofonm_m/01onm_m/2o`0000Coa<;H
0_l0001jooooo`009oooool01Ol@413ooooooooooooooooo410@01Oooooo0ol0000;ojRbg`03o`00
0?nX[mcoZ:oL00WoZ:oL00?o0000ojN[f_nWZmX02OnWZmX00ol0003oYjWHojNYf00:ojNYf003o`00
0?nVZ=OoYZSG00WoYZSG00?o0000ojJWeol000000_l00008ojRYe`03o`000?nZZ]OoZZ[G00_oZZ[G
00?o0000ojb/eon/[=L02_n/[=L00ol0003o[ZoHojj_f00;ojj_f003o`000?na/m[o000000Ko^;OH
00?o0000okRgf?nh]mP00_nh]mP00ol0003o^k_Iok^kf@0=ok^kf@03o`000?nm_m_o_KoK00Go_KoK
00?o0000olC2f?o4`]P01Oo4`]P2o`0007Wooooo000Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
5?ooool5o`000003ojRbgol0003oZ;;O00WoZ;;O00?o0000ojR_g?nX[m`02_nX[m`00ol0003oYj_J
ojN[fP09ojN[fP03o`000?nWZMSoYjWH00WoYjWH00?o0000ojJXeonVZ=L02OnVZ=L2o`0000_oZ:WG
00?o0000ojZZeonZZ]L02onZZ]L00ol0003o[:cGojb/e`0:ojb/e`03o`000?n^[mSo[ZoH00_o[ZoH
0_l00007okRgf003o`000?nh]mSo^;OH00?o^;OH00?o0000ok^kfOnk^mT03Onk^mT00ol0003o_KoK
okfof`02okfof`;o00002Oo4`]P00ol0003oooooooooo`1gooooo`009oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^01;ooooo0ol00004ojVgh`03o`000?nX/]ooZ;;O00[oZ;;O00?o0000ojR_g?nX[m`0
2_nX[m`00ol0003oYj_JojN[fP09ojN[fP03o`000?nWZMSoYjWH00WoYjWH00?o0000ojJXeonVZ=L0
1OnVZ=L3o`000003ojFXf?l0003oZ:WG00_oZ:WG00?o0000ojZZeonZZ]L02onZZ]L00ol0003o[:cG
ojb/e`0:ojb/e`03o`000?n^[mSo[ZoH00So[ZoH0_l000000one/mOo0000okRgf006okRgf003o`00
0?nh]mSo^;OH00Co^;OH00?o0000ok^kfOnk^mT03?nk^mT01Ol0003o_KoKokfofonm_m_o000000co
a<;H00?o0000ooooooooool0M_ooool003_ooooo1Ol00006ojVgh`03o`000?nX/]ooZ;;O00[oZ;;O
00?o0000ojR_g?nX[m`02OnX[m`00ol0003oYj_JojN[fP09ojN[fP03o`000?nWZMSoYjWH00[oYjWH
00?o0000ojJXeonVZ=L00_nVZ=L2o`0000GoYJSH00?o0000ojRYeonXZML02_nXZML00ol0003oZZ[G
ojZZe`0:ojZZe`03o`000?n/[=Oo[:cG00[o[:cG00?o0000ojj_f?n^[mP01_n^[mP2o`0000Co]K?G
00?o0000okRgf?nh]mP01?nh]mP00ol0003o^;OHokRgf005okRgf003o`000?nk^mWo^k_I00co^k_I
00?o0000okfofol000003Oo4`]P2o`0007Oooooo000iooooo`?o00002onY]n<00ol0003oZ;;OojRb
g`09ojRbg`03o`000?nX[mcoZ:oL00[oZ:oL00?o0000ojN[f_nWZmX02OnWZmX00ol0003oYjWHojNY
f009ojNYf003o`000?nVZ=Oo000000;o00002?nUZ=P00ol0003oZ:WGojRYe`09ojRYe`03o`000?nZ
Z]OoZZ[G00_oZZ[G00?o0000ojb/eon/[=L02_n/[=L00ol0003o[ZoHojj_f004ojj_f003o`000?ne
/mOo]K?G00Go]K?G00?o0000okRgf?nh]mP00onh]mP00ol0003o^;OHokRgf005okRgf003o`000?nk
^mWo^k_I00co^k_I0_l0000?olC2f0;o0000M_ooool003Oooooo1?l0000<ojVgh`03o`000?nX/]oo
Z;;O00[oZ;;O00?o0000ojR_g?nX[m`02_nX[m`00ol0003oYj_JojN[fP09ojN[fP03o`000?nWZMSo
YjWH00OoYjWH0ol0000;ojFXf003o`000?nXZMOoZ:WG00[oZ:WG00?o0000ojZZeonZZ]L02onZZ]L0
0ol0003o[:cGojb/e`0:ojb/e`04o`000?n^[mSo[ZoHojj_f0;o00002?ne/mL00ol0003o^;OHokRg
f003okRgf003o`000?nh]mSo^;OH00Ko^;OH00?o0000ok^kfOnk^mT02_nk^mT00ol0003o`[kFo`00
000@olC2f003o`000?oooooooooo07Cooooo000dooooo`?o000000GoZ[cWo`000?nZ_>OoZ[cWo`00
000<ojVgh`03o`000?nX/]ooZ;;O00[oZ;;O00?o0000ojR_g?nX[m`02OnX[m`00ol0003oYj_JojN[
fP09ojN[fP03o`000?nWZMSoYjWH00CoYjWH0ol00002oj>XfP03o`000?nUZ=SoYJSH00[oYJSH00?o
0000ojRYeonXZML02_nXZML00ol0003oZZ[GojZZe`0:ojZZe`03o`000?n/[=Oo[:cG00[o[:cG00Co
0000ojj_f?l0003o00002one/mL00ol0003o^;OHokRgf002okRgf003o`000?nh]mSo^;OH00Oo^;OH
00?o0000ok^kfOnk^mT01onk^mT2o`0000?o`[kF00?o0000olC2f?o4`]P03_o4`]P00ol0003ooooo
ooooo`1cooooo`00<_ooool3o`0000OoZ[cW00?o0000ojVghonY]n<02_nY]n<00ol0003oZ;;OojRb
g`0:ojRbg`03o`000?nX[mcoZ:oL00WoZ:oL00?o0000ojN[f_nWZmX02OnWZmX00ol0003oYjWHojNY
f003o`0000KoXjSJ00?o0000ojFXf?nUZ=P02OnUZ=P00ol0003oZ:WGojRYe`0:ojRYe`03o`000?nZ
Z]OoZZ[G00_oZZ[G00?o0000ojb/eon/[=L02On/[=L2o`0000ko]K?G00Go0000okRgf?nh]mSo^;OH
o`00000:okRgf003o`000?nk^mWo^k_I00Go^k_I00?o0000ol:ne_o2_]H01?o2_]H00ol0003oa<;H
olC2f00=olC2f0;o0000M?ooool0037ooooo00?o0000ojZlionZ_>L02OnZ_>L00ol0003oZKOSojVg
h`0:ojVgh`03o`000?nX/]ooZ;;O00WoZ;;O00?o0000ojR_g?nX[m`02_nX[m`00ol0003oYj_JojN[
fP07ojN[fPCo00002_nSZ=X00ol0003oYJSHojFXf009ojFXf003o`000?nXZMOoZ:WG00[oZ:WG00?o
0000ojZZeonZZ]L02_nZZ]L00ol0003o[:cGojb/e`07ojb/e`;o000000?o/K3Go`000?ne/mL03One
/mL01Ol0003o^;OHokRgf?nh]mSo000000[o^;OH00?o0000ok^kfOnk^mT01?nk^mT00ol0003o`[kF
ol:neP06ol:neP03o`000?o4`]Soa<;H00goa<;H00?o0000ooooooooool0L_ooool0037ooooo0_l0
000;ojZli`03o`000?nY]n?oZKOS00[oZKOS00?o0000ojRbgonX/]l02OnX/]l00ol0003oZ:oLojR_
g009ojR_g003o`000?nWZm[oYj_J00CoYj_J0ol00002oj6Zg@03o`000?nSZ=[oXjSJ00WoXjSJ00?o
0000ojFXf?nUZ=P02_nUZ=P00ol0003oZ:WGojRYe`09ojRYe`03o`000?nZZ]OoZZ[G00_oZZ[G00?o
0000ojb/eon/[=L01?n/[=L2o`0000Co/K3G00?o0000okFceone/mL03?ne/mL01?l0003o^;OHokRg
f?l0000;okRgf004o`000?nk^mWo^k_Iok^kf@;o00002Oo2_]H00ol0003oa<;HolC2f00>olC2f003
o`000?oooooooooo077ooooo000Uooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool2o`0000co
Z[cW00?o0000ojVghonY]n<02OnY]n<00ol0003oZ;;OojRbg`0:ojRbg`03o`000?nX[mcoZ:oL00Wo
Z:oL00?o0000ojN[f_nWZmX00ol00006oj6Zg@03o`000?nSZ=[oXjSJ00WoXjSJ00?o0000ojFXf?nU
Z=P02OnUZ=P00ol0003oZ:WGojRYe`0:ojRYe`03o`000?nZZ]OoZZ[G00_oZZ[G00Co0000ojb/eon/
[=Oo[:cG0_l00007ok6`e`03o`000?ne/mOo]K?G00co]K?G00?o0000okRgf?l000003?nh]mP00ol0
003o^k_Io`00000<ol:neP03o`000?o4`]Soa<;H00koa<;H00?o0000ooooooooool0L?ooool002Go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03o`000?oooooo000000coZ[cW00?o0000ojVg
honY]n<02OnY]n<00ol0003oZ;;OojRbg`09ojRbg`03o`000?nX[mcoZ:oL00SoZ:oL1?l0000:oj6Z
g@03o`000?nSZ=[oXjSJ00SoXjSJ00?o0000ojFXf?nUZ=P02_nUZ=P00ol0003oZ:WGojRYe`0:ojRY
e`03o`000?nZZ]OoZZ[G00[oZZ[G00Co0000ojb/eol0003o00002Ona/=L00ol0003o]K?GokFce`0<
okFce`03o`000?nh]mSo000000co^;OH0_l0000>ol:neP03o`000?o4`]Soa<;H00goa<;H0_l0001a
ooooo`009Oooool01Ol@413ooooooooooooooooo410@00Oooooo00Co0000oooooooooooo00003?nZ
_>L00ol0003oZKOSojVgh`09ojVgh`03o`000?nX/]ooZ;;O00WoZ;;O00?o0000ojR_g?nX[m`01?nX
[m`3o`0000;oWjcP00?o0000oj6ZgOnQZ]d02OnQZ]d00ol0003oXjSJoj>XfP09oj>XfP03o`000?nU
Z=SoYJSH00WoYJSH00?o0000ojRYeonXZML02_nXZML00ol0003oZZ[GojZZe`0:ojZZe`;o00003?na
/=L00ol0003o]K?GokFce`0<okFce`;o00002onh]mP00ol0003o_[[Fo`00000?ol:neP03o`000?o4
`]Soa<;H00_oa<;H00?o0000olW4eOl00000LOooool002Gooooo00Go0000ooooooooooooooooo`00
0006ooooo`;o00000oooool00ol0003oZ[cWojZli`09ojZli`03o`000?nY]n?oZKOS00[oZKOS00?o
0000ojRbgonX/]l02OnX/]l00ol0003oZ:oLojR_g003o`0000KoWjcP00?o0000oj6ZgOnQZ]d02OnQ
Z]d00ol0003oXjSJoj>XfP09oj>XfP03o`000?nUZ=SoYJSH00WoYJSH00?o0000ojRYeonXZML02_nX
ZML00ol0003oZZ[GojZZe`07ojZZe`;o000000?o[JgGo`000?na/=L03?na/=L00ol0003o]K?GokFc
e`0;okFce`;o00002Onh]mP2o`0000?o_[[F00?o0000ol:ne_o2_]H03?o2_]H00ol0003oa<;HolC2
f00:olC2f005o`000?o9a=GobLCEolW4eOl00000L?ooool002Gooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00?ooooo00?o0000ojZlionZ_>L02OnZ_>L00ol0003oZKOS
ojVgh`09ojVgh`03o`000?nX/]ooZ;;O00SoZ;;O1?l0000:oin/h003o`000?nQZ]goXJ[M00SoXJ[M
00?o0000oj>Xf_nSZ=X02OnSZ=X00ol0003oYJSHojFXf00:ojFXf003o`000?nXZMOoZ:WG00[oZ:WG
00?o0000ojZZeonZZ]L01?nZZ]L2o`0000Co[JgG00?o0000ok6`eona/=L02_na/=L00ol0003o]K?G
okFce`0<okFce`03o`000?nh]mSo^;OH00Go^;OH0_l00006okjjeP03o`000?o2_]Ko`[kF00co`[kF
00?o0000olC2f?o4`]P01oo4`]P2o`0000GobLCE00?o0000ooooooooool0KOooool002Gooooo00Go
410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo00?o0000ojZlionZ_>L0
2OnZ_>L00ol0003oZKOSojVgh`09ojVgh`03o`000?nX/]ooZ;;O00CoZ;;O0ol00002oij_i003o`00
0?nO[>3oWjcP00WoWjcP00?o0000oj6ZgOnQZ]d02OnQZ]d00ol0003oXjSJoj>XfP09oj>XfP03o`00
0?nUZ=SoYJSH00WoYJSH00?o0000ojRYeonXZML02_nXZML00ol0003oZZ[GojZZe`02ojZZe`;o0000
1on][ML00ol0003o/K3Gok6`e`0:ok6`e`03o`000?ne/mOo]K?G00_o]K?G0_l00005okRgf003o`00
0?nn^]Ko_[[F00Ko_[[F00?o0000ol:ne_o2_]H03Oo2_]H00ol0003oa<;HolC2f005olC2f003o`00
0?o9a=GobLCE00GobLCE0_l0001^ooooo`009Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01Oooool00ol0003oZ[cWojZli`09ojZli`03o`000?nY]n?oZKOS00WoZKOS
00?o0000ojRbgonX/]l00ol00006oij_i003o`000?nO[>3oWjcP00WoWjcP00?o0000oj6ZgOnQZ]d0
2OnQZ]d00ol0003oXjSJoj>XfP09oj>XfP03o`000?nUZ=SoYJSH00WoYJSH00?o0000ojRYeonXZML0
2_nXZML01?l0003oZZ[Go`000?l00009ojf]e`03o`000?na/=Oo/K3G00_o/K3G00?o0000okFceone
/mL02_ne/mL2o`0000?o^;OH0_l0000:okjjeP03o`000?o2_]Ko`[kF00co`[kF00?o0000olC2f?o4
`]P00oo4`]P2o`0000WobLCE00?o0000ooooooooool0K?ooool002Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP06ooooo`03o`000?oooooooooo00Kooooo00?o0000ojZlionZ_>L02OnZ_>L00ol0003o
ZKOSojVgh`07ojVgh`Co00002_nN[n@00ol0003oWjcPoin/h008oin/h003o`000?nQZ]goXJ[M00Wo
XJ[M00?o0000oj>Xf_nSZ=X02OnSZ=X00ol0003oYJSHojFXf009ojFXf003o`000?nXZMOoZ:WG00[o
Z:WG0_l0000<ojf]e`03o`000?na/=Oo/K3G00[o/K3G00?o0000okFceone/mL02_ne/mL01Ol0003o
]K?Go`000?nh]mSo000000go_[[F00?o0000ol:ne_o2_]H03?o2_]H01Ol0003oa<;HolC2f?o4`]So
000000cobLCE00?o0000ooooooooool0Joooool0033ooooo00?o0000ooooooooool01oooool00ol0
003oZ[cWojZli`09ojZli`04o`000?nY]n?oZKOSojVgh`Go00000_nL/nP00ol0003oWZoToij_i009
oij_i003o`000?nO[>3oWjcP00WoWjcP00?o0000oj6ZgOnQZ]d02OnQZ]d00ol0003oXjSJoj>XfP09
oj>XfP03o`000?nUZ=SoYJSH00WoYJSH00?o0000ojRYeonXZML01_nXZML3o`000003ojV[f?l0003o
[JgG00_o[JgG00?o0000ok6`eona/=L02ona/=L00ol0003o]K?GokFce`09okFce`04o`000?ne/mOo
0000o`0000ko_[[F00?o0000ol:ne_o2_]H03Oo2_]H00ol0003oa<;Ho`00000>olW4e@03o`000?oo
oooooooo06[ooooo000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ojZlionZ_>L02?nZ_>L4
o`0000SoW;?X00?o0000oij_i?nN[n@02OnN[n@00ol0003oWjcPoin/h009oin/h003o`000?nQZ]go
XJ[M00WoXJ[M00?o0000oj>Xf_nSZ=X02OnSZ=X00ol0003oYJSHojFXf009ojFXf003o`000?nXZMOo
Z:WG00;oZ:WG0ol00005ojV[f003o`000?n][MOo[JgG00[o[JgG00?o0000ok6`eona/=L02ona/=L0
0ol0003o]K?GokFce`08okFce`;o000000?o^kOFo`000?nn^]H03_nn^]H00ol0003o`[kFol:neP0<
ol:neP;o00003oo9a=D00ol0003oooooooooo`1Zooooo`00;oooool2o`0000_ooooo00?o0000ojZl
ionZ_>L01?nZ_>L3o`000003oi^hk?l0003oW;?X00[oW;?X00?o0000oij_i?nN[n@02OnN[n@00ol0
003oWjcPoin/h008oin/h003o`000?nQZ]goXJ[M00WoXJ[M00?o0000oj>Xf_nSZ=X02OnSZ=X00ol0
003oYJSHojFXf009ojFXf003o`000?nXZMOo000000;o00002?nYZmP00ol0003o[JgGojf]e`0;ojf]
e`03o`000?na/=Oo/K3G00[o/K3G00?o0000okFceone/mL01one/mL2o`0000?o^kOF00?o0000okjj
e_nn^]H03Onn^]H00ol0003o`[kFol:neP0:ol:neP03o`000?o7`MCo0000013obLCE00?o0000oooo
ooooool0JOooool0033ooooo00?o0000ooooooooool02_ooool00ol0003oZ[cWojZli`03o`0000Go
VkS/00?o0000oibcj?nL/nP02OnL/nP00ol0003oWZoToij_i008oij_i003o`000?nO[>3oWjcP00Wo
WjcP00?o0000oj6ZgOnQZ]d02OnQZ]d00ol0003oXjSJoj>XfP09oj>XfP03o`000?nUZ=SoYJSH00Oo
YJSH0ol0000<ojV[f003o`000?n][MOo[JgG00[o[JgG00?o0000ok6`eona/=L02ona/=L00ol0003o
]K?GokFce`05okFce`03o`000?nk]mKo000000Co^kOF00?o0000okjje_nn^]H03Onn^]H00ol0003o
`[kFol:neP08ol:neP05o`000?o7`MCoal7DolO1e?l000004?o9a=D00ol0003oooooooooo`1Xoooo
o`00;oooool00ol0003oooooooooo`0<ooooo`;o00002OnK^>`00ol0003oW;?Xoibcj009oibcj003
o`000?nN[nCoWZoT00SoWZoT00?o0000oin/h?nO[>002OnO[>000ol0003oXJ[Moj6Zg@09oj6Zg@03
o`000?nSZ=[oXjSJ00SoXjSJ00?o0000ojFXf?nUZ=P01?nUZ=P3o`0000;oYJWJ00?o0000ojV[f?nY
ZmP02onYZmP00ol0003o[JgGojf]e`0:ojf]e`03o`000?na/=Oo/K3G00_o/K3G00?o0000okFceone
/mL00one/mL01?l0003o^kOFok^ge_l00004ok^geP03o`000?nn^]Ko_[[F00go_[[F00?o0000ol:n
e_o2_]H01oo2_]H00ol0003oal7DolO1e003olO1e003o`000?o9a=GobLCE00kobLCE00?o0000oooo
ooooool0Ioooool002oooooo00?o0000ooooooooool03Oooool00ol0003oVkS/oi^hk008oi^hk003
o`000?nL/nSoW;?X00SoW;?X00?o0000oij_i?nN[n@02OnN[n@00ol0003oWjcPoin/h008oin/h003
o`000?nQZ]goXJ[M00WoXJ[M00?o0000oj>Xf_nSZ=X02OnSZ=X00ol0003oYJSHojFXf003o`0000Ko
YJWJ00?o0000ojV[f?nYZmP02_nYZmP00ol0003o[JgGojf]e`0;ojf]e`03o`000?na/=Oo/K3G00[o
/K3G00Co0000okFceone/mOo]K?G0_l00003ok^geP03o`000?nk]mKo^kOF00?o^kOF00?o0000okjj
e_nn^]H03Onn^]H00ol0003o`[kFol:neP04ol:neP;o00001oo7`M@00ol0003obLCEolW4e@0=olW4
e@03o`000?oooooooooo06Oooooo000_ooooo`03o`000?oooooooooo00kooooo00?o0000oi^hk?nK
^>`02?nK^>`00ol0003oW;?Xoibcj008oibcj003o`000?nN[nCoWZoT00SoWZoT00?o0000oin/h?nO
[>002OnO[>000ol0003oXJ[Moj6Zg@09oj6Zg@03o`000?nSZ=[oXjSJ00OoXjSJ1?l0000:ojFYfP03
o`000?nYZmSoZJ_H00[oZJ_H00?o0000ojf]eon][ML02_n][ML00ol0003o/K3Gok6`e`0;ok6`e`03
o`000?ne/mOo000000Go^kOF00?o0000ok^ge_nk]mH01?nk]mH00ol0003o_[[FokjjeP0=okjjeP03
o`000?o2_]Ko`[kF00;o`[kF00?o0000olO1e?o7`M@01oo7`M@00ol0003obLCEolW4e@0>olW4e@03
o`000?oooooooooo06Kooooo000_ooooo`03o`000?oooooooooo00oooooo00?o0000oi^hk?nK^>`0
2?nK^>`00ol0003oW;?Xoibcj008oibcj003o`000?nN[nCoWZoT00SoWZoT00?o0000oin/h?nO[>00
2OnO[>000ol0003oXJ[Moj6Zg@08oj6Zg@03o`000?nSZ=[oXjSJ00CoXjSJ0ol00002oj2Yg@03o`00
0?nUZM[oYJWJ00WoYJWJ00?o0000ojV[f?nYZmP02_nYZmP00ol0003o[JgGojf]e`0;ojf]e`03o`00
0?na/=Oo/K3G00[o/K3G0_l00006ok^geP03o`000?nk]mKo^kOF00Go^kOF00?o0000okjje_nn^]H0
3?nn^]H01Ol0003o`[kFol:ne_o2_]Ko000000_oal7D00?o0000olW4eOo9a=D03Oo9a=D2o`0006Oo
oooo000^ooooo`?o00004Oooool00ol0003oVkS/oi^hk008oi^hk003o`000?nL/nSoW;?X00SoW;?X
00?o0000oij_i?nN[n@02?nN[n@00ol0003oWjcPoin/h008oin/h003o`000?nQZ]goXJ[M00WoXJ[M
00?o0000oj>Xf_nSZ=X00ol00006oj2Yg@03o`000?nUZM[oYJWJ00WoYJWJ00?o0000ojV[f?nYZmP0
2_nYZmP00ol0003o[JgGojf]e`0;ojf]e`03o`000?na/=Oo/K3G00Oo/K3G0_l000000onf]=Oo0000
ok^geP05ok^geP03o`000?nk]mKo^kOF00Go^kOF00?o0000okjje_nn^]H03Onn^]H00ol0003o`[kF
o`00000=olO1e003o`000?o9a=GobLCE00_obLCE00Co0000olg5dol0003o0000I_ooool002oooooo
00?o0000ooooooooool04Oooool00ol0003oVkS/oi^hk008oi^hk003o`000?nL/nSoW;?X00SoW;?X
00?o0000oij_i?nN[n@01onN[n@00ol0003oWjcPoin/h009oin/h003o`000?nQZ]goXJ[M00OoXJ[M
1?l0000:oj2Yg@03o`000?nUZM[oYJWJ00SoYJWJ00?o0000ojV[f?nYZmP02onYZmP00ol0003o[JgG
ojf]e`0:ojf]e`03o`000?na/=Oo/K3G00Ko/K3G00?o0000okJdeonf]=L00_nf]=L00ol0003o^kOF
ok^geP03ok^geP03o`000?nk]mKo^kOF00Ko^kOF00?o0000okjje_nn^]H03?nn^]H2o`0000ooal7D
00?o0000olW4eOo9a=D02Oo9a=D01Ol0003ocLGColg5doo=aM?o000006Kooooo000_ooooo`03o`00
0?oooooooooo01;ooooo00?o0000oi^hk?nK^>`01onK^>`00ol0003oW;?Xoibcj009oibcj003o`00
0?nN[nCoWZoT00OoWZoT00?o0000oin/h?nO[>002?nO[>000ol0003oXJ[Moj6Zg@04oj6Zg@?o0000
0_nKZN000ol0003oX:WMoj2Yg@09oj2Yg@03o`000?nUZM[oYJWJ00WoYJWJ00?o0000ojV[f?nYZmP0
2_nYZmP00ol0003o[JgGojf]e`0;ojf]e`03o`000?na/=Oo/K3G00?o/K3G0_l00006okJde`03o`00
0?nk]mKo^kOF00;o^kOF00?o0000ok^ge_nk]mH01onk]mH00ol0003o_[[FokjjeP0:okjjeP03o`00
0?o4_]Co000000ooal7D00?o0000olW4eOo9a=D02?o9a=D00ol0003ocLGColg5d`03olg5d`03o`00
0?oooooooooo06?ooooo000_ooooo`03o`000?oooooooooo01?ooooo00?o0000oi^hk?nK^>`01onK
^>`00ol0003oW;?Xoibcj008oibcj003o`000?nN[nCoWZoT00SoWZoT00?o0000oin/h?nO[>002?nO
[>000ol0003oXJ[Moj6Zg@03o`0000KoVjWP00?o0000oj2YgOnPZMd02OnPZMd00ol0003oYJWJojFY
fP09ojFYfP03o`000?nYZmSoZJ_H00[oZJ_H00?o0000ojf]eon][ML02_n][ML01?l0003o/K3Gok6`
eona/=L2o`0000So][CG00?o0000ok^ge_nk]mH00_nk]mH00ol0003o^kOFok^geP07ok^geP03o`00
0?nn^]Ko_[[F00Wo_[[F00Go0000olBne?o4_]Coa;kDo`00000?olO1e003o`000?o9a=GobLCE00Ko
bLCE00?o0000olg5doo=aM<01Oo=aM<00ol0003oooooooooo`1Rooooo`00;oooool00ol0003ooooo
ooooo`0Cooooo`;o00002OnK^>`00ol0003oW;?Xoibcj008oibcj003o`000?nN[nCoWZoT00OoWZoT
00?o0000oin/h?nO[>001onO[>04o`0000[oVjWP00?o0000oj2YgOnPZMd02?nPZMd00ol0003oYJWJ
ojFYfP09ojFYfP03o`000?nYZmSoZJ_H00[oZJ_H00?o0000ojf]eon][ML02on][ML00ol0003o/K3G
o`00000;okJde`05o`000?nk]mKo^kOFok^ge_l000002_nk]mH00ol0003o_[[FokjjeP07okjjeP03
o`000?o4_]Coa;kD00?oa;kD00?o0000olO1e?o7`M@03Oo7`M@00ol0003obLCEolW4e@04olW4e@03
o`000?o=aM?ocLGC00KocLGC0_l0001Sooooo`00;_ooool00ol0003oooooooooo`0Eooooo`;o0000
2OnK^>`00ol0003oW;?Xoibcj008oibcj003o`000?nN[nCoWZoT00OoWZoT00Co0000oin/h?nO[>3o
WjcP1Ol00002oiJYi003o`000?nKZN3oVjWP00WoVjWP00?o0000oj2YgOnPZMd02OnPZMd00ol0003o
YJWJojFYfP09ojFYfP03o`000?nYZmSoZJ_H00[oZJ_H00?o0000ojf]eon][ML02_n][ML2o`0000go
][CG00Co0000ok^ge_nk]mKo00002onk]mH00ol0003o_[[FokjjeP04okjjeP;o00001oo4_]@00ol0
003oal7DolO1e00<olO1e003o`000?o9a=GobLCE00?obLCE00?o0000olg5doo=aM<02?o=aM<00ol0
003oooooooooo`1Qooooo`00;_ooool3o`0001Kooooo0_l00009oi^hk003o`000?nL/nSoW;?X00So
W;?X00?o0000oij_i?nN[n@00onN[n@7o`0000SoUZWT00?o0000oi^Yh?nKZN002OnKZN000ol0003o
X:WMoj2Yg@09oj2Yg@03o`000?nUZM[oYJWJ00WoYJWJ00?o0000ojV[f?nYZmP02OnYZmP00ol0003o
[JgGojf]e`08ojf]e`;o000000?o/K7Ho`000?nf]=L03?nf]=L01?l0003o^kOFok^ge_l0000<ok^g
eP03o`000?nn^]Ko_[[F00;o_[[F00?o0000olBne?o4_]@01oo4_]@00ol0003oal7DolO1e00=olO1
e005o`000?o9a=GobLCEolW4eOl000003?o=aM<00ol0003oooooooooo`1Pooooo`00;_ooool00ol0
003oooooooooo`0Gooooo`;o00002OnK^>`00ol0003oW;?Xoibcj003oibcj0[o00001?nAZnP00ol0
003oUZWToiJYi009oiJYi003o`000?nKZN3oVjWP00WoVjWP00?o0000oj2YgOnPZMd02?nPZMd00ol0
003oYJWJojFYfP09ojFYfP03o`000?nYZmSoZJ_H00[oZJ_H00?o0000ojf]eon][ML01?n][ML3o`00
00Co/K7H00?o0000okJdeonf]=L02onf]=L00ol0003o^kOFo`00000<ok^geP05o`000?nn^]Ko_[[F
okjje_l000002oo4_]@00ol0003oal7DolO1e00=olO1e003o`000?o9a=Go000000kocLGC00?o0000
ooooooooool0Goooool001;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Oooooo00?o0000ooooooooool06?ooool2o`0000GoVkS/2Ol00005ohf^k003o`000?nAZnSo
TJ_X00OoTJ_X00?o0000oiJYi?nFZN@02?nFZN@00ol0003oVjWPoi^Yh009oi^Yh003o`000?nPZMgo
X:WM00WoX:WM00?o0000ojFYf_nUZMX02OnUZMX00ol0003oZJ_HojV[f00:ojV[f004o`000?n][MOo
[JgGojf]e`;o00002?na/MP00ol0003o][CGokJde`0;okJde`;o00003Onk]mH00ol0003o_[[Fo`00
000=olBne003o`000?o7`MCoal7D00coal7D0_l0000@olg5d`03o`000?oooooooooo05kooooo000B
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A007ooooo`03o`000?oooooooooo01Wooooo1_l00004ohVal003o`000?n=[^coSJk/00SoSJk/
00?o0000oi6[j?nAZnP01onAZnP00ol0003oUZWToiJYi008oiJYi003o`000?nKZN3oVjWP00WoVjWP
00?o0000oj2YgOnPZMd02OnPZMd00ol0003oYJWJojFYfP09ojFYfP03o`000?nYZmSoZJ_H00WoZJ_H
00Co0000ojf]eol0003o00002_na/MP00ol0003o][CGokJde`0;okJde`;o00003Onk]mH2o`0000oo
a;kD00?o0000olO1e?o7`M@02_o7`M@00ol0003oblCCo`00000@olg5d`03o`000?oooooooooo05ko
oooo000Booooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP08ooooo`03
o`000?oooooooooo01[ooooo00?o0000ohVal?n9/O001on9/O000ol0003oSJk/ohf^k008ohf^k003
o`000?nAZnSoTJ_X00OoTJ_X00?o0000oiJYi?nFZN@02?nFZN@00ol0003oVjWPoi^Yh009oi^Yh003
o`000?nPZMgoX:WM00SoX:WM00?o0000ojFYf_nUZMX02OnUZMX00ol0003oZJ_HojV[f009ojV[f0;o
00003Ona/MP00ol0003o][CGokJde`0;okJde`03o`000?nk]mKo^kOF00[o^kOF00?o0000oknke_l0
00003oo4_]@00ol0003oal7DolO1e009olO1e005o`000?o;a=?oblCCol_4dol000004?o=aM<00ol0
003oooooooooo`1Mooooo`004_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q
8Oo^k^h01oooool00ol0003oooooooooo`0Kooooo`03o`000?n9/O3oRK7`00OoRK7`00?o0000ohf^
k?n=[^`02?n=[^`00ol0003oTJ_Xoi6[j007oi6[j003o`000?nFZNCoUZWT00SoUZWT00?o0000oi^Y
h?nKZN002?nKZN000ol0003oX:WMoj2Yg@09oj2Yg@03o`000?nUZM[oYJWJ00WoYJWJ00?o0000ojV[
f?nYZmP01OnYZmP3o`000003oj^^f_l0003o/K7H00go/K7H00?o0000okJdeonf]=L02_nf]=L00ol0
003o^kOFok^geP08ok^geP;o00000ono^mH00ol0003oa;kDolBne00=olBne003o`000?o7`MCoal7D
00Ooal7D00?o0000ol_4doo;a=<00oo;a=<00ol0003ocLGColg5d`0>olg5d`03o`000?oooooooooo
05cooooo000Booooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`06oooo
o`03o`000?oooooooooo01cooooo00?o0000ohVal?n9/O001on9/O000ol0003oSJk/ohf^k007ohf^
k003o`000?nAZnSoTJ_X00OoTJ_X00?o0000oiJYi?nFZN@02?nFZN@00ol0003oVjWPoi^Yh009oi^Y
h003o`000?nPZMgoX:WM00WoX:WM00?o0000ojFYf_nUZMX02?nUZMX00ol0003oZJ_HojV[f003ojV[
f0;o00001On[[]X00ol0003o/K7Hok6af00;ok6af003o`000?nf]=Oo][CG00[o][CG0_l00007ok^g
eP;o00001_no^mH00ol0003oa;kDolBne00=olBne003o`000?o7`MCoal7D00Coal7D0_l00007ol_4
d`03o`000?o=aM?ocLGC00gocLGC0_l0001Mooooo`004_ooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool01?ooool2o`0001oooooo00?o0000ohVal?n9/O001on9/O000ol0
003oSJk/ohf^k007ohf^k003o`000?nAZnSoTJ_X00OoTJ_X00?o0000oiJYi?nFZN@02?nFZN@00ol0
003oVjWPoi^Yh009oi^Yh003o`000?nPZMgoX:WM00SoX:WM00?o0000ojFYf_nUZMX02OnUZMX00ol0
003oZJ_Ho`000002o`0000SoZjkJ00?o0000ok6af?na/MP02ona/MP00ol0003o][CGokJde`09okJd
e`03o`000?nf]=Oo000000Go^kOF00?o0000oknke_no^mH01ono^mH00ol0003oa;kDolBne00<olBn
e003o`000?o7`MCoal7D00?oal7D00?o0000ol_4doo;a=<01oo;a=<00ol0003ocLGColg5d`0<olg5
d`03o`000?o?am;o000005gooooo000Booooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool07oooool00ol0003oRK7`ohVal007
ohVal003o`000?n=[^coSJk/00OoSJk/00?o0000oi6[j?nAZnP01onAZnP00ol0003oUZWToiJYi008
oiJYi003o`000?nKZN3oVjWP00SoVjWP00?o0000oj2YgOnPZMd02OnPZMd00ol0003oYJWJojFYfP07
ojFYfP?o00002on[[]X00ol0003o/K7Hok6af00<ok6af003o`000?nf]=Oo][CG00So][CG00?o0000
okJdeol000000onk]mH2o`0000[o_k_F00?o0000olBne?o4_]@03Oo4_]@01Ol0003oal7DolO1e?o7
`MCo000000_oblCC00?o0000olg5doo=aM<02_o=aM<01Ol0003oclOBolo7d_o?am;o000005cooooo
000Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool08?ooool00ol0003oRK7`ohVal007ohVal003o`000?n=[^coSJk/00Oo
SJk/00?o0000oi6[j?nAZnP01onAZnP00ol0003oUZWToiJYi007oiJYi003o`000?nKZN3oVjWP00Wo
VjWP00?o0000oj2YgOnPZMd02?nPZMd00ol0003oYJWJojFYfP04ojFYfP?o00000_nT[=d00ol0003o
ZjkJoj^^fP0:oj^^fP03o`000?na/MSo/K7H00_o/K7H00?o0000okJdeonf]=L02?nf]=L01_l0003o
][CGokJdeol0003o^kOFo`0000go_k_F00?o0000olBne?o4_]@03Oo4_]@00ol0003oal7Do`00000=
ol_4d`03o`000?o=aM?ocLGC00SocLGC00?o0000olo7d_o?am800oo?am800ol0003oooooooooo`1I
ooooo`00;Oooool00ol0003oooooooooo`0Qooooo`03o`000?n9/O3oRK7`00OoRK7`00?o0000ohf^
k?n=[^`01_n=[^`00ol0003oTJ_Xoi6[j008oi6[j003o`000?nFZNCoUZWT00OoUZWT00?o0000oi^Y
h?nKZN002OnKZN000ol0003oX:WMoj2Yg@08oj2Yg@03o`000?nUZM[oYJWJ00?o00001_nT[=d00ol0
003oZjkJoj^^fP0:oj^^fP03o`000?na/MSo/K7H00_o/K7H00?o0000okJdeonf]=L01onf]=L00ol0
003o][CGokJde`02o`0000oo_k_F00?o0000olBne?o4_]@03?o4_]@2o`0000ooblCC00?o0000olg5
doo=aM<01_o=aM<00ol0003oclOBolo7dP05olo7dP03o`000?oooooooooo05Sooooo000]ooooo`03
o`000?oooooooooo027ooooo00?o0000ohVal?n9/O001on9/O000ol0003oSJk/ohf^k007ohf^k003
o`000?nAZnSoTJ_X00SoTJ_X00?o0000oiJYi?nFZN@01onFZN@00ol0003oVjWPoi^Yh008oi^Yh003
o`000?nPZMgoX:WM00OoX:WM1?l0000:ojB/g@03o`000?n[[][oZjkJ00[oZjkJ00?o0000ok6af?na
/MP02_na/MP00ol0003o][CGokJde`07okJde`?o000000?o^[SGo`000?no^mH03ono^mH00ol0003o
a;kDolBne00:olBne003o`000?o8`]Co0000013oblCC00?o0000olg5doo=aM<01?o=aM<00ol0003o
clOBolo7dP06olo7dP03o`000?oooooooooo05Sooooo000]ooooo`03o`000?oooooooooo02;ooooo
00?o0000ohVal?n9/O001on9/O000ol0003oSJk/ohf^k007ohf^k003o`000?nAZnSoTJ_X00OoTJ_X
00?o0000oiJYi?nFZN@02?nFZN@00ol0003oVjWPoi^Yh008oi^Yh004o`000?nPZMgoX:WMoj2Yg@Go
00000_nLZ^000ol0003oY:cMojB/g@09ojB/g@03o`000?n[[][oZjkJ00[oZjkJ00?o0000ok6af?na
/MP02ona/MP00ol0003o][CGokJde`06okJde`03o`000?nj^=Oo^[SG00;o^[SG00?o0000oknke_no
^mH03Ono^mH00ol0003oa;kDolBne009olBne005o`000?o8`]Cob<;DolS2e?l000003oo;a=<00ol0
003ocLGColg5d`03olg5d`03o`000?o?am;oclOB00SoclOB00?o0000ooooooooool0Eoooool002co
oooo0ol0000Tooooo`03o`000?n9/O3oRK7`00OoRK7`00?o0000ohf^k?n=[^`01on=[^`00ol0003o
TJ_Xoi6[j007oi6[j003o`000?nFZNCoUZWT00OoUZWT00?o0000oi^Yh?nKZN001onKZN05o`0000So
W:[P00?o0000ojB/gOnT[=d02OnT[=d00ol0003oZjkJoj^^fP0:oj^^fP03o`000?na/MSo/K7H00_o
/K7H00?o0000okJdeonf]=L00onf]=L3o`0000Go^[SG00?o0000oknke_no^mH03Ono^mH00ol0003o
a;kDolBne007olBne003o`000?o8`]Cob<;D00?ob<;D00?o0000ol_4doo;a=<03Oo;a=<01Ol0003o
cLGColg5doo=aM?o000000coclOB00?o0000ooooooooool0E_ooool002gooooo00?o0000oooooooo
ool09?ooool00ol0003oRK7`ohVal007ohVal003o`000?n=[^coSJk/00KoSJk/00?o0000oi6[j?nA
ZnP02?nAZnP00ol0003oUZWToiJYi007oiJYi004o`000?nKZN3oVjWPoi^Yh0Go00000_nDZ><00ol0
003oW:[PoibZh009oibZh003o`000?nT[=goY:cM00WoY:cM00?o0000oj^^f_n[[]X02_n[[]X00ol0
003o/K7Hok6af00:ok6af004o`000?nf]=Oo][CGokJde`;o00000_nj^=L00ol0003o^[SGokZhe`03
okZhe`03o`000?no^mKo_k_F00ko_k_F00?o0000olBne?o4_]@01?o4_]@2o`0000Oob<;D00?o0000
ol_4doo;a=<03Oo;a=<00ol0003ocLGCo`00000>olo7dP03o`000?oooooooooo05Gooooo000]oooo
o`03o`000?oooooooooo02Gooooo00?o0000ohVal?n9/O001on9/O000ol0003oSJk/ohf^k006ohf^
k003o`000?nAZnSoTJ_X00SoTJ_X00?o0000oiJYi?nFZN@00onFZN@7o`0000SoU:SS00?o0000oibZ
h?nLZ^002?nLZ^000ol0003oY:cMojB/g@0:ojB/g@03o`000?n[[][oZjkJ00WoZjkJ00?o0000ok6a
f?na/MP02ona/MP00ol0003o][CGo`000004okZhe`03o`000?nj^=Oo^[SG00Co^[SG00?o0000oknk
e_no^mH03Ono^mH00ol0003oa;kDolBne003olBne003o`000?o8`]Cob<;D00Oob<;D00?o0000ol_4
doo;a=<03Oo;a=<2o`0000ooclOB0_l0001Fooooo`00;Oooool00ol0003oooooooooo`0Vooooo`03
o`000?n9/O3oRK7`00OoRK7`00?o0000ohf^k?n=[^`01_n=[^`00ol0003oTJ_Xoi6[j003oi6[j0[o
00001?n<YnL00ol0003oU:SSoiBXh`09oiBXh`03o`000?nLZ^3oW:[P00SoW:[P00?o0000ojB/gOnT
[=d02OnT[=d00ol0003oZjkJoj^^fP0:oj^^fP03o`000?na/MSo/K7H00[o/K7H0_l00005okZhe`03
o`000?nj^=Oo^[SG00Go^[SG00?o0000oknke_no^mH03Ono^mH01Ol0003oa;kDolBne?o4_]Co0000
00_ob<;D00?o0000ol_4doo;a=<02oo;a=<00ol0003oc/KCo`00000@olo7dP03o`000?oooooooooo
05Cooooo000/ooooo`03o`000?oooooooooo02Sooooo6?l00005oh>Vj`03o`000?n<YnOoS:OW00Oo
S:OW00?o0000oiBXhonDZ><02?nDZ><00ol0003oW:[PoibZh009oibZh003o`000?nT[=goY:cM00Wo
Y:cM00?o0000oj^^f_n[[]X02_n[[]X00ol0003o/K7Hok6af007ok6af0;o000000?o];GJo`000?nj
^=L01?nj^=L00ol0003o^[SGokZhe`05okZhe`03o`000?no^mKo_k_F00ko_k_F00?o0000olBne?l0
00003Oo8`]@00ol0003oblCCol_4d`09ol_4d`05o`000?o>a]?oc/KColk6dol000004?o?am800ol0
003oooooooooo`1Cooooo`00;?ooool00ol0003oooooooooo`0Yooooo`03o`000?mfZ?;oMZSb00Ko
MZSb00?o0000ogbWkomlYnl01_mlYnl00ol0003oPjK[oh>Vj`08oh>Vj`03o`000?n<YnOoS:OW00Oo
S:OW00?o0000oiBXhonDZ><02?nDZ><00ol0003oW:[PoibZh008oibZh003o`000?nT[=goY:cM00[o
Y:cM00?o0000oj^^f_n[[]X02_n[[]X00ol0003o/K7Hok6af004ok6af0;o00001?nd]MX00ol0003o
^[SGokZhe`02okZhe`03o`000?nj^=Oo^[SG00Ko^[SG00?o0000oknke_no^mH03Ono^mH2o`0000ko
b<;D00?o0000ol_4doo;a=<02?o;a=<00ol0003oc/KColk6d`03olk6d`03o`000?o?am;oclOB00ko
clOB00?o0000ooooooooool0D_ooool002cooooo0_l0000[ooooo`03o`000?mfZ?;oMZSb00KoMZSb
00?o0000ogbWkomlYnl01_mlYnl00ol0003oPjK[oh>Vj`08oh>Vj`03o`000?n<YnOoS:OW00KoS:OW
00?o0000oiBXhonDZ><02OnDZ><00ol0003oW:[PoibZh008oibZh003o`000?nT[=goY:cM00WoY:cM
00?o0000oj^^f_n[[]X02_n[[]X00ol0003o/K7Hok6af002ok6af0;o00001ond]MX01Ol0003o^[SG
okZheonj^=Oo000000Wo^[SG00?o0000oknke_no^mH02ono^mH00ol0003oa;oFo`00000?olS2e003
o`000?o;a=?oblCC00KoblCC00?o0000olk6doo>a]<01Oo>a]<00ol0003oclOBolo7dP0=olo7dP;o
0000Doooool002cooooo00?o0000ooooooooool0:oooool00ol0003oMZSbogJXlP06ogJXlP03o`00
0?mlYnooO:O_00KoO:O_00?o0000oh>Vjon3Y^/02?n3Y^/00ol0003oS:OWohbWi`06ohbWi`03o`00
0?nDZ>?oU:SS00SoU:SS00?o0000oibZh?nLZ^002OnLZ^000ol0003oY:cMojB/g@09ojB/g@03o`00
0?n[[][oZjkJ00[oZjkJ00Co0000ok6af?l0003o00002Ond]MX01Ol0003o^[SGokZheonj^=Oo0000
00[o^[SG00?o0000oknke_no^mH02Ono^mH01Ol0003oa;oFolBoe_o4_mKo000000oob<;D00?o0000
ol_4doo;a=<01?o;a=<00ol0003oc/KColk6d`06olk6d`03o`000?o?am;oclOB00goclOB0_l0001C
ooooo`00;?ooool00ol0003oooooooooo`0/ooooo`03o`000?mfZ?;oMZSb00KoMZSb00?o0000ogbW
komlYnl01_mlYnl00ol0003oPjK[oh>Vj`07oh>Vj`03o`000?n<YnOoS:OW00OoS:OW00?o0000oiBX
honDZ><02?nDZ><00ol0003oW:[PoibZh008oibZh003o`000?nT[=goY:cM00[oY:cM00?o0000oj^^
f_n[[]X02On[[]X2o`0000co];GJ00Co0000okZheonj^=Oo00002_nj^=L00ol0003o_k_FoknkeP07
oknkeP;o00001Oo4_mH00ol0003ob<;DolS2e00=olS2e003o`000?o;a=?oblCC00;oblCC00?o0000
olk6doo>a]<02?o>a]<00ol0003oclOBolo7dP0;olo7dP04o`000?o@b=;od<SBo`0005;ooooo000/
ooooo`03o`000?oooooooooo02gooooo00?o0000ogJXl_mfZ?801_mfZ?800ol0003oO:O_ogbWk`06
ogbWk`03o`000?n3Y^_oPjK[00OoPjK[00?o0000ohbWion<YnL01on<YnL00ol0003oU:SSoiBXh`08
oiBXh`03o`000?nLZ^3oW:[P00SoW:[P00?o0000ojB/gOnT[=d02_nT[=d00ol0003oZjkJoj^^fP05
oj^^fP?o000000?o[;;Mo`000?nd]MX03?nd]MX00ol0003o^[SGo`00000;okZhe`03o`000?no^mKo
_k_F00Go_k_F00?o0000olBoe_o4_mH01Oo4_mH00ol0003ob<;DolS2e00=olS2e005o`000?o;a=?o
blCCol_4dol000003?o>a]<00ol0003oclOBolo7dP09olo7dP03o`000?o@b=;od<SB00;od<SB00?o
0000ooooooooool0Coooool002cooooo00?o0000ooooooooool0;_ooool00ol0003oMZSbogJXlP06
ogJXlP03o`000?mlYnooO:O_00KoO:O_00?o0000oh>Vjon3Y^/01on3Y^/00ol0003oS:OWohbWi`06
ohbWi`03o`000?nDZ>?oU:SS00SoU:SS00?o0000oibZh?nLZ^002OnLZ^000ol0003oY:cMojB/g@09
ojB/g@03o`000?n[[][oZjkJ00?oZjkJ0_l00005ojbbg@03o`000?nd]M[o];GJ00[o];GJ00?o0000
okZheol000003?nj^=L00ol0003o_k_FoknkeP02oknkeP;o00002Oo4_mH00ol0003ob<;DolS2e00=
olS2e003o`000?o;a=?o000000goc/KC00?o0000olo7d_o?am802?o?am800ol0003od<SBom38dP03
om38dP;o0000D?ooool002cooooo00?o0000ooooooooool0;oooool00ol0003oMZSbogJXlP06ogJX
lP03o`000?mlYnooO:O_00KoO:O_00?o0000oh>Vjon3Y^/01on3Y^/00ol0003oS:OWohbWi`06ohbW
i`03o`000?nDZ>?oU:SS00SoU:SS00?o0000oibZh?nLZ^002?nLZ^000ol0003oY:cMojB/g@0:ojB/
g@03o`000?n[[][o000000;o00002?n//]d00ol0003o];GJokBefP0:okBefP;o00003?nj^=L01Ol0
003o_k_Foknke_no^mKo000000coa;oF00?o0000olS2e?o8`]@03?o8`]@2o`0000ooc/KC00?o0000
olo7d_o?am801_o?am800ol0003od<SBom38dP05om38dP03o`000?oooooooooo04kooooo000/oooo
o`;o0000<Oooool00ol0003oMZSbogJXlP05ogJXlP03o`000?mlYnooO:O_00KoO:O_00?o0000oh>V
jon3Y^/01on3Y^/00ol0003oS:OWohbWi`07ohbWi`03o`000?nDZ>?oU:SS00SoU:SS00?o0000oibZ
h?nLZ^002?nLZ^000ol0003oY:cMojB/g@09ojB/g@;o00002on//]d00ol0003o];GJokBefP0;okBe
fP03o`000?nj^=Oo^[SG00_o^[SG00?o0000oknke_l000003Oo4_mH00ol0003ob<;DolS2e00;olS2
e003o`000?o;aMCo0000013oc/KC00?o0000olo7d_o?am801?o?am800ol0003od<SBom38dP07om38
dP03o`000?oooooooooo04gooooo000[ooooo`03o`000?oooooooooo03;ooooo00?o0000ogJXl_mf
Z?801OmfZ?800ol0003oO:O_ogbWk`06ogbWk`03o`000?n3Y^_oPjK[00OoPjK[00?o0000ohbWion<
YnL01_n<YnL00ol0003oU:SSoiBXh`08oiBXh`03o`000?nLZ^3oW:[P00WoW:[P00?o0000ojB/gOnT
[=d01OnT[=d3o`000003oj>_h?l0003o[;;M00_o[;;M00?o0000okBef_nd]MX02_nd]MX2o`0000co
^[SG0_l0000?olBoeP03o`000?o8`]Cob<;D00Wob<;D00Go0000ol_5e?o;aMCoblGDo`00000@olk6
d`03o`000?o?am;oclOB00;oclOB00?o0000om38d_o@b=802Oo@b=800ol0003oooooooooo`1<oooo
o`00:oooool00ol0003oooooooooo`0cooooo`03o`000?mfZ?;oMZSb00GoMZSb00?o0000ogbWkoml
Ynl01_mlYnl00ol0003oPjK[oh>Vj`07oh>Vj`03o`000?n<YnOoS:OW00KoS:OW00?o0000oiBXhonD
Z><02?nDZ><00ol0003oW:[PoibZh008oibZh003o`000?nT[=goY:cM00?oY:cM0_l00005oj>_h003
o`000?n//]go[;;M00[o[;;M00?o0000okBef_nd]MX02Ond]MX2o`0000[o^[SG0_l000000onn_MWo
0000olBoeP0?olBoeP03o`000?o8`]Cob<;D00Oob<;D00?o0000ol_5e?o;aM@00oo;aM@00ol0003o
c/KColk6d`0=olk6d`05o`000?o?am;oclOBolo7d_l000003?o@b=82o`0004gooooo000@ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04oooo
o`03o`000?oooooooooo03Cooooo00?o0000ogJXl_mfZ?801OmfZ?800ol0003oO:O_ogbWk`06ogbW
k`03o`000?n3Y^_oPjK[00OoPjK[00?o0000ohbWion<YnL01_n<YnL00ol0003oU:SSoiBXh`08oiBX
h`03o`000?nLZ^3oW:[P00SoW:[P00?o0000ojB/gOl000000_l00008oj>_h003o`000?n//]go[;;M
00Wo[;;M00?o0000okBef_nd]MX02Ond]MX00ol0003o];GJo`000008okZhe`03o`000?nn_MWo_[gI
00;o_[gI00?o0000olBoe_o4_mH03Oo4_mH00ol0003ob<;DolS2e006olS2e003o`000?o;aMCoblGD
00GoblGD00?o0000olk6doo>a]<03Oo>a]<00ol0003oclOBo`00000>om38dP;o0000C?ooool0013o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo03Gooooo00?o0000ogJXl_mfZ?801OmfZ?800ol0003oO:O_ogbWk`06ogbW
k`03o`000?n3Y^_oPjK[00KoPjK[00?o0000ohbWion<YnL01on<YnL00ol0003oU:SSoiBXh`07oiBX
h`03o`000?nLZ^3oW:[P00OoW:[P0ol0000;oj>_h003o`000?n//]go[;;M00[o[;;M00?o0000okBe
f_nd]MX02?nd]MX01?l0003o];GJokBef_l00005okZhe`;o00001_nn_MT00ol0003oa;oFolBoeP0=
olBoeP03o`000?o8`]Cob<;D00Cob<;D00?o0000ol_5e?o;aM@01_o;aM@00ol0003oc/KColk6d`0=
olk6d`;o00004?o@b=800ol0003oooooooooo`1:ooooo`004?ooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo03Kooooo1_l00002ogJXlP03o`000?mlYnoo
O:O_00KoO:O_00?o0000oh>Vjon3Y^/01_n3Y^/00ol0003oS:OWohbWi`06ohbWi`03o`000?nDZ>?o
U:SS00SoU:SS00Co0000oibZh?nLZ^3oW:[P1Ol00002oiV/i003o`000?nS[n3oXjoP00[oXjoP00?o
0000ojbbgOn//]d02_n//]d00ol0003o];GJokBefP07okBefP04o`000?nd]M[o];GJo`0000?o^[SG
0_l00009okjmf@03o`000?o4_mKoa;oF00goa;oF00?o0000olS2e?o8`]@00_o8`]@00ol0003oblGD
ol_5e008ol_5e003o`000?o>a]?oc/KC00_oc/KC00?o0000olo8dol000004Oo@b=800ol0003ooooo
ooooo`19ooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo
00001oooool00ol0003oooooooooo`0gooooo`03o`000?mRWo;oHYob00;oHYob4_l00003oh>Vj`03
o`000?n<YnOoS:OW00KoS:OW00?o0000oiBXhonDZ><00onDZ><8o`0000SoVJcT00?o0000oj>_h?nS
[n002_nS[n000ol0003o[;;Mojbbg@09ojbbg@03o`000?nd]M[o];GJ00Oo];GJ00Oo0000okBef_nd
]M[o];GJo`000?nj^=Oo000000co_[gI00?o0000olBoe_o4_mH03?o4_mH01Ol0003ob<;DolS2e?o8
`]Co000000coblGD00?o0000olk6doo>a]<02Oo>a]<01Ol0003oclSColo8doo?b=?o0000013od<SB
0_l0001:ooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`0hooooo`03o`000?mRWo;oHYob00CoHYob00?o0000ofZPl?mZ
X?001_mZX?000ol0003oMJ;^ogFRkP03ogFRkQ;o00001On>Z>L00ol0003oVJcToiV/i009oiV/i003
o`000?nS[n3oXjoP00WoXjoP00?o0000ojbbgOn//]d02_n//]d00ol0003o];GJokBefP06okBefP04
o`000?nd]M[o];GJokBefP;o00003Onn_MT00ol0003oa;oFolBoeP0=olBoeP03o`000?o8`]Co0000
00goblGD00?o0000olk6doo>a]<02?o>a]<00ol0003oclSColo8d`03olo8d`03o`000?o@b=;od<SB
00kod<SB0_l00019ooooo`004?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<
c?l000001_ooool2o`0003_ooooo00?o0000of:Ol_mRWo801?mRWo800ol0003oJZ3`ofZPl006ofZP
l003o`000?meX^koMJ;^00KoMJ;^00?o0000oh6Ujon1YN/01_n1YN/00ol0003oSZSWohjXi`08ohjX
i`03o`000?nI[>CoVJcT00SoVJcT00?o0000oj>_h?nS[n002_nS[n000ol0003o[;;Mojbbg@09ojbb
g@03o`000?nd]M[o];GJ00Ko];GJ00Ko0000okBef_l0003o0000okNjg?l0000>okjmf@03o`000?o4
_mKoa;oF00coa;oF0_l0000?ol_5e003o`000?o>a]?oc/KC00Koc/KC00?o0000olo8doo?b=<01Oo?
b=<00ol0003od<SBom38dP0<om38dP03o`000?o@bM?o000004Wooooo000@ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03[ooooo00?o
0000of:Ol_mRWo801?mRWo800ol0003oJZ3`ofZPl006ofZPl003o`000?meX^koMJ;^00KoMJ;^00?o
0000oh6Ujon1YN/01_n1YN/00ol0003oSZSWohjXi`08ohjXi`03o`000?nI[>CoVJcT00SoVJcT00?o
0000oj>_h?nS[n002_nS[n000ol0003o[;;Mojbbg@09ojbbg@03o`000?nd]M[o];GJ00Go];GJ0_l0
0004okNjg003o`000?nn_MWo_[gI00co_[gI00?o0000olBoe_o4_mH02_o4_mH00ol0003oalCGo`00
000@ol_5e003o`000?o>a]?oc/KC00Coc/KC00?o0000olo8doo?b=<01oo?b=<00ol0003od<SBom38
dP0:om38dP05o`000?o@bM?od<WCom39dol00000B?ooool0013ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0??ooool00ol0003oHYob
of:OlP04of:OlP03o`000?mZX?3oJZ3`00KoJZ3`00?o0000ogFRk_meX^h01_meX^h00ol0003oPJG[
oh6Uj`06oh6Uj`03o`000?n>Z>OoSZSW00SoSZSW00?o0000oiV/i?nI[>@02?nI[>@00ol0003oXjoP
oj>_h009oj>_h003o`000?n//]go[;;M00[o[;;M00?o0000okBef_nd]MX00ond]MX2o`0000Ko]k[L
00?o0000okjmfOnn_MT03?nn_MT00ol0003oa;oFolBoeP07olBoeP;o00000oo7a=L00ol0003oblGD
ol_5e00>ol_5e003o`000?o>a]?oc/KC00;oc/KC00?o0000olo8doo?b=<02Oo?b=<00ol0003od<SB
om38dP08om38dP03o`000?o@bM?od<WC00;od<WC0_l00017ooooo`00:_ooool00ol0003ooooooooo
o`0mooooo`03o`000?mRWo;oHYob00CoHYob00?o0000ofZPl?mZX?001_mZX?000ol0003oMJ;^ogFR
kP06ogFRkP03o`000?n1YN_oPJG[00KoPJG[00?o0000ohjXion>Z>L01on>Z>L00ol0003oVJcToiV/
i008oiV/i003o`000?nS[n3oXjoP00[oXjoP00?o0000ojbbgOn//]d02On//]d01?l0003o];GJokBe
f_nd]MX2o`000003okNjg?l0003o]k[L00Ko]k[L00?o0000okjmfOnn_MT02onn_MT00ol0003oa;oF
olBoeP06olBoeP03o`000?o7a=OoalCG00CoalCG00?o0000ol_5e?o;aM@03Oo;aM@01Ol0003oc/KC
olk6doo>a]?o000000coclSC00?o0000om38d_o@b=801oo@b=800ol0003od<WCom39d`04om39d`03
o`000?oooooooooo04Gooooo000Zooooo`03o`000?oooooooooo03kooooo00?o0000of:Ol_mRWo80
1?mRWo800ol0003oJZ3`ofZPl006ofZPl003o`000?meX^koMJ;^00KoMJ;^00?o0000oh6Ujon1YN/0
1_n1YN/00ol0003oSZSWohjXi`07ohjXi`03o`000?nI[>CoVJcT00SoVJcT00?o0000oj>_h?nS[n00
2OnS[n000ol0003o[;;Mojbbg@0:ojbbg@03o`000?nd]M[o000000?o]k[L00?o0000okNjg?ng^]`0
1Ong^]`00ol0003o_[gIokjmf@0<okjmf@03o`000?o4_mKoa;oF00Coa;oF00?o0000olO4eoo7a=L0
1_o7a=L00ol0003oblGDol_5e00=ol_5e003o`000?o>a]?o000000koclSC00?o0000om38d_o@b=80
1Oo@b=800ol0003od<WCom39d`06om39d`03o`000?oooooooooo04Cooooo000Zooooo`03o`000?oo
oooooooo03oooooo00?o0000of:Ol_mRWo801?mRWo800ol0003oJZ3`ofZPl006ofZPl003o`000?me
X^koMJ;^00GoMJ;^00?o0000oh6Ujon1YN/01_n1YN/00ol0003oSZSWohjXi`08ohjXi`03o`000?nI
[>CoVJcT00SoVJcT00?o0000oj>_h?nS[n002OnS[n000ol0003o[;;Mojbbg@09ojbbg@;o00001?ng
^]`00ol0003o]k[LokNjg006okNjg003o`000?nn_MWo_[gI00co_[gI00Co0000olBoe_o4_mKoa;oF
0_l00009olO4e`03o`000?o;aMCoblGD00goblGD0_l0000@olo8d`03o`000?o@b=;od<SB00?od<SB
00?o0000om39doo@bM<02?o@bM<00ol0003oooooooooo`13ooooo`00:Oooool3o`00043ooooo0_l0
0006of:OlP03o`000?mZX?3oJZ3`00GoJZ3`00?o0000ogFRk_meX^h01_meX^h00ol0003oPJG[oh6U
j`06oh6Uj`03o`000?n>Z>OoSZSW00SoSZSW00?o0000oiV/i?nI[>@02?nI[>@00ol0003oXjoPoj>_
h009oj>_h003o`000?n//]go[;;M00Go[;;M0ol000000on^]n3o0000okNjg003okNjg003o`000?ng
^]co]k[L00Oo]k[L00?o0000okjmfOnn_MT03?nn_MT00ol0003oa;oFo`00000<olO4e`03o`000?o;
aMCoblGD00_oblGD00?o0000olg9e_l000004Oo?b=<01Ol0003od<SBom38d_o@b=;o000000_od<WC
0_l00014ooooo`00:_ooool00ol0003oooooooooo`10ooooo`;o00001_mRWo800ol0003oJZ3`ofZP
l005ofZPl003o`000?meX^koMJ;^00KoMJ;^00?o0000oh6Ujon1YN/01_n1YN/00ol0003oSZSWohjX
i`07ohjXi`03o`000?nI[>CoVJcT00SoVJcT00?o0000oj>_h?nS[n002OnS[n000ol0003o[;;Mojbb
g@03ojbbg@;o00001On^]n001Ol0003o]k[LokNjg?ng^]co000000[o]k[L00?o0000okjmfOnn_MT0
2onn_MT2o`0000koalCG00?o0000ol_5e?o;aM@02Oo;aM@01Ol0003ocLWFolg9e_o=bMKo0000017o
clSC00?o0000om38d_l000003Oo@bM<00ol0003oooooooooo`12ooooo`00:_ooool00ol0003ooooo
ooooo`11ooooo`;o00001_mRWo800ol0003oJZ3`ofZPl005ofZPl003o`000?meX^koMJ;^00KoMJ;^
00?o0000oh6Ujon1YN/01_n1YN/00ol0003oSZSWohjXi`07ohjXi`03o`000?nI[>CoVJcT00SoVJcT
00?o0000oj>_h?nS[n002OnS[n000ol0003o[;;Mo`000002o`0000So[[OP00Co0000okNjg?ng^]co
00002_ng^]`00ol0003o_[gIokjmf@0:okjmf@03o`000?o1`]_o000000ooalCG00?o0000ol_5e?o;
aM@01oo;aM@00ol0003ocLWFolg9eP03olg9eP03o`000?o?b=?oclSC00koclSC0_l0000?om39d`03
o`000?oooooooooo047ooooo000Zooooo`03o`000?oooooooooo04;ooooo1?l00004of:OlP03o`00
0?mZX?3oJZ3`00GoJZ3`00?o0000ogFRk_meX^h01OmeX^h00ol0003oPJG[oh6Uj`07oh6Uj`03o`00
0?n>Z>OoSZSW00OoSZSW00?o0000oiV/i?nI[>@02?nI[>@00ol0003oXjoPoj>_h007oj>_h0?o0000
3?n^]n000ol0003o]k[Lo`00000;okNjg003o`000?nn_MWo_[gI00Oo_[gI0_l00003ol72f`03o`00
0?o7a=OoalCG00goalCG00?o0000ol_5e?o;aM@01?o;aM@2o`0000OocLWF00?o0000olo8doo?b=<0
3?o?b=<00ol0003od<_Eo`00000@om39d`03o`000?oooooooooo043ooooo000Yooooo`03o`000?oo
oooooooo04Cooooo00?o0000oe6Fl?mAU_001_l00007ofZPl003o`000?meX^koMJ;^00GoMJ;^00?o
0000oh6Ujon1YN/01_n1YN/00ol0003oSZSWohjXi`07ohjXi`03o`000?nI[>CoVJcT00SoVJcT00?o
0000oj>_h?nS[n001?nS[n03o`0000;oXk?T00?o0000ojjgh?n^]n002on^]n02o`0000co]k[L00?o
0000okjmfOnn_MT01Onn_MT00ol0003o`L;Kol72f`04ol72f`03o`000?o7a=OoalCG00coalCG00?o
0000ol_5e?o;aM@00oo;aM@00ol0003ocLWFolg9eP08olg9eP03o`000?o?b=?oclSC00[oclSC00Go
0000om3;eOo@bmGod<_Eo`00000?om39d`03o`000?oooooooooo043ooooo000Yooooo`03o`000?oo
oooooooo04Gooooo00?o0000oe6Fl?mAU_001?mAU_07o`0000;oJZ3`00?o0000ogFRk_meX^h01Ome
X^h00ol0003oPJG[oh6Uj`06oh6Uj`03o`000?n>Z>OoSZSW00OoSZSW00?o0000oiV/i?nI[>@02?nI
[>@00ol0003oXjoPoj>_h003o`0000KoXk?T00?o0000ojjgh?n^]n002_n^]n02o`0000co]k[L00?o
0000okjmfOnn_MT01?nn_MT00ol0003o`L;Kol72f`06ol72f`03o`000?o7a=OoalCG00coalCG00Go
0000ol_5e?o;aMCoblGDo`00000<olg9eP03o`000?o?b=?oclSC00SoclSC00?o0000om3;eOo@bmD0
0oo@bmD00ol0003od<WCom39d`0=om39d`03o`000?oooooooooo03oooooo000Yooooo`03o`000?oo
oooooooo04Kooooo00?o0000oe6Fl?mAU_001?mAU_000ol0003oFYW`oeZIl003oeZIl0Wo00000_me
X^h00ol0003oPJG[oh6Uj`06oh6Uj`03o`000?n>Z>OoSZSW00OoSZSW00?o0000oiV/i?nI[>@00onI
[>@7o`0000[oXk?T00?o0000ojjgh?n^]n002_n^]n000ol0003o]k[LokNjg00;okNjg004o`000?nn
_MWo_[gIokjmf@;o00002Oo1`]/00ol0003oalCGolO4e`0=olO4e`03o`000?o;aMCo000000gocLWF
00?o0000olo8doo?b=<01oo?b=<00ol0003od<_Eom3;e@05om3;e@03o`000?o@bM?od<WC00cod<WC
0_l00010ooooo`00:Oooool2o`0004Sooooo00?o0000oe6Fl?mAU_001?mAU_000ol0003oFYW`oeZI
l005oeZIl003o`000?mWW^ooIik_00?oIik_2Ol00003oh6Uj`03o`000?n>Z>OoSZSW00?oSZSW2Ol0
0005oiJ_j003o`000?nS/nCoXk?T00[oXk?T00?o0000ojjgh?n^]n002On^]n02o`0000go]k[L00?o
0000okjmfOl000003?o1`]/00ol0003oalCGolO4e`0<olO4e`;o00003oo=bMH00ol0003oclSColo8
d`05olo8d`03o`000?o@bmGod<_E00Kod<_E00?o0000om39doo@bM<02oo@bM<01?l0003ocl[Eo`00
0?l0000oooooo`00:Oooool00ol0003oooooooooo`18ooooo`03o`000?mAU_3oDIK`00CoDIK`00?o
0000oeZIl?mJVO001OmJVO000ol0003oIik_ofNNk`05ofNNk`03o`000?mgY>koMjC^00?oMjC^2Ol0
0004ohNYk003o`000?nF[nSoUZoX00SoUZoX00?o0000oj>ci?nS/n@02_nS/n@00ol0003o[[OPojjg
h008ojjgh003o`000?n^]n3o000000co]k[L0_l0000>ol72f`03o`000?o7a=OoalCG00[oalCG00?o
0000olW8fOl000004?o=bMH00ol0003oclSColo8d`03olo8d`03o`000?o@bmGod<_E00Sod<_E00?o
0000om39doo@bM<02Oo@bM<01Ol0003ocl[Eolo:eOo?b]Go000003oooooo000Yooooo`03o`000?oo
oooooooo04Wooooo00?o0000oe6Fl?mAU_001?mAU_000ol0003oFYW`oeZIl005oeZIl003o`000?mW
W^ooIik_00GoIik_00?o0000ogNTk_mgY>h01_mgY>h00ol0003oQjW/ohNYk007ohNYk003o`000?nF
[nSoUZoX00SoUZoX00?o0000oj>ci?nS/n@02OnS/n@00ol0003o[[OPojjgh008ojjgh003o`000?n^
]n3o000000[o]k[L0_l000000oni`=oo0000ol72f`0=ol72f`03o`000?o7a=OoalCG00WoalCG00Go
0000olW8fOo9b=WobLSIo`00000@olg9eP05o`000?o?b=?oclSColo8dol000003?o@bmD00ol0003o
d<WCom39d`07om39d`03o`000?o?b]Gocl[E00?ocl[E00?o0000ooooooooool0??ooool002Wooooo
00?o0000ooooooooool0B_ooool00ol0003oDIK`oe6Fl004oe6Fl003o`000?mJVO3oFYW`00GoFYW`
00?o0000ofNNkomWW^l01OmWW^l00ol0003oMjC^ogNTkP06ogNTkP03o`000?n7ZNcoQjW/00OoQjW/
00?o0000oiJ_j?nF[nP02?nF[nP00ol0003oXk?Toj>ci009oj>ci003o`000?n^]n3o[[OP00Oo[[OP
00Co0000ojjgh?n^]n3o00001ong^]`2o`0000Co^L3O00?o0000ol72foo1`]/03?o1`]/00ol0003o
alCGolO4e`07olO4e`03o`000?o9b=WobLSI00?obLSI00?o0000olg9e_o=bMH03_o=bMH00ol0003o
clSCo`00000>om3;e@03o`000?o@bM?od<WC00Cod<WC0_l00007olo:e@03o`000?oooooooooo03_o
oooo000Yooooo`03o`000?oooooooooo04_ooooo00?o0000oe6Fl?mAU_001?mAU_000ol0003oFYW`
oeZIl005oeZIl003o`000?mWW^ooIik_00GoIik_00?o0000ogNTk_mgY>h01_mgY>h00ol0003oQjW/
ohNYk007ohNYk003o`000?nF[nSoUZoX00SoUZoX00?o0000oj>ci?nS/n@02OnS/n@00ol0003o[[OP
ojjgh006ojjgh005o`000?n^]n3o[[OPojjgh?l000001?ng^]`2o`0000Oo^L3O00?o0000ol72foo1
`]/03?o1`]/00ol0003oalCGolO4e`04olO4e`;o00001oo9b=T00ol0003ocLWFolg9eP0=olg9eP;o
00003oo@bmD00ol0003od<WCom39d`03om39d`03o`000?o?b]Gocl[E00Oocl[E0_l0000looooo`00
:Oooool00ol0003oooooooooo`1<ooooo`03o`000?mAU_3oDIK`00CoDIK`00?o0000oeZIl?mJVO00
1OmJVO000ol0003oIik_ofNNk`05ofNNk`03o`000?mgY>koMjC^00KoMjC^00?o0000ohNYk?n7ZN`0
1on7ZN`00ol0003oUZoXoiJ_j007oiJ_j003o`000?nS/nCoXk?T00[oXk?T00?o0000ojjgh?n^]n00
1On^]n000ol0003o[[OPojjgh002ojjgh004o`000?ng^]co0000o`0000[o^L3O00?o0000ol72foo1
`]/03?o1`]/00ol0003oalCGolO4e`02olO4e`03o`000?o9b=WobLSI00SobLSI00?o0000olg9e_o=
bMH02oo=bMH00ol0003oc/cHo`00000@om3;e@05o`000?o@bM?od<WCom39dol000002oo?b]D00ol0
003oooooooooo`0jooooo`00:?ooool3o`0004kooooo00?o0000oe6Fl?mAU_001?mAU_000ol0003o
FYW`oeZIl005oeZIl003o`000?mWW^ooIik_00CoIik_00?o0000ogNTk_mgY>h01omgY>h00ol0003o
QjW/ohNYk007ohNYk003o`000?nF[nSoUZoX00OoUZoX00?o0000oj>ci?nS/n@02OnS/n@00ol0003o
[[OPojjgh005ojjgh003o`000?n^]n3o[[OP00;o[[OP0_l0000=okW0g`03o`000?o1`]_o`L;K00_o
`L;K00Go0000olO4eoo7a=OoalCGo`00000<olW8f@03o`000?o=bMKocLWF00WocLWF00Go0000olk<
f?o>c=Soc/cHo`00000@om3;e@03o`000?o@bM?o000000gocl[E00?o0000ooooooooool0>Oooool0
02Sooooo00?o0000ooooooooool0Coooool00ol0003oDIK`oe6Fl004oe6Fl003o`000?mJVO3oFYW`
00CoFYW`00?o0000ofNNkomWW^l01OmWW^l00ol0003oMjC^ogNTkP06ogNTkP03o`000?n7ZNcoQjW/
00SoQjW/00?o0000oiJ_j?nF[nP01onF[nP00ol0003oXk?Toj>ci009oj>ci003o`000?n^]n3o[[OP
00Co[[OP00?o0000ojjgh?l000000_l000000on__NCo0000okW0g`0=okW0g`03o`000?o1`]_o`L;K
00_o`L;K00?o0000olO4eol000003Oo9b=T00ol0003ocLWFolg9eP08olg9eP03o`000?o>c=Soc/cH
00?oc/cH00?o0000om3;eOo@bmD03Oo@bmD2o`0000oocl[E00?o0000ooooooooool0>?ooool000co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413o
c<c<00Oooooo00?o0000ooooooooool0D?ooool3o`0000CoDIK`00?o0000oeZIl?mJVO001?mJVO00
0ol0003oIik_ofNNk`05ofNNk`03o`000?mgY>koMjC^00KoMjC^00?o0000ohNYk?n7ZN`01on7ZN`0
0ol0003oUZoXoiJ_j008oiJ_j003o`000?nS/nCoXk?T00WoXk?T00?o0000ojjgh?n^]n000on^]n02
o`0000Go[kgT00?o0000okW0goni`=l03?ni`=l00ol0003o`L;Kol72f`0:ol72f`;o00003oo9b=T0
0ol0003ocLWFolg9eP05olg9eP;o00001oo>c=P00ol0003od<_Eom3;e@0;om3;e@03o`000?o?cMSo
000000oocl[E0_l0000iooooo`003?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401oooool00ol0003oooooooooo`1@ooooo`03o`000?m6
T>ooAY3_00Ko00001_mJVO000ol0003oIik_ofNNk`05ofNNk`03o`000?mgY>koMjC^00KoMjC^00?o
0000ohNYk?n7ZN`01on7ZN`00ol0003oUZoXoiJ_j007oiJ_j003o`000?nS/nCoXk?T00[oXk?T00?o
0000ojjgh?l000000ol00007ojnmi003o`000?ni`=oo^L3O00_o^L3O00?o0000ol72foo1`]/02Oo1
`]/01?l0003o`lSNol?8g_l0000?olW8f@03o`000?o=bMKocLWF00?ocLWF00?o0000olk<f?o>c=P0
2?o>c=P00ol0003od<_Eom3;e@09om3;e@05o`000?o?cMSoclgHolo=f?l000003oo?b]D00ol0003o
ooooooooo`0gooooo`003?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo057ooooo00?o0000odJ@kom6T>l01?m6T>l4o`00
00CoFYW`00?o0000ofNNkomWW^l01?mWW^l00ol0003oMjC^ogNTkP07ogNTkP03o`000?n7ZNcoQjW/
00OoQjW/00?o0000oiJ_j?nF[nP01onF[nP00ol0003oXk?Toj>ci008oj>ci0Go000000?o[kgTo`00
0?n__N@01on__N@00ol0003o^L3OokW0g`0;okW0g`03o`000?o1`]_o`L;K00Ko`L;K0_l00004ol?8
gP03o`000?o9b=WobLSI00gobLSI00Go0000olg9e_o=bMKocLWFo`00000<olk<f003o`000?o@bmGo
d<_E00Ood<_E00?o0000olo=f?o?cMP00oo?cMP00ol0003ocl[Eolo:e@0=olo:e@03o`000?oooooo
oooo03Kooooo000<ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonH
V9So8B4Q00Oooooo00?o0000ooooooooool0D_ooool00ol0003oAY3_odJ@k`04odJ@k`03o`000?m?
U?3oCiC`00Ko00001_mWW^l00ol0003oMjC^ogNTkP06ogNTkP03o`000?n7ZNcoQjW/00SoQjW/00?o
0000oiJ_j?nF[nP01onF[nP00ol0003oXk?Toj>ci004oj>ci0Ko00001?n__N@00ol0003o[kgTojnm
i006ojnmi003o`000?ni`=oo^L3O00_o^L3O00?o0000ol72foo1`]/01?o1`]/00ol0003o`lSNol?8
gP05ol?8gP03o`000?o9b=WobLSI00gobLSI00?o0000olg9e_l000003_o>c=P00ol0003od<_Eom3;
e@05om3;e@03o`000?o?cMSoclgH00GoclgH00?o0000olo:eOo?b]D03?o?b]D2o`0003Oooooo000<
ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Oooooo
00?o0000ooooooooool0Doooool00ol0003oAY3_odJ@k`04odJ@k`03o`000?m?U?3oCiC`00CoCiC`
1?l00004ofNNk`03o`000?mgY>koMjC^00KoMjC^00?o0000ohNYk?n7ZN`02?n7ZN`00ol0003oUZoX
oiJ_j007oiJ_j003o`000?nS/nCoXk?T00Go00001?nR^NT00ol0003o[kgTojnmi002ojnmi003o`00
0?n__NCo[kgT00Ko[kgT00?o0000okW0goni`=l02oni`=l01?l0003o`L;Kol72foo1`]/2o`0000Wo
`lSN00?o0000olW8fOo9b=T03?o9b=T2o`00013oc/cH00?o0000om3;eOo@bmD00oo@bmD00ol0003o
clgHolo=f007olo=f003o`000?o?b]Gocl[E00[ocl[E00Co0000olc;fOl0003o0000=_ooool000co
oooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Wooooo00?o0000oooo
ooooool0E?ooool00ol0003oAY3_odJ@k`04odJ@k`03o`000?m?U?3oCiC`00CoCiC`00?o0000oefK
lOmMVo401_l00008ogNTkP03o`000?n7ZNcoQjW/00SoQjW/00?o0000oiJ_j?nF[nP00onF[nP8o`00
00SoX[WY00?o0000ojnmi?n__N@00_n__N@00ol0003o[kgTojnmi006ojnmi003o`000?ni`=oo^L3O
00_o^L3O00?o0000ol72fol000003?o3b=h00ol0003obLSIolW8f@0:olW8f@03o`000?o:cMco0000
017oc/cH00Go0000om3;eOo@bmGod<_Eo`00000;olo=f003o`000?o?b]Gocl[E00Oocl[E0_l00003
olc;f@03o`000?oooooooooo03Cooooo000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
0ooMgMgo410@oiRHV008ooooo`;o0000Eoooool00ol0003oAY3_odJ@k`04odJ@k`03o`000?m?U?3o
CiC`00CoCiC`00?o0000oefKlOmMVo401?mMVo47o`0000?oMjC^00?o0000ohNYk?n7ZN`00on7ZN`:
o`0000;oTk?]0ol0000<oj:ij@03o`000?n__NCo[kgT00;o[kgT00?o0000ojnmi?n__N@01On__N@0
0ol0003o^L3OokW0g`0;okW0g`;o00003_o3b=h00ol0003obLSIolW8f@08olW8f@05o`000?o:cMco
b/gLol[=g?l000004Oo>c=P00ol0003od<_Eo`00000<olo=f003o`000?o?b]Gocl[E00Kocl[E00?o
0000olc;fOo<bmT01?o<bmT00ol0003oooooooooo`0cooooo`003?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`1Gooooo`03o`00
0?m6T>ooAY3_00CoAY3_00?o0000odnDl?m?U?001?m?U?000ol0003oGI_aoefKl@05oefKl@03o`00
0?m^Xo7oKZ?a00;oKZ?a2Ol00005oh6/l004o`000?nC/ngoTk?]oi>ck@?o00000onC/nd00ol0003o
X[WYoj:ij@0:oj:ij@03o`000?n__NCo[kgT00;o[kgT00?o0000ojnmi?n__N@01On__N@00ol0003o
^L3OokW0g`08okW0g`;o000000?o^lKSo`000?o3b=h03_o3b=h00ol0003obLSIolW8f@05olW8f@;o
00001Oo:cM`00ol0003oc/cHolk<f00>olk<f0;o00003_o?cMP00ol0003ocl[Eolo:e@04olo:e@03
o`000?o<bmWoc<_I00Koc<_I00?o0000ooooooooool0<_ooool002Oooooo00?o0000ooooooooool0
F?ooool00ol0003oAY3_odJ@k`04odJ@k`03o`000?m?U?3oCiC`00CoCiC`00?o0000oefKlOmMVo40
1OmMVo400ol0003oKZ?aofjSl@05ofjSl@03o`000?n1[?3oPJc`00SoPJc`0ol00007oi>ck@03o`00
0?nR^NWoX[WY00[oX[WY00?o0000ojnmi?n__N@00_n__N@00ol0003o[kgTojnmi005ojnmi003o`00
0?ni`=oo^L3O00Go^L3O0_l00004ok_6h`03o`000?o3b=ko`lSN00go`lSN00?o0000olW8fOo9b=T0
0oo9b=T00ol0003ob/gLol[=g006ol[=g003o`000?o>c=Soc/cH00coc/cH00?o0000olg?fol00000
3oo?cMP01?l0003ocl[Eolo:eOo?b]D2o`0000[oc<_I00?o0000ooooooooool0<Oooool002Oooooo
00?o0000ooooooooool0FOooool00ol0003oAY3_odJ@k`04odJ@k`03o`000?m?U?3oCiC`00CoCiC`
00?o0000oefKlOmMVo401OmMVo400ol0003oKZ?aofjSl@05ofjSl@03o`000?n1[?3oPJc`00CoPJc`
0ol000000on1[?3o0000oi>ck@08oi>ck@03o`000?nR^NWoX[WY00[oX[WY00?o0000ojnmi?n__N@0
0_n__N@00ol0003o[kgTojnmi005ojnmi003o`000?ni`=oo^L3O00;o^L3O0_l00007ok_6h`03o`00
0?o3b=ko`lSN00go`lSN00Go0000olW8fOo9b=WobLSIo`00000:ol[=g003o`000?o>c=Soc/cH00[o
c/cH00Go0000olg?foo=cm_ocLoKo`00000?olo=f003o`000?o?b]Go000000coc<_I0_l0000boooo
o`009oooool00ol0003oooooooooo`1Jooooo`03o`000?m6T>ooAY3_00CoAY3_00?o0000odnDl?m?
U?001?m?U?000ol0003oGI_aoefKl@05oefKl@03o`000?m^Xo7oKZ?a00GoKZ?a00?o0000oh6/l?n1
[?000ol00005oh6/l003o`000?nC/ngoTk?]00OoTk?]00?o0000oj:ijOnR^NT02OnR^NT00ol0003o
[kgTojnmi002ojnmi003o`000?n__NCo[kgT00Ko[kgT00Co0000okW0gol0003o00002_nka^<00ol0
003o`lSNol?8gP0=ol?8gP03o`000?o9b=Wo000000cob/gL00?o0000olk<f?o>c=P02?o>c=P00ol0
003ocLoKolg?f`03olg?f`03o`000?o?cMSoclgH00coclgH0_l0000>olc;f@03o`000?oooooooooo
033ooooo000Wooooo`03o`000?oooooooooo05_ooooo00?o0000odJ@kom6T>l01?m6T>l00ol0003o
CiC`odnDl004odnDl003o`000?mMVo7oGI_a00GoGI_a00?o0000ofjSlOm^Xo401?m^Xo43o`0000So
PJc`00?o0000oi>ckOnC/nd02?nC/nd00ol0003oX[WYoj:ij@09oj:ij@03o`000?n__NCo[kgT00;o
[kgT00?o0000ojnmi?n__N@01On__N@2o`0000go^lKS00?o0000ol?8g_o3b=h03?o3b=h2o`0000ko
b/gL00?o0000olk<f?o>c=P01Oo>c=P2o`0000OocLoK00?o0000olo=f?o?cMP02_o?cMP00ol0003o
c<oLo`00000?olc;f@03o`000?oooooooooo02oooooo000Wooooo`;o0000GOooool3o`0000CoAY3_
00?o0000odnDl?m?U?000om?U?000ol0003oGI_aoefKl@06oefKl@03o`000?m^Xo7oKZ?a00?o0000
0_m^Xo400ol0003oPJc`oh6/l007oh6/l003o`000?nC/ngoTk?]00SoTk?]00?o0000oj:ijOnR^NT0
2OnR^NT00ol0003o[kgTojnmi002ojnmi004o`000?n__NCo[kgTojnmi0?o000000?o/<?Xo`000?nk
a^<03Onka^<00ol0003o`lSNol?8gP0:ol?8gP03o`000?o4cN7o000000oob/gL00?o0000olk<f?o>
c=P00oo>c=P00ol0003ocLoKolg?f`08olg?f`03o`000?o?cMSoclgH00SoclgH00Go0000olc?g?o<
cmcoc<oLo`00000?olc;f@03o`000?oooooooooo02kooooo000Vooooo`;o0000Goooool00ol0003o
@Xk^o`000005o`0000GoCiC`00?o0000oefKlOmMVo401OmMVo43o`0000KoKZ?a00?o0000oh6/l?n1
[?001on1[?000ol0003oTk?]oi>ck@07oi>ck@03o`000?nR^NWoX[WY00[oX[WY00?o0000ojnmi?n_
_N@00_n__N@3o`0000Go/<?X00?o0000ok_6honka^<02onka^<00ol0003o`lSNol?8gP08ol?8gP;o
00000oo4cN400ol0003ob/gLol[=g00=ol[=g005o`000?o>c=Soc/cHolk<f?l000003?o=cm/00ol0
003oclgHolo=f006olo=f003o`000?o<cmcoc<oL00?oc<oL00?o0000olc;fOo<bmT03?o<bmT2o`00
02oooooo000Wooooo`03o`000?oooooooooo05kooooo00?o0000od:>k_m2S^h00om2S^h4o`0000?o
CiC`00Co0000oefKlOmMVo7oGI_a0ol00002oefKl@03o`000?m^Xo7oKZ?a00GoKZ?a00?o0000oh6/
l?n1[?001on1[?000ol0003oTk?]oi>ck@07oi>ck@03o`000?nR^NWoX[WY00[oX[WY00?o0000ojnm
i?l000000ol00007ok33j003o`000?nka^?o^lKS00_o^lKS00?o0000ol?8g_o3b=h01_o3b=h00ol0
003oa<gQolC=h@04olC=h@03o`000?o:cMcob/gL00gob/gL00?o0000olk<f?l000003Oo=cm/00ol0
003oclgHolo=f005olo=f003o`000?o<cmcoc<oL00Goc<oL00?o0000olc;fOo<bmT03?o<bmT2o`00
02kooooo000Wooooo`03o`000?oooooooooo05oooooo00?o0000od:>k_m2S^h00om2S^h00ol0003o
BI;`odVBl003o`000004odnDl?l0003o0000o`0000KoGI_a00?o0000ofjSlOm^Xo401Om^Xo400ol0
003oPJc`oh6/l007oh6/l003o`000?nC/ngoTk?]00OoTk?]00?o0000oj:ijOnR^NT02?nR^NT3o`00
00Co/<?X00?o0000ok33j?n``nP01On``nP00ol0003o^lKSok_6h`0;ok_6h`03o`000?o3b=ko`lSN
00Co`lSN00?o0000olC=hOo4cN401_o4cN400ol0003ob/gLol[=g00<ol[=g0;o00003oo=cm/00ol0
003oclgHolo=f003olo=f003o`000?o<cmcoc<oL00Ooc<oL00?o0000olc;fOo<bmT02_o<bmT00ol0
003oal_Mo`00000^ooooo`009_ooool00ol0003oooooooooo`1Qooooo`03o`000?m2S^ko@Xk^00?o
@Xk^00?o0000odVBl?m9T_001Ol00008oefKl@03o`000?m^Xo7oKZ?a00GoKZ?a00?o0000oh6/l?n1
[?001_n1[?000ol0003oTk?]oi>ck@08oi>ck@03o`000?nR^NWoX[WY00CoX[WY0ol00002oj6nkP03
o`000?n``nSo/<?X00?o/<?X00?o0000ok33j?n``nP01On``nP00ol0003o^lKSok_6h`0;ok_6h`04
o`000?o3b=ko`lSNol?8gP;o00002_o4cN400ol0003ob/gLol[=g00:ol[=g003o`000?o9dN3o0000
013ocLoK00Go0000olo=f?o?cMSoclgHo`00000;olc?g003o`000?o<bmWoc<_I00Ooc<_I0_l00003
olO;g@03o`000?oooooooooo02_ooooo000Vooooo`03o`000?oooooooooo06;ooooo00?o0000od:>
k_m2S^h00_m2S^h3o`0000GoBI;`1_l00003oefKl@03o`000?m^Xo7oKZ?a00GoKZ?a00?o0000oh6/
l?n1[?001_n1[?000ol0003oTk?]oi>ck@08oi>ck@03o`000?nR^NWoX[WY00?o00001_nQ_^h00ol0
003o/<?Xok33j003ok33j003o`000?n``nSo/<?X00Go/<?X00?o0000ok_6honka^<02onka^<00ol0
003o`lSNo`00000=olC=h@03o`000?o:cMcob/gL00Oob/gL0_l00003olWAh003o`000?o=cm_ocLoK
00kocLoK00?o0000olo=f?l000003?o<cm`00ol0003oc<_Iolc;f@06olc;f@03o`000?o7bmgoal_M
00?oal_M0_l0000/ooooo`009_ooool00ol0003oooooooooo`1Sooooo`Co00000_m2S^h00ol0003o
BI;`odVBl004odVBl003o`000?mFV_;oEY[b00;oEY[b2_l00002ofjSl@03o`000?n1[?3oPJc`00Ko
PJc`00?o0000oi>ckOnC/nd00onC/nd7o`0000[oXKk^00?o0000ok33j?n``nP00_n``nP00ol0003o
/<?Xok33j005ok33j003o`000?nka^?o^lKS00_o^lKS0_l0000>olC=h@03o`000?o:cMcob/gL00Ko
b/gL00?o0000olWAh?o9dN001?o9dN000ol0003ocLoKolg?f`0=olg?f`;o00003_o<cm`00ol0003o
c<_Iolc;f@04olc;f@03o`000?o7bmgoal_M00Goal_M00?o0000ooooooooool0:_ooool002Kooooo
0_l0001Sooooo`?o00001Om2S^h00ol0003oBI;`odVBl004odVBl003o`000?mFV_;oEY[b00GoEY[b
00?o0000ofRUm?mXYO@00omXYO@Ao`0000KoT;Sb00?o0000oj6nk_nQ_^h02OnQ_^h00ol0003o/<?X
ok33j002ok33j003o`000?n``nSo/<?X00Go/<?X00?o0000ok_6honka^<02?nka^<2o`0000;o^lcW
00?o0000olC=hOo4cN403?o4cN400ol0003ob/gLol[=g004ol[=g003o`000?o9dN3obM7P00KobM7P
00?o0000olg?foo=cm/02oo=cm/01?l0003obm;Pol_Bh?l0000>olc?g004o`000?o<bmWoc<_Iolc;
f@;o00002Oo7bmd00ol0003oooooooooo`0Yooooo`009_ooool00ol0003oooooooooo`1Oooooo`?o
00000oooool00ol0003o@Xk^od:>kP03od:>kP03o`000?m9T_3oBI;`00CoBI;`00?o0000oeJJl_mF
V_801OmFV_800ol0003oJ:GdofRUm006ofRUm003o`000?ml[oCoO:od00KoO:od00?o0000oi2hl_n@
^?802?n@^?800ol0003oXKk^oj6nkP09oj6nkP03o`000?n``nSo/<?X00;o/<?X00?o0000ok33j?n`
`nP01On``nP00ol0003o^lKSok_6h`05ok_6h`;o00001Onkc>L00ol0003oa<gQolC=h@0<olC=h@04
o`000?o:cMcob/gLol[=g0;o00002_o9dN000ol0003ocLoKolg?f`08olg?f`;o00001?o;d^000ol0
003oc<oLolc?g00<olc?g003o`000?o<bmWo000000coal_M00?o0000ooooooooool0:?ooool002Ko
oooo00?o0000ooooooooool0G?ooool3o`0000Oooooo00?o0000od:>k_m2S^h00om2S^h00ol0003o
BI;`odVBl004odVBl003o`000?mFV_;oEY[b00GoEY[b00?o0000ofRUm?mXYO@01_mXYO@00ol0003o
O:odogb_m006ogb_m003o`000?n@^?;oT;Sb00SoT;Sb00?o0000oj6nk_nQ_^h02OnQ_^h00ol0003o
/<?Xok33j002ok33j003o`000?n``nSo/<?X00Go/<?X00?o0000ok_6honka^<00_nka^<2o`0000So
^lcW00?o0000olC=hOo4cN403?o4cN400ol0003ob/gLo`00000=olWAh003o`000?o=cm_ocLoK00Ko
cLoK00?o0000ol_Bh?o;d^001Oo;d^000ol0003oc<oLolc?g00;olc?g0;o00003Oo7bmd00ol0003o
ooooooooo`0Xooooo`009_ooool00ol0003oooooooooo`1Iooooo`?o00002oooool00ol0003o@Xk^
od:>kP03od:>kP03o`000?m9T_3oBI;`00CoBI;`00?o0000oeJJl_mFV_801OmFV_800ol0003oJ:Gd
ofRUm006ofRUm003o`000?ml[oCoO:od00KoO:od00?o0000oi2hl_n@^?802?n@^?800ol0003oXKk^
oj6nkP08oj6nkP03o`000?n``nSo/<?X00?o/<?X00?o0000ok33j?n``nP01On``nP01?l0003o^lKS
o`000?l0000;ok_<i`03o`000?o4cN7oa<gQ00_oa<gQ0ol0000>olWAh003o`000?o=cm_ocLoK00Co
cLoK00?o0000ol_Bh?o;d^001oo;d^000ol0003oc<oLolc?g009olc?g003o`000?o7d>7o000000ko
al_M00?o0000ooooooooool09oooool002Kooooo00?o0000ooooooooool0E_ooool3o`0000oooooo
0ol00003od:>kP03o`000?m9T_3oBI;`00CoBI;`00?o0000oeJJl_mFV_801OmFV_800ol0003oJ:Gd
ofRUm006ofRUm003o`000?ml[oCoO:od00KoO:od00?o0000oi2hl_n@^?802?n@^?800ol0003oXKk^
oj6nkP08oj6nkP03o`000?n``nSo/<?X00?o/<?X00?o0000ok33j?n``nP01?n``nP2o`0000ko^lcW
00?o0000olC=hOo4cN402Oo4cN401Ol0003o`m;Uol?BiOo3d^Go000000kobM7P00Co0000olg?foo=
cm_ocLoK0_l0000;ol_Bh003o`000?o<cmcoc<oL00Koc<oL0_l00003olO@h@03o`000?o7bmgoal_M
00coal_M00?o0000ooooooooool09_ooool002Kooooo00?o0000ooooooooool0Doooool3o`0001?o
oooo00?o0000odJ@kol000000_l000000om2S^ko0000odVBl005odVBl003o`000?mFV_;oEY[b00Go
EY[b00?o0000ofRUm?mXYO@01_mXYO@00ol0003oO:odogb_m006ogb_m003o`000?n@^?;oT;Sb00So
T;Sb00?o0000oj6nk_nQ_^h02?nQ_^h00ol0003o/<?Xok33j003ok33j003o`000?n``nSo/<?X00?o
00000_n`bNd00ol0003o^lcWok_<i`0<ok_<i`03o`000?o4cN7oa<gQ00Koa<gQ0_l00005ol?Bi@03
o`000?o9dN3obM7P00cobM7P00?o0000olg?fol000003_o;d^000ol0003oc<oLolc?g004olc?g003
o`000?o7d>7oam3Q00Coam3Q00?o0000olO;gOo7bmd02oo7bmd2o`0002Oooooo000Uooooo`03o`00
0?oooooooooo057ooooo0ol0000Gooooo`04o`000?m6T>ooAY3_odJ@k`?o00001_m9T_000ol0003o
EY[boeJJlP04oeJJlP03o`000?mXYOCoJ:Gd00OoJ:Gd00?o0000ogb_m?ml[o@01_ml[o@00ol0003o
T;Sboi2hlP08oi2hlP03o`000?nQ_^koXKk^00SoXKk^00?o0000ok33j?n``nP00_n``nP3o`0000Ko
/<W]00?o0000ok_<ionkc>L03?nkc>L00ol0003oa<gQolC=h@04olC=h@03o`000?o3d^Go`m;U00Ko
`m;U00?o0000olWAh?o9dN002oo9dN03o`0000oobm;P00Co0000olc?g?o<cmcoc<oL0_l00008olO@
h@03o`000?o7bmgoal_M00_oal_M00?o0000ooooooooool09Oooool002Gooooo0ol0001>ooooo`?o
00006_ooool2o`0000GoAY3_0ol00004odVBl003o`000?mFV_;oEY[b00CoEY[b00?o0000ofRUm?mX
YO@01omXYO@00ol0003oO:odogb_m006ogb_m003o`000?n@^?;oT;Sb00SoT;Sb00?o0000oj6nk_nQ
_^h02?nQ_^h00ol0003o/<?Xo`000003o`0000So/<W]00?o0000ok_<ionkc>L03?nkc>L01?l0003o
a<gQolC=hOo4cN42o`0000[o`m;U00?o0000olWAh?o9dN002Oo9dN001Ol0003oamGUolOEiOo7eNGo
000000oobm;P00?o0000olc?g?l000002oo7d>400ol0003oal_MolO;g@0:olO;g@;o00009_ooool0
02Gooooo00?o0000ooooooooool0Boooool3o`0001kooooo0_l00005odJ@k`03o`000?m:UO7o0000
00Go00001_mFV_800ol0003oJ:GdofRUm007ofRUm003o`000?ml[oCoO:od00KoO:od00?o0000oi2h
l_n@^?802?n@^?800ol0003oXKk^oj6nkP06oj6nkPCo00000on`bNd00ol0003o/<W]ok39k@06ok39
k@03o`000?nkc>Oo^lcW00co^lcW00?o0000olC=hOl000003Oo3d^D00ol0003obM7PolWAh006olWA
h0;o00001Oo7eND00ol0003obm;Pol_Bh00<ol_Bh0;o00003Oo7d>400ol0003oal_MolO;g@07olO;
g@;o000000?o`<WRo`000?l000009Oooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Oooooo00?o0000ooooooooool0B?ooool3
o`0002;ooooo0_l00005odJ@k`03o`000?m:UO7oBYGa00?oBYGa1?l00004oeJJlP03o`000?mXYOCo
J:Gd00OoJ:Gd00?o0000ogb_m?ml[o@01_ml[o@00ol0003oT;Sboi2hlP08oi2hlP03o`000?nQ_^ko
XKk^00Go00001?nPaO801Ol0003o/<W]ok39kOn`bNgo000000So/<W]00?o0000ok_<ionkc>L02onk
c>L3o`0000ko`m;U00?o0000olWAh?o9dN001?o9dN000ol0003oamGUolOEi@06olOEi@03o`000?o;
d^3obm;P00Wobm;P0_l000000oo6e>Go0000olO@h@0=olO@h@03o`000?o7bmgoal_M00Coal_M0_l0
0004ol39hP;o00009?ooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OlQ8B7oV9RHoooooonHV9So8B4Q00Oooooo00?o0000ooooooooool0AOooool3o`0002Kooooo
0_l00005odJ@k`03o`000?m:UO7oBYGa00GoBYGa1ol00009ofRUm003o`000?ml[oCoO:od00KoO:od
00?o0000oi2hl_n@^?800on@^?87o`0000[oX<Gb00Go0000ok39kOn`bNgo/<W]o`000008ok39k@03
o`000?nkc>Oo^lcW00So^lcW0_l00003ok_Bk003o`000?o3d^Go`m;U00co`m;U00Co0000olWAh?o9
dN3obM7P0_l0000:olOEi@03o`000?o;d^3obm;P00Oobm;P00?o0000olKDiOo6e>D00_o6e>D00ol0
003oam3QolO@h@0<olO@h@03o`000?o7bmgoal_M00;oal_M00?o0000ol39h_o0bN801Oo0bN800ol0
003oooooooooo`0Rooooo`002Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooooooo04;ooooo0ol0000Zooooo`;o00001Om6T>l0
0ol0003oBYGaodZEl@05odZEl@03o`000?mEWO?oEIgc00;oEIgc6Ol00006ohjmmP03o`000?nPaO;o
X<Gb00WoX<Gb00Go0000ok39kOn`bNgo/<W]o`000008ok39k@03o`000?nkc>Oo^lcW00Go^lcW0_l0
0006ok_Bk003o`000?o3d^Go`m;U00co`m;U00?o0000olWAh?l000003Oo7eND00ol0003obm;Pol_B
h004ol_Bh0;o00001_o6e>D00ol0003oam3QolO@h@0<olO@h@04o`000?o7bmgo0000o`0000Wo`<WR
00?o0000ooooooooool08Oooool000Wooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b
<_nHV9SooooooiRHV?lb<S801oooool00ol0003oooooooooo`0oooooo`?o0000;_ooool2o`0000Go
AY3_00?o0000odZElOm:UO401Om:UO400ol0003oEIgcoeFMl`04oeFMl`03o`000?mVZ?KoIZSf00Ko
IZSf00?o0000ogZcmomj/oL01_mj/oL00ol0003oS[gfohjmmP08ohjmmP03o`000?nPaO;oX<Gb00Wo
X<Gb00Go0000ok39kOn`bNgo/<W]o`000008ok39k@03o`000?nkc>Oo^lcW00;o^lcW0_l00009ok_B
k003o`000?o3d^Go`m;U00_o`m;U0ol0000>olOEi@04o`000?o;d^3obm;Pol_Bh0;o00002Oo6e>D0
0ol0003oam3QolO@h@0;olO@h@;o00002oo0bN82o`0002;ooooo0009ooooo`05o`000?oooooooooo
ooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Oooooo00?o0000ooooooooool0??oo
ool3o`0003;ooooo0_l00005odJ@k`03o`000?m:UO7oBYGa00GoBYGa00?o0000oeFMlomEWO<01?mE
WO<00ol0003oIZSfofJXmP06ofJXmP03o`000?mj/oOoN[?g00KoN[?g00?o0000ohjmm_n>_OH02?n>
_OH00ol0003oX<Gboj35lP09oj35lP05o`000?n`bNgo/<W]ok39kOl000002?n`bNd01?l0003o^lcW
o`000?l0000<ok_Bk003o`000?o3d^Go`m;U00So`m;U0_l00003ol7GjP03o`000?o7eNGoamGU00co
amGU00?o0000ol_Bh?l000003?o6e>D00ol0003oam3QolO@h@08olO@h@;o000000?o`=3Vo`000?o0
bN802oo0bN82o`00027ooooo0009ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o
^[Zjoooooonj^[[o410@00Oooooo00?o0000ooooooooool0>Oooool3o`0003Kooooo0_l00005odJ@
k`03o`000?m:UO7oBYGa00GoBYGa00?o0000oeFMlomEWO<01?mEWO<00ol0003oIZSfofJXmP06ofJX
mP03o`000?mj/oOoN[?g00KoN[?g00?o0000ohjmm_n>_OH02?n>_OH00ol0003oX<Gboj35lP09oj35
lP04o`000?n`bNgo/<W]o`0000Oo/<W]1?l0000>ok_Bk003o`000?o3d^Go`m;U00Go`m;U0_l00006
ol7GjP03o`000?o7eNGoamGU00_oamGU0ol0000=olKDi@03o`000?o7d>7oam3Q00Goam3Q0_l00004
ol3@iP03o`000?o0bN;o`<WR00[o`<WR00?o0000ooooooooool07oooool000Wooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003ooooooooo
o`0gooooo`?o0000>_ooool4o`0000?oAY3_00?o0000odZElOm:UO401Om:UO400ol0003oEIgcoeFM
l`04oeFMl`03o`000?mVZ?KoIZSf00KoIZSf00?o0000ogZcmomj/oL01_mj/oL00ol0003oS[gfohjm
mP08ohjmmP03o`000?nPaO;oX<Gb00WoX<Gb00Co0000ok39kOn`bNgo00000on`bNd3o`0000Co[m3a
00?o0000ok_Bk?nkd^`03?nkd^`00ol0003o`m;Uol?Bi@02ol?Bi@;o00002Oo1enX00ol0003oamGU
olOEi@09olOEi@05o`000?o2f>[o`]SZol;Hj_l000003Oo6e>D00ol0003oam3QolO@h@02olO@h@;o
00001oo0d>H00ol0003o`<WRol39hP09ol39hP;o00008?ooool000Wooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0doooo
o`?o0000?_ooool00ol0003oDIK`oe6Fl003o`000003odJ@kol0003oBYGa00KoBYGa00?o0000oeFM
lomEWO<01?mEWO<00ol0003oIZSfofJXmP06ofJXmP03o`000?mj/oOoN[?g00KoN[?g00?o0000ohjm
m_n>_OH02?n>_OH00ol0003oX<Gboj35lP09oj35lP03o`000?n`bNgo/<W]00?o00002?n_d?400ol0
003o^m;/ok_Bk00<ok_Bk004o`000?o3d^Go0000o`0000co`MOZ00?o0000olOEiOo7eND01_o7eND2
o`0000Go`]SZ00?o0000olKDiOo6e>D02oo6e>D01?l0003oam3Qo`000?l0000:ol3@iP03o`000?o0
bN;o`<WR00Wo`<WR0_l0000Oooooo`009?ooool00ol0003oooooooooo`0aooooo`?o0000@_ooool0
0ol0003oDIK`oe6Fl002oe6Fl0?o00001om:UO400ol0003oEIgcoeFMl`04oeFMl`03o`000?mVZ?Ko
IZSf00KoIZSf00?o0000ogZcmomj/oL01_mj/oL00ol0003oS[gfohjmmP08ohjmmP03o`000?nPaO;o
X<Gb00SoX<Gb0ol000000on_d?7o0000ojo@l@09ojo@l@03o`000?nkd^co^m;/00_o^m;/0ol0000>
ol7GjP03o`000?o7eNGoamGU00CoamGU00?o0000ol;Hj_o2f>X01_o2f>X00ol0003oa]CUolKDi@0:
olKDi@;o00003Oo0d>H00ol0003o`<WRol39hP09ol39hP;o00007_ooool002Cooooo00?o0000oooo
ooooool0;oooool2o`0004Kooooo00?o0000oe6Fl?mAU_001?mAU_06o`0000;oBYGa00?o0000oeFM
lomEWO<01?mEWO<00ol0003oIZSfofJXmP06ofJXmP03o`000?mj/oOoN[?g00KoN[?g00?o0000ohjm
m_n>_OH02?n>_OH00ol0003oX<Gboj35lP04oj35lP?o00000onOboH00ol0003o[m3ao`00000:ojo@
l@;o00002Onkd^`2o`0000?o^=O`00?o0000ol7Gj_o1enX03?o1enX01?l0003oamGUolOEiOo7eND2
o`0000[o`]SZ00?o0000olKDiOo6e>D01oo6e>D2o`0000;o_]G[00?o0000ol3@i_o0d>H02_o0d>H0
0ol0003o`<WRol39hP09ol39hP;o00007_ooool002Cooooo00?o0000ooooooooool0;?ooool3o`00
04Wooooo00?o0000oe6Fl?mAU_001?mAU_000ol0003oDi_coe>Kl`02oe>Kl`Ko00001?mEWO<00ol0
003oIZSfofJXmP06ofJXmP03o`000?mj/oOoN[?g00KoN[?g00?o0000ohjmm_n>_OH02?n>_OH00ol0
003oX<Gboj35lP03o`0000OoWl_f00?o0000ojo@lOl000002on_d?400ol0003o^m;/ok_Bk004ok_B
k0;o00001_nheo000ol0003o`MOZol7GjP0<ol7GjP03o`000?o7eNGo000000go`]SZ00?o0000olKD
iOo6e>D01?o6e>D2o`0000Go_]G[00?o0000ol3@i_o0d>H02_o0d>H00ol0003o`<WRol39hP06ol39
hP;o000000?o]/OWo`000?l000007Oooool002Cooooo00?o0000ooooooooool0:Oooool3o`0004go
oooo00?o0000oe6Fl?mAU_001?mAU_000ol0003oDi_coe>Kl`05oe>Kl`03o`000?mJXoKo000000Go
00002?mVZ?H00ol0003oN[?gogZcm`06ogZcm`03o`000?n>_OKoS[gf00?oS[gf1ol0000;oio;mP03
o`000?n_d?7o000000_o[m3a00?o0000ok_Bk?nkd^`00_nkd^`00ol0003o^=O`okSGl007okSGl003
o`000?o1en[o`MOZ00_o`MOZ0ol0000>ol;HjP03o`000?o6e>Goa]CU00;oa]CU00?o0000okkEjonn
eN/01_nneN/00ol0003o`=3Vol3@iP0:ol3@iP03o`000?o0bN;o`<WR00;o`<WR0ol00004okK7i`;o
00007?ooool002Cooooo00?o0000ooooooooool09_ooool3o`00057ooooo00?o0000oe6Fl?mAU_00
1?mAU_000ol0003oDi_coe>Kl`05oe>Kl`03o`000?mJXoKoFZ?f00?oFZ?f6?l00007ohg3n@03o`00
0?nOboKoWl_f00WoWl_f0ol0000;ojo@l@04o`000?nkd^co0000o`0000_o^=O`00?o0000ol7Gj_o1
enX02?o1enX2o`0000?o_M__00?o0000ol;Hj_o2f>X03?o2f>X01?l0003oa]CUo`000?l0000:okkE
j`03o`000?o0d>Ko`=3V00[o`=3V00Co0000ol39h_l0003o00002?nfanL2o`0001_ooooo000Soooo
o`;o00009Oooool3o`0005Gooooo00?o0000oe6Fl?mAU_001?mAU_000ol0003oDi_coe>Kl`05oe>K
l`03o`000?mJXoKoFZ?f00GoFZ?f00?o0000ofR]n?mX[OP01_mX[OP00ol0003oN[WjogZinP06ogZi
nP03o`000?n=`oWoSL?i00SoSL?i00?o0000oio;m_nOboH02_nOboH00ol0003o[m3aojo@l@08ojo@
l@Co00003Onheo000ol0003o`MOZol7GjP05ol7GjP;o00001_nmfnl00ol0003o`]SZol;HjP0;ol;H
jP;o00003OnneN/00ol0003o`=3Vol3@iP09ol3@iP;o00002onfanL00ol0003oooooooooo`0Ioooo
o`009?ooool00ol0003oooooooooo`0Pooooo`?o0000FOooool00ol0003oDIK`oe6Fl004oe6Fl003
o`000?mCVo?oDi_c00GoDi_c00?o0000oeZSm_mJXoH01OmJXoH00ol0003oJ:ghofR]n006ofR]n003
o`000?mj^O[oN[Wj00KoN[Wj00?o0000ohg3nOn=`oT02?n=`oT00ol0003oWl_foio;mP0:oio;mP03
o`000?n_d?7o[m3a00Co[m3a0ol00004ojgEm@03o`000?nheo3o^=O`00_o^=O`00?o0000ol7Gj_o1
enX00_o1enX2o`0000Wo_M__0_l00009ol;HjP;o00000_nkf^l00ol0003o_]G[okkEj`0;okkEj`03
o`000?o0d>Ko`=3V00Ko`=3V0_l000000onfc^co0000okK7i`0;okK7i`03o`000?oooooooooo01So
oooo000Sooooo`03o`000?oooooooooo01kooooo0ol0001Mooooo`03o`000?mAU_3oDIK`00CoDIK`
00?o0000oe>KlomCVo<01OmCVo<00ol0003oFZ?foeZSmP05oeZSmP03o`000?mX[OSoJ:gh00KoJ:gh
00?o0000ogZin_mj^OX01_mj^OX00ol0003oSL?iohg3n@08ohg3n@;o00002onOboH00ol0003o[m3a
ojo@l@03o`0000So[MGe00?o0000okSGl?nheo002onheo001?l0003o`MOZo`000?l0000=okgKk`03
o`000?o2f>[o`]SZ00Co`]SZ0_l00005ok_Jk`03o`000?nneN_o_]G[00_o_]G[00?o0000ol3@i_o0
d>H00_o0d>H3o`0000Co]/k/00?o0000okK7ionfanL02_nfanL00ol0003oooooooooo`0Gooooo`00
8oooool00ol0003oooooooooo`0Kooooo`?o0000HOooool00ol0003oDIK`oe6Fl004oe6Fl003o`00
0?mCVo?oDi_c00GoDi_c00?o0000oeZSm_mJXoH01OmJXoH00ol0003oJ:ghofR]n006ofR]n003o`00
0?mj^O[oN[Wj00KoN[Wj0_l0000:ohg3n@03o`000?nOboKoWl_f00SoWl_f0ol0000<ojgEm@;o0000
2onheo03o`0000oo_M__00?o0000ol;Hj_o2f>X00_o2f>X00ol0003o^m[_ok_Jk`06ok_Jk`03o`00
0?nneN_o_]G[00_o_]G[00Co0000ol3@i_l0003o00002?nfc^`00ol0003o]/OWokK7i`09okK7i`;o
00006?ooool002?ooooo00?o0000ooooooooool06?ooool3o`0006Gooooo0ol00004oe6Fl003o`00
0?mCVo?oDi_c00GoDi_c00?o0000oeZSm_mJXoH01OmJXoH00ol0003oJ:ghofR]n006ofR]n003o`00
0?mj^O[oN[Wj00OoN[Wj00?o0000ohg3nOn=`oT02?n=`oT00ol0003oWl_foio;mP04oio;mP?o0000
0_nNd?T2o`0000go[MGe00?o0000okSGl?nheo001_nheo02o`0000?o]=_d00?o0000okgKkonmfnl0
3Onmfnl01?l0003o`]SZo`000?l0000:ok_Jk`03o`000?nneN_o_]G[00[o_]G[0_l0000;okK>k003
o`000?nfanOo]/OW00Wo]/OW00?o0000ooooooooool05_ooool002?ooooo00?o0000ooooooooool0
5Oooool3o`0006Sooooo00?o0000of:Ol_mRWo801_l00007oe>Kl`03o`000?mJXoKoFZ?f00GoFZ?f
00?o0000ofR]n?mX[OP01_mX[OP00ol0003oN[WjogZinP07ogZinP03o`000?n=`oWoSL?i00SoSL?i
00?o0000oio;m_nOboH00ol00006oik@n@?o00003?n]eOD00ol0003o^=O`okSGl002okSGl0?o0000
1_ndfo@2o`0000go_M__0ol0000<ok_Jk`03o`000?nneN_o_]G[00Ko_]G[0ol00002okCDl003o`00
0?nfc^co]/k/00Wo]/k/00?o0000okK7ionfanL02OnfanL00ol0003oooooooooo`0Eooooo`008ooo
ool00ol0003oooooooooo`0Booooo`?o0000K?ooool00ol0003oHYobof:OlP04of:OlPOo00000_mC
Vo<00ol0003oFZ?foeZSmP05oeZSmP03o`000?mX[OSoJ:gh00KoJ:gh00?o0000ogZin_mj^OX01omj
^OX00ol0003oSL?iohg3n@03ohg3n@Oo00002_nNd?T00ol0003oW]3io`00000<ojgEm@04o`000?nh
eo3o0000o`0000_o]=_d00?o0000okgKkonmfnl01onmfnl3o`0000?o]]gd00?o0000ok_Jkonkf^l0
2_nkf^l00ol0003o_]G[okkEj`03okkEj`;o00001_nde?000ol0003o]/k/okK>k009okK>k003o`00
0?nfanOo]/OW00Wo]/OW00?o0000ooooooooool05?ooool002;ooooo0ol0000@ooooo`?o0000L?oo
ool00ol0003oHYobof:OlP06of:OlP04o`000?mQY?GoHJCeof6Tm@Wo00000_mJXoH00ol0003oJ:gh
ofR]n006ofR]n003o`000?mj^O[oN[Wj00?oN[Wj2Ol00007ohk9o003o`000?nNd?WoW]3i00SoW]3i
00?o0000oik@nOl000002on]eOD3o`0000go]=_d0_l00005okgKk`;o00001onfgO@00ol0003o^m[_
ok_Jk`0:ok_Jk`03o`000?nneN_o000000;o00002Onde?000ol0003o]/k/okK>k009okK>k003o`00
0?nfanOo]/OW00Oo]/OW0ol0000Eooooo`008oooool00ol0003oooooooooo`0<ooooo`?o0000M?oo
ool00ol0003oHYobof:OlP06of:OlP03o`000?mQY?GoHJCe00GoHJCe00Co0000ofJ[n?mVZoSoIZ_h
4Ol00006ogfoo003o`000?n>bOcoS/Wl00SoS/Wl00?o0000oik@nOnNd?T01onNd?T00ol0003oW]3i
oik@n@02o`0000Ko[MGe0ol00003ojWJn003o`000?ndfoCo]=_d00co]=_d00?o0000okgKkol00000
0_l0000:okKMm003o`000?nkf^oo^m[_00Wo^m[_0ol0000<okCDl003o`000?nfc^co]/k/00Wo]/k/
00Co0000okK7ionfanOo]/OW1Ol00002ooooo`03o`000?oooooooooo01?ooooo000Sooooo`03o`00
0?oooooooooo00Wooooo0ol0001hooooo`03o`000?mRWo;oHYob00KoHYob00?o0000of6TmOmQY?D0
1OmQY?D00ol0003oIZ_hofJ[n005ofJ[n003o`000?m`]O[oL;Gj00KoL;Gj00?o0000ogfoo?mm_o`0
1omm_o`00ol0003oS/Wlohk9o008ohk9o0;o00002?nNd?T01Ol0003oW]3ioik@nOnNd?Wo000000;o
[MGe0ol00007ojWJn0;o00003?ndfo@3o`0000go]]gd00?o0000ok_Jkonkf^l01_nkf^l2o`0000?o
/MWd00?o0000okCDl?nde?002_nde?000ol0003o]/k/okK>k008okK>k0Ko00001Oooool00ol0003o
ooooooooo`0Cooooo`008oooool00ol0003oooooooooo`06ooooo`?o0000O?ooool00ol0003oHYob
of:OlP06of:OlP03o`000?mQY?GoHJCe00GoHJCe00?o0000ofJ[n?mVZoP01OmVZoP00ol0003oL;Gj
og2enP06og2enP03o`000?mm_ocoOKol00OoOKol00?o0000ohk9o?n>bO`02On>bO`00ol0003oW]3i
oik@n@06oik@n@03o`000?nNd?Wo000000?o00003?nYf_P00ol0003o]=_dokCKm007okCKm0;o0000
0on_gOL00ol0003o]]gdokKMm00;okKMm003o`000?nkf^oo^m[_00;o^m[_0ol00006ok7Im003o`00
0?nde?3o]=C`00[o]=C`00?o0000okK>k?nfc^`01?nfc^`6o`0000Sooooo00?o0000ooooooooool0
4oooool002;ooooo00?o0000ooooooooool01?ooool3o`00083ooooo00?o0000of:Ol_mRWo801_mR
Wo800ol0003oHJCeof6Tm@05of6Tm@03o`000?mVZoSoIZ_h00GoIZ_h00?o0000og2en_m`]OX01_m`
]OX00ol0003oOKologfoo007ogfoo0;o00002_n>bO`00ol0003oW]3ioik@n@04oik@n@?o00001?nM
eO/00ol0003oZM[hojWJn00:ojWJn0;o00001?ndfo@3o`0000Ko[mgg0_l0000<okKMm004o`000?nk
f^oo0000o`0000[o/MWd0_l0000;okCDl003o`000?nfc^co]/k/00Go00003?ooool00ol0003ooooo
ooooo`0Cooooo`008_ooool01?l0003oooooooooooooool3o`0008Cooooo00?o0000of:Ol_mRWo80
1_mRWo800ol0003oHJCeof6Tm@05of6Tm@03o`000?mVZoSoIZ_h00GoIZ_h0_l00007og2enP;o0000
2Omm_o`00ol0003oS/Wlohk9o008ohk9o003o`000?nNd?WoW]3i00?o00000onMeO/00ol0003oWMGk
oigEn`02oigEn`;o00003?nYf_P01?l0003o]=_do`000?l0000;ojoMm`03o`000?nfgOCo]]gd00Wo
]]gd0ol0000=ok7Im003o`000?nde?3o]=C`00So]=C`1Ol0000?ooooo`03o`000?oooooooooo01?o
oooo000Rooooo`Co0000R?ooool00ol0003oHYobof:OlP06of:OlP03o`000?mQY?GoHJCe00GoHJCe
00?o0000ofJ[n?mVZoP01_mVZoP00ol0003oL;Gjog2enP06og2enP03o`000?mm_ocoOKol00OoOKol
00?o0000ohk9o?n>bO`01_n>bO`4o`0000OoWMGk00?o0000oigEnonMeO/00onMeO/00ol0003oZM[h
ojWJn009ojWJn0?o00003On_gOL2o`0000Ko]]gd0ol00003ojgLn003o`000?nafOCo/MWd00_o/MWd
00?o0000okCDl?nde?001?nde?05o`0001;ooooo00?o0000ooooooooool04oooool002;ooooo0ol0
002:ooooo`03o`000?mRWo;oHYob00KoHYob00?o0000of6TmOmQY?D01OmQY?D00ol0003oIZ_hofJ[
n006ofJ[n003o`000?m`]O[oL;Gj00KoL;Gj00?o0000ogfoo?mm_o`01omm_o`00ol0003oS/Wlohk9
o005o`0000CoT<om0_l00006oigEn`03o`000?nMeO_oWMGk00?oWMGk0_l00006ojWJn0?o00000onV
g?X00ol0003o[mggojoMm`0<ojoMm`03o`000?nfgOCo]]gd00?o00001on]g?P00ol0003o/MWdok7I
m00;ok7Im003o`000?nde?3o]=C`00Co00005oooool00ol0003oooooooooo`0Booooo`009?ooool0
0ol0003oooooooooo`29ooooo`oo00000_mQY?D00ol0003oIZ_hofJ[n006ofJ[n003o`000?m`]O[o
L;Gj00KoL;Gj00?o0000ogfoo?mm_o`00omm_o`6o`0000_oT<om00?o0000oigEnonMeO/00onMeO/0
0ol0003oWMGkoigEn`05oigEn`03o`000?nYf_SoZM[h00?o00001onVg?X2o`0000co[mgg0ol0000;
ojgLn0;o00002_nafO@5o`0001[ooooo00?o0000ooooooooool04_ooool001Kooooo00?ok^k^o`00
0?l000000_l000000ol@413oooooooooo`07ooooo`03o`000?oooooooooo08Wooooo00?o0000ogJX
l_mfZ?801_mfZ?800ol0003oM:kfogB^mP02ogB^mQ[o00001_n4a_d00ol0003oT<omoi3?o@09oi3?
o@;o00001?nMeO/00ol0003oWMGkoigEn`04oigEn`?o00003?nVg?X00ol0003o[mggojoMm`07ojoM
m`;o00000onXg_X00ol0003o[MchojgLn00:ojgLn003o`000?nafOCo/MWd00Co/MWd1Ol0000Moooo
o`03o`000?oooooooooo01;ooooo000Fooooo`05ogMgMonHV9Soooooo`000?mgMgL02oooool00ol0
003oooooooooo`29ooooo`03o`000?mfZ?;oMZSb00KoMZSb00?o0000ogB^m_md[_H01_md[_H00ol0
003oM[GiogJen@06ogJen@03o`000?mk_OcoNkgl00KoNkgl00?o0000ohC6oOn4a_d01on4a_d2o`00
00_oT<om0_l00003oigEn`03o`000?nMeO_oWMGk00?o00000onMfO`2o`0000_oY]cj0_l00004ojoM
m`?o00001_nXg_X00ol0003o[MchojgLn00:ojgLn003o`000?nafOCo/MWd00Co00008Oooool00ol0
003oooooooooo`0Booooo`005_ooool01Ol@413oooooooooool0003o410@00cooooo00?o0000oooo
ooooool0ROooool00ol0003oMZSbogJXlP06ogJXlP03o`000?md[_KoM:kf00KoM:kf00?o0000ogJe
nOmf]OT01_mf]OT00ol0003oNkglog^mo006og^mo0;o00002On4a_d00ol0003oT<omoi3?o@0:oi3?
o@03o`000?nMeO_oWMGk00?o00002?nMfO`2o`0000_oY]cj00Co0000ojoMmol0003o00002_nXg_X2
o`0000[o[Mch1?l0000Tooooo`03o`000?oooooooooo01;ooooo000Fooooo`03o`000?oooooooooo
00;o00003Oooool00ol0003oooooooooo`29ooooo`03o`000?mfZ?;oMZSb00KoMZSb00?o0000ogB^
m_md[_H01_md[_H00ol0003oM[GiogJen@06ogJen@03o`000?mk_OcoNkgl00OoNkgl00?o0000ohC6
oOn4a_d01on4a_d2o`0000WoT<om1?l00002oigIo003o`000?nMfOcoWMWl00SoWMWl00?o0000ojKL
n_nVg?X01onVg?X4o`0000goZ=kj00?o0000ojgLn?n]g?P01?n]g?P4o`0002Oooooo00?o0000oooo
ooooool04_ooool001Kooooo00?o0000ooooooooool00_l0000>ooooo`03o`000?oooooooooo08Wo
oooo00?o0000ogJXl_mfZ?801_mfZ?800ol0003oM:kfogB^mP06ogB^mP;o00001omf]OT00ol0003o
Nkglog^mo007og^mo0;o00002On4a_d01?l0003oT<omoi3?oOn@cod5o`0000CoUM?m0_l000000onM
fOco0000oigIo009oigIo0;o00000_nVg?X5o`0000CoXmgl0_l0000<ojSNnP03o`000?n]g?So[Mch
00Co0000:_ooool00ol0003oooooooooo`0Booooo`005_ooool01Ol@413oooooooooool0003o410@
00oooooo00?o0000ooooooooool0ROooool00ol0003oMZSbogJXlP06ogJXlP03o`000?md[_KoM:kf
00OoM:kf00?o0000ogJenOmf]OT01Omf]OT00ol0003oNkglog^mo008og^mo003o`000?n4a_goQ<Km
00?oQ<Km1ol0000;oiGCo@?o00002_nMfO`3o`0000_oXmgl0_l00009ojSNnPCo0000;_ooool00ol0
003oooooooooo`0Booooo`005_ooool01OmgMgOoV9RHooooool0003oMgMg013ooooo0_l0002:oooo
o`03o`000?mfZ?;oMZSb00KoMZSb00?o0000ogB^m_md[_H01omd[_H00ol0003oM[GiogJen@05ogJe
n@03o`000?mk_OcoNkgl00KoNkgl1ol00006ohk=o@;o00003?nEdod2o`0000KoWMWl0ol00003oikK
o003o`000?nSgOcoXmgl00[oXmgl0_l00002ojSNnPKo0000<Oooool00ol0003oooooooooo`0Boooo
o`005_ooool01Oo^k^ko0`<3o`000?l0003ok^k^01;ooooo00?o0000ooooooooool0R?ooool00ol0
003oMZSbogJXlP06ogJXlP03o`000?md[_KoM:kf00OoM:kf00?o0000ogJenOmf]OT01Omf]OT00ol0
003oNkglog^mo005o`0000CoR/Gk00?o0000ohk=oOn>cOd02?n>cOd2o`0000_oUM?m0_l00002oigI
o0?o00001onNfo`2o`0000_oXmgl1_l0000dooooo`03o`000?oooooooooo01;ooooo000/ooooo`03
o`000?oooooo000008[ooooo00?o0000ogJXl_mfZ?801_mfZ?800ol0003oM:kfogB^mP03ogB^mPko
00002_n:aO/2o`0000[oS/gm0_l00009oiGCo@Co00003?nNfo`2o`0000KoXmgl1Ol0000hooooo`03
o`000?oooooooooo01;ooooo000_ooooo`03o`000?oooooooooo08Sooooo3_l00006ohRgm@03o`00
0?n8__WoR;ki00GoR;ki0_l0000:oh[5n`03o`000?n>cOgoS/gm00WoS/gm0_l00002oiGCo@Go0000
0_nKeo`00ol0003oVmOlo`00000=oikKo003o`000?nSgOcoXmgl00Go0000??ooool00ol0003ooooo
ooooo`0Aooooo`00<?ooool00ol0003oooooooooo`27ooooo`;o00002?n9/O000ol0003oR;OeohRg
m@08ohRgm@03o`000?n8__WoR;ki00KoR;ki00?o0000oh[5non:aO/02?n:aO/00ol0003oS/gmohk=
o@09ohk=o@?o00002?nKeo`01?l0003oVmOlo`000?l0000;oikKo0Go0000?oooool00ol0003ooooo
ooooo`0Aooooo`00<Oooool00ol0003oooooooooo`27ooooo`;o00002?n9/O000ol0003oR;OeohRg
m@08ohRgm@03o`000?n8__WoR;ki00KoR;ki0_l00009oh[5n`;o00001_n>cOd3o`0000?oVM;l00?o
0000oi_Go?nKeo`01_nKeo`00ol0003oVmOloi_Go002o`0000KoW]_l1?l00013ooooo`03o`000?oo
oooooooo017ooooo000booooo`03o`000?oooooooooo08Oooooo0_l00008ohVal003o`000?n8]oGo
R;Oe00SoR;Oe00?o0000ohRnnOn8__T01on8__T2o`0000WoR/Gk00?o0000ohk=oOn>cOd00ol00007
oiWBo003o`000?nKeocoVmOl00KoVmOl00Go0000oi_Go?nKeocoVmOlo`000002oikKo0Co0000A_oo
ool00ol0003oooooooooo`0Aooooo`00<oooool00ol0003oooooooooo`27ooooo`;o00002?n9/O00
0ol0003oR;OeohRgm@08ohRgm@03o`000?n8__WoR;ki00SoR;ki00?o0000oh[5non:aO/00on:aO/6
o`0000_oVM;l0_l00007oi_Go003o`000?nKeocoVmOl00Co0000BOooool00ol0003oooooooooo`0A
ooooo`00=?ooool2o`0008Sooooo0_l00008ohVal003o`000?n8]oGoR;Oe00SoR;Oe00?o0000ohRn
nOn8__T01_n8__T7o`0000KoVLci00?o0000oiWBo?nId_`02_nId_`00ol0003oVmOloi_Go004oi_G
o0?o0000COooool00ol0003oooooooooo`0Aooooo`00=_ooool00ol0003oooooooooo`26ooooo`;o
00002?n9/O000ol0003oR;OeohRgm@08ohRgm@03o`000?n8__WoR;ki00Go00001?nIaOH00ol0003o
VLcioiW<n@07oiW<n@;o00002onId_`00ol0003oVmOloi_Go003o`000003ooooool0003ooooo04go
oooo00?o0000ooooooooool04Oooool003Oooooo0_l00027ooooo`;o00002?n9/O000ol0003oR;Oe
ohRgm@06ohRgm@Co00002_nIaOH00ol0003oVLcioiW<n@08oiW<n@;o00002?nId_`4o`0000Gooooo
00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Aooooo`00=_ooool00ol0003oooooo`00
0028ooooo`;o00002?n9/O000ol0003oR;OeohRgm@05o`0000CoV[ka00?o0000oiW5m_nIaOH02?nI
aOH2o`0000[oVLci00?o0000oiWBo?nId_`01Ol0000:ooooo`03o`000?oooooooooo04[ooooo00?o
0000ooooooooool04Oooool003Wooooo00?o0000ooooooooool0Q_ooool2o`0000CoRK7`1_l0000:
oiZnl@03o`000?nIaOKoVLGf00WoVLGf00?o0000oiW<nOnIc?T01onIc?T5o`0000kooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`0Aooooo`00>_ooool00ol0003oooooooooo`26oooo
o`Go00001_nK^>`00ol0003oV[kaoiZnl@08oiZnl@03o`000?nIaOKoVLGf00WoVLGf00?o0000oiW<
nOnIc?T00onIc?T5o`0001;ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Aoooo
o`00>oooool00ol0003oooooooooo`26ooooo`03o`000?nK^>coVkS/00SoVkS/00?o0000oiZnlOnJ
__402?nJ__400ol0003oVLGfoiW5mP09oiW5mP03o`000?nIc?Wo000000?o00005oooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo013ooooo000looooo`03o`000?oooooooooo08Kooooo
00?o0000oi^hk?nK^>`02?nK^>`00ol0003oV[kaoiZnl@08oiZnl@03o`000?nIaOKoVLGf00SoVLGf
0ol0000Kooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04?ooool003gooooo0_l0
0027ooooo`03o`000?nK^>coVkS/00SoVkS/00?o0000oiZnlOnJ__402?nJ__400ol0003oVLGfoiW5
mP04oiW5mP?o00007oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo013ooooo000o
ooooo`03o`000?oooooooooo08Gooooo00?o0000oi^hk?nK^>`02?nK^>`00ol0003oV[kaoiZnl@08
oiZnl@03o`000?nIaOKoVLGf00?o00008_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooo
oooo013ooooo0010ooooo`03o`000?oooooooooo08Gooooo00?o0000oi^hk?nK^>`02?nK^>`00ol0
003oV[kaoiZnl@06oiZnl@Co00009_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
013ooooo0011ooooo`;o0000Q_ooool00ol0003oVkS/oi^hk008oi^hk003o`000?nJ__7oV[ka00Go
0000:oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo013ooooo0010ooooo`03o`00
0?oooooo000008Oooooo00?o0000oi^hk?nK^>`01onK^>`5o`0002oooooo00?o0000ooooooooool0
@oooool00ol0003oooooooooo`0@ooooo`00@oooool00ol0003oooooooooo`25ooooo`03o`000?nK
^>coVkS/00?oVkS/1?l0000dooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool04?oo
ool004Cooooo00?o0000ooooooooool0QOooool00ol0003oVkS/o`000003o`0003Sooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`0@ooooo`00AOooool00ol0003oooooooooo`25oooo
o`;o0000??ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo013ooooo0016ooooo`;o
0000QOooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool04?ooool004Sooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo043ooooo00?o0000ooooooooool03oooool004Wooooo00?o0000ooooooooool0POoo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool03ooo
ool004[ooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool03oooool004[ooooo0_l00021ooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0?ooooo`00C?ooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`0?ooooo`00COooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo047ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0?ooooo`00C_ooool00ol0003ooooooooo
o`1looooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`0?ooooo`00Coooool2o`0007cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo00oooooo001Aooooo`03o`000?oooooooooo07Wooooo00?o0000oooo
ooooool0@oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00oooooo001Booooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo00oooooo001Cooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0
AOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00oooooo001Dooooo`?o0000M_oo
ool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03ooo
ool005Cooooo0_l0001gooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0>ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd02?ooool00ol0003oooooooooo`1dooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0>ooooo`00>?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Sooooo00?o
0000ooooooooool0Loooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool03_ooool003Sooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo00Sooooo0_l0001cooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0>ooooo`00>?ooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool02oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo04[ooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`0>ooooo`00>?ooool01Ol0003ooooooooooooo
oooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00=ooooo`03o`000?oooooooooo06oooooo
00?o0000ooooooooool0Boooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00kooooo
000hooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo00kooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0COooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo00kooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`00013ooooo0_l0001^ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0>ooooo`00Goooool00ol0003oooooooooo`1[ooooo`03o`000?oo
oooooooo04oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0>ooooo`00H?ooool0
0ol0003oooooooooo`1Zooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0>ooooo`00HOooool2o`0006[ooooo00?o0000ooooooooool0D?ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo00gooooo001Sooooo`03o`000?oooooooooo06Oo
oooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00go
oooo001Tooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0D_ooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo00gooooo001Uooooo`03o`000?oooooooooo06Gooooo00?o
0000ooooooooool0Doooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00gooooo001V
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo00gooooo001Vooooo`?o0000I?ooool00ol0003oooooooooo`1Eoooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03Oooool006Sooooo00?o0000oooooooo
ool0H_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool03Oooool006Wooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Gooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool03Oooool006[ooooo0_l0001Qooooo`03o`000?oo
oooooooo05Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0=ooooo`00K?ooool0
0ol0003oooooooooo`1Nooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0=ooooo`00KOooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo
05Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0=ooooo`00K_ooool00ol0003o
ooooooooo`1Looooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0<ooooo`00Koooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo05_ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0<ooooo`00Koooool3o`0005_ooooo00?o
0000ooooooooool0G?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00cooooo001a
ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo00cooooo001booooo`03o`000?oooooooooo05Sooooo00?o0000oooo
ooooool0GOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00cooooo001cooooo`;o
0000F?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool03?ooool007Gooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`1Oooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool03?ooool007Kooooo00?o0000ooooooooool0E?oo
ool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03?oo
ool007Oooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`1Qooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool03?ooool007Sooooo0_l0001Cooooo`03o`000?oooooooooo
06;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0<ooooo`00N?ooool2o`0005?o
oooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00co
oooo001jooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0I?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00cooooo001kooooo`03o`000?oooooooooo04oooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00_ooooo001l
ooooo`;o0000Coooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool02oooool007kooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1Voooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02oooool007oooooo00?o0000oooooooo
ool0Boooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool02oooool0083ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1Xooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool02oooool0087ooooo0ol00019ooooo`03o`000?oo
oooooooo06Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0;ooooo`00M_ooool4
o`000003oa0@4?oooooooooo00Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1Z
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool007Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo06_ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0;ooooo`00N?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00_ooooo001hooooo`03o`000?oooooooooo00[ooooo0_l00016ooooo`03o`00
0?oooooooooo06cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;ooooo`00G?oo
ool3o`000003oa0@4?oooooooooo01Kooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0;ooooo`00G_ooool00ol@413o^[Zjooooo`0Gooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0@_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool02_ooool005kooooo00?oV9RHoc8b<_ooool05oooool00ol0003oooooooooo`0>oooo
o`;o0000@_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool02_ooool005kooooo00?ogMgMo`000?nj^[X05Oooool00omEEEGoIVIVo`00000@ooooo`;o
0000@_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool02_ooool005kooooo00?oEEEEogMgMom4A4@0:_ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo077ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0:ooooo`00GOoo
ool01OoMgMgo410@oooooolQ8B7ogMgM02[ooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool005gooooo00Go
IVIVohN7QoooooooV9RHoeEEE@0[ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
L_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo001Looooo`03onk^k_l0
003ok^k^00;ooooo00?o0000omgMgOooool0:_ooool2o`0003gooooo00?o0000ooooooooool0Looo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo001Looooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool0:oooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo07Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`00TOooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0:ooooo`00TOooool2o`0003[ooooo00?o0000ooooooooool0M_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo002Cooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo002Dooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0N?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo002Eooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool0N?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo002F
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo002Gooooo`;o0000=?ooool00ol0003oooooooooo`1joooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool009Wooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02Oooool009Wooooo0ol0000aooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`09ooooo`00Voooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo07gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`00W?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`09ooooo`00WOooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
07oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`00W_ooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`09ooooo`00Woooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo083ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`00X?ooool2o`0002_ooooo00?o
0000ooooooooool0POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo002Q
ooooo`;o0000:_ooool00ol0003oooooooooo`22ooooo`05o`000?ooooooooooooooool000002_oo
ool00:?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`23ooooo`04o`000?oooooo
ooooo`0000[ooooo002Tooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Q?ooool0
0ol0003oooooo`00000:ooooo`00YOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
08Gooooo0_l0000:ooooo`00Y_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo08Co
oooo0ol0000:ooooo`00Yoooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo083ooooo
1?l0000=ooooo`00Z?ooool01?l0003oooooo`000?l0000Qooooo`03o`000?oooooooooo07cooooo
1?l0000Aooooo`00S_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01_ooool2o`0002;ooooo00?o0000ooooooooool0N?ooool4o`0001Gooooo
002@ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Oooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`1dooooo`Co00006Oooool0093ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0L?ooool4o`0001gooooo002@ooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b
<_ooool02Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo06gooooo0ol0000Qoooo
o`00T?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`02oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo06Wooooo1?l0000Tooooo`00T?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`1Uooooo`Co0000:?ooool0093ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0?ooooo`?o00006_ooool00ol0003oooooooooo`1Qooooo`Co0000;?ooool008kooooo00?o
EEEEofIVI_l000003Oooool4o`0000kooooo0_l0000Kooooo`03o`000?oooooooooo05gooooo1?l0
000`ooooo`00/_ooool2o`0001Wooooo00?o0000ooooooooool0FOooool4o`0003Cooooo002doooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0EOooool4o`0003Sooooo002eooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0DOooool4o`0003cooooo002fooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0COooool4o`00043ooooo002gooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0BOooool4o`0004Cooooo002hooooo`;o00004oooool0
0ol0003oooooooooo`15ooooo`Co0000B?ooool00;Wooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`11ooooo`Co0000C?ooool00;[ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0nooooo`?o0000D?ooool00;_ooooo0_l0000@ooooo`03o`000?oooooooooo03[ooooo
1?l0001Cooooo`00_Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Kooooo1?l0
001Gooooo`00__ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03;ooooo1?l0001K
ooooo`00_oooool2o`0000cooooo00?o0000ooooooooool0;_ooool4o`0005oooooo002oooooo`;o
00003?ooool00ol0003oooooooooo`0Zooooo`Co0000Hoooool00<7ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Vooooo`Co0000Ioooool00<;ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Rooooo`Co0000Joooool00<?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Nooooo`Co0000Koooool00<Cooooo0_l00007ooooo`03o`000?oooooooooo
01[ooooo1?l0001cooooo`00a_ooool3o`0000Cooooo00?o0000ooooooooool05_ooool4o`0007Oo
oooo0036ooooo`;o00001Oooool00ol0003oooooooooo`0Cooooo`?o0000Noooool00<Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`Co0000O_ooool00<Wooooo00Go0000
ooooooooooooooooo`00000=ooooo`Co0000P_ooool00<[ooooo00Co0000oooooooooooo00002Ooo
ool4o`0008Kooooo003;ooooo`03o`000?oooooo000000Gooooo1?l0002:ooooo`00c?ooool7o`00
08kooooo0032ooooo`Go00001_ooool2o`0009;ooooo0032ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@0V_ooool00<?ooooo00?oV9RHob4Q8Oo^k^h0Voooool00<Cooooo00?oV9RHob4Q8Oo^k^h0V_oo
ool00<Gooooo00?oMgMgofIVI_ooool0VOooool00<Kooooo00?o0000ooooooooool0V?ooool00<;o
oooo00Go0000okZj^_ooooooV9RHoa0@402Jooooo`00`_ooool01OnHV9So410@o`000?lQ8B7oc<c<
09[ooooo003oooooof;ooooo003oooooof;ooooo003oooooof;ooooo003oooooof;ooooo003ooooo
of;ooooo003oooooof;ooooo003oooooof;ooooo003oooooof;ooooo003oooooof;ooooo003ooooo
of;ooooo003oooooof;ooooo003oooooof;ooooo003oooooof;ooooo002Uooooo`?o000000?o410@
ooooooooool0]_ooool009?ooooo0_l0000;ooooo`03o`000?nj^[[ooooo00Cooooo00?o410@okZj
^_ooool01Oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2Ioooo
o`00Toooool00ol0003oooooooooo`0:ooooo`;o<S8b1Oooool00onHV9So<S8booooo`05ooooo`;o
<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8bV_ooool008Sooooo00Go410@o`000?l0003o
0000oa0@4006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`00
0?nj^[X01?ooool00ooMgMgo0000okZj^P05ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`00
0?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X01Oooool0
1OnHV9So0000o`000?m4A4Co^[Zj00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM073ooooo002:ooooo`03o`000?oooooooooo00Kooooo
00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@
4004ooooo`03oeEEEOmgMgOoA4A400Gooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^
k_mgMgOo410@00Cooooo00?o0000ooooooooool00oooool00oo<c<co0000oa0@4005ooooo`06oa0@
4?nj^[[ok^k^ogMgMol@413ooooo1_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool0Koooool008[ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0[ooooo00GogMgMoa0@4?oooooo8B4QomgM
g@0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0;ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`1^ooooo`00R_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^
2_ooool01OmVIVKoQhN7oooooonHV9SoEEEE00_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo1_l00002ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`1_ooooo`00R_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2Oooool00oo^k^ko0000onk^kP02oooo
o`03o`000?oMgMgooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`0L?ooool008Oooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00Co410@o`000?l0003o
oooo0_l000000ol@413oooooooooo`06ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003o
ooooooooo`09ooooo`03oa0@4?l0003o000000?o00002_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool0L_ooool008Oooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03o`000?oooooooooo07;ooooo0027ooooo`Oo00001Oooool2o`00027ooooo00?o0000oooo
ooooool01Oooool2o`0000gooooo00?o0000ooooooooool02oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l0001aooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00\
\>"],
  ImageRangeCache->{{{0, 352.438}, {392.188, 0}} -> {-0.0365789, -0.0401404, \
0.00334761, 0.00334761}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11253 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.066106 1.21212 -1.11022e-16 1.21212 [
[.5 1.12503 -44 0 ]
[.5 1.12503 44 24.5 ]
[.03831 .17557 -5.85635 -9 ]
[.03831 .17557 .14365 0 ]
[.12814 .13981 -17.2021 -9 ]
[.12814 .13981 .79789 0 ]
[.22015 .10319 -16.8352 -9 ]
[.22015 .10319 1.16484 0 ]
[.31441 .06568 -16.4682 -9 ]
[.31441 .06568 1.53178 0 ]
[.411 .02725 -16.1013 -9 ]
[.411 .02725 1.89873 0 ]
[.51 -0.01213 -5.24477 -9 ]
[.51 -0.01213 .75523 0 ]
[.21792 .02683 -9.25094 -12 ]
[.21792 .02683 .74906 0 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[.1484 .76875 -18 -3.08128 ]
[.1484 .76875 0 5.91872 ]
[.29382 .89692 -6 -3.18183 ]
[.29382 .89692 0 5.81817 ]
[.42456 1.01215 -18 -3.26907 ]
[.42456 1.01215 0 5.73093 ]
[.54272 1.11629 -6 -3.34548 ]
[.54272 1.11629 0 5.65452 ]
[.22112 .91822 -10 -4.24244 ]
[.22112 .91822 0 7.75756 ]
[.03467 .19213 -6 -2.71522 ]
[.03467 .19213 0 6.28478 ]
[.02559 .27239 -18 -2.7611 ]
[.02559 .27239 0 6.2389 ]
[.01617 .35567 -18 -2.80881 ]
[.01617 .35567 0 6.19119 ]
[.00638 .44212 -18 -2.85847 ]
[.00638 .44212 0 6.14153 ]
[-0.00378 .53194 -18 -2.9102 ]
[-0.00378 .53194 0 6.0898 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 1.11253 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.12503 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
.04875 .18654 m
.0558 .18375 L
s
[(0)] .03467 .19213 1 -0.39662 Mshowa
.03972 .26693 m
.04679 .2642 L
s
[(0.2)] .02559 .27239 1 -0.38642 Mshowa
.03035 .35034 m
.03744 .34767 L
s
[(0.4)] .01617 .35567 1 -0.37582 Mshowa
.02062 .43693 m
.02774 .43433 L
s
[(0.6)] .00638 .44212 1 -0.36478 Mshowa
.01051 .52689 m
.01765 .52437 L
s
[(0.8)] -0.00378 .53194 1 -0.35329 Mshowa
0 .62042 m
.00717 .61797 L
s
[(1)] -0.01434 .62532 1 -0.3413 Mshowa
.125 Mabswid
.04653 .20636 m
.05076 .2047 L
s
.04428 .22637 m
.04851 .22471 L
s
.04201 .24656 m
.04625 .24491 L
s
.03741 .28749 m
.04165 .28587 L
s
.03508 .30825 m
.03933 .30663 L
s
.03272 .32919 m
.03698 .32759 L
s
.02795 .37168 m
.03221 .37009 L
s
.02553 .39322 m
.02979 .39164 L
s
.02309 .41497 m
.02735 .4134 L
s
.01813 .45909 m
.0224 .45755 L
s
.01561 .48147 m
.01989 .47994 L
s
.01307 .50407 m
.01736 .50255 L
s
.00792 .54993 m
.01221 .54843 L
s
.00531 .5732 m
.0096 .5717 L
s
.00267 .59669 m
.00696 .59521 L
s
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
.5561 .7194 m
.04875 .18654 L
s
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.5561 .7194 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
0 0 m
1 0 L
1 1.11253 L
0 1.11253 L
closepath
clip
newpath
.5 Mabswid
.625 .726 .919 r
.52593 .68772 .5561 .7194 .58394 .7109 .55403 .68189 Metetra
.623 .745 .934 r
.55403 .68189 .58394 .7109 .61197 .70234 .58236 .67587 Metetra
.623 .764 .947 r
.58236 .67587 .61197 .70234 .64019 .69372 .61092 .66952 Metetra
.624 .783 .958 r
.61092 .66952 .64019 .69372 .66861 .68504 .63969 .6627 Metetra
.628 .801 .965 r
.63969 .6627 .66861 .68504 .69723 .6763 .66869 .65531 Metetra
.634 .815 .97 r
.66869 .65531 .69723 .6763 .72605 .6675 .69789 .64727 Metetra
.643 .826 .97 r
.69789 .64727 .72605 .6675 .75507 .65863 .72729 .63852 Metetra
.655 .832 .968 r
.72729 .63852 .75507 .65863 .7843 .6497 .75687 .62905 Metetra
.667 .832 .963 r
.75687 .62905 .7843 .6497 .81374 .64071 .78663 .61886 Metetra
.678 .828 .955 r
.78663 .61886 .81374 .64071 .84339 .63166 .81656 .608 Metetra
.688 .818 .945 r
.81656 .608 .84339 .63166 .87325 .62254 .84666 .59655 Metetra
.696 .804 .933 r
.84666 .59655 .87325 .62254 .90333 .61335 .87691 .58461 Metetra
.7 .788 .919 r
.87691 .58461 .90333 .61335 .93362 .6041 .90734 .57231 Metetra
.701 .769 .905 r
.90734 .57231 .93362 .6041 .96413 .59478 .93794 .55978 Metetra
.578 .709 .932 r
.49498 .6552 .52593 .68772 .55403 .68189 .52331 .65194 Metetra
.576 .727 .945 r
.52331 .65194 .55403 .68189 .58236 .67587 .5519 .64834 Metetra
.579 .747 .957 r
.5519 .64834 .58236 .67587 .61092 .66952 .58076 .64416 Metetra
.587 .768 .965 r
.58076 .64416 .61092 .66952 .63969 .6627 .60988 .63913 Metetra
.601 .788 .97 r
.60988 .63913 .63969 .6627 .66869 .65531 .63923 .63304 Metetra
.618 .806 .972 r
.63923 .63304 .66869 .65531 .69789 .64727 .66881 .62572 Metetra
.64 .819 .969 r
.66881 .62572 .69789 .64727 .72729 .63852 .69858 .61708 Metetra
.662 .828 .963 r
.69858 .61708 .72729 .63852 .75687 .62905 .72853 .60705 Metetra
.683 .831 .954 r
.72853 .60705 .75687 .62905 .78663 .61886 .75863 .59568 Metetra
.701 .829 .943 r
.75863 .59568 .78663 .61886 .81656 .608 .78886 .58306 Metetra
.716 .821 .93 r
.78886 .58306 .81656 .608 .84666 .59655 .81922 .56933 Metetra
.725 .809 .917 r
.81922 .56933 .84666 .59655 .87691 .58461 .8497 .55471 Metetra
.73 .794 .903 r
.8497 .55471 .87691 .58461 .90734 .57231 .8803 .53945 Metetra
.73 .777 .89 r
.8803 .53945 .90734 .57231 .93794 .55978 .91103 .52381 Metetra
.529 .69 .941 r
.4632 .62183 .49498 .6552 .52331 .65194 .49173 .62087 Metetra
.529 .707 .953 r
.49173 .62087 .52331 .65194 .5519 .64834 .52056 .61946 Metetra
.536 .727 .962 r
.52056 .61946 .5519 .64834 .58076 .64416 .5497 .61724 Metetra
.552 .749 .969 r
.5497 .61724 .58076 .64416 .60988 .63913 .57913 .61382 Metetra
.577 .772 .972 r
.57913 .61382 .60988 .63913 .63923 .63304 .60882 .60889 Metetra
.606 .792 .97 r
.60882 .60889 .63923 .63304 .66881 .62572 .63875 .60221 Metetra
.638 .809 .965 r
.63875 .60221 .66881 .62572 .69858 .61708 .6689 .59362 Metetra
.669 .82 .956 r
.6689 .59362 .69858 .61708 .72853 .60705 .69921 .58306 Metetra
.697 .825 .944 r
.69921 .58306 .72853 .60705 .75863 .59568 .72966 .57057 Metetra
.72 .824 .93 r
.72966 .57057 .75863 .59568 .78886 .58306 .76023 .55629 Metetra
.737 .818 .915 r
.76023 .55629 .78886 .58306 .81922 .56933 .79089 .54045 Metetra
.747 .809 .901 r
.79089 .54045 .81922 .56933 .8497 .55471 .82163 .52335 Metetra
.753 .796 .888 r
.82163 .52335 .8497 .55471 .8803 .53945 .85245 .50535 Metetra
.753 .782 .876 r
.85245 .50535 .8803 .53945 .91103 .52381 .88337 .48685 Metetra
.482 .67 .946 r
.43058 .58756 .4632 .62183 .49173 .62087 .45928 .58851 Metetra
.484 .685 .955 r
.45928 .58851 .49173 .62087 .52056 .61946 .48832 .58892 Metetra
.498 .705 .963 r
.48832 .58892 .52056 .61946 .5497 .61724 .5177 .58832 Metetra
.524 .729 .968 r
.5177 .58832 .5497 .61724 .57913 .61382 .54741 .58623 Metetra
.558 .754 .969 r
.54741 .58623 .57913 .61382 .60882 .60889 .57742 .58224 Metetra
.598 .777 .966 r
.57742 .58224 .60882 .60889 .63875 .60221 .6077 .57606 Metetra
.638 .795 .958 r
.6077 .57606 .63875 .60221 .6689 .59362 .6382 .56748 Metetra
.676 .808 .946 r
.6382 .56748 .6689 .59362 .69921 .58306 .66888 .55641 Metetra
.707 .814 .931 r
.66888 .55641 .69921 .58306 .72966 .57057 .6997 .54291 Metetra
.733 .815 .916 r
.6997 .54291 .72966 .57057 .76023 .55629 .73062 .52718 Metetra
.751 .811 .9 r
.73062 .52718 .76023 .55629 .79089 .54045 .76162 .50948 Metetra
.763 .804 .886 r
.76162 .50948 .79089 .54045 .82163 .52335 .79266 .4902 Metetra
.769 .794 .874 r
.79266 .4902 .82163 .52335 .85245 .50535 .82376 .46983 Metetra
.77 .783 .864 r
.82376 .46983 .85245 .50535 .88337 .48685 .85493 .44884 Metetra
.443 .652 .948 r
.39706 .55236 .43058 .58756 .45928 .58851 .42592 .55471 Metetra
.45 .666 .955 r
.42592 .55471 .45928 .58851 .48832 .58892 .45515 .55645 Metetra
.47 .686 .96 r
.45515 .55645 .48832 .58892 .5177 .58832 .48475 .55704 Metetra
.504 .71 .964 r
.48475 .55704 .5177 .58832 .54741 .58623 .51472 .5559 Metetra
.547 .736 .963 r
.51472 .5559 .54741 .58623 .57742 .58224 .54503 .55257 Metetra
.594 .76 .958 r
.54503 .55257 .57742 .58224 .6077 .57606 .57563 .5467 Metetra
.639 .779 .948 r
.57563 .5467 .6077 .57606 .6382 .56748 .60648 .53805 Metetra
.68 .793 .934 r
.60648 .53805 .6382 .56748 .66888 .55641 .63753 .52651 Metetra
.714 .8 .918 r
.63753 .52651 .66888 .55641 .6997 .54291 .66872 .51217 Metetra
.74 .803 .902 r
.66872 .51217 .6997 .54291 .73062 .52718 .70001 .49523 Metetra
.759 .801 .887 r
.70001 .49523 .73062 .52718 .76162 .50948 .73137 .47602 Metetra
.772 .797 .873 r
.73137 .47602 .76162 .50948 .79266 .4902 .76277 .455 Metetra
.779 .79 .862 r
.76277 .455 .79266 .4902 .82376 .46983 .7942 .43272 Metetra
.781 .783 .854 r
.7942 .43272 .82376 .46983 .85493 .44884 .82567 .40974 Metetra
.417 .639 .948 r
.36263 .5162 .39706 .55236 .42592 .55471 .39163 .51934 Metetra
.429 .652 .952 r
.39163 .51934 .42592 .55471 .45515 .55645 .42104 .52184 Metetra
.456 .671 .956 r
.42104 .52184 .45515 .55645 .48475 .55704 .45085 .52309 Metetra
.496 .695 .957 r
.45085 .52309 .48475 .55704 .51472 .5559 .48106 .52246 Metetra
.544 .72 .955 r
.48106 .52246 .51472 .5559 .54503 .55257 .51163 .51946 Metetra
.594 .743 .948 r
.51163 .51946 .54503 .55257 .57563 .5467 .54254 .51368 Metetra
.64 .762 .936 r
.54254 .51368 .57563 .5467 .60648 .53805 .57373 .50488 Metetra
.682 .775 .921 r
.57373 .50488 .60648 .53805 .63753 .52651 .60513 .49293 Metetra
.716 .784 .905 r
.60513 .49293 .63753 .52651 .66872 .51217 .6367 .47792 Metetra
.743 .788 .889 r
.6367 .47792 .66872 .51217 .70001 .49523 .66838 .46009 Metetra
.762 .789 .875 r
.66838 .46009 .70001 .49523 .73137 .47602 .70012 .43978 Metetra
.776 .788 .863 r
.70012 .43978 .73137 .47602 .76277 .455 .73191 .41751 Metetra
.783 .785 .854 r
.73191 .41751 .76277 .455 .7942 .43272 .76372 .39388 Metetra
.786 .781 .848 r
.76372 .39388 .7942 .43272 .82567 .40974 .79557 .36951 Metetra
.408 .635 .948 r
.32723 .47902 .36263 .5162 .39163 .51934 .35639 .4823 Metetra
.424 .645 .95 r
.35639 .4823 .39163 .51934 .42104 .52184 .38598 .48492 Metetra
.456 .662 .951 r
.38598 .48492 .42104 .52184 .45085 .52309 .41599 .48625 Metetra
.499 .684 .949 r
.41599 .48625 .45085 .52309 .48106 .52246 .44642 .48565 Metetra
.547 .706 .944 r
.44642 .48565 .48106 .52246 .51163 .51946 .47726 .48258 Metetra
.596 .727 .935 r
.47726 .48258 .51163 .51946 .54254 .51368 .50845 .47666 Metetra
.642 .744 .923 r
.50845 .47666 .54254 .51368 .57373 .50488 .53995 .46761 Metetra
.682 .757 .908 r
.53995 .46761 .57373 .50488 .60513 .49293 .57171 .4553 Metetra
.715 .766 .893 r
.57171 .4553 .60513 .49293 .6367 .47792 .60365 .43984 Metetra
.741 .773 .879 r
.60365 .43984 .6367 .47792 .66838 .46009 .63572 .42146 Metetra
.761 .776 .866 r
.63572 .42146 .66838 .46009 .70012 .43978 .66787 .40053 Metetra
.775 .778 .856 r
.66787 .40053 .70012 .43978 .73191 .41751 .70007 .37757 Metetra
.783 .778 .848 r
.70007 .37757 .73191 .41751 .76372 .39388 .73231 .35321 Metetra
.787 .778 .844 r
.73231 .35321 .76372 .39388 .79557 .36951 .76458 .32809 Metetra
.417 .639 .948 r
.29083 .44079 .32723 .47902 .35639 .4823 .32018 .44351 Metetra
.437 .647 .947 r
.32018 .44351 .35639 .4823 .38598 .48492 .34995 .44558 Metetra
.469 .66 .944 r
.34995 .44558 .38598 .48492 .41599 .48625 .38017 .44638 Metetra
.511 .677 .94 r
.38017 .44638 .41599 .48625 .44642 .48565 .41083 .44527 Metetra
.557 .695 .932 r
.41083 .44527 .44642 .48565 .47726 .48258 .44191 .44175 Metetra
.602 .712 .922 r
.44191 .44175 .47726 .48258 .50845 .47666 .47338 .43542 Metetra
.643 .727 .909 r
.47338 .43542 .50845 .47666 .53995 .46761 .50519 .42602 Metetra
.68 .739 .896 r
.50519 .42602 .53995 .46761 .57171 .4553 .53727 .41342 Metetra
.711 .749 .882 r
.53727 .41342 .57171 .4553 .60365 .43984 .56957 .39773 Metetra
.736 .757 .87 r
.56957 .39773 .60365 .43984 .63572 .42146 .60203 .37917 Metetra
.755 .763 .859 r
.60203 .37917 .63572 .42146 .66787 .40053 .6346 .35811 Metetra
.769 .767 .851 r
.6346 .35811 .66787 .40053 .70007 .37757 .66723 .33505 Metetra
.779 .771 .846 r
.66723 .33505 .70007 .37757 .73231 .35321 .69992 .31062 Metetra
.784 .773 .844 r
.69992 .31062 .73231 .35321 .76458 .32809 .73265 .28543 Metetra
.443 .652 .948 r
.25338 .40146 .29083 .44079 .32018 .44351 .28295 .40293 Metetra
.463 .655 .943 r
.28295 .40293 .32018 .44351 .34995 .44558 .31295 .40379 Metetra
.493 .663 .937 r
.31295 .40379 .34995 .44558 .38017 .44638 .3434 .40345 Metetra
.53 .675 .93 r
.3434 .40345 .38017 .44638 .41083 .44527 .37429 .40134 Metetra
.57 .688 .92 r
.37429 .40134 .41083 .44527 .44191 .44175 .40562 .39696 Metetra
.609 .7 .909 r
.40562 .39696 .44191 .44175 .47338 .43542 .43736 .38997 Metetra
.645 .712 .896 r
.43736 .38997 .47338 .43542 .50519 .42602 .46945 .38012 Metetra
.677 .723 .884 r
.46945 .38012 .50519 .42602 .53727 .41342 .50185 .3673 Metetra
.704 .733 .873 r
.50185 .3673 .53727 .41342 .56957 .39773 .53449 .35159 Metetra
.727 .741 .863 r
.53449 .35159 .56957 .39773 .60203 .37917 .56733 .33321 Metetra
.746 .749 .855 r
.56733 .33321 .60203 .37917 .6346 .35811 .6003 .3125 Metetra
.76 .756 .849 r
.6003 .3125 .6346 .35811 .66723 .33505 .63338 .28992 Metetra
.77 .763 .847 r
.63338 .28992 .66723 .33505 .69992 .31062 .66654 .26605 Metetra
.776 .769 .846 r
.66654 .26605 .69992 .31062 .73265 .28543 .69976 .24147 Metetra
.482 .67 .946 r
.21484 .36098 .25338 .40146 .28295 .40293 .2447 .36057 Metetra
.5 .668 .938 r
.2447 .36057 .28295 .40293 .31295 .40379 .27497 .35959 Metetra
.525 .67 .929 r
.27497 .35959 .31295 .40379 .3434 .40345 .30568 .35755 Metetra
.555 .675 .919 r
.30568 .35755 .3434 .40345 .37429 .40134 .33683 .35394 Metetra
.586 .683 .907 r
.33683 .35394 .37429 .40134 .40562 .39696 .36841 .34834 Metetra
.617 .691 .896 r
.36841 .34834 .40562 .39696 .43736 .38997 .40041 .34045 Metetra
.647 .699 .885 r
.40041 .34045 .43736 .38997 .46945 .38012 .43277 .33006 Metetra
.673 .708 .874 r
.43277 .33006 .46945 .38012 .50185 .3673 .46547 .31707 Metetra
.697 .718 .865 r
.46547 .31707 .50185 .3673 .53449 .35159 .49844 .30155 Metetra
.716 .727 .858 r
.49844 .30155 .53449 .35159 .56733 .33321 .53163 .28368 Metetra
.733 .736 .853 r
.53163 .28368 .56733 .33321 .6003 .3125 .565 .26377 Metetra
.747 .745 .85 r
.565 .26377 .6003 .3125 .63338 .28992 .5985 .24221 Metetra
.757 .754 .85 r
.5985 .24221 .63338 .28992 .66654 .26605 .63213 .21951 Metetra
.763 .763 .852 r
.63213 .21951 .66654 .26605 .69976 .24147 .66586 .19616 Metetra
.529 .69 .941 r
.17516 .3193 .21484 .36098 .2447 .36057 .20537 .31642 Metetra
.542 .683 .93 r
.20537 .31642 .2447 .36057 .27497 .35959 .23597 .31306 Metetra
.56 .679 .919 r
.23597 .31306 .27497 .35959 .30568 .35755 .26699 .30882 Metetra
.581 .679 .907 r
.26699 .30882 .30568 .35755 .33683 .35394 .29842 .30329 Metetra
.604 .68 .895 r
.29842 .30329 .33683 .35394 .36841 .34834 .33028 .29615 Metetra
.627 .684 .884 r
.33028 .29615 .36841 .34834 .40041 .34045 .36254 .28715 Metetra
.648 .689 .875 r
.36254 .28715 .40041 .34045 .43277 .33006 .39517 .27613 Metetra
.669 .696 .866 r
.39517 .27613 .43277 .33006 .46547 .31707 .42815 .26301 Metetra
.687 .704 .86 r
.42815 .26301 .46547 .31707 .49844 .30155 .46141 .24785 Metetra
.704 .713 .856 r
.46141 .24785 .49844 .30155 .53163 .28368 .49493 .23079 Metetra
.718 .723 .853 r
.49493 .23079 .53163 .28368 .565 .26377 .52867 .21207 Metetra
.73 .733 .853 r
.52867 .21207 .565 .26377 .5985 .24221 .56258 .192 Metetra
.739 .744 .856 r
.56258 .192 .5985 .24221 .63213 .21951 .59666 .17099 Metetra
.746 .755 .86 r
.59666 .17099 .63213 .21951 .66586 .19616 .63089 .14942 Metetra
.578 .709 .932 r
.13429 .27638 .17516 .3193 .20537 .31642 .16493 .27056 Metetra
.586 .698 .92 r
.16493 .27056 .20537 .31642 .23597 .31306 .19593 .26436 Metetra
.596 .69 .907 r
.19593 .26436 .23597 .31306 .26699 .30882 .22731 .2575 Metetra
.609 .684 .895 r
.22731 .2575 .26699 .30882 .29842 .30329 .25908 .24972 Metetra
.622 .681 .884 r
.25908 .24972 .29842 .30329 .33028 .29615 .29123 .24077 Metetra
.636 .68 .875 r
.29123 .24077 .33028 .29615 .36254 .28715 .32377 .2305 Metetra
.65 .682 .867 r
.32377 .2305 .36254 .28715 .39517 .27613 .35666 .21878 Metetra
.664 .686 .861 r
.35666 .21878 .39517 .27613 .42815 .26301 .38989 .20556 Metetra
.677 .692 .857 r
.38989 .20556 .42815 .26301 .46141 .24785 .42343 .19089 Metetra
.689 .701 .855 r
.42343 .19089 .46141 .24785 .49493 .23079 .45725 .17487 Metetra
.7 .71 .856 r
.45725 .17487 .49493 .23079 .52867 .21207 .49131 .15764 Metetra
.71 .721 .859 r
.49131 .15764 .52867 .21207 .56258 .192 .5256 .13944 Metetra
.718 .734 .863 r
.5256 .13944 .56258 .192 .59666 .17099 .5601 .12053 Metetra
.724 .746 .87 r
.5601 .12053 .59666 .17099 .63089 .14942 .59481 .1012 Metetra
.625 .726 .919 r
.09217 .23214 .13429 .27638 .16493 .27056 .12333 .22304 Metetra
.627 .712 .907 r
.12333 .22304 .16493 .27056 .19593 .26436 .15481 .21368 Metetra
.631 .7 .895 r
.15481 .21368 .19593 .26436 .22731 .2575 .18661 .20393 Metetra
.635 .69 .884 r
.18661 .20393 .22731 .2575 .25908 .24972 .21875 .19365 Metetra
.641 .683 .874 r
.21875 .19365 .25908 .24972 .29123 .24077 .25124 .18271 Metetra
.647 .679 .867 r
.25124 .18271 .29123 .24077 .32377 .2305 .28406 .17104 Metetra
.653 .678 .861 r
.28406 .17104 .32377 .2305 .35666 .21878 .31722 .15857 Metetra
.66 .679 .857 r
.31722 .15857 .35666 .21878 .38989 .20556 .35069 .14528 Metetra
.667 .683 .856 r
.35069 .14528 .38989 .20556 .42343 .19089 .38448 .13118 Metetra
.674 .69 .857 r
.38448 .13118 .42343 .19089 .45725 .17487 .41855 .11633 Metetra
.68 .699 .86 r
.41855 .11633 .45725 .17487 .49131 .15764 .45291 .10081 Metetra
.687 .709 .866 r
.45291 .10081 .49131 .15764 .5256 .13944 .48753 .08473 Metetra
.692 .722 .873 r
.48753 .08473 .5256 .13944 .5601 .12053 .52242 .06821 Metetra
.696 .736 .881 r
.52242 .06821 .5601 .12053 .59481 .1012 .55756 .05142 Metetra
.666 .738 .904 r
.04875 .18654 .09217 .23214 .12333 .22304 .08051 .17394 Metetra
.664 .723 .893 r
.08051 .17394 .12333 .22304 .15481 .21368 .11254 .16124 Metetra
.662 .709 .883 r
.11254 .16124 .15481 .21368 .18661 .20393 .14483 .14843 Metetra
.66 .697 .874 r
.14483 .14843 .18661 .20393 .21875 .19365 .1774 .13551 Metetra
.658 .688 .866 r
.1774 .13551 .21875 .19365 .25124 .18271 .21025 .12249 Metetra
.657 .681 .861 r
.21025 .12249 .25124 .18271 .28406 .17104 .24339 .10934 Metetra
.656 .676 .857 r
.24339 .10934 .28406 .17104 .31722 .15857 .27681 .09609 Metetra
.656 .675 .856 r
.27681 .09609 .31722 .15857 .35069 .14528 .31052 .08272 Metetra
.656 .676 .857 r
.31052 .08272 .35069 .14528 .38448 .13118 .34452 .06923 Metetra
.657 .681 .861 r
.34452 .06923 .38448 .13118 .41855 .11633 .37882 .05563 Metetra
.658 .688 .866 r
.37882 .05563 .41855 .11633 .45291 .10081 .41342 .04191 Metetra
.66 .697 .874 r
.41342 .04191 .45291 .10081 .48753 .08473 .44833 .02806 Metetra
.662 .709 .883 r
.44833 .02806 .48753 .08473 .52242 .06821 .48355 .01409 Metetra
.664 .723 .893 r
.48355 .01409 .52242 .06821 .55756 .05142 .51908 0 Metetra
0 g
.25 Mabswid
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282.75, 314.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005Q0001RB000`400?l00000o`00003ooooooomR
ooooo`00oooooomRooooo`00oooooomRooooo`00^_ooool4o`000003oa0@4?oooooooooo0:3ooooo
002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002loooo
o`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`00
0?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002jooooo`03oeEEEOmVIVKo
00000:Cooooo003oooooof;ooooo003oooooof;ooooo001Mooooo`;o00000_ooool2o`000?kooooo
001Mooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgMo_ooool005kooooo00CogMgMo`000?l@413o
c<c<:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`07oooool2o`0009oooooo001Nooooo`04onk^k_lQ8B7o410@onk^kR[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01cooooo
0ol000000onY^NCo0000o`00002Nooooo`00G_ooool01?lQ8B7oMgMgogMgMolb<S8Zooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001[ooooo0ol00003ojVi
i0?o0000WOooool005gooooo0_l00002ooooo`;o0000:Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`?o00001_nY^N@00ol0003oZKWTo`00002M
ooooo`00S?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00Eooooo`?o00000_nY^N@00ol0003oZKWTojVii003ojVii004o`000?nY^NCoZKWTo`0009cooooo
002<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@01;o
oooo1?l0000:ojVii004o`000?nY^NCoZKWTo`0009cooooo002<ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000013ooooo1?l000000onY]N;o0000ojVii009
ojVii005o`000?nY^NCoZKWTojVii?l00000Voooool008cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT03Oooool4o`000003ojVeh_l0003oZKGR00;oZKGR
00?o0000ojVii?nY^N@01onY^N@00ol0003oZKWTojVii002ojVii003o`000?oooooooooo09Sooooo
002/ooooo`Co00002?nY]N800ol0003oZKWTojVii006ojVii003o`000?nY^NCoZKWT00?oZKWT00?o
0000ooooooooool0Uoooool00:Wooooo1?l0000<ojVehP03o`000?nY^NCoZKWT00GoZKWT00?o0000
ojVii?nY^N@00onY^N@00ol0003oooooooooo`2Gooooo`00Yoooool6o`0000coZKGR00?o0000ojVi
i?nY^N@01OnY^N@00ol0003oZKWTojVii004ojVii003o`000?oooooooooo09Kooooo002Tooooo`Co
00001OnX/]l00ol0003oZKGRojVehP0:ojVehP03o`000?nY^NCoZKWT00CoZKWT00?o0000ojVii?nY
^N@01OnY^N@00ol0003oooooooooo`2Eooooo`00KOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`08?ooool3o`0000WoZ;;O00?o0000ojVe
h_nY]N802_nY]N800ol0003oZKWTojVii003ojVii003o`000?nY^NCoZKWT00KoZKWT00?o0000oooo
ooooool0U?ooool006gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q01gooooo0ol000000onX/]oo0000ojRbg`09ojRbg`03o`000?nY]N;o
ZKGR00_oZKGR00?o0000ojVii?nY^N@00_nY^N@00ol0003oZKWTojVii006ojVii003o`000?oooooo
oooo09Cooooo001]ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000001_ooooo0ol000001OnX/=go0000ojRbgonX/]oo000000[oZ;;O00?o0000ojVeh_nY]N80
2_nY]N800ol0003oZKWTojVii002ojVii003o`000?nY^NCoZKWT00OoZKWT00?o0000ooooooooool0
Toooool006gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B406?ooool3o`0000GoZ;3M00?o0000ojRbgonX/]l02onX/]l00ol0003oZKGRojVehP0:ojVehP05
o`000?nY^NCoZKWTojVii?l000002_nY^N@00ol0003oooooooooo`2Booooo`00KOooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Eooooo`Co000000?oZ;3M
o`000?nX/=d01OnX/=d00ol0003oZ;;OojRbg`0;ojRbg`03o`000?nY]N;oZKGR00[oZKGR00Co0000
ojVii?nY^NCo00002_nY^N@2o`0009?ooooo001]ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool00omEEEGoQhN7ooooo`0Eooooo`?o00002onX/=d00ol0003oZ;;OojRbg`0;ojRbg`03o`000?nY
]N;oZKGR00_oZKGR00?o0000ojVii?l000002?nY^N@2o`000003ok:lhOl0003ooooo09;ooooo001]
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00Cooooo`Co00003OnX
/=d00ol0003oZ;;OojRbg`0;ojRbg`03o`000?nY]N;oZKGR00[oZKGR00?o0000ojVii?l000001OnY
^N@3o`0000Co/[cQ00?o0000ooooooooool0T?ooool006gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`04olc<c?m4A4Co0000oa0@40oooooo0_l00002ojR^g003o`000?nX[]co000000goZ;3M
00?o0000ojRbgonX/]l02onX/]l00ol0003oZKGRojVehP0:ojVehP;o00000onY^N@2o`0000So/[cQ
00?o0000ooooooooool0Soooool008kooooo0ol00007ojR^g003o`000?nX/=goZ;3M00[oZ;3M00?o
0000ojRbgonX/]l02onX/]l00ol0003oZKGRojVehP0;ojVehP04o`000?nY^NCo0000o`0000_o/[cQ
00?o0000ooooooooool0S_ooool008cooooo0ol00009ojR^g003o`000?nX/=goZ;3M00_oZ;3M00?o
0000ojRbgonX/]l02onX/]l00ol0003oZKGRojVehP0:ojVehP;o00003Onb_>42o`0008oooooo0029
ooooo`Co000000?oZ:kLo`000?nX[]`02OnX[]`00ol0003oZ;3MojR`g@0;ojR`g@03o`000?nX/]oo
Z;;O00_oZ;;O00?o0000ojVeh_nY]N801onY]N84o`0000ko/[cQ00?o0000ooooooooool0SOooool0
053ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooo
oooo023ooooo1?l000000onW[M_o0000ojR^g00;ojR^g003o`000?nX/=goZ;3M00_oZ;3M00?o0000
ojRbgonX/]l03?nX/]l00ol0003oZKGRojVehP04ojVehP;o00000_na^=l00ol0003o/KSOo`00000>
ok:lh@03o`000?oooooooooo08cooooo001@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool07_ooool4o`0000GoYjgK00?o0000ojR^g?nX[]`02_nX[]`0
0ol0003oZ;3MojR`g@0;ojR`g@03o`000?nX/]ooZ;;O00_oZ;;O00?o0000ojVeh_nY]N800_nY]N82
o`0000Co/KSO00Co0000ok6hgona^=oo00003_nb_>400ol0003oooooooooo`2;ooooo`00D?ooool0
1Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Mooooo`?o000000?oYjgKo`000?nW[M/01_nW
[M/00ol0003oZ:kLojR^g00:ojR^g003o`000?nX/=goZ;3M00_oZ;3M00?o0000ojRbgonX/]l02onX
/]l01?l0003oZKGRo`000?l00006ok6hg`05o`000?na^=oo/KSOok6hgol000003Onb_>42o`0008co
oooo001@ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0000Koooo
o`?o00001OnW[M/00ol0003oYjgKojN]f`04ojN]f`03o`000?nX[]coZ:kL00[oZ:kL00?o0000ojR`
gOnX/=d02onX/=d00ol0003oZ;;OojRbg`0;ojRbg`;o00002?na^=l01Ol0003o/KSOok6hgona^=oo
000000ko/[cQ0_l0002;ooooo`00D?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgM
oeEEEOoooooo00006Oooool3o`000003ojN/fol0003oYjgK00coYjgK00?o0000ojR^g?nX[]`02_nX
[]`00ol0003oZ;3MojR`g@0;ojR`g@03o`000?nX/]ooZ;;O00SoZ;;O0_l000000on_]Mgo0000ok6h
g`07ok6hg`03o`000?na^=oo/KSO00;o/KSO00?o0000ok:lhOnb_>403?nb_>400ol0003ooooooooo
o`29ooooo`00D?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000005_oo
ool3o`0000;oYjcK00Co0000ojN/fonW[=_o00003?nW[M/00ol0003oZ:kLojR^g00;ojR^g003o`00
0?nX/=goZ;3M00_oZ;3M00?o0000ojRbgonX/]l01?nX/]l3o`0000Co[kGM00?o0000ok6hgona^=l0
1Ona^=l00ol0003o/KSOok6hg`03ok6hg`03o`000?nb_>7o/[cQ00co/[cQ00?o0000ooooooooool0
R?ooool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000001Cooooo
0ol00008ojN/f`03o`000?nW[M_oYjgK00[oYjgK00?o0000ojR^g?nX[]`02_nX[]`00ol0003oZ;3M
ojR`g@0;ojR`g@03o`000?nX/]ooZ;;O00;oZ;;O0_l00008ojneg@03o`000?na^=oo/KSO00Co/KSO
00?o0000ok6hgona^=l01?na^=l00ol0003o/[cQok:lh@0;ok:lh@;o0000ROooool0053ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo013ooooo0ol0000;ojN/f`03o`00
0?nW[M_oYjgK00_oYjgK00?o0000ojR^g?nX[]`02_nX[]`00ol0003oZ;3MojR`g@0;ojR`g@04o`00
0?nX/]oo0000o`0000[o[kGM00?o0000ok6hgona^=l01?na^=l00ol0003o/KSOok6hg`04ok6hg`03
o`000?nb_>7o/[cQ00co/[cQ0_l00028ooooo`00Loooool3o`000003ojN]fol0003o000000_oYjcK
00?o0000ojN]fonW[M/02_nW[M/00ol0003oZ:kLojR^g00;ojR^g003o`000?nX/=goZ;3M00[oZ;3M
0_l0000=ojneg@03o`000?na^=oo/KSO00?o/KSO00?o0000ok6hgona^=l01Ona^=l00ol0003o/[cQ
ok:lh@0<ok:lh@;o0000Qoooool0073ooooo0ol00005ojN]f`03o`000?nW[=_oYjcK00[oYjcK00?o
0000ojN]fonW[M/02_nW[M/00ol0003oZ:kLojR^g00:ojR^g003o`000?nX/=goZ;3M00SoZ;3M0_l0
00000on^/]co0000ojneg@0=ojneg@03o`000?na^=oo/KSO00;o/KSO00?o0000ok6hgona^=l01_na
^=l00ol0003o/[cQok:lh@09ok:lh@;o000000?o^KkNo`000?ooool0Q_ooool006kooooo0ol00008
ojN]f`03o`000?nW[=_oYjcK00WoYjcK00?o0000ojN]fonW[M/02onW[M/00ol0003oZ:kLojR^g00:
ojR^g003o`000?nX/=goZ;3M00CoZ;3M0ol00004ojjbg003o`000?n_]Mgo[kGM00_o[kGM00?o0000
ok6hgona^=l00_na^=l00ol0003o/KSOok6hg`07ok6hg`03o`000?nb_>7o/[cQ00Ko/[cQ0_l00003
okVngP;o0000Q_ooool003?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0002?ooooo0ol00002ojN]f`03o`000?nW[M_oYjgK00KoYjgK00?o0000ojN/fonW[=/02_nW[=/0
0ol0003oYjgKojN]f`0:ojN]f`03o`000?nX[]coZ:kL00[oZ:kL00?o0000ojR`gOnX/=d00_nX/=d2
o`0000So[[;L00?o0000ojnegOn_]Md02on_]Md01Ol0003o/KSOok6hgona^=oo000000Wo/KSO00?o
0000ok:lhOnb_>401Onb_>400ol0003o^KkNokVngP04okVngP;o0000QOooool003?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4027ooooo
0ol000000onX[]co0000ojN]f`0;ojN]f`03o`000?nW[=_oYjcK00[oYjcK00?o0000ojN]fonW[M/0
2_nW[M/00ol0003oZ:kLojR^g00:ojR^g004o`000?nX/=go0000o`0000[o[[;L00?o0000ojnegOn_
]Md03?n_]Md01?l0003o/KSOok6hgol0000:ok6hg`03o`000?nb_>7o/[cQ00;o/[cQ0_l00008okVn
gP;o0000Q?ooool003?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^
01oooooo1?l00004ojR^g003o`000?nW[M_oYjgK00WoYjgK00?o0000ojN/fonW[=/02onW[=/00ol0
003oYjgKojN]f`0:ojN]f`03o`000?nX[]coZ:kL00WoZ:kL0_l0000=ojjbg003o`000?n_]Mgo[kGM
00_o[kGM00Co0000ok6hgona^=oo00002ona^=l01?l0003o/[cQo`000?l0000;okVngP03o`000?oo
oooooooo08;ooooo000cooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP0Kooooo`?o00001?nX[]`00ol0003oZ:kLojR^g002ojR^g003o`000?nW[M_oYjgK00WoYjgK00?o
0000ojN/fonW[=/02_nW[=/00ol0003oYjgKojN]f`0:ojN]f`03o`000?nX[]coZ:kL00OoZ:kL0_l0
00000on//=_o0000ojjbg00=ojjbg003o`000?n_]Mgo[kGM00_o[kGM00?o0000ok6hgol000002ona
^=l2o`0000go^KkN0_l00023ooooo`00<oooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool06?ooool3o`0000_oZ:kL00?o0000ojN]fonW[M/02_nW[M/00ol0003oYjcKojN/
f`0:ojN/f`03o`000?nW[M_oYjgK00[oYjgK00?o0000ojR^g?nX[]`01?nX[]`2o`0000Co[;3K00?o
0000ojjbg?n^/]`02on^/]`00ol0003o[kGMojneg@0;ojneg@03o`000?na^=oo000000Wo/KSO0_l0
00000ong^mco0000okVngP0=okVngP;o0000P_ooool003?ooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo01Cooooo0ol000000onX/=go0000ojR^g00<ojR^g003o`000?nW
[M_oYjgK00WoYjgK00?o0000ojN/fonW[=/02onW[=/00ol0003oYjgKojN]f`09ojN]f`03o`000?nX
[]coZ:kL00;oZ:kL0_l00007ojb`f`03o`000?n^/]co[[;L00_o[[;L00?o0000ojnegOn_]Md02on_
]Md2o`0000Oo/KSO0_l00004okNkg003o`000?ni_]ko^KkN00co^KkN0_l00021ooooo`00<oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Dooooo`?o0000
1?nX/=d00ol0003oZ:kLojR^g00:ojR^g003o`000?nW[M_oYjgK00[oYjgK00?o0000ojN/fonW[=/0
2_nW[=/00ol0003oYjgKojN]f`0:ojN]f`04o`000?nX[]co0000o`0000Wo[;3K00?o0000ojjbg?n^
/]`03?n^/]`00ol0003o[kGMojneg@0;ojneg@03o`000?na^=oo/KSO00Co/KSO00?o0000okNkg?ng
^m`01Ong^m`00ol0003o^KkNokVngP0<okVngP03o`000?oooooooooo07oooooo000cooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<017ooooo0ol00008ojR`
g@03o`000?nX[]coZ:kL00[oZ:kL00?o0000ojN]fonW[M/02_nW[M/00ol0003oYjcKojN/f`0:ojN/
f`03o`000?nW[M_oYjgK00WoYjgK0_l0000<ojb`f`03o`000?n^/]co[[;L00_o[[;L00?o0000ojne
gOn_]Md02on_]Md00ol0003o/KSOok6hg`02ok6hg`;o00002?ng^m`00ol0003o^KkNokVngP0<okVn
gP;o0000P?ooool005Oooooo0ol000000onX/=go0000ojR`g@07ojR`g@03o`000?nX[]coZ:kL00_o
Z:kL00?o0000ojN]fonW[M/02OnW[M/00ol0003oYjcKojN/f`0;ojN/f`03o`000?nW[M_oYjgK00Go
YjgK0ol000000onZ[]_o0000ojb`f`0<ojb`f`03o`000?n^/]co[[;L00_o[[;L00?o0000ojnegOn_
]Md02_n_]Md2o`000003ok6hgol0003o000000_o]k_L00?o0000okVng_ni_]h03?ni_]h2o`0007oo
oooo001Dooooo`?o000000?oZ;;Oo`000?nX/=d02onX/=d00ol0003oZ:kLojR^g00:ojR^g003o`00
0?nW[M_oYjgK00[oYjgK00?o0000ojN/fonW[=/02_nW[=/00ol0003oYjgKojN]f`03ojN]f`;o0000
1OnZ[]/00ol0003o[;3Kojb`f`0:ojb`f`03o`000?n^/]co[[;L00co[[;L00?o0000ojnegOn_]Md0
2On_]Md3o`0000ko]k_L00?o0000okVng_ni_]h03?ni_]h00ol0003oooooooooo`1mooooo`00D_oo
ool3o`0000CoZ;;O00?o0000ojR`gOnX/=d02_nX/=d00ol0003oZ:kLojR^g00:ojR^g003o`000?nW
[M_oYjgK00[oYjgK00?o0000ojN/fonW[=/02_nW[=/00ol0003oYjgKo`000002o`0000SoZZkK00?o
0000ojb`fon//=/02_n//=/00ol0003o[[;Lojjbg00;ojjbg003o`000?n_]Mgo[kGM00So[kGM0_l0
00000one^=_o0000okNkg00=okNkg003o`000?ni_]ko^KkN00go^KkN00?o0000ooooooooool0O?oo
ool002Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Sooooo`Co000000?oZ;;Oo`000?nX/]l01?nX
/]l00ol0003oZ;3MojR`g@09ojR`g@03o`000?nX[]coZ:kL00_oZ:kL00?o0000ojN]fonW[M/02OnW
[M/00ol0003oYjcKojN/f`0:ojN/f`;o00002onZ[]/00ol0003o[;3Kojb`f`0;ojb`f`03o`000?n^
/]co[[;L00_o[[;L00?o0000ojnegOn_]Md01_n_]Md00ol0003o]KSKo`000002okFhf`03o`000?ng
^mco]k_L00co]k_L00?o0000okVng_ni_]h03?ni_]h2o`0007gooooo000Wooooo`05ogMgMonHV9So
oooooiRHV?mgMgL08Oooool3o`0000_oZ;;O00?o0000ojR`gOnX/=d02OnX/=d00ol0003oZ:kLojR^
g00:ojR^g003o`000?nW[M_oYjgK00[oYjgK00?o0000ojN/fonW[=/01_nW[=/3o`000003ojR]fol0
003oZZkK00_oZZkK00?o0000ojb`fon//=/02_n//=/00ol0003o[[;Lojjbg00<ojjbg003o`000?n_
]Mgo[kGM00?o[kGM0_l00002okFhf`05o`000?ne^=_o]KSKokFhfol000003_ng^m`00ol0003o^KkN
okVngP0<okVngP;o0000O?ooool002Oooooo00Go410@oooooooooooooooooa0@400Nooooo`Go0000
3?nX/]l00ol0003oZ;3MojR`g@0:ojR`g@03o`000?nX[]coZ:kL00[oZ:kL00?o0000ojN]fonW[M/0
2OnW[M/00ol0003oYjcKojN/f`03ojN/f`?o00001OnX[M/00ol0003oZZkKojZ^f`0:ojZ^f`03o`00
0?n//=_o[;3K00[o[;3K00?o0000ojjbg?n^/]`02on^/]`01?l0003o[kGMojnegOn_]Md2o`0000Co
]KSK00?o0000okFhfone^=/00_ne^=/00ol0003o]k_LokNkg00<okNkg003o`000?ni_]ko^KkN00[o
^KkN00?o0000okk1g?l00000O?ooool002Oooooo00Go0000ooooooooooooooooo`00000Looooo`?o
00000_nY]N800ol0003oZKGRo`00000<ojRbg`03o`000?nX/=goZ;3M00[oZ;3M00?o0000ojR^g?nX
[]`02_nX[]`00ol0003oYjgKojN]f`09ojN]f`03o`000?nW[=_o000000;o00002OnX[M/00ol0003o
ZZkKojZ^f`09ojZ^f`03o`000?n//=_o[;3K00_o[;3K00?o0000ojjbg?n^/]`02on^/]`00ol0003o
[kGMo`000006okFhf`03o`000?ne^=_o]KSK00;o]KSK00?o0000okNkg?ng^m`03?ng^m`00ol0003o
^KkNokVngP08okVngP;o00000onn`M`00ol0003oooooooooo`1iooooo`009oooool01Ol0003ooooo
oooooooooooo000001Wooooo1?l00005ojVehP03o`000?nY]N;o000000coZ;;O00?o0000ojR`gOnX
/=d02OnX/=d00ol0003oZ:kLojR^g00:ojR^g003o`000?nW[M_oYjgK00WoYjgK0_l0000<ojR]f`03
o`000?nZ[]_oZZkK00[oZZkK00?o0000ojb`fon//=/02_n//=/00ol0003o[[;Lojjbg00;ojjbg0;o
00001one^=/00ol0003o]KSKokFhf`03okFhf`03o`000?ng^mco]k_L00co]k_L00?o0000okVng_ni
_]h01Oni_]h2o`0000Go_/7L0_l0001jooooo`009oooool01Ol@413ooooooooooooooooo410@01Oo
oooo0ol0000;ojVehP03o`000?nX/]ooZ;;O00WoZ;;O00?o0000ojR`gOnX/=d02_nX/=d00ol0003o
Z:kLojR^g00:ojR^g003o`000?nW[M_oYjgK00GoYjgK0ol000000onW[Mco0000ojR]f`0<ojR]f`03
o`000?nZ[]_oZZkK00[oZZkK00?o0000ojb`fon//=/02_n//=/00ol0003o[[;Lojjbg008ojjbg0;o
000000?o/kGKo`000?ne^=/01_ne^=/00ol0003o]KSKokFhf`04okFhf`03o`000?ng^mco]k_L00co
]k_L00?o0000okVng_ni_]h00oni_]h00ol0003o_/7Lokk1g006okk1g0;o0000NOooool002Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`Go000000?oZKGRo`000?nY]N802OnY]N800ol0003o
Z;;OojRbg`0:ojRbg`03o`000?nX/=goZ;3M00[oZ;3M00?o0000ojR^g?nX[]`02OnX[]`00ol0003o
YjgKojN]f`03ojN]f`;o00001OnW[M`00ol0003oZ:gKojR]f`0:ojR]f`03o`000?nZ[]_oZZkK00[o
ZZkK00?o0000ojb`fon//=/02on//=/00ol0003o[[;Lojjbg004ojjbg0?o00001?nc]M/00ol0003o
]KSKokFhf`04okFhf`03o`000?ne^=_o]KSK00Go]KSK00?o0000okNkg?ng^m`02ong^m`01?l0003o
^KkNokVng_ni_]h2o`0000[o_/7L00?o0000ooooooooool0Moooool002Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Booooo`?o00001?nY^N@00ol0003oZKGRojVehP0:ojVehP03o`000?nX/]ooZ;;O
00[oZ;;O00?o0000ojR`gOnX/=d02OnX/=d00ol0003oZ:kLojR^g00:ojR^g003o`000?nW[M_o0000
00;o00002?nW[M`00ol0003oZ:gKojR]f`0:ojR]f`03o`000?nZ[]_oZZkK00[oZZkK00?o0000ojb`
fon//=/02_n//=/00ol0003o[[;Lojjbg002ojjbg0;o00002?nc]M/00ol0003o]KSKokFhf`03okFh
f`03o`000?ne^=_o]KSK00Go]KSK00?o0000okNkg?ng^m`03?ng^m`00ol0003o^KkNo`00000=okk1
g003o`000?oooooooooo07Kooooo000kooooo`Go00001_nY^N@00ol0003oZKGRojVehP0:ojVehP03
o`000?nX/]ooZ;;O00[oZ;;O00?o0000ojR`gOnX/=d02OnX/=d00ol0003oZ:kLojR^g009ojR^g0;o
00002onW[M`00ol0003oZ:gKojR]f`0;ojR]f`03o`000?nZ[]_oZZkK00[oZZkK00?o0000ojb`fon/
/=/02_n//=/01?l0003o[[;Lo`000?l0000:ok>ef`03o`000?ne^=_o]KSK00?o]KSK00?o0000okFh
fone^=/01_ne^=/00ol0003o]k_LokNkg00;okNkg0;o00003_nn`M`2o`0007Oooooo000iooooo`?o
00002onY^N@00ol0003oZKGRojVehP0:ojVehP03o`000?nX/]ooZ;;O00WoZ;;O00?o0000ojR`gOnX
/=d02_nX/=d00ol0003oZ:kLojR^g005ojR^g0?o000000?oYJgMo`000?nW[M`02onW[M`00ol0003o
Z:gKojR]f`0:ojR]f`03o`000?nZ[]_oZZkK00[oZZkK00?o0000ojb`fon//=/02_n//=/2o`0000go
/kGK00?o0000okFhfone^=/00_ne^=/00ol0003o]KSKokFhf`07okFhf`03o`000?ng^mco]k_L00So
]k_L0_l000000onm_]_o0000okk1g00>okk1g0;o0000M_ooool003Oooooo1?l0000=ojVii003o`00
0?nY]N;oZKGR00[oZKGR00?o0000ojRbgonX/]l02OnX/]l00ol0003oZ;3MojR`g@09ojR`g@03o`00
0?nX[]coZ:kL00?oZ:kL0_l00005ojF]g@03o`000?nW[McoYjgL00WoYjgL00?o0000ojR]fonX[M/0
2onX[M/00ol0003oZZkKojZ^f`0:ojZ^f`03o`000?n//=_o[;3K00Oo[;3K0_l000000on`/m[o0000
ok>ef`0=ok>ef`05o`000?ne^=_o]KSKokFhfol000002_ne^=/00ol0003o]k_LokNkg006okNkg003
o`000?nm_]_o_KkK00;o_KkK00?o0000okk1g?nn`M`03Onn`M`00ol0003oooooooooo`1dooooo`00
=?ooool3o`000005ojZliol0003oZ[cWojZliol000003?nY^N@00ol0003oZKGRojVehP0:ojVehP03
o`000?nX/]ooZ;;O00[oZ;;O00?o0000ojR`gOnX/=d02OnX/=d00ol0003oZ:kLo`000002o`0000So
YJgM00?o0000ojN]g?nW[M`02OnW[M`00ol0003oZ:gKojR]f`0;ojR]f`03o`000?nZ[]_oZZkK00[o
ZZkK00?o0000ojb`fon//=/01?n//=/2o`0000Co/;?J00?o0000ok>efonc]M/02onc]M/01Ol0003o
]KSKokFhfone^=_o000000[o]KSK00?o0000okNkg?ng^m`01?ng^m`2o`0000Ko_KkK00?o0000okk1
g?nn`M`03Onn`M`00ol0003oooooooooo`1cooooo`00<_ooool3o`0000OoZ[cW00?o0000ojVii?nY
^N@02_nY^N@00ol0003oZKGRojVehP0:ojVehP03o`000?nX/]ooZ;;O00WoZ;;O00?o0000ojR`gOnX
/=d02?nX/=d3o`0000_oYJgM00?o0000ojN]g?nW[M`02_nW[M`00ol0003oZ:gKojR]f`0:ojR]f`03
o`000?nZ[]_oZZkK00[oZZkK00?o0000ojb`fon//=/00_n//=/2o`0000Oo/;?J00?o0000ok>efonc
]M/02onc]M/01?l0003o]KSKokFhfol0000;okFhf`04o`000?ng^mco]k_LokNkg0;o00002Onm_]/0
0ol0003o_/7Lokk1g00<okk1g0;o0000M?ooool0037ooooo00?o0000ojZlionZ_>L02OnZ_>L00ol0
003oZKWTojVii00:ojVii003o`000?nY]N;oZKGR00[oZKGR00?o0000ojRbgonX/]l02OnX/]l00ol0
003oZ;3MojR`g@04ojR`g@?o00000_nT[]l00ol0003oYJgMojF]g@0:ojF]g@03o`000?nW[McoYjgL
00WoYjgL00?o0000ojR]fonX[M/02onX[M/00ol0003oZZkKojZ^f`0:ojZ^f`04o`000?n//=_o0000
o`0000Wo/;?J00?o0000ok>efonc]M/03?nc]M/00ol0003o]KSKo`00000<okFhf`03o`000?ng^mco
000000_o_KkK00?o0000okk1g?nn`M`03Onn`M`00ol0003oooooooooo`1booooo`00<Oooool2o`00
00_oZ[cW00?o0000ojVii?nY^N@02_nY^N@00ol0003oZKGRojVehP0:ojVehP03o`000?nX/]ooZ;;O
00WoZ;;O00?o0000ojR`gOnX/=d00ol00006ojB^g`03o`000?nU[MgoYJgM00[oYJgM00?o0000ojN]
g?nW[M`02OnW[M`00ol0003oZ:gKojR]f`0;ojR]f`03o`000?nZ[]_oZZkK00WoZZkK0_l0000<ok2c
fP03o`000?nc]M_o/kGK00_o/kGK00?o0000okFhfol000003?ne^=/2o`0000go_KkK00?o0000okk1
g?nn`M`03Onn`M`00ol0003oooooooooo`1aooooo`009Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Oooooo0_l0000<ojZli`03o`000?nY^NCoZKWT00[oZKWT00?o0000ojVeh_nY]N802OnY]N800ol0
003oZ;;OojRbg`08ojRbg`Co00002_nT[]l00ol0003oYJgMojF]g@09ojF]g@03o`000?nW[McoYjgL
00[oYjgL00?o0000ojR]fonX[M/02_nX[M/00ol0003oZZkKojZ^f`07ojZ^f`;o000000?o[K7Ko`00
0?n`/mX03?n`/mX00ol0003o/kGKok>ef`0;ok>ef`;o00002one^=/00ol0003o^[_Jo`00000>okfn
f`03o`000?nn`Mco_/7L00go_/7L00?o0000ooooooooool0L?ooool002Gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`07ooooo`03o`000?oooooo000000coZ[cW00?o0000ojVii?nY^N@02_nY^N@00ol0
003oZKGRojVehP09ojVehP03o`000?nX/]ooZ;;O00CoZ;;O0ol00002oj:`hP03o`000?nT[]ooY:kO
00WoY:kO00?o0000ojF]gOnU[Md02_nU[Md00ol0003oYjgLojN]g009ojN]g003o`000?nX[M_oZ:gK
00_oZ:gK00?o0000ojZ^fonZ[]/01?nZ[]/2o`0000Co[K7K00?o0000ok2cf_n`/mX02on`/mX00ol0
003o/kGKok>ef`0:ok>ef`;o00002One^=/2o`0000?o^[_J00?o0000okfnfonm_]/03?nm_]/00ol0
003o_/7Lokk1g00<okk1g0;o0000LOooool002Gooooo00Go410@oooooooooooooooooa0@4007oooo
o`04o`000?ooooooooooo`0000coZ[cW00?o0000ojVii?nY^N@02OnY^N@00ol0003oZKGRojVehP0:
ojVehP03o`000?nX/]ooZ;;O00?o00001_nR/>800ol0003oY:kOojB^g`09ojB^g`03o`000?nU[Mgo
YJgM00[oYJgM00?o0000ojN]g?nW[M`02OnW[M`00ol0003oZ:gKojR]f`0:ojR]f`03o`000?nZ[]_o
ZZkK00;oZZkK0_l00007ojfaf`03o`000?n`/m[o/;?J00[o/;?J00?o0000ok>efonc]M/02onc]M/0
0ol0003o]KSKokFhf`05okFhf`;o00001_nj^mX00ol0003o_KkKokfnf`0;okfnf`03o`000?nn`Mco
_/7L00_o_/7L00?o0000ol?3f_l00000LOooool002Gooooo00Go0000ooooooooooooooooo`000006
ooooo`;o00000oooool00ol0003oZ[cWojZli`0:ojZli`03o`000?nY^NCoZKWT00WoZKWT00?o0000
ojVeh_nY]N802?nY]N84o`0000[oX[3R00?o0000ojB^gonT[]l02OnT[]l00ol0003oYJgMojF]g@09
ojF]g@03o`000?nW[McoYjgL00[oYjgL00?o0000ojR]fonX[M/02_nX[M/01?l0003oZZkKo`000?l0
0009ojfaf`03o`000?n`/m[o/;?J00_o/;?J00?o0000ok>efonc]M/02_nc]M/2o`0000Go]KSK00?o
0000okZkf_nj^mX01_nj^mX00ol0003o_KkKokfnf`0<okfnf`03o`000?nn`Mco_/7L00So_/7L0_l0
0003ol?3fP03o`000?oooooooooo06kooooo000Uooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`03ooooo`03o`000?nZ_>OoZ[cW00[oZ[cW00?o0000ojVii?nY^N@02OnY
^N@00ol0003oZKGRojVehP04ojVehP?o00000_nQ/nD00ol0003oX[3Roj:`hP09oj:`hP03o`000?nT
[]ooY:kO00[oY:kO00?o0000ojF]gOnU[Md02OnU[Md00ol0003oYjgLojN]g009ojN]g003o`000?nX
[M_oZ:gK00[oZ:gK0_l0000<ojfaf`03o`000?n`/m[o/;?J00_o/;?J00?o0000ok>efonc]M/02Onc
]M/2o`0000?o]KSK0_l0000:okZkfP03o`000?nm_]_o_KkK00co_KkK00?o0000okk1g?nn`M`01Onn
`M`2o`0000Ko`l?J00?o0000ooooooooool0KOooool002Gooooo00Go410@oooooooooooooooooa0@
4006ooooo`03o`000?oooooooooo00Cooooo00?o0000ojZlionZ_>L02_nZ_>L00ol0003oZKWTojVi
i009ojVii003o`000?nY]N;oZKGR00?o00001_nQ/nD00ol0003oX[3Roj:`hP09oj:`hP03o`000?nT
[]ooY:kO00WoY:kO00?o0000ojF]gOnU[Md02_nU[Md00ol0003oYjgLojN]g009ojN]g003o`000?nX
[M_oZ:gK00KoZ:gK0ol000000onY[mco0000ojfaf`0<ojfaf`03o`000?n`/m[o/;?J00[o/;?J00?o
0000ok>efonc]M/02Onc]M/01Ol0003o/kGKo`000?ne^=_o000000go^[_J00?o0000okfnfonm_]/0
2onm_]/00ol0003o_/7Lokk1g004okk1g003o`000?o3`m[o`l?J00Ko`l?J0_l0001^ooooo`009Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01Oooool00ol0003oZ[cW
ojZli`0:ojZli`03o`000?nY^NCoZKWT00SoZKWT0ol0000:oj6ci@03o`000?nR/>;oX[3R00WoX[3R
00?o0000ojB^gonT[]l02OnT[]l00ol0003oYJgMojF]g@09ojF]g@03o`000?nW[McoYjgL00WoYjgL
00?o0000ojR]fonX[M/00onX[M/3o`0000GoZJoL00?o0000ojfafon]/M/02_n]/M/00ol0003o/;?J
ok2cfP0;ok2cfP03o`000?nc]M_o/kGK00So/kGK00Co0000ok>efol0003o00003_nj^mX00ol0003o
_KkKokfnf`0<okfnf`04o`000?nn`Mco_/7Lokk1g0;o00002_o3`mX00ol0003oooooooooo`1/oooo
o`009Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01_ooool00ol0
003oZ[cWojZli`0:ojZli`03o`000?nY^NCoZKWT00CoZKWT0ol000000onP]^So0000oj6ci@0;oj6c
i@03o`000?nR/>;oX[3R00WoX[3R00?o0000ojB^gonT[]l02OnT[]l00ol0003oYJgMojF]g@09ojF]
g@03o`000?nW[McoYjgL00WoYjgL00?o0000ojR]fol000000_l00009ojV_g003o`000?n]/M_o[K7K
00[o[K7K00?o0000ok2cf_n`/mX02on`/mX00ol0003o/kGKok>ef`07ok>ef`;o000000?o]kWJo`00
0?nj^mX03_nj^mX00ol0003o_KkKokfnf`0<okfnf`03o`000?nn`Mco000000go`l?J00?o0000oooo
ooooool0Joooool0033ooooo00?o0000ooooooooool01oooool00ol0003oZ[cWojZli`0:ojZli`03
o`000?nY^NCoZKWT00?o00001OnP]^P00ol0003oXK?Uoj6ci@09oj6ci@03o`000?nR/>;oX[3R00Wo
X[3R00?o0000ojB^gonT[]l02OnT[]l00ol0003oYJgMojF]g@0:ojF]g@03o`000?nW[McoYjgL00Oo
YjgL0ol0000<ojV_g003o`000?n]/M_o[K7K00_o[K7K00?o0000ok2cf_n`/mX02on`/mX00ol0003o
/kGKok>ef`04ok>ef`?o00000ong^MX00ol0003o^[_JokZkfP0=okZkfP03o`000?nm_]_o_KkK00_o
_KkK0_l0000?ol?3fP03o`000?oooooooooo06[ooooo000`ooooo`03o`000?oooooooooo00Sooooo
00?o0000ojZlionZ_>L02?nZ_>L4o`0000WoX;KX00?o0000oj6ciOnQ/nD02OnQ/nD00ol0003oX[3R
oj:`hP09oj:`hP03o`000?nT[]ooY:kO00WoY:kO00?o0000ojF]gOnU[Md02OnU[Md00ol0003oYjgL
ojN]g004ojN]g0?o00000_nV[]d00ol0003oZJoLojV_g00;ojV_g003o`000?n]/M_o[K7K00[o[K7K
00?o0000ok2cf_n`/mX02on`/mX00ol0003o/kGKok>ef`02ok>ef`;o00000_ng^MX00ol0003o]kWJ
okNifP02okNifP03o`000?nj^m[o^[_J00go^[_J00?o0000okfnfonm_]/02Onm_]/00ol0003o`L7I
o`00000?ol?3fP03o`000?oooooooooo06[ooooo000_ooooo`;o00002oooool00ol0003oZ[cWojZl
i`04ojZli`?o00000_nO^N/00ol0003oX;KXoj2fj009oj2fj003o`000?nQ/nGoXK?U00WoXK?U00?o
0000oj:`h_nR/>802OnR/>800ol0003oY:kOojB^g`09ojB^g`03o`000?nU[MgoYJgM00WoYJgM00?o
0000ojN]g?nW[M`00ol00006ojJ^g@03o`000?nY[mcoZJoL00_oZJoL00?o0000ojfafon]/M/02_n]
/M/00ol0003o/;?Jok2cfP0;ok2cfP04o`000?nc]M_o0000o`0000Co]kWJ00?o0000okNif_ng^MX0
0ong^MX00ol0003o^[_JokZkfP0<okZkfP03o`000?nm_]_o_KkK00Oo_KkK0_l00003ol71f@03o`00
0?o3`m[o`l?J00go`l?J00?o0000ooooooooool0JOooool0033ooooo00?o0000ooooooooool02_oo
ool00ol0003oZ[cWojZli`03o`0000KoWkW[00?o0000oj2fj?nP]^P02OnP]^P00ol0003oXK?Uoj6c
i@09oj6ci@03o`000?nR/>;oX[3R00SoX[3R00?o0000ojB^gonT[]l02_nT[]l00ol0003oYJgMojF]
g@07ojF]g@Co00002_nV[]d00ol0003oZJoLojV_g00:ojV_g003o`000?n]/M_o[K7K00_o[K7K00?o
0000ok2cf_n`/mX02_n`/mX2o`0000Ko]kWJ00?o0000okNif_ng^MX00ong^MX00ol0003o^[_JokZk
fP0=okZkfP03o`000?nm_]_o_KkK00Go_KkK00?o0000ol71fOo1`MT01?o1`MT00ol0003o`l?Jol?3
fP0=ol?3fP03o`000?oooooooooo06Sooooo000_ooooo`03o`000?oooooooooo00cooooo0_l0000:
oinij`03o`000?nP]^SoX;KX00SoX;KX00?o0000oj6ciOnQ/nD02_nQ/nD00ol0003oX[3Roj:`hP08
oj:`hP03o`000?nT[]ooY:kO00WoY:kO00?o0000ojF]gOnU[Md01?nU[Md3o`0000;oXZkO00?o0000
ojJ^gOnV[]d02OnV[]d00ol0003oZJoLojV_g00;ojV_g003o`000?n]/M_o[K7K00[o[K7K00?o0000
ok2cf_n`/mX02?n`/mX2o`000003okBffol0003o]kWJ00Go]kWJ00?o0000okNif_ng^MX01?ng^MX0
0ol0003o^[_JokZkfP0=okZkfP03o`000?nm_]_o_KkK00?o_KkK00?o0000ol71fOo1`MT01_o1`MT0
0ol0003o`l?Jol?3fP0=ol?3fP03o`000?oooooooooo06Oooooo000_ooooo`03o`000?oooooooooo
00gooooo00?o0000oinijonO^N/02OnO^N/00ol0003oX;KXoj2fj008oj2fj003o`000?nQ/nGoXK?U
00WoXK?U00?o0000oj:`h_nR/>802OnR/>800ol0003oY:kOojB^g`09ojB^g`03o`000?nU[MgoYJgM
00?o00001_nR[]l00ol0003oYZkMojJ^g@09ojJ^g@03o`000?nY[mcoZJoL00_oZJoL00?o0000ojfa
fon]/M/02_n]/M/00ol0003o/;?Jok2cfP06ok2cfP03o`000?nd]]_o];KK00;o];KK00?o0000okNi
f_ng^MX00ong^MX00ol0003o]kWJokNifP05okNifP03o`000?nj^m[o^[_J00co^[_J00Co0000okfn
fonm_]_o_KkK0_l0000:ol71f@03o`000?o3`m[o`l?J00co`l?J00?o0000ooooooooool0Ioooool0
02oooooo00?o0000ooooooooool03_ooool00ol0003oWkW[oinij`09oinij`03o`000?nP]^SoX;KX
00SoX;KX00?o0000oj6ciOnQ/nD02OnQ/nD00ol0003oX[3Roj:`hP09oj:`hP03o`000?nT[]ooY:kO
00OoY:kO1?l0000:oj:^g`03o`000?nV[]goYZkM00WoYZkM00?o0000ojV_g?nY[m`02_nY[m`00ol0
003o[K7Kojfaf`0;ojfaf`03o`000?n`/m[o/;?J00?o/;?J0_l00006okBff`03o`000?ng^M[o]kWJ
00;o]kWJ00?o0000okNif_ng^MX01_ng^MX00ol0003o^[_JokZkfP0<okZkfP03o`000?nm_]_o0000
00co`L7I00?o0000ol?3f_o3`mX03Oo3`mX00ol0003oooooooooo`1Vooooo`00;oooool00ol0003o
ooooooooo`0?ooooo`03o`000?nO^N_oWkW[00SoWkW[00?o0000oj2fj?nP]^P02OnP]^P00ol0003o
XK?Uoj6ci@09oj6ci@03o`000?nR/>;oX[3R00SoX[3R00?o0000ojB^gonT[]l01?nT[]l3o`0000;o
WjkR00?o0000oj:^gonR[]l02OnR[]l00ol0003oYZkMojJ^g@0:ojJ^g@03o`000?nY[mcoZJoL00[o
ZJoL00?o0000ojfafon]/M/02_n]/M/01?l0003o/;?Jok2cf_n`/mX2o`0000So];KK00?o0000okNi
f_ng^MX00_ng^MX00ol0003o]kWJokNifP06okNifP03o`000?nj^m[o^[_J00co^[_J0_l0000>ol71
f@03o`000?o3`m[o`l?J00co`l?J0_l0001Wooooo`00;_ooool3o`00017ooooo00?o0000oinijonO
^N/02?nO^N/00ol0003oX;KXoj2fj009oj2fj003o`000?nQ/nGoXK?U00WoXK?U00?o0000oj:`h_nR
/>802?nR/>800ol0003oY:kOojB^g`03o`0000KoWjkR00?o0000oj:^gonR[]l02OnR[]l00ol0003o
YZkMojJ^g@09ojJ^g@03o`000?nY[mcoZJoL00[oZJoL00?o0000ojfafon]/M/02on]/M/00ol0003o
/;?Jo`00000;okBff`05o`000?ng^M[o]kWJokNif_l000002Ong^MX00ol0003o^[_JokZkfP0:okZk
fP03o`000?no_]Wo000000oo`L7I00?o0000ol?3f_o3`mX02_o3`mX01?l0003oa/CHo`000?l0001V
ooooo`00;oooool00ol0003oooooooooo`0Aooooo`03o`000?nO^N_oWkW[00SoWkW[00?o0000oj2f
j?nP]^P02OnP]^P00ol0003oXK?Uoj6ci@08oj6ci@03o`000?nR/>;oX[3R00SoX[3R0ol0000:oin^
hP03o`000?nR[]ooXZkO00WoXZkO00?o0000ojJ^gOnV[]d02OnV[]d00ol0003oZJoLojV_g00:ojV_
g003o`000?n]/M_o[K7K00[o[K7K0_l0000=okBff`04o`000?ng^M[o]kWJo`0000[o]kWJ00?o0000
okZkf_nj^mX01onj^mX2o`0000?o_kkI00?o0000ol71fOo1`MT03Oo1`MT00ol0003o`l?Jol?3fP07
ol?3fP;o00000oo6a=P00ol0003oooooooooo`1Tooooo`00;oooool00ol0003oooooooooo`0Boooo
o`03o`000?nO^N_oWkW[00SoWkW[00?o0000oj2fj?nP]^P02?nP]^P00ol0003oXK?Uoj6ci@09oj6c
i@03o`000?nR/>;oX[3R00CoX[3R0ol000000onK[nGo0000oin^hP0:oin^hP03o`000?nR[]ooXZkO
00WoXZkO00?o0000ojJ^gOnV[]d02_nV[]d00ol0003oZJoLojV_g00:ojV_g003o`000?n]/M_o[K7K
00Ko[K7K0ol000000on_]=co0000okBff`0<okBff`04o`000?ng^M[o]kWJo`0000_o]kWJ00?o0000
okZkf_nj^mX01Onj^mX00ol0003o_kkIoknnf@04oknnf@03o`000?o1`MWo`L7I00co`L7I00?o0000
ol?3f_o3`mX01_o3`mX00ol0003oa/CHolK4f004olK4f003o`000?oooooooooo06?ooooo000_oooo
o`03o`000?oooooooooo01?ooooo00?o0000oinijonO^N/02?nO^N/00ol0003oX;KXoj2fj008oj2f
j003o`000?nQ/nGoXK?U00WoXK?U00?o0000oj:`h_nR/>800ol00005oi^_i@03o`000?nO[^;oWjkR
00WoWjkR00?o0000oj:^gonR[]l02OnR[]l00ol0003oYZkMojJ^g@09ojJ^g@03o`000?nY[mcoZJoL
00[oZJoL00?o0000ojfafon]/M/00on]/M/3o`0000Go[kCL00?o0000okBffond]]/02ond]]/00ol0
003o]kWJo`00000;okNifP03o`000?nj^m[o^[_J00Co^[_J00?o0000oknnfOno_]T01_no_]T00ol0
003o`L7Iol71f@0<ol71f@03o`000?o3`m[o`l?J00Co`l?J00?o0000olK4f?o6a=P01_o6a=P00ol0
003oooooooooo`1Rooooo`00;oooool00ol0003oooooooooo`0Cooooo`;o00002OnO^N/00ol0003o
X;KXoj2fj009oj2fj003o`000?nQ/nGoXK?U00OoXK?U1?l00009oi^_i@03o`000?nO[^;oWjkR00Wo
WjkR00?o0000oj:^gonR[]l02OnR[]l00ol0003oYZkMojJ^g@09ojJ^g@03o`000?nY[mcoZJoL00[o
ZJoL00?o0000ojfafol000000_l00009ojndg003o`000?nd]]_o];KK00_o];KK0_l0000<okNifP04
o`000?nj^m[o^[_JokZkfP;o00002Ono_]T00ol0003o`L7Iol71f@0=ol71f@04o`000?o3`m[o`l?J
ol?3fP;o00002Oo6a=P2o`0006?ooooo000^ooooo`03o`000?oooooooooo01Gooooo0_l00009oini
j`03o`000?nP]^SoX;KX00WoX;KX00Co0000oj6ciOnQ/nGoXK?U1Ol00002oiR`j003o`000?nK[nGo
VjoU00SoVjoU00?o0000oin^h_nO[^802OnO[^800ol0003oXZkOoj:^g`09oj:^g`03o`000?nV[]go
YZkM00[oYZkM00?o0000ojV_g?nY[m`02OnY[m`2o`0000co[kCL00?o0000okBffond]]/02ond]]/2
o`0000go]kWJ00?o0000okZkf_l000003?no_]T00ol0003o`L7Iol71f@0=ol71f@03o`000?o3`m[o
000000coa/CH00?o0000ooooooooool0HOooool002kooooo0ol0000Fooooo`;o00002OnO^N/00ol0
003oX;KXoj2fj007oj2fj0Go00002?nH/>P00ol0003oVjoUoi^_i@08oi^_i@03o`000?nO[^;oWjkR
00WoWjkR00?o0000oj:^gonR[]l02OnR[]l00ol0003oYZkMojJ^g@0:ojJ^g@03o`000?nY[mcoZJoL
00GoZJoL0ol000000on[/]go0000ojndg00<ojndg003o`000?nd]]_o];KK00_o];KK00?o0000okNi
f_ng^MX02ong^MX2o`0000ko_kkI00?o0000ol71fOo1`MT03?o1`MT2o`0000koa/CH00?o0000oooo
ooooool0H?ooool002kooooo00?o0000ooooooooool05oooool2o`0000WoWkW[00Co0000oj2fj?nP
]^SoX;KX1Ol00002oiJbj`03o`000?nH/>SoV;3X00WoV;3X00?o0000oi^_iOnK[nD02?nK[nD00ol0
003oWjkRoin^hP09oin^hP03o`000?nR[]ooXZkO00WoXZkO00?o0000ojJ^gOnV[]d02OnV[]d00ol0
003oZJoLojV_g003ojV_g0;o00001On[/]d00ol0003o[kCLojndg00;ojndg003o`000?nd]]_o];KK
00[o];KK00?o0000okNif_ng^MX02Ong^MX2o`000003ok^lf_l0003o_kkI00ko_kkI00?o0000ol71
fOo1`MT02_o1`MT00ol0003oaL?Ho`00000?olK4f003o`000?oooooooooo05oooooo000Booooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00007ooooo`03o`000?oooooooooo
01Sooooo0_l00005oinij`Oo00002?nF/^/00ol0003oV;3XoiR`j009oiR`j003o`000?nK[nGoVjoU
00SoVjoU00?o0000oin^h_nO[^802?nO[^800ol0003oXZkOoj:^g`09oj:^g`03o`000?nV[]goYZkM
00[oYZkM00?o0000ojV_g?l000000_l00008oj^bg@03o`000?n_]=co[kCL00[o[kCL00?o0000okBf
fond]]/02_nd]]/2o`0000So]kWJ0_l00004ok^lfP03o`000?no_]Wo_kkI00co_kkI00?o0000ol71
fOo1`MT02Oo1`MT01Ol0003oaL?HolG3f?o5`mSo000000ooa/CH00?o0000ooooooooool0G_ooool0
01;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Oooooo00?o0000ooooooooool06Oooool6o`0000CoTkG^00?o0000oiJbjonF/^/02OnF
/^/00ol0003oV;3XoiR`j009oiR`j003o`000?nK[nGoVjoU00OoVjoU00?o0000oin^h_nO[^802OnO
[^800ol0003oXZkOoj:^g`09oj:^g`03o`000?nV[]goYZkM00WoYZkM0_l0000;oj^bg@03o`000?n_
]=co[kCL00_o[kCL00?o0000okBffond]]/02Ond]]/00ol0003o];KKo`000006okNifP03o`000?nk
_=[o^kcJ00Go^kcJ00?o0000oknnfOno_]T03?no_]T00ol0003o`L7Iol71f@07ol71f@03o`000?o5
`mSoaL?H00?oaL?H00?o0000olK4f?o6a=P03?o6a=P00ol0003oooooooooo`1Nooooo`004_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?nC]NkoTkG^00OoTkG^00?o0000oiJbjonF/^/02OnF/^/00ol0003oV;3XoiR`
j008oiR`j003o`000?nK[nGoVjoU00SoVjoU00?o0000oin^h_nO[^802OnO[^800ol0003oXZkOoj:^
g`09oj:^g`03o`000?nV[]goYZkM00GoYZkM0ol000000onU/=oo0000oj^bg@0;oj^bg@03o`000?n_
]=co[kCL00_o[kCL00?o0000okBffond]]/02?nd]]/00ol0003o];KKo`000004okNifP;o00002?nk
_=X00ol0003o_kkIoknnf@0=oknnf@03o`000?o1`MWo`L7I00Co`L7I0_l00007olG3f003o`000?o6
a=Soa/CH00coa/CH00?o0000ooooooooool0GOooool001;ooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool06oooool00ol0003oTkG^oi>e
kP07oi>ekP03o`000?nF/^_oU[;[00WoU[;[00?o0000oiR`j?nH/>P02?nH/>P00ol0003oVjoUoi^_
i@08oi^_i@03o`000?nO[^;oWjkR00SoWjkR00?o0000oj:^gonR[]l02OnR[]l00ol0003oYZkMojJ^
g@03ojJ^g@;o00001OnU/=l00ol0003oZk;Moj^bg@0:oj^bg@03o`000?n_]=co[kCL00_o[kCL00?o
0000okBffond]]/01ond]]/01Ol0003o];KKokBffol0003o]kWJ00;o00002onk_=X00ol0003o_kkI
oknnf@0<oknnf@03o`000?o1`MWo`L7I00?o`L7I00?o0000olG3f?o5`mP01oo5`mP00ol0003oa/CH
olK4f00=olK4f003o`000?oooooooooo05cooooo000Booooo`05o`000?ooooooooooooooool00000
3_ooool00omgMgOoIVIVooooo`06ooooo`03o`000?oooooooooo01cooooo00?o0000oi>ek_nC]Nh0
1onC]Nh00ol0003oU[;[oiJbj`08oiJbj`03o`000?nH/>SoV;3X00WoV;3X00?o0000oi^_iOnK[nD0
1onK[nD00ol0003oWjkRoin^hP09oin^hP03o`000?nR[]ooXZkO00WoXZkO00?o0000ojJ^gOl00000
0_l00008ojF`g`03o`000?n[/]goZk;M00[oZk;M00?o0000ojndg?n_]=`02_n_]=`00ol0003o];KK
okBff`07okBff`03o`000?nd]]_o];KK00;o00003_nk_=X00ol0003o_kkIoknnf@0<oknnf@05o`00
0?o1`MWo`L7Iol71fOl000002oo5`mP00ol0003oa/CHolK4f00<olK4f0;o0000GOooool001;ooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo0_l0000Oooooo`03
o`000?nC]NkoTkG^00OoTkG^00?o0000oiJbjonF/^/02?nF/^/00ol0003oV;3XoiR`j009oiR`j003
o`000?nK[nGoVjoU00OoVjoU00?o0000oin^h_nO[^802OnO[^800ol0003oXZkOoj:^g`07oj:^g`?o
00002onU/=l00ol0003oZk;Moj^bg@0:oj^bg@03o`000?n_]=co[kCL00_o[kCL00?o0000okBffond
]]/01_nd]]/3o`000003okNjfol0003o^kcJ00go^kcJ00?o0000oknnfOno_]T03Ono_]T00ol0003o
`L7Io`00000=olG3f003o`000?o6a=Soa/CH00[oa/CH00?o0000olS5f?l00000GOooool001;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0
003oooooooooo`0Oooooo`03o`000?nC]NkoTkG^00OoTkG^00?o0000oiJbjonF/^/02?nF/^/00ol0
003oV;3XoiR`j009oiR`j003o`000?nK[nGoVjoU00OoVjoU00?o0000oin^h_nO[^802?nO[^800ol0
003oXZkOoj:^g`04oj:^g`?o00000_nP[n800ol0003oYK3OojF`g`0:ojF`g`03o`000?n[/]goZk;M
00[oZk;M00?o0000ojndg?n_]=`02on_]=`00ol0003o];KKokBff`04okBff`;o00001?ng^]/00ol0
003o^kcJok^lfP0<ok^lfP03o`000?no_]Wo_kkI00co_kkI0_l0000>olG3f003o`000?o6a=Soa/CH
00Woa/CH00Go0000olS5f?o8aMSob<GHo`00001Looooo`004_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo023ooooo00?o
0000oi>ek_nC]Nh01onC]Nh00ol0003oU[;[oiJbj`08oiJbj`03o`000?nH/>SoV;3X00SoV;3X00?o
0000oi^_iOnK[nD02?nK[nD00ol0003oWjkRoin^hP08oin^hP03o`000?nR[]ooXZkO00?o00001_nP
[n800ol0003oYK3OojF`g`0:ojF`g`03o`000?n[/]goZk;M00[oZk;M00?o0000ojndg?n_]=`02_n_
]=`00ol0003o];KKokBff`02okBff`;o000000?o]k[Ko`000?ng^]/01?ng^]/00ol0003o^kcJok^l
fP0<ok^lfP03o`000?no_]Wo_kkI00[o_kkI00?o0000ol;1fOl000003oo5`mP00ol0003oa/CHolK4
f007olK4f003o`000?o8aMSob<GH00?ob<GH00?o0000ooooooooool0FOooool002gooooo00?o0000
ooooooooool08Oooool00ol0003oTkG^oi>ekP07oi>ekP03o`000?nF/^_oU[;[00SoU[;[00?o0000
oiR`j?nH/>P02?nH/>P00ol0003oVjoUoi^_i@07oi^_i@03o`000?nO[^;oWjkR00OoWjkR1?l0000:
oj2_hP03o`000?nU/=ooYK3O00[oYK3O00?o0000oj^bgOn[/]d02On[/]d00ol0003o[kCLojndg00;
ojndg004o`000?nd]]_o0000o`0000?o]k[K00?o0000okNjfong^]/01?ng^]/00ol0003o^kcJok^l
fP0;ok^lfP03o`000?no_]Wo_kkI00So_kkI0_l00003ol;1f@03o`000?o5`mSoaL?H00goaL?H00?o
0000olK4f?o6a=P01?o6a=P2o`0000Oob<GH00?o0000ooooooooool0F?ooool002gooooo00?o0000
ooooooooool08Oooool00ol0003oTkG^oi>ekP08oi>ekP03o`000?nF/^_oU[;[00OoU[;[00?o0000
oiR`j?nH/>P02OnH/>P00ol0003oVjoUoi^_i@07oi^_i@04o`000?nO[^;oWjkRoin^hPGo00000_nJ
[^D00ol0003oX:oRoj2_hP0:oj2_hP03o`000?nU/=ooYK3O00WoYK3O00?o0000oj^bgOn[/]d02_n[
/]d00ol0003o[kCLojndg00:ojndg0;o00001Ong^]/00ol0003o]k[KokNjf`04okNjf`03o`000?nk
_=[o^kcJ00co^kcJ00?o0000oknnfOno_]T01Ono_]T2o`0000Ko`/7I00?o0000olG3f?o5`mP03Oo5
`mP00ol0003oa/CHolK4f002olK4f003o`000?o8aMSob<GH00Oob<GH00?o0000ooooooooool0F?oo
ool002gooooo00?o0000ooooooooool08_ooool00ol0003oTkG^oi>ekP08oi>ekP03o`000?nF/^_o
U[;[00OoU[;[00?o0000oiR`j?nH/>P02OnH/>P00ol0003oVjoUoi^_i@03oi^_i@Oo00002?nJ[^D0
0ol0003oX:oRoj2_hP09oj2_hP03o`000?nU/=ooYK3O00[oYK3O00?o0000oj^bgOn[/]d02_n[/]d0
0ol0003o[kCLojndg007ojndg0;o000000?o/[OMo`000?ng^]/01?ng^]/00ol0003o]k[KokNjf`05
okNjf`03o`000?nk_=[o^kcJ00co^kcJ00?o0000oknnfOno_]T00ono_]T00ol0003o`/7Iol;1f@07
ol;1f@03o`000?o5`mSoaL?H00coaL?H00Go0000olK4f?o6a=Soa/CHo`00000;olS5f003o`000?oo
oooooooo05Oooooo000/ooooo`?o00009?ooool00ol0003oTkG^oi>ekP08oi>ekP03o`000?nF/^_o
U[;[00OoU[;[00?o0000oiR`j?nH/>P01onH/>P7o`0000CoU:gX00?o0000oiZ^iOnJ[^D02OnJ[^D0
0ol0003oX:oRoj2_hP09oj2_hP03o`000?nU/=ooYK3O00[oYK3O00?o0000oj^bgOn[/]d02_n[/]d0
0ol0003o[kCLojndg004ojndg0;o00001?nb]md00ol0003o]k[KokNjf`02okNjf`03o`000?ng^]_o
]k[K00Ko]k[K00?o0000ok^lf_nk_=X02onk_=X01?l0003o_kkIoknnfOno_]T2o`0000[o`/7I00?o
0000olG3f?o5`mP03Oo5`mP00ol0003oa/CHo`00000=olS5f003o`000?oooooooooo05Kooooo000]
ooooo`03o`000?oooooooooo02Cooooo00?o0000oi>ek_nC]Nh02?nC]Nh00ol0003oU[;[oiJbj`07
oiJbj`04o`000?nH/>SoV;3XoiR`j0Go00000_n?[N/00ol0003oU:gXoiB]j007oiB]j003o`000?nJ
[^GoVZkU00WoVZkU00?o0000oj2_h_nP[n802OnP[n800ol0003oYK3OojF`g`09ojF`g`03o`000?n[
/]goZk;M00[oZk;M00?o0000ojndg?n_]=`00_n_]=`2o`0000Oo/[OM00Go0000okNjfong^]_o]k[K
o`000009okNjf`03o`000?nk_=[o^kcJ00_o^kcJ00?o0000oknnfOl000003Oo2`MT00ol0003oaL?H
olG3f00<olG3f0;o00003oo8aMP00ol0003oooooooooo`1Eooooo`00;Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?nC]NkoTkG^00SoTkG^00?o0000oiJbjonF/^/00onF/^/7o`0000SoSjg[00?o
0000oiB]j?nD[NP01onD[NP00ol0003oVZkUoiZ^i@08oiZ^i@03o`000?nP[n;oX:oR00[oX:oR00?o
0000ojF`gonU/=l02OnU/=l00ol0003oZk;Moj^bg@0:oj^bg@04o`000?n_]=co0000o`0000Wo/[OM
00Go0000okNjfong^]_o]k[Ko`000009okNjf`03o`000?nk_=[o^kcJ00_o^kcJ0_l0000?ol;1f@03
o`000?o5`mSoaL?H00[oaL?H00?o0000olO5f?l000003oo8aMP2o`0005Kooooo000]ooooo`03o`00
0?oooooooooo02Kooooo00?o0000oi>ek_nC]Nh00onC]Nh:o`0000CoRZk^00?o0000ohn]jon?[N/0
2On?[N/00ol0003oU:gXoiB]j007oiB]j003o`000?nJ[^GoVZkU00SoVZkU00?o0000oj2_h_nP[n80
2OnP[n800ol0003oYK3OojF`g`0:ojF`g`03o`000?n[/]goZk;M00WoZk;M0_l0000<ok:gg@04o`00
0?ng^]_o]k[Ko`0000[o]k[K00?o0000ok^lf_nk_=X02?nk_=X2o`000003okjof_l0003o`/7I00ko
`/7I00?o0000olG3f?o5`mP02Oo5`mP01Ol0003oalGHolO5f?o7aMSo000000oob<GH00?o0000oooo
ooooool0E?ooool002cooooo00?o0000ooooooooool0:?ooool5o`0000GoQk3`00?o0000ohZ^k_n:
[^h01on:[^h00ol0003oSjg[ohn]j`09ohn]j`03o`000?nD[NSoU:gX00OoU:gX00?o0000oiZ^iOnJ
[^D02?nJ[^D00ol0003oX:oRoj2_hP09oj2_hP03o`000?nU/=ooYK3O00[oYK3O00?o0000oj^bgOn[
/]d01On[/]d3o`000003ojbegol0003o/[OM00co/[OM00?o0000okNjfol000002ong^]/00ol0003o
^kcJok^lfP06ok^lfP03o`000?nn_m[o_[oJ00;o_[oJ00?o0000ol;1fOo2`MT03Oo2`MT00ol0003o
aL?HolG3f007olG3f003o`000?o7aMSoalGH00?oalGH00?o0000olS5f?o8aMP03Oo8aMP00ol0003o
ooooooooo`1Cooooo`00;?ooool00ol0003oooooooooo`0Yooooo`03o`000?n7/?3oQk3`00OoQk3`
00?o0000ohZ^k_n:[^h01on:[^h00ol0003oSjg[ohn]j`09ohn]j`03o`000?nD[NSoU:gX00KoU:gX
00?o0000oiZ^iOnJ[^D02OnJ[^D00ol0003oX:oRoj2_hP09oj2_hP03o`000?nU/=ooYK3O00WoYK3O
00?o0000oj^bgOn[/]d00on[/]d2o`0000Go[;GO00?o0000ok:ggOnb]md02_nb]md00ol0003o]k[K
o`00000;okNjf`03o`000?nk_=[o^kcJ00Co^kcJ0_l00006okjofP03o`000?o2`MWo`/7I00go`/7I
00?o0000olG3f?o5`mP01?o5`mP2o`0000OoalGH00?o0000olS5f?o8aMP03Oo8aMP00ol0003ooooo
ooooo`1Booooo`00;?ooool2o`0002_ooooo00?o0000ohN`l?n7/?001on7/?000ol0003oRZk^ohZ^
kP07ohZ^kP03o`000?n?[N_oSjg[00SoSjg[00?o0000oiB]j?nD[NP01onD[NP00ol0003oVZkUoiZ^
i@08oiZ^i@03o`000?nP[n;oX:oR00[oX:oR00?o0000ojF`gonU/=l02OnU/=l00ol0003oZk;Mo`00
0002o`0000So[;GO00?o0000ok:ggOnb]md02_nb]md2o`0000co]k[K00Co0000ok^lf_nk_=[o^kcJ
0_l00009okjofP03o`000?o2`MWo`/7I00go`/7I00?o0000olG3f?o5`mP00_o5`mP00ol0003oalGH
olO5f007olO5f003o`000?o8aMSob<GH00gob<GH0_l0001Cooooo`00;?ooool00ol0003ooooooooo
o`0[ooooo`03o`000?n7/?3oQk3`00OoQk3`00?o0000ohZ^k_n:[^h01on:[^h00ol0003oSjg[ohn]
j`08ohn]j`03o`000?nD[NSoU:gX00OoU:gX00?o0000oiZ^iOnJ[^D02?nJ[^D00ol0003oX:oRoj2_
hP09oj2_hP03o`000?nU/=ooYK3O00SoYK3O0ol0000<ojbeg`03o`000?nb]mgo/[OM00[o/[OM00?o
0000okNjfong^]/02ong^]/00ol0003o^kcJo`00000<okjofP03o`000?o2`MWo`/7I00co`/7I00Go
0000olG3f?o5`mSoaL?Ho`00000;olO5f003o`000?o8aMSob<GH00_ob<GH00?o0000olW7f?l00000
Doooool002cooooo00?o0000ooooooooool0;?ooool00ol0003oQk3`ohN`l007ohN`l003o`000?n:
[^koRZk^00OoRZk^00?o0000ohn]jon?[N/02?n?[N/00ol0003oU:gXoiB]j007oiB]j003o`000?nJ
[^GoVZkU00SoVZkU00?o0000oj2_h_nP[n802OnP[n800ol0003oYK3OojF`g`04ojF`g`?o00000_nU
/^800ol0003o[;GOojbeg`0:ojbeg`03o`000?nb]mgo/[OM00[o/[OM0_l0000<okNjf`;o00003Onn
_mX00ol0003o`/7Iol;1f@0=ol;1f@03o`000?o5`mSo000000goalGH00?o0000olS5f?o8aMP02Oo8
aMP01Ol0003obLOHolW7f?o9amSo000005;ooooo000/ooooo`03o`000?oooooooooo02gooooo00?o
0000ohN`l?n7/?001on7/?000ol0003oRZk^ohZ^kP07ohZ^kP03o`000?n?[N_oSjg[00SoSjg[00?o
0000oiB]j?nD[NP01onD[NP00ol0003oVZkUoiZ^i@08oiZ^i@03o`000?nP[n;oX:oR00WoX:oR00?o
0000ojF`gonU/=l00ol00006ojFbhP03o`000?n/]Moo[;GO00[o[;GO00?o0000ok:ggOnb]md02Onb
]md2o`0000[o]k[K0_l000000onj_Mco0000okjofP0=okjofP03o`000?o2`MWo`/7I00co`/7I0_l0
000?olO5f003o`000?o8aMSob<GH00Oob<GH00?o0000olW7f?o9amP00oo9amP00ol0003ooooooooo
o`1?ooooo`00;?ooool00ol0003oooooooooo`0^ooooo`03o`000?n7/?3oQk3`00OoQk3`00?o0000
ohZ^k_n:[^h01_n:[^h00ol0003oSjg[ohn]j`09ohn]j`03o`000?nD[NSoU:gX00KoU:gX00?o0000
oiZ^iOnJ[^D02?nJ[^D00ol0003oX:oRoj2_hP08oj2_hPCo00002_nU/^800ol0003o[;GOojbeg`0:
ojbeg`03o`000?nb]mgo/[OM00So/[OM00?o0000ok:ggOl000002?ng^]/00ol0003o^[gLokZmg002
okZmg003o`000?nn_m[o_[oJ00co_[oJ00?o0000ol;1fOo2`MT02_o2`MT00ol0003oa<CIo`00000@
olO5f003o`000?o8aMSob<GH00Cob<GH0_l00006olW7f0;o0000D?ooool002cooooo00?o0000oooo
ooooool0;oooool00ol0003oQk3`ohN`l007ohN`l003o`000?n:[^koRZk^00KoRZk^00?o0000ohn]
jon?[N/02?n?[N/00ol0003oU:gXoiB]j007oiB]j003o`000?nJ[^GoVZkU00SoVZkU00?o0000oj2_
h_nP[n801?nP[n83o`0000;oWK3U00?o0000ojFbh_nU/^802_nU/^800ol0003o[;GOojbeg`0:ojbe
g`03o`000?nb]mgo/[OM00Oo/[OM00Co0000ok:ggOnb]mgo00001Ong^]/2o`0000Ko^[gL00?o0000
okjof_nn_mX03?nn_mX00ol0003o`/7Iol;1f@07ol;1f@;o00000oo4a=T00ol0003oalGHolO5f00=
olO5f003o`000?o8aMSob<GH00?ob<GH00?o0000olW7f?o9amP01oo9amP00ol0003oooooooooo`1>
ooooo`00;?ooool2o`00037ooooo00?o0000ohN`l?n7/?001on7/?000ol0003oRZk^ohZ^kP06ohZ^
kP03o`000?n?[N_oSjg[00SoSjg[00?o0000oiB]j?nD[NP01onD[NP00ol0003oVZkUoiZ^i@08oiZ^
i@03o`000?nP[n;oX:oR00?o00001_nM/>D00ol0003oYK;RojFbhP09ojFbhP03o`000?n/]Moo[;GO
00[o[;GO00?o0000ok:ggOnb]md01onb]md01?l0003o/[OMok:ggOl00003okNjf`;o00002Onj_M`0
0ol0003o_[oJokjofP0;okjofP03o`000?o2`MWo`/7I00Ko`/7I00?o0000olC4fOo4a=T01?o4a=T0
0ol0003oalGHolO5f00=olO5f005o`000?o8aMSob<GHolS5f?l000002oo9amP00ol0003ooooooooo
o`1=ooooo`00:oooool00ol0003oooooooooo`0booooo`03o`000?n7/?3oQk3`00OoQk3`00?o0000
ohZ^k_n:[^h01_n:[^h00ol0003oSjg[ohn]j`08ohn]j`03o`000?nD[NSoU:gX00OoU:gX00?o0000
oiZ^iOnJ[^D00onJ[^D7o`0000[oWK3U00?o0000ojFbh_nU/^802OnU/^800ol0003o[;GOojbeg`0:
ojbeg`03o`000?nb]mgo/[OM00Ko/[OM00Oo0000ok:ggOnb]mgo/[OMo`000?ng^]_o000000co^[gL
00?o0000okjof_nn_mX02onn_mX00ol0003o`/7Iol;1f@04ol;1f@03o`000?o4a=Woa<CI00Koa<CI
00?o0000olO5f?o7aMP03Oo7aMP00ol0003ob<GHo`00000=olW7f003o`000?oooooooooo04cooooo
000[ooooo`03o`000?oooooooooo03?ooooo00?o0000ohN`l?n7/?001on7/?000ol0003oRZk^ohZ^
kP06ohZ^kP03o`000?n?[N_oSjg[00SoSjg[00?o0000oiB]j?nD[NP00onD[NP9o`0000GoUZkX00?o
0000oif`iOnM/>D02_nM/>D00ol0003oYK;RojFbhP09ojFbhP03o`000?n/]Moo[;GO00[o[;GO00?o
0000ok:ggOnb]md01Onb]md01?l0003o/[OMok:ggOnb]md2o`0000go^[gL00?o0000okjof_nn_mX0
3?nn_mX01?l0003o`/7Iol;1fOo2`MT2o`0000Woa<CI00?o0000olO5f?o7aMP03Oo7aMP2o`0000ko
bLOH0_l0001=ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o
000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0dooooo`03o`000?n7/?3oQk3`00Oo
Qk3`00?o0000ohZ^k_n:[^h01_n:[^h00ol0003oSjg[ohn]j`03ohn]j`[o00001?n>[>/00ol0003o
UZkXoiJ^j008oiJ^j003o`000?nM/>GoWK3U00WoWK3U00?o0000ojFbh_nU/^802_nU/^800ol0003o
[;GOojbeg`09ojbeg`03o`000?nb]mgo/[OM00Go/[OM1?l000000ond^moo0000okZmg00=okZmg003
o`000?nn_m[o_[oJ00co_[oJ00?o0000ol;1fOl000003?o4a=T00ol0003oalGHolO5f00;olO5f003
o`000?o8amWo000000oobLOH0_l0001<ooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=Oooool00ol0003o
Qk3`ohN`l003ohN`l1;o00001On6Znd00ol0003oSZc[ohj/j`07ohj/j`03o`000?nF[^SoUZkX00So
UZkX00?o0000oif`iOnM/>D02OnM/>D00ol0003oYK;RojFbhP09ojFbhP03o`000?n/]Moo[;GO00[o
[;GO00?o0000ok:ggOnb]md00onb]md2o`0000Go];_O00?o0000okZmg?nj_M`03?nj_M`00ol0003o
_[oJokjofP0;okjofP;o00003_o4a=T00ol0003oalGHolO5f009olO5f005o`000?o8amWob<OIolS7
fOl000003oo9amP00ol0003oooooooooo`1:ooooo`004?ooool01Ol@413ooooooooooooooooo410@
00_ooooo1Ol00006ooooo`03o`000?oooooooooo03Kooooo1Ol00004og^[lP03o`000?moZo3oOj_`
00KoOj_`00?o0000ohJ[kOn6Znd02?n6Znd00ol0003oSZc[ohj/j`07ohj/j`03o`000?nF[^SoUZkX
00SoUZkX00?o0000oif`iOnM/>D02OnM/>D00ol0003oYK;RojFbhP09ojFbhP03o`000?n/]Moo[;GO
00[o[;GO00?o0000ok:ggOl000000_l000000ond^moo0000okBkg`05okBkg`03o`000?nj_Mco^[gL
00co^[gL00?o0000okjof_nn_mX02?nn_mX2o`000003ol73fol0003oa<CI00koa<CI00?o0000olO5
f?o7aMP01oo7aMP00ol0003ob<OIolS7f@03olS7f@03o`000?o9amSobLOH00gobLOH00?o0000oooo
ooooool0BOooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgooooo
o`0000Oooooo00?o0000ooooooooool0=oooool00ol0003oNj_bog^[lP06og^[lP03o`000?moZo3o
Oj_`00KoOj_`00?o0000ohJ[kOn6Znd02?n6Znd00ol0003oSZc[ohj/j`07ohj/j`03o`000?nF[^So
UZkX00OoUZkX00?o0000oif`iOnM/>D02_nM/>D00ol0003oYK;RojFbhP09ojFbhP03o`000?n/]Moo
[;GO00Wo[;GO0_l00004okBkg`03o`000?nd^moo];_O00Go];_O00?o0000okZmg?nj_M`02onj_M`0
0ol0003o_[oJokjofP07okjofP03o`000?o1`m_o`L?K00;o`L?K00?o0000olC4fOo4a=T03Oo4a=T0
0ol0003oalGHolO5f004olO5f0;o00001oo8amT00ol0003obLOHolW7f00<olW7f0;o0000B_ooool0
013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool0>?ooool00ol0003oNj_bog^[lP06og^[lP03o`000?moZo3oOj_`00KoOj_`00?o
0000ohJ[kOn6Znd02?n6Znd00ol0003oSZc[ohj/j`07ohj/j`03o`000?nF[^SoUZkX00OoUZkX00?o
0000oif`iOnM/>D02OnM/>D00ol0003oYK;RojFbhP09ojFbhP03o`000?n/]Moo[;GO00Ko[;GO0ol0
00000on]^N;o0000okBkg`03okBkg`03o`000?nd^moo];_O00Ko];_O00?o0000okZmg?nj_M`02onj
_M`00ol0003o_[oJokjofP04okjofP;o00001_o1`m/00ol0003oa<CIolC4f@0<olC4f@03o`000?o7
aMSoalGH00?oalGH00?o0000olS7fOo8amT01oo8amT00ol0003obLOHolW7f00=olW7f0;o0000BOoo
ool0013ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo0_l0
000kooooo`03o`000?mkZo;oNj_b00KoNj_b00?o0000ogn[l?moZo001_moZo000ol0003oQZ_]ohJ[
k@07ohJ[k@03o`000?n>[>_oSZc[00OoSZc[00?o0000oiJ^j?nF[^P02?nF[^P00ol0003oWK3Uoif`
i@09oif`i@03o`000?nU/^;oYK;R00WoYK;R00?o0000ojbegon/]Ml00on/]Ml2o`0000Go[KWR00Go
0000okBkgond^moo];_Oo`000008okBkg`03o`000?nj_Mco^[gL00co^[gL00Co0000okjof_nn_m[o
_[oJ0_l00009ol73f`03o`000?o4a=Woa<CI00coa<CI00Go0000olO5f?o7aMSoalGHo`00000;olS7
f@03o`000?o9amSobLOH00_obLOH00?o0000olW7fOl00000BOooool0013ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0>_ooool00ol0
003oNj_bog^[lP06og^[lP03o`000?moZo3oOj_`00KoOj_`00?o0000ohJ[kOn6Znd01on6Znd00ol0
003oSZc[ohj/j`07ohj/j`03o`000?nF[^SoUZkX00SoUZkX00?o0000oif`iOnM/>D02OnM/>D00ol0
003oYK;RojFbhP09ojFbhP03o`000?n/]Moo000000;o00002?n]^N801?l0003o];_OokBkgol00009
okBkg`03o`000?nj_Mco^[gL00co^[gL00?o0000okjof_l000002oo1`m/00ol0003oa<CIolC4f@0=
olC4f@03o`000?o7aMSo000000gob<OI00?o0000olW7f?o9amP02Oo9amP01Ol0003obLOIolW7fOo9
amWo000004Sooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`05ooooo`03o`000?oooooooooo03cooooo00?o0000og^[l_mkZo801_mkZo800ol0003oOj_`ogn[
l006ogn[l003o`000?n6ZngoQZ_]00OoQZ_]00?o0000ohj/jon>[>/01on>[>/00ol0003oUZkXoiJ^
j007oiJ^j003o`000?nM/>GoWK3U00WoWK3U00?o0000ojFbh_nU/^802?nU/^83o`0000co[KWR00?o
0000okBkgol000002_nd^ml00ol0003o^[gLokZmg00;okZmg0;o00003Oo1`m/00ol0003oa<CIolC4
f@0<olC4f@;o00003oo8amT00ol0003obLOHolW7f007olW7f003o`000?o9amWobLOI00;obLOI0_l0
0017ooooo`00:_ooool00ol0003oooooooooo`0mooooo`03o`000?mkZo;oNj_b00KoNj_b00?o0000
ogn[l?moZo001_moZo000ol0003oQZ_]ohJ[k@07ohJ[k@03o`000?n>[>_oSZc[00OoSZc[00?o0000
oiJ^j?nF[^P01onF[^P00ol0003oWK3Uoif`i@09oif`i@03o`000?nU/^;oYK;R00CoYK;R0ol00002
ojFfi@03o`000?n]^N;o[KWR00[o[KWR00?o0000okBkgol000002ond^ml00ol0003o^[gLokZmg008
okZmg0;o000000?o_<7No`000?o1`m/03Oo1`m/00ol0003oa<CIolC4f@0:olC4f@03o`000?o6am_o
0000013ob<OI00?o0000olW7f?o9amP01?o9amP2o`0000KobLOI00?o0000ooooooooool0AOooool0
02[ooooo00?o0000ooooooooool0?_ooool00ol0003oNj_bog^[lP06og^[lP03o`000?moZo3oOj_`
00GoOj_`00?o0000ohJ[kOn6Znd01on6Znd00ol0003oSZc[ohj/j`08ohj/j`03o`000?nF[^SoUZkX
00OoUZkX00?o0000oif`iOnM/>D02OnM/>D00ol0003oYK;RojFbhP03o`0000KoYKKU00?o0000ojfi
h_n]^N802_n]^N82o`0000_o];_O00?o0000okZmg?nj_M`01onj_M`00ol0003o_<7Nokc1gP02okc1
gP03o`000?o1`m_o`L?K00co`L?K00?o0000olC4fOo4a=T01oo4a=T2o`0000?oa/OK00?o0000olS7
fOo8amT03Oo8amT00ol0003obLOHolW7f003olW7f003o`000?o9amWobLOI00OobLOI00?o0000oooo
ooooool0A?ooool002[ooooo00?o0000ooooooooool0?oooool00ol0003oNj_bog^[lP06og^[lP03
o`000?moZo3oOj_`00GoOj_`00?o0000ohJ[kOn6Znd01on6Znd00ol0003oSZc[ohj/j`07ohj/j`03
o`000?nF[^SoUZkX00OoUZkX00?o0000oif`iOnM/>D02?nM/>D4o`0000[oYKKU00?o0000ojfih_n]
^N802_n]^N800ol0003o];_OokBkg`0:okBkg`03o`000?nj_Mco^[gL00Co^[gL0_l00006okc1gP03
o`000?o1`m_o`L?K00co`L?K00?o0000olC4fOo4a=T01Oo4a=T00ol0003oa/OKolK7f`04olK7f`03
o`000?o8amWob<OI00gob<OI00Go0000olW7f?o9amSobLOHo`00000;olW7f@03o`000?oooooooooo
04?ooooo000Yooooo`?o0000@?ooool2o`0000SoNj_b00?o0000ogn[l?moZo001OmoZo000ol0003o
QZ_]ohJ[k@07ohJ[k@03o`000?n>[>_oSZc[00OoSZc[00?o0000oiJ^j?nF[^P01onF[^P00ol0003o
WK3Uoif`i@04oif`i@?o00000_nK/nP00ol0003oYKKUojFfi@0:ojFfi@03o`000?n]^N;o[KWR00Wo
[KWR0_l0000<okBkg`04o`000?nj_Mco^[gLokZmg0;o00002Onl`Mh00ol0003o`L?Kol73f`0;ol73
f`03o`000?o4a=Woa<CI00Coa<CI00?o0000olK7foo6am/01_o6am/00ol0003ob<OIolS7f@0=olS7
f@03o`000?o9amSo000000cobLOI0_l00014ooooo`00:_ooool00ol0003oooooooooo`10ooooo`;o
00002?mkZo800ol0003oOj_`ogn[l005ogn[l003o`000?n6ZngoQZ_]00KoQZ_]00?o0000ohj/jon>
[>/02?n>[>/00ol0003oUZkXoiJ^j007oiJ^j003o`000?nM/>GoWK3U00?o00001_nK/nP00ol0003o
YKKUojFfi@09ojFfi@03o`000?n]^N;o[KWR00Wo[KWR0_l0000=okBkg`03o`000?nj_Mco000000_o
_<7N00?o0000ol73foo1`m/03?o1`m/01?l0003oa<CIolC4fOo4a=T2o`0000[oa/OK00?o0000olS7
fOo8amT03?o8amT2o`0000kobLOI00?o0000ooooooooool0@_ooool002[ooooo00?o0000oooooooo
ool0@Oooool2o`0000SoNj_b00?o0000ogn[l?moZo001OmoZo000ol0003oQZ_]ohJ[k@06ohJ[k@03
o`000?n>[>_oSZc[00SoSZc[00?o0000oiJ^j?nF[^P00onF[^P6o`0000[oVk?X00?o0000ojFfiOnU
]^D02OnU]^D00ol0003o[KWRojfihP08ojfihP03o`000?n]^N;o000000co];_O0_l0000=okc1gP03
o`000?o1`m_o`L?K00co`L?K00?o0000olC4fOl000003Oo6am/00ol0003ob<OIolS7f@0:olS7f@03
o`000?o8b=[o000000oobLOI00?o0000ooooooooool0@Oooool002[ooooo00?o0000ooooooooool0
@_ooool@o`0000;oOj_`00?o0000ohJ[kOn6Znd01_n6Znd00ol0003oSZc[ohj/j`03ohj/j`[o0000
1?nA/>/00ol0003oVk?Xoi^cj00:oi^cj003o`000?nU]^GoYKKU00WoYKKU00?o0000ojfih_n]^N80
1on]^N801?l0003o[KWRojfih_l00009okBkg`;o000000?o][oQo`000?nl`Mh03Onl`Mh00ol0003o
`L?Kol73f`0;ol73f`;o00003_o6am/00ol0003ob<OIolS7f@08olS7f@;o00000oo8b=X00ol0003o
bLOIolW7f@0=olW7f@03o`000?oooooooooo043ooooo000Yooooo`03o`000?oooooooooo04Cooooo
00?o0000og6Vl_maY_801_maY_800ol0003oMZOaogJWl@03ogJWlA7o00001On7[>h00ol0003oTK3[
oi6`j`07oi6`j`03o`000?nK/nSoVk?X00[oVk?X00?o0000ojFfiOnU]^D02OnU]^D00ol0003o[KWR
ojfihP06ojfihP04o`000?n]^N;o[KWRo`0000Oo];_O0_l00004okJoh@03o`000?nl`Mko_<7N00co
_<7N00?o0000ol73foo1`m/02?o1`m/2o`000003ol;6gOl0003oa/OK00koa/OK00?o0000olS7fOo8
amT01_o8amT00ol0003ob<SJolS8fP04olS8fP03o`000?o9amWobLOI00cobLOI00?o0000oooooooo
ool0@?ooool002Wooooo00?o0000ooooooooool0AOooool00ol0003oLJKbog6VlP06og6VlP03o`00
0?mfYo7oMZOa00GoMZOa00?o0000ogjYkomnZNl01_mnZNl00ol0003oQjc^ohN/kP08ohN/kP03o`00
0?nA/>_oTK3[00OoTK3[00?o0000oi^cj?nK/nP02OnK/nP00ol0003oYKKUojFfi@09ojFfi@03o`00
0?n]^N;o[KWR00Ko[KWR00Go0000ojfih_n]^N;o[KWRo`000004okBkg`;o00001onf_n400ol0003o
_<7Nokc1gP0<okc1gP03o`000?o1`m_o`L?K00Ko`L?K00?o0000ol;6gOo2a]d00_o2a]d00ol0003o
a/OKolK7f`0=olK7f`03o`000?o8amWob<OI00Cob<OI00?o0000olS8f_o8b=X01_o8b=X00ol0003o
bLOIolW7f@0<olW7f@03o`000?oooooooooo03oooooo000Yooooo`03o`000?oooooooooo04Kooooo
00?o0000og6Vl_maY_801_maY_800ol0003oMZOaogJWl@05ogJWl@03o`000?mnZNooOZW_00KoOZW_
00?o0000ohN/k_n7[>h02?n7[>h00ol0003oTK3[oi6`j`07oi6`j`03o`000?nK/nSoVk?X00WoVk?X
00?o0000ojFfiOnU]^D02OnU]^D00ol0003o[KWRojfihP05ojfihP03o`000?n]^N;o[KWR00;o[KWR
00Co0000okBkgol0003o00002_nf_n400ol0003o_<7Nokc1gP0;okc1gP03o`000?o1`m_o`L?K00Co
`L?K0_l00006ol;6g@03o`000?o6am_oa/OK00goa/OK00Co0000olS7fOo8amWob<OI0_l00009olS8
fP03o`000?o9amWobLOI00cobLOI0_l00010ooooo`00:Oooool2o`0004Sooooo00?o0000og6Vl_ma
Y_801_maY_800ol0003oMZOaogJWl@05ogJWl@03o`000?mnZNooOZW_00KoOZW_00?o0000ohN/k_n7
[>h02?n7[>h00ol0003oTK3[oi6`j`07oi6`j`03o`000?nK/nSoVk?X00WoVk?X00?o0000ojFfiOnU
]^D02OnU]^D00ol0003o[KWRojfihP04ojfihP03o`000?n]^N;o[KWR00;o[KWR0_l0000<okJoh@03
o`000?nl`Mko_<7N00co_<7N00Co0000ol73foo1`m_o`L?K0_l00009ol;6g@03o`000?o6am_oa/OK
00goa/OK00?o0000olS7fOl000003?o8b=X00ol0003obLOIolW7f@0:olW7f@04o`000?o7b=[o0000
o`0003oooooo000Yooooo`03o`000?oooooooooo04Sooooo00?o0000og6Vl_maY_801_maY_800ol0
003oMZOaogJWl@05ogJWl@03o`000?mnZNooOZW_00KoOZW_00?o0000ohN/k_n7[>h02?n7[>h00ol0
003oTK3[oi6`j`07oi6`j`03o`000?nK/nSoVk?X00WoVk?X00?o0000ojFfiOnU]^D02?nU]^D00ol0
003o[KWRojfihP04ojfihP03o`000?n]^N;o000000;o000000?o[[gUo`000?nf_n403?nf_n400ol0
003o_<7Nokc1gP0<okc1gP03o`000?o1`m_o000000co`/KM00?o0000olK7foo6am/03?o6am/2o`00
00kob<SJ00?o0000olW7fOo9amT01oo9amT2o`0000?oalSJ00?o0000ooooooooool0?Oooool002Wo
oooo00?o0000ooooooooool0BOooool00ol0003oLJKbog6VlP06og6VlP03o`000?mfYo7oMZOa00Go
MZOa00?o0000ogjYkomnZNl01_mnZNl00ol0003oQjc^ohN/kP08ohN/kP03o`000?nA/>_oTK3[00Oo
TK3[00?o0000oi^cj?nK/nP02?nK/nP00ol0003oYKKUojFfi@09ojFfi@03o`000?n]^N;o[KWR00?o
[KWR0_l00005ojjmi@03o`000?nf_n7o][oQ00_o][oQ00?o0000okc1g_nl`Mh02onl`Mh2o`0000ko
`/KM00?o0000olK7foo6am/02_o6am/00ol0003oa/WLo`00000?olS8fP03o`000?o9amWobLOI00Go
bLOI00?o0000olO8f_o7b=X01?o7b=X00ol0003oooooooooo`0looooo`00:Oooool00ol0003ooooo
ooooo`1:ooooo`03o`000?maY_;oLJKb00KoLJKb00?o0000ogJWlOmfYo401OmfYo400ol0003oOZW_
ogjYk`06ogjYk`03o`000?n7[>koQjc^00SoQjc^00?o0000oi6`jonA/>/01onA/>/00ol0003oVk?X
oi^cj008oi^cj003o`000?nU]^GoYKKU00WoYKKU00?o0000ojfih_l000000ol00007ojjmi@03o`00
0?nf_n7o][oQ00_o][oQ00?o0000okc1g_nl`Mh02?nl`Mh2o`000003okg5hOl0003o`/KM00go`/KM
00?o0000olK7foo6am/02?o6am/2o`0000?oa/WL00?o0000olS8f_o8b=X03?o8b=X00ol0003obLOI
olW7f@04olW7f@03o`000?o7b=[oalSJ00KoalSJ00?o0000ooooooooool0>oooool002Wooooo00?o
0000ooooooooool0Boooool00ol0003oLJKbog6VlP05og6VlP03o`000?mfYo7oMZOa00KoMZOa00?o
0000ogjYkomnZNl01_mnZNl00ol0003oQjc^ohN/kP07ohN/kP03o`000?nA/>_oTK3[00SoTK3[00?o
0000oi^cj?nK/nP02?nK/nP00ol0003oYKKUojFfi@07ojFfi@?o00000on^_ND00ol0003o[[gUojjm
i@06ojjmi@03o`000?nf_n7o][oQ00_o][oQ00?o0000okc1g_nl`Mh01_nl`Mh00ol0003o_LGQokg5
h@02okg5h@03o`000?o2a]go`/KM00co`/KM00?o0000olK7foo6am/01_o6am/00ol0003oa/WLolK9
g004olK9g003o`000?o8b=[ob<SJ00cob<SJ00Co0000olW7fOo9amWobLOI0_l00009olO8fP;o0000
??ooool002Wooooo00?o0000ooooooooool0C?ooool00ol0003oLJKbog6VlP05og6VlP03o`000?mf
Yo7oMZOa00GoMZOa00?o0000ogjYkomnZNl01omnZNl00ol0003oQjc^ohN/kP07ohN/kP03o`000?nA
/>_oTK3[00SoTK3[00?o0000oi^cj?nK/nP02?nK/nP01?l0003oYKKUojFfiOnU]^D5o`0000;oY;[X
00Go0000ojjmiOn^_NGo[[gUo`000009ojjmi@03o`000?nf_n7o][oQ00[o][oQ00?o0000okc1g_nl
`Mh01?nl`Mh2o`0000Ko_LGQ00?o0000ol;6gOo2a]d03?o2a]d00ol0003oa/OKolK7f`04olK7f`03
o`000?o6bMcoa/WL00Koa/WL00?o0000olS8f_o8b=X03?o8b=X00ol0003obLOIo`00000<olO8fP03
o`000?oooooooooo03[ooooo000Xooooo`?o0000C_ooool00ol0003oLJKbog6VlP05og6VlP03o`00
0?mfYo7oMZOa00GoMZOa00?o0000ogjYkomnZNl01omnZNl00ol0003oQjc^ohN/kP07ohN/kP03o`00
0?nA/>_oTK3[00SoTK3[00?o0000oi^cj?nK/nP01_nK/nP5o`0000SoY;[X00Co0000ojjmiOn^_NGo
00002_n^_ND00ol0003o][oQokJoh@0:okJoh@04o`000?nl`Mko_<7Nokc1gP;o00002OnmaN400ol0
003o`/KMol;6g@0<ol;6g@04o`000?o6am_oa/OKolK7f`;o00002_o6bM`00ol0003ob<SJolS8fP0;
olS8fP;o00003_o7b=X00ol0003oooooooooo`0iooooo`00:?ooool00ol0003oooooooooo`1?oooo
o`03o`000?maY_;oLJKb00GoLJKb00?o0000ogJWlOmfYo401OmfYo400ol0003oOZW_ogjYk`07ogjY
k`03o`000?n7[>koQjc^00OoQjc^00?o0000oi6`jonA/>/02?nA/>/00ol0003oVk?Xoi^cj005o`00
00;oV[K/00?o0000ojBjj?nT^^P02OnT^^P00ol0003o[[gUo`00000;ojjmi@03o`000?nf_n7o][oQ
00[o][oQ00?o0000okc1g_l000003?nmaN400ol0003o`/KMol;6g@0<ol;6g@03o`000?o6am_o0000
00goa/WL00?o0000olS8f_o8b=X02Oo8b=X00ol0003oal[Lo`00000?olO8fP03o`000?oooooooooo
03Sooooo000<ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b
<_l0003o410@olc<c007ooooo`03o`000?oooooooooo053ooooo1_l00002og6VlP03o`000?mfYo7o
MZOa00GoMZOa00?o0000ogjYkomnZNl01omnZNl00ol0003oQjc^ohN/kP07ohN/kP03o`000?nA/>_o
TK3[00?oTK3[1ol00008oiZfk003o`000?nT^^SoY;[X00WoY;[X0_l0000;ojjmi@03o`000?nf_n7o
][oQ00[o][oQ0_l0000>okg5h@03o`000?o2a]go`/KM00_o`/KM0_l0000?olK9g003o`000?o8b=[o
b<SJ00Kob<SJ0_l00003olO:g003o`000?o7b=[oalSJ00coalSJ0_l0000iooooo`003?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401ooo
ool00ol0003oooooooooo`1@ooooo`03o`000?mZXo;oJZ?b00?oJZ?b2Ol00002ogJWl@03o`000?mn
ZNooOZW_00OoOZW_00?o0000ohN/k_n7[>h00on7[>h9o`0000GoS[7^00?o0000oiZfk?nJ]^`02?nJ
]^`00ol0003oY;[XojBjj008ojBjj0;o00003?n^_ND00ol0003o][oQokJoh@07okJoh@;o000000?o
]lCTo`000?nmaN403OnmaN400ol0003o`/KMol;6g@09ol;6g@;o000000?o`lWOo`000?o6bM`03oo6
bM`00ol0003ob<SJolS8fP04olS8fP03o`000?o7b]coal[L00Coal[L00?o0000olO8f_o7b=X03?o7
b=X00ol0003oooooooooo`0gooooo`003?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo057ooooo00?o0000ofZSl_mZXo80
1OmZXo800ol0003oKjGbofnUlP03ofnUlQ;o00001?n2[O000ol0003oS[7^ohjakP08ohjakP03o`00
0?nJ]^coV[K/00SoV[K/00?o0000ojBjj?nT^^P01?nT^^P3o`000003ojBjj?l0003o000000co[[gU
00?o0000okJohOnf_n401?nf_n42o`0000Co]lCT00?o0000okg5hOnmaN403?nmaN400ol0003o`/KM
ol;6g@07ol;6g@03o`000?o3bMoo`lWO00;o`lWO00?o0000olK9g?o6bM`03_o6bM`01?l0003ob<SJ
olS8f_o8b=X2o`0000Soal[L00?o0000olO8f_o7b=X03?o7b=X00ol0003oooooooooo`0fooooo`00
3?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@07oooo
o`03o`000?oooooooooo05;ooooo00?o0000ofZSl_mZXo801OmZXo800ol0003oKjGbofnUlP05ofnU
lP03o`000?mhZ?7oN:Sa00OoN:Sa00?o0000oh:]l?n2[O001on2[O000ol0003oS[7^ohjakP08ohja
kP03o`000?nJ]^coV[K/00SoV[K/00?o0000ojBjj?nT^^P00ol00005ojBjj0;o00003?n^_ND00ol0
003o][oQokJoh@02okJoh@03o`000?nga>Co]lCT00Go]lCT00?o0000okg5hOnmaN403?nmaN400ol0
003o`/KMol;6g@04ol;6g@;o00001_o3bMl00ol0003oa/WLolK9g00>olK9g003o`000?o8b=[o0000
00_oal[L00?o0000olO8f_o7b=X02oo7b=X2o`0003Oooooo000<ooooo`05o`000?oooooooooooooo
ool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Oooooo00?o0000ooooooooool0Doooool0
0ol0003oJZ?bofZSlP05ofZSlP03o`000?m_YO;oKjGb00GoKjGb00?o0000ogRXlOmhZ?401omhZ?40
0ol0003oPZg`oh:]l007oh:]l003o`000?n>/NkoS[7^00SoS[7^00?o0000oiZfk?nJ]^`01onJ]^`3
o`0000WoY;[X0_l0000<ojjmi@04o`000?nf_n7o0000o`0000Wo]lCT00?o0000okg5hOnmaN403?nm
aN401?l0003o`/KMol;6gOo2a]d2o`0000Wo`lWO00?o0000olK9g?o6bM`03Oo6bM`2o`0000goal[L
00?o0000olO8f_o7b=X02?o7b=X2o`000003olG8gOl0003o000003Kooooo000<ooooo`05oa0@4?oo
ooooooooooooool@41002oooool00omEEEGoQhN7ooooo`09ooooo`03o`000?oooooooooo05Cooooo
00?o0000ofZSl_mZXo801OmZXo800ol0003oKjGbofnUlP05ofnUlP03o`000?mhZ?7oN:Sa00OoN:Sa
00?o0000oh:]l?n2[O001on2[O000ol0003oS[7^ohjakP08ohjakP03o`000?nJ]^coV[K/00?oV[K/
0ol00002oiZfk003o`000?nT^^SoY;[X00SoY;[X0_l0000:ojjmi@?o00003?nga>@00ol0003o_LGQ
okg5h@0<okg5h@03o`000?o2a]go000000co`lWO00?o0000olK9g?o6bM`02oo6bM`00ol0003oaLcO
o`00000=olO:g003o`000?o7b=[oalSJ00OoalSJ00?o0000olG8gOo5b=d00_o5b=d00ol0003ooooo
ooooo`0dooooo`003?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0
2?ooool2o`0005Oooooo00?o0000ofZSl_mZXo801OmZXo800ol0003oKjGbofnUlP05ofnUlP03o`00
0?mhZ?7oN:Sa00OoN:Sa00?o0000oh:]l?n2[O001on2[O000ol0003oS[7^ohjakP08ohjakP03o`00
0?nJ]^co000000;o00001OnJ]^`00ol0003oY;[XojBjj009ojBjj0;o00001_n^_ND3o`0000;o[/7X
00?o0000okO4i?nga>@02onga>@00ol0003o_LGQokg5h@0;okg5h@;o00003_o3bMl00ol0003oa/WL
olK9g008olK9g0;o00000oo5c=l00ol0003oal[LolO:g00;olO:g003o`000?o7b=[oalSJ00CoalSJ
0_l00006olG8g@03o`000?oooooooooo03?ooooo000<ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo05Oooooo00?o0000ofZSl_mZ
Xo801OmZXo800ol0003oKjGbofnUlP05ofnUlP03o`000?mhZ?7oN:Sa00OoN:Sa00?o0000oh:]l?n2
[O001on2[O000ol0003oS[7^ohjakP06ohjakP?o00002OnJ]^`00ol0003oY;[XojBjj009ojBjj0;o
00000_n^_ND3o`0000Ko[/7X00?o0000okO4i?nga>@02onga>@00ol0003o_LGQokg5h@09okg5h@03
o`000?nnbN?o000000oo`lWO00?o0000olK9g?o6bM`01_o6bM`00ol0003oaLcOolG<g`04olG<g`03
o`000?o7b]coal[L00_oal[L00Co0000olO8f_o7b=[oalSJ0_l00009olG8g@03o`000?oooooooooo
03;ooooo000Wooooo`03o`000?oooooooooo05Sooooo00?o0000ofZSl_mZXo801OmZXo800ol0003o
KjGbofnUlP05ofnUlP03o`000?mhZ?7oN:Sa00OoN:Sa00?o0000oh:]l?n2[O001on2[O000ol0003o
S[7^ohjakP02ohjakP?o00000_n>/Nh00ol0003oV[K/oiZfk008oiZfk003o`000?nT^^SoY;[X00So
Y;[X1?l0000:ojk1j003o`000?nga>Co]lCT00_o]lCT00?o0000okg5hOnmaN401_nmaN42o`0000?o
_/WS00?o0000ol?9goo3bMl03Oo3bMl00ol0003oa/WLolK9g004olK9g003o`000?o5c=ooaLcO00Ko
aLcO00?o0000olO:g?o7b]`02oo7b]`00ol0003oalSJo`00000<olG8g@03o`000?oooooooooo037o
oooo000Wooooo`03o`000?oooooooooo05Wooooo00?o0000ofZSl_mZXo801OmZXo800ol0003oKjGb
ofnUlP05ofnUlP03o`000?mhZ?7oN:Sa00OoN:Sa00?o0000oh:]l?n2[O001_n2[O000ol0003oS[7^
o`000002o`0000KoS[7^00?o0000oiZfk?nJ]^`02?nJ]^`00ol0003oY;[XojBjj004ojBjj0?o0000
0_nT_^`00ol0003o[/7Xojk1j00:ojk1j003o`000?nga>Co]lCT00_o]lCT00?o0000okg5hOnmaN40
1?nmaN400ol0003o_/WSokk9h`04okk9h`03o`000?o3bMoo`lWO00go`lWO00Co0000olK9g?o6bMco
a/WL0_l0000:olG<g`03o`000?o7b]coal[L00[oal[L0_l0000=olG8g@;o0000<_ooool002Oooooo
00?o0000ooooooooool0F_ooool00ol0003oJZ?bofZSlP05ofZSlP03o`000?m_YO;oKjGb00GoKjGb
00?o0000ogRXlOmhZ?401omhZ?400ol0003oPZg`oh:]l004oh:]l0?o00002_n>/Nh00ol0003oV[K/
oiZfk008oiZfk003o`000?nT^^SoY;[X00?o00001OnT_^`2o`0000co[/7X00?o0000okO4i?nga>@0
2onga>@01?l0003o_LGQokg5hOnmaN42o`0000So_/WS00?o0000ol?9goo3bMl03Oo3bMl00ol0003o
a/WLo`00000=olG<g`03o`000?o7b]coal[L00Soal[L00?o0000olC;gol000003_o5b=d00ol0003o
ooooooooo`0`ooooo`009oooool00ol0003oooooooooo`1Kooooo`03o`000?mZXo;oJZ?b00GoJZ?b
00?o0000ofnUl_m_YO801Om_YO800ol0003oN:SaogRXl@07ogRXl@03o`000?n2[O3oPZg`00?o0000
0on2[O000ol0003oS[7^ohjakP08ohjakP03o`000?nJ]^coV[K/00KoV[K/1?l00009ojBnk0;o0000
3?n^`NP00ol0003o]lCTokO4i00;okO4i003o`000?nmaN7o000000_o_/WS00?o0000ol?9goo3bMl0
3?o3bMl2o`0000koaLcO00?o0000olO:g?o7b]`01_o7b]`2o`0000?oa<_O00?o0000olG8gOo5b=d0
3?o5b=d00ol0003oooooooooo`0_ooooo`009oooool2o`0005gooooo1_l00002ofZSlP03o`000?m_
YO;oKjGb00GoKjGb00?o0000ogRXlOmhZ?401_mhZ?43o`0000OoPZg`00?o0000ohjak_n>/Nh02?n>
/Nh00ol0003oV[K/oiZfk005o`0000;oV;[_00?o0000ojBnk?nT_^`02OnT_^`2o`0000co[/7X00?o
0000okO4i?nga>@02_nga>@2o`0000go_/WS00?o0000ol?9goo3bMl02Oo3bMl2o`000003ol;=hol0
003oaLcO00koaLcO00?o0000olO:g?o7b]`01?o7b]`00ol0003oa<_OolC;g`04olC;g`03o`000?o5
b=goaLSM00coaLSM00?o0000ooooooooool0;_ooool002Kooooo0_l0001Oooooo`03o`000?mXX_;o
J:;b00;oJ:;b2Ol00002ofnUlP03o`000?mhZ?7oN:Sa00;oN:Sa0ol00002ogRXl@03o`000?n2[O3o
PZg`00KoPZg`00?o0000ohjak_n>/Nh00on>/Nh7o`0000SoV;[_00?o0000ojBnk?nT_^`02OnT_^`2
o`0000co[/7X00?o0000okO4i?nga>@01_nga>@3o`0000;o]lSW00?o0000okk9honnbN<02onnbN<0
0ol0003o`lWOol?9g`07ol?9g`03o`000?o2cN?o`/gS00;o`/gS00?o0000olG<goo5c=l03Oo5c=l0
1?l0003oal[LolO:g?o7b]`2o`0000Soa<_O00?o0000olG8gOo5b=d02oo5b=d2o`0002oooooo000W
ooooo`03o`000?oooooooooo05kooooo00?o0000ofRRl_mXX_801OmXX_800ol0003oK:GcofbUl`02
ofbUla_o00001On<]?400ol0003oV;[_oiRjk`08oiRjk`03o`000?nT_^coY;k/00WoY;k/0_l0000<
ojk1j003o`000?nga>Co]lCT00?o]lCT0_l00006okO8i`03o`000?nnbN?o_/WS00_o_/WS00?o0000
ol?9goo3bMl01?o3bMl2o`0000Ko`/gS00?o0000olG<goo5c=l03Oo5c=l00ol0003oal[Lo`00000;
olC;g`03o`000?o5b=goaLSM00_oaLSM0_l0000^ooooo`009oooool00ol0003oooooooooo`1Ooooo
o`03o`000?mXX_;oJ:;b00GoJ:;b00?o0000ofbUlom/YO<00_m/YO<4o`0000SoM:Wc00?o0000ogn_
l_mo[o801omo[o800ol0003oS;Caohbdl@07ohbdl@03o`000?nH^^ooV;[_00SoV;[_00?o0000ojBn
k?nT_^`02OnT_^`00ol0003o[/7Xojk1j00;ojk1j003o`000?nga>Co000000;o00002Ongb>L00ol0
003o_/WSokk9h`0;okk9h`04o`000?o3bMoo`lWOol?9g`;o00002Oo2cN<00ol0003oaLcOolG<g`0<
olG<g`;o00003Oo4bml00ol0003oaLSMolG8g@08olG8g@;o000000?o`<SPo`000?ooool0;Oooool0
02Kooooo00?o0000ooooooooool0HOooool00ol0003oJ:;bofRRlP05ofRRlPCo00001?m/YO<00ol0
003oM:WcogBYl`06ogBYl`03o`000?mo[o;oOjob00OoOjob00?o0000ohbdlOn<]?401on<]?400ol0
003oV;[_oiRjk`08oiRjk`03o`000?nT_^coY;k/00WoY;k/00?o0000ojk1j?n^`NP02_n^`NP2o`00
00go]lSW00?o0000okk9honnbN<02onnbN<00ol0003o`lWOo`00000<ol;=h`03o`000?o5c=ooaLcO
00WoaLcO0_l000000oo3cN;o0000olC;g`0<olC;g`03o`000?o5b=goaLSM00OoaLSM00?o0000ol38
h?o0b>000_o0b>000ol0003oooooooooo`0[ooooo`009_ooool00ol0003oooooooooo`1Rooooo`03
o`000?mXX_;oJ:;b00;oJ:;b1?l00007ofbUl`03o`000?mdZO?oM:Wc00KoM:Wc00?o0000ogn_l_mo
[o801omo[o800ol0003oS;Caohbdl@07ohbdl@03o`000?nH^^ooV;[_00SoV;[_00?o0000ojBnk?nT
_^`02OnT_^`00ol0003o[/7Xojk1j006ojk1j0?o00000_n^a^/00ol0003o]lSWokO8i`0;okO8i`03
o`000?nnbN?o_/WS00[o_/WS0_l0000>ol;=h`03o`000?o5c=ooaLcO00OoaLcO00?o0000ol?=h_o3
cN800_o3cN800ol0003oa<_OolC;g`0;olC;g`03o`000?o5b=goaLSM00CoaLSM0_l00005ol38h0;o
0000;?ooool002Kooooo00?o0000ooooooooool0Hoooool4o`0000CoJ:;b00?o0000ofbUlom/YO<0
1Om/YO<00ol0003oM:WcogBYl`06ogBYl`03o`000?mo[o;oOjob00OoOjob00?o0000ohbdlOn<]?40
1on<]?400ol0003oV;[_oiRjk`08oiRjk`03o`000?nT_^coY;k/00SoY;k/0_l00005ojk1j0;o0000
1_n^a^/00ol0003o]lSWokO8i`0;okO8i`03o`000?nnbN?o_/WS00Oo_/WS0_l00002okg=iP03o`00
0?o2cN?o`/gS00co`/gS00?o0000olG<goo5c=l01?o5c=l2o`0000Ko`lgR00?o0000olC;goo4bml0
2oo4bml01?l0003oaLSMolG8gOo5b=d2o`0000So`<SP00?o0000ooooooooool0:_ooool002Kooooo
0_l0001Sooooo`?o00001omXX_800ol0003oK:GcofbUl`05ofbUl`03o`000?mdZO?oM:Wc00KoM:Wc
00?o0000ogn_l_mo[o801omo[o800ol0003oS;Caohbdl@07ohbdl@03o`000?nH^^ooV;[_00SoV;[_
00?o0000ojBnk?nT_^`02?nT_^`2o`000004ojk1j?l0003o0000o`0000Wo[/K[00?o0000okO8iong
b>L02ongb>L00ol0003o_/WSokk9h`04okk9h`;o00001OnmcNH00ol0003o`/gSol;=h`0<ol;=h`04
o`000?o5c=ooaLcOolG<g`;o00002Oo3cN800ol0003oa<_OolC;g`0;olC;g`03o`000?o5b=go0000
00_o`<SP00?o0000ooooooooool0:Oooool002Kooooo00?o0000ooooooooool0Goooool3o`0000?o
oooo00?o0000ofRRl_mXX_801OmXX_800ol0003oK:GcofbUl`05ofbUl`03o`000?mdZO?oM:Wc00Ko
M:Wc00?o0000ogn_l_mo[o801omo[o800ol0003oS;Caohbdl@07ohbdl@03o`000?nH^^ooV;[_00So
V;[_00?o0000ojBnk?nT_^`02?nT_^`2o`0000go[/K[00?o0000okO8iongb>L02ongb>L00ol0003o
_/WSokk9h`02okk9h`03o`000?nmcNKo_LgV00Ko_LgV00?o0000ol;=hoo2cN<03?o2cN<00ol0003o
aLcOo`00000<ol?=hP03o`000?o4bmooa<_O00[oa<_O0_l0000=ol38h003o`000?oooooooooo02So
oooo000Vooooo`03o`000?oooooooooo05cooooo0ol00007ooooo`03o`000?mXX_;oJ:;b00GoJ:;b
00?o0000ofbUlom/YO<01Om/YO<00ol0003oM:WcogBYl`06ogBYl`03o`000?mo[o;oOjob00OoOjob
00?o0000ohbdlOn<]?401on<]?400ol0003oV;[_oiRjk`08oiRjk`03o`000?nT_^coY;k/00CoY;k/
0ol000000onS`noo0000o`00000=ojk6j`03o`000?ngb>Oo]lSW00_o]lSW00Co0000okk9hol0003o
00002_nmcNH00ol0003o`/gSol;=h`0;ol;=h`;o00003_o3cN800ol0003oa<_OolC;g`08olC;g`03
o`000?o0bn?o000000go`<SP00?o0000ooooooooool0:?ooool002Kooooo00?o0000ooooooooool0
FOooool3o`0000_ooooo00?o0000ofRRl_mXX_801OmXX_800ol0003oK:GcofbUl`05ofbUl`03o`00
0?mdZO?oM:Wc00KoM:Wc00?o0000ogn_l_mo[o801omo[o800ol0003oS;Caohbdl@07ohbdl@03o`00
0?nH^^ooV;[_00SoV;[_00?o0000ojBnk?nT_^`00ol00005oj?3k`;o00003On^a^/00ol0003o]lSW
okO8i`0:okO8i`;o00003OnmcNH00ol0003o`/gSol;=h`09ol;=h`03o`000?o0cnKo000000ko`lgR
00?o0000olC;goo4bml01_o4bml2o`0000?o`<_S00?o0000ol38h?o0b>002oo0b>000ol0003ooooo
ooooo`0Wooooo`009_ooool00ol0003oooooooooo`1Fooooo`?o00003oooool6o`0000;oJ:;b00?o
0000ofbUlom/YO<01Om/YO<00ol0003oM:WcogBYl`06ogBYl`03o`000?mo[o;oOjob00OoOjob00?o
0000ohbdlOn<]?401on<]?400ol0003oV;[_oiRjk`03oiRjk`Oo00002OnS`nl2o`0000go[/K[00?o
0000okO8iongb>L01_ngb>L3o`000003okK<jol0003o_LgV00go_LgV00?o0000ol;=hoo2cN<01_o2
cN<2o`0000?o`<oV00?o0000ol?=h_o3cN803?o3cN800ol0003oa<_OolC;g`04olC;g`03o`000?o0
bn?o`<_S00Co`<_S00?o0000ol38h?o0b>002oo0b>000ol0003oooooooooo`0Vooooo`009_ooool0
0ol0003oooooooooo`1Cooooo`?o00004oooool00ol0003oJZ?bofZSlP02ofZSlPWo00000_m/YO<0
0ol0003oM:WcogBYl`06ogBYl`03o`000?mo[o;oOjob00OoOjob00?o0000ohbdlOn<]?400on<]?49
o`0000KoV;kb00?o0000oj?3konS`nl02?nS`nl2o`0000go[/K[00?o0000okO8iongb>L00ongb>L2
o`0000Go]/c[00?o0000okg=i_nmcNH03?nmcNH00ol0003o`/gSol;=h`04ol;=h`03o`000?o0cnKo
`<oV00Co`<oV00?o0000ol?=h_o3cN803?o3cN801?l0003oa<_OolC;goo4bml2o`0000So`<_S00?o
0000ol38h?o0b>002_o0b>02o`0002Oooooo000Uooooo`03o`000?oooooooooo057ooooo0ol0000G
ooooo`03o`000?mZXo;oJZ?b00GoJZ?b00?o0000offVlom]Y_<00_m]Y_<Ko`0000CoRkSd00?o0000
oiRnl_nH__802OnH__800ol0003oXl?_oj?3k`07oj?3k`03o`000?nS`noo000000go[/K[00?o0000
okO8iol000000_l00008okK<j`03o`000?nmcNKo_LgV00co_LgV00Co0000ol;=hoo2cN?o`/gS0_l0
0008ol3?iP03o`000?o3cN;o`lgR00co`lgR00?o0000olC;gol000002oo0bn<00ol0003o`<SPol38
h00:ol38h003o`000?oooooooooo02Gooooo000Uooooo`?o0000C_ooool3o`0001[ooooo0_l00007
ofZSlP03o`000?m]Y_?oKJKc00GoKJKc00?o0000ogB[m?mdZo@01_mdZo@00ol0003oO[7dogjam006
ogjam003o`000?n;^?CoRkSd00OoRkSd00?o0000oiRnl_nH__802OnH__800ol0003oXl?_oj?3k`07
oj?3k`03o`000?nS`noo000000co[/K[0_l0000<okK<j`03o`000?nmcNKo_LgV00co_LgV00?o0000
ol;=hol000002oo0cnH00ol0003o`lgRol?=hP0;ol?=hP;o00003Oo0bn<00ol0003o`<SPol38h009
ol38h0;o00009_ooool002Gooooo00?o0000ooooooooool0Boooool3o`0001kooooo0_l00007ofZS
lP03o`000?m]Y_?oKJKc00GoKJKc00?o0000ogB[m?mdZo@01_mdZo@00ol0003oO[7dogjam006ogja
m003o`000?n;^?CoRkSd00OoRkSd00?o0000oiRnl_nH__802OnH__800ol0003oXl?_oj?3k`07oj?3
k`03o`000?nS`noo000000So[/K[0ol00002ojk;k`03o`000?nfc>_o]/c[00[o]/c[00?o0000okg=
i_nmcNH02onmcNH2o`0000go`<oV00?o0000ol?=h_o3cN802?o3cN82o`000003oko?i_l0003o`<_S
00go`<_S00?o0000ol38h?o0b>001_o0b>02o`000003ok[6hol0003o000002Gooooo0009ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c007
ooooo`03o`000?oooooooooo04Sooooo0ol0000Rooooo`;o00001omZXo800ol0003oKJKcoffVl`05
offVl`03o`000?mdZoCoM:_d00KoM:_d00?o0000ogjam?mn/O@01_mn/O@00ol0003oRkSdoh^hm007
oh^hm003o`000?nH__;oV;kb00WoV;kb00?o0000oj?3konS`nl01onS`nl00ol0003oXl?_o`000005
ojk6j`;o00001_n^bnl00ol0003o]/c[okK<j`0:okK<j`03o`000?nmcNKo_LgV00So_LgV0_l00002
ok_@jP03o`000?o0cnKo`<oV00_o`<oV00?o0000ol?=h_o3cN801Oo3cN82o`0000Co_loV00?o0000
ol3;hoo0bn<03?o0bn<00ol0003o`<SPol38h002ol38h0?o00001?nja^<2o`0002Cooooo0009oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q
8@07ooooo`03o`000?oooooooooo04Gooooo0ol0000Vooooo`;o00001omZXo800ol0003oKJKcoffV
l`05offVl`03o`000?mdZoCoM:_d00KoM:_d00?o0000ogjam?mn/O@01_mn/O@00ol0003oRkSdoh^h
m007oh^hm003o`000?nH__;oV;kb00WoV;kb00?o0000oj?3konS`nl01onS`nl01?l0003oXl?_o`00
0?n^a^/3o`0000Wo[/__00?o0000okK<jonfc>/02_nfc>/00ol0003o_LgVokg=iP05okg=iP;o0000
1Onkd>X00ol0003o`<oVol3?iP0;ol3?iP03o`000?o3cN;o`lgR00;o`lgR0_l00007oko?iP03o`00
0?o0bn?o`<_S00co`<_S00Co0000ol38h?l0003o00002?nja^<00ol0003oooooooooo`0Rooooo`00
2Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooooooo04;ooooo0ol0000Zooooo`;o00001omZXo800ol0003oKJKcoffVl`05offV
l`03o`000?mdZoCoM:_d00KoM:_d00?o0000ogjam?mn/O@01_mn/O@00ol0003oRkSdoh^hm007oh^h
m003o`000?nH__;oV;kb00WoV;kb00?o0000oj?3konS`nl01onS`nl4o`0000co[/__00?o0000okK<
jonfc>/02_nfc>/00ol0003o_LgVokg=iP02okg=iP;o00002?nkd>X00ol0003o`<oVol3?iP0;ol3?
iP04o`000?o3cN;o0000o`0000[o_loV00?o0000ol3;hoo0bn<02oo0bn<2o`0000_o^/KS00?o0000
ooooooooool08Oooool000Wooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9So
oooooiRHV?lb<S801oooool00ol0003oooooooooo`0oooooo`?o0000;_ooool2o`0000OoJZ?b00?o
0000offVlom]Y_<01Om]Y_<00ol0003oM:_dogB[m006ogB[m003o`000?mn/OCoO[7d00KoO[7d00?o
0000oh^hm?n;^?@01on;^?@00ol0003oV;kboiRnlP09oiRnlP03o`000?nS`nooXl?_00CoXl?_1?l0
0002oj?7lP03o`000?n^bnoo[/__00[o[/__00?o0000okK<jonfc>/02_nfc>/01?l0003o_LgVo`00
0?l0000;ok_@jP03o`000?o0cnKo`<oV00[o`<oV0_l0000=oko?iP03o`000?o0bn?o`<_S00So`<_S
0_l000000onjbnOo0000ok[6h`0:ok[6h`;o00008_ooool000Wooooo00Go0000oooooooooooooooo
o`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01oooool00ol0003oooooooooo`0looooo`?o
0000<_ooool2o`0000OoJZ?b00?o0000offVlom]Y_<01Om]Y_<00ol0003oM:_dogB[m006ogB[m003
o`000?mn/OCoO[7d00KoO[7d00?o0000oh^hm?n;^?@01on;^?@00ol0003oV;kboiRnlP09oiRnlP03
o`000?nS`nooXl?_00?o00001?nSao801?l0003oXlOboj?7l_l0000<ojk;k`03o`000?nfc>_o]/c[
00Wo]/c[0ol0000=ok_@jP03o`000?o0cnKo`<oV00Oo`<oV0_l00002okcAjP03o`000?nocnKo_loV
00_o_loV00?o0000ol3;hoo0bn<01Oo0bn<2o`0000Co^/_W00?o0000ok[6honja^<02Onja^<2o`00
027ooooo0009ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o
410@00Oooooo00?o0000ooooooooool0>Oooool3o`0003Kooooo0_l00007ofZSlP03o`000?m]Y_?o
KJKc00GoKJKc00?o0000ogB[m?mdZo@01_mdZo@00ol0003oO[7dogjam006ogjam003o`000?n;^?Co
RkSd00OoRkSd00?o0000oiRnl_nH__801onH__84o`0000OoXlOb00Go0000oj?7l_nSao;oXlObo`00
000<ojk;k`03o`000?nfc>_o]/c[00Ko]/c[0_l00003okC@kP03o`000?nkd>[o^m3Z00_o^m3Z00?o
0000ol3?i_o0cnH01?o0cnH2o`0000Go_=7Z00?o0000oko?i_nocnH02onocnH00ol0003o`<_Sol3;
h`02ol3;h`;o00001onjbnL00ol0003o^/KSok[6h`09ok[6h`03o`000?oooooooooo01oooooo0009
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0=oooool3o`0003[ooooo1ol00002ofZSlP03o`000?m]Y_?oKJKc00GoKJKc
00?o0000ogB[m?mdZo@01_mdZo@00ol0003oO[7dogjam006ogjam003o`000?n;^?CoRkSd00OoRkSd
00Co0000oiRnl_nH__;oV;kb1Ol00004oiS2m@03o`000?nSao;oXlOb00GoXlOb00Go0000oj?7l_nS
ao;oXlObo`00000<ojk;k`03o`000?nfc>_o]/c[00;o]/c[0ol00006okC@kP03o`000?nkd>[o^m3Z
00_o^m3Z00?o0000ol3?i_o0cnH00_o0cnH00ol0003o_=7ZokcAjP06okcAjP03o`000?nocnKo_loV
00_o_loV00Co0000ol3;hol0003o00002_njbnL00ol0003o^/KSok[6h`08ok[6h`;o00008?ooool0
00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_oo
ool00ol0003oooooooooo`0dooooo`?o0000?_ooool00ol0003oLJKbog6VlP03og6VlPWo00000_m]
Y_<00ol0003oM:_dogB[m006ogB[m003o`000?mn/OCoO[7d00KoO[7d00?o0000oh^hm?n;^?@00on;
^?@7o`0000[oV<;e00?o0000oj?7l_nSao801OnSao801Ol0003oXlOboj?7l_nSao;o000000co[/__
00Co0000okK<jol0003o00002_ndd>h00ol0003o^m3Zok_@jP0;ok_@jP04o`000?o0cnKo0000o`00
00[o_=7Z00?o0000oko?i_nocnH02_nocnH2o`0000co^/_W00?o0000ok[6honja^<02Onja^<2o`00
01oooooo000Tooooo`03o`000?oooooooooo037ooooo0ol00012ooooo`03o`000?maY_;oLJKb00Go
LJKb00?o0000og>Zm?mcZ_@00omcZ_@Jo`0000KoS;cf00?o0000oiS2mOnH`_D02OnH`_D00ol0003o
XlOboj?7lP05oj?7lP05o`000?nSao;oXlOboj?7l_l000002_n^bnl4o`0000co]=3^00?o0000ok_@
j_nkd>X02_nkd>X3o`0000co_=7Z00?o0000oko?i_nocnH01onocnH2o`0000;o^LoZ00?o0000ok[;
ionjbnL02_njbnL00ol0003o^/KSok[6h`09ok[6h`;o00007_ooool002Cooooo00?o0000oooooooo
ool0;oooool2o`0004Kooooo00?o0000og6Vl_maY_801OmaY_800ol0003oLj[dog>Zm006og>Zm003
o`000?mh[oGoN:oe00KoN:oe00?o0000oh6em_n1]OH01on1]OH00ol0003oS;cfohblmP07ohblmP03
o`000?nH`_GoV<;e00WoV<;e00?o0000oj?7l_nSao801OnSao801Ol0003oXlOboj?7l_nSao;o0000
00Ko[/__0ol00004ojg>lP03o`000?ndd>ko]=3^00[o]=3^00?o0000ok_@j_nkd>X01_nkd>X3o`00
00?o^=;^00?o0000okcAj_nldNX02_nldNX00ol0003o_loVoko?iP04oko?iP;o00001OnicnX00ol0
003o^/_Wok[;i`0:ok[;i`03o`000?nja^?o^/KS00So^/KS0_l0000Nooooo`009?ooool00ol0003o
ooooooooo`0/ooooo`?o0000BOooool00ol0003oLJKbog6VlP05og6VlP03o`000?mcZ_CoLj[d00Ko
Lj[d00?o0000ogR_mOmh[oD01_mh[oD00ol0003oPKGfoh6emP07oh6emP03o`000?n<_?KoS;cf00Oo
S;cf00?o0000oiS2mOnH`_D02OnH`_D00ol0003oXlOboj?7lP05oj?7lP05o`000?nSao;oXlOboj?7
l_l000000_n^bnl3o`0000So[Lkb00?o0000okC@k_ndd>h02_ndd>h00ol0003o^m3Zok_@jP03ok_@
jP;o00001onhd^h00ol0003o_=7ZokcAjP0:okcAjP03o`000?nocnKo_loV00;o_loV00?o0000okW?
j_nicnX01_nicnX00ol0003o^/_Wok[;i`09ok[;i`03o`000?nja^?o^/KS00Ko^/KS0_l000000onc
a>Oo0000o`00000Mooooo`009?ooool00ol0003oooooooooo`0Yooooo`?o0000COooool00ol0003o
LJKbog6VlP05og6VlP03o`000?mcZ_CoLj[d00KoLj[d00?o0000ogR_mOmh[oD01_mh[oD00ol0003o
PKGfoh6emP07oh6emP03o`000?n<_?KoS;cf00OoS;cf00?o0000oiS2mOnH`_D02OnH`_D00ol0003o
XlOboj?7lP05oj?7lP03o`000?nSao;oXlOb00?o00003?n]c_800ol0003o]=3^okC@kP0:okC@kP03
o`000?nkd>[o000000;o00002_nhd^h00ol0003o_=7ZokcAjP0:okcAjP04o`000?nocnKo0000o`00
00[o^LoZ00?o0000ok[;ionjbnL02OnjbnL00ol0003o^/KSok[6h`02ok[6h`?o00001?nca>L2o`00
01cooooo000Tooooo`03o`000?oooooooooo02Kooooo0ol0001Aooooo`03o`000?maY_;oLJKb00Go
LJKb00?o0000og>Zm?mcZ_@01_mcZ_@00ol0003oN:oeogR_m@06ogR_m@03o`000?n1]OKoPKGf00Oo
PKGf00?o0000ohblm_n<_?H01on<_?H00ol0003oV<;eoiS2m@09oiS2m@03o`000?nSao;oXlOb00Co
XlOb0ol00003oj?;m@03o`000?n]c_;o[Lkb00[o[Lkb00?o0000okC@k_ndd>h02Ondd>h3o`0000go
^=;^00?o0000okcAj_nldNX02OnldNX2o`0000go^LoZ00?o0000ok[;ionjbnL02OnjbnL01?l0003o
^/KSo`000?l00008ok?4i`;o00006oooool002?ooooo0_l0000Uooooo`?o0000EOooool00ol0003o
LJKbog6VlP05og6VlP03o`000?mcZ_CoLj[d00KoLj[d00?o0000ogR_mOmh[oD01_mh[oD00ol0003o
PKGfoh6emP07oh6emP03o`000?n<_?KoS;cf00OoS;cf00?o0000oiS2mOnH`_D02OnH`_D00ol0003o
XlOboj?7lP03o`000003oj?;mOl0003oXl_e00CoXl_e00?o0000ojg>l_n]c_802_n]c_800ol0003o
]=3^okC@kP06okC@kP;o00000onbdo400ol0003o^=;^okSBkP0;okSBkP03o`000?nldN[o_=7Z00Ko
_=7Z0_l00002okOBkP03o`000?nicn[o^LoZ00_o^LoZ00?o0000ok[;ionjbnL02?njbnL2o`0000_o
/lCW00?o0000ooooooooool06Oooool002Cooooo00?o0000ooooooooool08?ooool3o`0005Wooooo
00?o0000og6Vl_maY_801OmaY_800ol0003oLj[dog>Zm006og>Zm003o`000?mh[oGoN:oe00KoN:oe
00?o0000oh6em_n1]OH01on1]OH00ol0003oS;cfohblmP07ohblmP03o`000?nH`_GoV<;e00OoV<;e
1?l00005oj?;m@03o`000?nSboGoXl_e00?oXl_e00?o0000ojg>l_n]c_802_n]c_800ol0003o]=3^
okC@kP02okC@kP?o00001_nbdo400ol0003o^=;^okSBkP0;okSBkP03o`000?nldN[o_=7Z00;o_=7Z
0ol00005okOBkP03o`000?nicn[o^LoZ00_o^LoZ00?o0000ok[;ionjbnL01?njbnL3o`000003ok?9
jol0003o/lCW00_o/lCW00?o0000ooooooooool06?ooool002?ooooo00?o0000ooooooooool07_oo
ool3o`0005gooooo00?o0000og6Vl_maY_801OmaY_800ol0003oLj[dog>Zm006og>Zm003o`000?mh
[oGoN:oe00KoN:oe00?o0000oh6em_n1]OH01on1]OH00ol0003oS;cfohblmP07ohblmP04o`000?nH
`_GoV<;eoiS2m@Go00001?nIa_L00ol0003oXl_eoj?;m@03oj?;m@03o`000?nSboGoXl_e00?oXl_e
0_l0000;ojg>lP04o`000?ndd>ko0000o`0000[o/]?a00?o0000okSBk_nhd^h02onhd^h01?l0003o
_=7Zo`000?l00009okOBkP03o`000?nicn[o^LoZ00_o^LoZ00?o0000ok[;ionjbnL00ol00005ok?9
j`03o`000?nca>Oo/lCW00[o/lCW00?o0000ooooooooool05oooool002?ooooo00?o0000oooooooo
ool06oooool3o`00067ooooo00?o0000og6Vl_maY_801OmaY_800ol0003oLj[dog>Zm006og>Zm003
o`000?mh[oGoN:oe00KoN:oe00?o0000oh6em_n1]OH01on1]OH00ol0003oS;cfohblmP03ohblmPOo
00002_nIa_L00ol0003oXl_eoj?;m@03oj?;m@03o`000?nSboGoXl_e00CoXl_e00?o0000ojg>l_n]
c_802?n]c_83o`0000co/]?a00?o0000okSBk_nhd^h02_nhd^h2o`0000co]m;^00?o0000okW?j_ni
cnX02_nicnX3o`0000Wo/lW[00?o0000ok?4ionca>L02Onca>L2o`0001Sooooo000Sooooo`03o`00
0?oooooooooo01Sooooo0ol0001Uooooo`Ko00000_maY_800ol0003oLj[dog>Zm006og>Zm003o`00
0?mh[oGoN:oe00KoN:oe00?o0000oh6em_n1]OH00on1]OH9o`0000KoS/7h00?o0000oiW6monIa_L0
2OnIa_L00ol0003oXl_eoj?;m@03oj?;m@03o`000?nSboGoXl_e00CoXl_e00?o0000ojg>l_n]c_80
1?n]c_83o`0000?oZm7d00?o0000ok;ClOnbdo402_nbdo400ol0003o^=;^okSBkP06okSBkP?o0000
0_nce?400ol0003o]m;^okOBkP0:okOBkP03o`000?nicn[o^LoZ00Ko^LoZ0ol000000onbcNko0000
ok?9j`0:ok?9j`03o`000?nca>Oo/lCW00Wo/lCW00?o0000ooooooooool05_ooool002?ooooo00?o
0000ooooooooool05Oooool3o`0006Sooooo00?o0000og^[l_mkZo800omkZo8Jo`0000KoQ[[g00?o
0000ohk1n?n>`OP01on>`OP00ol0003oVLKgoiW6m`09oiW6m`03o`000?nSboGoXl_e00?oXl_e00?o
0000oj?;mOnSboD01?nSboD00ol0003o[Lkbojg>lP03o`0000OoZm7d00?o0000ok;ClOnbdo402_nb
do400ol0003o^=;^okSBkP03okSBkP;o00001_nce?400ol0003o]m;^okOBkP0:okOBkP03o`000?ni
cn[o^LoZ00?o^LoZ0_l00005ok;=kP03o`000?ncbN_o/lW[00Wo/lW[00?o0000ok?4ionca>L02Onc
a>L00ol0003oooooooooo`0Eooooo`008oooool00ol0003oooooooooo`0Booooo`?o0000K?ooool0
0ol0003oNj_bog^[lP06og^[lP03o`000?mk[oCoNjod00OoNjod00?o0000ogndm_mo]?H01_mo]?H0
0ol0003oQ[[gohJjm`07ohJjm`03o`000?n>`OSoS/7h00OoS/7h00?o0000oiW6monIa_L02OnIa_L0
0ol0003oXl_eoj?;m@03oj?;m@03o`000?nSboGoXl_e00;oXl_e1?l0000;oj_Am0;o00002onbdo40
0ol0003o^=;^o`000002o`0000Wo/mCa00?o0000okOBk_ngd^h02_ngd^h00ol0003o^LoZo`000002
o`0000So//g^00?o0000ok?9joncbN/02OncbN/00ol0003o/lCWok?4i`09ok?4i`03o`000?oooooo
oooo01Cooooo000Rooooo`?o00004?ooool3o`00073ooooo00?o0000og^[l_mkZo801_mkZo800ol0
003oNjodog^_m007og^_m003o`000?mo]?KoOkCf00KoOkCf00?o0000ohJjmon6^_L01on6^_L00ol0
003oS/7hohk1n007ohk1n0;o00002_nIa_L00ol0003oXl_eoj?;m@03oj?;m@Co00001?nScoL00ol0
003oZm7doj_Am00:oj_Am003o`000?nbdo7o/]?a00So/]?a0ol0000<ok?Dl@03o`000?ngd^ko]m;^
00Wo]m;^0ol0000;ok;=kP03o`000?ncbN_o/lW[00Wo/lW[00?o0000ok?4ionca>L01onca>L3o`00
01Gooooo000Sooooo`03o`000?oooooooooo00cooooo0ol0001dooooo`03o`000?mkZo;oNj_b00Ko
Nj_b00?o0000og^_m?mk[o@01omk[o@00ol0003oOkCfogndmP06ogndmP03o`000?n6^_OoQ[[g00Oo
Q[[g0_l00009ohk1n003o`000?nIa_OoVLKg00SoVLKg00?o0000oj?;mOnSboD00ol00008oj??m`03
o`000?n[dOCoZm7d00[oZm7d00?o0000ok;ClOnbdo401?nbdo43o`0000?o[]Cd00?o0000ok?DlOnc
e?402_nce?400ol0003o]m;^okOBkP06okOBkP;o00000on`dO400ol0003o//g^ok;=kP09ok;=kP03
o`000?ncbN_o/lW[00Wo/lW[00Co0000ok?4ionca>Oo/lCW1Ol00002ooooo`03o`000?oooooooooo
01?ooooo000Sooooo`03o`000?oooooooooo00Wooooo0ol0001hooooo`03o`000?mkZo;oNj_b00Ko
Nj_b00?o0000og^_m?mk[o@01omk[o@00ol0003oOkCfogndmP06ogndmP;o00002On6^_L00ol0003o
S/7hohk1n007ohk1n003o`000?nIa_OoVLKg00KoVLKg1?l00003oj??m`03o`000?nScoOoXlog00Ko
Xlog0_l0000;oj_Am003o`000?nbdo7o/]?a00?o00001on^e?@00ol0003o/mCaok?Dl@0:ok?Dl@03
o`000?ngd^ko]m;^00;o]m;^0ol00006ok3Al@03o`000?nbcNko//g^00Wo//g^00?o0000ok?9jonc
bN/02?ncbN/6o`0000Gooooo00?o0000ooooooooool04oooool002?ooooo00?o0000ooooooooool0
1_ooool3o`0007cooooo00?o0000og^[l_mkZo801_mkZo800ol0003oNjodog^_m007og^_m003o`00
0?mo]?KoOkCf00OoOkCf00?o0000ohJjmon6^_L01on6^_L00ol0003oS/7hohk1n007ohk1n003o`00
0?nIa_OoVLKg00Go00001?nKb_P01Ol0003oXlogoj??monScoOo000000WoXlog00?o0000oj_Am?n[
dO@02?n[dO@3o`0000_o[]Cd0_l0000;ok?Dl@04o`000?ngd^ko0000o`0000[o/=7a00?o0000ok;=
k_nbcNh02OnbcNh00ol0003o/lW[ok?9j`04ok?9j`Ko00002?ooool00ol0003oooooooooo`0Coooo
o`008_ooool00ol0003oooooooooo`04ooooo`?o0000P?ooool00ol0003oNj_bog^[lP06og^[lP03
o`000?mk[oCoNjod00OoNjod00?o0000ogndm_mo]?H01omo]?H00ol0003oQ[[gohJjm`07ohJjm`03
o`000?n>`OSoS/7h00?oS/7h1_l0000:oi_:n0;o00000_nScoL00ol0003oXlogoj??m`07oj??m`03
o`000?n[dOCoZm7d00CoZm7d0ol00003ojWCmP03o`000?n^e?Co[]Cd00[o[]Cd00?o0000ok?DlOnc
e?402?nce?43o`0000co/=7a00?o0000ok;=k_nbcNh02OnbcNh00ol0003o/lW[ok?9j`05o`0000co
oooo00?o0000ooooooooool04oooool002;ooooo00Co0000oooooooooooooooo0ol00024ooooo`03
o`000?mkZo;oNj_b00KoNj_b00?o0000og^_m?mk[o@01omk[o@00ol0003oOkCfogndmP07ogndmP03
o`000?n6^_OoQ[[g00?oQ[[g2Ol00006oi?5n003o`000?nKb_SoVl[h00WoVl[h00Co0000oj??monS
coOo00002OnScoL00ol0003oZm7doj_Am003o`0000OoZM?f00?o0000ojkDm?n^e?@02_n^e?@00ol0
003o/mCaok?Dl@04ok?Dl@?o00000on]do@00ol0003o/=7aok3Al@0:ok3Al@03o`000?nbcNko//g^
00So//g^1Ol0000?ooooo`03o`000?oooooooooo01?ooooo000Rooooo`Co0000R?ooool00ol0003o
Nj_bog^[lP06og^[lP03o`000?mk[oCoNjod00OoNjod00?o0000ogndm_mo]?H00omo]?H9o`0000Ko
SKoh00?o0000oi?5n?nCaOP01onCaOP00ol0003oVl[hoi_:n009oi_:n004o`000?nScoOoXlogo`00
00SoXlog0ol0000;ojWCmP;o00002on^e?@00ol0003o/mCaok?Dl@03o`0000Oo[M?d00?o0000ok3A
lOn`dO402_n`dO400ol0003o//g^ok;=kP04ok;=kPGo00004_ooool00ol0003oooooooooo`0Coooo
o`008_ooool3o`0008[ooooo00?o0000og^[l_mkZo801_mkZo800ol0003oNjodog^_m003og^_m0Wo
00001On9^_H00ol0003oSKohohfon008ohfon003o`000?nCaOSoTlGh00OoTlGh0_l0000:oi_:n0;o
000000?oXlogo`000?nScoL00onScoL3o`0000?oXm7h00?o0000ojWCm_nYdoH02_nYdoH00ol0003o
[]CdojkDm008ojkDm0?o00002on]do@00ol0003o/=7aok3Al@0:ok3Al@03o`000?nbcNko//g^00Co
00005oooool00ol0003oooooooooo`0Booooo`009?ooool00ol0003oooooooooo`29ooooo`ko0000
1_n7]?<00ol0003oRK[fohVjmP06ohVjmP03o`000?n=_oSoSKoh00SoSKoh00?o0000oi?5n?nCaOP0
2?nCaOP00ol0003oVl[hoi_:n009oi_:n0;o000000CoXlogo`000?l0003o00001onSdOP00ol0003o
ZM?fojWCmP0:ojWCmP03o`000?n^e?Co[]Cd00Co[]Cd0ol00003oj[DmP03o`000?n]doCo[M?d00Wo
[M?d00?o0000ok3AlOn`dO402?n`dO45o`0001[ooooo00?o0000ooooooooool04_ooool001Kooooo
00?ok^k^o`000?l000000_l000000ol@413oooooooooo`07ooooo`03o`000?oooooooooo08Wooooo
00?o0000ohN`l?n7/?001on7/?000ol0003oQkCcohNdl`07ohNdl`03o`000?n9^_KoRK[f00KoRK[f
00?o0000ohfon?n=_oP02?n=_oP00ol0003oTlGhoi?5n008oi?5n003o`000?nKb_SoVl[h00OoVl[h
1?l0000;oj?An0;o00002onYdoH00ol0003o[]CdojkDm003o`0000OoZ]Cf00?o0000ojgCm?n]do@0
2On]do@00ol0003o/=7aok3Al@04ok3Al@Go00007Oooool00ol0003oooooooooo`0Booooo`005_oo
ool01OmgMgOoV9RHooooool0003oMgMg00_ooooo00?o0000ooooooooool0ROooool00ol0003oQk3`
ohN`l007ohN`l003o`000?n7]??oQkCc00OoQkCc00?o0000ohVjm_n9^_H01_n9^_H00ol0003oSKoh
ohfon008ohfon003o`000?nCaOSoTlGh00SoTlGh00Co0000oi_:n?nKb_SoVl[h1Ol00004oik>n003
o`000?nSdOSoXm7h00[oXm7h00?o0000ojWCm_nYdoH02?nYdoH3o`0000_oZ]Cf00?o0000ojgCm?n]
do@02On]do@00ol0003o/=7aok3Al@04o`00027ooooo00?o0000ooooooooool04_ooool001Kooooo
00Go410@oooooooooooo0000oa0@400<ooooo`03o`000?oooooooooo08Wooooo00?o0000ohN`l?n7
/?001on7/?000ol0003oQkCcohNdl`07ohNdl`03o`000?n9^_KoRK[f00KoRK[f00?o0000ohfon?n=
_oP02?n=_oP00ol0003oTlGhoi?5n006oi?5n0Go00002_nNc_P00ol0003oXm7hoj?An00:oj?An003
o`000?nYdoKoZM?f00CoZM?f0ol00003ojODm`03o`000?nZe?KoZ]Cf00WoZ]Cf00?o0000ojgCm?n]
do@02?n]do@4o`0002Cooooo00?o0000ooooooooool04_ooool001Kooooo00?o0000ooooooooool0
0_l0000=ooooo`03o`000?oooooooooo08Wooooo00?o0000ohN`l?n7/?001on7/?000ol0003oQkCc
ohNdl`07ohNdl`03o`000?n9^_KoRK[f00KoRK[f00?o0000ohfon?n=_oP02?n=_oP00ol0003oTlGh
oi?5n005o`0000CoVLWh00?o0000oik>n?nNc_P02OnNc_P2o`0000_oXm7h00?o0000ojWCm_nYdoH0
0ol00007ojODm`03o`000?nZe?KoZ]Cf00WoZ]Cf00?o0000ojgCm?n]do@01?n]do@4o`0002Oooooo
00?o0000ooooooooool04_ooool001Kooooo00?o0000ooooooooool00_l0000>ooooo`03o`000?oo
oooooooo08Wooooo00?o0000ohN`l?n7/?001on7/?000ol0003oQkCcohNdl`07ohNdl`03o`000?n9
^_KoRK[f00KoRK[f00?o0000ohfon?n=_oP01_n=_oP4o`0000[oVLWh0_l0000:oik>n0;o00002_nS
dOP3o`0000_oYmCg0_l0000:oj[DmP03o`000?n]doCo[M?d00Co0000:_ooool00ol0003ooooooooo
o`0Booooo`005_ooool01Ol@413oooooooooool0003o410@00oooooo00?o0000ooooooooool0ROoo
ool00ol0003oQk3`ohN`l007ohN`l003o`000?n7]??oQkCc00OoQkCc00?o0000ohVjm_n9^_H01_n9
^_H00ol0003oSKohohfon005o`0000CoU/Cg00?o0000oiW9n?nIbOP02OnIbOP00ol0003oW/khoik>
n008oik>n0;o00001_nSdOP3o`0000?oY=?h00?o0000ojODmonWe?L02_nWe?L00ol0003oZ]Cfoj[D
mP06oj[DmPCo0000;_ooool00ol0003oooooooooo`0Booooo`005_ooool01OmgMgOoV9RHooooool0
003oMgMg013ooooo0_l0002:ooooo`03o`000?n7/?3oQk3`00OoQk3`00?o0000ohNdlon7]?<01on7
]?<00ol0003oRK[fohVjmP02ohVjmPKo00002_nFa?L2o`0000[oVLWh00?o0000oik>n?nNc_P02?nN
c_P2o`0000;oXm7h0ol00007ojCCn003o`000?nWe?OoYmCg00[oYmCg00?o0000oj[Dm_nZe?H01_l0
000aooooo`03o`000?oooooooooo01;ooooo000Fooooo`05onk^k_l30`?o0000o`000?o^k^h04_oo
ool00ol0003oooooooooo`28ooooo`03o`000?n7/?3oQk3`00OoQk3`00?o0000ohNdlon7]?<00on7
]?<8o`0000KoU;od00?o0000oiK4monFa?L02OnFa?L00ol0003oVLWhoiW9n008oiW9n0;o00002?nN
c_P4o`0000_oY=?h0_l0000:ojODm`Ko0000=?ooool00ol0003oooooooooo`0Booooo`00;?ooool0
0ol0003oooooo`00002:ooooo`03o`000?n7/?3oQk3`00?oQk3`2Ol00005oi>jl@03o`000?nD_oCo
U;od00OoU;od00?o0000oiK4monFa?L02OnFa?L00ol0003oVLWhoiW9n009oiW9n003o`000?nNc_So
W/kh00Go000000GoX]3ho`000?nRd?SoX]3ho`00000<ojCCn003o`000?nWe?OoYmCg00CoYmCg1Ol0
000hooooo`03o`000?oooooooooo01;ooooo000_ooooo`03o`000?oooooooooo08Sooooo1Ol00005
oi>ekP03o`000?nC^_7oTk[a00OoTk[a00?o0000oiBom?nD_o@01onD_o@00ol0003oU/CgoiK4m`09
oiK4m`;o00002?nIbOP4o`0000OoX]3h00Co0000oj;@n?nRd?So00003?nTdoP00ol0003oYmCgojOD
m`05o`0003cooooo00?o0000ooooooooool04Oooool0033ooooo00?o0000ooooooooool0Qoooool2
o`0000WoTkG^00?o0000oi>jlOnC^_401onC^_400ol0003oU;odoiBom007oiBom0;o00002onFa?L0
0ol0003oVLWhoiW9n005o`0000CoX<gg00?o0000oj;@n?nRd?P01OnRd?P00ol0003oX]3hoj;@n002
o`0000[oY=?h1Ol0000oooooo`03o`000?oooooooooo017ooooo000aooooo`03o`000?oooooooooo
08Oooooo0_l00009oi>ekP03o`000?nC^_7oTk[a00OoTk[a00?o0000oiBom?nD_o@02?nD_o@00ol0
003oU/CgoiK4m`08oiK4m`?o00002_nPcOL00ol0003oX]3hoj;@n005oj;@n005o`000?nRd?SoX]3h
oj;@n?l000001_nTdoP4o`0004?ooooo00?o0000ooooooooool04Oooool003;ooooo00?o0000oooo
ooooool0Qoooool2o`0000WoTkG^00?o0000oi>jlOnC^_401onC^_400ol0003oU;odoiBom008oiBo
m003o`000?nFa?OoU/Cg00CoU/Cg0ol00003oio8m@03o`000?nPcOOoX<gg00SoX<gg00?o0000oj;@
n?nRd?P01OnRd?P01Ol0003oX]3hoj;@n?nRd?So000000;oY=?h1?l00016ooooo`03o`000?oooooo
oooo017ooooo000cooooo`03o`000?oooooooooo08Oooooo0_l00009oi>ekP03o`000?nC^_7oTk[a
00OoTk[a00?o0000oiBom?nD_o@02?nD_o@00ol0003oU/CgoiK4m`03o`0000OoWlSe00?o0000oj3=
monPcOL02?nPcOL00ol0003oX]3hoj;@n005oj;@n003o`000?nRd?SoX]3h00Co0000BOooool00ol0
003oooooooooo`0Aooooo`00=?ooool2o`0008Sooooo0_l00009oi>ekP03o`000?nC^_7oTk[a00Oo
Tk[a00?o0000oiBom?nD_o@01_nD_o@4o`0000_oWlSe00?o0000oj3=monPcOL02?nPcOL00ol0003o
X]3hoj;@n004oj;@n0?o0000COooool00ol0003oooooooooo`0Aooooo`00=_ooool00ol0003ooooo
ooooo`26ooooo`;o00002OnC]Nh00ol0003oTk[aoi>jl@07oi>jl@03o`000?nD_oCoU;od00Go0000
1?nO`o800ol0003oWlSeoio8m@09oio8m@03o`000?nPcOOoX<gg00SoX<gg00?o0000oj;@n?nRd?P0
0ol000000ooooooo0000ooooo`1=ooooo`03o`000?oooooooooo017ooooo000gooooo`;o0000Qooo
ool2o`0000WoTkG^00?o0000oi>jlOnC^_400onC^_46o`0000[oWl?b00?o0000oio8mOnOb?D02OnO
b?D00ol0003oX<ggoj3=m`06oj3=m`Co00001Oooool00ol0003oooooooooo`1;ooooo`03o`000?oo
oooooooo017ooooo000fooooo`03o`000?oooooo000008Sooooo0_l00007oi>ekPOo00001_nO_^l0
0ol0003oWl?boio3lP08oio3lP;o00002_nOb?D00ol0003oX<ggoj3=m`05o`0000[ooooo00?o0000
ooooooooool0B_ooool00ol0003oooooooooo`0Aooooo`00>Oooool00ol0003oooooooooo`26oooo
o`;o00000_nC]Nh4o`0000?oWkW[00?o0000oinnkonO_^l02?nO_^l00ol0003oWl?boio3lP09oio3
lP03o`000?nOb?GoWlSe00OoWlSe1Ol0000>ooooo`03o`000?oooooooooo04Wooooo00?o0000oooo
ooooool04Oooool003[ooooo00?o0000ooooooooool0Q_ooool3o`0000SoWkW[00?o0000oinnkonO
_^l02?nO_^l00ol0003oWl?boio3lP09oio3lP03o`000?nOb?GoWlSe00?oWlSe1Ol0000Booooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool04Oooool003_ooooo00?o0000ooooooooool0
Q_ooool00ol0003oWkW[oinij`08oinij`03o`000?nO_^ooWkk_00SoWkk_00?o0000oio3l_nO`o80
2OnO`o800ol0003oWlSeo`000003o`0001Oooooo00?o0000ooooooooool0B?ooool00ol0003ooooo
ooooo`0@ooooo`00??ooool00ol0003oooooooooo`26ooooo`03o`000?nO^N_oWkW[00SoWkW[00?o
0000oinnkonO_^l02?nO_^l00ol0003oWl?boio3lP08oio3lP?o00006oooool00ol0003ooooooooo
o`17ooooo`03o`000?oooooooooo013ooooo000mooooo`;o0000Qoooool00ol0003oWkW[oinij`08
oinij`03o`000?nO_^ooWkk_00SoWkk_00?o0000oio3l_nO`o801?nO`o83o`0001oooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`0@ooooo`00?oooool00ol0003oooooooooo`25oooo
o`03o`000?nO^N_oWkW[00SoWkW[00?o0000oinnkonO_^l02?nO_^l00ol0003oWl?boio3lP03o`00
02;ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0@ooooo`00@?ooool00ol0003o
ooooooooo`25ooooo`03o`000?nO^N_oWkW[00SoWkW[00?o0000oinnkonO_^l01_nO_^l4o`0002Ko
oooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0@ooooo`00@Oooool2o`0008Kooooo
00?o0000oinijonO^N/02?nO^N/00ol0003oWkk_oinnk`05o`0002_ooooo00?o0000ooooooooool0
A?ooool00ol0003oooooooooo`0@ooooo`00@?ooool00ol0003oooooo`000027ooooo`03o`000?nO
^N_oWkW[00OoWkW[1Ol0000_ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool04?oo
ool004?ooooo00?o0000ooooooooool0QOooool00ol0003oWkW[oinij`03oinij`Co0000=?ooool0
0ol0003oooooooooo`12ooooo`03o`000?oooooooooo013ooooo0014ooooo`03o`000?oooooooooo
08Gooooo00?o0000oinijol000000ol0000hooooo`03o`000?oooooooooo047ooooo00?o0000oooo
ooooool04?ooool004Gooooo00?o0000ooooooooool0QOooool2o`0003cooooo00?o0000oooooooo
ool0@?ooool00ol0003oooooooooo`0@ooooo`00A_ooool2o`0008Gooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo013ooooo0018ooooo`03o`000?oo
oooooooo08;ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo00oooooo0019ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo001:ooooo`03o`000?oooooooooo
083ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
00oooooo001:ooooo`;o0000POooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool03oooool004cooooo00?o0000ooooooooool0O_ooool00ol0003ooooo
ooooo`10ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool03oooool004gooooo00?o
0000ooooooooool0OOooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool03oooool004kooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`12
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool03oooool004oooooo0_l0001loooo
o`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0?oooo
o`00DOooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo04?ooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`0?ooooo`00D_ooool00ol0003oooooooooo`1hooooo`03o`00
0?oooooooooo04Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0?ooooo`00Dooo
ool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0?ooooo`00E?ooool3o`0007Kooooo00?o0000ooooooooool0A_ooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo00oooooo001Dooooo`;o0000Moooool00ol0
003oooooooooo`17ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03_ooool003So
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Sooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool03_ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`08ooooo`03o`000?oooooooooo07?ooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00kooooo000hoooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`08ooooo`;o0000Loooool0
0ol0003oooooooooo`19ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03_ooool0
03Sooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00_ooooo00?o0000
ooooooooool0L?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool03_ooool003Sooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`03Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0>ooooo`00>?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1^ooooo`03o`000?oo
oooooooo04cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0>ooooo`00>?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0>ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`;o0000K_oo
ool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03_oo
ool005oooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`1?ooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool03_ooool0063ooooo00?o0000ooooooooool0J_ooool00ol0
003oooooooooo`1@ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03_ooool0067o
oooo0_l0001Zooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`0=ooooo`00Hoooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo057ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0=ooooo`00I?ooool00ol0003ooooooooo
o`1Vooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`0=ooooo`00IOooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo05?ooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`0=ooooo`00I_ooool00ol0003oooooooooo`1Toooo
o`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0=oooo
o`00I_ooool3o`0006Cooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo00gooooo001Xooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0
E_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00gooooo001Yooooo`03o`000?oo
oooooooo067ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00gooooo001Zooooo`;o0000HOooool00ol0003oooooooooo`1Gooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool03Oooool006cooooo00?o0000ooooooooool0G_ooool00ol0
003oooooooooo`1Hooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03Oooool006go
oooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool03Oooool006kooooo00?o0000ooooooooool0G?ooool00ol0003ooooo
ooooo`1Jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03?ooool006oooooo00?o
0000ooooooooool0Foooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool03?ooool006oooooo0ol0001Kooooo`03o`000?oooooooooo05cooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0<ooooo`00LOooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo05gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0<oooo
o`00L_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo05gooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0<ooooo`00Loooool2o`0005Sooooo00?o0000ooooooooool0
G_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00cooooo001eooooo`03o`000?oo
oooooooo05Gooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo00cooooo001fooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0H?ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00cooooo001gooooo`03o`000?oooooooooo
05?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00cooooo001hooooo`;o0000Doooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool03?ooool007Sooooo0_l0001Cooooo`03o`000?oooooooooo06?ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0<ooooo`00N_ooool00ol0003ooooooooo
o`1@ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0<ooooo`00Noooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0;ooooo`00O?ooool2o`0004oooooo00?o0000oooo
ooooool0IOooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00_ooooo001nooooo`03
o`000?oooooooooo04cooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00_ooooo001oooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
Ioooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo0020ooooo`03o`000?oo
oooooooo04[ooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00_ooooo0021ooooo`?o0000BOooool00ol0003oooooooooo`1Yooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool02oooool007Kooooo1?l000000ol@413oooooooooo`05oooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00_ooooo001hooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool02oooool007Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo06_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0;ooooo`00N?oo
ool00ol0003oooooooooo`0:ooooo`;o0000A_ooool00ol0003oooooooooo`1/ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool02oooool005cooooo0ol000000ol@413oooooooooo`0F
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool005kooooo00?o410@okZj
^_ooool05oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04;ooooo00?o0000oooo
ooooool0K_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo001Nooooo`03
oiRHV?lb<S;ooooo01Oooooo00?o0000ooooooooool03_ooool2o`0004;ooooo00?o0000oooooooo
ool0Koooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo001Nooooo`03omgM
gOl0003o^[Zj01Gooooo00?oEEEEofIVI_l000004?ooool2o`0004;ooooo00?o0000ooooooooool0
L?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00[ooooo001Nooooo`03oeEEEOmg
MgOoA4A402[ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool02_ooool005gooooo00GogMgMoa0@4?oooooo8B4QomgM
g@0Zooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0L_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00[ooooo001Mooooo`05ofIVI_n7QhOooooooiRHV?mEEED0:ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0:ooooo`00G?ooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgo
oooo02[ooooo0_l0000mooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0:ooooo`00G?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooo
oooo02_ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`1dooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool02_ooool0097ooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`1eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool0097o
oooo0_l0000jooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0:ooooo`00Toooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo07Oooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`00U?ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`09ooooo`00UOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo07Sooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`00U_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo07Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`00Uoooool2o`0003Cooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Wooooo002Iooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
Noooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo002Iooooo`?o0000<Ooo
ool00ol0003oooooooooo`1looooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Ooo
ool009_ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1mooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool009cooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`1nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool009go
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02Oooool009kooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`1oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool009oooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02Oooool00:3ooooo0_l0000[ooooo`03o`000?oooooooooo087ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`08ooooo`00XOooool2o`0002[ooooo00?o0000oooo
ooooool0P_ooool01Ol0003ooooooooooooooooo000000[ooooo002Sooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0Poooool01?l0003oooooooooool0000:ooooo`00Y?ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo08Cooooo00?o0000ooooool000002_ooool00:Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`25ooooo`;o00002_ooool00:Kooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`24ooooo`?o00002_ooool00:Oooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`20ooooo`Co00003Oooool00:Sooooo00Co0000
ooooool0003o00008Oooool00ol0003oooooooooo`1looooo`Co00004Oooool008kooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Kooooo0_l0
000Rooooo`03o`000?oooooooooo07Sooooo1?l0000Eooooo`00T?ooool00ol0003oooooooooo`04
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`07ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0M?ooool4o`0001Wooooo002@ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo073ooooo1?l0000Moooo
o`00T?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Wooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`1]ooooo`?o00008Oooool0093ooooo00?o0000ooooooooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00_ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`1Yooooo`Co00009?ooool0093ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0IOooool4o`0002Sooooo
002@ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool3o`0001[ooooo00?o
0000ooooooooool0HOooool4o`0002cooooo002>ooooo`03oeEEEOmVIVKo000000gooooo1?l0000>
ooooo`;o00006oooool00ol0003oooooooooo`1Mooooo`Co0000<?ooool00;;ooooo0_l0000Ioooo
o`03o`000?oooooooooo05Wooooo1?l0000dooooo`00]?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo05Gooooo1?l0000hooooo`00]Oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo057ooooo1?l0000looooo`00]_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo04gooooo1?l00010ooooo`00]oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo04Wooooo1?l00014ooooo`00^?ooool2o`0001?ooooo00?o0000ooooooooool0AOooool4o`00
04Sooooo002iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0@Oooool4o`0004co
oooo002jooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0?_ooool3o`00053ooooo
002kooooo`;o00004?ooool00ol0003oooooooooo`0jooooo`Co0000Doooool00;gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0fooooo`Co0000Eoooool00;kooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0booooo`Co0000Foooool00;oooooo0_l0000<ooooo`03
o`000?oooooooooo02kooooo1?l0001Oooooo`00_oooool2o`0000cooooo00?o0000ooooooooool0
:_ooool4o`0006?ooooo0031ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09_oo
ool4o`0006Oooooo0032ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08_ooool4
o`0006_ooooo0033ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07_ooool4o`00
06oooooo0034ooooo`;o00001oooool00ol0003oooooooooo`0Jooooo`Co0000Loooool00<Kooooo
0ol00004ooooo`03o`000?oooooooooo01Kooooo1?l0001gooooo`00a_ooool2o`0000Gooooo00?o
0000ooooooooool04oooool3o`0007_ooooo0038ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool03oooool4o`0007kooooo0039ooooo`05o`000?ooooooooooooooool000003Oooool4
o`0008;ooooo003:ooooo`04o`000?ooooooooooo`0000Wooooo1?l00026ooooo`00boooool00ol0
003oooooo`000005ooooo`Co0000R_ooool00<cooooo1ol0002>ooooo`00`_ooool5o`0000Kooooo
0_l0002Booooo`00`_ooool01OnHV9So8B4Qonk^k_ooooooA4A409[ooooo0033ooooo`03oiRHV?lQ
8B7ok^k^09_ooooo0034ooooo`03oiRHV?lQ8B7ok^k^09[ooooo0035ooooo`03ogMgMomVIVKooooo
09Wooooo0036ooooo`03o`000?oooooooooo09Sooooo0032ooooo`05o`000?nj^[[ooooooiRHV?l@
4100V_ooool00<;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02Jooooo`00oooooomRooooo`00oooo
oomRooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00oooo
oomRooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00oooo
oomRooooo`00oooooomRooooo`00YOooool3o`000003oa0@4?oooooooooo0;Kooooo002Cooooo`;o
00002oooool00ol0003o^[Zjooooo`04ooooo`03oa0@4?nj^[[ooooo00Gooooo00?o0000okZj^_oo
ool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0VOooool009?ooooo00?o0000ooooooooool0
2_ooool2oc8b<PGooooo00?oV9RHoc8b<_ooool01Oooool2oc8b<Pkooooo00?o0000ooooooooool0
0oooool2oc8b<Y[ooooo0028ooooo`05oa0@4?l0003o0000o`000?l@41001_ooool01?l0003ooooo
ooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00?ogMgMo`000?nj
^[X01Oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0
003oooooooooo`03ooooo`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P09
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@
olc<c01aooooo`00R_ooool00ol0003oooooooooo`06ooooo`0:o`000?ooooooooooooooooo^k^ko
8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool00omEEEGoMgMgodA4A005
ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oo
oooooooo00?ooooo00?oc<c<o`000?l@41001Oooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko
00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B40LOooool008[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02oooo
o`04omgMgOl0003o410@olc<c0[ooooo00GogMgMoa0@4?oooooo8B4QomgMg@0;ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol0003ooooooooooooooooo0000077ooooo002:ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h:ooooo`05
ofIVI_n7QhOooooooiRHV?mEEED02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool00oooool6o`0000;ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B40LOooool008[ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<PWooooo00?ok^k^o`000?o^k^h00_oo
ool00ol0003ogMgMooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<077ooooo0027ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool01_ooool00ol@413o0000o`000003o`0000Gooooo00?o0000
ooooooooool02Oooool00ol@413o0000o`000003o`0000[ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo07?ooooo0027ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool00ooMgMgo410@oiRHV01cooooo`00Qoooool7o`0000Gooooo0_l0000Qooooo`03o`000?oo
oooooooo00Gooooo0_l0000=ooooo`03o`000?oooooooooo00_ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@477ooooo003oooooof;ooooo003oooooof;ooooo003o
ooooof;ooooo0000\
\>"],
  ImageRangeCache->{{{0, 352.438}, {392.188, 0}} -> {-0.0365789, -0.0401404, \
0.00334761, 0.00334761}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11253 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.066106 1.21212 -1.11022e-16 1.21212 [
[.5 1.12503 -44 0 ]
[.5 1.12503 44 24.5 ]
[.03831 .17557 -5.85635 -9 ]
[.03831 .17557 .14365 0 ]
[.12814 .13981 -17.2021 -9 ]
[.12814 .13981 .79789 0 ]
[.22015 .10319 -16.8352 -9 ]
[.22015 .10319 1.16484 0 ]
[.31441 .06568 -16.4682 -9 ]
[.31441 .06568 1.53178 0 ]
[.411 .02725 -16.1013 -9 ]
[.411 .02725 1.89873 0 ]
[.51 -0.01213 -5.24477 -9 ]
[.51 -0.01213 .75523 0 ]
[.21792 .02683 -9.25094 -12 ]
[.21792 .02683 .74906 0 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[.1484 .76875 -18 -3.08128 ]
[.1484 .76875 0 5.91872 ]
[.29382 .89692 -6 -3.18183 ]
[.29382 .89692 0 5.81817 ]
[.42456 1.01215 -18 -3.26907 ]
[.42456 1.01215 0 5.73093 ]
[.54272 1.11629 -6 -3.34548 ]
[.54272 1.11629 0 5.65452 ]
[.22112 .91822 -10 -4.24244 ]
[.22112 .91822 0 7.75756 ]
[.03467 .19213 -6 -2.71522 ]
[.03467 .19213 0 6.28478 ]
[.02559 .27239 -18 -2.7611 ]
[.02559 .27239 0 6.2389 ]
[.01617 .35567 -18 -2.80881 ]
[.01617 .35567 0 6.19119 ]
[.00638 .44212 -18 -2.85847 ]
[.00638 .44212 0 6.14153 ]
[-0.00378 .53194 -18 -2.9102 ]
[-0.00378 .53194 0 6.0898 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 1.11253 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.12503 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
.04875 .18654 m
.0558 .18375 L
s
[(0)] .03467 .19213 1 -0.39662 Mshowa
.03972 .26693 m
.04679 .2642 L
s
[(0.2)] .02559 .27239 1 -0.38642 Mshowa
.03035 .35034 m
.03744 .34767 L
s
[(0.4)] .01617 .35567 1 -0.37582 Mshowa
.02062 .43693 m
.02774 .43433 L
s
[(0.6)] .00638 .44212 1 -0.36478 Mshowa
.01051 .52689 m
.01765 .52437 L
s
[(0.8)] -0.00378 .53194 1 -0.35329 Mshowa
0 .62042 m
.00717 .61797 L
s
[(1)] -0.01434 .62532 1 -0.3413 Mshowa
.125 Mabswid
.04653 .20636 m
.05076 .2047 L
s
.04428 .22637 m
.04851 .22471 L
s
.04201 .24656 m
.04625 .24491 L
s
.03741 .28749 m
.04165 .28587 L
s
.03508 .30825 m
.03933 .30663 L
s
.03272 .32919 m
.03698 .32759 L
s
.02795 .37168 m
.03221 .37009 L
s
.02553 .39322 m
.02979 .39164 L
s
.02309 .41497 m
.02735 .4134 L
s
.01813 .45909 m
.0224 .45755 L
s
.01561 .48147 m
.01989 .47994 L
s
.01307 .50407 m
.01736 .50255 L
s
.00792 .54993 m
.01221 .54843 L
s
.00531 .5732 m
.0096 .5717 L
s
.00267 .59669 m
.00696 .59521 L
s
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
.5561 .7194 m
.04875 .18654 L
s
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.5561 .7194 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
0 0 m
1 0 L
1 1.11253 L
0 1.11253 L
closepath
clip
newpath
.5 Mabswid
.636 .729 .915 r
.52593 .68772 .5561 .7194 .58394 .7109 .55403 .68113 Metetra
.636 .743 .926 r
.55403 .68113 .58394 .7109 .61197 .70234 .58235 .67438 Metetra
.636 .758 .936 r
.58235 .67438 .61197 .70234 .64019 .69372 .61088 .66736 Metetra
.639 .771 .944 r
.61088 .66736 .64019 .69372 .66861 .68504 .63964 .65999 Metetra
.642 .784 .949 r
.63964 .65999 .66861 .68504 .69723 .6763 .66861 .65219 Metetra
.647 .794 .953 r
.66861 .65219 .69723 .6763 .72605 .6675 .69778 .64388 Metetra
.654 .802 .954 r
.69778 .64388 .72605 .6675 .75507 .65863 .72715 .63504 Metetra
.661 .806 .952 r
.72715 .63504 .75507 .65863 .7843 .6497 .75672 .62565 Metetra
.669 .806 .948 r
.75672 .62565 .7843 .6497 .81374 .64071 .78647 .61571 Metetra
.677 .803 .942 r
.78647 .61571 .81374 .64071 .84339 .63166 .81641 .60527 Metetra
.683 .796 .935 r
.81641 .60527 .84339 .63166 .87325 .62254 .84652 .59437 Metetra
.688 .786 .925 r
.84652 .59437 .87325 .62254 .90333 .61335 .87681 .58309 Metetra
.691 .774 .915 r
.87681 .58309 .90333 .61335 .93362 .6041 .90728 .57153 Metetra
.691 .761 .905 r
.90728 .57153 .93362 .6041 .96413 .59478 .93794 .55978 Metetra
.604 .719 .925 r
.49498 .6552 .52593 .68772 .55403 .68113 .52331 .65044 Metetra
.604 .732 .935 r
.52331 .65044 .55403 .68113 .58235 .67438 .55189 .64541 Metetra
.608 .747 .943 r
.55189 .64541 .58235 .67438 .61088 .66736 .58073 .63993 Metetra
.614 .761 .95 r
.58073 .63993 .61088 .66736 .63964 .65999 .6098 .63381 Metetra
.624 .775 .953 r
.6098 .63381 .63964 .65999 .66861 .65219 .63911 .62689 Metetra
.637 .787 .954 r
.63911 .62689 .66861 .65219 .69778 .64388 .66863 .61905 Metetra
.651 .797 .953 r
.66863 .61905 .69778 .64388 .72715 .63504 .69835 .61022 Metetra
.666 .803 .948 r
.69835 .61022 .72715 .63504 .75672 .62565 .72826 .60035 Metetra
.68 .805 .942 r
.72826 .60035 .75672 .62565 .78647 .61571 .75834 .58948 Metetra
.692 .804 .934 r
.75834 .58948 .78647 .61571 .81641 .60527 .78858 .57768 Metetra
.702 .798 .925 r
.78858 .57768 .81641 .60527 .84652 .59437 .81897 .56504 Metetra
.709 .79 .915 r
.81897 .56504 .84652 .59437 .87681 .58309 .8495 .55173 Metetra
.713 .78 .904 r
.8495 .55173 .87681 .58309 .90728 .57153 .88019 .53792 Metetra
.714 .768 .895 r
.88019 .53792 .90728 .57153 .93794 .55978 .91103 .52381 Metetra
.572 .707 .933 r
.4632 .62183 .49498 .6552 .52331 .65044 .49175 .61869 Metetra
.573 .72 .942 r
.49175 .61869 .52331 .65044 .55189 .64541 .52058 .61521 Metetra
.58 .734 .948 r
.52058 .61521 .55189 .64541 .58073 .63993 .54969 .6111 Metetra
.592 .749 .953 r
.54969 .6111 .58073 .63993 .6098 .63381 .57906 .6061 Metetra
.608 .765 .954 r
.57906 .6061 .6098 .63381 .63911 .62689 .60869 .59996 Metetra
.628 .778 .953 r
.60869 .59996 .63911 .62689 .66863 .61905 .63855 .59252 Metetra
.649 .79 .949 r
.63855 .59252 .66863 .61905 .69835 .61022 .66863 .58366 Metetra
.67 .797 .943 r
.66863 .58366 .69835 .61022 .72826 .60035 .69889 .57333 Metetra
.689 .801 .934 r
.69889 .57333 .72826 .60035 .75834 .58948 .72931 .56158 Metetra
.705 .801 .924 r
.72931 .56158 .75834 .58948 .78858 .57768 .75987 .54849 Metetra
.718 .797 .914 r
.75987 .54849 .78858 .57768 .81897 .56504 .79056 .53423 Metetra
.727 .791 .903 r
.79056 .53423 .81897 .56504 .8495 .55173 .82137 .51902 Metetra
.731 .782 .893 r
.82137 .51902 .8495 .55173 .88019 .53792 .8523 .50313 Metetra
.732 .772 .885 r
.8523 .50313 .88019 .53792 .91103 .52381 .88337 .48685 Metetra
.542 .695 .939 r
.43058 .58756 .4632 .62183 .49175 .61869 .45932 .58576 Metetra
.545 .707 .946 r
.45932 .58576 .49175 .61869 .52058 .61521 .48838 .58355 Metetra
.556 .721 .95 r
.48838 .58355 .52058 .61521 .54969 .6111 .51774 .58056 Metetra
.573 .737 .953 r
.51774 .58056 .54969 .6111 .57906 .6061 .5474 .57646 Metetra
.596 .753 .953 r
.5474 .57646 .57906 .6061 .60869 .59996 .57733 .57094 Metetra
.621 .767 .95 r
.57733 .57094 .60869 .59996 .63855 .59252 .60753 .56379 Metetra
.648 .78 .944 r
.60753 .56379 .63855 .59252 .66863 .58366 .63794 .55487 Metetra
.674 .789 .935 r
.63794 .55487 .66863 .58366 .69889 .57333 .66855 .5441 Metetra
.696 .794 .925 r
.66855 .5441 .69889 .57333 .72931 .56158 .69932 .53153 Metetra
.715 .795 .914 r
.69932 .53153 .72931 .56158 .75987 .54849 .73022 .51731 Metetra
.729 .793 .903 r
.73022 .51731 .75987 .54849 .79056 .53423 .76124 .50161 Metetra
.739 .789 .892 r
.76124 .50161 .79056 .53423 .82137 .51902 .79237 .48474 Metetra
.744 .782 .883 r
.79237 .48474 .82137 .51902 .8523 .50313 .82359 .46703 Metetra
.746 .774 .876 r
.82359 .46703 .8523 .50313 .88337 .48685 .85493 .44884 Metetra
.518 .685 .943 r
.39706 .55236 .43058 .58756 .45932 .58576 .42599 .55152 Metetra
.523 .695 .947 r
.42599 .55152 .45932 .58576 .48838 .58355 .45526 .55022 Metetra
.538 .708 .95 r
.45526 .55022 .48838 .58355 .51774 .58056 .48486 .54803 Metetra
.56 .724 .951 r
.48486 .54803 .51774 .58056 .5474 .57646 .51478 .54455 Metetra
.587 .74 .949 r
.51478 .54455 .5474 .57646 .57733 .57094 .54501 .53943 Metetra
.618 .755 .944 r
.54501 .53943 .57733 .57094 .60753 .56379 .57552 .53244 Metetra
.648 .768 .936 r
.57552 .53244 .60753 .56379 .63794 .55487 .60627 .52339 Metetra
.676 .778 .926 r
.60627 .52339 .63794 .55487 .66855 .5441 .63723 .5122 Metetra
.701 .784 .915 r
.63723 .5122 .66855 .5441 .69932 .53153 .66836 .49895 Metetra
.721 .786 .904 r
.66836 .49895 .69932 .53153 .73022 .51731 .69962 .48376 Metetra
.736 .786 .893 r
.69962 .48376 .73022 .51731 .76124 .50161 .73099 .46689 Metetra
.747 .784 .883 r
.73099 .46689 .76124 .50161 .79237 .48474 .76246 .44866 Metetra
.753 .78 .875 r
.76246 .44866 .79237 .48474 .82359 .46703 .79402 .42947 Metetra
.755 .774 .868 r
.79402 .42947 .82359 .46703 .85493 .44884 .82567 .40974 Metetra
.502 .678 .944 r
.36263 .5162 .39706 .55236 .42599 .55152 .39174 .51587 Metetra
.51 .687 .947 r
.39174 .51587 .42599 .55152 .45526 .55022 .42121 .51505 Metetra
.528 .699 .948 r
.42121 .51505 .45526 .55022 .48486 .54803 .45103 .51327 Metetra
.553 .713 .946 r
.45103 .51327 .48486 .54803 .51478 .54455 .48121 .51009 Metetra
.584 .728 .943 r
.48121 .51009 .51478 .54455 .54501 .53943 .51172 .50513 Metetra
.616 .743 .936 r
.51172 .50513 .54501 .53943 .57552 .53244 .54253 .49812 Metetra
.648 .755 .928 r
.54253 .49812 .57552 .53244 .60627 .52339 .57361 .48889 Metetra
.678 .765 .917 r
.57361 .48889 .60627 .52339 .63723 .5122 .60491 .47732 Metetra
.703 .772 .906 r
.60491 .47732 .63723 .5122 .66836 .49895 .6364 .4635 Metetra
.724 .776 .894 r
.6364 .4635 .66836 .49895 .69962 .48376 .66803 .44758 Metetra
.74 .778 .884 r
.66803 .44758 .69962 .48376 .73099 .46689 .69978 .42983 Metetra
.751 .778 .875 r
.69978 .42983 .73099 .46689 .76246 .44866 .73162 .41061 Metetra
.758 .776 .868 r
.73162 .41061 .76246 .44866 .79402 .42947 .76355 .39035 Metetra
.76 .773 .863 r
.76355 .39035 .79402 .42947 .82567 .40974 .79557 .36951 Metetra
.496 .676 .945 r
.32723 .47902 .36263 .5162 .39174 .51587 .35653 .47872 Metetra
.507 .682 .945 r
.35653 .47872 .39174 .51587 .42121 .51505 .38621 .47791 Metetra
.526 .692 .944 r
.38621 .47791 .42121 .51505 .45103 .51327 .41626 .47611 Metetra
.553 .705 .941 r
.41626 .47611 .45103 .51327 .48121 .51009 .44668 .47287 Metetra
.585 .718 .935 r
.44668 .47287 .48121 .51009 .51172 .50513 .47746 .46779 Metetra
.617 .731 .927 r
.47746 .46779 .51172 .50513 .54253 .49812 .50856 .46059 Metetra
.649 .743 .918 r
.50856 .46059 .54253 .49812 .57361 .48889 .53995 .45109 Metetra
.678 .752 .907 r
.53995 .45109 .57361 .48889 .60491 .47732 .5716 .43919 Metetra
.702 .76 .896 r
.5716 .43919 .60491 .47732 .6364 .4635 .60344 .42495 Metetra
.723 .765 .886 r
.60344 .42495 .6364 .4635 .66803 .44758 .63545 .40855 Metetra
.739 .768 .877 r
.63545 .40855 .66803 .44758 .69978 .42983 .66758 .39026 Metetra
.751 .77 .869 r
.66758 .39026 .69978 .42983 .73162 .41061 .69982 .37045 Metetra
.758 .771 .864 r
.69982 .37045 .73162 .41061 .76355 .39035 .73215 .34957 Metetra
.762 .771 .861 r
.73215 .34957 .76355 .39035 .79557 .36951 .76458 .32809 Metetra
.502 .678 .944 r
.29083 .44079 .32723 .47902 .35653 .47872 .32034 .44 Metetra
.514 .682 .942 r
.32034 .44 .35653 .47872 .38621 .47791 .35023 .43871 Metetra
.534 .689 .939 r
.35023 .43871 .38621 .47791 .41626 .47611 .38051 .43644 Metetra
.56 .699 .933 r
.38051 .43644 .41626 .47611 .44668 .47287 .41118 .43274 Metetra
.59 .709 .926 r
.41118 .43274 .44668 .47287 .47746 .46779 .44222 .42725 Metetra
.62 .72 .918 r
.44222 .42725 .47746 .46779 .50856 .46059 .47361 .41967 Metetra
.65 .73 .908 r
.47361 .41967 .50856 .46059 .53995 .45109 .50531 .40983 Metetra
.677 .739 .898 r
.50531 .40983 .53995 .45109 .5716 .43919 .53728 .39763 Metetra
.7 .747 .888 r
.53728 .39763 .5716 .43919 .60344 .42495 .56948 .38314 Metetra
.719 .753 .879 r
.56948 .38314 .60344 .42495 .63545 .40855 .60186 .36652 Metetra
.735 .758 .871 r
.60186 .36652 .63545 .40855 .66758 .39026 .63439 .34804 Metetra
.747 .762 .865 r
.63439 .34804 .66758 .39026 .69982 .37045 .66704 .32807 Metetra
.755 .765 .862 r
.66704 .32807 .69982 .37045 .73215 .34957 .69979 .30704 Metetra
.759 .768 .86 r
.69979 .30704 .73215 .34957 .76458 .32809 .73265 .28543 Metetra
.518 .685 .943 r
.25338 .40146 .29083 .44079 .32034 .44 .28314 .39968 Metetra
.53 .686 .938 r
.28314 .39968 .32034 .44 .35023 .43871 .31327 .39741 Metetra
.548 .689 .932 r
.31327 .39741 .35023 .43871 .38051 .43644 .3438 .39422 Metetra
.572 .695 .925 r
.3438 .39422 .38051 .43644 .41118 .43274 .37472 .38971 Metetra
.598 .703 .917 r
.37472 .38971 .41118 .43274 .44222 .42725 .40602 .3835 Metetra
.625 .711 .908 r
.40602 .3835 .44222 .42725 .47361 .41967 .43769 .37536 Metetra
.65 .719 .899 r
.43769 .37536 .47361 .41967 .50531 .40983 .46968 .3651 Metetra
.674 .727 .889 r
.46968 .3651 .50531 .40983 .53728 .39763 .50197 .35264 Metetra
.695 .734 .881 r
.50197 .35264 .53728 .39763 .56948 .38314 .53451 .33805 Metetra
.713 .741 .874 r
.53451 .33805 .56948 .38314 .60186 .36652 .56726 .32147 Metetra
.728 .748 .868 r
.56726 .32147 .60186 .36652 .63439 .34804 .60018 .30316 Metetra
.74 .754 .864 r
.60018 .30316 .63439 .34804 .66704 .32807 .63325 .28344 Metetra
.748 .759 .862 r
.63325 .28344 .66704 .32807 .69979 .30704 .66644 .26274 Metetra
.752 .764 .862 r
.66644 .26274 .69979 .30704 .73265 .28543 .69976 .24147 Metetra
.542 .695 .939 r
.21484 .36098 .25338 .40146 .28314 .39968 .24488 .35772 Metetra
.552 .692 .932 r
.24488 .35772 .28314 .39968 .31327 .39741 .27529 .35402 Metetra
.568 .692 .925 r
.27529 .35402 .31327 .39741 .3438 .39422 .30609 .34951 Metetra
.587 .695 .916 r
.30609 .34951 .3438 .39422 .37472 .38971 .33728 .34381 Metetra
.608 .698 .908 r
.33728 .34381 .37472 .38971 .40602 .3835 .36885 .33663 Metetra
.63 .704 .899 r
.36885 .33663 .40602 .3835 .43769 .37536 .4008 .32774 Metetra
.652 .71 .89 r
.4008 .32774 .43769 .37536 .46968 .3651 .43308 .31699 Metetra
.672 .716 .882 r
.43308 .31699 .46968 .3651 .50197 .35264 .46568 .30431 Metetra
.69 .723 .875 r
.46568 .30431 .50197 .35264 .53451 .33805 .49854 .28976 Metetra
.705 .73 .87 r
.49854 .28976 .53451 .33805 .56726 .32147 .53165 .27346 Metetra
.719 .737 .866 r
.53165 .27346 .56726 .32147 .60018 .30316 .56495 .25563 Metetra
.729 .745 .864 r
.56495 .25563 .60018 .30316 .63325 .28344 .59843 .23656 Metetra
.737 .752 .864 r
.59843 .23656 .63325 .28344 .66644 .26274 .63207 .21662 Metetra
.742 .758 .866 r
.63207 .21662 .66644 .26274 .69976 .24147 .66586 .19616 Metetra
.572 .707 .933 r
.17516 .3193 .21484 .36098 .24488 .35772 .20554 .31415 Metetra
.58 .701 .925 r
.20554 .31415 .24488 .35772 .27529 .35402 .23627 .3086 Metetra
.591 .697 .916 r
.23627 .3086 .27529 .35402 .30609 .34951 .26738 .30238 Metetra
.605 .696 .907 r
.26738 .30238 .30609 .34951 .33728 .34381 .29886 .29519 Metetra
.621 .696 .898 r
.29886 .29519 .33728 .34381 .36885 .33663 .33072 .28679 Metetra
.637 .698 .89 r
.33072 .28679 .36885 .33663 .4008 .32774 .36294 .27699 Metetra
.653 .702 .882 r
.36294 .27699 .4008 .32774 .43308 .31699 .39551 .26569 Metetra
.668 .707 .876 r
.39551 .26569 .43308 .31699 .46568 .30431 .4284 .25283 Metetra
.683 .713 .871 r
.4284 .25283 .46568 .30431 .49854 .28976 .46158 .23843 Metetra
.696 .72 .868 r
.46158 .23843 .49854 .28976 .53165 .27346 .49502 .22262 Metetra
.707 .727 .866 r
.49502 .22262 .53165 .27346 .56495 .25563 .52868 .20556 Metetra
.716 .735 .866 r
.52868 .20556 .56495 .25563 .59843 .23656 .56256 .18748 Metetra
.723 .744 .868 r
.56256 .18748 .59843 .23656 .63207 .21662 .59663 .16867 Metetra
.728 .752 .872 r
.59663 .16867 .63207 .21662 .66586 .19616 .63089 .14942 Metetra
.604 .719 .925 r
.13429 .27638 .17516 .3193 .20554 .31415 .16507 .26896 Metetra
.609 .71 .916 r
.16507 .26896 .20554 .31415 .23627 .3086 .19617 .26125 Metetra
.616 .703 .907 r
.19617 .26125 .23627 .3086 .26738 .30238 .22763 .25302 Metetra
.624 .699 .898 r
.22763 .25302 .26738 .30238 .29886 .29519 .25943 .24407 Metetra
.634 .696 .89 r
.25943 .24407 .29886 .29519 .33072 .28679 .2916 .23425 Metetra
.644 .695 .882 r
.2916 .23425 .33072 .28679 .36294 .27699 .32411 .22342 Metetra
.655 .696 .876 r
.32411 .22342 .36294 .27699 .39551 .26569 .35696 .21151 Metetra
.665 .699 .872 r
.35696 .21151 .39551 .26569 .4284 .25283 .39013 .19847 Metetra
.675 .704 .869 r
.39013 .19847 .4284 .25283 .46158 .23843 .4236 .18434 Metetra
.684 .71 .868 r
.4236 .18434 .46158 .23843 .49502 .22262 .45735 .16918 Metetra
.693 .717 .868 r
.45735 .16918 .49502 .22262 .52868 .20556 .49136 .15311 Metetra
.7 .726 .87 r
.49136 .15311 .52868 .20556 .56256 .18748 .52561 .13629 Metetra
.706 .735 .874 r
.52561 .13629 .56256 .18748 .59663 .16867 .5601 .11892 Metetra
.71 .745 .879 r
.5601 .11892 .59663 .16867 .63089 .14942 .59481 .1012 Metetra
.636 .729 .915 r
.09217 .23214 .13429 .27638 .16507 .26896 .12341 .22222 Metetra
.638 .719 .907 r
.12341 .22222 .16507 .26896 .19617 .26125 .15495 .21208 Metetra
.64 .71 .898 r
.15495 .21208 .19617 .26125 .22763 .25302 .1868 .20162 Metetra
.643 .703 .89 r
.1868 .20162 .22763 .25302 .25943 .24407 .21897 .19075 Metetra
.647 .697 .882 r
.21897 .19075 .25943 .24407 .2916 .23425 .25146 .17936 Metetra
.652 .694 .876 r
.25146 .17936 .2916 .23425 .32411 .22342 .28428 .16741 Metetra
.657 .693 .872 r
.28428 .16741 .32411 .22342 .35696 .21151 .31741 .15484 Metetra
.662 .694 .869 r
.31741 .15484 .35696 .21151 .39013 .19847 .35085 .14164 Metetra
.667 .697 .868 r
.35085 .14164 .39013 .19847 .4236 .18434 .3846 .12782 Metetra
.672 .702 .869 r
.3846 .12782 .4236 .18434 .45735 .16918 .41863 .11341 Metetra
.677 .708 .871 r
.41863 .11341 .45735 .16918 .49136 .15311 .45296 .09848 Metetra
.682 .717 .875 r
.45296 .09848 .49136 .15311 .52561 .13629 .48755 .0831 Metetra
.686 .726 .881 r
.48755 .0831 .52561 .13629 .5601 .11892 .52242 .06738 Metetra
.689 .737 .887 r
.52242 .06738 .5601 .11892 .59481 .1012 .55756 .05142 Metetra
.666 .738 .904 r
.04875 .18654 .09217 .23214 .12341 .22222 .08051 .17394 Metetra
.664 .727 .896 r
.08051 .17394 .12341 .22222 .15495 .21208 .11254 .16124 Metetra
.663 .717 .888 r
.11254 .16124 .15495 .21208 .1868 .20162 .14483 .14843 Metetra
.662 .708 .882 r
.14483 .14843 .1868 .20162 .21897 .19075 .1774 .13551 Metetra
.66 .7 .876 r
.1774 .13551 .21897 .19075 .25146 .17936 .21025 .12249 Metetra
.66 .695 .872 r
.21025 .12249 .25146 .17936 .28428 .16741 .24339 .10934 Metetra
.659 .692 .869 r
.24339 .10934 .28428 .16741 .31741 .15484 .27681 .09609 Metetra
.659 .69 .868 r
.27681 .09609 .31741 .15484 .35085 .14164 .31052 .08272 Metetra
.659 .692 .869 r
.31052 .08272 .35085 .14164 .3846 .12782 .34452 .06923 Metetra
.66 .695 .872 r
.34452 .06923 .3846 .12782 .41863 .11341 .37882 .05563 Metetra
.66 .7 .876 r
.37882 .05563 .41863 .11341 .45296 .09848 .41342 .04191 Metetra
.662 .708 .882 r
.41342 .04191 .45296 .09848 .48755 .0831 .44833 .02806 Metetra
.663 .717 .888 r
.44833 .02806 .48755 .0831 .52242 .06738 .48355 .01409 Metetra
.664 .727 .896 r
.48355 .01409 .52242 .06738 .55756 .05142 .51908 0 Metetra
0 g
.25 Mabswid
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282.75, 314.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005Q0001RB000`400?l00000o`00003ooooooomR
ooooo`00oooooomRooooo`00oooooomRooooo`00^_ooool4o`000003oa0@4?oooooooooo0:3ooooo
002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002loooo
o`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`00
0?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002jooooo`03oeEEEOmVIVKo
00000:Cooooo003oooooof;ooooo003oooooof;ooooo001Mooooo`;o00000_ooool2o`000?kooooo
001Mooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgMo_ooool005kooooo00CogMgMo`000?l@413o
c<c<:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`07oooool2o`0009oooooo001Nooooo`04onk^k_lQ8B7o410@onk^kR[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01cooooo
0ol000000onY^^Go0000o`00002Nooooo`00G_ooool01?lQ8B7oMgMgogMgMolb<S8Zooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001[ooooo0ol00003ojVj
i@?o0000WOooool005gooooo0_l00002ooooo`;o0000:Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`?o00001_nY^^D00ol0003oZK[Uo`00002M
ooooo`00S?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00Eooooo`?o00000_nY^^D00ol0003oZK[UojVji@03ojVji@04o`000?nY^^GoZK[Uo`0009cooooo
002<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@01;o
oooo1?l0000:ojVji@04o`000?nY^^GoZK[Uo`0009cooooo002<ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000013ooooo1?l000000onY]n?o0000ojVji@09
ojVji@05o`000?nY^^GoZK[UojVjiOl00000Voooool008cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT03Oooool4o`000003ojVghol0003oZKOS00;oZKOS
00?o0000ojVjiOnY^^D01onY^^D00ol0003oZK[UojVji@02ojVji@03o`000?oooooooooo09Sooooo
002/ooooo`Co00002?nY]n<00ol0003oZK[UojVji@06ojVji@03o`000?nY^^GoZK[U00?oZK[U00?o
0000ooooooooool0Uoooool00:Wooooo1?l0000<ojVgh`03o`000?nY^^GoZK[U00GoZK[U00?o0000
ojVjiOnY^^D00onY^^D00ol0003oooooooooo`2Gooooo`00Yoooool6o`0000coZKOS00?o0000ojVj
iOnY^^D01OnY^^D00ol0003oZK[UojVji@04ojVji@03o`000?oooooooooo09Kooooo002Tooooo`Co
00001OnY]N400ol0003oZKOSojVgh`0:ojVgh`03o`000?nY^^GoZK[U00CoZK[U00?o0000ojVjiOnY
^^D01OnY^^D00ol0003oooooooooo`2Eooooo`00KOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`08?ooool3o`0000WoZKGQ00?o0000ojVg
honY]n<02_nY]n<00ol0003oZK[UojVji@03ojVji@03o`000?nY^^GoZK[U00KoZK[U00?o0000oooo
ooooool0U?ooool006gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q01gooooo0ol000000onY]N7o0000ojVeh@09ojVeh@03o`000?nY]n?o
ZKOS00_oZKOS00?o0000ojVjiOnY^^D00_nY^^D00ol0003oZK[UojVji@06ojVji@03o`000?oooooo
oooo09Cooooo001]ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000001_ooooo0ol000001OnX/n3o0000ojVehOnY]N7o000000[oZKGQ00?o0000ojVghonY]n<0
2_nY]n<00ol0003oZK[UojVji@02ojVji@03o`000?nY^^GoZK[U00OoZK[U00?o0000ooooooooool0
Toooool006gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B406?ooool3o`0000GoZ;?P00?o0000ojVehOnY]N402onY]N400ol0003oZKOSojVgh`0:ojVgh`05
o`000?nY^^GoZK[UojVjiOl000002_nY^^D00ol0003oooooooooo`2Booooo`00KOooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Eooooo`Co000000?oZ;?P
o`000?nX/n001OnX/n000ol0003oZKGQojVeh@0;ojVeh@03o`000?nY]n?oZKOS00[oZKOS00Co0000
ojVjiOnY^^Go00002_nY^^D2o`0009?ooooo001]ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool00omEEEGoQhN7ooooo`0Eooooo`?o00002onX/n000ol0003oZKGQojVeh@0;ojVeh@03o`000?nY
]n?oZKOS00_oZKOS00?o0000ojVjiOl000002?nY^^D2o`000003ok2lhol0003ooooo09;ooooo001]
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00Cooooo`Co00003OnX
/n000ol0003oZKGQojVeh@0;ojVeh@03o`000?nY]n?oZKOS00[oZKOS00?o0000ojVjiOl000001OnY
^^D3o`0000Co/;cS00?o0000ooooooooool0T?ooool006gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`04olc<c?m4A4Co0000oa0@40oooooo0_l00002ojRag`03o`000?nX/Moo000000goZ;?P
00?o0000ojVehOnY]N402onY]N400ol0003oZKOSojVgh`0:ojVgh`;o00000onY^^D2o`0000So/;cS
00?o0000ooooooooool0Soooool008kooooo0ol00007ojRag`03o`000?nX/n3oZ;?P00[oZ;?P00?o
0000ojVehOnY]N402onY]N400ol0003oZKOSojVgh`0;ojVgh`04o`000?nY^^Go0000o`0000_o/;cS
00?o0000ooooooooool0S_ooool008cooooo0ol00009ojRag`03o`000?nX/n3oZ;?P00_oZ;?P00?o
0000ojVehOnY]N402onY]N400ol0003oZKOSojVgh`0:ojVgh`;o00003On`_><2o`0008oooooo0029
ooooo`Co000000?oZ;7Oo`000?nX/Ml02OnX/Ml00ol0003oZ;?PojRch00;ojRch003o`000?nY]N7o
ZKGQ00_oZKGQ00?o0000ojVghonY]n<01onY]n<4o`0000ko/;cS00?o0000ooooooooool0SOooool0
053ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooo
oooo023ooooo1?l000000onX/Mko0000ojRag`0<ojRag`03o`000?nX/n3oZ;?P00[oZ;?P00?o0000
ojVehOnY]N403?nY]N400ol0003oZKOSojVgh`04ojVgh`;o00000_n_^N400ol0003o[kWQo`00000>
ok2lh`03o`000?oooooooooo08cooooo001@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool07_ooool4o`0000GoZ;7N00?o0000ojRagonX/Ml02_nX/Ml0
0ol0003oZ;?PojRch00;ojRch003o`000?nY]N7oZKGQ00_oZKGQ00?o0000ojVghonY]n<00_nY]n<2
o`0000Co[kWQ00Co0000ojnihOn_^N7o00003_n`_><00ol0003oooooooooo`2;ooooo`00D?ooool0
1Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Mooooo`?o000000?oZ;7No`000?nX/Mh01_nX
/Mh00ol0003oZ;7OojRag`0:ojRag`03o`000?nX/n3oZ;?P00_oZ;?P00?o0000ojVehOnY]N402onY
]N401?l0003oZKOSo`000?l00006ojnih@05o`000?n_^N7o[kWQojnihOl000003On`_><2o`0008co
oooo001@ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0000Koooo
o`?o00001OnX/Mh00ol0003oZ;7NojRagP04ojRagP03o`000?nX/MooZ;7O00_oZ;7O00?o0000ojRc
h?nX/n002_nX/n000ol0003oZKGQojVeh@0;ojVeh@;o00002?n_^N401Ol0003o[kWQojnihOn_^N7o
000000ko/;cS0_l0002;ooooo`00D?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgM
oeEEEOoooooo00006Oooool3o`000003ojR`g_l0003oZ;7N00coZ;7N00?o0000ojRagonX/Ml02_nX
/Ml00ol0003oZ;?PojRch00;ojRch003o`000?nY]N7oZKGQ00SoZKGQ0_l000000on^]moo0000ojni
h@07ojnih@03o`000?n_^N7o[kWQ00;o[kWQ00?o0000ok2lhon`_><03?n`_><00ol0003ooooooooo
o`29ooooo`00D?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000005_oo
ool3o`0000;oZ;3N00Co0000ojR`g_nX/=ko00003OnX/Mh00ol0003oZ;7OojRag`0:ojRag`03o`00
0?nX/n3oZ;?P00_oZ;?P00?o0000ojVehOnY]N401?nY]N43o`0000Co[[OO00?o0000ojnihOn_^N40
1On_^N400ol0003o[kWQojnih@03ojnih@03o`000?n`_>?o/;cS00co/;cS00?o0000ooooooooool0
R?ooool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000001Cooooo
0ol00008ojR`gP03o`000?nX/MkoZ;7N00[oZ;7N00?o0000ojRagonX/Ml02onX/Ml00ol0003oZ;?P
ojRch00:ojRch003o`000?nY]N7oZKGQ00;oZKGQ0_l00008ojjgg`03o`000?n_^N7o[kWQ00Co[kWQ
00?o0000ojnihOn_^N401?n_^N400ol0003o/;cSok2lh`0;ok2lh`;o0000ROooool0053ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo013ooooo0ol0000<ojR`gP03o`00
0?nX/MkoZ;7N00[oZ;7N00?o0000ojRagonX/Ml02_nX/Ml00ol0003oZ;?PojRch00;ojRch004o`00
0?nY]N7o0000o`0000[o[[OO00?o0000ojnihOn_^N401?n_^N400ol0003o[kWQojnih@04ojnih@03
o`000?n`_>?o/;cS00co/;cS0_l00028ooooo`00Loooool3o`000003ojRag_l0003o000000_oZ;3N
00?o0000ojRag_nX/Mh02onX/Mh00ol0003oZ;7OojRag`0:ojRag`03o`000?nX/n3oZ;?P00[oZ;?P
0_l0000=ojjgg`03o`000?n_^N7o[kWQ00?o[kWQ00?o0000ojnihOn_^N401On_^N400ol0003o/;cS
ok2lh`0<ok2lh`;o0000Qoooool0073ooooo0ol00005ojRagP03o`000?nX/=koZ;3N00[oZ;3N00?o
0000ojRag_nX/Mh02_nX/Mh00ol0003oZ;7OojRag`0;ojRag`03o`000?nX/n3oZ;?P00KoZ;?P0ol0
00000on]]Mko0000ojjgg`0=ojjgg`03o`000?n_^N7o[kWQ00;o[kWQ00?o0000ojnihOn_^N401_n_
^N400ol0003o/;cSok2lh`09ok2lh`;o000000?o]KkQo`000?ooool0Q_ooool006kooooo0ol00008
ojRagP03o`000?nX/=koZ;3N00[oZ;3N00?o0000ojRag_nX/Mh02_nX/Mh00ol0003oZ;7OojRag`0:
ojRag`03o`000?nX/n3oZ;?P00?oZ;?P0ol00005ojfegP03o`000?n^]moo[[OO00_o[[OO00?o0000
ojnihOn_^N400_n_^N400ol0003o[kWQojnih@07ojnih@03o`000?n`_>?o/;cS00Ko/;cS0_l00003
okFnh@;o0000Q_ooool003?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0002?ooooo0ol00002ojRagP03o`000?nX/MkoZ;7N00KoZ;7N00?o0000ojR`g_nX/=h02_nX/=h0
0ol0003oZ;7NojRagP0;ojRagP03o`000?nX/MooZ;7O00[oZ;7O00?o0000ojRch?l000000_l00009
ojfegP03o`000?n^]moo[[OO00_o[[OO00Go0000ojnihOn_^N7o[kWQo`000009ojnih@03o`000?n`
_>?o/;cS00Go/;cS00?o0000okFnhOne_^401?ne_^42o`0008Gooooo000cooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Qooooo`?o0000
00?oZ;7Oo`000?nX/Mh02onX/Mh00ol0003oZ;3NojR`gP0:ojR`gP03o`000?nX/MkoZ;7N00[oZ;7N
00?o0000ojRagonX/Ml02_nX/Ml2o`0000go[KGN00?o0000ojjggon^]ml02on^]ml01?l0003o[kWQ
ojnihOl0000:ojnih@03o`000?n`_>?o/;cS00;o/;cS0_l00008okFnh@;o0000Q?ooool003?ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^01oooooo1?l00004ojRag`03
o`000?nX/MkoZ;7N00[oZ;7N00?o0000ojR`g_nX/=h02_nX/=h00ol0003oZ;7NojRagP0:ojRagP03
o`000?nX/MooZ;7O00OoZ;7O0_l000000on//mko0000ojfegP0<ojfegP03o`000?n^]moo[[OO00co
[[OO00?o0000ojnihOl000002on_^N401?l0003o/;cSo`000?l0000;okFnh@03o`000?oooooooooo
08;ooooo000cooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Koooo
o`?o00001?nX/Ml00ol0003oZ;7OojRag`02ojRag`03o`000?nX/MkoZ;7N00WoZ;7N00?o0000ojR`
g_nX/=h02onX/=h00ol0003oZ;7NojRagP0:ojRagP03o`000?nX/MooZ;7O00CoZ;7O0_l00004ojbc
gP03o`000?n]]Mko[KGN00_o[KGN00?o0000ojjggon^]ml02on^]ml00ol0003o[kWQo`00000;ojni
h@;o00003One_^42o`0008?ooooo000cooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOoIVIVooooo`0Hooooo`?o00002onX/Ml00ol0003oZ;7NojRagP0:ojRagP03o`000?nX/=koZ;3N
00[oZ;3N00?o0000ojRag_nX/Mh02_nX/Mh00ol0003oZ;7OojRag`02ojRag`;o00001on//mh00ol0
003o[KGNojfegP0;ojfegP03o`000?n^]moo[[OO00_o[[OO0_l00009ojnih@;o000000?o];cOo`00
0?ne_^403One_^42o`0008;ooooo000cooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0
003oooooooooo`0Dooooo`?o000000?oZ;?Po`000?nX/Ml03?nX/Ml00ol0003oZ;7NojRagP0:ojRa
gP03o`000?nX/=koZ;3N00[oZ;3N00?o0000ojRag_nX/Mh02_nX/Mh01?l0003oZ;7Oo`000?l00009
ojbcgP03o`000?n]]Mko[KGN00co[KGN00?o0000ojjggon^]ml02on^]ml00ol0003o[kWQojnih@04
ojnih@?o00001?nd_=l00ol0003o]KkQokFnh@0<okFnh@;o0000POooool003?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41005?ooool3o`0000CoZ;?P00?o
0000ojRagonX/Ml02onX/Ml00ol0003oZ;7NojRagP09ojRagP03o`000?nX/=koZ;3N00_oZ;3N00?o
0000ojRag_nX/Mh02OnX/Mh2o`0000co[;?N00?o0000ojfeg_n]]Mh02on]]Mh00ol0003o[[OOojjg
g`0;ojjgg`03o`000?n_^N7o[kWQ00;o[kWQ0_l00008okBlg`03o`000?ne_^7o]KkQ00co]KkQ00?o
0000ooooooooool0Ooooool003?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`04Oooool3o`0000SoZ;?P00?o0000ojRagonX/Ml02_nX/Ml00ol0003oZ;7N
ojRagP0:ojRagP03o`000?nX/=koZ;3N00[oZ;3N00?o0000ojRag_nX/Mh01_nX/Mh3o`000003ojZb
g_l0003o[;?N00co[;?N00?o0000ojfeg_n]]Mh02on]]Mh00ol0003o[[OOojjgg`0:ojjgg`;o0000
00?o[kWQo`000?l000002ond_=l00ol0003o]KkQokFnh@0;okFnh@;o0000P?ooool005Oooooo0ol0
00000onX/n3o0000ojRch008ojRch003o`000?nX/MooZ;7O00[oZ;7O00?o0000ojRag_nX/Mh02_nX
/Mh00ol0003oZ;3NojR`gP0:ojR`gP03o`000?nX/MkoZ;7N00?oZ;7N0_l00005ojZbgP03o`000?n/
/mko[;?N00_o[;?N00?o0000ojfeg_n]]Mh02on]]Mh00ol0003o[[OOojjgg`09ojjgg`?o00003Ond
_=l00ol0003o]KkQokFnh@0<okFnh@;o0000Ooooool005Cooooo0ol000000onY]N7o0000ojRch00;
ojRch003o`000?nX/MooZ;7O00_oZ;7O00?o0000ojRag_nX/Mh02OnX/Mh00ol0003oZ;3NojR`gP0;
ojR`gP03o`000?nX/Mko000000;o00002?nZ/]h00ol0003o[;?NojbcgP0:ojbcgP03o`000?n]]Mko
[KGN00co[KGN00?o0000ojjggon^]ml01on^]ml2o`000003ok>ig_l0003o];cO00go];cO00?o0000
okFnhOne_^403?ne_^400ol0003oooooooooo`1mooooo`00D_ooool3o`0000CoZKGQ00?o0000ojRc
h?nX/n002_nX/n000ol0003oZ;7OojRag`0:ojRag`03o`000?nX/MkoZ;7N00[oZ;7N00?o0000ojR`
g_nX/=h02_nX/=h2o`0000_oZ[;N00?o0000ojbcg_n//mh02on//mh00ol0003o[KGNojfegP0;ojfe
gP03o`000?n^]moo[[OO00Go[[OO0_l000001Onc^Mko0000ok>ig_nc^Mko000000ko];cO00?o0000
okFnhOne_^403?ne_^400ol0003oooooooooo`1looooo`009oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo1?l000000onY]N7o0000ojVeh@04ojVeh@03o`000?nX/n3oZ;?P00[oZ;?P00?o0000
ojRagonX/Ml02_nX/Ml00ol0003oZ;7NojRagP0:ojRagP03o`000?nX/=koZ;3N00KoZ;3N0ol00000
0onY/Mko0000ojZbgP0;ojZbgP03o`000?n//mko[;?N00_o[;?N00?o0000ojfeg_n]]Mh02on]]Mh0
0ol0003o[[OOojjgg`02ojjgg`;o00000onc^Mh01Ol0003o/kWNok>ig_nc^Mko000000ko];cO00?o
0000okFnhOne_^402one_^42o`0007gooooo000Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL08Ooo
ool3o`0000_oZKGQ00?o0000ojRch?nX/n002OnX/n000ol0003oZ;7OojRag`0;ojRag`03o`000?nX
/MkoZ;7N00WoZ;7N00?o0000ojR`g_nX/=h00onX/=h3o`0000GoZK7N00?o0000ojZbg_nZ/]h02_nZ
/]h00ol0003o[;?NojbcgP0:ojbcgP03o`000?n]]Mko[KGN00co[KGN00Co0000ojjggol0003o0000
1Onc^Mh00ol0003o/kWNok>igP02ok>igP03o`000?nd_=oo];cO00_o];cO00?o0000okFnhOne_^40
3?ne_^42o`0007cooooo000Wooooo`05oa0@4?ooooooooooooooool@41007_ooool5o`0000coZKGQ
00?o0000ojRch?nX/n002_nX/n000ol0003oZ;7OojRag`0:ojRag`03o`000?nX/MkoZ;7N00[oZ;7N
00?o0000ojR`g_l000000_l00009ojVagP03o`000?nZ/]koZ[;N00[oZ[;N00?o0000ojbcg_n//mh0
2_n//mh00ol0003o[KGNojfegP0;ojfegP;o00001onc^Mh00ol0003o/kWNok>igP02ok>igP03o`00
0?nd_=oo];cO00co];cO00?o0000okFnhOne_^402One_^42o`000003ok[0gol0003ooooo07_ooooo
000Wooooo`05o`000?ooooooooooooooool000007?ooool3o`0000;oZKOS00?o0000ojVghol00000
3?nY]N400ol0003oZ;?PojRch00:ojRch003o`000?nX/MooZ;7O00[oZ;7O00?o0000ojRag_nX/Mh0
2OnX/Mh2o`0000coZK7N00?o0000ojZbg_nZ/]h02_nZ/]h00ol0003o[;?NojbcgP0;ojbcgP03o`00
0?n]]Mko[KGN00So[KGN0_l000000ona]mko0000ok>igP06ok>igP03o`000?nc^Mko/kWN00?o/kWN
00?o0000okBlgond_=l03?nd_=l00ol0003o]KkQokFnh@06okFnh@;o00001?nj`=l00ol0003ooooo
ooooo`1iooooo`009oooool01Ol0003ooooooooooooooooo000001Wooooo1?l00005ojVgh`03o`00
0?nY]n?o000000coZKGQ00?o0000ojRch?nX/n002_nX/n000ol0003oZ;7OojRag`0:ojRag`03o`00
0?nX/MkoZ;7N00GoZ;7N0ol000000onX/Moo0000ojVagP0<ojVagP03o`000?nZ/]koZ[;N00[oZ[;N
00?o0000ojbcg_n//mh02on//mh00ol0003o[KGNojfegP04ojfegP?o00001?na]mh00ol0003o/kWN
ok>igP04ok>igP03o`000?nc^Mko/kWN00Co/kWN00?o0000okBlgond_=l02ond_=l00ol0003o]KkQ
okFnh@05okFnh@03o`000?nj`=oo^/3O00Co^/3O0_l0001jooooo`009oooool01Ol@413ooooooooo
oooooooo410@01Oooooo0ol0000;ojVgh`03o`000?nY]N7oZKGQ00[oZKGQ00?o0000ojRch?nX/n00
2OnX/n000ol0003oZ;7OojRag`0:ojRag`03o`000?nX/MkoZ;7N00?oZ;7N0_l00005ojRag`03o`00
0?nY/MkoZK7N00_oZK7N00?o0000ojZbg_nZ/]h02_nZ/]h00ol0003o[;?NojbcgP0:ojbcgP03o`00
0?n]]Mko[KGN00;o[KGN0_l00008ok6ggP03o`000?nc^Mko/kWN00?o/kWN00?o0000ok>ig_nc^Mh0
1Onc^Mh00ol0003o];cOokBlg`0;okBlg`03o`000?ne_^7o]KkQ00;o]KkQ0_l00008ok[0g`;o0000
NOooool002Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`Go000000?oZKOSo`000?nY]n<0
2_nY]n<00ol0003oZKGQojVeh@0:ojVeh@03o`000?nX/n3oZ;?P00WoZ;?P00?o0000ojRagonX/Ml0
2_nX/Ml00ol0003oZ;7No`000002o`0000SoZ;7O00?o0000ojVag_nY/Mh02onY/Mh00ol0003oZ[;N
ojZbgP09ojZbgP03o`000?n//mko[;?N00_o[;?N00Co0000ojfeg_l0003o00002_na]mh00ol0003o
/kWNok>igP03ok>igP03o`000?nc^Mko/kWN00Go/kWN00?o0000okBlgond_=l03?nd_=l01?l0003o
]KkQo`000?l0000;ok[0g`03o`000?oooooooooo07Oooooo000Wooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h04_ooool3o`0000CoZK[U00?o0000ojVghonY]n<02_nY]n<00ol0003oZKGQojVeh@0:ojVe
h@03o`000?nX/n3oZ;?P00[oZ;?P00?o0000ojRagonX/Ml02OnX/Ml2o`0000_oZ;7O00?o0000ojVa
g_nY/Mh02onY/Mh00ol0003oZ[;NojZbgP0:ojZbgP03o`000?n//mko[;?N00[o[;?N0_l0000=ok6g
gP03o`000?nc^Mko/kWN00;o/kWN00?o0000ok>ig_nc^Mh01_nc^Mh00ol0003o];cOokBlg`0;okBl
g`;o00003_nj`=l00ol0003oooooooooo`1fooooo`00>oooool5o`0000KoZK[U00?o0000ojVghonY
]n<02_nY]n<00ol0003oZKGQojVeh@0:ojVeh@03o`000?nX/n3oZ;?P00WoZ;?P00?o0000ojRagonX
/Ml01_nX/Ml3o`000003ojJah?l0003oZ;7O00_oZ;7O00?o0000ojVag_nY/Mh02onY/Mh00ol0003o
Z[;NojZbgP0:ojZbgP03o`000?n//mko[;?N00Oo[;?N0_l000000on_]Mko0000ok6ggP0=ok6ggP05
o`000?nc^Mko/kWNok>ig_l000002Onc^Mh00ol0003o];cOokBlg`08okBlg`;o000000?o^KkNo`00
0?nj`=l03Onj`=l2o`0007Oooooo000iooooo`?o00002onY^^D00ol0003oZKOSojVgh`0:ojVgh`03
o`000?nY]N7oZKGQ00[oZKGQ00?o0000ojRch?nX/n002OnX/n000ol0003oZ;7OojRag`03ojRag`;o
00001OnV/N000ol0003oZ;7OojRag`0:ojRag`03o`000?nY/MkoZK7N00_oZK7N00?o0000ojZbg_nZ
/]h02_nZ/]h00ol0003o[;?NojbcgP04ojbcgP;o00001?n_]Mh00ol0003o/KONok6ggP0;ok6ggP05
o`000?nc^Mko/kWNok>ig_l000002_nc^Mh00ol0003o];cOokBlg`06okBlg`03o`000?ni_]ko^KkN
00;o^KkN00?o0000ok[0gonj`=l03?nj`=l2o`0007Kooooo000gooooo`Co00003OnY^^D00ol0003o
ZKOSojVgh`0:ojVgh`03o`000?nY]N7oZKGQ00[oZKGQ00?o0000ojRch?nX/n002OnX/n000ol0003o
Z;7Oo`000002o`0000SoY[7P00?o0000ojRagonX/Ml02_nX/Ml00ol0003oZK7NojVagP0:ojVagP03
o`000?nZ/]koZ[;N00[oZ[;N00?o0000ojbcg_n//mh00_n//mh2o`0000Oo[kGN00?o0000ok6gg_na
]mh02ona]mh01?l0003o/kWNok>ig_l0000:ok>igP03o`000?nd_=oo];cO00Co];cO0_l00006okVn
gP03o`000?nj`=oo^/3O00co^/3O00?o0000ooooooooool0M?ooool003Cooooo0ol000001OnZ_>Oo
0000ojZlionZ_>Oo000000coZK[U00?o0000ojVghonY]n<02onY]n<00ol0003oZKGQojVeh@09ojVe
h@03o`000?nX/n3oZ;?P00SoZ;?P0ol0000;ojJah003o`000?nX/MooZ;7O00[oZ;7O00?o0000ojVa
g_nY/Mh02onY/Mh00ol0003oZ[;NojZbgP0:ojZbgP04o`000?n//mko0000o`0000Wo[kGN00?o0000
ok6gg_na]mh03?na]mh00ol0003o/kWNo`00000;ok>igP04o`000?nd_=oo];cOokBlg`;o00002Oni
_]h00ol0003o^/3Ook[0g`0<ok[0g`03o`000?oooooooooo07?ooooo000booooo`?o00001onZ_>L0
0ol0003oZK[UojVji@0:ojVji@03o`000?nY]n?oZKOS00_oZKOS00?o0000ojVehOnY]N402OnY]N40
0ol0003oZ;?PojRch004ojRch0?o00000_nU/^400ol0003oY[7PojJah00:ojJah003o`000?nX/Moo
Z;7O00[oZ;7O00?o0000ojVag_nY/Mh02onY/Mh00ol0003oZ[;NojZbgP09ojZbgP;o00003?n_]Mh0
0ol0003o/KONok6ggP0;ok6ggP03o`000?nc^Mko000000co/kWN00?o0000okBlgol000002oni_]h0
0ol0003o^/3Ook[0g`0<ok[0g`;o0000M?ooool0037ooooo00?o0000ojZlionZ_>L02OnZ_>L00ol0
003oZK[UojVji@0:ojVji@03o`000?nY]n?oZKOS00[oZKOS00?o0000ojVehOnY]N402_nY]N400ol0
003oZ;?PojRch003o`0000KoYK;Q00?o0000ojJah?nV/N002_nV/N000ol0003oZ;7OojRag`0:ojRa
g`03o`000?nY/MkoZK7N00_oZK7N00?o0000ojZbg_nZ/]h01OnZ/]h3o`000003ojbdg_l0003o[kGN
00co[kGN00?o0000ok6gg_na]mh02ona]mh2o`0000co/kWN0_l0000=okVngP03o`000?nj`=oo^/3O
00co^/3O00?o0000ooooooooool0L_ooool0037ooooo0_l0000;ojZli`03o`000?nY^^GoZK[U00[o
ZK[U00?o0000ojVghonY]n<02_nY]n<00ol0003oZKGQojVeh@08ojVeh@Co00002_nU/^400ol0003o
Y[7PojJah00:ojJah003o`000?nX/MooZ;7O00WoZ;7O00?o0000ojVag_nY/Mh02onY/Mh00ol0003o
Z[;NojZbgP03ojZbgP;o00001On/]=h00ol0003o[kGNojnegP0;ojnegP03o`000?na]mko/KON00[o
/KON0_l0000:ok>igP;o000000?o]kcMo`000?ni_]h03Oni_]h00ol0003o^/3Ook[0g`0<ok[0g`03
o`000?oooooooooo077ooooo000Uooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool2o`0000co
Z[cW00?o0000ojVjiOnY^^D02_nY^^D00ol0003oZKOSojVgh`0:ojVgh`03o`000?nY]N7oZKGQ00Co
ZKGQ0ol00002ojBch`03o`000?nU/^7oYK;Q00[oYK;Q00?o0000ojJah?nV/N002OnV/N000ol0003o
Z;7OojRag`0:ojRag`03o`000?nY/MkoZK7N00_oZK7N00?o0000ojZbg_l000000_l00008ojbdgP03
o`000?n_]Mko[kGN00[o[kGN00?o0000ok6gg_na]mh02ona]mh00ol0003o/kWNok>igP06ok>igP;o
00001?ng_=d00ol0003o^KkNokVngP0<okVngP03o`000?nj`=oo^/3O00co^/3O00?o0000oooooooo
ool0L?ooool002Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03o`000?oooooo000000co
Z[cW00?o0000ojVjiOnY^^D02_nY^^D00ol0003oZKOSojVgh`0:ojVgh`03o`000?nY]N7oZKGQ00?o
00001_nT/n<00ol0003oYK;QojFbh@09ojFbh@03o`000?nV/N3oY[7P00[oY[7P00?o0000ojRagonX
/Ml02_nX/Ml00ol0003oZK7NojVagP0:ojVagP;o00002on/]=h00ol0003o[kGNojnegP0;ojnegP03
o`000?na]mko/KON00[o/KON0_l00006ok>igP03o`000?ng_=go]kcM00Go]kcM00?o0000okVng_ni
_]h02oni_]h00ol0003o^/3Ook[0g`0<ok[0g`;o0000LOooool002Gooooo00Go410@oooooooooooo
oooooa0@4007ooooo`04o`000?ooooooooooo`0000coZ[cW00?o0000ojVjiOnY^^D02OnY^^D00ol0
003oZKOSojVgh`0:ojVgh`?o00002_nT/n<00ol0003oYK;QojFbh@09ojFbh@03o`000?nV/N3oY[7P
00[oY[7P00?o0000ojRagonX/Ml02_nX/Ml00ol0003oZK7NojVagP06ojVagP?o000000?oZ[;Oo`00
0?n/]=h02on/]=h00ol0003o[kGNojnegP0;ojnegP03o`000?na]mko/KON00Wo/KON0_l00004ok>i
gP;o00002Ong_=d00ol0003o^KkNokVngP0;okVngP03o`000?nj`=oo^/3O00Wo^/3O0_l000000onm
`]go0000ooooo`1`ooooo`009Oooool01Ol0003ooooooooooooooooo000000Kooooo0_l00003oooo
o`03o`000?nZ_>OoZ[cW00[oZ[cW00?o0000ojVjiOnY^^D02OnY^^D00ol0003oZKOSojVgh`06ojVg
h`?o000000?oXkGUo`000?nT/n<02onT/n<00ol0003oYK;QojFbh@09ojFbh@03o`000?nV/N3oY[7P
00WoY[7P00?o0000ojRagonX/Ml02_nX/Ml00ol0003oZK7NojVagP03ojVagP?o00001OnZ/]l00ol0
003o[;CNojbdgP0:ojbdgP03o`000?n_]Mko[kGN00[o[kGN00?o0000ok6gg_na]mh02Ona]mh01?l0
003o/KONo`000?nc^Mh2o`0000_o]kcM00?o0000okVng_ni_]h03?ni_]h00ol0003o^/3Ook[0g`06
ok[0g`;o00001?nm`]d00ol0003oooooooooo`1^ooooo`009Oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool00oooool00ol0003oZ[cWojZli`0:ojZli`03o`000?nY^^Go
ZK[U00WoZK[U00?o0000ojVghonY]n<00onY]n<2o`0000GoXkGU00?o0000ojBchonT/n<02OnT/n<0
0ol0003oYK;QojFbh@0:ojFbh@03o`000?nV/N3oY[7P00WoY[7P00?o0000ojRagonX/Ml02_nX/Ml0
0ol0003oZK7No`000002o`0000WoZ[;O00?o0000ojbdg_n/]=h02_n/]=h00ol0003o[kGNojnegP0:
ojnegP03o`000?na]mko/KON00So/KON00Co0000ok6gg_l0003o00003_ng_=d00ol0003o^KkNokVn
gP0;okVngP03o`000?nj`=oo^/3O00Go^/3O00?o0000okg2gOnm`]d01Onm`]d00ol0003ooooooooo
o`1]ooooo`009Oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool01?oo
ool00ol0003oZ[cWojZli`0:ojZli`03o`000?nY^^GoZK[U00WoZK[U00?o0000ojVghol000000_l0
0008oj>ei@03o`000?nT/n?oY;?S00WoY;?S00?o0000ojFbhOnU/^402OnU/^400ol0003oY[7PojJa
h00:ojJah003o`000?nX/MooZ;7O00WoZ;7O0_l0000<ojZbg`03o`000?n/]=ko[;CN00[o[;CN00?o
0000ojneg_n_]Mh02on_]Mh00ol0003o/KONok6ggP07ok6ggP;o000000?o];[Mo`000?ng_=d03_ng
_=d00ol0003o^KkNokVngP0;okVngP03o`000?nj`=oo^/3O00;o^/3O0_l00008okg2g@;o0000K_oo
ool002Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ojZlionZ_>L02_nZ_>L00ol0003oZK[UojVji@08ojVji@;o00003?nS]ND00ol0003oY;?SojBc
h`09ojBch`03o`000?nU/^7oYK;Q00WoYK;Q00?o0000ojJah?nV/N002_nV/N000ol0003oZ;7OojRa
g`05ojRag`?o000000?oYk;Po`000?nZ/]l03?nZ/]l00ol0003o[;CNojbdgP0:ojbdgP03o`000?n_
]Mko[kGN00_o[kGN00?o0000ok6gg_na]mh01?na]mh3o`0000?o];[M00?o0000okNlgOng_=d03Ong
_=d00ol0003o^KkNokVngP0;okVngP04o`000?nj`=oo0000o`0000_o_L;M00?o0000ooooooooool0
K?ooool002Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ojZlionZ_>L02_nZ_>L00ol0003oZK[UojVji@04ojVji@?o000000?oXkSXo`000?nS]ND0
3?nS]ND00ol0003oY;?SojBch`09ojBch`03o`000?nU/^7oYK;Q00WoYK;Q00?o0000ojJah?nV/N00
2OnV/N000ol0003oZ;7OojRag`03ojRag`;o00001OnW/^000ol0003oZ[;OojZbg`0;ojZbg`03o`00
0?n/]=ko[;CN00[o[;CN00?o0000ojneg_n_]Mh02_n_]Mh00ol0003o/KONok6ggP02ok6ggP;o0000
0_nd^]d00ol0003o];[MokBjg@02okBjg@03o`000?ng_=go]kcM00co]kcM00?o0000okVng_ni_]h0
2oni_]h2o`0000ko_L;M00?o0000ooooooooool0Joooool0033ooooo00?o0000ooooooooool01ooo
ool00ol0003oZ[cWojZli`0:ojZli`03o`000?nY^^GoZK[U00?o00001OnS^>P00ol0003oXkGUoj>e
i@0:oj>ei@03o`000?nT/n?oY;?S00WoY;?S00?o0000ojFbhOnU/^402_nU/^400ol0003oY[7PojJa
h009ojJah003o`000?nX/Moo000000;o00002?nW/^000ol0003oZ[;OojZbg`0:ojZbg`03o`000?n/
]=ko[;CN00[o[;CN00?o0000ojneg_n_]Mh02on_]Mh01?l0003o/KONo`000?l00004okBjg@03o`00
0?nd^]go];[M00?o];[M00?o0000okNlgOng_=d03?ng_=d00ol0003o^KkNokVngP08okVngP;o0000
00?o_<3Mo`000?nm`]d03_nm`]d00ol0003oooooooooo`1Zooooo`00<?ooool00ol0003ooooooooo
o`08ooooo`03o`000?nZ_>OoZ[cW00SoZ[cW1?l00009oj>hj003o`000?nS]NGoXkGU00[oXkGU00?o
0000ojBchonT/n<02OnT/n<00ol0003oYK;QojFbh@09ojFbh@03o`000?nV/N3oY[7P00SoY[7P0ol0
000;ojNbh003o`000?nZ/]ooZ[;O00_oZ[;O00?o0000ojbdg_n/]=h02_n/]=h00ol0003o[kGNojne
gP0:ojnegP;o00001_nd^]d00ol0003o];[MokBjg@04okBjg@03o`000?ng_=go]kcM00co]kcM00?o
0000okVng_ni_]h01_ni_]h00ol0003o_<3Mokc0g@02okc0g@03o`000?nm`]go_L;M00co_L;M00?o
0000ooooooooool0J_ooool002oooooo0_l0000;ooooo`03o`000?nZ_>OoZ[cW00CoZ[cW0ol00002
oj:jjP03o`000?nS^>SoXkSX00WoXkSX00?o0000oj>eiOnS]ND02_nS]ND00ol0003oY;?SojBch`09
ojBch`03o`000?nU/^7oYK;Q00WoYK;Q00?o0000ojJah?nV/N001?nV/N03o`0000;oY;7Q00?o0000
ojNbh?nW/^002_nW/^000ol0003oZ[;OojZbg`0;ojZbg`03o`000?n/]=ko[;CN00[o[;CN00?o0000
ojneg_n_]Mh01on_]Mh2o`000003ok:hg_l0003o];[M00Go];[M00?o0000okBjgOnd^]d01?nd^]d0
0ol0003o]kcMokNlg@0<okNlg@03o`000?ni_]ko^KkN00Co^KkN0_l00006okc0g@03o`000?nm`]go
_L;M00co_L;M00?o0000ooooooooool0JOooool0033ooooo00?o0000ooooooooool02_ooool00ol0
003oZ[cWojZli`03o`0000KoX[[Z00?o0000oj>hj?nS^>P02OnS^>P00ol0003oXkGUoj>ei@0:oj>e
i@03o`000?nT/n?oY;?S00WoY;?S00?o0000ojFbhOnU/^402OnU/^400ol0003oY[7PojJah003o`00
00KoY;7Q00?o0000ojNbh?nW/^002_nW/^000ol0003oZ[;OojZbg`0:ojZbg`03o`000?n/]=ko[;CN
00_o[;CN00?o0000ojneg_n_]Mh01?n_]Mh2o`0000Co/[SN00?o0000okBjgOnd^]d00ond^]d00ol0
003o];[MokBjg@05okBjg@03o`000?ng_=go]kcM00co]kcM00Co0000okVng_ni_]ko^KkN0_l00009
okc0g@03o`000?nm`]go_L;M00co_L;M00?o0000ooooooooool0J?ooool002oooooo00?o0000oooo
ooooool03?ooool2o`0000[oX[[Z00?o0000oj>hj?nS^>P02OnS^>P00ol0003oXkGUoj>ei@0:oj>e
i@03o`000?nT/n?oY;?S00SoY;?S00?o0000ojFbhOnU/^402?nU/^44o`0000[oY;7Q00?o0000ojNb
h?nW/^002_nW/^000ol0003oZ[;OojZbg`0:ojZbg`03o`000?n/]=ko[;CN00[o[;CN00?o0000ojne
g_n_]Mh00_n_]Mh2o`0000Oo/[SN00?o0000okBjgOnd^]d00_nd^]d00ol0003o];[MokBjg@06okBj
g@03o`000?ng_=go]kcM00co]kcM00?o0000okVng_l000003?nl`=d00ol0003o_L;Mokg2g@0<okg2
g@03o`000?oooooooooo06Oooooo000_ooooo`03o`000?oooooooooo00gooooo00?o0000oj:jj_nR
^^X02OnR^^X00ol0003oXkSXoj>hj009oj>hj003o`000?nS]NGoXkGU00[oXkGU00?o0000ojBchonT
/n<02?nT/n<00ol0003oYK;QojFbh@04ojFbh@?o00000_nR/^<00ol0003oY;7QojBah@09ojBah@03
o`000?nW/^3oYk;P00[oYk;P00?o0000ojZbgonZ/]l02_nZ/]l00ol0003o[;CNojbdgP0;ojbdgP04
o`000?n_]Mko0000o`0000Wo/[SN00?o0000okBjgOnd^]d00_nd^]d00ol0003o];[MokBjg@07okBj
g@03o`000?ng_=go]kcM00_o]kcM0_l0000=okc0g@03o`000?nm`]go_L;M00co_L;M00?o0000oooo
ooooool0Ioooool002oooooo00?o0000ooooooooool03_ooool00ol0003oX[[Zoj:jjP09oj:jjP03
o`000?nS^>SoXkSX00WoXkSX00?o0000oj>eiOnS]ND02OnS]ND00ol0003oY;?SojBch`09ojBch`03
o`000?nU/^7oYK;Q00?o00001_nR/^<00ol0003oY;7QojBah@09ojBah@03o`000?nW/^3oYk;P00[o
Yk;P00?o0000ojZbgonZ/]l02_nZ/]l00ol0003o[;CNojbdgP0:ojbdgP;o00003?nb^=h01Ol0003o
];[MokBjgOnd^]go000000[o];[M00?o0000okNlgOng_=d02?ng_=d2o`000003okZngOl0003o_<3M
00go_<3M00?o0000okg2gOnm`]d03?nm`]d00ol0003oooooooooo`1Vooooo`00;oooool00ol0003o
ooooooooo`0?ooooo`03o`000?nR^^[oX[[Z00WoX[[Z00?o0000oj>hj?nS^>P02?nS^>P00ol0003o
XkGUoj>ei@0:oj>ei@03o`000?nT/n?oY;?S00SoY;?S0ol0000:oj:bh`03o`000?nT/N7oY;7Q00Wo
Y;7Q00?o0000ojNbh?nW/^002_nW/^000ol0003oZ[;OojZbg`0:ojZbg`03o`000?n/]=ko[;CN00Ko
[;CN0ol000000on^]]ko0000ok:hgP0<ok:hgP04o`000?nd^]go];[Mo`0000[o];[M00?o0000okNl
gOng_=d01ong_=d00ol0003o^[kMokZng@02okZng@03o`000?nl`=go_<3M00co_<3M00?o0000okg2
gOnm`]d02onm`]d2o`0006Oooooo000^ooooo`?o00004Oooool00ol0003oX[[Zoj:jjP09oj:jjP03
o`000?nS^>SoXkSX00SoXkSX00?o0000oj>eiOnS]ND02_nS]ND00ol0003oY;?SojBch`04ojBch`?o
000000?oWk;Uo`000?nR/^<02_nR/^<00ol0003oY;7QojBah@0:ojBah@03o`000?nW/^3oYk;P00Wo
Yk;P00?o0000ojZbgonZ/]l02_nZ/]l00ol0003o[;CNojbdgP03ojbdgP?o00001On^]]h00ol0003o
/[SNok:hgP0:ok:hgP04o`000?nd^]go];[Mo`0000_o];[M00?o0000okNlgOng_=d01?ng_=d2o`00
00Ko^[kM00?o0000okc0gOnl`=d03?nl`=d00ol0003o_L;Mokg2g@08okg2g@;o000000?o`<?Lo`00
0?l00000I_ooool002oooooo00?o0000ooooooooool04Oooool00ol0003oX[[Zoj:jjP08oj:jjP03
o`000?nS^>SoXkSX00WoXkSX00?o0000oj>eiOnS]ND02_nS]ND00ol0003oY;?SojBch`03o`0000Go
Wk;U00?o0000oj:bhonR/^<02OnR/^<00ol0003oY;7QojBah@09ojBah@03o`000?nW/^3oYk;P00[o
Yk;P00?o0000ojZbgonZ/]l02_nZ/]l00ol0003o[;CNo`000002o`0000Wo[[KN00?o0000ok:hg_nb
^=h02_nb^=h00ol0003o];[Mo`00000<okBjg@04o`000?ng_=go]kcMokNlg@;o00002Onj_]d00ol0
003o_<3Mokc0g@0;okc0g@03o`000?nm`]go_L;M00Oo_L;M00?o0000ol33g?o0`m`00_o0`m`00ol0
003oooooooooo`1Tooooo`00;oooool00ol0003oooooooooo`0Booooo`03o`000?nR^^[oX[[Z00So
X[[Z00?o0000oj>hj?nS^>P02OnS^>P00ol0003oXkGUoj>ei@08oj>ei@Co00002OnO/^D00ol0003o
X[;Soj:bh`09oj:bh`03o`000?nT/N7oY;7Q00WoY;7Q00?o0000ojNbh?nW/^002_nW/^000ol0003o
Z[;OojZbg`09ojZbg`;o00003?n^]]h00ol0003o/[SNok:hgP0;ok:hgP;o00003Ond^]d00ol0003o
]kcMo`00000;okZng@03o`000?nl`=go_<3M00co_<3M00?o0000okg2gOnm`]d01?nm`]d2o`0000Ko
`<?L00?o0000ooooooooool0Hoooool002oooooo00?o0000ooooooooool04oooool00ol0003oX[[Z
oj:jjP08oj:jjP03o`000?nS^>SoXkSX00WoXkSX00?o0000oj>eiOnS]ND01?nS]ND3o`0000;oWK?X
00?o0000oinbiOnO/^D02OnO/^D00ol0003oX[;Soj:bh`09oj:bh`03o`000?nT/N7oY;7Q00WoY;7Q
00?o0000ojNbh?nW/^002_nW/^000ol0003oZ[;OojZbg`05ojZbg`?o000000?oZkCPo`000?n^]]h0
3?n^]]h00ol0003o/[SNok:hgP0;ok:hgP03o`000?nd^]go];[M00_o];[M0_l0000=okZng@03o`00
0?nl`=go_<3M00co_<3M00Co0000okg2gOnm`]go_L;M0_l00009ol33g003o`000?oooooooooo06;o
oooo000_ooooo`03o`000?oooooooooo01?ooooo0_l0000:oj:jjP03o`000?nS^>SoXkSX00WoXkSX
00?o0000oj>eiOnS]ND00ol00006oifcj003o`000?nO/^GoWk;U00WoWk;U00?o0000oj:bhonR/^<0
2?nR/^<00ol0003oY;7QojBah@09ojBah@03o`000?nW/^3oYk;P00[oYk;P00?o0000ojZbgonZ/]l0
0onZ/]l2o`0000GoZkCP00?o0000ojjfg_n^]]h02on^]]h00ol0003o/[SNok:hgP0:ok:hgP03o`00
0?nd^]go];[M00Wo];[M0_l000000onh_=go0000okZng@0=okZng@03o`000?nl`=go_<3M00co_<3M
00?o0000okg2gOl000002oo0`m`2o`0006?ooooo000^ooooo`03o`000?oooooooooo01Gooooo0_l0
000:oj:jjP03o`000?nS^>SoXkSX00OoXkSX1?l0000:oifcj003o`000?nO/^GoWk;U00SoWk;U00?o
0000oj:bhonR/^<02OnR/^<00ol0003oY;7QojBah@09ojBah@03o`000?nW/^3oYk;P00[oYk;P00?o
0000ojZbgol000000_l00008oj^dh003o`000?n^]]ko[[KN00[o[[KN00?o0000ok:hg_nb^=h02_nb
^=h2o`0000So];[M0_l00004okRlg@03o`000?nj_]go^[kM00co^[kM00?o0000okc0gOnl`=d02onl
`=d2o`0000go`<?L00?o0000ooooooooool0HOooool002kooooo0ol0000Fooooo`;o00002_nR^^X0
1?l0003oXkSXoj>hj?nS^>P5o`0000;oVkGZ00?o0000oifcj?nM/nP02_nM/nP00ol0003oWk;Uoinb
i@08oinbi@03o`000?nR/^?oX[;S00WoX[;S00?o0000ojBahOnT/N402OnT/N400ol0003oYk;PojNb
h009ojNbh0;o00003?n[]>000ol0003o[[KNojjfgP0:ojjfgP03o`000?nb^=ko/[SN00Wo/[SN00?o
0000ok:hg_l000001_nd^]d00ol0003o^;cMokRlg@05okRlg@03o`000?nj_]go^[kM00_o^[kM00?o
0000okc0gOnl`=d02_nl`=d00ol0003o_l;Lo`00000>ol33g003o`000?oooooooooo063ooooo000^
ooooo`03o`000?oooooooooo01Oooooo0_l00008oj:jjPGo00002?nK]NX00ol0003oWK?Xoifcj00:
oifcj003o`000?nO/^GoWk;U00SoWk;U00?o0000oj:bhonR/^<02?nR/^<00ol0003oY;7QojBah@0:
ojBah@03o`000?nW/^3oYk;P00GoYk;P0ol000000onW/n7o0000oj^dh00;oj^dh003o`000?n^]]ko
[[KN00_o[[KN00?o0000ok:hg_nb^=h02?nb^=h00ol0003o/[SNo`000004okBjg@;o00002?nh_=d0
0ol0003o^[kMokZng@0<okZng@03o`000?nl`=go_<3M00Oo_<3M0_l00003oko2g003o`000?o0`mco
`<?L00co`<?L00?o0000ooooooooool0Goooool001;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool5o`0000Oooooo00?o0000ooooooooool06?ooool2o`0000;oX[[Z1Ol00002
oiZhk003o`000?nK]N[oVkGZ00WoVkGZ00?o0000oifcj?nM/nP02OnM/nP00ol0003oWk;Uoinbi@09
oinbi@03o`000?nR/^?oX[;S00SoX[;S00?o0000ojBahOnT/N402OnT/N400ol0003oYk;PojNbh003
ojNbh0;o00001OnW/n400ol0003oZkCPoj^dh00:oj^dh003o`000?n^]]ko[[KN00_o[[KN00?o0000
ok:hg_nb^=h01onb^=h01Ol0003o/[SNok:hg_l0003o];[M00;o00002onh_=d00ol0003o^[kMokZn
g@0<okZng@03o`000?nl`=go_<3M00Go_<3M00?o0000oko2g?no`]`01?no`]`00ol0003o`<?Lol33
g00<ol33g003o`000?oooooooooo05kooooo000Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03o`000?oooooooooo01Wooooo
0ol00008oiZhk003o`000?nK]N[oVkGZ00WoVkGZ00?o0000oifcj?nM/nP02OnM/nP00ol0003oWk;U
oinbi@09oinbi@03o`000?nR/^?oX[;S00SoX[;S00?o0000ojBahOnT/N402OnT/N400ol0003oYk;P
o`000002o`0000SoYk?Q00?o0000oj^dh?n[]>002_n[]>000ol0003o[[KNojjfgP0:ojjfgP03o`00
0?nb^=ko/[SN00Oo/[SN00?o0000ok:hg_nb^=h00_l0000>okRlg@03o`000?nj_]go^[kM00_o^[kM
00?o0000okc0gOnl`=d01?nl`=d00ol0003o_l;Loko2g006oko2g003o`000?o0`mco`<?L00_o`<?L
00?o0000ooooooooool0G_ooool001;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Sooooo00?o0000ooooooooool06_ooool00ol0003oV[S/oiZhk008oiZhk003o`00
0?nK]N[oVkGZ00WoVkGZ00?o0000oifcj?nM/nP02OnM/nP00ol0003oWk;Uoinbi@09oinbi@03o`00
0?nR/^?oX[;S00SoX[;S00?o0000ojBahOnT/N401onT/N43o`0000coYk?Q00?o0000oj^dh?n[]>00
2_n[]>000ol0003o[[KNojjfgP0:ojjfgP03o`000?nb^=ko/[SN00Ko/[SN0ol000000ond^]ko0000
okRlg@0=okRlg@03o`000?nj_]go^[kM00co^[kM00Co0000okc0gOnl`=go_<3M0_l00009oko2g003
o`000?o0`mco`<?L00co`<?L00?o0000ooooooooool0GOooool001;ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool06oooool00ol0003o
V[S/oiZhk008oiZhk003o`000?nK]N[oVkGZ00WoVkGZ00?o0000oifcj?nM/nP02OnM/nP00ol0003o
Wk;Uoinbi@08oinbi@03o`000?nR/^?oX[;S00SoX[;S00?o0000ojBahOnT/N401?nT/N43o`0000;o
Xk;S00?o0000ojNchOnW/n402_nW/n400ol0003oZkCPoj^dh00:oj^dh003o`000?n^]]ko[[KN00_o
[[KN00?o0000ok:hg_nb^=h01?nb^=h2o`0000Co];[N00?o0000okRlgOnh_=d03?nh_=d00ol0003o
^[kMokZng@0<okZng@03o`000?nl`=go000000co_l;L00?o0000ol33g?o0`m`03?o0`m`00ol0003o
ooooooooo`1Looooo`004_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool01_ooool00ol0003oooooooooo`0Looooo`03o`000?nJ^>coV[S/00SoV[S/00?o0000oi^ej_nK
]NX02OnK]NX00ol0003oWK?Xoifcj009oifcj003o`000?nO/^GoWk;U00SoWk;U00?o0000oj:bhonR
/^<02?nR/^<00ol0003oY;7QojBah@03o`0000KoXk;S00?o0000ojNchOnW/n402_nW/n400ol0003o
ZkCPoj^dh00:oj^dh003o`000?n^]]ko[[KN00[o[[KN00?o0000ok:hg_nb^=h00_nb^=h2o`000003
okBjg_l0003o];[N00Co];[N00?o0000okRlgOnh_=d03?nh_=d00ol0003o^[kMokZng@0;okZng@;o
00003_no`]`00ol0003o`<?Lol33g00;ol33g0;o0000GOooool001;ooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00Cooooo0_l0000Oooooo`03o`000?nJ^>coV[S/00So
V[S/00?o0000oi^ej_nK]NX02?nK]NX00ol0003oWK?Xoifcj009oifcj003o`000?nO/^GoWk;U00Wo
Wk;U00?o0000oj:bhonR/^<01_nR/^<4o`0000[oXk;S00?o0000ojNchOnW/n402_nW/n400ol0003o
ZkCPoj^dh00:oj^dh003o`000?n^]]ko[[KN00[o[[KN00Co0000ok:hg_l0003o00000ond^]h00ol0
003o];[NokBjgP04okBjgP03o`000?nh_=go^;cM00_o^;cM00?o0000okZngOnj_]d02Onj_]d2o`00
0003okg1gOl0003o_l;L00go_l;L00?o0000ol33g?o0`m`02_o0`m`00ol0003o`/CLo`00001Moooo
o`004_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006
ooooo`03o`000?oooooooooo01oooooo00?o0000oiZhk?nJ^>`02?nJ^>`00ol0003oVkGZoi^ejP08
oi^ejP03o`000?nM/nSoWK?X00WoWK?X00?o0000oinbiOnO/^D02OnO/^D00ol0003oX[;Soj:bh`05
o`0000;oW[;U00?o0000oj>bhonS/^<02_nS/^<00ol0003oYk?QojNch@0:ojNch@03o`000?n[]>3o
ZkCP00[oZkCP00?o0000ojjfg_n^]]h02On^]]h2o`0000Go];[N00?o0000okBjg_nd^]h01Ond^]h0
0ol0003o^;cMokRlg@0;okRlg@03o`000?nj_]go^[kM00Ko^[kM0_l00004okg1g@03o`000?no`]co
_l;L00co_l;L00?o0000ol33g?o0`m`01oo0`m`2o`0000?o`/CL00?o0000ooooooooool0F_ooool0
01;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_oo
ool00ol0003oooooooooo`0Pooooo`03o`000?nJ^>coV[S/00SoV[S/00?o0000oi^ej_nK]NX02?nK
]NX00ol0003oWK?Xoifcj009oifcj003o`000?nO/^GoWk;U00OoWk;U1?l00008oijbi@03o`000?nS
/^?oXk;S00[oXk;S00?o0000ojNchOnW/n402OnW/n400ol0003oZkCPoj^dh00:oj^dh003o`000?n^
]]ko[[KN00Ko[[KN0ol000000on`^Moo0000okBjgP04okBjgP03o`000?nd^]ko];[N00Go];[N00?o
0000okRlgOnh_=d03?nh_=d00ol0003o^[kMokZng@04okZng@03o`000?nm`Mgo_L7M00Go_L7M00?o
0000oko2g?no`]`03?no`]`00ol0003o`<?Lol33g005ol33g003o`000?o2a=co`/CL00Co`/CL00?o
0000ooooooooool0FOooool002gooooo00?o0000ooooooooool08Oooool00ol0003oV[S/oiZhk008
oiZhk003o`000?nK]N[oVkGZ00SoVkGZ00?o0000oifcj?nM/nP02OnM/nP01?l0003oWk;UoinbiOnO
/^D5o`0000;oV[;X00?o0000oijbiOnN/^D02?nN/^D00ol0003oXk;Soj>bh`09oj>bh`03o`000?nW
/n7oYk?Q00[oYk?Q00?o0000oj^dh?n[]>002_n[]>000ol0003o[[KNojjfgP03ojjfgP;o00001On`
^Ml00ol0003o];[NokBjgP02okBjgP03o`000?nd^]ko];[N00Ko];[N00?o0000okRlgOnh_=d02onh
_=d00ol0003o^[kMokZng@02okZng@;o00002Onm`Md00ol0003o_l;Loko2g00<oko2g003o`000?o0
`mco`<?L00?o`<?L00?o0000ol;4g?o2a=`01_o2a=`00ol0003oooooooooo`1Hooooo`00;Oooool0
0ol0003oooooooooo`0Qooooo`03o`000?nJ^>coV[S/00WoV[S/00?o0000oi^ej_nK]NX02?nK]NX0
0ol0003oWK?Xoifcj007oifcj0Go00002?nJ/^P00ol0003oW[;Uoijbi@08oijbi@03o`000?nS/^?o
Xk;S00WoXk;S00?o0000ojNchOnW/n402_nW/n400ol0003oZkCPoj^dh00:oj^dh003o`000?n^]]ko
000000;o00002?n`^Ml01Ol0003o];[NokBjg_nd^]ko000000Wo];[N00?o0000okRlgOnh_=d02onh
_=d01?l0003o^[kMo`000?l0000;okg1g@03o`000?no`]co_l;L00co_l;L00Co0000ol33g?o0`mco
`<?L0_l00009ol;4g003o`000?oooooooooo05Sooooo000]ooooo`03o`000?oooooooooo02;ooooo
00?o0000oiZhk?nJ^>`02OnJ^>`00ol0003oVkGZoi^ejP08oi^ejP04o`000?nM/nSoWK?Xoifcj0Go
00000_nG/^X00ol0003oV[;XoiZbj009oiZbj003o`000?nN/^GoW[;U00SoW[;U00?o0000oj>bhonS
/^<02OnS/^<00ol0003oYk?QojNch@0:ojNch@03o`000?n[]>3oZkCP00WoZkCP0_l0000<ok2ig`04
o`000?nd^]ko];[No`0000[o];[N00?o0000okRlgOnh_=d02_nh_=d2o`0000ko_L7M00?o0000oko2
g?no`]`03?no`]`00ol0003o`<?Lo`00000<ol;4g003o`000?oooooooooo05Oooooo000/ooooo`?o
00009?ooool00ol0003oV[S/oiZhk009oiZhk003o`000?nK]N[oVkGZ00KoVkGZ1Ol00008oiNbjP03
o`000?nJ/^SoV[;X00WoV[;X00?o0000oijbiOnN/^D01onN/^D00ol0003oXk;Soj>bh`0:oj>bh`03
o`000?nW/n7oYk?Q00WoYk?Q00?o0000oj^dh?n[]>001_n[]>03o`000003ojbghOl0003o/;WO00co
/;WO00?o0000okBjg_l000002_nd^]h00ol0003o^;cMokRlg@08okRlg@;o000000?o^[oNo`000?nm
`Md03_nm`Md00ol0003o_l;Loko2g00;oko2g0;o00003_o2a=`00ol0003oooooooooo`1Fooooo`00
;Oooool00ol0003oooooooooo`0Tooooo`03o`000?nJ^>coV[S/00WoV[S/00?o0000oi^ej_nK]NX0
1Ol00002oiBck003o`000?nG/^[oUk;Z00WoUk;Z00?o0000oiZbj?nJ/^P02?nJ/^P00ol0003oW[;U
oijbi@08oijbi@03o`000?nS/^?oXk;S00[oXk;S00?o0000ojNchOnW/n402OnW/n400ol0003oZkCP
oj^dh003oj^dh0;o00001On/]n400ol0003o/;WOok2ig`0:ok2ig`03o`000?nd^]ko000000_o];[N
00?o0000okRlgOnh_=d01Onh_=d2o`0000Co^[oN00?o0000okg1gOnm`Md03Onm`Md00ol0003o_l;L
oko2g008oko2g0;o000000?o`L?Lo`000?o2a=`03_o2a=`00ol0003oooooooooo`1Eooooo`00;Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?nJ^>coV[S/00OoV[S/1?l00008oiBck003o`000?nG
/^[oUk;Z00WoUk;Z00?o0000oiZbj?nJ/^P02?nJ/^P00ol0003oW[;Uoijbi@08oijbi@03o`000?nS
/^?oXk;S00WoXk;S00?o0000ojNchOnW/n402_nW/n400ol0003oZkCPo`000002o`0000So[;OQ00?o
0000ok2igon`^Ml02_n`^Ml2o`0000co];[N00?o0000okRlgOnh_=d00_nh_=d2o`0000Oo^[oN00?o
0000okg1gOnm`Md03Onm`Md00ol0003o_l;Loko2g006oko2g003o`000?o1`mco`L?L00;o`L?L00?o
0000ol;4g?o2a=`03?o2a=`2o`0005Kooooo000]ooooo`03o`000?oooooooooo02Kooooo00Co0000
oiZhk?nJ^>coV[S/1Ol00002oi:dkP03o`000?nD/ncoU;?/00SoU;?/00?o0000oiNbj_nG/^X02OnG
/^X00ol0003oV[;XoiZbj008oiZbj003o`000?nN/^GoW[;U00SoW[;U00?o0000oj>bhonS/^<02OnS
/^<00ol0003oYk?QojNch@08ojNch@?o00003?n/]n400ol0003o/;WOok2ig`0:ok2ig`03o`000?nd
^]ko];[N00_o];[N00Co0000okRlgOl0003o00002_nj_mh00ol0003o_L7Mokg1g@0<okg1g@03o`00
0?no`]co_l;L00Co_l;L0_l00006ol73g003o`000?o2a=co`/CL00co`/CL00?o0000ooooooooool0
E?ooool002cooooo00?o0000ooooooooool0:?ooool3o`0000SoT[C^00?o0000oiBck?nD/n`02?nD
/n`00ol0003oUk;ZoiNbjP08oiNbjP03o`000?nJ/^SoV[;X00WoV[;X00?o0000oijbiOnN/^D02?nN
/^D00ol0003oXk;Soj>bh`09oj>bh`03o`000?nW/n7oYk?Q00CoYk?Q0ol00002ojJeh`03o`000?n/
]n7o[;OQ00[o[;OQ00?o0000ok2igon`^Ml02_n`^Ml2o`0000co];[N0_l0000=okZogP03o`000?nm
`Mgo_L7M00co_L7M00Co0000oko2g?no`]co_l;L0_l00009ol73g003o`000?o2a=co`/CL00co`/CL
00?o0000ooooooooool0Doooool002cooooo00?o0000ooooooooool0:Oooool00ol0003oT[C^oi:d
kP08oi:dkP03o`000?nD/ncoU;?/00SoU;?/00?o0000oiNbj_nG/^X02?nG/^X00ol0003oV[;XoiZb
j008oiZbj003o`000?nN/^GoW[;U00SoW[;U00?o0000oj>bhonS/^<02_nS/^<00ol0003oYk?QojNc
h@03o`0000KoY[GS00?o0000ojbghOn/]n402_n/]n400ol0003o/;WOok2ig`09ok2ig`;o00002_nd
^]h2o`000003okJmgol0003o^[oN00co^[oN00?o0000okg1gOnm`Md03Onm`Md00ol0003o_l;Lo`00
000;ol73g003o`000?o2a=co`/CL00go`/CL00?o0000ooooooooool0D_ooool002cooooo0_l0000[
ooooo`03o`000?nB]>koT[C^00SoT[C^00?o0000oiBck?nD/n`02?nD/n`00ol0003oUk;ZoiNbjP08
oiNbjP03o`000?nJ/^SoV[;X00SoV[;X00?o0000oijbiOnN/^D02?nN/^D00ol0003oXk;Soj>bh`08
oj>bh`Co00002_nV]N<00ol0003o[;OQojbgh@0:ojbgh@03o`000?n`^Moo/;WO00So/;WO00?o0000
ok2igol000001ond^]h2o`0000Co][gO00?o0000okZog_nj_mh02onj_mh00ol0003o_L7Mokg1g@0<
okg1g@;o00003Oo1`m`00ol0003o`/CLol;4g00<ol;4g0;o0000Doooool002cooooo00?o0000oooo
ooooool0:oooool00ol0003oT[C^oi:dkP08oi:dkP03o`000?nD/ncoU;?/00SoU;?/00?o0000oiNb
j_nG/^X02?nG/^X00ol0003oV[;XoiZbj008oiZbj003o`000?nN/^GoW[;U00SoW[;U00?o0000oj>b
honS/^<01?nS/^<3o`0000;oXKCV00?o0000ojJehonV]N<02_nV]N<00ol0003o[;OQojbgh@0:ojbg
h@03o`000?n`^Moo/;WO00Oo/;WO00Co0000ok2igon`^Moo00001?nd^]h2o`0000Oo][gO00?o0000
okZog_nj_mh02onj_mh00ol0003o_L7Mokg1g@0:okg1g@03o`000?no`mgo000000ko`L?L00?o0000
ol;4g?o2a=`02_o2a=`00ol0003o`lGLo`00001Cooooo`00;?ooool00ol0003oooooooooo`0/oooo
o`03o`000?nB]>koT[C^00SoT[C^00?o0000oiBck?nD/n`01onD/n`00ol0003oUk;ZoiNbjP09oiNb
jP03o`000?nJ/^SoV[;X00OoV[;X00?o0000oijbiOnN/^D02OnN/^D00ol0003oXk;Soj>bh`03o`00
00KoXKCV00?o0000ojJehonV]N<02OnV]N<00ol0003o[;OQojbgh@0:ojbgh@03o`000?n`^Moo/;WO
00Oo/;WO00Ko0000ok2igon`^Moo/;WOo`000?nd^]h2o`0000[o][gO00?o0000okZog_nj_mh02onj
_mh00ol0003o_L7Mokg1g@07okg1g@;o00000ono`md00ol0003o`L?Lol73g00<ol73g003o`000?o2
a=co`/CL00Oo`/CL0_l00003ol?5g003o`000?oooooooooo053ooooo000/ooooo`03o`000?oooooo
oooo02gooooo00?o0000oi:dk_nB]>h02?nB]>h00ol0003oU;?/oiBck007oiBck003o`000?nG/^[o
Uk;Z00SoUk;Z00?o0000oiZbj?nJ/^P02?nJ/^P00ol0003oW[;Uoijbi@07oijbi@Co00002_nQ]>H0
0ol0003oY[GSojJeh`09ojJeh`03o`000?n/]n7o[;OQ00[o[;OQ00?o0000ok2igon`^Ml01_n`^Ml0
1?l0003o/;WOok2igon`^Ml2o`0000go][gO00?o0000okZog_nj_mh02_nj_mh00ol0003o_L7Mokg1
g@06okg1g@03o`000?no`mgo_l?M00Co_l?M00?o0000ol73g?o1`m`03?o1`m`00ol0003o`/CLol;4
g005ol;4g003o`000?o3aMco`lGL00Co`lGL00?o0000ooooooooool0Coooool002cooooo00?o0000
ooooooooool0;_ooool00ol0003oT[C^oi:dkP08oi:dkP03o`000?nD/ncoU;?/00OoU;?/00?o0000
oiNbj_nG/^X02?nG/^X00ol0003oV[;XoiZbj008oiZbj004o`000?nN/^GoW[;Uoijbi@Go00000_nK
/^P00ol0003oXKCVoj6diP0:oj6diP03o`000?nV]N?oY[GS00WoY[GS00?o0000ojbghOn/]n402_n/
]n400ol0003o/;WOok2ig`05ok2ig`06o`000?n`^Moo0000o`000?na^n7o00003Onf_Ml00ol0003o
^[oNokZogP0;okZogP03o`000?nm`Mgo_L7M00Co_L7M00?o0000oko3gOno`md01_no`md00ol0003o
`L?Lol73g00;ol73g003o`000?o2a=co`/CL00Co`/CL00?o0000ol?5g?o3aM`01Oo3aM`2o`00053o
oooo000/ooooo`03o`000?oooooooooo02oooooo00?o0000oi:dk_nB]>h02?nB]>h00ol0003oU;?/
oiBck007oiBck003o`000?nG/^[oUk;Z00SoUk;Z00?o0000oiZbj?nJ/^P01_nJ/^P5o`0000SoVk;X
00?o0000oj6di_nQ]>H02OnQ]>H00ol0003oY[GSojJeh`0:ojJeh`03o`000?n/]n7o[;OQ00Wo[;OQ
00?o0000ok2igon`^Ml01On`^Ml2o`0000Co/K_Q00?o0000okJmgonf_Ml02onf_Ml00ol0003o^[oN
okZogP0;okZogP04o`000?nm`Mgo_L7Mokg1g@;o00002Ono`md00ol0003o`L?Lol73g00<ol73g004
o`000?o2a=co`/CLol;4g0;o00002Oo3aM`00ol0003oooooooooo`1>ooooo`00;?ooool2o`00037o
oooo00?o0000oi:dk_nB]>h02?nB]>h00ol0003oU;?/oiBck007oiBck003o`000?nG/^[oUk;Z00So
Uk;Z00?o0000oiZbj?nJ/^P01Ol00002oiJajP03o`000?nK/^SoVk;X00WoVk;X00?o0000oj6di_nQ
]>H02OnQ]>H00ol0003oY[GSojJeh`09ojJeh`03o`000?n/]n7o[;OQ00[o[;OQ00?o0000ok2igon`
^Ml00_n`^Ml3o`0000Ko/K_Q00?o0000okJmgonf_Ml02onf_Ml00ol0003o^[oNokZogP0;okZogP03
o`000?nm`Mgo000000co_l?M00?o0000ol73g?o1`m`03?o1`m`00ol0003o`/CLo`00000<ol?5g003
o`000?oooooooooo04gooooo000[ooooo`03o`000?oooooooooo03;ooooo00?o0000oi:dk_nB]>h0
2?nB]>h00ol0003oU;?/oiBck007oiBck003o`000?nG/^[oUk;Z00?oUk;Z1ol00008oiJajP03o`00
0?nK/^SoVk;X00WoVk;X00?o0000oj6di_nQ]>H02OnQ]>H00ol0003oY[GSojJeh`09ojJeh`03o`00
0?n/]n7o[;OQ00[o[;OQ00Co0000ok2igol0003o00000_na^n400ol0003o/K_Qok6kh@05ok6kh@03
o`000?nf_Moo][gO00_o][gO00?o0000okZog_nj_mh02_nj_mh2o`0000ko_l?M00?o0000ol73g?o1
`m`02oo1`m`2o`0000ko`lGL00?o0000ooooooooool0C?ooool002_ooooo00?o0000ooooooooool0
<oooool00ol0003oT[C^oi:dkP08oi:dkP03o`000?nD/ncoU;?/00?oU;?/2Ol00005oi6ak003o`00
0?nF/N[oU[7Z00SoU[7Z00?o0000oi^bj?nK/^P02OnK/^P00ol0003oXKCVoj6diP09oj6diP03o`00
0?nV]N?oY[GS00WoY[GS00?o0000ojbghOn/]n402On/]n42o`0000Co/K_Q00?o0000ok6khOna^n40
1_na^n400ol0003o][gOokJmg`0:okJmg`03o`000?nj_mko^[oN00So^[oN0_l000000onl`]ko0000
oko3g@0>oko3g@03o`000?o1`mco`L?L00So`L?L0_l000000oo2aMgo0000ol?5g00=ol?5g0;o0000
COooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@
4?oooooooooo00Cooooo00?o0000ooooooooool0=?ooool00ol0003oT[C^oi:dkP06oi:dkPOo0000
1?n=/Nh00ol0003oTK7/oi6ak008oi6ak003o`000?nF/N[oU[7Z00SoU[7Z00?o0000oi^bj?nK/^P0
2OnK/^P00ol0003oXKCVoj6diP08oj6diP03o`000?nV]N?oY[GS00WoY[GS00?o0000ojbghOn/]n40
1_n/]n43o`000003ojbjhol0003o/K_Q00?o/K_Q00?o0000ok6khOna^n401_na^n400ol0003o][gO
okJmg`0;okJmg`03o`000?nj_mko^[oN00Go^[oN0_l00004okc2gP03o`000?no`mgo_l?M00go_l?M
00?o0000ol73g?o1`m`01_o1`m`00ol0003o`/GMol;5g@02ol;5g@03o`000?o3aMco`lGL00co`lGL
0_l0001<ooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0=Oooool00ol0003oT[C^oi:dkP05o`0000;oR[7`
00?o0000ohfak_n=/Nh01on=/Nh00ol0003oTK7/oi6ak008oi6ak003o`000?nF/N[oU[7Z00SoU[7Z
00?o0000oi^bj?nK/^P02OnK/^P00ol0003oXKCVoj6diP08oj6diP03o`000?nV]N?oY[GS00WoY[GS
00?o0000ojbghOn/]n400on/]n42o`0000Go[;[S00Go0000ok6khOna^n7o/K_Qo`000009ok6kh@03
o`000?nf_Moo][gO00_o][gO00?o0000okZog_nj_mh00_nj_mh2o`0000Oo_<;N00?o0000oko3gOno
`md03?no`md00ol0003o`L?Lol73g004ol73g0;o00001_o2aMd00ol0003o`lGLol?5g00<ol?5g003
o`000?oooooooooo04[ooooo000@ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Ko
oooo00?o0000ooooooooool0=_ooool2o`0000SoR[7`00?o0000ohfak_n=/Nh01on=/Nh00ol0003o
TK7/oi6ak008oi6ak003o`000?nF/N[oU[7Z00SoU[7Z00?o0000oi^bj?nK/^P02?nK/^P00ol0003o
XKCVoj6diP09oj6diP03o`000?nV]N?oY[GS00WoY[GS00?o0000ojbghOl000000_l00008ojbjh`04
o`000?na^n7o/K_Qo`0000[o/K_Q00?o0000okJmgonf_Ml02onf_Ml01?l0003o^[oNo`000?l0000:
okc2gP03o`000?no`mgo_l?M00co_l?M00Co0000ol73g?o1`mco`L?L0_l00009ol;5g@03o`000?o3
aMco`lGL00co`lGL00?o0000ooooooooool0BOooool0013ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0=oooool00ol0003oR[7`
ohZal007ohZal003o`000?n=/NkoSK7^00OoSK7^00?o0000oi6ak?nA/N`02?nA/N`00ol0003oU[7Z
oiJajP08oiJajP03o`000?nK/^SoVk;X00SoVk;X00?o0000oj6di_nQ]>H02?nQ]>H00ol0003oY[GS
ojJeh`08ojJeh`?o00003?n/^^<00ol0003o/K_Qo`00000;ok6kh@03o`000?nf_Moo][gO00[o][gO
0_l0000<okc2gP03o`000?no`mgo_l?M00go_l?M00?o0000ol73g?l000002oo2aMd00ol0003o`lGL
ol?5g00<ol?5g0;o0000B_ooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0>?ooool00ol0003oR[7`ohZal007ohZal003
o`000?n=/NkoSK7^00OoSK7^00?o0000oi6ak?nA/N`01onA/N`00ol0003oU[7ZoiJajP08oiJajP03
o`000?nK/^SoVk;X00WoVk;X00?o0000oj6di_nQ]>H02?nQ]>H00ol0003oY[GSojJeh`04ojJeh`?o
00000_nV^>H00ol0003o[;[Sojbjh`0;ojbjh`;o00002ona^n400ol0003o][gOokJmg`08okJmg`;o
000000?o^<3Qo`000?nl`]h03?nl`]h00ol0003o_l?Moko3g@0<oko3g@;o00003Oo2aMd00ol0003o
`lGLol?5g00<ol?5g0;o0000BOooool0013ooooo00Go410@oooooooooooooooooa0@400<ooooo`03
ogMgMoo<c<co000000Kooooo0_l0000kooooo`03o`000?n:/O3oR[7`00OoR[7`00?o0000ohfak_n=
/Nh01on=/Nh00ol0003oTK7/oi6ak007oi6ak003o`000?nF/N[oU[7Z00SoU[7Z00?o0000oi^bj?nK
/^P02OnK/^P00ol0003oXKCVoj6diP08oj6diP03o`000?nV]N?oY[GS00?o00001_nV^>H00ol0003o
[;[Sojbjh`0:ojbjh`;o00003?na^n400ol0003o][gOokJmg`05okJmg`;o00001?nh`>400ol0003o
_<;Nokc2gP0;okc2gP03o`000?no`mgo_l?M00[o_l?M00?o0000ol35g_l000003_o2aMd00ol0003o
`lGLol?5g00:ol?5g003o`000?o2aMco000004Wooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03[ooooo00?o0000ohZal?n:
/O001on:/O000ol0003oSK7^ohfakP07ohfakP03o`000?nA/NcoTK7/00OoTK7/00?o0000oiJaj_nF
/NX02?nF/NX00ol0003oVk;Xoi^bj009oi^bj003o`000?nQ]>KoXKCV00KoXKCV1?l0000:ojJhiP03
o`000?n/^^?o[;[S00[o[;[S00?o0000ok6khOna^n402ona^n400ol0003o][gOokJmg`02okJmg`;o
00001onh`>400ol0003o_<;Nokc2gP0;okc2gP03o`000?no`mgo_l?M00Oo_l?M0_l00003ol35gP03
o`000?o2aMgo`/GM00co`/GM00?o0000ol?5g?o3aM`01oo3aM`2o`0000?o`/GL00?o0000oooooooo
ool0A_ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Go
oooo00?o0000ooooooooool0??ooool00ol0003oR[7`ohZal007ohZal003o`000?n=/NkoSK7^00Ko
SK7^00?o0000oi6ak?nA/N`02?nA/N`00ol0003oU[7ZoiJajP08oiJajP03o`000?nK/^SoVk;X00Wo
Vk;X00?o0000oj6di_nQ]>H01Ol00002oinfj003o`000?nV^>KoY[SV00[oY[SV00?o0000ojbjhon/
^^<02On/^^<2o`0000go/K_Q00Co0000okJmgol0003o00002_nh`>400ol0003o_<;Nokc2gP0;okc2
gP03o`000?no`mgo_l?M00Go_l?M00?o0000ol35g_o0aMh01?o0aMh00ol0003o`/GMol;5g@0<ol;5
g@03o`000?o3aMco`lGL00Go`lGL00?o0000ol;5g?o2aM`00oo2aM`2o`0004Oooooo000Zooooo`03
o`000?oooooooooo03gooooo00?o0000ohZal?n:/O001on:/O000ol0003oSK7^ohfakP06ohfakP03
o`000?nA/NcoTK7/00OoTK7/00?o0000oiJaj_nF/NX02OnF/NX00ol0003oVk;Xoi^bj007oi^bj0Co
00002?nO]^P00ol0003oY[SVojJhiP0:ojJhiP03o`000?n/^^?o[;[S00So[;[S00?o0000ojbjhol0
00003?na^n42o`0000co^<3Q00?o0000okc2g_nl`]h02onl`]h00ol0003o_l?Moko3g@04oko3g@03
o`000?o0aMko`<GN00Ko`<GN00?o0000ol;5gOo2aMd02oo2aMd00ol0003o`lGLol?5g004ol?5g003
o`000?o2aMco`/GL00Go`/GL00?o0000ooooooooool0AOooool002[ooooo00?o0000ooooooooool0
?_ooool00ol0003oR[7`ohZal007ohZal003o`000?n=/NkoSK7^00KoSK7^00?o0000oi6ak?nA/N`0
1onA/N`00ol0003oU[7ZoiJajP09oiJajP04o`000?nK/^SoVk;Xoi^bj0Go00000_nI/nX00ol0003o
WkKXoinfj008oinfj003o`000?nV^>KoY[SV00WoY[SV00?o0000ojbjhon/^^<02?n/^^<00ol0003o
[;[So`00000:ok6kh@;o000000?o/koSo`000?nh`>403?nh`>400ol0003o_<;Nokc2gP0;okc2gP04
o`000?no`mgo_l?Moko3g@;o00002Oo0aMh00ol0003o`/GMol;5g@0<ol;5g@04o`000?o3aMco`lGL
ol?5g0;o00002Oo2aM`00ol0003oooooooooo`14ooooo`00:_ooool00ol0003oooooooooo`0ooooo
o`03o`000?n:/O3oR[7`00OoR[7`00?o0000ohfak_n=/Nh01_n=/Nh00ol0003oTK7/oi6ak007oi6a
k003o`000?nF/N[oU[7Z00OoU[7Z1Ol00008oiVcjP03o`000?nO]^SoWkKX00SoWkKX00?o0000ojJh
i_nV^>H02OnV^>H00ol0003o[;[Sojbjh`07ojbjh`04o`000?n/^^?o[;[So`0000Oo/K_Q0_l00004
ok>oh`03o`000?nh`>7o^<3Q00_o^<3Q00?o0000okc2g_nl`]h02onl`]h00ol0003o_l?Mo`00000<
ol35gP03o`000?o2aMgo`/GM00co`/GM00?o0000ol?5g?l000003?o2aM`00ol0003oooooooooo`13
ooooo`00:Oooool3o`00043ooooo0_l00009ohZal003o`000?n=/NkoSK7^00KoSK7^00?o0000oi6a
k?nA/N`01onA/N`01?l0003oU[7ZoiJaj_nF/NX5o`0000;oT[7/00?o0000oiVcj_nI/nX02OnI/nX0
0ol0003oWkKXoinfj008oinfj003o`000?nV^>KoY[SV00WoY[SV00?o0000ojbjhon/^^<01_n/^^<0
1Ol0003o[;[Sojbjhon/^^?o000000Co/K_Q0_l00007ok>oh`03o`000?nh`>7o^<3Q00_o^<3Q00?o
0000okc2g_nl`]h02_nl`]h2o`0000ko`<GN00?o0000ol;5gOo2aMd02oo2aMd2o`0000go`/GL0_l0
0014ooooo`00:_ooool00ol0003oooooooooo`10ooooo`;o00002On:/O000ol0003oSK7^ohfakP06
ohfakP03o`000?nA/NcoTK7/00?oTK7/1ol00008oi:ak003o`000?nI/n[oVK?Z00WoVK?Z00?o0000
oinfj?nO]^P01onO]^P00ol0003oY[SVojJhiP0:ojJhiP03o`000?n/^^?o[;[S00Go[;[S00?o0000
ojbjhon/^^<00_n/^^<01?l0003o/K_Qo`000?l0000:ok>oh`03o`000?nh`>7o^<3Q00_o^<3Q00?o
0000okc2g_nl`]h01onl`]h2o`000003okg4h?l0003o`<GN00ko`<GN00?o0000ol;5gOo2aMd02?o2
aMd2o`000003ol;6g_l0003o`/GL00go`/GL00?o0000ooooooooool0@_ooool002[ooooo00?o0000
ooooooooool0@Oooool2o`0000GoR[7`4_l00004ohb`kP03o`000?nB/NcoT[7/00WoT[7/00?o0000
oiVcj_nI/nX02OnI/nX00ol0003oWkKXoinfj007oinfj003o`000?nV^>KoY[SV00WoY[SV00?o0000
ojbjhon/^^<01On/^^<00ol0003o[;[Sojbjh`02ojbjh`;o00003?nc_n<00ol0003o^<3QokS0h@0;
okS0h@03o`000?nl`]ko_<;N00Go_<;N0_l00004okg4h003o`000?o0aMko`<GN00go`<GN00?o0000
ol;5gOo2aMd01_o2aMd00ol0003o`/KNol;6gP02ol;6gP03o`000?o2aMco`/GL00co`/GL00?o0000
ooooooooool0@Oooool002[ooooo00?o0000ooooooooool0@_ooool6o`0000CoQ:oa00?o0000ohN_
l?n7[o001_n7[o000ol0003oS;3^ohb`kP07ohb`kP03o`000?nB/NcoT[7/00WoT[7/00?o0000oiVc
j_nI/nX02?nI/nX00ol0003oWkKXoinfj008oinfj003o`000?nV^>KoY[SV00WoY[SV00?o0000ojbj
hon/^^<01?n/^^<00ol0003o[;[So`000002o`000003ojfmiOl0003o/koS00co/koS00?o0000okS0
hOnh`>402onh`>400ol0003o_<;Nokc2gP02okc2gP;o00001onma>000ol0003o`<GNol35gP0<ol35
gP03o`000?o2aMgo`/GM00Co`/GM0_l00006ol;6gP03o`000?o2aMco`/GL00co`/GL00?o0000oooo
ooooool0@?ooool002Wooooo00?o0000ooooooooool0A?ooool00ol0003oQ:oaohB_l@07ohB_l@03
o`000?n7[o3oQjo`00KoQjo`00?o0000ohb`k_n</>h01on</>h00ol0003oT[7/oi:ak009oi:ak003
o`000?nI/n[oVK?Z00SoVK?Z00?o0000oinfj?nO]^P02?nO]^P00ol0003oY[SVojJhiP09ojJhiP03
o`000?n/^^?o[;[S00?o[;[S0_l00005ojfmi@03o`000?nc_n?o/koS00_o/koS00?o0000okS0hOnh
`>402onh`>401?l0003o_<;No`000?l0000:okg4h003o`000?o0aMko`<GN00co`<GN00Co0000ol;5
gOo2aMgo`/GM0_l00009ol;6gP03o`000?o2aMco`/GL00_o`/GL00?o0000ooooooooool0@?ooool0
02Wooooo00?o0000ooooooooool0AOooool00ol0003oQ:oaohB_l@07ohB_l@03o`000?n7[o3oQjo`
00KoQjo`00?o0000ohb`k_n</>h01on</>h00ol0003oT[7/oi:ak008oi:ak003o`000?nI/n[oVK?Z
00WoVK?Z00?o0000oinfj?nO]^P01onO]^P00ol0003oY[SVojJhiP0:ojJhiP03o`000?n/^^?o0000
00?o00001on]_ND00ol0003o/koSok>oh`0;ok>oh`03o`000?nh`>7o^<3Q00[o^<3Q0_l0000=okg4
h003o`000?o0aMko`<GN00co`<GN00?o0000ol;5gOl000002oo2a]h00ol0003o`/GLol;5g00<ol;5
g003o`000?oooooooooo03oooooo000Yooooo`03o`000?oooooooooo04Kooooo00?o0000ohB_lOn4
[o401on4[o400ol0003oQjo`ohN_l006ohN_l003o`000?n</>koS;3^00OoS;3^00?o0000oi:ak?nB
/N`02?nB/N`00ol0003oVK?ZoiVcjP09oiVcjP03o`000?nO]^SoWkKX00OoWkKX00?o0000ojJhi_nV
^>H02?nV^>H3o`0000?o[KgU00?o0000ojfmiOn]_ND01_n]_ND00ol0003o/koSok>oh`0;ok>oh`03
o`000?nh`>7o^<3Q00Oo^<3Q0_l000000oni`n;o0000okg4h00=okg4h003o`000?o0aMko`<GN00_o
`<GN0_l0000=ol;6gP03o`000?o2aMco`/GL00_o`/GL0_l00010ooooo`00:Oooool2o`0004Sooooo
00?o0000ohB_lOn4[o401on4[o400ol0003oQjo`ohN_l006ohN_l003o`000?n</>koS;3^00OoS;3^
00?o0000oi:ak?nB/N`02?nB/N`00ol0003oVK?ZoiVcjP08oiVcjP03o`000?nO]^SoWkKX00SoWkKX
00?o0000ojJhi_nV^>H01?nV^>H3o`0000;oY[[X00Go0000ojfmiOn]_NGo[KgUo`000009ojfmi@03
o`000?nc_n?o/koS00[o/koS00?o0000okS0hOnh`>401Onh`>42o`0000Co^L?R00?o0000okg4h?nm
a>002onma>000ol0003o`<GNol35gP09ol35gP;o000000?o`<OOo`000?o2a]h03Oo2a]h00ol0003o
`/GLol;5g008ol;5g0;o000000?o`LKNo`000?l00000?oooool002Wooooo00?o0000ooooooooool0
B?ooool00ol0003oQ:oaohB_l@07ohB_l@03o`000?n7[o3oQjo`00KoQjo`00?o0000ohb`k_n</>h0
1on</>h00ol0003oT[7/oi:ak008oi:ak003o`000?nI/n[oVK?Z00SoVK?Z00?o0000oinfj?nO]^P0
2?nO]^P00ol0003oY[SVojJhiP03o`0000KoY[[X00Co0000ojfmiOn]_NGo00002_n]_ND00ol0003o
/koSok>oh`0:ok>oh`03o`000?nh`>7o^<3Q00;o^<3Q0_l00007okW3hP03o`000?nma>3o_LCP00_o
_LCP00?o0000ol35g_o0aMh01oo0aMh00ol0003o`<OOol37g`02ol37g`03o`000?o2a]ko`/KN00co
`/KN00?o0000ol;5g?o2aM`01_o2aM`00ol0003o`LKNol76gP02ol76gP03o`000?oooooooooo03go
oooo000Yooooo`03o`000?oooooooooo04Wooooo00?o0000ohB_lOn4[o401on4[o400ol0003oQjo`
ohN_l006ohN_l003o`000?n</>koS;3^00OoS;3^00?o0000oi:ak?nB/N`01onB/N`00ol0003oVK?Z
oiVcjP09oiVcjP03o`000?nO]^SoWkKX00KoWkKX1?l0000:ojJjj003o`000?n]_NGo000000_o[KgU
00?o0000ok>ohonc_n<02_nc_n<01?l0003o^<3Qo`000?l0000:okW3hP03o`000?nma>3o_LCP00_o
_LCP00?o0000ol35g_o0aMh01?o0aMh2o`0000Ko`<OO00?o0000ol;6g_o2a]h02oo2a]h00ol0003o
`/GLol;5g004ol;5g0;o00001_o1a]h00ol0003oooooooooo`0looooo`00:Oooool00ol0003ooooo
ooooo`1:ooooo`03o`000?n4[o7oQ:oa00KoQ:oa00?o0000ohN_l?n7[o001on7[o000ol0003oS;3^
ohb`kP07ohb`kP03o`000?nB/NcoT[7/00OoT[7/00?o0000oiVcj_nI/nX02OnI/nX00ol0003oWkKX
oinfj005o`0000;oW[S[00?o0000ojJjj?nV^^P02_nV^^P2o`0000_o[KgU00?o0000ok>ohonc_n<0
2_nc_n<2o`0000go^L?R00?o0000okg4h?nma>002onma>001?l0003o`<GNol35g_o0aMh2o`0000Wo
`<OO00?o0000ol;6g_o2a]h02oo2a]h01?l0003o`/GLol;5g?o2aM`2o`0000Wo`LKN00?o0000oooo
ooooool0>oooool002Wooooo00?o0000ooooooooool0Boooool00ol0003oQ:oaohB_l@06ohB_l@03
o`000?n7[o3oQjo`00OoQjo`00?o0000ohb`k_n</>h01on</>h00ol0003oT[7/oi:ak007oi:ak003
o`000?nI/n[oVK?Z00OoVK?Z1?l00008oijhj`03o`000?nV^^SoY[[X00[oY[[X00?o0000ojfmiOn]
_ND02_n]_ND00ol0003o/koSok>oh`07ok>oh`;o000000?o/l;Uo`000?ni`n803Oni`n800ol0003o
_LCPokg4h00;okg4h003o`000?o0aMko000000_o`<OO00?o0000ol;6g_o2a]h03?o2a]h00ol0003o
`/GLo`00000;ol76gP;o0000??ooool002Wooooo00?o0000ooooooooool0C?ooool00ol0003oQ:oa
ohB_l@06ohB_l@03o`000?n7[o3oQjo`00OoQjo`00?o0000ohb`k_n</>h01on</>h00ol0003oT[7/
oi:ak007oi:ak004o`000?nI/n[oVK?ZoiVcjPGo00000_nG]Nd00ol0003oW[S[oijhj`08oijhj`03
o`000?nV^^SoY[[X00WoY[[X0_l0000<ojfmi@03o`000?nc_n?o/koS00Co/koS0_l00004ok?2i@03
o`000?ni`n;o^L?R00_o^L?R00?o0000okg4h?nma>002onma>02o`0000go`<OO00?o0000ol;6g_o2
a]h02oo2a]h2o`0000go`LKN00?o0000ooooooooool0>_ooool002Sooooo0ol0001>ooooo`03o`00
0?n4[o7oQ:oa00KoQ:oa00?o0000ohN_l?n7[o001on7[o000ol0003oS;3^ohb`kP07ohb`kP03o`00
0?nB/NcoT[7/00?oT[7/1ol00008oiNek@03o`000?nN^>_oW[S[00SoW[S[00?o0000ojJjj?nV^^P0
2?nV^^P00ol0003oY[[Xo`00000<ojfmi@03o`000?nc_n?o/koS00;o/koS00?o0000ok?2iOnc`^D0
1Onc`^D00ol0003o^L?RokW3hP0;okW3hP03o`000?nma>3o_LCP00So_LCP0_l000000onman;o0000
ol37g`0=ol37g`03o`000?o2a]ko`/KN00So`/KN0_l000000oo0amoo0000ol76gP0=ol76gP03o`00
0?oooooooooo03Wooooo000Xooooo`03o`000?oooooooooo04oooooo00?o0000ohB_lOn4[o401_n4
[o400ol0003oQjo`ohN_l003ohN_l1?o00001?n?/^h00ol0003oUkG]oiNek@09oiNek@03o`000?nN
^>_oW[S[00SoW[S[00?o0000ojJjj?nV^^P01onV^^P01?l0003oY[[XojJjj?l0000<ojfmi@04o`00
0?nc_n?o0000o`0000Wo/l;U00?o0000okW3h_ni`n802oni`n800ol0003o_LCPokg4h005okg4h0;o
00001?nman800ol0003o`<OOol37g`0<ol37g`03o`000?o2a]ko`/KN00Ko`/KN00?o0000ol37goo0
aml00_o0aml00ol0003o`LKNol76gP0<ol76gP03o`000?oooooooooo03Sooooo000<ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c007oooo
o`03o`000?oooooooooo053ooooo3_l00004oh>^l@03o`000?n8/?3oR;3`00OoR;3`00?o0000ohnb
k_n?/^h01on?/^h00ol0003oUkG]oiNek@09oiNek@03o`000?nN^>_oW[S[00SoW[S[00?o0000ojJj
j?nV^^P01_nV^^P01Ol0003oY[[XojJjj?nV^^So000000[o[KgU0ol0000<ok?2i@03o`000?ni`n;o
^L?R00_o^L?R00?o0000okg4h?nma>000_nma>02o`0000Oo_LOR00?o0000ol37goo0aml02oo0aml0
0ol0003o`/KNol;6gP04ol;6gP;o00001_o0aml00ol0003o`LKNol76gP0;ol76gP;o0000>Oooool0
00cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonH
V9So8B4Q00Oooooo00?o0000ooooooooool0D?ooool00ol0003oP:gaoh2]l@06oh2]l@03o`000?n3
[_7oPjka00OoPjka00?o0000ohR`l?n8/?001on8/?000ol0003oSk;^ohnbkP07ohnbkP03o`000?nG
]NgoUkG]00WoUkG]00?o0000oijhjonN^>/02?nN^>/00ol0003oY[[XojJjj004ojJjj0;o00001?nV
^^P00ol0003o[KgUojfmi@04ojfmi@?o00000_n]`>P00ol0003o/l;Uok?2i@0;ok?2i@03o`000?ni
`n;o^L?R00_o^L?R00Co0000okg4h?l0003o00002_nman800ol0003o`<OOol37g`0;ol37g`04o`00
0?o2a]ko`/KNol;6gP;o00002Oo0aml00ol0003o`LKNol76gP0;ol76gP03o`000?oooooooooo03Oo
oooo000<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool0DOooool00ol0003oP:gaoh2]l@06oh2]l@03o`000?n3[_7oPjka
00OoPjka00?o0000ohR`l?n8/?001on8/?000ol0003oSk;^ohnbkP07ohnbkP03o`000?nG]NgoUkG]
00WoUkG]00?o0000oijhjonN^>/02?nN^>/00ol0003oY[[XojJjj003o`000003ojJjj?l0003oY[[X
00CoY[[X00?o0000ojfmiOn]_ND00ol00006ojg0j003o`000?nc`^Go/l;U00_o/l;U00?o0000okW3
h_ni`n802_ni`n82o`0000go_LOR00?o0000ol37goo0aml02oo0aml00ol0003o`/KNo`00000<ol37
g`03o`000?o1a]ko`LKN00_o`LKN00?o0000ooooooooool0=_ooool000cooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401oooool00ol0003oooooooooo`1B
ooooo`03o`000?n0[O7oP:ga00KoP:ga00?o0000oh>^lOn3[_401on3[_400ol0003oR;3`ohR`l007
ohR`l003o`000?n?/^koSk;^00OoSk;^00?o0000oiNekOnG]Nd02OnG]Nd00ol0003oW[S[oijhj`07
oijhj`?o00001OnV^^P01?l0003oY[[XojJjj?nV^^P4o`0000[o[L3X00?o0000ok?2iOnc`^D02onc
`^D00ol0003o^L?RokW3hP07okW3hP;o000000?o^LKTo`000?nman803Onman800ol0003o`<OOol37
g`0:ol37g`;o00003_o0aml00ol0003o`LKNol76gP0:ol76gP;o0000=oooool000cooooo00Go0000
ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01oooool00ol0003ooooo
ooooo`1Cooooo`03o`000?n0[O7oP:ga00KoP:ga00?o0000oh>^lOn3[_401on3[_400ol0003oR;3`
ohR`l007ohR`l003o`000?n?/^koSk;^00OoSk;^00?o0000oiNekOnG]Nd02OnG]Nd00ol0003oW[S[
oijhj`03oijhj`?o00000_nN^>/00ol0003oY[[XojJjj004ojJjj0?o00000_nV_^/00ol0003o[L3X
ojg0j00:ojg0j003o`000?nc`^Go/l;U00_o/l;U00?o0000okW3h_ni`n801?ni`n82o`0000Co^LKT
00?o0000okg7h_nman803?nman800ol0003o`<OOol37g`07ol37g`;o000000?o_lSRo`000?o0aml0
3Oo0aml00ol0003o`LKNol76gP08ol76gP;o000000?o_/KPo`000?l00000=_ooool000cooooo00Go
410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Wooooo00?o0000ooooooooool0
E?ooool00ol0003oP:gaoh2]l@06oh2]l@03o`000?n3[_7oPjka00OoPjka00?o0000ohR`l?n8/?00
1on8/?000ol0003oSk;^ohnbkP07ohnbkP03o`000?nG]NgoUkG]00WoUkG]00?o0000oijhjol00000
0_l00006oijhj`03o`000?nV^^SoY[[X00?o000000?oY[k[o`000?nV_^/00onV_^/00ol0003o[L3X
ojg0j00:ojg0j003o`000?nc`^Go/l;U00_o/l;U00?o0000okW3h_ni`n800_ni`n800ol0003o^LKT
okW6i005okW6i003o`000?nman;o_LOR00co_LOR00?o0000ol37goo0aml01?o0aml2o`0000Co_lSR
00?o0000ol37goo0aml03?o0aml00ol0003o`LKNol76gP05ol76gP;o00001?nna^000ol0003ooooo
ooooo`0dooooo`003?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0
2?ooool2o`0005Oooooo00?o0000oh2]lOn0[O401_n0[O400ol0003oPjkaoh>^l@07oh>^l@03o`00
0?n8/?3oR;3`00OoR;3`00?o0000ohnbk_n?/^h01on?/^h00ol0003oUkG]oiNek@07oiNek@?o0000
2?nN^>/4o`0000GoY[k[00?o0000ojJnjonV_^/00_nV_^/00ol0003o[L3Xojg0j00:ojg0j003o`00
0?nc`^Go/l;U00_o/l;U00Co0000okW3h_l0003o00002Onia^@00ol0003o_LORokg7hP0<okg7hP03
o`000?o0amoo`<OO00;o`<OO00?o0000oko8h_nob>801Onob>800ol0003o`<OOol37g`0<ol37g`03
o`000?o1a]ko`LKN00;o`LKN0_l00007okk6h003o`000?oooooooooo03?ooooo000<ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo
05Oooooo00?o0000oh2]lOn0[O401_n0[O400ol0003oPjkaoh>^l@06oh>^l@03o`000?n8/?3oR;3`
00SoR;3`00?o0000ohnbk_n?/^h01on?/^h00ol0003oUkG]oiNek@03oiNek@?o00000onG]Nd00ol0
003oW[S[oijhj`05o`0000;oWK_]00?o0000ojJnjonV_^/01OnV_^/00ol0003oY[k[ojJnj`02ojJn
j`03o`000?n]`>So[L3X00[o[L3X00?o0000ok?2iOnc`^D02_nc`^D2o`0000co^LKT00?o0000okg7
h_nman803?nman801?l0003o`<OOo`000?l00009oko8hP03o`000?o0amoo`<OO00co`<OO00Co0000
ol76g_l0003o00002_nna^000ol0003oooooooooo`0booooo`009oooool00ol0003oooooooooo`1H
ooooo`03o`000?n0[O7oP:ga00KoP:ga00?o0000oh>^lOn3[_401_n3[_400ol0003oR;3`ohR`l008
ohR`l003o`000?n?/^koSk;^00OoSk;^00?o0000oiNekOl000000_l00005oiNek@Co00002?nM^nd0
0ol0003oY[k[ojJnj`05ojJnj`03o`000?nV_^_oY[k[00;oY[k[00?o0000ojg0j?n]`>P02_n]`>P0
0ol0003o/l;Uok?2i@06ok?2i@?o000000?o/lGWo`000?nia^@03?nia^@00ol0003o_LORokg7hP0;
okg7hP;o00003?nob>800ol0003o`<OOol37g`0;ol37g`;o00003Onna^000ol0003oooooooooo`0a
ooooo`009oooool00ol0003oooooooooo`1Iooooo`03o`000?n0[O7oP:ga00KoP:ga00?o0000oh>^
lOn3[_401_n3[_400ol0003oR;3`ohR`l008ohR`l003o`000?n?/^koSk;^00GoSk;^0ol00003oiNe
k@Go00000_nE]nl00ol0003oWK_]oifkk@08oifkk@03o`000?nV_^_oY[k[00GoY[k[00?o0000ojJn
jonV_^/00_nV_^/00ol0003o[L3Xojg0j00:ojg0j003o`000?nc`^Go/l;U00?o/l;U0_l00005ok?5
i`03o`000?nia^Co^LKT00_o^LKT00?o0000okg7h_nman802?nman82o`000003okc9i?l0003o_lSR
00co_lSR00?o0000ol37goo0aml02Oo0aml00ol0003o_/SRo`00000=okk6h0;o0000<_ooool002Oo
oooo00?o0000ooooooooool0F_ooool00ol0003oP:gaoh2]l@06oh2]l@03o`000?n3[_7oPjka00Ko
Pjka00?o0000ohR`l?n8/?002?n8/?001?l0003oSk;^ohnbk_n?/^h9o`0000SoUKO_00?o0000oifk
kOnM^nd02?nM^nd00ol0003oY[k[ojJnj`04ojJnj`03o`000?nV_^_oY[k[00;oY[k[00?o0000ojg0
j?n]`>P02on]`>P00ol0003o/l;Uo`000002o`0000So/lGW00?o0000okW6i?nia^@02onia^@00ol0
003o_LORokg7hP05okg7hP;o00001?nlbN@00ol0003o_lSRoko8hP0;oko8hP03o`000?o0amoo`<OO
00Ko`<OO0_l00003okk8hP03o`000?nna^3o_/KP00_o_/KP00?o0000ooooooooool0<?ooool002Oo
oooo00?o0000ooooooooool0Foooool00ol0003oP:gaoh2]l@06oh2]l@03o`000?n3[_7oPjka00Ko
Pjka00?o0000ohR`l?n8/?000on8/?0:o`0000GoSKC`00?o0000oiFgkonE]nl02?nE]nl00ol0003o
WK_]oifkk@08oifkk@03o`000?nV_^_oY[k[00CoY[k[00?o0000ojJnjonV_^/00_nV_^/00ol0003o
[L3Xojg0j00:ojg0j0;o00003?ncaNL00ol0003o^LKTokW6i00;okW6i003o`000?nman;o_LOR00;o
_LOR0_l00007okc9i003o`000?nob>;o_lSR00_o_lSR00?o0000ol37goo0aml01?o0aml00ol0003o
_/SRokk8hP04okk8hP03o`000?nna^3o_/KP00_o_/KP00?o0000ooooooooool0;oooool002Oooooo
0_l0001MoooooaOo00000_n6/O44o`0000[oSKC`00?o0000oiFgkonE]nl02?nE]nl00ol0003oWK_]
oifkk@08oifkk@03o`000?nV_^_oY[k[00CoY[k[00?o0000ojJnjonV_^/00_nV_^/00ol0003o[L3X
ojg0j006ojg0j0?o000000?o[L?Zo`000?ncaNL03?ncaNL00ol0003o^LKTokW6i00;okW6i004o`00
0?nman;o0000o`0000[o_<WT00?o0000oko8h_nob>802onob>801?l0003o`<OOol37goo0aml2o`00
00So_/SR00?o0000okk6h?nna^002onna^000ol0003oooooooooo`0^ooooo`009_ooool2o`0005oo
oooo00?o0000ogj]lOmn[O401_mn[O400ol0003oPJkaoh6^l@06oh6^l@03o`000?n6/O7oQ[7a00?o
00001?n6/O400ol0003oSKC`ohfdl008ohfdl003o`000?nE]nooUKO_00SoUKO_00?o0000oifkkOnM
^nd02?nM^nd00ol0003oY[k[ojJnj`04ojJnj`03o`000?nV_^_oY[k[00;oY[k[00?o0000ojg0j?n]
`>P00on]`>P2o`0000Go[L?Z00?o0000ok?5ioncaNL02oncaNL00ol0003o^LKTokW6i00:okW6i0;o
00003OnlbN@00ol0003o_lSRoko8hP0;oko8hP03o`000?o0amoo000000_o_/SR00?o0000okk6h?nn
a^002_nna^02o`0002oooooo000Wooooo`03o`000?oooooooooo05kooooo00?o0000ogj]lOmn[O40
1_mn[O400ol0003oPJkaoh6^l@05oh6^l@?o00002?n6/O400ol0003oSKC`ohfdl008ohfdl003o`00
0?nE]nooUKO_00SoUKO_00?o0000oifkkOnM^nd02?nM^nd00ol0003oY[k[ojJnj`04ojJnj`03o`00
0?nV_^_oY[k[00;oY[k[00?o0000ojg0j?l000000_l00008ojg3jP03o`000?ncaNOo/lGW00[o/lGW
00?o0000okW6i?nia^@02?nia^@2o`000003okS9iol0003o_<WT00go_<WT00?o0000oko8h_nob>80
2_nob>82o`0000go_/SR00?o0000okk6h?nna^002_nna^02o`0002kooooo000Wooooo`03o`000?oo
oooooooo05oooooo00?o0000ogj]lOmn[O401_mn[O401?l0003oPJkaoh6^lOn1[_43o`0000;oPJka
00?o0000ohJalOn6/O401on6/O400ol0003oSKC`ohfdl008ohfdl003o`000?nE]nooUKO_00OoUKO_
00?o0000oifkkOnM^nd02OnM^nd00ol0003oY[k[ojJnj`04ojJnj`04o`000?nV_^_oY[k[ojJnj`;o
00003?n]`nX00ol0003o/lGWok?5i`0:ok?5i`03o`000?nia^Co^LKT00Go^LKT0_l00004okS9i`03
o`000?nlbNCo_<WT00_o_<WT00?o0000oko8h_nob>802?nob>82o`000003okg9i?l0003o_/SR00co
_/SR00?o0000okk6h?nna^002?nna^02o`000003ok_5h_l0003ooooo02gooooo000Vooooo`03o`00
0?oooooooooo067ooooo00?o0000ogj]lOmn[O401_mn[O43o`0000KoPJka00?o0000ohJalOn6/O40
1on6/O400ol0003oSKC`ohfdl008ohfdl003o`000?nE]nooUKO_00OoUKO_00?o0000oifkkOnM^nd0
2OnM^nd00ol0003oY[k[ojJnj`04ojJnj`?o000000?oYL7]o`000?n]`nX03?n]`nX00ol0003o/lGW
ok?5i`0:ok?5i`03o`000?nia^Co^LKT00;o^LKT0_l00007okS9i`03o`000?nlbNCo_<WT00_o_<WT
00?o0000oko8h_nob>801Onob>82o`0000Co_LWT00?o0000okk8h_nnb>802onnb>800ol0003o_/KP
okk6h005okk6h0;o00001?nkaN800ol0003oooooooooo`0[ooooo`009_ooool00ol0003ooooooooo
o`1Rooooo`03o`000?mn[O7oOZga00;oOZga0ol000000omn[O7o0000oh6^l@07oh6^l@03o`000?n6
/O7oQ[7a00OoQ[7a00?o0000ohfdl?n=]?002?n=]?000ol0003oUKO_oiFgk`07oiFgk`03o`000?nM
^ngoWK_]00WoWK_]00?o0000ojJnjonV_^/00ol000000onU`Ngo0000ojG1k@02ojG1k@03o`000?n]
`n[o[L?Z00_o[L?Z00?o0000ok?5ioncaNL02_ncaNL01?l0003o^LKTo`000?l0000:okS9i`03o`00
0?nlbNCo_<WT00_o_<WT00?o0000oko8h_nob>800_nob>82o`0000Oo_LWT00?o0000okk8h_nnb>80
2onnb>800ol0003o_/KPokk6h002okk6h0;o00001_nkaN82o`0002cooooo000Vooooo`03o`000?oo
oooooooo06?ooooo1?l00005ogj]l@03o`000?n1[_7oPJka00KoPJka00?o0000ohJalOn6/O401on6
/O400ol0003oSKC`ohfdl008ohfdl003o`000?nE]nooUKO_00OoUKO_00?o0000oifkkOnM^nd01onM
^nd4o`0000CoYL7]00?o0000ojG1kOnU`Nd00_nU`Nd00ol0003o[L?Zojg3jP0;ojg3jP03o`000?nc
aNOo/lGW00Wo/lGW0_l0000=okS9i`03o`000?nlbNCo_<WT00_o_<WT00Co0000oko8h_l0003o0000
2_nmbN@00ol0003o_/SRokk8hP0;okk8hP04o`000?nna^3o0000o`0000Wo^lGR00?o0000oooooooo
ool0:_ooool002Kooooo0_l0001Sooooo`?o00002?mn[O400ol0003oPJkaoh6^l@06oh6^l@03o`00
0?n6/O7oQ[7a00OoQ[7a00?o0000ohfdl?n=]?002?n=]?000ol0003oUKO_oiFgk`07oiFgk`04o`00
0?nM^ngoWK_]oifkk@Go00000onM_^l00ol0003oYL7]ojG1k@03ojG1k@03o`000?nU`NgoYL7]00;o
YL7]00?o0000ojg3j_n]`nX02on]`nX00ol0003o/lGWok?5i`06ok?5i`;o00000_ncb>X00ol0003o
^<WWokS9i`0;okS9i`03o`000?nlbNCo_<WT00[o_<WT0_l0000=okg9i003o`000?nnb>;o_/SR00[o
_/SR0_l0000<ok_5hP03o`000?oooooooooo02Wooooo000Vooooo`03o`000?oooooooooo05oooooo
0ol00003ooooo`03o`000?mn[O7oOZga00KoOZga00?o0000oh6^lOn1[_401_n1[_400ol0003oQ[7a
ohJal@07ohJal@03o`000?n=]?3oSKC`00SoSKC`00?o0000oiFgkonE]nl00onE]nl7o`0000WoWKk_
00?o0000ojG1kOnU`Nd00onU`Nd00ol0003oYL7]ojG1k@02ojG1k@03o`000?n]`n[o[L?Z00_o[L?Z
00?o0000ok?5ioncaNL00_ncaNL3o`0000Go/lSZ00?o0000okS9ionhbNL02_nhbNL00ol0003o_<WT
okc9i008okc9i0;o000000?o^/_Wo`000?nmbN@03OnmbN@00ol0003o_/SRokk8hP07okk8hP;o0000
00?o^lSTo`000?nkaN803?nkaN800ol0003oooooooooo`0Xooooo`009_ooool00ol0003ooooooooo
o`1Looooo`?o00001oooool00ol0003oOZgaogj]l@06ogj]l@03o`000?n1[_7oPJka00KoPJka00?o
0000ohJalOn6/O401on6/O400ol0003oSKC`ohfdl003ohfdl0[o00001OnE^_400ol0003oWKk_oifn
k`09oifnk`03o`000?nU`NgoYL7]00?oYL7]00?o0000ojG1kOnU`Nd00_nU`Nd00ol0003o[L?Zojg3
jP0;ojg3jP04o`000?ncaNOo0000o`0000Wo/lSZ00?o0000okS9ionhbNL02_nhbNL00ol0003o_<WT
okc9i005okc9i0;o00001?njbnL00ol0003o_LWTokg9i00<okg9i003o`000?nnb>;o_/SR00Co_/SR
0_l00004ok_8i003o`000?nkaN;o^lGR00[o^lGR00?o0000ooooooooool0:?ooool002Kooooo00?o
0000ooooooooool0FOooool3o`0000_ooooo00?o0000ogj]lOmn[O401_mn[O400ol0003oPJkaoh6^
l@06oh6^l@03o`000?n6/O7oQ[7a00?oQ[7a2Ol00005ohfflP03o`000?nE^_7oUK[a00SoUK[a00?o
0000oifnkonM_^l02OnM_^l00ol0003oYL7]ojG1k@03ojG1k@03o`000?nU`NgoYL7]00;oYL7]00?o
0000ojg3j_n]`nX02_n]`nX2o`0000co/lSZ00?o0000okS9ionhbNL02_nhbNL00ol0003o_<WTokc9
i002okc9i0;o00001onjbnL00ol0003o_LWTokg9i00<okg9i003o`000?nnb>;o_/SR00;o_/SR00?o
0000ok_8i?nkb>@01Onkb>@00ol0003o^lGRok_5hP0:ok_5hP03o`000?oooooooooo02Oooooo000V
ooooo`03o`000?oooooooooo05Kooooo0ol0000?oooooaOo00001On7/_800ol0003oSKKbohfflP07
ohfflP03o`000?nE^_7oUK[a00SoUK[a00?o0000oifnkonM_^l02OnM_^l00ol0003oYL7]ojG1k@03
ojG1k@03o`000?nU`NgoYL7]00;oYL7]00?o0000ojg3j_n]`nX01_n]`nX3o`000003ojg7kOl0003o
/lSZ00co/lSZ00?o0000okS9ionhbNL02_nhbNL01?l0003o_<WTo`000?l0000:ok[;i`03o`000?nm
bNCo_LWT00co_LWT00Co0000okk8h_l0003o00002Onkb>@00ol0003o^lGRok_5hP0:ok_5hP03o`00
0?oooooooooo02Kooooo000Vooooo`03o`000?oooooooooo05?ooooo0ol0000Cooooo`03o`000?n0
[O7oP:ga00KoP:ga00?o0000oh:_l_n2[o801_n2[o800ol0003oQk;bohNblP07ohNblP03o`000?n=
]_;oSKKb00OoSKKb00?o0000oiFjlOnE^_402?nE^_400ol0003oWKk_oifnk`09oifnk`03o`000?nU
`NgoYL7]00?oYL7]00?o0000ojG1kOnU`Nd00_nU`Nd00ol0003o[L?Zojg3jP03ojg3jP;o00001On]
and00ol0003o/lSZok?8jP0;ok?8jP03o`000?nhbNOo^<WW00Wo^<WW0ol0000<ok[;i`03o`000?nm
bNCo_LWT00_o_LWT0_l0000<ok_8i003o`000?nkaN;o^lGR00Wo^lGR0_l0000Wooooo`009Oooool0
0ol0003oooooooooo`1Aooooo`?o00005oooool00ol0003oP:gaoh2]l@06oh2]l@03o`000?n2[o;o
PZob00KoPZob00?o0000ohNbl_n7/_801on7/_800ol0003oSKKbohfflP07ohfflP03o`000?nE^_7o
UK[a00SoUK[a00?o0000oifnkonM_^l02OnM_^l00ol0003oYL7]ojG1k@02ojG1k@03o`000?nU`Ngo
YL7]00?oYL7]00?o0000ojg3j_l000000_l00008ojg7k@03o`000?ncb>[o/lSZ00_o/lSZ00?o0000
okS9ionhbNL01_nhbNL2o`0000?o]l_Y00?o0000ok[;ionjbnL02_njbnL00ol0003o_LWTokg9i008
okg9i0;o000000?o^/[Wo`000?nkb>@03?nkb>@00ol0003o^lGRok_5hP09ok_5hP03o`000?oooooo
oooo02Gooooo000Uooooo`?o0000C_ooool3o`0001[ooooo0_l00008oh2]l@03o`000?n2[o;oPZob
00KoPZob00?o0000ohNbl_n7/_801on7/_800ol0003oSKKbohfflP07ohfflP03o`000?nE^_7oUK[a
00SoUK[a00?o0000oifnkonM_^l02OnM_^l00ol0003oYL7]ojG1k@02ojG1k@04o`000?nU`NgoYL7]
ojG1k@Co00002on]and00ol0003o/lSZok?8jP0;ok?8jP03o`000?nhbNOo^<WW00;o^<WW0ol00006
okO;j@03o`000?njbnOo^/_W00[o^/_W00?o0000okg9i?nmbN@01OnmbN@2o`0000Co^/[W00?o0000
ok_8i?nkb>@02_nkb>@00ol0003o^lGRok_5hP09ok_5hP;o00009_ooool002Gooooo00?o0000oooo
ooooool0Boooool3o`0001kooooo0_l00008oh2]l@03o`000?n2[o;oPZob00KoPZob00?o0000ohNb
l_n7/_801on7/_800ol0003oSKKbohfflP07ohfflP03o`000?nE^_7oUK[a00SoUK[a00?o0000oifn
konM_^l02OnM_^l00ol0003oYL7]ojG1k@05o`0000CoYLC_00?o0000ojg7kOn]and02On]and00ol0
003o/lSZok?8jP0;ok?8jP04o`000?nhbNOo0000o`0000[o]l_Y00?o0000ok[;ionjbnL02_njbnL0
0ol0003o_LWTokg9i002okg9i0;o00001onjb^L00ol0003o^lSTok_8i00:ok_8i003o`000?nkaN;o
^lGR00Ko^lGR0_l000000onfa>Go0000o`00000Uooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01oooool00ol0003ooooooooo
o`18ooooo`?o00008_ooool2o`0000SoP:ga00?o0000oh:_l_n2[o801_n2[o800ol0003oQk;bohNb
lP07ohNblP03o`000?n=]_;oSKKb00OoSKKb00?o0000oiFjlOnE^_402?nE^_400ol0003oWKk_oifn
k`07oifnk`Co00000onUa>l00ol0003oYLC_ojG4k`04ojG4k`03o`000?n]ango[LO]00Wo[LO]00?o
0000ok?8j_ncb>X02_ncb>X2o`0000go]l_Y00?o0000ok[;ionjbnL02_njbnL01?l0003o_LWTo`00
0?l0000:ok[:i`03o`000?nkb>Co^lST00[o^lST00?o0000ok_5h_nkaN800_nkaN83o`0000Co]/CU
0_l0000Tooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q
8OnHV9SooooooiRHV?lQ8B401oooool00ol0003oooooooooo`15ooooo`?o00009_ooool2o`0000So
P:ga00?o0000oh:_l_n2[o801_n2[o800ol0003oQk;bohNblP07ohNblP03o`000?n=]_;oSKKb00Oo
SKKb00?o0000oiFjlOnE^_402?nE^_401?l0003oWKk_oifnkonM_^l5o`0000?oW/7a00?o0000ojG4
konUa>l00_nUa>l00ol0003oYLC_ojG4k`04ojG4k`03o`000?n]ango[LO]00Wo[LO]00?o0000ok?8
j_ncb>X01_ncb>X3o`0000;o//_/00?o0000okO;jOngbnT02ongbnT00ol0003o^/_Wok[;i`09ok[;
i`;o00003Onjb^L00ol0003o^lSTok_8i00:ok_8i004o`000?nkaN;o0000o`0000So]/CU00?o0000
ooooooooool08_ooool000Wooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooooooo`12ooooo`?o0000:_ooool2o`0000SoP:ga00?o
0000oh:_l_n2[o801_n2[o800ol0003oQk;bohNblP07ohNblP03o`000?n=]_;oSKKb00OoSKKb00?o
0000oiFjlOnE^_401_nE^_45o`0000WoW/7a00?o0000ojG4konUa>l00_nUa>l00ol0003oYLC_ojG4
k`04ojG4k`03o`000?n]ango[LO]00Wo[LO]00?o0000ok?8j_ncb>X00oncb>X2o`0000Ko//_/00?o
0000okO;jOngbnT02ongbnT00ol0003o^/_Wok[;i`06ok[;i`;o00000_ngc>T00ol0003o^/[Wok[:
i`0:ok[:i`03o`000?nkb>Co^lST00[o^lST0_l0000;okK4i@03o`000?oooooooooo027ooooo0009
ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Oooooo
00?o0000ooooooooool0?oooool3o`0002kooooo0_l00008oh2]l@03o`000?n2[o;oPZob00KoPZob
00?o0000ohNbl_n7/_801on7/_800ol0003oSKKbohfflP07ohfflP03o`000?nE^_7oUK[a00Go0000
0onF_O800ol0003oW/7aoik1l@09oik1l@03o`000?nUa>ooYLC_00;oYLC_00?o0000ojG4konUa>l0
1?nUa>l00ol0003o[LO]ojg7k@09ojg7k@03o`000?ncb>[o000000;o00002Onbbn`00ol0003o]l_Y
okO;j@0;okO;j@03o`000?njbnOo^/_W00;o^/_W0ol00005okO<j@03o`000?njb^Oo^/[W00[o^/[W
00?o0000ok_8i?nkb>@01_nkb>@3o`000003okK7iol0003o]/CU00[o]/CU0_l0000Rooooo`002Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c007ooooo`03
o`000?oooooooooo03cooooo0ol0000booooo`;o00002?n0[O400ol0003oPZoboh:_lP06oh:_lP03
o`000?n7/_;oQk;b00OoQk;b00?o0000ohffl_n=]_800on=]_86o`0000WoU[gb00?o0000oik1lOnN
`O402OnN`O400ol0003oYLC_ojG4k`02ojG4k`03o`000?nUa>ooYLC_00CoYLC_00?o0000ojg7kOn]
and02?n]and3o`0000co//_/00?o0000okO;jOngbnT02ongbnT01?l0003o^/_Wo`000?l00009okO<
j@03o`000?njb^Oo^/[W00[o^/[W00?o0000ok_8i?nkb>@00onkb>@2o`0000Go]/OW00?o0000okK4
iOnfa>D02Onfa>D2o`00027ooooo0009ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@
413o^[Zjoooooonj^[[o410@00Oooooo00?o0000ooooooooool0>Oooool3o`0003Kooooo0_l00008
oh2]l@03o`000?n2[o;oPZob00KoPZob00?o0000ohNbl_n7/_800on7/_89o`0000GoSkWc00?o0000
oiJml_nF_O802?nF_O800ol0003oW/7aoik1l@09oik1l@05o`000?nUa>ooYLC_ojG4kol000001onU
a>l00ol0003o[LO]ojg7k@04ojg7k@?o00000on/bNl00ol0003o//_/ok;;k00:ok;;k003o`000?ng
bnWo]l_Y00[o]l_Y0_l0000<okO<j@03o`000?njb^Oo^/[W00[o^/[W00?o0000ok_8i?l000000_l0
0008okK7i`03o`000?nfa>Go]/CU00Wo]/CU00?o0000ooooooooool07oooool000Wooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003ooooo
ooooo`0gooooo`?o0000>_oooolHo`0000GoRKGc00?o0000ohnilon?^O<01on?^O<00ol0003oU[gb
oiJmlP08oiJmlP03o`000?nN`O7oW/7a00WoW/7a00Go0000ojG4konUa>ooYLC_o`000007ojG4k`03
o`000?n]ango[LO]00?o00001on/bNl00ol0003o//_/ok;;k00:ok;;k003o`000?ngbnWo]l_Y00Ko
]l_Y0ol000000ondcNco0000okO<j@0<okO<j@03o`000?njb^Oo^/[W00Wo^/[W0_l0000<okK7i`03
o`000?nfa>Go]/CU00So]/CU0_l0000Pooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo03Cooooo0ol0000noooo
o`03o`000?n4[o7oQ:oa00KoQ:oa00?o0000ohFal_n5/O801on5/O800ol0003oRKGcohVel`07ohVe
l`03o`000?n?^O?oSkWc00OoSkWc00?o0000oiJml_nF_O802?nF_O800ol0003oW/7aoik1l@09oik1
l@05o`000?nUa>ooYLC_ojG4kol000001_nUa>l3o`0000_o[<W_00?o0000ok;;k?nbbn`02_nbbn`0
0ol0003o]l_YokO;j@03okO;j@;o00001OndcN`00ol0003o]lcYokO<j@0;okO<j@03o`000?njb^Oo
^/[W00Ko^/[W0_l000000oneb^[o0000okK7i`0<okK7i`03o`000?nfa>Go]/CU00So]/CU0_l0000O
ooooo`009?ooool00ol0003oooooooooo`0aooooo`?o0000@_ooool00ol0003oQ:oaohB_l@06ohB_
l@03o`000?n5/O;oQK7b00OoQK7b00?o0000ohVelon9]O<01on9]O<00ol0003oSkWcohnil`07ohni
l`03o`000?nF_O;oU[gb00SoU[gb00?o0000oik1lOnN`O402OnN`O401Ol0003oYLC_ojG4konUa>oo
000000;oYLC_0ol00003ojG7l@03o`000?n/bNoo[<W_00Wo[<W_00?o0000ok;;k?nbbn`02_nbbn`0
0ol0003o]l_Yo`000002o`0000So]<g/00?o0000okO<jOngc>T02ongc>T00ol0003o^/[Wok[:i`02
ok[:i`?o00001?neb^X00ol0003o]/OWokK7i`0:okK7i`03o`000?nfa>Go]/CU00Wo]/CU0_l0000N
ooooo`009?ooool00ol0003oooooooooo`0_ooooo`;o0000A_ooool00ol0003oQ:oaohB_l@06ohB_
l@03o`000?n5/O;oQK7b00OoQK7b00?o0000ohVelon9]O<01on9]O<00ol0003oSkWcohnil`07ohni
l`03o`000?nF_O;oU[gb00SoU[gb00?o0000oik1lOnN`O402OnN`O400ol0003oYLC_ojG4k`03o`00
00OoYLOa00?o0000ojc9kon/bNl02On/bNl00ol0003o//_/ok;;k009ok;;k0;o00003?ndcN`00ol0
003o]lcYokO<j@0;okO<j@04o`000?njb^Oo0000o`0000So]L[Z00?o0000okK7ionfanL02_nfanL0
0ol0003o]/CUokK4i@08okK4i@;o00007_ooool002Cooooo00?o0000ooooooooool0;?ooool3o`00
04Wooooo00?o0000ohB_lOn4[o401_n4[o400ol0003oQK7bohFalP07ohFalP03o`000?n9]O?oRKGc
00OoRKGc00?o0000ohnilon?^O<01on?^O<00ol0003oU[gboiJmlP08oiJmlP03o`000?nN`O7oW/7a
00OoW/7a1?l00002ojG7l@03o`000?nUao7oYLOa00KoYLOa00?o0000ojc9kon/bNl02On/bNl00ol0
003o//_/ok;;k006ok;;k0;o00000_n`cNl00ol0003o]<g/okC=k00:okC=k003o`000?ngc>Wo]lcY
00[o]lcY0_l0000;okG:jP03o`000?nfanOo]/OW00[o]/OW00?o0000okK4iOnfa>D01?nfa>D3o`00
0003ok32iol0003o000001gooooo000Tooooo`03o`000?oooooooooo02Wooooo0ol0001=ooooo`03
o`000?n4[o7oQ:oa00KoQ:oa00?o0000ohFal_n5/O801on5/O800ol0003oRKGcohVel`07ohVel`03
o`000?n?^O?oSkWc00OoSkWc00?o0000oiJml_nF_O802?nF_O801?l0003oW/7aoik1lOnN`O45o`00
00?oW/Cc00Go0000ojG7lOnUao7oYLOao`000008ojG7l@03o`000?n/bNoo[<W_00Wo[<W_00?o0000
ok;;k?nbbn`00_nbbn`3o`0000Go/<g_00?o0000okC=k?ndcN`02_ndcN`00ol0003o]lcYokO<j@06
okO<j@?o000000?o/lc/o`000?neb^X02oneb^X00ol0003o]/OWokK7i`0:okK7i`03o`000?nfa>Go
]/CU00?o00001On``^L2o`0001cooooo000Tooooo`03o`000?oooooooooo02Kooooo0ol0001Aoooo
o`03o`000?n4[o7oQ:oa00KoQ:oa00?o0000ohFal_n5/O801on5/O800ol0003oRKGcohVel`07ohVe
l`03o`000?n?^O?oSkWc00OoSkWc00?o0000oiJml_nF_O801_nF_O85o`0000WoW/Cc00Go0000ojG7
lOnUao7oYLOao`000008ojG7l@03o`000?n/bNoo[<W_00Wo[<W_00Co0000ok;;k?l0003o00002On`
cNl00ol0003o]<g/okC=k00:okC=k003o`000?ngc>Wo]lcY00?o]lcY0_l00005ok?<k003o`000?ne
b^[o]L[Z00[o]L[Z00?o0000okK7ionfanL02OnfanL3o`0000Wo/<;W0_l0000Kooooo`008oooool2
o`0002Gooooo0ol0001Eooooo`03o`000?n4[o7oQ:oa00KoQ:oa00?o0000ohFal_n5/O801on5/O80
0ol0003oRKGcohVel`07ohVel`03o`000?n?^O?oSkWc00OoSkWc00?o0000oiJml_nF_O801Ol00004
oiS0l`03o`000?nNa??oW/Cc00SoW/Cc00Co0000ojG7lOnUao7o00002OnUao400ol0003o[<W_ojc9
k`08ojc9k`?o00002on`cNl00ol0003o]<g/okC=k00:okC=k003o`000?ngc>Wo000000;o00002?nc
c>`00ol0003o]L[ZokG:jP0:okG:jP03o`000?nfanOo]/OW00Ko]/OW0_l000000on`a^[o0000ok32
i`0:ok32i`03o`000?oooooooooo01Wooooo000Tooooo`03o`000?oooooooooo023ooooo0ol0001I
ooooo`03o`000?n4[o7oQ:oa00KoQ:oa00?o0000ohFal_n5/O801on5/O800ol0003oRKGcohVel`07
ohVel`03o`000?n?^O?oSkWc00?oSkWc1_l0000:oiS0l`03o`000?nNa??oW/Cc00SoW/Cc00Co0000
ojG7lOnUao7o00002OnUao400ol0003o[<W_ojc9k`04ojc9k`?o00000on[c?400ol0003o/<g_ok3=
k`09ok3=k`03o`000?ndcNco]<g/00Wo]<g/0_l0000<ok?<k003o`000?neb^[o]L[Z00[o]L[Z00?o
0000okK7ionfanL00_nfanL3o`0000Co/<KZ00?o0000ok32ion``^L02On``^L00ol0003ooooooooo
o`0Hooooo`008oooool00ol0003oooooooooo`0Nooooo`?o0000GOooool00ol0003oQ:oaohB_l@06
ohB_l@03o`000?n5/O;oQK7b00OoQK7b00?o0000ohVelon9]O<00on9]O<9o`0000KoT[cc00?o0000
oiS0lonH`?<02?nH`?<00ol0003oW/Ccoik4l`08oik4l`04o`000?nUao7oYLOao`0000WoYLOa00?o
0000ojc9kon/bNl00ol00007oj_<l@03o`000?n`cNoo/<g_00Wo/<g_00?o0000okC=k?ndcN`01_nd
cN`2o`0000;o/Lg_00?o0000ok?<k?ncc>`02_ncc>`00ol0003o]L[ZokG:jP0:okG:jP04o`000?nf
anOo0000o`0000So/<KZ00?o0000ok32ion``^L02On``^L00ol0003oooooooooo`0Gooooo`008ooo
ool00ol0003oooooooooo`0Kooooo`?o0000HOooool00ol0003oQ:oaohB_l@06ohB_l@03o`000?n5
/O;oQK7b00?oQK7b2Ol00005ohjhl`03o`000?nB_??oT[cc00SoT[cc00?o0000oiS0lonH`?<02?nH
`?<00ol0003oW/Ccoik4l`08oik4l`04o`000?nUao7oYLOao`0000OoYLOa1?l0000;oj_<l@03o`00
0?n`cNoo/<g_00Wo/<g_00?o0000okC=k?ndcN`00_ndcN`3o`0000Go/Lg_00?o0000ok?<k?ncc>`0
2_ncc>`00ol0003o]L[ZokG:jP08okG:jP?o00002on`a^X00ol0003o/<;Wok32i`08ok32i`;o0000
6?ooool002?ooooo00?o0000ooooooooool06?ooool3o`0006Gooooo3_l00005oh^dlP03o`000?n>
^??oS[Sc00OoS[Sc00?o0000oi:llonB_?<02?nB_?<00ol0003oV<3coiS0l`08oiS0l`03o`000?nN
a??oW/Cc00SoW/Cc00Co0000ojG7lOnUao7o00000onUao43o`0000CoY/[b00?o0000oj_<lOn[c?40
2On[c?400ol0003o/<g_ok3=k`09ok3=k`04o`000?ndcNco0000o`0000Wo/Lg_00?o0000ok?<k?nc
c>`02_ncc>`00ol0003o]L[ZokG:jP04okG:jP?o00000_n`bN`00ol0003o/<KZok36jP0:ok36jP03
o`000?n``^Oo/<;W00So/<;W00?o0000ooooooooool05_ooool002?ooooo00?o0000ooooooooool0
5Oooool3o`0006Sooooo00?o0000ohZal?n:/O001on:/O000ol0003oRkCboh^dlP07oh^dlP03o`00
0?n>^??oS[Sc00OoS[Sc00?o0000oi:llonB_?<02?nB_?<00ol0003oV<3coiS0l`08oiS0l`03o`00
0?nNa??oW/Cc00SoW/Cc00?o0000ojG7lOnUao400ol00008ojK:lP03o`000?n[c?7oZlca00WoZlca
00?o0000ok3=kon`cNl02?n`cNl3o`0000_o/Lg_00?o0000ok?<k?ncc>`02_ncc>`00ol0003o]L[Z
okG:jP03o`0000Ko/<W/00?o0000ok36j_n`a^X02On`a^X00ol0003o/<;Wok32i`09ok32i`03o`00
0?oooooooooo01Gooooo000Sooooo`03o`000?oooooooooo01;ooooo0ol0001/ooooo`03o`000?n:
/O3oR[7`00OoR[7`00?o0000oh^dl_n;]?801on;]?800ol0003oS[Scohjhl`07ohjhl`03o`000?nB
_??oT[cc00SoT[cc00?o0000oiS0lonH`?<02?nH`?<00ol0003oW/Ccoik4l`06oik4l`Co000000?o
Y/[bo`000?nVb_802OnVb_800ol0003oZlcaoj_<l@09oj_<l@03o`000?n`cNoo/<g_00Co/<g_0ol0
0003ojk>l@03o`000?nacNoo/Lg_00Wo/Lg_00?o0000ok?<k?ncc>`02Oncc>`3o`0000[o/<W/00?o
0000ok36j_n`a^X02On`a^X00ol0003o/<;Wok32i`09ok32i`03o`000?oooooooooo01Cooooo000R
ooooo`?o00004?ooool3o`00073ooooo00?o0000ohZal?n:/O001on:/O000ol0003oRkCboh^dlP07
oh^dlP03o`000?n>^??oS[Sc00OoS[Sc00?o0000oi:llonB_?<02?nB_?<00ol0003oV<3coiS0l`08
oiS0l`03o`000?nNa??oW/Cc00Go00001?nPao<00ol0003oY/[bo`00000:ojK:lP03o`000?n[c?7o
Zlca00WoZlca00?o0000ok3=kon`cNl00ol00007ojk>l@03o`000?nacNoo/Lg_00Wo/Lg_00?o0000
ok?<k?ncc>`01_ncc>`2o`0000;o[/__00?o0000ok39k?n`bN`02On`bN`00ol0003o/<KZok36jP09
ok36jP03o`000?n``^Oo/<;W00Oo/<;W0ol0000Eooooo`008oooool00ol0003oooooooooo`0<oooo
o`?o0000M?ooool00ol0003oR[7`ohZal007ohZal003o`000?n;]?;oRkCb00OoRkCb00?o0000ohjh
lon>^?<01on>^?<00ol0003oT[ccoi:ll`08oi:ll`03o`000?nH`??oV<3c00KoV<3c1?l0000:oj37
l`;o00002onVb_800ol0003oZlcaoj_<l@08oj_<l@?o00002on^c_400ol0003o/Lg_ok7=k`09ok7=
k`03o`000?ncc>co/lc/00;o/lc/0ol00005ojk;k`03o`000?n`bNco/<W/00Wo/<W/00?o0000ok36
j_n`a^X02On`a^X01?l0003o/<;Wok32ion``^L5o`0000;ooooo00?o0000ooooooooool04oooool0
02?ooooo00?o0000ooooooooool02Oooool3o`0007Sooooo00?o0000ohZal?n:/O001on:/O000ol0
003oRkCboh^dlP07oh^dlP03o`000?n>^??oS[Sc00OoS[Sc00?o0000oi:llonB_?<02?nB_?<00ol0
003oV<3coiS0l`05o`0000CoVl?d00?o0000oj37lonPao<02?nPao<2o`0000_oY/[b00?o0000oj_<
lOn[c?401?n[c?43o`0000?oZ/gb00?o0000ojk>lOn^c_402On^c_400ol0003o/Lg_ok7=k`09ok7=
k`04o`000?ncc>co0000o`0000Wo[/__00?o0000ok39k?n`bN`02On`bN`00ol0003o/<KZok36jP08
ok36jPKo00001Oooool00ol0003oooooooooo`0Cooooo`008oooool00ol0003oooooooooo`06oooo
o`?o0000O?ooool00ol0003oR[7`ohZal007ohZal003o`000?n;]?;oRkCb00OoRkCb00?o0000ohjh
lon>^?<01on>^?<00ol0003oT[ccoi:ll`06oi:ll`Co00002_nK`o@00ol0003oX<Ocoj37l`08oj37
l`;o00002onVb_800ol0003oZlcaoj_<l@03o`0000OoZ/gb00?o0000ojk>lOn^c_402On^c_400ol0
003o/Lg_ok7=k`08ok7=k`;o00003?n^bnl00ol0003o/<W/ok39k009ok39k003o`000?n`a^[o/<KZ
00Co/<KZ1_l00008ooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo00Co
oooo0ol00020ooooo`03o`000?n:/O3oR[7`00OoR[7`00?o0000oh^dl_n;]?801on;]?800ol0003o
S[Scohjhl`07ohjhl`03o`000?nB_??oT[cc00Go00000onG_o<00ol0003oVl?doi_3m009oi_3m003
o`000?nPao?oX<Oc00WoX<Oc00?o0000ojK:l_nVb_802?nVb_83o`0000_oZ/gb00?o0000ojk>lOn^
c_402On^c_400ol0003o/Lg_ok7=k`04ok7=k`?o00000_n]cO400ol0003o[/__ojk;k`0:ojk;k`03
o`000?n`bNco/<W/00Wo/<W/00?o0000ok36j_n`a^X01Ol0000<ooooo`03o`000?oooooooooo01?o
oooo000Rooooo`04o`000?ooooooooooooooo`?o0000Q?ooool00ol0003oR[7`ohZal007ohZal003
o`000?n;]?;oRkCb00OoRkCb00?o0000ohjhlon>^?<00on>^?<6o`0000WoUkoc00?o0000oi_3m?nK
`o@02OnK`o@00ol0003oX<Ocoj37l`09oj37l`03o`000?nVb_;oY/[b00CoY/[b0ol00003ojK<l`03
o`000?nZcO;oZ/gb00WoZ/gb00?o0000ojk>lOn^c_402On^c_400ol0003o/Lg_ok7=k`03o`0000Ko
[Lga00?o0000ojk;kon^bnl02_n^bnl00ol0003o/<W/ok39k008ok39k0Go00003oooool00ol0003o
ooooooooo`0Cooooo`008_ooool4o`0008Sooooo00?o0000ohZal?n:/O001on:/O000ol0003oRkCb
oh^dlP03oh^dlPWo00001_nD^o800ol0003oUkocoiNol`07oiNol`03o`000?nK`oCoVl?d00WoVl?d
00?o0000oj37lonPao<02OnPao<00ol0003oY/[bojK:lP03o`0000OoY/cc00?o0000oj[=l_nZcO80
2OnZcO800ol0003o[/kaojk>l@08ojk>l@?o00002_n]cO400ol0003o[/__ojk;k`0:ojk;k`03o`00
0?n`bNco/<W/00Co/<W/1Ol0000Booooo`03o`000?oooooooooo01?ooooo000Rooooo`?o0000R_oo
ool00ol0003oR[7`ohZal003ohZal0Wo00001_nB^?400ol0003oU;_boiBklP07oiBklP03o`000?nG
_o?oUkoc00OoUkoc00?o0000oi_3m?nK`o@02OnK`o@00ol0003oX<Ocoj37l`07oj37l`Co00002onV
c?<00ol0003oZ/gboj[=lP09oj[=lP03o`000?n^c_7o[/ka00Co[/ka0ol00002oj_>lP03o`000?n]
cO7o[Lga00Wo[Lga00?o0000ojk;kon^bnl02_n^bnl00ol0003o/<W/ok39k004o`0001Oooooo00?o
0000ooooooooool04_ooool002Cooooo00?o0000ooooooooool0ROooool5o`0000GoT[C^00?o0000
oi:hlOnB^?402?nB^?400ol0003oU;_boiBklP07oiBklP03o`000?nG_o?oUkoc00OoUkoc00?o0000
oi_3m?nK`o@02OnK`o@01?l0003oX<Ocoj37lonPao<5o`0000;oXlWd0_l0000<ojK<l`03o`000?nZ
cO;oZ/gb00WoZ/gb00?o0000ojk>lOn^c_400ol00006oj_>lP03o`000?n]cO7o[Lga00Wo[Lga00?o
0000ojk;kon^bnl02?n^bnl5o`0001[ooooo00?o0000ooooooooool04_ooool001Kooooo00?ok^k^
o`000?l000000_l000000ol@413oooooooooo`07ooooo`03o`000?oooooooooo08Wooooo00?o0000
oi:dk_nB]>h01onB]>h00ol0003oT[Saoi:hl@08oi:hl@03o`000?nD^o;oU;_b00OoU;_b00?o0000
oiNolonG_o<01onG_o<00ol0003oVl?doi_3m008oi_3m0Co00002?nSbO@2o`0000coY/cc00?o0000
oj[=l_nZcO802?nZcO83o`0000[oZlkb00?o0000ojg=lOn]cO402On]cO400ol0003o[/__ojk;k`04
ojk;k`Go00007Oooool00ol0003oooooooooo`0Booooo`005_ooool01OmgMgOoV9RHooooool0003o
MgMg00_ooooo00?o0000ooooooooool0ROooool00ol0003oT[C^oi:dkP07oi:dkP03o`000?nB^?7o
T[Sa00SoT[Sa00?o0000oiBkl_nD^o801onD^o800ol0003oUkocoiNol`07oiNol`03o`000?nK`oCo
Vl?d00CoVl?d0ol00003oio6l`03o`000?nSbOCoXlWd00OoXlWd0_l0000<ojK<l`03o`000?nZcO;o
Z/gb00CoZ/gb0ol00003ojW>l`03o`000?n[c_;oZlkb00SoZlkb00?o0000ojg=lOn]cO402On]cO40
0ol0003o[/__ojk;k`04o`00027ooooo00?o0000ooooooooool04_ooool001Kooooo00Go410@oooo
oooooooo0000oa0@400<ooooo`03o`000?oooooooooo08Wooooo00?o0000oi:dk_nB]>h01onB]>h0
0ol0003oT[Saoi:hl@08oi:hl@03o`000?nD^o;oU;_b00OoU;_b00?o0000oiNolonG_o<01onG_o<0
0ol0003oVl?doi_3m003o`0000OoWlKc00?o0000oj?9m?nSbO@01onSbO@2o`0000coY/cc00?o0000
oj[=l_nZcO800ol00007ojW>l`03o`000?n[c_;oZlkb00SoZlkb00?o0000ojg=lOn]cO402?n]cO44
o`0002Cooooo00?o0000ooooooooool04_ooool001Kooooo00?o0000ooooooooool00_l0000=oooo
o`03o`000?oooooooooo08Wooooo00?o0000oi:dk_nB]>h01onB]>h00ol0003oT[Saoi:hl@08oi:h
l@03o`000?nD^o;oU;_b00OoU;_b00?o0000oiNolonG_o<00onG_o<6o`0000_oWlKc00?o0000oj?9
m?nSbO@01onSbO@2o`0000[oY/cc1?l0000;ojW>l`03o`000?n[c_;oZlkb00SoZlkb00?o0000ojg=
lOn]cO401?n]cO44o`0002Oooooo00?o0000ooooooooool04_ooool001Kooooo00?o0000oooooooo
ool00_l0000>ooooo`03o`000?oooooooooo08Wooooo00?o0000oi:dk_nB]>h01onB]>h00ol0003o
T[Saoi:hl@08oi:hl@03o`000?nD^o;oU;_b00GoU;_b1ol00006oig2l`03o`000?nOa_?oWlKc00Wo
WlKc00?o0000oj?9m?nSbO@01onSbO@2o`0000KoY/cc0ol00004ojO=m003o`000?nYc_?oZLkc00Wo
ZLkc00?o0000oj_>l_n[c_802?n[c_800ol0003o[Lgaojg=l@04o`0002[ooooo00?o0000oooooooo
ool04_ooool001Kooooo00Go410@oooooooooooo0000oa0@400?ooooo`03o`000?oooooooooo08Wo
oooo00?o0000oi:dk_nB]>h01onB]>h00ol0003oT[Saoi:hl@08oi:hl@03o`000?nD^o;oU;_b00Co
00001?nK_o400ol0003oWL;coig2l`07oig2l`03o`000?nOa_?oWlKc00WoWlKc00?o0000oj?9m?nS
bO@01onSbO@2o`0000;oY/cc0ol00008ojO=m003o`000?nYc_?oZLkc00WoZLkc00?o0000oj_>l_n[
c_801_n[c_84o`0002kooooo00?o0000ooooooooool04_ooool001Kooooo00GoMgMgoiRHV?oooooo
0000ogMgM`0@ooooo`;o0000R_ooool00ol0003oT[C^oi:dkP07oi:dkP03o`000?nB^?7oT[Sa00Ko
T[Sa1?l00009oi^ol@03o`000?nM`_?oWL;c00OoWL;c00?o0000oio6lonOa_<02OnOa_<00ol0003o
XlWdoj?9m006oj?9m0Co00003?nWcO@00ol0003oZLkcojW>l`09ojW>l`03o`000?n[c_;oZlkb00Ko
0000<Oooool00ol0003oooooooooo`0Booooo`005_ooool01Oo^k^ko0`<3o`000?l0003ok^k^01;o
oooo00?o0000ooooooooool0R?ooool00ol0003oT[C^oi:dkP07oi:dkP03o`000?nB^?7oT[Sa00Go
00000onJ^nl00ol0003oVkoaoi^ol@08oi^ol@03o`000?nM`_?oWL;c00OoWL;c0_l0000:oio6l`03
o`000?nSbOCoXlWd00Go000000GoYL_co`000?nUbo?oYL_co`00000<ojO=m003o`000?nYc_?oZLkc
00SoZLkc1_l0000dooooo`03o`000?oooooooooo01;ooooo000/ooooo`03o`000?oooooo000008[o
oooo00?o0000oi:dk_nB]>h00onB]>h6o`0000WoV[__00?o0000oi^olOnK_o402?nK_o400ol0003o
WL;coig2l`08oig2l`03o`000?nOa_?oWlKc00OoWlKc0ol00007ojG;l`04o`000?nUbo?oYL_co`00
00coYlgd00?o0000ojW>lonYc_<01?nYc_<5o`0003Sooooo00?o0000ooooooooool04_ooool002oo
oooo00?o0000ooooooooool0R?ooool5o`0000GoV[S/00?o0000oiZkkonJ^nl02?nJ^nl00ol0003o
Vkoaoi^ol@08oi^ol@03o`000?nM`_?oWL;c00SoWL;c00?o0000oio6lonOa_<00onOa_<3o`0000?o
Y<Sb00?o0000ojG;lonUbo<01OnUbo<00ol0003oYL_cojG;l`02o`0000_oYlgd00?o0000ojW>lonY
c_<01Ol0000looooo`03o`000?oooooooooo017ooooo000`ooooo`03o`000?oooooooooo08Oooooo
0_l00009oiZhk003o`000?nJ^nooV[__00SoV[__00?o0000oi^olOnK_o402?nK_o400ol0003oWL;c
oig2l`08oig2l`03o`000?nOa_?o000000;o00001onTb?800ol0003oYL_cojG;l`05ojG;l`05o`00
0?nUbo?oYL_cojG;lol000002_nWcO@5o`0003oooooo00?o0000ooooooooool04Oooool0037ooooo
00?o0000ooooooooool0Qoooool2o`0000WoV[S/00?o0000oiZkkonJ^nl02?nJ^nl00ol0003oVkoa
oi^ol@08oi^ol@03o`000?nM`_?oWL;c00KoWL;c1?l0000:ojC8lP03o`000?nUbo?oYL_c00GoYL_c
00Go0000ojG;lonUbo?oYL_co`000006ojO=m0Co0000@oooool00ol0003oooooooooo`0Aooooo`00
<_ooool00ol0003oooooooooo`27ooooo`;o00002OnJ^>`00ol0003oV[__oiZkk`08oiZkk`03o`00
0?nK_o7oVkoa00SoVkoa00?o0000oig2lonM`_<01Ol00004oj?5l@03o`000?nTb?;oY<Sb00SoY<Sb
00?o0000ojG;lonUbo<01OnUbo<01Ol0003oYL_cojG;lonUbo?o000000;oYlgd1?l00016ooooo`03
o`000?oooooooooo017ooooo000cooooo`03o`000?oooooooooo08Oooooo0_l00009oiZhk003o`00
0?nJ^nooV[__00SoV[__00?o0000oi^olOnK_o401_nK_o44o`0000[oXlGa00?o0000ojC8l_nTb?80
2?nTb?800ol0003oYL_cojG;l`05ojG;l`03o`000?nUbo?oYL_c00Co0000BOooool00ol0003ooooo
ooooo`0Aooooo`00=?ooool2o`0008Sooooo0_l00009oiZhk003o`000?nJ^nooV[__00SoV[__00?o
0000oi^olOnK_o401Ol00004oj;2k`03o`000?nSaO7oXlGa00SoXlGa00?o0000ojC8l_nTb?802?nT
b?800ol0003oYL_cojG;l`04ojG;l`?o0000COooool00ol0003oooooooooo`0Aooooo`00=_ooool0
0ol0003oooooooooo`26ooooo`;o00002OnJ^>`00ol0003oV[__oiZkk`06oiZkk`Co00002_nR`^l0
0ol0003oXlGaoj?5l@08oj?5l@03o`000?nTb?;oY<Sb00SoY<Sb00?o0000ojG;lonUbo<00ol00000
0ooooooo0000ooooo`1=ooooo`03o`000?oooooooooo017ooooo000gooooo`;o0000Qoooool2o`00
00WoV[S/00?o0000oiZkkonJ^nl01Ol00003oj:nk@03o`000?nR`^ooX/;_00WoX/;_00?o0000oj?5
lOnSaO402?nSaO400ol0003oY<SbojC8lP06ojC8lPCo00001Oooool00ol0003oooooooooo`1;oooo
o`03o`000?oooooooooo017ooooo000fooooo`03o`000?oooooo000008Sooooo0_l00007oiZhk0Co
00002OnR_^d00ol0003oX/;_oj;2k`09oj;2k`03o`000?nSaO7oXlGa00SoXlGa00?o0000ojC8l_nT
b?801Ol0000:ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool04Oooool003Wooooo
00?o0000ooooooooool0Q_ooool2o`0000;oV[S/1?l00003oj:jjP03o`000?nR_^goX[k]00SoX[k]
00?o0000oj;2konR`^l02OnR`^l00ol0003oXlGaoj?5l@07oj?5l@Go00003_ooool00ol0003ooooo
ooooo`19ooooo`03o`000?oooooooooo017ooooo000jooooo`03o`000?oooooooooo08Kooooo0ol0
0008oj:jjP03o`000?nR_^goX[k]00SoX[k]00?o0000oj;2konR`^l02OnR`^l00ol0003oXlGaoj?5
l@03oj?5l@Go00004_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo017ooooo000k
ooooo`03o`000?oooooooooo08Kooooo00?o0000oj:jj_nR^^X02?nR^^X00ol0003oX[k]oj:nk@08
oj:nk@03o`000?nR`^ooX/;_00WoX/;_00?o0000oj?5lOl000000ol0000Gooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool04?ooool003cooooo00?o0000ooooooooool0Q_ooool00ol0
003oX[[Zoj:jjP08oj:jjP03o`000?nR_^goX[k]00SoX[k]00?o0000oj;2konR`^l02?nR`^l3o`00
01_ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0@ooooo`00?Oooool2o`0008Oo
oooo00?o0000oj:jj_nR^^X02?nR^^X00ol0003oX[k]oj:nk@08oj:nk@03o`000?nR`^ooX/;_00Co
X/;_0ol0000Oooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool04?ooool003oooooo
00?o0000ooooooooool0QOooool00ol0003oX[[Zoj:jjP08oj:jjP03o`000?nR_^goX[k]00SoX[k]
00?o0000oj;2konR`^l00ol0000Rooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
4?ooool0043ooooo00?o0000ooooooooool0QOooool00ol0003oX[[Zoj:jjP08oj:jjP03o`000?nR
_^goX[k]00KoX[k]1?l0000Vooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool04?oo
ool0047ooooo0_l00026ooooo`03o`000?nR^^[oX[[Z00SoX[[Z00?o0000oj:nkOnR_^d01Ol0000[
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool04?ooool0043ooooo00?o0000oooo
ool00000Qoooool00ol0003oX[[Zoj:jjP07oj:jjPGo0000;oooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo013ooooo0013ooooo`03o`000?oooooooooo08Gooooo00?o0000oj:jj_nR
^^X00onR^^X4o`0003Cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0@ooooo`00
A?ooool00ol0003oooooooooo`25ooooo`03o`000?nR^^[o000000?o0000>?ooool00ol0003ooooo
ooooo`11ooooo`03o`000?oooooooooo013ooooo0015ooooo`03o`000?oooooooooo08Gooooo0_l0
000looooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool04?ooool004Kooooo0_l00025
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0@
ooooo`00B?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`0?ooooo`00BOooool00ol0003oooooooooo`21ooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`00
B_ooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0?ooooo`00B_ooool2o`00087ooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00oooooo001<ooooo`03o`000?oooooo
oooo07kooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo00oooooo001=ooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool0@Oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo00oooooo001>ooooo`03o`000?oooooooooo07co
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00oo
oooo001?ooooo`;o0000O?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool03oooool0057ooooo00?o0000ooooooooool0NOooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool03oooool005;ooooo00?o0000
ooooooooool0N?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool03oooool005?ooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03oooool005Cooooo0ol0001fooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0?ooooo`00
E?ooool2o`0007Oooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo00kooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@08ooooo`03o`000?oooooooooo07Cooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00kooooo000hooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool02?ooool00ol0003o
ooooooooo`1cooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`0>ooooo`00>?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooooooo
ool02?ooool2o`0007?ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo00kooooo000hooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`0;ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0B_ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo00kooooo000hooooo`05o`000?ooooooooooooooool0
00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00gooooo00?o0000ooooooooool0Koooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool03_ooool003So
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0K_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool03_ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool03_ooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00004?ooool2o`0006kooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo00kooooo001Oooooo`03o`000?oooooooooo06_ooooo00?o0000oooooooo
ool0Coooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00kooooo001Pooooo`03o`00
0?oooooooooo06[ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo00kooooo001Qooooo`;o0000J_ooool00ol0003oooooooooo`1@ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool03Oooool006?ooooo00?o0000ooooooooool0Ioooool0
0ol0003oooooooooo`1Aooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03Oooool0
06Cooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool03Oooool006Gooooo00?o0000ooooooooool0IOooool00ol0003o
ooooooooo`1Cooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03Oooool006Kooooo
00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool03Oooool006Kooooo0ol0001Tooooo`03o`000?oooooooooo05Gooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0=ooooo`00J?ooool00ol0003oooooooooo`1R
ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0=
ooooo`00JOooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo05Oooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0=ooooo`00J_ooool2o`00067ooooo00?o0000oooooooo
ool0Eoooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00gooooo001/ooooo`03o`00
0?oooooooooo05kooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00gooooo001]ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0FOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00gooooo001^ooooo`03o`000?oooooo
oooo05cooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00cooooo001_ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0Foooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo00cooooo001_ooooo`?o0000Foooool00ol0003o
ooooooooo`1Looooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03?ooool0077ooooo
00?o0000ooooooooool0FOooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool03?ooool007;ooooo00?o0000ooooooooool0F?ooool00ol0003ooooooooo
o`1Mooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03?ooool007?ooooo0_l0001H
ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0<
ooooo`00MOooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo05oooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0<ooooo`00M_ooool00ol0003oooooooooo`1Dooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0<ooooo`00
Moooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0<ooooo`00N?ooool2o`0005?ooooo00?o0000ooooooooool0H_oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00cooooo001hooooo`;o0000Doooool0
0ol0003oooooooooo`1Sooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03?ooool0
07[ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool03?ooool007_ooooo00?o0000ooooooooool0Coooool00ol0003o
ooooooooo`1Tooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02oooool007cooooo
0_l0001?ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0;ooooo`00O_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo06Kooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0;ooooo`00Ooooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0;
ooooo`00P?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo06Sooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0;ooooo`00POooool3o`0004Wooooo00?o0000oooooooo
ool0JOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00_ooooo001fooooo`Co0000
00?o410@ooooooooool01Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo06[ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`00N?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0Joooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00_ooooo001hooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool02oooool007Sooooo00?o0000ooooooooool02_ooool2o`0004Kooooo00?o0000oooo
ooooool0K?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo001Looooo`?o
000000?o410@ooooooooool05_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04?o
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_o
oooo001Nooooo`03oa0@4?nj^[[ooooo01Oooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`12ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0:ooooo`00G_ooool00onHV9So<S8booooo`0Gooooo`03o`000?oooooooooo00kooooo0_l0
0012ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0:ooooo`00G_ooool00ooMgMgo0000okZj^P0Eooooo`03oeEEEOmVIVKo0000013ooooo0_l00012
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0:
ooooo`00G_ooool00omEEEGoMgMgodA4A00Zooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool0LOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00[ooooo001Mooooo`05
omgMgOl@413oooooob4Q8OoMgMd0:_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`00GOooool01OmVIVKo
QhN7oooooonHV9SoEEEE02_ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool005cooooo00?ok^k^o`000?o^
k^h00_ooool00ol0003ogMgMooooo`0Zooooo`;o0000?Oooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool005cooooo00Co410@o`000?l0003o
oooo0_l000000ol@413oooooooooo`0[ooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool0M?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo002Aooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00[ooooo002Aooooo`;o0000>_ooool00ol0003oooooooooo`1fooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02_ooool009?ooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`1gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
09Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02Oooool009Gooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`1hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool009Kooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool009Oooooo0_l0000dooooo`03o`000?oooooooooo07[ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`00VOooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09
ooooo`00VOooool3o`00037ooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Wooooo002Kooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool0OOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo002Looooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Wooooo002Mooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Oooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo002Nooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Wooooo002Oooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0P?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo002Pooooo`;o0000:oooool00ol0003o
ooooooooo`21ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00:7ooooo
0_l0000Zooooo`03o`000?oooooooooo08;ooooo00Go0000ooooooooooooooooo`00000:ooooo`00
Xoooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo08?ooooo00Co0000oooooooooooo
00002_ooool00:Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`24ooooo`03o`00
0?oooooo000000[ooooo002Uooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0QOoo
ool2o`0000[ooooo002Vooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Q?ooool3
o`0000[ooooo002Wooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0P?ooool4o`00
00gooooo002Xooooo`04o`000?oooooo0000o`00027ooooo00?o0000ooooooooool0O?ooool4o`00
017ooooo002>ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@06ooooo`;o00008_ooool00ol0003oooooooooo`1hooooo`Co00005Oooool0093o
oooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo07Cooooo1?l0000Iooooo`00T?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`1`ooooo`Co00007Oooool0093ooooo00?o0000ooooooooool03_ooool00omgMgOo<S8boooo
o`09ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0KOooool3o`00027ooooo002@
ooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00;ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool0JOooool4o`0002Cooooo002@ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo06Gooooo1?l0000Xooooo`00T?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00oooooo0ol0000Jooooo`03o`000?oooooooooo067ooooo1?l0000/ooooo`00S_ooool00omEEEGo
IVIVo`00000=ooooo`Co00003_ooool2o`0001_ooooo00?o0000ooooooooool0GOooool4o`00033o
oooo002booooo`;o00006Oooool00ol0003oooooooooo`1Iooooo`Co0000=?ooool00;Cooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`1Eooooo`Co0000>?ooool00;Gooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`1Aooooo`Co0000??ooool00;Kooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`1=ooooo`Co0000@?ooool00;Oooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`19ooooo`Co0000A?ooool00;Sooooo0_l0000Cooooo`03o`00
0?oooooooooo04Gooooo1?l00018ooooo`00^Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo047ooooo1?l0001<ooooo`00^_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo03kooooo0ol0001@ooooo`00^oooool2o`00013ooooo00?o0000ooooooooool0>_ooool4o`00
05?ooooo002mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0=_ooool4o`0005Oo
oooo002nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0<_ooool4o`0005_ooooo
002oooooo`;o00003?ooool00ol0003oooooooooo`0^ooooo`Co0000Goooool00;oooooo0_l0000<
ooooo`03o`000?oooooooooo02[ooooo1?l0001Sooooo`00`Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo02Kooooo1?l0001Wooooo`00`_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo02;ooooo1?l0001[ooooo`00`oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01kooooo1?l0001_ooooo`00a?ooool2o`0000Oooooo00?o0000ooooooooool06_oo
ool4o`0007?ooooo0036ooooo`?o00001?ooool00ol0003oooooooooo`0Fooooo`Co0000Moooool0
0<Kooooo0_l00005ooooo`03o`000?oooooooooo01?ooooo0ol0001kooooo`00b?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00oooooo1?l0001nooooo`00bOooool01Ol0003ooooo
oooooooooooo000000gooooo1?l00022ooooo`00b_ooool01?l0003oooooooooool00009ooooo`Co
0000Q_ooool00<_ooooo00?o0000ooooool000001Oooool4o`0008[ooooo003<ooooo`Oo0000S_oo
ool00<;ooooo1Ol00006ooooo`;o0000T_ooool00<;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A02J
ooooo`00`oooool00onHV9So8B4Qonk^kP2Kooooo`00a?ooool00onHV9So8B4Qonk^kP2Jooooo`00
aOooool00omgMgOoIVIVooooo`2Iooooo`00a_ooool00ol0003oooooooooo`2Hooooo`00`_ooool0
1Ol0003o^[ZjoooooonHV9So410@09[ooooo0032ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0V_oo
ool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_oo
ool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_oo
ool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00:Gooooo0ol000000ol@413ooooo
ooooo`2fooooo`00Toooool2o`0000_ooooo00?o0000okZj^_ooool01?ooool00ol@413o^[Zjoooo
o`05ooooo`03o`000?nj^[[ooooo00cooooo0_l00005ooooo`03o`000?nj^[[ooooo09Wooooo002C
ooooo`03o`000?oooooooooo00[ooooo0_lb<S85ooooo`03oiRHV?lb<S;ooooo00Gooooo0_lb<S8>
ooooo`03o`000?oooooooooo00?ooooo0_lb<S:Jooooo`00R?ooool01Ol@413o0000o`000?l0003o
410@00Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj
^P04ooooo`03omgMgOl0003o^[Zj00Gooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`00
0?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7QhOo0000okZj^P05ooooo`05oiRH
V?l0003o0000odA4A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`03o`000?o^k^kooooo077ooooo002:ooooo`03o`000?oooooooooo00Kooooo00[o0000oooooooo
ooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`03oeEE
EOmgMgOoA4A400Gooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Co
oooo00?o0000ooooooooool00oooool00oo<c<co0000oa0@4005ooooo`06oa0@4?nj^[[ok^k^ogMg
Mol@413ooooo1_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?o
EEEEojVYZOooool0LOooool008[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02
ooooo`04omgMgOl0003o410@olc<c0[ooooo00GogMgMoa0@4?oooooo8B4QomgMg@0;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`05oa0@
4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`1aooooo`00R_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2_ooool01OmVIVKo
QhN7oooooonHV9SoEEEE00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00?ooooo1_l00002ooooo`05o`000?ooooooooooooooool000003_ooool0
0olQ8B7oooooooooo`1`ooooo`00R_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00;ooooo00Co8B4QogMgMomgMgOo<S8b2Oooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgo
oooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo073ooooo0027
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool01?l0003ooooooooo
ooooool2o`0000;ooooo0_l00008ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooooooo
ool01_ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool02Oooool00ol@413o
0000o`000003o`0000[ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo
073ooooo0027ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooo
oooo<S8b077ooooo0027ooooo`Oo00001Oooool2o`00027ooooo00?o0000ooooooooool01Oooool2
o`0000gooooo00?o0000ooooooooool02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol0
001aooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00\
\>"],
  ImageRangeCache->{{{0, 352.438}, {392.188, 0}} -> {-0.0365789, -0.0401404, \
0.00334761, 0.00334761}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11253 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.066106 1.21212 -1.11022e-16 1.21212 [
[.5 1.12503 -44 0 ]
[.5 1.12503 44 24.5 ]
[.03831 .17557 -5.85635 -9 ]
[.03831 .17557 .14365 0 ]
[.12814 .13981 -17.2021 -9 ]
[.12814 .13981 .79789 0 ]
[.22015 .10319 -16.8352 -9 ]
[.22015 .10319 1.16484 0 ]
[.31441 .06568 -16.4682 -9 ]
[.31441 .06568 1.53178 0 ]
[.411 .02725 -16.1013 -9 ]
[.411 .02725 1.89873 0 ]
[.51 -0.01213 -5.24477 -9 ]
[.51 -0.01213 .75523 0 ]
[.21792 .02683 -9.25094 -12 ]
[.21792 .02683 .74906 0 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[.1484 .76875 -18 -3.08128 ]
[.1484 .76875 0 5.91872 ]
[.29382 .89692 -6 -3.18183 ]
[.29382 .89692 0 5.81817 ]
[.42456 1.01215 -18 -3.26907 ]
[.42456 1.01215 0 5.73093 ]
[.54272 1.11629 -6 -3.34548 ]
[.54272 1.11629 0 5.65452 ]
[.22112 .91822 -10 -4.24244 ]
[.22112 .91822 0 7.75756 ]
[.03467 .19213 -6 -2.71522 ]
[.03467 .19213 0 6.28478 ]
[.02559 .27239 -18 -2.7611 ]
[.02559 .27239 0 6.2389 ]
[.01617 .35567 -18 -2.80881 ]
[.01617 .35567 0 6.19119 ]
[.00638 .44212 -18 -2.85847 ]
[.00638 .44212 0 6.14153 ]
[-0.00378 .53194 -18 -2.9102 ]
[-0.00378 .53194 0 6.0898 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 1.11253 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.12503 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
.04875 .18654 m
.0558 .18375 L
s
[(0)] .03467 .19213 1 -0.39662 Mshowa
.03972 .26693 m
.04679 .2642 L
s
[(0.2)] .02559 .27239 1 -0.38642 Mshowa
.03035 .35034 m
.03744 .34767 L
s
[(0.4)] .01617 .35567 1 -0.37582 Mshowa
.02062 .43693 m
.02774 .43433 L
s
[(0.6)] .00638 .44212 1 -0.36478 Mshowa
.01051 .52689 m
.01765 .52437 L
s
[(0.8)] -0.00378 .53194 1 -0.35329 Mshowa
0 .62042 m
.00717 .61797 L
s
[(1)] -0.01434 .62532 1 -0.3413 Mshowa
.125 Mabswid
.04653 .20636 m
.05076 .2047 L
s
.04428 .22637 m
.04851 .22471 L
s
.04201 .24656 m
.04625 .24491 L
s
.03741 .28749 m
.04165 .28587 L
s
.03508 .30825 m
.03933 .30663 L
s
.03272 .32919 m
.03698 .32759 L
s
.02795 .37168 m
.03221 .37009 L
s
.02553 .39322 m
.02979 .39164 L
s
.02309 .41497 m
.02735 .4134 L
s
.01813 .45909 m
.0224 .45755 L
s
.01561 .48147 m
.01989 .47994 L
s
.01307 .50407 m
.01736 .50255 L
s
.00792 .54993 m
.01221 .54843 L
s
.00531 .5732 m
.0096 .5717 L
s
.00267 .59669 m
.00696 .59521 L
s
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
.5561 .7194 m
.04875 .18654 L
s
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.5561 .7194 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
0 0 m
1 0 L
1 1.11253 L
0 1.11253 L
closepath
clip
newpath
.5 Mabswid
.644 .732 .913 r
.52593 .68772 .5561 .7194 .58394 .7109 .55403 .68056 Metetra
.644 .742 .92 r
.55403 .68056 .58394 .7109 .61197 .70234 .58234 .67328 Metetra
.645 .753 .927 r
.58234 .67328 .61197 .70234 .64019 .69372 .61086 .66578 Metetra
.647 .762 .933 r
.61086 .66578 .64019 .69372 .66861 .68504 .6396 .658 Metetra
.65 .771 .937 r
.6396 .658 .66861 .68504 .69723 .6763 .66855 .64989 Metetra
.654 .779 .94 r
.66855 .64989 .69723 .6763 .72605 .6675 .6977 .64139 Metetra
.659 .784 .941 r
.6977 .64139 .72605 .6675 .75507 .65863 .72705 .63248 Metetra
.664 .787 .94 r
.72705 .63248 .75507 .65863 .7843 .6497 .75661 .62315 Metetra
.669 .787 .937 r
.75661 .62315 .7843 .6497 .81374 .64071 .78635 .6134 Metetra
.674 .785 .932 r
.78635 .6134 .81374 .64071 .84339 .63166 .81629 .60326 Metetra
.679 .78 .927 r
.81629 .60326 .84339 .63166 .87325 .62254 .84641 .59276 Metetra
.682 .773 .92 r
.84641 .59276 .87325 .62254 .90333 .61335 .87673 .58197 Metetra
.684 .765 .913 r
.87673 .58197 .90333 .61335 .93362 .6041 .90723 .57095 Metetra
.685 .755 .905 r
.90723 .57095 .93362 .6041 .96413 .59478 .93794 .55978 Metetra
.622 .725 .92 r
.49498 .6552 .52593 .68772 .55403 .68056 .52331 .64933 Metetra
.623 .735 .927 r
.52331 .64933 .55403 .68056 .58234 .67328 .55189 .64325 Metetra
.626 .745 .933 r
.55189 .64325 .58234 .67328 .61086 .66578 .5807 .63682 Metetra
.631 .756 .937 r
.5807 .63682 .61086 .66578 .6396 .658 .60974 .6299 Metetra
.638 .766 .94 r
.60974 .6299 .6396 .658 .66855 .64989 .63901 .62237 Metetra
.647 .774 .941 r
.63901 .62237 .66855 .64989 .6977 .64139 .6685 .61415 Metetra
.657 .781 .94 r
.6685 .61415 .6977 .64139 .72705 .63248 .69819 .60518 Metetra
.667 .785 .937 r
.69819 .60518 .72705 .63248 .75661 .62315 .72807 .59544 Metetra
.677 .787 .932 r
.72807 .59544 .75661 .62315 .78635 .6134 .75813 .58493 Metetra
.685 .786 .926 r
.75813 .58493 .78635 .6134 .81629 .60326 .78837 .57373 Metetra
.693 .782 .92 r
.78837 .57373 .81629 .60326 .84641 .59276 .81878 .56189 Metetra
.698 .776 .912 r
.81878 .56189 .84641 .59276 .87673 .58197 .84936 .54953 Metetra
.701 .769 .905 r
.84936 .54953 .87673 .58197 .90723 .57095 .88011 .53679 Metetra
.702 .76 .898 r
.88011 .53679 .90723 .57095 .93794 .55978 .91103 .52381 Metetra
.6 .717 .926 r
.4632 .62183 .49498 .6552 .52331 .64933 .49177 .6171 Metetra
.602 .727 .932 r
.49177 .6171 .52331 .64933 .55189 .64325 .52059 .61209 Metetra
.607 .737 .937 r
.52059 .61209 .55189 .64325 .5807 .63682 .54968 .6066 Metetra
.615 .748 .94 r
.54968 .6066 .5807 .63682 .60974 .6299 .57902 .60043 Metetra
.627 .758 .941 r
.57902 .60043 .60974 .6299 .63901 .62237 .6086 .5934 Metetra
.641 .768 .94 r
.6086 .5934 .63901 .62237 .6685 .61415 .63841 .58541 Metetra
.655 .775 .937 r
.63841 .58541 .6685 .61415 .69819 .60518 .66843 .57635 Metetra
.67 .781 .933 r
.66843 .57635 .69819 .60518 .72807 .59544 .69865 .5662 Metetra
.683 .784 .927 r
.69865 .5662 .72807 .59544 .75813 .58493 .72904 .55498 Metetra
.695 .784 .92 r
.72904 .55498 .75813 .58493 .78837 .57373 .7596 .54276 Metetra
.704 .782 .912 r
.7596 .54276 .78837 .57373 .81878 .56189 .79032 .52966 Metetra
.711 .778 .904 r
.79032 .52966 .81878 .56189 .84936 .54953 .82118 .51584 Metetra
.715 .771 .897 r
.82118 .51584 .84936 .54953 .88011 .53679 .85219 .5015 Metetra
.716 .764 .89 r
.85219 .5015 .88011 .53679 .91103 .52381 .88337 .48685 Metetra
.581 .71 .931 r
.43058 .58756 .4632 .62183 .49177 .6171 .45936 .58375 Metetra
.583 .718 .936 r
.45936 .58375 .49177 .6171 .52059 .61209 .48842 .5796 Metetra
.591 .728 .939 r
.48842 .5796 .52059 .61209 .54968 .6066 .51776 .57487 Metetra
.603 .739 .941 r
.51776 .57487 .54968 .6066 .57902 .60043 .54738 .56929 Metetra
.618 .75 .94 r
.54738 .56929 .57902 .60043 .6086 .5934 .57727 .56265 Metetra
.636 .76 .938 r
.57727 .56265 .6086 .5934 .63841 .58541 .6074 .5548 Metetra
.654 .768 .933 r
.6074 .5548 .63841 .58541 .66843 .57635 .63775 .54562 Metetra
.672 .775 .927 r
.63775 .54562 .66843 .57635 .69865 .5662 .6683 .53507 Metetra
.688 .779 .92 r
.6683 .53507 .69865 .5662 .72904 .55498 .69904 .52319 Metetra
.702 .78 .912 r
.69904 .52319 .72904 .55498 .7596 .54276 .72993 .51006 Metetra
.713 .779 .904 r
.72993 .51006 .7596 .54276 .79032 .52966 .76097 .49584 Metetra
.721 .776 .896 r
.76097 .49584 .79032 .52966 .82118 .51584 .79215 .48073 Metetra
.725 .772 .89 r
.79215 .48073 .82118 .51584 .85219 .5015 .82347 .46497 Metetra
.727 .766 .884 r
.82347 .46497 .85219 .5015 .88337 .48685 .85493 .44884 Metetra
.565 .704 .935 r
.39706 .55236 .43058 .58756 .45936 .58375 .42605 .54919 Metetra
.569 .711 .938 r
.42605 .54919 .45936 .58375 .48842 .5796 .45534 .54564 Metetra
.579 .72 .939 r
.45534 .54564 .48842 .5796 .51776 .57487 .48494 .54141 Metetra
.594 .73 .939 r
.48494 .54141 .51776 .57487 .54738 .56929 .51483 .53622 Metetra
.612 .741 .937 r
.51483 .53622 .54738 .56929 .57727 .56265 .545 .52981 Metetra
.633 .751 .933 r
.545 .52981 .57727 .56265 .6074 .5548 .57544 .52199 Metetra
.654 .76 .928 r
.57544 .52199 .6074 .5548 .63775 .54562 .60612 .51265 Metetra
.674 .767 .921 r
.60612 .51265 .63775 .54562 .6683 .53507 .63701 .50173 Metetra
.692 .771 .913 r
.63701 .50173 .6683 .53507 .69904 .52319 .66809 .48926 Metetra
.707 .774 .905 r
.66809 .48926 .69904 .52319 .72993 .51006 .69933 .47536 Metetra
.719 .775 .897 r
.69933 .47536 .72993 .51006 .76097 .49584 .73072 .46019 Metetra
.727 .773 .889 r
.73072 .46019 .76097 .49584 .79215 .48073 .76224 .444 Metetra
.733 .771 .883 r
.76224 .444 .79215 .48073 .82347 .46497 .79389 .42709 Metetra
.735 .767 .879 r
.79389 .42709 .82347 .46497 .85493 .44884 .82567 .40974 Metetra
.555 .7 .937 r
.36263 .5162 .39706 .55236 .42605 .54919 .39182 .51333 Metetra
.56 .706 .938 r
.39182 .51333 .42605 .54919 .45534 .54564 .42134 .51006 Metetra
.572 .713 .938 r
.42134 .51006 .45534 .54564 .48494 .54141 .45117 .50606 Metetra
.589 .723 .936 r
.45117 .50606 .48494 .54141 .51483 .53622 .48133 .50101 Metetra
.609 .733 .933 r
.48133 .50101 .51483 .53622 .545 .52981 .51178 .49464 Metetra
.631 .742 .928 r
.51178 .49464 .545 .52981 .57544 .52199 .54253 .48674 Metetra
.653 .751 .921 r
.54253 .48674 .57544 .52199 .60612 .51265 .57353 .47718 Metetra
.674 .758 .914 r
.57353 .47718 .60612 .51265 .63701 .50173 .60475 .4659 Metetra
.693 .763 .906 r
.60475 .4659 .63701 .50173 .66809 .48926 .63618 .45294 Metetra
.709 .767 .897 r
.63618 .45294 .66809 .48926 .69933 .47536 .66778 .43842 Metetra
.722 .769 .89 r
.66778 .43842 .69933 .47536 .73072 .46019 .69953 .42254 Metetra
.731 .769 .884 r
.69953 .42254 .73072 .46019 .76224 .444 .73141 .40554 Metetra
.736 .768 .878 r
.73141 .40554 .76224 .444 .79389 .42709 .76342 .38775 Metetra
.739 .766 .875 r
.76342 .38775 .79389 .42709 .82567 .40974 .79557 .36951 Metetra
.551 .699 .938 r
.32723 .47902 .36263 .5162 .39182 .51333 .35664 .47609 Metetra
.558 .703 .937 r
.35664 .47609 .39182 .51333 .42134 .51006 .38638 .47276 Metetra
.571 .709 .935 r
.38638 .47276 .42134 .51006 .45117 .50606 .41645 .46867 Metetra
.588 .716 .932 r
.41645 .46867 .45117 .50606 .48133 .50101 .44687 .4635 Metetra
.609 .725 .927 r
.44687 .4635 .48133 .50101 .51178 .49464 .4776 .45695 Metetra
.631 .734 .921 r
.4776 .45695 .51178 .49464 .54253 .48674 .50864 .44884 Metetra
.654 .742 .914 r
.50864 .44884 .54253 .48674 .57353 .47718 .53995 .43901 Metetra
.674 .749 .906 r
.53995 .43901 .57353 .47718 .60475 .4659 .57152 .42739 Metetra
.693 .754 .899 r
.57152 .42739 .60475 .4659 .63618 .45294 .60329 .41405 Metetra
.709 .759 .891 r
.60329 .41405 .63618 .45294 .66778 .43842 .63525 .3991 Metetra
.721 .762 .884 r
.63525 .3991 .66778 .43842 .69953 .42254 .66737 .38273 Metetra
.731 .764 .879 r
.66737 .38273 .69953 .42254 .73141 .40554 .69964 .36521 Metetra
.737 .765 .875 r
.69964 .36521 .73141 .40554 .76342 .38775 .73204 .34689 Metetra
.74 .765 .873 r
.73204 .34689 .76342 .38775 .79557 .36951 .76458 .32809 Metetra
.555 .7 .937 r
.29083 .44079 .32723 .47902 .35664 .47609 .32046 .43743 Metetra
.562 .702 .935 r
.32046 .43743 .35664 .47609 .38638 .47276 .35044 .43366 Metetra
.575 .706 .931 r
.35044 .43366 .38638 .47276 .41645 .46867 .38076 .42915 Metetra
.592 .712 .927 r
.38076 .42915 .41645 .46867 .44687 .4635 .41144 .42356 Metetra
.612 .718 .921 r
.41144 .42356 .44687 .4635 .4776 .45695 .44245 .41663 Metetra
.633 .725 .914 r
.44245 .41663 .4776 .45695 .50864 .44884 .47377 .40815 Metetra
.654 .732 .907 r
.47377 .40815 .50864 .44884 .53995 .43901 .5054 .39799 Metetra
.674 .739 .9 r
.5054 .39799 .53995 .43901 .57152 .42739 .53729 .38607 Metetra
.691 .745 .892 r
.53729 .38607 .57152 .42739 .60329 .41405 .56941 .37245 Metetra
.706 .75 .886 r
.56941 .37245 .60329 .41405 .63525 .3991 .60173 .35726 Metetra
.719 .754 .88 r
.60173 .35726 .63525 .3991 .66737 .38273 .63423 .34066 Metetra
.728 .758 .876 r
.63423 .34066 .66737 .38273 .69964 .36521 .66689 .32294 Metetra
.735 .76 .873 r
.66689 .32294 .69964 .36521 .73204 .34689 .6997 .30442 Metetra
.738 .762 .872 r
.6997 .30442 .73204 .34689 .76458 .32809 .73265 .28543 Metetra
.565 .704 .935 r
.25338 .40146 .29083 .44079 .32046 .43743 .28327 .39728 Metetra
.572 .704 .931 r
.28327 .39728 .32046 .43743 .35044 .43366 .3135 .39272 Metetra
.584 .705 .926 r
.3135 .39272 .35044 .43366 .38076 .42915 .34409 .38745 Metetra
.599 .709 .921 r
.34409 .38745 .38076 .42915 .41144 .42356 .37502 .38118 Metetra
.617 .713 .914 r
.37502 .38118 .41144 .42356 .44245 .41663 .40631 .37365 Metetra
.636 .719 .907 r
.40631 .37365 .44245 .41663 .47377 .40815 .43793 .36466 Metetra
.654 .724 .9 r
.43793 .36466 .47377 .40815 .5054 .39799 .46985 .35411 Metetra
.672 .73 .893 r
.46985 .35411 .5054 .39799 .53729 .38607 .50206 .34192 Metetra
.688 .736 .887 r
.50206 .34192 .53729 .38607 .56941 .37245 .53452 .32813 Metetra
.702 .741 .882 r
.53452 .32813 .56941 .37245 .60173 .35726 .56721 .31287 Metetra
.714 .746 .877 r
.56721 .31287 .60173 .35726 .63423 .34066 .60009 .2963 Metetra
.723 .751 .874 r
.60009 .2963 .63423 .34066 .66689 .32294 .63315 .27868 Metetra
.729 .755 .873 r
.63315 .27868 .66689 .32294 .6997 .30442 .66637 .2603 Metetra
.733 .759 .873 r
.66637 .2603 .6997 .30442 .73265 .28543 .69976 .24147 Metetra
.581 .71 .931 r
.21484 .36098 .25338 .40146 .28327 .39728 .24502 .35563 Metetra
.587 .707 .926 r
.24502 .35563 .28327 .39728 .3135 .39272 .27553 .34993 Metetra
.597 .707 .92 r
.27553 .34993 .3135 .39272 .34409 .38745 .30639 .3436 Metetra
.609 .707 .914 r
.30639 .3436 .34409 .38745 .37502 .38118 .33761 .33638 Metetra
.624 .71 .907 r
.33761 .33638 .37502 .38118 .40631 .37365 .36918 .32804 Metetra
.64 .713 .9 r
.36918 .32804 .40631 .37365 .43793 .36466 .40108 .31842 Metetra
.655 .717 .894 r
.40108 .31842 .43793 .36466 .46985 .35411 .43331 .30742 Metetra
.67 .722 .888 r
.43331 .30742 .46985 .35411 .50206 .34192 .46583 .29497 Metetra
.684 .727 .883 r
.46583 .29497 .50206 .34192 .53452 .32813 .49862 .28112 Metetra
.696 .733 .879 r
.49862 .28112 .53452 .32813 .56721 .31287 .53166 .26597 Metetra
.707 .738 .876 r
.53166 .26597 .56721 .31287 .60009 .2963 .56492 .24966 Metetra
.715 .744 .875 r
.56492 .24966 .60009 .2963 .63315 .27868 .59837 .23241 Metetra
.721 .749 .875 r
.59837 .23241 .63315 .27868 .66637 .2603 .63202 .21449 Metetra
.725 .755 .876 r
.63202 .21449 .66637 .2603 .69976 .24147 .66586 .19616 Metetra
.6 .717 .926 r
.17516 .3193 .21484 .36098 .24502 .35563 .20566 .31247 Metetra
.605 .713 .92 r
.20566 .31247 .24502 .35563 .27553 .34993 .23649 .30533 Metetra
.612 .709 .914 r
.23649 .30533 .27553 .34993 .30639 .3436 .26766 .29766 Metetra
.622 .708 .907 r
.26766 .29766 .30639 .3436 .33761 .33638 .29918 .28925 Metetra
.633 .708 .9 r
.29918 .28925 .33761 .33638 .36918 .32804 .33104 .27992 Metetra
.644 .709 .894 r
.33104 .27992 .36918 .32804 .40108 .31842 .36324 .26955 Metetra
.656 .711 .888 r
.36324 .26955 .40108 .31842 .43331 .30742 .39576 .25804 Metetra
.668 .715 .883 r
.39576 .25804 .43331 .30742 .46583 .29497 .42859 .24536 Metetra
.679 .719 .88 r
.42859 .24536 .46583 .29497 .49862 .28112 .4617 .23153 Metetra
.689 .724 .877 r
.4617 .23153 .49862 .28112 .53166 .26597 .49508 .21663 Metetra
.697 .73 .876 r
.49508 .21663 .53166 .26597 .56492 .24966 .5287 .20078 Metetra
.705 .737 .876 r
.5287 .20078 .56492 .24966 .59837 .23241 .56254 .18416 Metetra
.71 .743 .878 r
.56254 .18416 .59837 .23241 .63202 .21449 .59661 .16697 Metetra
.713 .75 .88 r
.59661 .16697 .63202 .21449 .66586 .19616 .63089 .14942 Metetra
.622 .725 .92 r
.13429 .27638 .17516 .3193 .20566 .31247 .16516 .26779 Metetra
.625 .718 .914 r
.16516 .26779 .20566 .31247 .23649 .30533 .19635 .25896 Metetra
.629 .713 .907 r
.19635 .25896 .23649 .30533 .26766 .29766 .22786 .24972 Metetra
.635 .709 .9 r
.22786 .24972 .26766 .29766 .29918 .28925 .2597 .23993 Metetra
.642 .707 .894 r
.2597 .23993 .29918 .28925 .33104 .27992 .29187 .22946 Metetra
.65 .706 .888 r
.29187 .22946 .33104 .27992 .36324 .26955 .32437 .21823 Metetra
.658 .707 .884 r
.32437 .21823 .36324 .26955 .39576 .25804 .35719 .20618 Metetra
.666 .709 .88 r
.35719 .20618 .39576 .25804 .42859 .24536 .39031 .19327 Metetra
.673 .713 .878 r
.39031 .19327 .42859 .24536 .4617 .23153 .42373 .17952 Metetra
.68 .717 .877 r
.42373 .17952 .4617 .23153 .49508 .21663 .45743 .165 Metetra
.687 .723 .877 r
.45743 .165 .49508 .21663 .5287 .20078 .4914 .14977 Metetra
.692 .729 .879 r
.4914 .14977 .5287 .20078 .56254 .18416 .52562 .13397 Metetra
.696 .736 .882 r
.52562 .13397 .56254 .18416 .59661 .16697 .56009 .11773 Metetra
.699 .744 .886 r
.56009 .11773 .59661 .16697 .63089 .14942 .59481 .1012 Metetra
.644 .732 .913 r
.09217 .23214 .13429 .27638 .16516 .26779 .12347 .22161 Metetra
.645 .724 .906 r
.12347 .22161 .16516 .26779 .19635 .25896 .15505 .2109 Metetra
.647 .718 .9 r
.15505 .2109 .19635 .25896 .22786 .24972 .18693 .19993 Metetra
.649 .712 .894 r
.18693 .19993 .22786 .24972 .2597 .23993 .21912 .18862 Metetra
.652 .708 .888 r
.21912 .18862 .2597 .23993 .29187 .22946 .25162 .1769 Metetra
.655 .705 .884 r
.25162 .1769 .29187 .22946 .32437 .21823 .28443 .16474 Metetra
.659 .704 .88 r
.28443 .16474 .32437 .21823 .35719 .20618 .31755 .1521 Metetra
.663 .705 .878 r
.31755 .1521 .35719 .20618 .39031 .19327 .35097 .13897 Metetra
.667 .707 .877 r
.35097 .13897 .39031 .19327 .42373 .17952 .38469 .12534 Metetra
.671 .711 .878 r
.38469 .12534 .42373 .17952 .45743 .165 .4187 .11126 Metetra
.675 .716 .88 r
.4187 .11126 .45743 .165 .4914 .14977 .45299 .09677 Metetra
.678 .722 .883 r
.45299 .09677 .4914 .14977 .52562 .13397 .48757 .08191 Metetra
.681 .729 .887 r
.48757 .08191 .52562 .13397 .56009 .11773 .52242 .06677 Metetra
.683 .737 .892 r
.52242 .06677 .56009 .11773 .59481 .1012 .55756 .05142 Metetra
.666 .738 .904 r
.04875 .18654 .09217 .23214 .12347 .22161 .08051 .17394 Metetra
.665 .73 .898 r
.08051 .17394 .12347 .22161 .15505 .2109 .11254 .16124 Metetra
.664 .722 .893 r
.11254 .16124 .15505 .2109 .18693 .19993 .14483 .14843 Metetra
.663 .716 .887 r
.14483 .14843 .18693 .19993 .21912 .18862 .1774 .13551 Metetra
.662 .71 .883 r
.1774 .13551 .21912 .18862 .25162 .1769 .21025 .12249 Metetra
.661 .706 .88 r
.21025 .12249 .25162 .1769 .28443 .16474 .24339 .10934 Metetra
.661 .703 .878 r
.24339 .10934 .28443 .16474 .31755 .1521 .27681 .09609 Metetra
.661 .702 .878 r
.27681 .09609 .31755 .1521 .35097 .13897 .31052 .08272 Metetra
.661 .703 .878 r
.31052 .08272 .35097 .13897 .38469 .12534 .34452 .06923 Metetra
.661 .706 .88 r
.34452 .06923 .38469 .12534 .4187 .11126 .37882 .05563 Metetra
.662 .71 .883 r
.37882 .05563 .4187 .11126 .45299 .09677 .41342 .04191 Metetra
.663 .716 .887 r
.41342 .04191 .45299 .09677 .48757 .08191 .44833 .02806 Metetra
.664 .722 .893 r
.44833 .02806 .48757 .08191 .52242 .06677 .48355 .01409 Metetra
.665 .73 .898 r
.48355 .01409 .52242 .06677 .55756 .05142 .51908 0 Metetra
0 g
.25 Mabswid
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282.75, 314.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005Q0001RB000`400?l00000o`00003ooooooomR
ooooo`00oooooomRooooo`00oooooomRooooo`00^_ooool4o`000003oa0@4?oooooooooo0:3ooooo
002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002loooo
o`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`00
0?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002jooooo`03oeEEEOmVIVKo
00000:Cooooo003oooooof;ooooo003oooooof;ooooo001Mooooo`;o00000_ooool2o`000?kooooo
001Mooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgMo_ooool005kooooo00CogMgMo`000?l@413o
c<c<:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`07oooool2o`0009oooooo001Nooooo`04onk^k_lQ8B7o410@onk^kR[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01cooooo
0ol000000onZ^^Go0000o`00002Nooooo`00G_ooool01?lQ8B7oMgMgogMgMolb<S8Zooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001[ooooo0ol00003ojZj
i@?o0000WOooool005gooooo0_l00002ooooo`;o0000:Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`?o00001_nZ^^D00ol0003oZ[[Uo`00002M
ooooo`00S?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00Eooooo`?o00000_nZ^^D00ol0003oZ[[UojZji@03ojZji@04o`000?nZ^^GoZ[[Uo`0009cooooo
002<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@01;o
oooo1?l0000:ojZji@04o`000?nZ^^GoZ[[Uo`0009cooooo002<ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000013ooooo1?l000000onY^>Co0000ojZji@09
ojZji@05o`000?nZ^^GoZ[[UojZjiOl00000Voooool008cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT03Oooool4o`000003ojVhi?l0003oZKST00;oZKST
00?o0000ojZjiOnZ^^D01onZ^^D00ol0003oZ[[UojZji@02ojZji@03o`000?oooooooooo09Sooooo
002/ooooo`Co00002?nY^>@00ol0003oZ[[UojZji@06ojZji@03o`000?nZ^^GoZ[[U00?oZ[[U00?o
0000ooooooooool0Uoooool00:Wooooo1?l0000<ojVhi003o`000?nZ^^GoZ[[U00GoZ[[U00?o0000
ojZjiOnZ^^D00onZ^^D00ol0003oooooooooo`2Gooooo`00Yoooool6o`0000coZKST00?o0000ojZj
iOnZ^^D01OnZ^^D00ol0003oZ[[UojZji@04ojZji@03o`000?oooooooooo09Kooooo002Tooooo`Co
00001OnY]n<00ol0003oZKSTojVhi00:ojVhi003o`000?nZ^^GoZ[[U00CoZ[[U00?o0000ojZjiOnZ
^^D01OnZ^^D00ol0003oooooooooo`2Eooooo`00KOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`08?ooool3o`0000WoZKOS00?o0000ojVh
i?nY^>@02_nY^>@00ol0003oZ[[UojZji@03ojZji@03o`000?nZ^^GoZ[[U00KoZ[[U00?o0000oooo
ooooool0U?ooool006gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q01gooooo0ol000000onY]n?o0000ojVgh`09ojVgh`03o`000?nY^>Co
ZKST00_oZKST00?o0000ojZjiOnZ^^D00_nZ^^D00ol0003oZ[[UojZji@06ojZji@03o`000?oooooo
oooo09Cooooo001]ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000001_ooooo0ol000001OnY]N;o0000ojVghonY]n?o000000[oZKOS00?o0000ojVhi?nY^>@0
2_nY^>@00ol0003oZ[[UojZji@02ojZji@03o`000?nZ^^GoZ[[U00OoZ[[U00?o0000ooooooooool0
Toooool006gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B406?ooool3o`0000GoZKGR00?o0000ojVghonY]n<02onY]n<00ol0003oZKSTojVhi00:ojVhi005
o`000?nZ^^GoZ[[UojZjiOl000002_nZ^^D00ol0003oooooooooo`2Booooo`00KOooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Eooooo`Co000000?oZKGR
o`000?nY]N801OnY]N800ol0003oZKOSojVgh`0;ojVgh`03o`000?nY^>CoZKST00[oZKST00Co0000
ojZjiOnZ^^Go00002_nZ^^D2o`0009?ooooo001]ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool00omEEEGoQhN7ooooo`0Eooooo`?o00002onY]N800ol0003oZKOSojVgh`0;ojVgh`03o`000?nY
^>CoZKST00_oZKST00?o0000ojZjiOl000002?nZ^^D2o`000003ojjli?l0003ooooo09;ooooo001]
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00Cooooo`Co00003OnY
]N800ol0003oZKOSojVgh`0;ojVgh`03o`000?nY^>CoZKST00[oZKST00?o0000ojZjiOl000001OnZ
^^D3o`0000Co[[cT00?o0000ooooooooool0T?ooool006gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`04olc<c?m4A4Co0000oa0@40oooooo0_l00002ojVdh@03o`000?nY]>7o000000goZKGR
00?o0000ojVghonY]n<02onY]n<00ol0003oZKSTojVhi00:ojVhi0;o00000onZ^^D2o`0000So[[cT
00?o0000ooooooooool0Soooool008kooooo0ol00007ojVdh@03o`000?nY]N;oZKGR00_oZKGR00?o
0000ojVghonY]n<02_nY]n<00ol0003oZKSTojVhi00;ojVhi004o`000?nZ^^Go0000o`0000_o[[cT
00?o0000ooooooooool0S_ooool008cooooo0ol0000:ojVdh@03o`000?nY]N;oZKGR00[oZKGR00?o
0000ojVghonY]n<02onY]n<00ol0003oZKSTojVhi00:ojVhi0;o00003On^_>@2o`0008oooooo0029
ooooo`Co000000?oZKCQo`000?nY]>402OnY]>400ol0003oZKGRojVehP0;ojVehP03o`000?nY]n?o
ZKOS00_oZKOS00?o0000ojVhi?nY^>@01onY^>@4o`0000ko[[cT00?o0000ooooooooool0SOooool0
053ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooo
oooo023ooooo1?l000000onY/n3o0000ojVdh@0<ojVdh@03o`000?nY]N;oZKGR00_oZKGR00?o0000
ojVghonY]n<02onY]n<00ol0003oZKSTojVhi004ojVhi0;o00000_n^^^<00ol0003o[[[So`00000>
ojjli003o`000?oooooooooo08cooooo001@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool07_ooool4o`0000GoZK?P00?o0000ojVdhOnY]>402onY]>40
0ol0003oZKGRojVehP0:ojVehP03o`000?nY]n?oZKOS00_oZKOS00?o0000ojVhi?nY^>@00_nY^>@2
o`0000Co[[[S00Co0000ojjjhon^^^?o00003_n^_>@00ol0003oooooooooo`2;ooooo`00D?ooool0
1Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Mooooo`?o000000?oZK?Po`000?nY/n001_nY
/n000ol0003oZKCQojVdh@0:ojVdh@03o`000?nY]N;oZKGR00_oZKGR00?o0000ojVghonY]n<02onY
]n<01?l0003oZKSTo`000?l00006ojjjh`05o`000?n^^^?o[[[Sojjjhol000003On^_>@2o`0008co
oooo001@ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0000Koooo
o`?o00001OnY/n000ol0003oZK?PojVch004ojVch003o`000?nY]>7oZKCQ00_oZKCQ00?o0000ojVe
h_nY]N802onY]N800ol0003oZKOSojVgh`0:ojVgh`;o00002?n^^^<01Ol0003o[[[Sojjjhon^^^?o
000000ko[[cT0_l0002;ooooo`00D?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgM
oeEEEOoooooo00006Oooool3o`000003ojVch?l0003oZK?P00coZK?P00?o0000ojVdhOnY]>402onY
]>400ol0003oZKGRojVehP0;ojVehP03o`000?nY]n?oZKOS00KoZKOS0ol000000on]^>;o0000ojjj
h`07ojjjh`03o`000?n^^^?o[[[S00;o[[[S00?o0000ojjli?n^_>@03?n^_>@00ol0003ooooooooo
o`29ooooo`00D?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000005_oo
ool3o`0000;oZK?P00Co0000ojVch?nY/n3o00003OnY/n000ol0003oZKCQojVdh@0;ojVdh@03o`00
0?nY]N;oZKGR00[oZKGR00?o0000ojVghonY]n<00onY]n<3o`0000Go[KSR00?o0000ojjjhon^^^<0
1On^^^<00ol0003o[[[Sojjjh`03ojjjh`03o`000?n^_>Co[[cT00co[[cT00?o0000ooooooooool0
R?ooool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000001Cooooo
0ol00008ojVch003o`000?nY/n3oZK?P00_oZK?P00?o0000ojVdhOnY]>402_nY]>400ol0003oZKGR
ojVehP0;ojVehP03o`000?nY]n?o000000;o00002On]^>800ol0003o[[[Sojjjh`04ojjjh`03o`00
0?n^^^?o[[[S00Co[[[S00?o0000ojjli?n^_>@02on^_>@2o`0008Wooooo001@ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0@ooooo`?o00003?nY/n000ol0003oZK?P
ojVch00:ojVch003o`000?nY]>7oZKCQ00_oZKCQ00?o0000ojVeh_nY]N802_nY]N82o`0000co[KSR
00?o0000ojjjhon^^^<01?n^^^<00ol0003o[[[Sojjjh`04ojjjh`03o`000?n^_>Co[[cT00co[[cT
0_l00028ooooo`00Loooool3o`000003ojVch?l0003o000000_oZK?P00?o0000ojVch?nY/n002onY
/n000ol0003oZKCQojVdh@0;ojVdh@03o`000?nY]N;oZKGR00OoZKGR0_l000000on/]n7o0000ojfh
hP0<ojfhhP03o`000?n^^^?o[[[S00?o[[[S00?o0000ojjjhon^^^<01On^^^<00ol0003o[[cTojjl
i00<ojjli0;o0000Qoooool0073ooooo0ol00005ojVch003o`000?nY/n3oZK?P00[oZK?P00?o0000
ojVch?nY/n002onY/n000ol0003oZKCQojVdh@0:ojVdh@03o`000?nY]N;oZKGR00GoZKGR0_l00004
ojbgh@03o`000?n]^>;o[KSR00_o[KSR00?o0000ojjjhon^^^<00_n^^^<00ol0003o[[[Sojjjh`06
ojjjh`03o`000?n^_>Co[[cT00Wo[[cT0_l000000onb_^;o0000ooooo`26ooooo`00K_ooool3o`00
00SoZK?P00?o0000ojVch?nY/n002_nY/n000ol0003oZK?PojVch00:ojVch003o`000?nY]>7oZKCQ
00_oZKCQ00?o0000ojVeh_nY]N800_nY]N82o`0000Oo[;OQ00?o0000ojfhh_n]^>802_n]^>800ol0
003o[[[Sojjjh`02ojjjh`03o`000?n^^^?o[[[S00Oo[[[S00?o0000ojjli?n^_>@01_n^_>@2o`00
00?o/[kR0_l00026ooooo`00<oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00008oooool3o`0000;oZK?P00?o0000ojVch?nY/n001_nY/n000ol0003oZK?PojVch00;ojVc
h003o`000?nY/n3oZK?P00[oZK?P00?o0000ojVdhOnY]>402onY]>401?l0003oZKGRo`000?l0000:
ojbgh@03o`000?n]^>;o[KSR00[o[KSR00Go0000ojjjhon^^^?o[[[So`000009ojjjh`03o`000?n^
_>Co[[cT00Go[[cT00?o0000ok:nh_nb_^801?nb_^82o`0008Gooooo000cooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Qooooo`?o0000
00?oZKCQo`000?nY/n002onY/n000ol0003oZK?PojVch00;ojVch003o`000?nY/n3oZK?P00[oZK?P
00?o0000ojVdhOnY]>402_nY]>42o`0000co[;OQ00?o0000ojfhh_n]^>802on]^>801?l0003o[[[S
ojjjhol0000:ojjjh`03o`000?n^_>Co[[cT00;o[[cT0_l00008ok:nhP;o0000Q?ooool003?ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^01oooooo1?l00004ojVdh@03
o`000?nY/n3oZK?P00[oZK?P00?o0000ojVch?nY/n002_nY/n000ol0003oZK?PojVch00;ojVch003
o`000?nY]>7oZKCQ00KoZKCQ0ol000000on[]^3o0000ojbgh@0<ojbgh@03o`000?n]^>;o[KSR00_o
[KSR00?o0000ojjjhol000002on^^^<01?l0003o[[cTo`000?l0000;ok:nhP03o`000?oooooooooo
08;ooooo000cooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Koooo
o`?o00001?nY]>400ol0003oZKCQojVdh@02ojVdh@03o`000?nY/n3oZK?P00[oZK?P00?o0000ojVc
h?nY/n002_nY/n000ol0003oZK?PojVch00:ojVch003o`000?nY]>7oZKCQ00?oZKCQ0ol00005oj^f
h003o`000?n/]n7o[;OQ00_o[;OQ00?o0000ojfhh_n]^>802_n]^>800ol0003o[[[So`00000;ojjj
h`;o00003Onb_^82o`0008?ooooo000cooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOoIVIVooooo`0Hooooo`?o00002onY]>400ol0003oZK?PojVch00:ojVch003o`000?nY/n3oZK?P
00_oZK?P00?o0000ojVch?nY/n002_nY/n000ol0003oZKCQo`000002o`0000WoZkKP00?o0000ojbg
hOn/]n402on/]n400ol0003o[KSRojfhhP0:ojfhhP;o00002On^^^<2o`000003ok:lhOl0003o/[kR
00go/[kR0_l00022ooooo`00<oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool05?ooool3o`000003ojVeh_l0003oZKCQ00coZKCQ00?o0000ojVch?nY/n002_nY/n000ol0
003oZK?PojVch00;ojVch003o`000?nY/n3oZK?P00WoZK?P0_l0000<oj^fh003o`000?n/]n7o[;OQ
00_o[;OQ00?o0000ojfhh_n]^>802on]^>800ol0003o[[[Sojjjh`04ojjjh`?o00001?nb_>400ol0
003o/[kRok:nhP0<ok:nhP;o0000POooool003?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooooiRHV?l@41005?ooool3o`0000CoZKGR00?o0000ojVdhOnY]>402onY]>40
0ol0003oZK?PojVch00:ojVch003o`000?nY/n3oZK?P00[oZK?P00?o0000ojVch?nY/n001_nY/n03
o`000003ojZdh?l0003oZkKP00coZkKP00?o0000ojbghOn/]n402on/]n400ol0003o[KSRojfhhP0:
ojfhhP03o`000?n^^^?o[[[S00;o[[[S0_l00008ok:lh@03o`000?nb_^;o/[kR00co/[kR00?o0000
ooooooooool0Ooooool003?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`04Oooool3o`0000SoZKGR00?o0000ojVdhOnY]>402onY]>400ol0003oZK?PojVc
h009ojVch003o`000?nY/n3oZK?P00_oZK?P00?o0000ojVch?nY/n000onY/n02o`0000GoZ[CP00?o
0000oj^fh?n[]^002on[]^000ol0003o[;OQojbgh@0;ojbgh@03o`000?n]^>;o[KSR00Wo[KSR0_l0
00000on^^^?o0000o`00000;ok:lh@03o`000?nb_^;o/[kR00_o/[kR0_l00020ooooo`00Eoooool3
o`000003ojVeh_l0003oZKGR00SoZKGR00?o0000ojVdhOnY]>402_nY]>400ol0003oZK?PojVch00:
ojVch003o`000?nY/n3oZK?P00_oZK?P00?o0000ojVch?l000000_l00008ojZdh003o`000?n[]^3o
ZkKP00[oZkKP00?o0000ojbghOn/]n403?n/]n400ol0003o[KSRojfhhP08ojfhhP?o00003Onb_>40
0ol0003o/[kRok:nhP0<ok:nhP;o0000Ooooool005Cooooo0ol000000onY]n?o0000ojVehP0;ojVe
hP03o`000?nY]>7oZKCQ00_oZKCQ00?o0000ojVch?nY/n002_nY/n000ol0003oZK?PojVch00:ojVc
h0;o00002onZ]>000ol0003oZkKPoj^fh00;oj^fh003o`000?n/]n7o[;OQ00_o[;OQ00?o0000ojfh
h_n]^>801_n]^>83o`000003ok6jhOl0003o/[cQ00go/[cQ00?o0000ok:nh_nb_^803?nb_^800ol0
003oooooooooo`1mooooo`00D_ooool3o`0000CoZKOS00?o0000ojVeh_nY]N802_nY]N800ol0003o
ZKCQojVdh@0;ojVdh@03o`000?nY/n3oZK?P00[oZK?P00?o0000ojVch?nY/n001_nY/n03o`000003
ojVdh?l0003oZ[CP00_oZ[CP00?o0000oj^fh?n[]^002on[]^000ol0003o[;OQojbgh@0;ojbgh@03
o`000?n]^>;o[KSR00?o[KSR0_l00002ok6jh@04o`000?na^^7o/K[Qo`0000ko/[cQ00?o0000ok:n
h_nb_^803?nb_^800ol0003oooooooooo`1looooo`009oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
02?ooooo1?l000000onY]n?o0000ojVgh`04ojVgh`03o`000?nY]N;oZKGR00[oZKGR00?o0000ojVd
hOnY]>402_nY]>400ol0003oZK?PojVch00:ojVch003o`000?nY/n3oZK?P00?oZK?P0ol00005ojVd
h003o`000?nZ]>3oZ[CP00[oZ[CP00?o0000oj^fh?n[]^002on[]^000ol0003o[;OQojbgh@0;ojbg
h@03o`000?n]^>;o000000;o00001?na^^401Ol0003o/K[Qok6jhOna^^7o000000ko/[cQ00?o0000
ok:nh_nb_^802onb_^82o`0007gooooo000Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL08Oooool3
o`0000_oZKOS00?o0000ojVeh_nY]N802_nY]N800ol0003oZKCQojVdh@0:ojVdh@03o`000?nY/n3o
ZK?P00[oZK?P00?o0000ojVch?l000000_l00009ojVdh003o`000?nZ]>3oZ[CP00[oZ[CP00?o0000
oj^fh?n[]^002_n[]^000ol0003o[;OQojbgh@0;ojbgh@;o00001ona^^400ol0003o/K[Qok6jh@02
ok6jh@03o`000?nb_>7o/[cQ00_o/[cQ00?o0000ok:nh_nb_^803?nb_^82o`0007cooooo000Woooo
o`05oa0@4?ooooooooooooooool@41007_ooool5o`0000goZKOS00?o0000ojVeh_nY]N802_nY]N80
0ol0003oZKCQojVdh@0:ojVdh@03o`000?nY/n3oZK?P00WoZK?P0_l0000<ojVdh003o`000?nZ]>3o
Z[CP00[oZ[CP00?o0000oj^fh?n[]^002on[]^000ol0003o[;OQojbgh@08ojbgh@;o000000?o[kWP
o`000?na^^401_na^^400ol0003o/K[Qok6jh@03ok6jh@03o`000?nb_>7o/[cQ00_o/[cQ00?o0000
ok:nh_nb_^802Onb_^82o`000003okJohOl0003ooooo07_ooooo000Wooooo`05o`000?oooooooooo
ooooool000007?ooool3o`0000;oZKST00?o0000ojVhi?l000003?nY]n<00ol0003oZKGRojVehP0:
ojVehP03o`000?nY]>7oZKCQ00_oZKCQ00?o0000ojVch?nY/n001OnY/n03o`000003ojRdhOl0003o
ZKCP00coZKCP00?o0000ojZdh?nZ]>002_nZ]>000ol0003oZkKPoj^fh00;oj^fh003o`000?n/]n7o
[;OQ00Co[;OQ0ol00004ojnih003o`000?na^^7o/K[Q00Co/K[Q00?o0000ok6jhOna^^400ona^^40
0ol0003o/[cQok:lh@0<ok:lh@03o`000?nb_^;o/[kR00Ko/[kR0_l00004okJoh@03o`000?oooooo
oooo07Wooooo000Wooooo`05o`000?ooooooooooooooool000006Oooool4o`0000GoZKST00?o0000
ojVhi?l000003?nY]n<00ol0003oZKGRojVehP0:ojVehP03o`000?nY]>7oZKCQ00[oZKCQ00?o0000
ojVch?nY/n000onY/n02o`0000GoZ;CQ00?o0000ojVdh?nY]>002onY]>000ol0003oZ[CPojZdh00:
ojZdh003o`000?n[]^3oZkKP00[oZkKP00?o0000ojbghOn/]n400_n/]n42o`0000So[kWP00?o0000
ok6jhOna^^400ona^^400ol0003o/K[Qok6jh@04ok6jh@03o`000?nb_>7o/[cQ00_o/[cQ00?o0000
ok:nh_nb_^801Onb_^800ol0003o][oQokJoh@04okJoh@;o0000N_ooool002Oooooo00Go410@oooo
oooooooooooooa0@400Gooooo`?o00002onY^>@00ol0003oZKOSojVgh`0:ojVgh`03o`000?nY]N;o
ZKGR00[oZKGR00?o0000ojVdhOnY]>402_nY]>400ol0003oZK?Po`000002o`0000SoZ;CQ00?o0000
ojVdh?nY]>002onY]>000ol0003oZ[CPojZdh009ojZdh003o`000?n[]^3oZkKP00_oZkKP00Co0000
ojbghOl0003o00002_n_^N000ol0003o/K[Qok6jh@03ok6jh@03o`000?na^^7o/K[Q00Go/K[Q00?o
0000ok:lhOnb_>402onb_>400ol0003o/[kRok:nhP02ok:nhP;o00002?nf_n42o`0007Wooooo000W
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05?ooool5o`000003ojVhi?l0003oZKST00[oZKST00?o
0000ojVghonY]n<02_nY]n<00ol0003oZKGRojVehP0:ojVehP03o`000?nY]>7oZKCQ00WoZKCQ0_l0
000<ojRdh@03o`000?nY]>3oZKCP00[oZKCP00?o0000ojZdh?nZ]>002_nZ]>000ol0003oZkKPoj^f
h00:oj^fh0;o00003On_^N000ol0003o/K[Qok6jh@02ok6jh@03o`000?na^^7o/K[Q00Ko/K[Q00?o
0000ok:lhOnb_>402onb_>401?l0003o/[kRo`000?l0000;okJoh@03o`000?oooooooooo07Oooooo
000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool3o`0000CoZ[[U00?o0000ojVhi?nY^>@0
2_nY^>@00ol0003oZKOSojVgh`0;ojVgh`03o`000?nY]N;oZKGR00WoZKGR00?o0000ojVdhOnY]>40
1_nY]>43o`000003ojNdh_l0003oZ;CQ00_oZ;CQ00?o0000ojVdh?nY]>002onY]>000ol0003oZ[CP
ojZdh00:ojZdh003o`000?n[]^3oZkKP00OoZkKP0_l000000on^]n3o0000ojnih00=ojnih005o`00
0?na^^7o/K[Qok6jhOl000002Ona^^400ol0003o/[cQok:lh@0:ok:lh@;o00003_nf_n400ol0003o
ooooooooo`1fooooo`00>oooool5o`0000KoZ[[U00?o0000ojVhi?nY^>@02_nY^>@00ol0003oZKOS
ojVgh`0;ojVgh`03o`000?nY]N;oZKGR00WoZKGR00?o0000ojVdhOnY]>400onY]>42o`0000GoYkCR
00?o0000ojRdhOnX]>402_nX]>400ol0003oZKCPojVdh00;ojVdh003o`000?nZ]>3oZ[CP00[oZ[CP
00?o0000oj^fh?n[]^001?n[]^02o`0000Co[[OP00?o0000ojnih?n_^N002on_^N001Ol0003o/K[Q
ok6jhOna^^7o000000Wo/K[Q00?o0000ok:lhOnb_>402?nb_>42o`000003okFnh?l0003o][oQ00go
][oQ0_l0001gooooo`00>Oooool3o`0000_oZ[[U00?o0000ojVhi?nY^>@02_nY^>@00ol0003oZKOS
ojVgh`0:ojVgh`03o`000?nY]N;oZKGR00[oZKGR00?o0000ojVdhOl000000_l00008ojNdhP03o`00
0?nX]>7oZ;CQ00[oZ;CQ00?o0000ojVdh?nY]>002_nY]>000ol0003oZ[CPojZdh00:ojZdh003o`00
0?n[]^3oZkKP00;oZkKP0_l00007ojjgh003o`000?n_^N3o[kWP00_o[kWP00Co0000ok6jhOna^^7o
00002_na^^400ol0003o/[cQok:lh@05ok:lh@;o00001?ne_^000ol0003o][oQokJoh@0<okJoh@;o
0000M_ooool003Oooooo1?l0000=ojZji@03o`000?nY^>CoZKST00[oZKST00?o0000ojVghonY]n<0
2_nY]n<00ol0003oZKGRojVehP08ojVehP?o00002onW]>800ol0003oZ;CQojRdh@0;ojRdh@03o`00
0?nY]>3oZKCP00[oZKCP00?o0000ojZdh?nZ]>002_nZ]>001?l0003oZkKPo`000?l0000:ojjgh003
o`000?n_^N3o[kWP00_o[kWP00?o0000ok6jhOl000002ona^^400ol0003o/[cQok:lh@02ok:lh@;o
00001one_^000ol0003o][oQokJoh@0<okJoh@03o`000?oooooooooo07Cooooo000dooooo`?o0000
00GoZ[cWo`000?nZ_>OoZ[cWo`00000=ojZji@03o`000?nY^>CoZKST00[oZKST00?o0000ojVghonY
]n<02_nY]n<00ol0003oZKGRojVehP04ojVehP?o00000_nV]N<00ol0003oYkCRojNdhP0:ojNdhP03
o`000?nX]>7oZ;CQ00_oZ;CQ00?o0000ojVdh?nY]>002_nY]>000ol0003oZ[CPojZdh009ojZdh0;o
00003?n^]n000ol0003o[kWPojnih00<ojnih0;o00003?na^^401?l0003o/[cQo`000?l0000:okFn
h003o`000?nf_n7o][oQ00co][oQ00?o0000ooooooooool0Loooool003;ooooo0ol00007ojZli`03
o`000?nZ^^GoZ[[U00_oZ[[U00?o0000ojVhi?nY^>@02_nY^>@00ol0003oZKOSojVgh`0:ojVgh`03
o`000?nY]N;oZKGR00?o00001_nV]N<00ol0003oYkCRojNdhP0:ojNdhP03o`000?nX]>7oZ;CQ00[o
Z;CQ00?o0000ojVdh?nY]>002onY]>000ol0003oZ[CPojZdh005ojZdh0?o000000?o[;KPo`000?n^
]n003?n^]n000ol0003o[kWPojnih00;ojnih0;o00003?na^^42o`0000go]KkP00?o0000okJohOnf
_n402onf_n42o`0007Cooooo000aooooo`03o`000?nZ_>OoZ[cW00WoZ[cW00?o0000ojZjiOnZ^^D0
2onZ^^D00ol0003oZKSTojVhi009ojVhi003o`000?nY]n?oZKOS00[oZKOS0ol0000:ojJeh`03o`00
0?nW]>;oYkCR00[oYkCR00?o0000ojRdhOnX]>402_nX]>400ol0003oZKCPojVdh00:ojVdh003o`00
0?nZ]>3oZ[CP00?oZ[CP0_l00005ojbfh003o`000?n^]n3o[[OP00_o[[OP00?o0000ojnih?n_^N00
2on_^N000ol0003o/K[Qok6jh@08ok6jh@;o000000?o];cPo`000?ne_^003?ne_^000ol0003o][oQ
okJoh@0<okJoh@03o`000?oooooooooo07;ooooo000aooooo`;o00002onZ_>L00ol0003oZ[[UojZj
i@0:ojZji@03o`000?nY^>CoZKST00[oZKST00?o0000ojVghonY]n<01_nY]n<3o`000003ojJfi?l0
003oY[GS00_oY[GS00?o0000ojNdh_nW]>802OnW]>800ol0003oZ;CQojRdh@0;ojRdh@03o`000?nY
]>3oZKCP00[oZKCP00?o0000ojZdh?l000000_l00008ojbfh003o`000?n^]n3o[[OP00_o[[OP00?o
0000ojnih?n_^N002_n_^N02o`0000Ko/K[Q0ol00004okBlh003o`000?ne_^3o]KkP00_o]KkP00?o
0000okJohOnf_n403?nf_n400ol0003oooooooooo`1aooooo`009Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Oooooo0_l0000<ojZli`03o`000?nZ^^GoZ[[U00[oZ[[U00?o0000ojVhi?nY^>@02_nY
^>@00ol0003oZKOSojVgh`03ojVgh`;o00001OnV]^@00ol0003oY[GSojJeh`09ojJeh`03o`000?nW
]>;oYkCR00[oYkCR00?o0000ojRdhOnX]>402onX]>400ol0003oZKCPojVdh009ojVdh0;o00003?n/
]^000ol0003o[[OPojjgh00:ojjgh003o`000?n_^N3o[kWP00[o[kWP0_l00004ok6jh@;o00002?nd
_>000ol0003o]KkPokFnh00;okFnh003o`000?nf_n7o][oQ00co][oQ00?o0000ooooooooool0L?oo
ool002Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03o`000?oooooo000000coZ[cW00?o
0000ojZjiOnZ^^D02_nZ^^D00ol0003oZKSTojVhi00:ojVhi003o`000?nY]n?o000000;o00002?nV
]^@00ol0003oY[GSojJeh`09ojJeh`03o`000?nW]>;oYkCR00[oYkCR00?o0000ojRdhOnX]>402_nX
]>400ol0003oZKCPojVdh006ojVdh0?o000000?oZ[GQo`000?n/]^002on/]^000ol0003o[[OPojjg
h00;ojjgh003o`000?n_^N3o[kWP00Wo[kWP00Co0000ojnih?l0003o/K[Q0_l0000;okBlh003o`00
0?ne_^3o]KkP00_o]KkP00?o0000okJohOnf_n402onf_n42o`00077ooooo000Uooooo`05oa0@4?oo
ooooooooooooool@41001oooool01?l0003oooooooooool0000<ojZli`03o`000?nZ^^GoZ[[U00[o
Z[[U00?o0000ojVhi?nY^>@02?nY^>@3o`0000coY[KT00?o0000ojJehonV]N<02OnV]N<00ol0003o
YkCRojNdhP09ojNdhP03o`000?nX]>7oZ;CQ00_oZ;CQ00?o0000ojVdh?nY]>000onY]>02o`0000Go
Z[GQ00?o0000ojbfh?n/]^002_n/]^000ol0003o[[OPojjgh00;ojjgh003o`000?n_^N3o[kWP00So
[kWP00Co0000ojnih?l0003o00003Ond_>000ol0003o]KkPokFnh00;okFnh003o`000?nf_n7o][oQ
00Wo][oQ0_l000000oni`N3o0000ooooo`1`ooooo`009Oooool01Ol0003ooooooooooooooooo0000
00Kooooo0_l00003ooooo`03o`000?nZ_>OoZ[cW00[oZ[cW00?o0000ojZjiOnZ^^D02_nZ^^D00ol0
003oZKSTojVhi004ojVhi0?o00000_nU]nH00ol0003oY[KTojJfi00;ojJfi003o`000?nV]N?oY[GS
00WoY[GS00?o0000ojNdh_nW]>802OnW]>800ol0003oZ;CQojRdh@0;ojRdh@03o`000?nY]>3o0000
00;o00002?nZ]N400ol0003o[;KPojbfh00:ojbfh003o`000?n^]n3o[[OP00_o[[OP00?o0000ojni
h?n_^N001on_^N02o`000003ok:jh?l0003o];cP00go];cP00?o0000okFnh?ne_^002one_^000ol0
003o][oQokJoh@05okJoh@?o00001?ni`N000ol0003oooooooooo`1^ooooo`009Oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool00ol0003oZ[cWojZli`0:ojZl
i`03o`000?nZ^^GoZ[[U00[oZ[[U00?o0000ojVhi?nY^>@00ol00006ojFgiP03o`000?nV]^CoY[KT
00[oY[KT00?o0000ojJehonV]N<02OnV]N<00ol0003oYkCRojNdhP0:ojNdhP03o`000?nX]>7oZ;CQ
00[oZ;CQ0_l0000<ojZeh@03o`000?n/]^3o[;KP00[o[;KP00?o0000ojjgh?n^]n002_n^]n000ol0
003o[kWPojnih005ojnih0?o00000onb^^000ol0003o];cPokBlh00<okBlh003o`000?ne_^3o]KkP
00_o]KkP00?o0000okJohOnf_n400_nf_n42o`0000So^L7P00?o0000ooooooooool0KOooool002Go
oooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo00?o0000ojZl
ionZ_>L02_nZ_>L00ol0003oZ[[UojZji@09ojZji@?o00002_nU]nH00ol0003oY[KTojJfi00:ojJf
i003o`000?nV]N?oY[GS00WoY[GS00?o0000ojNdh_nW]>802_nW]>800ol0003oZ;CQojRdh@06ojRd
h@?o000000?oZ;CRo`000?nZ]N402onZ]N400ol0003o[;KPojbfh00:ojbfh003o`000?n^]n3o[[OP
00_o[[OP00?o0000ojnih?n_^N000_n_^N02o`0000;o/[[P00?o0000ok:jh?nb^^000_nb^^000ol0
003o];cPokBlh00<okBlh003o`000?ne_^3o]KkP00_o]KkP00Co0000okJohOl0003o00002_ni`N02
o`0006kooooo000Uooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`05
ooooo`03o`000?nZ_>OoZ[cW00[oZ[cW00?o0000ojZjiOnZ^^D01_nZ^^D2o`000003ojFiiol0003o
YKOV00_oYKOV00?o0000ojJfi?nV]^@02_nV]^@00ol0003oY[GSojJeh`09ojJeh`03o`000?nW]>;o
YkCR00WoYkCR00?o0000ojRdhOnX]>400onX]>43o`0000GoZ;CR00?o0000ojZehOnZ]N402_nZ]N40
0ol0003o[;KPojbfh00:ojbfh003o`000?n^]n3o[[OP00_o[[OP00Co0000ojnih?l0003o00001?nb
^^000ol0003o/[[Pok:jh003ok:jh003o`000?nd_>3o];cP00_o];cP00?o0000okFnh?ne_^002one
_^02o`0000go^L7P00?o0000ooooooooool0K?ooool002Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooooooo00Kooooo00?o0000ojZlionZ_>L02_nZ_>L00ol0003oZ[[UojZj
i@02ojZji@?o00001?nU^NL00ol0003oYKOVojFgiP0:ojFgiP03o`000?nV]^CoY[KT00[oY[KT00?o
0000ojJehonV]N<02OnV]N<00ol0003oYkCRojNdhP09ojNdhP03o`000?nX]>7o000000;o00002OnX
]>800ol0003oZ[GQojZeh@0:ojZeh@03o`000?n/]^3o[;KP00[o[;KP00?o0000ojjgh?n^]n002_n^
]n02o`0000Ko/[[P00?o0000ok:jh?nb^^001?nb^^000ol0003o];cPokBlh00;okBlh003o`000?ne
_^3o]KkP00So]KkP0_l000000onh_moo0000okW1h00=okW1h003o`000?oooooooooo06_ooooo000`
ooooo`03o`000?oooooooooo00Oooooo00?o0000ojZlionZ_>L02_nZ_>L01?l0003oZ[[Uo`000?l0
0008ojFii`03o`000?nU]nKoYKOV00[oYKOV00?o0000ojJfi?nV]^@02_nV]^@00ol0003oY[GSojJe
h`08ojJeh`03o`000?nW]>;oYkCR00SoYkCR0ol0000<ojRdhP03o`000?nZ]N7oZ[GQ00_oZ[GQ00?o
0000ojbfh?n/]^002_n/]^000ol0003o[[OPojjgh007ojjgh0;o000000?o/;WPo`000?nb^^001Onb
^^000ol0003o/[[Pok:jh004ok:jh003o`000?nd_>3o];cP00co];cP00?o0000okFnh?ne_^001_ne
_^000ol0003o^;oOokRog`02okRog`03o`000?ni`N3o^L7P00co^L7P00?o0000ooooooooool0J_oo
ool0033ooooo00?o0000ooooooooool02?ooool00ol0003oZ[cWojZli`08ojZli`?o00002onU^NL0
0ol0003oYKOVojFgiP0:ojFgiP03o`000?nV]^CoY[KT00[oY[KT00?o0000ojJehonV]N<02?nV]N<0
0ol0003oYkCRojNdhP04ojNdhP?o00000_nV]><00ol0003oZ;CRojRdhP0;ojRdhP03o`000?nZ]N7o
Z[GQ00[oZ[GQ00?o0000ojbfh?n/]^002_n/]^000ol0003o[[OPojjgh005ojjgh0;o00001?n`^N00
0ol0003o/[[Pok:jh003ok:jh003o`000?nb^^3o/[[P00Go/[[P00?o0000okBlh?nd_>002ond_>00
0ol0003o]KkPokFnh004okFnh0;o00001_nh_ml00ol0003o^L7PokW1h00;okW1h003o`000?oooooo
oooo06[ooooo000_ooooo`;o00002oooool00ol0003oZ[cWojZli`04ojZli`?o00000_nT^nT00ol0
003oYKWWojFii`0:ojFii`03o`000?nU]nKoYKOV00[oYKOV00?o0000ojJfi?nV]^@02OnV]^@00ol0
003oY[GSojJeh`09ojJeh`03o`000?nW]>;oYkCR00?o00001_nV]><00ol0003oZ;CRojRdhP0;ojRd
hP03o`000?nZ]N7oZ[GQ00[oZ[GQ00?o0000ojbfh?n/]^002_n/]^000ol0003o[[OPojjgh002ojjg
h0;o00001on`^N000ol0003o/[[Pok:jh002ok:jh003o`000?nb^^3o/[[P00Ko/[[P00?o0000okBl
h?nd_>002ond_>001?l0003o]KkPokFnh?ne_^02o`0000Wo^;oO00?o0000okW1h?ni`N002oni`N00
0ol0003oooooooooo`1Yooooo`00<?ooool00ol0003oooooooooo`0:ooooo`03o`000?nZ_>OoZ[cW
00?o00001_nT^nT00ol0003oYKWWojFii`0:ojFii`03o`000?nU]nKoYKOV00WoYKOV00?o0000ojJf
i?nV]^@02_nV]^@00ol0003oY[GSojJeh`08ojJeh`?o00002_nV]><00ol0003oZ;CRojRdhP0:ojRd
hP03o`000?nZ]N7oZ[GQ00_oZ[GQ00?o0000ojbfh?n/]^002_n/]^001?l0003o[[OPo`000?l0000:
ok2ih005o`000?nb^^3o/[[Pok:jh?l000002Onb^^000ol0003o];cPokBlh00;okBlh003o`000?ne
_^3o000000co^;oO00?o0000okW1h?ni`N002oni`N000ol0003oooooooooo`1Xooooo`00;oooool0
0ol0003oooooooooo`0<ooooo`;o00002_nT^nT00ol0003oYKWWojFii`0:ojFii`03o`000?nU]nKo
YKOV00WoYKOV00?o0000ojJfi?nV]^@02_nV]^@00ol0003oY[GSojJeh`04ojJeh`?o000000?oY;CT
o`000?nV]><02onV]><00ol0003oZ;CRojRdhP0:ojRdhP03o`000?nZ]N7oZ[GQ00_oZ[GQ00?o0000
ojbfh?n/]^002On/]^02o`0000co/;WP00Go0000ok:jh?nb^^3o/[[Po`00000:ok:jh003o`000?nd
_>3o];cP00[o];cP0_l0000=okRog`03o`000?ni`N3o^L7P00co^L7P00?o0000ooooooooool0Iooo
ool002oooooo00?o0000ooooooooool03Oooool00ol0003oY;_YojBkj@09ojBkj@03o`000?nU^NOo
YKWW00[oYKWW00?o0000ojFgi_nU]nH02OnU]nH00ol0003oY[KTojJfi00:ojJfi003o`000?nV]N?o
Y[GS00?o00001OnT]>@00ol0003oY[CSojJdh`0:ojJdh`03o`000?nX]>;oZ;CR00[oZ;CR00?o0000
ojZehOnZ]N402_nZ]N400ol0003o[;KPojbfh006ojbfh0?o000000?o[KSQo`000?n`^N003?n`^N00
1?l0003o/[[Pok:jh?l0000:ok:jh003o`000?nd_>3o];cP00So];cP0_l000000ong_]oo0000okRo
g`0=okRog`03o`000?ni`N3o^L7P00_o^L7P00?o0000ooooooooool0Ioooool002oooooo00?o0000
ooooooooool03_ooool00ol0003oY;_YojBkj@09ojBkj@03o`000?nU^NOoYKWW00WoYKWW00?o0000
ojFgi_nU]nH02_nU]nH00ol0003oY[KTojJfi008ojJfi0Co00002OnT]>@00ol0003oY[CSojJdh`09
ojJdh`03o`000?nX]>;oZ;CR00_oZ;CR00?o0000ojZehOnZ]N402_nZ]N400ol0003o[;KPojbfh003
ojbfh0;o00001On]^>400ol0003o/;WPok2ih00;ok2ih003o`000?nb^^3o000000_o/[[P00?o0000
okBlh?nd_>001Ond_>02o`0000Co]kkO00?o0000okRogonh_ml03?nh_ml00ol0003o^L7PokW1h00;
okW1h003o`000?oooooooooo06Kooooo000_ooooo`03o`000?oooooooooo00oooooo00?o0000ojBk
jOnT^nT02OnT^nT00ol0003oYKWWojFii`09ojFii`03o`000?nU]nKoYKOV00[oYKOV00?o0000ojJf
i?nV]^@01?nV]^@3o`0000;oX[GV00?o0000ojBdi?nT]>@02OnT]>@00ol0003oY[CSojJdh`09ojJd
h`03o`000?nX]>;oZ;CR00[oZ;CR00?o0000ojZehOnZ]N402onZ]N400ol0003o[;KPo`000002o`00
00So[KSQ00?o0000ok2ih?n`^N002on`^N02o`0000co/[[P00?o0000okBlh?nd_>000_nd_>02o`00
00Oo]kkO00?o0000okRogonh_ml03?nh_ml00ol0003o^L7PokW1h00:okW1h0;o0000Ioooool002ko
oooo0ol0000Aooooo`03o`000?nT^nWoY;_Y00WoY;_Y00?o0000ojFiionU^NL02OnU^NL00ol0003o
YKOVojFgiP0:ojFgiP03o`000?nV]^CoY[KT00?o00001_nR]NH00ol0003oY;CTojBdi009ojBdi003
o`000?nV]>?oY[CS00WoY[CS00?o0000ojRdh_nX]>802_nX]>800ol0003oZ[GQojZeh@0:ojZeh@;o
00003?n]^>400ol0003o/;WPok2ih00:ok2ih0;o00003Onb^^001?l0003o];cPo`000?l0000:okNn
g`03o`000?nh_moo^;oO00_o^;oO00?o0000okW1h?ni`N002?ni`N02o`000003ok_2gol0003o0000
06Kooooo000_ooooo`03o`000?oooooooooo017ooooo00?o0000ojBkjOnT^nT02?nT^nT00ol0003o
YKWWojFii`0:ojFii`03o`000?nU]nKoYKOV00SoYKOV1?l0000:oj:eiP03o`000?nT]>CoY;CT00So
Y;CT00?o0000ojJdhonV]><02_nV]><00ol0003oZ;CRojRdhP0:ojRdhP03o`000?nZ]N7oZ[GQ00Ko
Z[GQ0ol000000on[]n;o0000ojfhh@0;ojfhh@03o`000?n`^N3o/;WP00_o/;WP00?o0000ok:jh?nb
^^002onb^^02o`0000go]kkO00?o0000okRogonh_ml02onh_ml00ol0003o^L7PokW1h005okW1h0;o
00001?nk`]l00ol0003oooooooooo`1Tooooo`00;oooool00ol0003oooooooooo`0Booooo`03o`00
0?nT^nWoY;_Y00SoY;_Y00?o0000ojFiionU^NL02_nU^NL00ol0003oYKOVojFgiP04ojFgiP?o0000
0_nQ]^P00ol0003oX[GVoj:eiP0:oj:eiP03o`000?nT]>CoY;CT00SoY;CT00?o0000ojJdhonV]><0
2_nV]><00ol0003oZ;CRojRdhP09ojRdhP03o`000?nZ]N7oZ[GQ00?oZ[GQ0ol00005oj^ghP03o`00
0?n]^>7o[KSQ00[o[KSQ00?o0000ok2ih?n`^N002_n`^N02o`0000[o/[[P0_l000000ond_>3o0000
okNng`0<okNng`03o`000?nh_moo^;oO00co^;oO00?o0000okW1h?ni`N000_ni`N02o`0000Oo^l;O
00?o0000ooooooooool0Hoooool002oooooo00?o0000ooooooooool04oooool00ol0003oY;_YojBk
j@08ojBkj@03o`000?nU^NOoYKWW00[oYKWW00?o0000ojFgi_nU]nH00ol00006oj6fj003o`000?nR
]NKoX[GV00[oX[GV00?o0000ojBdi?nT]>@02?nT]>@00ol0003oY[CSojJdh`09ojJdh`03o`000?nX
]>;oZ;CR00[oZ;CR00?o0000ojZehOl000000_l00009oj^ghP03o`000?n]^>7o[KSQ00[o[KSQ00?o
0000ok2ih?n`^N002On`^N02o`0000Oo/[[P0ol00004okBlh003o`000?ng_]oo]kkO00_o]kkO00?o
0000okRogonh_ml03?nh_ml01?l0003o^L7Po`000?l0000:ok_2g`03o`000?oooooooooo06;ooooo
000_ooooo`03o`000?oooooooooo01?ooooo0_l0000:ojBkj@03o`000?nU^NOoYKWW00SoYKWW1?l0
000:oj6fj003o`000?nR]NKoX[GV00WoX[GV00?o0000ojBdi?nT]>@02OnT]>@00ol0003oY[CSojJd
h`09ojJdh`03o`000?nX]>;oZ;CR00SoZ;CR0ol0000=oj^ghP03o`000?n]^>7o[KSQ00[o[KSQ00?o
0000ok2ih?n`^N002?n`^N000ol0003o/;WPo`000004ok:jh0;o00002?nd_>000ol0003o]kkOokNn
g`0;okNng`03o`000?nh_moo^;oO00_o^;oO0_l0000<ok_2g`;o0000Hoooool002kooooo00?o0000
ooooooooool05Oooool2o`0000[oY;_Y00?o0000ojFiionU^NL01?nU^NL3o`0000;oWkOY00?o0000
oj6fj?nQ]^P02_nQ]^P00ol0003oX[GVoj:eiP09oj:eiP03o`000?nT]>CoY;CT00WoY;CT00?o0000
ojJdhonV]><02OnV]><00ol0003oZ;CRojRdhP04ojRdhP?o00000_nW]^<00ol0003oZkORoj^ghP0;
oj^ghP03o`000?n]^>7o[KSQ00[o[KSQ00?o0000ok2ih?n`^N002?n`^N001Ol0003o/;WPok2ih?l0
003o/[[P00;o00002_nd_>000ol0003o]kkOokNng`0<okNng`03o`000?nh_moo^;oO00So^;oO0_l0
00000onj`Moo0000ok_2g`0<ok_2g`03o`000?oooooooooo067ooooo000^ooooo`?o00005_ooool2
o`0000[oY;_Y00?o0000ojFiionU^NL00ol00006oingj@03o`000?nQ]^SoXKKX00[oXKKX00?o0000
oj:ei_nR]NH02OnR]NH00ol0003oY;CTojBdi009ojBdi003o`000?nV]>?oY[CS00WoY[CS00?o0000
ojRdh_nX]>800ol00006ojNfh`03o`000?n[]n;oZkOR00_oZkOR00?o0000ojfhhOn]^>402_n]^>40
0ol0003o/;WPok2ih007ok2ih003o`000?n`^N3o/;WP00;o00003Ond_>000ol0003o]kkOokNng`0;
okNng`03o`000?nh_moo^;oO00Oo^;oO00?o0000ok[1gonj`Ml00_nj`Ml00ol0003o^l;Ook_2g`0;
ok_2g`03o`000?oooooooooo063ooooo000^ooooo`03o`000?oooooooooo01Oooooo0_l00008ojBk
j@Co00002_nO]nT00ol0003oXKKXoj6fj009oj6fj003o`000?nR]NKoX[GV00[oX[GV00?o0000ojBd
i?nT]>@02?nT]>@00ol0003oY[CSojJdh`09ojJdh`?o00002_nW]^<00ol0003oZkORoj^ghP0;oj^g
hP03o`000?n]^>7o[KSQ00[o[KSQ00?o0000ok2ih?n`^N001_n`^N03o`000003ok:khOl0003o];cP
00go];cP00?o0000okNngong_]l02ong_]l00ol0003o^;oOokRog`04okRog`;o00001_nj`Ml00ol0
003o^l;Ook_2g`0;ok_2g`03o`000?oooooooooo05oooooo000Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00007ooooo`03o`000?oooooooooo01Sooooo0_l00002ojBk
j@Go00000_nO^N/00ol0003oWkOYoingj@0:oingj@03o`000?nQ]^SoXKKX00WoXKKX00?o0000oj:e
i_nR]NH02_nR]NH00ol0003oY;CTojBdi008ojBdi003o`000?nV]>?oY[CS00KoY[CS0_l000000onT
]NCo0000ojNfh`0;ojNfh`03o`000?n[]n;oZkOR00_oZkOR00?o0000ojfhhOn]^>402On]^>400ol0
003o/;WPok2ih005ok2ih0;o00001?nb^n400ol0003o];cPokBlh00;okBlh003o`000?ng_]oo]kkO
00co]kkO00Co0000okRogonh_moo^;oO0_l00009ok[1g`03o`000?nk`]oo^l;O00_o^l;O00?o0000
ooooooooool0G_ooool001;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o0000ooooooooool06Oooool3o`0000SoWkW[00?o
0000oingjOnO]nT02_nO]nT00ol0003oXKKXoj6fj009oj6fj003o`000?nR]NKoX[GV00WoX[GV00?o
0000ojBdi?nT]>@02OnT]>@00ol0003oY[CSojJdh`02ojJdh`?o00001?nT]N@00ol0003oYkKSojNf
h`0:ojNfh`03o`000?n[]n;oZkOR00[oZkOR00?o0000ojfhhOn]^>402_n]^>400ol0003o/;WPok2i
h002ok2ih0;o000000?o/[_Qo`000?nb^n401?nb^n400ol0003o];cPokBlh00;okBlh003o`000?ng
_]oo]kkO00co]kkO00?o0000okRogol000002onj`Ml00ol0003o^l;Ook_2g`0;ok_2g`03o`000?oo
oooooooo05kooooo000Booooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP08ooooo`03o`000?oooooooooo01[ooooo00?o0000oinijonO^N/02?nO^N/00ol0003oWkOYoing
j@0:oingj@03o`000?nQ]^SoXKKX00WoXKKX00?o0000oj:ei_nR]NH02OnR]NH00ol0003oY;CTojBd
i009ojBdi004o`000?nV]>?o0000o`0000SoY;GT00?o0000ojNfhonW]^<02OnW]^<00ol0003oZkOR
oj^ghP0;oj^ghP03o`000?n]^>7o[KSQ00[o[KSQ00Co0000ok2ih?l0003o00000onb^n400ol0003o
/[_Qok:kh@04ok:kh@03o`000?nd_>3o];cP00_o];cP00?o0000okNngong_]l02ong_]l2o`0000go
^/7O00?o0000ok_2gonk`]l02onk`]l00ol0003oooooooooo`1Mooooo`004_ooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`0Kooooo`03
o`000?nO^N_oWkW[00SoWkW[00?o0000oingjOnO]nT02_nO]nT00ol0003oXKKXoj6fj009oj6fj003
o`000?nR]NKoX[GV00WoX[GV00?o0000ojBdi?nT]>@01onT]>@3o`0000_oY;GT00?o0000ojNfhonW
]^<02OnW]^<00ol0003oZkORoj^ghP0;oj^ghP03o`000?n]^>7o[KSQ00Wo[KSQ0_l00005ok:kh@03
o`000?nb^n7o/[_Q00Co/[_Q00?o0000okBlh?nd_>002ond_>000ol0003o]kkOokNng`09okNng`;o
000000?o^L3Oo`000?nj`Ml03Onj`Ml00ol0003o^l;Ook_2g`0;ok_2g`03o`000?oooooooooo05co
oooo000Booooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`06ooooo`03
o`000?oooooooooo01cooooo00?o0000oinijonO^N/02?nO^N/00ol0003oWkOYoingj@09oingj@03
o`000?nQ]^SoXKKX00WoXKKX00?o0000oj:ei_nR]NH02_nR]NH01?l0003oY;CTojBdi?nT]>@5o`00
00;oX[GV00?o0000ojBei?nT]N@02_nT]N@00ol0003oYkKSojNfh`09ojNfh`03o`000?n[]n;oZkOR
00[oZkOR00?o0000ojfhhOn]^>401_n]^>43o`000003ojnjh_l0003o/[_Q00Co/[_Q00?o0000ok:k
hOnb^n401Onb^n400ol0003o];cPokBlh00;okBlh003o`000?ng_]oo]kkO00Ko]kkO0_l00004okW0
g`03o`000?nj`Moo^/7O00_o^/7O00?o0000ok_2gonk`]l02onk`]l2o`0005gooooo000Booooo`05
oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`;o00007oooool00ol0
003oWkW[oinij`08oinij`03o`000?nO]nWoWkOY00WoWkOY00?o0000oj6fj?nQ]^P02OnQ]^P00ol0
003oX[GVoj:eiP08oj:eiPGo00002?nR]NH00ol0003oY;GTojBei009ojBei003o`000?nW]^?oYkKS
00[oYkKS00?o0000oj^gh_n[]n802_n[]n800ol0003o[KSQojfhh@03ojfhh@;o00001On_^^800ol0
003o/[_Qok:kh@02ok:kh@03o`000?nb^n7o/[_Q00Ko/[_Q00?o0000okBlh?nd_>002ond_>000ol0
003o]kkOokNng`04okNng`03o`000?ni`=oo^L3O00Go^L3O00?o0000ok[1gonj`Ml02onj`Ml00ol0
003o^l;Ook_2g`08ok_2g`;o000000?o_<?Oo`000?ooool0G?ooool001;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0O
ooooo`03o`000?nO^N_oWkW[00SoWkW[00?o0000oingjOnO]nT02OnO]nT00ol0003oXKKXoj6fj009
oj6fj003o`000?nR]NKoX[GV00CoX[GV0ol00002oinej003o`000?nR]NKoX[GV00WoX[GV00?o0000
ojBei?nT]N@02OnT]N@00ol0003oYkKSojNfh`0:ojNfh`03o`000?n[]n;oZkOR00[oZkOR00?o0000
ojfhhOl000000_l00008ojnjhP05o`000?nb^n7o/[_Qok:khOl000002Onb^n400ol0003o];cPokBl
h00:okBlh003o`000?ng_]oo]kkO00;o]kkO0_l00009okW0g`03o`000?nj`Moo^/7O00_o^/7O00?o
0000ok_2gonk`]l01_nk`]l00ol0003o_<?Ookc3g`02okc3g`03o`000?oooooooooo05[ooooo000B
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool08?ooool00ol0003oWkW[oinij`08oinij`03o`000?nO]nWoWkOY00WoWkOY
00?o0000oj6fj?nQ]^P02OnQ]^P00ol0003oX[GVoj:eiP03o`0000KoWkGX00?o0000oj:ei_nR]NH0
2OnR]NH00ol0003oY;GTojBei009ojBei003o`000?nW]^?oYkKS00WoYkKS00?o0000oj^gh_n[]n80
2_n[]n82o`0000co[k[R00Co0000ok:khOnb^n7o00002Onb^n400ol0003o];cPokBlh00;okBlh004
o`000?ng_]oo0000o`0000_o^L3O00?o0000ok[1gonj`Ml03?nj`Ml00ol0003o^l;Ook_2g`03ok_2
g`;o00001_nl`ml00ol0003oooooooooo`1Iooooo`00;Oooool00ol0003oooooooooo`0Qooooo`03
o`000?nO^N_oWkW[00SoWkW[00?o0000oingjOnO]nT02OnO]nT00ol0003oXKKXoj6fj007oj6fj0Co
00002_nO]NP00ol0003oX[GVoj:eiP09oj:eiP03o`000?nT]NCoY;GT00WoY;GT00?o0000ojNfhonW
]^<02OnW]^<00ol0003oZkORoj^ghP06oj^ghP?o000000?oZkSSo`000?n_^^803?n_^^800ol0003o
/[_Qo`00000:ok:kh@03o`000?nd_>3o];cP00[o];cP0_l0000>okW0g`03o`000?nj`Moo^/7O00_o
^/7O00Co0000ok_2gonk`]oo^l;O0_l00009okc3g`03o`000?oooooooooo05Sooooo000]ooooo`03
o`000?oooooooooo027ooooo00?o0000oinijonO^N/02OnO^N/00ol0003oWkOYoingj@09oingj@04
o`000?nQ]^SoXKKXoj6fj0Go00000_nL]NT00ol0003oWkGXoinej00:oinej003o`000?nR]NKoX[GV
00SoX[GV00?o0000ojBei?nT]N@02_nT]N@00ol0003oYkKSojNfh`09ojNfh`03o`000?n[]n;oZkOR
00?oZkOR0_l00005oj^hh`03o`000?n_^^;o[k[R00[o[k[R00?o0000ok:khOl000002onb^n400ol0
003o];cPokBlh007okBlh0;o000000?o][kPo`000?ni`=l03_ni`=l00ol0003o^/7Ook[1g`0;ok[1
g`03o`000?nk`]oo000000_o_<?O00?o0000ooooooooool0F?ooool002gooooo00?o0000oooooooo
ool08_ooool00ol0003oWkW[oinij`09oinij`03o`000?nO]nWoWkOY00SoWkOY1?l00008oibej@03
o`000?nO]NSoWkGX00[oWkGX00?o0000oj:ei_nR]NH02?nR]NH00ol0003oY;GTojBei009ojBei003
o`000?nW]^?oYkKS00[oYkKS00?o0000oj^gh_l000000_l00008oj^hh`03o`000?n_^^;o[k[R00[o
[k[R0_l0000;ok:kh@03o`000?nd_>3o];cP00Go];cP0_l00004okJnh003o`000?ni`=oo^L3O00co
^L3O00?o0000ok[1gonj`Ml02onj`Ml2o`0000go_<?O00?o0000ooooooooool0Eoooool002cooooo
0ol0000Tooooo`03o`000?nO^N_oWkW[00WoWkW[00?o0000oingjOnO]nT01?nO]nT3o`000003oiZf
jol0003oW;GY00[oW;GY00?o0000oinej?nO]NP02OnO]NP00ol0003oX[GVoj:eiP09oj:eiP03o`00
0?nT]NCoY;GT00WoY;GT00?o0000ojNfhonW]^<02?nW]^<3o`0000coZkSS00?o0000ojnjh_n_^^80
2_n_^^800ol0003o/[_Qok:kh@0:ok:kh@03o`000?nd_>3o];cP00;o];cP0_l00007okJnh003o`00
0?ni`=oo^L3O00co^L3O00?o0000ok[1gonj`Ml02?nj`Ml2o`000003okc2gol0003o_<?O00go_<?O
00?o0000ooooooooool0E_ooool002gooooo00?o0000ooooooooool09?ooool00ol0003oWkW[oini
j`09oinij`03o`000?nO]nWoWkOY00?o00001OnJ]^/00ol0003oW;GYoibej@09oibej@03o`000?nO
]NSoWkGX00WoWkGX00?o0000oj:ei_nR]NH02OnR]NH00ol0003oY;GTojBei009ojBei003o`000?nW
]^?oYkKS00CoYkKS0ol00002ojNgi003o`000?n[^>?oZkSS00[oZkSS00?o0000ojnjh_n_^^802_n_
^^82o`0000co/[_Q00Co0000okBlh?l0003o00002_nf_^000ol0003o^L3OokW0g`0<okW0g`03o`00
0?nj`Moo^/7O00Ko^/7O00?o0000okc2gonl`]l00_nl`]l00ol0003o_<?Ookc3g`0<okc3g`03o`00
0?oooooooooo05Gooooo000]ooooo`03o`000?oooooooooo02Gooooo00?o0000oinijonO^N/01onO
^N/4o`0000WoV[K[00?o0000oibejOnL]NT02OnL]NT00ol0003oWkGXoinej009oinej003o`000?nR
]NKoX[GV00SoX[GV00?o0000ojBei?nT]N@02_nT]N@00ol0003oYkKSojNfh`03o`0000KoYkOT00?o
0000oj^hhon[^><02_n[^><00ol0003o[k[RojnjhP09ojnjhP;o00003?nb^n42o`0000go][kP00?o
0000okW0goni`=l03?ni`=l00ol0003o^/7Ook[1g`03ok[1g`;o00001_nl`]l00ol0003o_<?Ookc3
g`0;okc3g`;o0000E_ooool002gooooo00?o0000ooooooooool09_ooool01?l0003oWkW[oinijonO
^N/5o`0000;oVKO]00?o0000oiZfjonJ]^/02OnJ]^/00ol0003oW;GYoibej@09oibej@03o`000?nO
]NSoWkGX00WoWkGX00?o0000oj:ei_nR]NH02?nR]NH00ol0003oY;GTojBei008ojBei0Co00002_nW
]n@00ol0003oZkSSoj^hh`0:oj^hh`03o`000?n_^^;o[k[R00So[k[R00?o0000ojnjh_l000002?nb
^n43o`000003ok>mhOl0003o][kP00go][kP00?o0000okW0goni`=l02oni`=l01?l0003o^/7Ook[1
gonj`Ml2o`0000Wo_<;O00?o0000okc3gonl`ml02onl`ml00ol0003oooooooooo`1Dooooo`00;?oo
ool00ol0003oooooooooo`0Xooooo`?o00002?nI]nd00ol0003oV[K[oiZfj`09oiZfj`03o`000?nL
]NWoW;GY00WoW;GY00?o0000oinej?nO]NP02OnO]NP00ol0003oX[GVoj:eiP08oj:eiP03o`000?nT
]NCoY;GT00CoY;GT0ol00002oj>fiP03o`000?nW]nCoYkOT00[oYkOT00?o0000oj^hhon[^><02_n[
^><00ol0003o[k[RojnjhP07ojnjhP04o`000?n_^^;o[k[Ro`0000Go/[_Q0_l00005ok>mh@03o`00
0?nf_^3o][kP00co][kP00?o0000okW0goni`=l02oni`=l00ol0003o^/7Oo`00000;okc2g`03o`00
0?nl`moo_<?O00co_<?O00?o0000ooooooooool0Doooool002cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oVKO]oiVgk@08oiVgk@03o`000?nJ]^_oV[K[00WoV[K[00?o0000oibejOnL]NT02?nL
]NT00ol0003oWkGXoinej009oinej003o`000?nR]NKoX[GV00WoX[GV00?o0000ojBei?nT]N@00ol0
0006oj>fiP03o`000?nW]nCoYkOT00[oYkOT00?o0000oj^hhon[^><02On[^><00ol0003o[k[Rojnj
hP07ojnjhP06o`000?n_^^;o[k[Rojnjh_l0003o/[_Q0ol00008ok>mh@03o`000?nf_^3o][kP00_o
][kP00?o0000okW0goni`=l02oni`=l2o`0000go_<;O00?o0000okc3gonl`ml03?nl`ml00ol0003o
ooooooooo`1Booooo`00;?ooool2o`0002_ooooo00?o0000oiVgkOnI]nd02?nI]nd00ol0003oV[K[
oiZfj`09oiZfj`03o`000?nL]NWoW;GY00SoW;GY00?o0000oinej?nO]NP02OnO]NP00ol0003oX[GV
oj:eiP08oj:eiP?o00002_nS]^H00ol0003oYkOTojNgi009ojNgi003o`000?n[^>?oZkSS00[oZkSS
00?o0000ojnjh_n_^^801_n_^^801?l0003o[k[Rojnjh_n_^^82o`0000co/kgQ00?o0000okJnh?nf
_^002onf_^000ol0003o^L3OokW0g`08okW0g`;o000000?o^/;Po`000?nl`]l03Onl`]l00ol0003o
_<?Ookc3g`0;okc3g`;o0000Doooool002cooooo00?o0000ooooooooool0:oooool00ol0003oVKO]
oiVgk@08oiVgk@03o`000?nJ]^_oV[K[00SoV[K[00?o0000oibejOnL]NT02OnL]NT00ol0003oWkGX
oinej009oinej003o`000?nR]NKoX[GV00CoX[GV0ol000000onO]NSo0000oj>fiP0;oj>fiP03o`00
0?nW]nCoYkOT00WoYkOT00?o0000oj^hhon[^><02_n[^><00ol0003o[k[RojnjhP05ojnjhP06o`00
0?n_^^;o0000o`000?n`_>?o00003Onc_N400ol0003o][kPokJnh00;okJnh003o`000?ni`=oo^L3O
00Go^L3O0_l00004ok[2h003o`000?nl`]oo_<;O00co_<;O00?o0000okc3gonl`ml02?nl`ml2o`00
0003okg3gol0003ooooo05;ooooo000/ooooo`03o`000?oooooooooo02cooooo00?o0000oiVgkOnI
]nd02?nI]nd00ol0003oV[K[oiZfj`08oiZfj`03o`000?nL]NWoW;GY00WoW;GY00?o0000oinej?nO
]NP02OnO]NP00ol0003oX[GVoj:eiP03o`0000GoWkGX00?o0000oj>fi_nS]^H02OnS]^H00ol0003o
YkOTojNgi00:ojNgi003o`000?n[^>?oZkSS00WoZkSS00?o0000ojnjh_n_^^801On_^^82o`0000Co
/;cS00?o0000ok>mhOnc_N402onc_N400ol0003o][kPokJnh00;okJnh003o`000?ni`=oo^L3O00;o
^L3O0_l00007ok[2h003o`000?nl`]oo_<;O00co_<;O00?o0000okc3gonl`ml01_nl`ml00ol0003o
_L?Ookg3g`02okg3g`03o`000?oooooooooo053ooooo000/ooooo`03o`000?oooooooooo02gooooo
00?o0000oiVgkOnI]nd02?nI]nd00ol0003oV[K[oiZfj`08oiZfj`03o`000?nL]NWoW;GY00WoW;GY
00?o0000oinej?nO]NP01onO]NP4o`0000WoWkGX00?o0000oj>fi_nS]^H02OnS]^H00ol0003oYkOT
ojNgi00:ojNgi003o`000?n[^>?oZkSS00WoZkSS00?o0000ojnjh_n_^^800_n_^^83o`0000Ko/;cS
00?o0000ok>mhOnc_N402onc_N400ol0003o][kPokJnh00;okJnh004o`000?ni`=oo0000o`0000[o
^/;P00?o0000okc2gonl`]l02onl`]l00ol0003o_<?Ookc3g`04okc3g`;o00001_nm`ml00ol0003o
ooooooooo`1?ooooo`00;?ooool00ol0003oooooooooo`0^ooooo`03o`000?nI]ngoVKO]00SoVKO]
00?o0000oiZfjonJ]^/02?nJ]^/00ol0003oW;GYoibej@09oibej@04o`000?nO]NSoWkGXoinej0Go
00000_nK]>T00ol0003oWkGXoinej009oinej003o`000?nS]^KoXkKV00WoXkKV00?o0000ojNgi?nW
]n@02OnW]n@00ol0003oZkSSoj^hh`0:oj^hh`04o`000?n_^^;o0000o`0000;o/;cS00?o0000ok2l
hon`_><01On`_><00ol0003o/kgQok>mh@0:ok>mh@03o`000?nf_^3o][kP00_o][kP0_l0000<ok[2
h003o`000?nl`]oo_<;O00co_<;O00Co0000okc3gonl`moo_<?O0_l00008okg3g`;o0000D?ooool0
02cooooo00?o0000ooooooooool0;oooool00ol0003oVKO]oiVgk@08oiVgk@03o`000?nJ]^_oV[K[
00SoV[K[00?o0000oibejOnL]NT01onL]NT5o`0000SoVkCY00?o0000oinej?nO]NP02OnO]NP00ol0
003oXkKVoj>fiP09oj>fiP03o`000?nW]nCoYkOT00WoYkOT00?o0000oj^hhon[^><02?n[^><3o`00
00Co/;cS00?o0000ok2lhon`_><01_n`_><00ol0003o/kgQok>mh@0:ok>mh@03o`000?nf_^3o][kP
00So][kP0_l000000onh`N7o0000ok[2h00<ok[2h003o`000?nl`]oo_<;O00co_<;O00?o0000okc3
gol000002onm`ml00ol0003oooooooooo`1>ooooo`00;?ooool2o`00037ooooo00?o0000oiVgkOnI
]nd02?nI]nd00ol0003oV[K[oiZfj`08oiZfj`04o`000?nL]NWoW;GYoibej@Go00000_nH]>/00ol0
003oVkCYoi^dj@09oi^dj@03o`000?nO]NSoWkGX00WoWkGX00?o0000oj>fi_nS]^H02?nS]^H00ol0
003oYkOTojNgi00:ojNgi003o`000?n[^>?oZkSS00CoZkSS0ol00002ojbji003o`000?n`_>?o/;cS
00;o/;cS00?o0000ok2lhon`_><01_n`_><00ol0003o/kgQok>mh@0;ok>mh@03o`000?nf_^3o][kP
00Go][kP0_l00004okS1h@03o`000?nj`^3o^/;P00_o^/;P00?o0000okc2gonl`]l02onl`]l2o`00
00go_L?O00?o0000ooooooooool0COooool002_ooooo00?o0000ooooooooool0<_ooool00ol0003o
VKO]oiVgk@08oiVgk@03o`000?nJ]^_oV[K[00KoV[K[1Ol00008oiRdj`03o`000?nK]>WoVkCY00Wo
VkCY00?o0000oinej?nO]NP02OnO]NP00ol0003oXkKVoj>fiP08oj>fiP03o`000?nW]nCoYkOT00[o
YkOT00?o0000oj^hhon[^><00ol00006ojbji005o`000?n`_>?o/;cSok2lhol000002On`_><00ol0
003o/kgQok>mh@0;ok>mh@03o`000?nf_^3o][kP00;o][kP0_l00007okS1h@03o`000?nj`^3o^/;P
00_o^/;P00?o0000okc2gonl`]l02?nl`]l2o`000003okc3gol0003o_L?O00go_L?O00?o0000oooo
ooooool0C?ooool002_ooooo00?o0000ooooooooool0<oooool00ol0003oVKO]oiVgk@08oiVgk@03
o`000?nJ]^_oV[K[00Go00000_nF]>d00ol0003oV;C[oiRdj`09oiRdj`03o`000?nK]>WoVkCY00Wo
VkCY00?o0000oinej?nO]NP02?nO]NP00ol0003oXkKVoj>fiP09oj>fiP03o`000?nW]nCoYkOT00Wo
YkOT0ol0000:ojbji004o`000?n`_>?o/;cSo`0000[o/;cS00?o0000ok>mhOnc_N402onc_N401?l0
003o][kPo`000?l0000:okS1h@03o`000?nj`^3o^/;P00_o^/;P00?o0000okc2gonl`]l01_nl`]l0
0ol0003o_<?Ookc3g`02okc3g`03o`000?nm`moo_L?O00_o_L?O0_l0001=ooooo`004?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool0
0ol0003oooooooooo`0dooooo`03o`000?nI]ngoVKO]00KoVKO]1?l00008oiJdk@03o`000?nH]>_o
V;C[00WoV;C[00?o0000oi^djOnK]>T02?nK]>T00ol0003oWkGXoinej009oinej003o`000?nS]^Ko
XkKV00SoXkKV00?o0000ojNgi?nW]n@01_nW]n@3o`000003ojNii_l0003o[;[T00_o[;[T00?o0000
ok2lhol000002on`_><00ol0003o/kgQok>mh@0:ok>mh@;o00003?nh`N400ol0003o^/;Pok[2h00;
ok[2h003o`000?nl`]oo_<;O00Co_<;O0_l00006okc3g`03o`000?nm`moo_L?O00_o_L?O0_l0001<
ooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0=Oooool00ol0003oVKO]oiVgk@05o`0000;oU;G^00?o0000
oiJdkOnF]>d02?nF]>d00ol0003oV;C[oiRdj`09oiRdj`03o`000?nK]>WoVkCY00SoVkCY00?o0000
oinej?nO]NP02OnO]NP00ol0003oXkKVoj>fiP08oj>fiP03o`000?nW]nCoYkOT00?oYkOT0_l00005
ojNiiP03o`000?n/^^Co[;[T00[o[;[T0_l0000;ok2lh`03o`000?nc_N7o/kgQ00So/kgQ0_l00000
0ond_n;o0000okS1h@0<okS1h@03o`000?nj`^3o^/;P00_o^/;P00Co0000okc2gonl`]oo_<;O0_l0
0009okc3g`03o`000?nm`moo_L?O00_o_L?O00?o0000ooooooooool0B_ooool0013ooooo00Go410@
oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`0fooooo`;o00002?nD
]Nh00ol0003oU[C]oiJdk@08oiJdk@03o`000?nH]>_oV;C[00WoV;C[00?o0000oi^djOnK]>T02?nK
]>T00ol0003oWkGXoinej009oinej003o`000?nS]^KoXkKV00SoXkKV00?o0000ojNgi?l000000_l0
0008ojNiiP03o`000?n/^^Co[;[T00[o[;[T00?o0000ok2lhon`_><02_n`_><00ol0003o/kgQok>m
h@05ok>mh@;o00001?nd_n800ol0003o^<7QokS1h@0;okS1h@03o`000?nj`^3o^/;P00_o^/;P00?o
0000okc2gol000002onl`ml00ol0003o_L?Ookg3g`0<okg3g`03o`000?oooooooooo04Wooooo000@
ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`00
0?oooooooooo03Oooooo00?o0000oiBek_nD]Nh01onD]Nh00ol0003oU[C]oiJdk@08oiJdk@03o`00
0?nH]>_oV;C[00WoV;C[00?o0000oi^djOnK]>T02?nK]>T00ol0003oWkGXoinej009oinej003o`00
0?nS]^KoXkKV00KoXkKV0ol0000<ojNiiP03o`000?n/^^Co[;[T00Wo[;[T0_l0000<ok2lh`03o`00
0?nc_N7o/kgQ00;o/kgQ0_l00007okBohP03o`000?nh`N7o^<7Q00_o^<7Q00?o0000ok[2h?nj`^00
2_nj`^02o`0000go_<?O00?o0000okg3gonm`ml02onm`ml2o`0004[ooooo000@ooooo`05o`000?oo
ooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo03So
oooo00?o0000oiBek_nD]Nh01onD]Nh00ol0003oU[C]oiJdk@08oiJdk@03o`000?nH]>_oV;C[00So
V;C[00?o0000oi^djOnK]>T02?nK]>T00ol0003oWkGXoinej00:oinej003o`000?nS]^KoXkKV00Go
00000_nR^>P00ol0003oYkWVojNiiP0;ojNiiP03o`000?n/^^Co[;[T00So[;[T0_l0000=ok2lh`04
o`000?nc_N7o0000o`0000[o];oR00?o0000okS1hOnh`N402onh`N400ol0003o^/;Pok[2h007ok[2
h0;o000000?o^l?Qo`000?nl`ml03Onl`ml00ol0003o_L?Ookg3g`0;okg3g`;o0000BOooool0013o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo0_l0000koooo
o`03o`000?nD]NkoU;G^00OoU;G^00?o0000oiJdkOnF]>d02?nF]>d00ol0003oV;C[oiRdj`08oiRd
j`03o`000?nK]>WoVkCY00SoVkCY00?o0000oinej?nO]NP02?nO]NP4o`0000SoX[SX00?o0000ojNi
i_nW^NH02_nW^NH00ol0003o[;[Tojbji008ojbji003o`000?n/^^Co000000co/;cS0_l0000<okBo
hP03o`000?nh`N7o^<7Q00_o^<7Q00?o0000ok[2h?nj`^001Onj`^02o`0000Co^l?Q00?o0000okc3
gonl`ml03?nl`ml00ol0003o_L?Ookg3g`08okg3g`;o000000?o_LCOo`000?ooool0B?ooool0013o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000oooo
ooooool0>_ooool00ol0003oU;G^oiBekP07oiBekP03o`000?nF]>goU[C]00SoU[C]00?o0000oiRd
jonH]>/02?nH]>/00ol0003oVkCYoi^dj@08oi^dj@03o`000?nO]NSoWkGX00CoWkGX0ol00002oiff
j@03o`000?nR^>SoX[SX00SoX[SX00?o0000ojNii_nW^NH02_nW^NH00ol0003o[;[Tojbji007ojbj
i004o`000?n/^^Co[;[To`0000So/;cS0ol000000on`_^Co0000okBohP0<okBohP03o`000?nh`N7o
^<7Q00_o^<7Q00?o0000ok[2h?nj`^000_nj`^02o`0000Oo^l?Q00?o0000okc3gonl`ml03?nl`ml0
0ol0003o_L?Ookg3g`06okg3g`03o`000?nma=oo_LCO00;o_LCO00?o0000ooooooooool0A_ooool0
013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000
ooooooooool0??ooool00ol0003oU;G^oiBekP07oiBekP03o`000?nF]>goU[C]00SoU[C]00?o0000
oiRdjonH]>/02?nH]>/00ol0003oVkCYoi^dj@08oi^dj@03o`000?nO]NSoWkGX00?o00001_nM]^T0
0ol0003oX[SXoj:hj008oj:hj003o`000?nW^NKoYkWV00[oYkWV00?o0000ojbji?n/^^@01_n/^^@0
1Ol0003o[;[Tojbji?n/^^Co000000Go/;cS0_l00005ok2ni003o`000?nd_n;o];oR00_o];oR00?o
0000okS1hOnh`N402onh`N401?l0003o^/;Po`000?l0000:ok_3h@03o`000?nl`moo_<?O00_o_<?O
00?o0000okg3gonm`ml01?nm`ml2o`0000Go_LCO0_l00017ooooo`00:_ooool00ol0003ooooooooo
o`0mooooo`03o`000?nD]NkoU;G^00OoU;G^00?o0000oiJdkOnF]>d02?nF]>d00ol0003oV;C[oiRd
j`08oiRdj`03o`000?nK]>WoVkCY00KoVkCY1?l0000:oiffj@03o`000?nR^>SoX[SX00SoX[SX00?o
0000ojNii_nW^NH02_nW^NH00ol0003o[;[Tojbji005ojbji003o`000?n/^^Co[;[T00;o[;[T00?o
0000ok2lhol000000_l00008ok2ni003o`000?nd_n;o];oR00_o];oR00?o0000okS1hOnh`N402_nh
`N42o`0000go^l?Q00?o0000okc3gonl`ml02onl`ml01?l0003o_L?Ookg3gonm`ml2o`0000So_LCO
00?o0000ooooooooool0AOooool002[ooooo00?o0000ooooooooool0?_ooool00ol0003oU;G^oiBe
kP07oiBekP03o`000?nF]>goU[C]00SoU[C]00?o0000oiRdjonH]>/02?nH]>/00ol0003oVkCYoi^d
j@05o`0000;oVKG[00?o0000oiffjOnM]^T02_nM]^T00ol0003oX[SXoj:hj008oj:hj003o`000?nW
^NKoYkWV00WoYkWV00?o0000ojbji?n/^^@01On/^^@00ol0003o[;[Tojbji002ojbji0;o00003?n`
_^@00ol0003o];oRokBohP0;okBohP03o`000?nh`N7o^<7Q00Oo^<7Q0_l000000onh`n;o0000ok_3
h@0=ok_3h@03o`000?nl`moo_<?O00_o_<?O00?o0000okg3gol000002onma=l00ol0003ooooooooo
o`14ooooo`00:_ooool00ol0003oooooooooo`0oooooo`03o`000?nD]NkoU;G^00OoU;G^00?o0000
oiJdkOnF]>d02?nF]>d00ol0003oV;C[oiRdj`03oiRdj`Oo00002?nI]N/00ol0003oWKKYoiffj@0:
oiffj@03o`000?nR^>SoX[SX00SoX[SX00?o0000ojNii_nW^NH02OnW^NH00ol0003o[;[Tojbji004
ojbji003o`000?n/^^Co000000;o000000?o[;gVo`000?n`_^@02on`_^@00ol0003o];oRokBohP0;
okBohP03o`000?nh`N7o^<7Q00Go^<7Q0_l00004okS3hP03o`000?nk`n7o^l?Q00_o^l?Q00?o0000
okc3gonl`ml02onl`ml2o`0000go_LCO00?o0000ooooooooool0@oooool002Wooooo0ol00010oooo
o`;o00002OnD]Nh00ol0003oU[C]oiJdk@06oiJdk@Oo00001OnE]>d00ol0003oVKG[oiVej`08oiVe
j`03o`000?nM]^WoWKKY00WoWKKY00?o0000oj:hj?nR^>P02?nR^>P00ol0003oYkWVojNiiP0:ojNi
iP03o`000?n/^^Co[;[T00?o[;[T0_l00005ojbmiP03o`000?n`_^Co/;kT00[o/;kT00?o0000okBo
h_nd_n802ond_n800ol0003o^<7QokS1h@02okS1h@;o00001onh`n800ol0003o^l?Qok_3h@0;ok_3
h@03o`000?nl`moo_<?O00So_<?O0_l000000onla>3o0000okg4g`0<okg4g`;o0000A?ooool002[o
oooo00?o0000ooooooooool0@?ooool2o`0000WoU;G^00?o0000oiJdkOnF]>d01Ol00002oi:dkP03
o`000?nE]>goUKC]00SoUKC]00?o0000oiVejonI]N/02?nI]N/00ol0003oWKKYoiffj@09oiffj@03
o`000?nR^>SoX[SX00SoX[SX00?o0000ojNii_nW^NH02_nW^NH00ol0003o[;[To`000003o`0000Oo
[;gV00?o0000ok2ni?n`_^@02_n`_^@00ol0003o];oRokBohP0;okBohP04o`000?nh`N7o0000o`00
00[o^<?R00?o0000ok_3hOnk`n402onk`n400ol0003o_<?Ookc3g`05okc3g`;o00001?nla>000ol0
003o_LCOokg4g`0;okg4g`03o`000?oooooooooo04;ooooo000Zooooo`03o`000?oooooooooo047o
oooo0_l00005oiBekPKo00002?nB]>h00ol0003oUKC]oiFdk@08oiFdk@03o`000?nI]N_oVKG[00So
VKG[00?o0000oiffjOnM]^T02OnM]^T00ol0003oX[SXoj:hj008oj:hj003o`000?nW^NKoYkWV00So
YkWV0ol00003ojbmiP03o`000?n/_NKo[;gV00Ko[;gV00?o0000ok2ni?n`_^@02_n`_^@00ol0003o
];oRokBohP0:okBohP;o00003Onh`n800ol0003o^l?Qok_3h@0;ok_3h@03o`000?nl`moo_<?O00;o
_<?O0_l00007okc4h003o`000?nma=oo_LCO00_o_LCO00?o0000ooooooooool0@Oooool002[ooooo
00?o0000ooooooooool0@_ooool6o`0000CoT;C_00?o0000oi:dk_nB]>h02?nB]>h00ol0003oUKC]
oiFdk@08oiFdk@03o`000?nI]N_oVKG[00SoVKG[00?o0000oiffjOnM]^T02OnM]^T00ol0003oX[SX
oj:hj008oj:hj003o`000?nW^NKoYkWV00CoYkWV0ol00002ojNkj005o`000?n/_NKo[;gVojbmi_l0
00002On/_NH00ol0003o/;kTok2ni00:ok2ni003o`000?nd_n;o];oR00Oo];oR0_l000000one`^Co
0000okS3hP0=okS3hP03o`000?nk`n7o^l?Q00_o^l?Q00Co0000okc3gol0003o00002_nla>000ol0
003o_LCOokg4g`0;okg4g`03o`000?oooooooooo043ooooo000Yooooo`03o`000?oooooooooo04Co
oooo00?o0000oi2dkon@]>l01on@]>l00ol0003oT[C^oi:dkP08oi:dkP03o`000?nE]>goUKC]00So
UKC]00?o0000oiVejonI]N/02?nI]N/00ol0003oWKKYoiffj@08oiffj@03o`000?nR^>SoX[SX00Wo
X[SX00?o0000ojNii_nW^NH00ol00006ojNkj004o`000?n/_NKo[;gVo`0000[o[;gV00?o0000ok2n
i?n`_^@02On`_^@00ol0003o];oRokBohP05okBohP;o00001?ne`^@00ol0003o^<?RokS3hP0;okS3
hP03o`000?nk`n7o^l?Q00_o^l?Q0_l0000<okc4h003o`000?nma=oo_LCO00_o_LCO00?o0000oooo
ooooool0@?ooool002Wooooo00?o0000ooooooooool0AOooool00ol0003oT;C_oi2dk`07oi2dk`03
o`000?nB]>koT[C^00SoT[C^00?o0000oiFdkOnE]>d02?nE]>d00ol0003oVKG[oiVej`07oiVej`03
o`000?nM]^WoWKKY00WoWKKY00?o0000oj:hj?nR^>P02?nR^>P3o`0000[oYk_X00?o0000ojbmi_l0
00002on/_NH00ol0003o/;kTok2ni009ok2ni003o`000?nd_n;o];oR00;o];oR0_l00007okG2i003
o`000?nh`n;o^<?R00_o^<?R00?o0000ok_3hOnk`n402?nk`n42o`000003ok_4h_l0003o_<CP00co
_<CP00?o0000okg4gonma=l02onma=l00ol0003oooooooooo`0oooooo`00:Oooool00ol0003ooooo
ooooo`16ooooo`03o`000?n@]>ooT;C_00OoT;C_00?o0000oi:dk_nB]>h02?nB]>h00ol0003oUKC]
oiFdk@08oiFdk@03o`000?nI]N_oVKG[00OoVKG[00?o0000oiffjOnM]^T02OnM]^T00ol0003oX[SX
oj:hj004oj:hj0?o000000?oX[WYo`000?nW^nP02onW^nP2o`0000_o[;gV00?o0000ok2ni?n`_^@0
2_n`_^@01?l0003o];oRo`000?l0000:okG2i003o`000?nh`n;o^<?R00_o^<?R00?o0000ok_3hOnk
`n401Onk`n42o`0000Co^lCR00?o0000okc4h?nla>002onla>000ol0003o_LCOokg4g`0:okg4g`;o
0000@?ooool002Wooooo0_l00018ooooo`03o`000?n@]>ooT;C_00OoT;C_00?o0000oi:dk_nB]>h0
2?nB]>h00ol0003oUKC]oiFdk@07oiFdk@03o`000?nI]N_oVKG[00SoVKG[00?o0000oiffjOnM]^T0
2OnM]^T00ol0003oX[SXoj:hj003o`0000GoX[WY00?o0000ojNkj?nW^nP02_nW^nP00ol0003o[;gV
ojbmiP0:ojbmiP03o`000?n`_^Co/;kT00Wo/;kT0_l0000=okG2i003o`000?nh`n;o^<?R00_o^<?R
00?o0000ok_3hOnk`n400_nk`n42o`0000Oo^lCR00?o0000okc4h?nla>002onla>000ol0003o_LCO
okg4g`07okg4g`;o000000?o_<CQo`000?l00000?oooool002Wooooo00?o0000ooooooooool0B?oo
ool00ol0003oT;C_oi2dk`07oi2dk`03o`000?nB]>koT[C^00OoT[C^00?o0000oiFdkOnE]>d02?nE
]>d00ol0003oVKG[oiVej`08oiVej`03o`000?nM]^WoWKKY00OoWKKY1?l00009oj:ij@03o`000?nW
^nSoYk_X00WoYk_X0_l0000<ojbmiP03o`000?n`_^Co/;kT00Ko/;kT0_l000000ona`NKo0000okG2
i00=okG2i003o`000?nh`n;o^<?R00_o^<?R00Co0000ok_3hOl0003o00002_nka>800ol0003o_<CP
okc4h00:okc4h003o`000?nma=oo_LCO00Go_LCO0_l00004okc4h@03o`000?oooooooooo03gooooo
000Yooooo`03o`000?oooooooooo04Wooooo00?o0000oi2dkon@]>l01on@]>l00ol0003oT[C^oi:d
kP07oi:dkP03o`000?nE]>goUKC]00SoUKC]00?o0000oiVejonI]N/02?nI]N/01?l0003oWKKYoiff
jOnM]^T5o`0000;oW;O[00?o0000oj:ijOnR^NT02OnR^NT00ol0003oYk_XojNkj008ojNkj003o`00
0?nW^nSo000000co[;gV00?o0000ok2ni?n`_^@00_n`_^@3o`0000Co/L7V00?o0000okG2i?ne`^@0
2one`^@00ol0003o^<?RokS3hP0;okS3hP;o00003?nka>800ol0003o_<CPokc4h00;okc4h003o`00
0?nma=oo_LCO00;o_LCO0_l00007okc4h@03o`000?oooooooooo03cooooo000Yooooo`03o`000?oo
oooooooo04[ooooo00?o0000oi2dkon@]>l01on@]>l00ol0003oT[C^oi:dkP07oi:dkP03o`000?nE
]>goUKC]00SoUKC]00?o0000oiVejonI]N/01_nI]N/5o`0000SoW;O[00?o0000oj:ijOnR^NT02OnR
^NT00ol0003oYk_XojNkj007ojNkj003o`000?nW^nSo000000go[;gV00Co0000ok2ni?l0003o0000
2?na`NH00ol0003o]L;TokG2i00;okG2i003o`000?nh`n;o^<?R00So^<?R0_l000000onha>?o0000
ok_4hP0<ok_4hP03o`000?nla>3o_<CP00_o_<CP00Co0000okg4gol0003o00002_nla>400ol0003o
ooooooooo`0kooooo`00:Oooool00ol0003oooooooooo`1;ooooo`03o`000?n@]>ooT;C_00OoT;C_
00?o0000oi:dk_nB]>h01onB]>h00ol0003oUKC]oiFdk@08oiFdk@03o`000?nI]N_oVKG[00Go0000
0_nG]^d00ol0003oW;O[oibgj`09oibgj`03o`000?nR^NWoX[WY00WoX[WY00?o0000ojNkj?nW^nP0
1_nW^nP01?l0003oYk_XojNkj?l0000<ojbmiP;o00002ona`NH00ol0003o]L;TokG2i00;okG2i003
o`000?nh`n;o^<?R00Go^<?R0_l00004okS4h`03o`000?nka>;o^lCR00_o^lCR00?o0000okc4h?nl
a>002_nla>02o`0000co_<CQ0_l0000looooo`00:Oooool00ol0003oooooooooo`1<ooooo`03o`00
0?n@]>ooT;C_00OoT;C_00?o0000oi:dk_nB]>h01onB]>h00ol0003oUKC]oiFdk@03oiFdk@Oo0000
2?nG]^d00ol0003oW;O[oibgj`09oibgj`03o`000?nR^NWoX[WY00WoX[WY00?o0000ojNkj?nW^nP0
1OnW^nP01Ol0003oYk_XojNkj?nW^nSo000000So[;gV0ol000000on/_nOo0000ok71iP0;ok71iP03
o`000?ne`^Co]L;T00_o]L;T00?o0000okS3h_nh`n800_nh`n82o`0000Oo^<CS00?o0000ok_4h_nk
a>802onka>800ol0003o_<CPokc4h007okc4h0;o000000?o^lGRo`000?nla>403?nla>400ol0003o
ooooooooo`0jooooo`00:?ooool3o`0004kooooo00?o0000oi2dkon@]>l01on@]>l00ol0003oT[C^
oi:dkP03oi:dkPWo00001OnC]>h00ol0003oUkK]oiNfk@08oiNfk@03o`000?nL]n_oW;O[00WoW;O[
00?o0000oj:ijOnR^NT02?nR^NT00ol0003oYk_XojNkj005ojNkj003o`000?nW^nSoYk_X00;oYk_X
00?o0000ojbmi_n/_NH00on/_NH2o`0000Go[;oW00?o0000ok71i_na`NH02_na`NH00ol0003o]L;T
okG2i00;okG2i004o`000?nh`n;o0000o`0000[o^<CS00?o0000ok_4h_nka>802_nka>800ol0003o
_<CPokc4h005okc4h0;o00001?nkaN800ol0003o_<CQokc4h@0;okc4h@03o`000?oooooooooo03Wo
oooo000Xooooo`03o`000?oooooooooo04oooooo00?o0000oi2dkon@]>l00on@]>l9o`0000GoSk?_
00?o0000oi>dk_nC]>h01onC]>h00ol0003oUkK]oiNfk@08oiNfk@03o`000?nL]n_oW;O[00WoW;O[
00?o0000oj:ijOnR^NT02?nR^NT00ol0003oYk_XojNkj004ojNkj003o`000?nW^nSoYk_X00?oYk_X
00?o0000ojbmi_l000000_l00008ojboi`03o`000?na`NKo/L7V00[o/L7V00?o0000okG2i?ne`^@0
2_ne`^@2o`0000go^<CS00?o0000ok_4h_nka>802_nka>800ol0003o_<CPokc4h002okc4h0;o0000
1onkaN800ol0003o_<CQokc4h@0;okc4h@03o`000?oooooooooo03Sooooo000<ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c007ooooo`03
o`000?oooooooooo053ooooo1Ol00004ohjck`03o`000?n?/nooSk?_00SoSk?_00?o0000oi>dk_nC
]>h01onC]>h00ol0003oUkK]oiNfk@08oiNfk@03o`000?nL]n_oW;O[00WoW;O[00?o0000oj:ijOnR
^NT02?nR^NT00ol0003oYk_XojNkj003ojNkj003o`000?nW^nSoYk_X00;oYk_X0ol0000<ojboi`03
o`000?na`NKo/L7V00[o/L7V00?o0000okG2i?ne`^@01one`^@2o`000003okG4iOl0003o^<CS00go
^<CS00?o0000ok_4h_nka>802_nka>801?l0003o_<CPo`000?l0000:ok_5hP03o`000?nla>7o_<CQ
00[o_<CQ0_l0000iooooo`003?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oeEEEOmgMgOooooooiRHV?lQ8B401oooool00ol0003oooooooooo`1@ooooo`03o`000?n>/noo
S[?_00OoS[?_00?o0000ohnckon?/nl02?n?/nl00ol0003oTkC^oi>dkP07oi>dkP03o`000?nG]^go
UkK]00SoUkK]00?o0000oibgjonL]n/02OnL]n/00ol0003oX[WYoj:ij@08oj:ij@04o`000?nW^nSo
Yk_XojNkj0;o000000CoYk_Xo`000?l0003o00000_nW_NT00ol0003o[;oWojboi`0;ojboi`03o`00
0?na`NKo/L7V00[o/L7V00?o0000okG2i?ne`^@01?ne`^@2o`0000Co]LCU00?o0000okS4honha><0
2onha><00ol0003o^lCRok_4hP0:ok_4hP;o00003?nkaN800ol0003o_<CQokc4h@0;okc4h@03o`00
0?oooooooooo03Oooooo000<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000000Oooooo00?o0000ooooooooool0DOooool00ol0003oS[?_ohjck`07ohjck`03
o`000?n?/nooSk?_00SoSk?_00?o0000oi>dk_nC]>h01onC]>h00ol0003oUkK]oiNfk@08oiNfk@03
o`000?nL]n_oW;O[00WoW;O[00?o0000oj:ijOnR^NT02?nR^NT6o`0000KoYkgY00?o0000ojboion/
_nL02on/_nL00ol0003o/L7Vok71iP0:ok71iP03o`000?ne`^Co]L;T00;o]L;T00?o0000okG4iOne
a>D01Onea>D00ol0003o^<CSokS4h`0;okS4h`03o`000?nka>;o^lCR00Oo^lCR0_l000000onjaN?o
0000ok_5hP0<ok_5hP03o`000?nla>7o_<CQ00_o_<CQ00?o0000ooooooooool0=_ooool000cooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401oooool00ol0
003oooooooooo`1Booooo`03o`000?n>/nooS[?_00OoS[?_00?o0000ohnckon?/nl02?n?/nl00ol0
003oTkC^oi>dkP07oi>dkP03o`000?nG]^goUkK]00SoUkK]00?o0000oibgjonL]n/02OnL]n/00ol0
003oX[WYoj:ij@04oj:ij@Ko00000_nW_NT00ol0003oYkgYojNmj@05ojNmj@03o`000?n/_nOo[;oW
00[o[;oW00?o0000ok71i_na`NH02ona`NH01?l0003o]L;To`000?l00009okG4i@03o`000?nha>?o
^<CS00_o^<CS00?o0000ok_4h_nka>801?nka>82o`0000Co^/GS00?o0000ok_5h_nkaN802onkaN80
0ol0003o_<CQokc4h@0:okc4h@;o0000=oooool000cooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01oooool00ol0003oooooooooo`1Cooooo`03o`000?n>
/nooS[?_00OoS[?_00?o0000ohnckon?/nl02?n?/nl00ol0003oTkC^oi>dkP07oi>dkP03o`000?nG
]^goUkK]00SoUkK]00?o0000oibgjonL]n/02OnL]n/00ol0003oX[WYoj:ij@05o`0000?oXK_[00Go
0000ojNmjOnW_NWoYkgYo`000007ojNmj@03o`000?n/_nOo[;oW00[o[;oW00?o0000ok71i_na`NH0
2_na`NH2o`0000co]LCU00?o0000okS4honha><02onha><00ol0003o^lCRok_4hP02ok_4hP03o`00
0?njaN?o^/GS00Go^/GS00?o0000ok_5h_nkaN802onkaN800ol0003o_<CQokc4h@07okc4h@;o0000
00?o^/CRo`000?l00000=_ooool000cooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEE
EOn7QhOooooo00Wooooo00?o0000ooooooooool0E?ooool00ol0003oS[?_ohjck`07ohjck`03o`00
0?n?/nooSk?_00SoSk?_00?o0000oi>dk_nC]>h01onC]>h00ol0003oUkK]oiNfk@08oiNfk@03o`00
0?nL]n_oW;O[00OoW;O[1?l00009oj6kj`05o`000?nW_NWoYkgYojNmjOl000001onW_NT00ol0003o
[;oWojboi`0:ojboi`03o`000?na`NKo/L7V00Ko/L7V0ol000000ona`nOo0000okG4i@0<okG4i@03
o`000?nha>?o^<CS00_o^<CS00Co0000ok_4h_l0003o00002OnjaN<00ol0003o^lGRok_5hP0:ok_5
hP03o`000?nla>7o_<CQ00Go_<CQ0_l00004ok[4hP03o`000?oooooooooo03Cooooo000<ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`;o0000Eoooool00ol0
003oS[?_ohjck`07ohjck`03o`000?n?/nooSk?_00SoSk?_00?o0000oi>dk_nC]>h01onC]>h00ol0
003oUkK]oiNfk@08oiNfk@04o`000?nL]n_oW;O[oibgj`Ko000000?oVkW]o`000?nQ^n/02_nQ^n/0
1Ol0003oYkgYojNmjOnW_NWo000000OoYkgY00?o0000ojboion/_nL02_n/_nL00ol0003o/L7Vok71
iP03ok71iP;o00001Ona`nL00ol0003o]LCUokG4i@0:okG4i@03o`000?nha>?o^<CS00_o^<CS0_l0
000<ok[5h`03o`000?nkaN;o^lGR00[o^lGR00?o0000okc4hOnla>400_nla>42o`0000Oo^/CR00?o
0000ooooooooool0<oooool000cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0Eoooool00ol0003oS[?_ohjck`07ohjck`03o`00
0?n?/nooSk?_00SoSk?_00?o0000oi>dk_nC]>h01onC]>h00ol0003oUkK]oiNfk@06oiNfk@So0000
1OnK^Nd00ol0003oXK_[oj6kj`09oj6kj`05o`000?nW_NWoYkgYojNmjOl000001onW_NT00ol0003o
[;oWojboi`0:ojboi`03o`000?na`NKo000000;o00002?na`nL00ol0003o]LCUokG4i@0:okG4i@03
o`000?nha>?o^<CS00So^<CS0_l000000onha^Go0000ok[5h`0<ok[5h`03o`000?nkaN;o^lGR00[o
^lGR00Co0000okc4hOl0003o00002_nja>800ol0003oooooooooo`0booooo`009oooool00ol0003o
ooooooooo`1Hooooo`03o`000?n>/nooS[?_00OoS[?_00?o0000ohnckon?/nl02?n?/nl00ol0003o
TkC^oi>dkP07oi>dkP03o`000?nG]^goUkK]00Go00000_nF]nh3o`0000WoVkW]00?o0000oj6kjonQ
^n/02OnQ^n/01Ol0003oYkgYojNmjOnW_NWo000000OoYkgY00?o0000ojboion/_nL02?n/_nL3o`00
00co/L?W00?o0000okG4iOnea>D02_nea>D00ol0003o^<CSokS4h`05okS4h`;o00001?nha^D00ol0
003o^/GSok[5h`0;ok[5h`03o`000?nkaN;o^lGR00Wo^lGR0_l0000=ok[4hP03o`000?oooooooooo
037ooooo000Wooooo`03o`000?oooooooooo05Wooooo00?o0000ohjckon>/nl01on>/nl00ol0003o
Sk?_ohnck`08ohnck`03o`000?nC]>koTkC^00?oTkC^1_l00004oiJgkP?o000000?oU[O^o`000?nK
^Nd02_nK^Nd00ol0003oXK_[oj6kj`09oj6kj`05o`000?nW_NWoYkgYojNmjOl000001onW_NT00ol0
003o[;oWojboi`04ojboi`?o00000_n/`^T00ol0003o/L?Wok73i`0;ok73i`03o`000?nea>Go]LCU
00[o]LCU00?o0000okS4honha><00_nha><2o`0000Oo^<KU00?o0000ok[5honjaN<02onjaN<00ol0
003o^lGRok_5hP06ok_5hP;o000000?o^LGSo`000?nja>803?nja>82o`0003;ooooo000Wooooo`03
o`000?oooooooooo05[ooooo00?o0000ohjckon>/nl01on>/nl00ol0003oSk?_ohnck`03ohnck`[o
00001OnB]Nl00ol0003oU[O^o`000002o`0000GoU[O^00?o0000oi^ikOnK^Nd02OnK^Nd00ol0003o
XK_[oj6kj`09oj6kj`04o`000?nW_NWoYkgYo`0000SoYkgY00?o0000ojboion/_nL00ol00006ojc2
j@03o`000?na`nOo/L?W00_o/L?W00?o0000okG4iOnea>D02_nea>D01?l0003o^<CSo`000?l0000:
okS6i@03o`000?njaN?o^/GS00_o^/GS00?o0000ok_5h_nkaN800_nkaN83o`0000Co^LGS00?o0000
ok[4h_nja>802onja>800ol0003oooooooooo`0`ooooo`009oooool00ol0003oooooooooo`1Koooo
o`03o`000?n>/nooS[?_00?oS[?_2Ol00005ohjck`03o`000?nB]NooT[G_00KoT[G_0ol00009oiJg
kP03o`000?nK^NgoVkW]00WoVkW]00?o0000oj6kjonQ^n/02OnQ^n/01?l0003oYkgYojNmjOl00007
ojNmj@?o00002_n/`^T00ol0003o/L?Wok73i`0:ok73i`03o`000?nea>Go]LCU00[o]LCU0_l0000=
okS6i@03o`000?njaN?o^/GS00_o^/GS00Co0000ok_5h_l0003o00002?niaN<00ol0003o^/CRok[4
hP0;ok[4hP03o`000?oooooooooo02oooooo000Wooooo`;o0000GOooool5o`0000GoSK;`00?o0000
ohjckon>/nl01on>/nl00ol0003oT[G_oi:ek`02oi:ek`?o00000onB]Nl00ol0003oU[O^oiJgkP07
oiJgkP03o`000?nK^NgoVkW]00SoVkW]00?o0000oj6kjonQ^n/02_nQ^n/01?l0003oYkgYojNmjOl0
0003ojNmj@?o000000?oYl3[o`000?n/`^T02on/`^T00ol0003o/L?Wok73i`0:ok73i`03o`000?ne
a>Go]LCU00Ko]LCU0ol000000onda^Oo0000okS6i@0=okS6i@03o`000?njaN?o^/GS00[o^/GS0_l0
000;okW5h`03o`000?nja>;o^/CR00_o^/CR00?o0000ooooooooool0;_ooool002Kooooo0_l0001O
ooooo`03o`000?n=/_3oSK;`00OoSK;`00?o0000ohjckon>/nl01on>/nl4o`0000OoT[G_00?o0000
oiJgk_nF]nh01onF]nh00ol0003oVkW]oi^ik@08oi^ik@03o`000?nQ^n_oXK_[00[oXK_[00?o0000
ojNmjOnW_NT00ol00005ojO0j`03o`000?n/`^Wo[<;Y00[o[<;Y00?o0000ok73iona`nL02_na`nL0
0ol0003o]LCUokG4i@03okG4i@;o00001Onda^L00ol0003o^<KUokS6i@0;okS6i@03o`000?njaN?o
^/GS00So^/GS0_l000000onha^Go0000okW5h`0;okW5h`03o`000?nja>;o^/CR00[o^/CR0_l0000_
ooooo`009oooool00ol0003oooooooooo`1Nooooo`03o`000?n=/_3oSK;`00OoSK;`00?o0000ohjc
kon>/nl01?n>/nl4o`0000[oT[G_00?o0000oiJgk_nF]nh01onF]nh00ol0003oVkW]oi^ik@08oi^i
k@03o`000?nQ^n_oXK_[00SoXK_[1?l000000onW`>_o0000ojO0j`06ojO0j`03o`000?n/`^Wo[<;Y
00[o[<;Y00?o0000ok73iona`nL02_na`nL00ol0003o]LCUo`000002o`0000So]<KW00?o0000okS6
iOnha^D02onha^D00ol0003o^/GSok[5h`05ok[5h`;o00001?nha^D00ol0003o^LGSokW5h`0:okW5
h`03o`000?nja>;o^/CR00[o^/CR0_l0000^ooooo`009oooool00ol0003oooooooooo`1Oooooo`03
o`000?n=/_3oSK;`00OoSK;`00?o0000ohjckon>/nl00ol00004ohjck`03o`000?nB]NooT[G_00So
T[G_00?o0000oiJgk_nF]nh01onF]nh00ol0003oVkW]oi^ik@08oi^ik@03o`000?nQ^n_oXK_[00Co
XK_[0ol00002oj6mk@05o`000?nW`>_oYl3[ojO0jol000001onW`>/00ol0003o[<;Yojc2j@0:ojc2
j@03o`000?na`nOo/L?W00Wo/L?W0_l0000<okC6i`03o`000?nha^Go^<KU00_o^<KU00?o0000ok[5
honjaN<00_njaN<2o`0000Oo^<KU00?o0000okW5honiaN<02OniaN<00ol0003o^/CRok[4hP08ok[4
hP;o000000?o]l?So`000?ooool0;Oooool002Kooooo00?o0000ooooooooool0HOooool00ol0003o
SK;`ohfbl006ohfbl0?o00002?n>/nl00ol0003oT[G_oi:ek`08oi:ek`03o`000?nF]nkoU[O^00Oo
U[O^00?o0000oi^ikOnK^Nd02?nK^Nd00ol0003oXK_[oj6kj`03o`0000KoXKg]00Go0000ojO0jonW
`>_oYl3[o`000007ojO0j`03o`000?n/`^Wo[<;Y00[o[<;Y00?o0000ok73iona`nL01_na`nL2o`00
00;o/LGY00?o0000okC6ionda^L02_nda^L00ol0003o^<KUokS6i@0;okS6i@04o`000?njaN?o0000
o`0000[o^<KU00?o0000okW5honiaN<02OniaN<00ol0003o^/CRok[4hP05ok[4hP;o00001?ng`n<0
0ol0003oooooooooo`0[ooooo`009_ooool00ol0003oooooooooo`1Rooooo`03o`000?n=/_3oSK;`
00;oSK;`0ol00002ohfbl003o`000?n>/nooS[?_00OoS[?_00?o0000oi:ekonB]Nl02?nB]Nl00ol0
003oU[O^oiJgkP07oiJgkP03o`000?nK^NgoVkW]00KoVkW]1?l0000:oj6mk@05o`000?nW`>_oYl3[
ojO0jol000001onW`>/00ol0003o[<;Yojc2j@0:ojc2j@03o`000?na`nOo/L?W00;o/L?W0ol00005
ok75j@03o`000?nda^Oo]<KW00[o]<KW00?o0000okS6iOnha^D02_nha^D2o`0000co^<KU00?o0000
okW5honiaN<02_niaN<00ol0003o^/CRok[4hP02ok[4hP;o00001_ng`n<2o`0002cooooo000Voooo
o`03o`000?oooooooooo06?ooooo1?l00006ohfbl003o`000?n>/nooS[?_00OoS[?_00?o0000oi:e
konB]Nl02?nB]Nl00ol0003oU[O^oiJgkP07oiJgkP03o`000?nK^NgoVkW]00Go00000_nK^nh00ol0
003oXKg]oj6mk@0:oj6mk@04o`000?nW`>_oYl3[o`0000SoYl3[00?o0000ojc2jOn/`^T02_n/`^T0
1?l0003o/L?Wo`000?l00009ok75j@03o`000?nda^Oo]<KW00[o]<KW00?o0000okS6iOnha^D01_nh
a^D3o`000003okK7iol0003o^<KU00co^<KU00?o0000okW5honiaN<02_niaN<01?l0003o^/CRo`00
0?l00009okO3h`03o`000?oooooooooo02[ooooo000Vooooo`;o0000Hoooool3o`0000WoSK;`00?o
0000ohjckon>/nl01on>/nl00ol0003oT[G_oi:ek`08oi:ek`03o`000?nF]nkoU[O^00?oU[O^1_l0
0008oi^kkP03o`000?nQ_NgoXKg]00[oXKg]00Co0000ojO0jonW`>_o00002?nW`>/00ol0003o[<;Y
ojc2j@08ojc2j@?o00003?naaNT00ol0003o]<KWokC6i`0:okC6i`03o`000?nha^Go^<KU00?o^<KU
0_l00005okK7i`03o`000?nha^Go^<KU00_o^<KU00?o0000okW5honiaN<02OniaN<2o`0000co]l?S
00?o0000ooooooooool0:Oooool002Kooooo00?o0000ooooooooool0Goooool3o`0000?ooooo00?o
0000ohfbl?n=/_001on=/_000ol0003oS[?_ohjck`07ohjck`03o`000?nB]NooT[G_00?oT[G_2_l0
0005oiJik`03o`000?nK^nkoVk_^00OoVk_^00?o0000oj6mkOnQ_Nd02_nQ_Nd01?l0003oYl3[ojO0
jol00008ojO0j`03o`000?n/`^Wo[<;Y00Co[<;Y0ol00002ojc4j`03o`000?naaNWo/LGY00_o/LGY
00?o0000okC6ionda^L02_nda^L00ol0003o^<KUo`000002o`0000So]/OW00?o0000okS6iOnha^D0
2_nha^D00ol0003o^LGSokW5h`06okW5h`?o000000?o]lGUo`000?ng`n<03?ng`n<00ol0003ooooo
ooooo`0Xooooo`009_ooool00ol0003oooooooooo`1Looooo`?o00001oooool00ol0003oSK;`ohfb
l007ohfbl003o`000?n>/nooS[?_00?oS[?_2Ol00005oi:fl003o`000?nF^NooU[W_00SoU[W_00?o
0000oi^kk_nK^nh01onK^nh00ol0003oXKg]oj6mk@0:oj6mk@04o`000?nW`>_oYl3[o`0000SoYl3[
00?o0000ojc2jOn/`^T00ol00006ojc4j`03o`000?naaNWo/LGY00_o/LGY00?o0000okC6ionda^L0
2Onda^L2o`0000co]/OW00?o0000okS6iOnha^D02_nha^D00ol0003o^LGSokW5h`03okW5h`;o0000
1OngaND00ol0003o]l?SokO3h`0:okO3h`03o`000?oooooooooo02Sooooo000Vooooo`03o`000?oo
oooooooo05Wooooo0ol0000;ooooo`03o`000?n=/_3oSK;`00?oSK;`2Ol00005ohndl003o`000?nB
]_3oT[K`00OoT[K`00?o0000oiJikonF^Nl02?nF^Nl00ol0003oVk_^oi^kkP07oi^kkP03o`000?nQ
_NgoXKg]00[oXKg]00Co0000ojO0jonW`>_o00001onW`>/3o`0000[o[<C[00?o0000ok75jOnaaNT0
2onaaNT00ol0003o]<KWokC6i`06okC6i`;o00000_ncanT00ol0003o]/OWokK7i`0:okK7i`03o`00
0?nha^Go^<KU00[o^<KU00?o0000okW5hol000000_l00008okO5i@03o`000?ng`n?o]l?S00[o]l?S
00?o0000ooooooooool09oooool002Kooooo00?o0000ooooooooool0E_ooool3o`0000oooooo1Ol0
0005ohjck`03o`000?n?]?3oSkC`00OoSkC`00?o0000oi:fl?nB]_001onB]_000ol0003oU[W_oiJi
k`08oiJik`03o`000?nK^nkoVk_^00OoVk_^00?o0000oj6mkOnQ_Nd02_nQ_Nd01?l0003oYl3[ojO0
jol00003ojO0j`?o00000_nW`^d00ol0003o[<C[ojc4j`09ojc4j`03o`000?naaNWo/LGY00_o/LGY
00?o0000okC6ionda^L00_nda^L3o`0000Go/lOY00?o0000okK7ionfanL02_nfanL00ol0003o^<KU
okS6i@09okS6i@;o00003?ngaND00ol0003o]l?SokO3h`0:okO3h`03o`000?oooooooooo02Kooooo
000Vooooo`03o`000?oooooooooo05?ooooo0ol0000Cooooo`03o`000?n>/nooS[?_00OoS[?_00?o
0000ohndl?n?]?001on?]?000ol0003oT[K`oi:fl007oi:fl003o`000?nF^NooU[W_00SoU[W_00?o
0000oi^kk_nK^nh01onK^nh00ol0003oXKg]oj6mk@0:oj6mk@03o`000?nW`>_oYl3[00?o00001_nW
`^d00ol0003o[<C[ojc4j`09ojc4j`03o`000?naaNWo/LGY00_o/LGY00Co0000okC6iol0003o0000
2OncanT00ol0003o]/OWokK7i`0:okK7i`03o`000?nha^Go^<KU00Ko^<KU0_l000000onfanOo0000
okO5i@0<okO5i@03o`000?ng`n?o]l?S00Wo]l?S0_l0000Wooooo`009Oooool00ol0003ooooooooo
o`1Aooooo`?o00005oooool00ol0003oS[?_ohjck`07ohjck`03o`000?n?]?3oSkC`00OoSkC`00?o
0000oi:fl?nB]_001onB]_000ol0003oU[W_oiJik`08oiJik`03o`000?nK^nkoVk_^00OoVk_^00?o
0000oj6mkOnQ_Nd02?nQ_Nd5o`0000WoYl;]00?o0000ojc4jon/a>/02On/a>/00ol0003o/LGYok75
j@0:ok75j@;o00003?ncanT00ol0003o]/OWokK7i`0:okK7i`03o`000?nha^Go^<KU00;o^<KU0ol0
0004okK7i`03o`000?ngaNGo]lGU00_o]lGU00?o0000okO3hong`n<02Ong`n<00ol0003ooooooooo
o`0Uooooo`009Oooool3o`0004kooooo0ol0000Jooooo`;o00002On>/nl00ol0003oSkC`ohndl007
ohndl003o`000?nB]_3oT[K`00OoT[K`00?o0000oiJikonF^Nl02?nF^Nl00ol0003oVk_^oi^kkP07
oi^kkP03o`000?nQ_NgoXKg]00CoXKg]0ol00003oj;0kP03o`000?nW`^go000000WoYl;]00?o0000
ojc4jon/a>/02On/a>/00ol0003o/LGYok75j@06ok75j@?o000000?o/<O[o`000?ncanT03?ncanT0
0ol0003o]/OWokK7i`0:okK7i`04o`000?nha^Go0000o`0000So]/OW00?o0000okO5iOngaND02_ng
aND00ol0003o]l?SokO3h`09okO3h`;o00009_ooool002Gooooo00?o0000ooooooooool0Boooool3
o`0001kooooo0_l00009ohjck`03o`000?n?]?3oSkC`00OoSkC`00?o0000oi:fl?nB]_001onB]_00
0ol0003oU[W_oiJik`08oiJik`03o`000?nK^nkoVk_^00OoVk_^00?o0000oj6mkOnQ_Nd00ol00007
oj;0kP03o`000?nW`^go000000WoYl;]00?o0000ojc4jon/a>/02On/a>/00ol0003o/LGYok75j@03
ok75j@;o00001On`an/00ol0003o/lOYok?7j@0;ok?7j@03o`000?nfanOo]/OW00Wo]/OW0_l0000;
okK7i`03o`000?ngaNGo]lGU00[o]lGU00?o0000okO3hong`n<01_ng`n<2o`000003ok?2iOl0003o
000002Gooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<
ob4Q8Ol0003o8B4Qolc<c007ooooo`03o`000?oooooooooo04Sooooo0ol0000Rooooo`;o00002On>
/nl00ol0003oSkC`ohndl007ohndl003o`000?nB]_3oT[K`00OoT[K`00?o0000oiJikonF^Nl02?nF
^Nl00ol0003oVk_^oi^kkP03oi^kkPKo00002onR`>h00ol0003oYl;]o`000009ojO2k@03o`000?n/
a>_o[<C[00Wo[<C[00?o0000ok75jOl000000_l00008ok37j`03o`000?ncanWo/lOY00_o/lOY00?o
0000okK7ionfanL01_nfanL2o`000003okC8jOl0003o]/OW00_o]/OW00?o0000okO5iOngaND02_ng
aND00ol0003o]l?SokO3h`02okO3h`?o00001?nc`^D2o`0002Cooooo0009ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@07ooooo`03o`00
0?oooooooooo04Gooooo0ol0000Vooooo`;o00002On>/nl00ol0003oSkC`ohndl007ohndl003o`00
0?nB]_3oT[K`00OoT[K`00?o0000oiJikonF^Nl01_nF^Nl7o`0000GoW;g_00?o0000oj;0k_nR`>h0
2_nR`>h00ol0003oYl;]o`000009ojO2k@03o`000?n/a>_o[<C[00So[<C[0_l0000<ok37j`03o`00
0?ncanWo/lOY00_o/lOY00?o0000okK7ionfanL00_nfanL3o`0000Co]<SY00?o0000okK7ionfanL0
2_nfanL00ol0003o]lGUokO5i@0:okO5i@04o`000?ng`n?o0000o`0000So/l;U00?o0000oooooooo
ool08_ooool000Wooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`12ooooo`?o0000:_ooool2o`0000WoS[?_00?o0000ohnd
l?n?]?001on?]?000ol0003oT[K`oi:fl007oi:fl003o`000?nF^NooU[W_00Go00000_nH^_000ol0
003oW;g_oibmk`08oibmk`03o`000?nR`>koX/3^00[oX/3^00?o0000ojO2kOl000002OnW`^d00ol0
003o[<C[ojc4j`04ojc4j`?o00000_n/a^d00ol0003o/<O[ok37j`0:ok37j`03o`000?ncanWo/lOY
00_o/lOY00Co0000okK7iol0003o00002?ndb>T00ol0003o]/OWokK7i`09okK7i`03o`000?ngaNGo
]lGU00[o]lGU0_l0000;ok?2i@03o`000?oooooooooo027ooooo0009ooooo`05o`000?oooooooooo
ooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Oooooo00?o0000ooooooooool0?ooo
ool3o`0002kooooo0_l00009ohjck`03o`000?n?]?3oSkC`00OoSkC`00?o0000oi:fl?nB]_000onB
]_06o`0000SoV;[`00?o0000oibmkonL_Nl02?nL_Nl00ol0003oX/3^oj;0kP0:oj;0kP03o`000?nW
`^go000000WoYl;]00?o0000ojc4jon/a>/00ol00006ojc6k@03o`000?n`an_o/<O[00[o/<O[00?o
0000ok?7jOncanT02_ncanT2o`0000_o]<SY00?o0000okK7ionfanL02OnfanL00ol0003o]lGUokO5
i@06okO5i@?o000000?o/lCWo`000?nc`^D02_nc`^D2o`0002;ooooo0009ooooo`05o`000?oooooo
ooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Oooooo00?o0000ooooooooool0
??ooool3o`0003;ooooo0_l00009ohjck`03o`000?n?]?3oSkC`00?oSkC`2Ol00005oiBhl003o`00
0?nH^_3oV;[`00OoV;[`00?o0000oibmkonL_Nl02?nL_Nl00ol0003oX/3^oj;0kP0:oj;0kP03o`00
0?nW`^go000000SoYl;]0ol0000:ojc6k@03o`000?n`an_o/<O[00[o/<O[00?o0000ok?7jOncanT0
1_ncanT3o`000003ok78jol0003o]<SY00_o]<SY00?o0000okK7ionfanL02OnfanL00ol0003o]lGU
okO5i@03okO5i@;o00001Onca>L00ol0003o/l;Uok?2i@09ok?2i@;o00008Oooool000Wooooo00Go
410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001oooool00ol0003o
ooooooooo`0iooooo`?o0000=_ooool2o`0000GoS[?_2Ol00004oi6fl003o`000?nD^?3oU;S`00So
U;S`00?o0000oiRjl?nH^_001onH^_000ol0003oW;g_oibmk`08oibmk`03o`000?nR`>koX/3^00[o
X/3^0_l00005ojO2k@?o000000?oYlC^o`000?n/a^d02on/a^d00ol0003o/<O[ok37j`0:ok37j`03
o`000?ncanWo/lOY00?o/lOY0_l00005ok78j`03o`000?ndb>Wo]<SY00[o]<SY00?o0000okK7ionf
anL02OnfanL00ol0003o]lGUo`000002o`0000So/lCW00?o0000ok?2iOnc`^D02Onc`^D00ol0003o
ooooooooo`0Oooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
oooo^[Zjo`000006ooooo`03o`000?oooooooooo03Oooooo0ol0000jooooo`Ko00001?n@]>l00ol0
003oTKK`oi6fl007oi6fl003o`000?nD^?3oU;S`00SoU;S`00?o0000oiRjl?nH^_001onH^_000ol0
003oW;g_oibmk`08oibmk`03o`000?nR`>koX/3^00[oX/3^0_l000001?nW`^go0000o`000?l00005
ojO4kP03o`000?n/a^go[<K]00[o[<K]00?o0000ok37jon`an/02_n`an/00ol0003o/lOYo`000002
o`0000So/LS[00?o0000okC8jOndb>T02_ndb>T00ol0003o]/OWokK7i`08okK7i`;o00003?nca>L0
0ol0003o/l;Uok?2i@08ok?2i@;o00008?ooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0dooooo`?o0000?_oo
ool00ol0003oT;C_oi2dk`07oi2dk`03o`000?nA]_3oTKK`00OoTKK`00?o0000oiBhl?nD^?002?nD
^?000ol0003oV;[`oiRjl007oiRjl003o`000?nL_NooW;g_00SoW;g_00?o0000oj;0k_nR`>h02?nR
`>h4o`0000WoYlC^00?o0000ojc6kOn/a^d02_n/a^d00ol0003o/<O[ok37j`09ok37j`;o00003?na
b>/00ol0003o]<SYokC8j@0:okC8j@03o`000?nfanOo]/OW00Co]/OW0ol000000onba^Wo0000ok?4
i`0<ok?4i`03o`000?nc`^Go/l;U00So/l;U0_l0000Oooooo`009?ooool00ol0003oooooooooo`0a
ooooo`?o0000@_ooool00ol0003oT;C_oi2dk`07oi2dk`03o`000?nA]_3oTKK`00OoTKK`00?o0000
oiBhl?nD^?002?nD^?000ol0003oV;[`oiRjl007oiRjl003o`000?nL_NooW;g_00SoW;g_00?o0000
oj;0k_nR`>h01?nR`>h3o`0000;oX/;`00?o0000ojO4k_l000002OnWa>h00ol0003o[<K]ojc6k@0:
ojc6k@03o`000?n`an_o/<O[00Ko/<O[0_l00002ojk8k@03o`000?nab>_o/LS[00[o/LS[00?o0000
okC8jOndb>T02_ndb>T00ol0003o]/OWokK7i`03o`0000Go//KY00?o0000ok?4ionca>L02_nca>L0
0ol0003o/l;Uok?2i@09ok?2i@;o00007_ooool002Cooooo00?o0000ooooooooool0;oooool2o`00
04Kooooo00?o0000oi2dkon@]>l01on@]>l00ol0003oTKK`oi6fl007oi6fl003o`000?nD^?3oU;S`
00SoU;S`00?o0000oiRjl?nH^_001onH^_000ol0003oW;g_oibmk`08oibmk`03o`000?nR`>koX/3^
00?o00001_nR`_000ol0003oYlC^o`000009ojO4kP03o`000?n/a^go[<K]00[o[<K]00?o0000ok37
jon`an/00_n`an/3o`0000Go[/S]00?o0000ok78jonab>/02Onab>/00ol0003o]<SYokC8j@0:okC8
j@?o00002Onba^T00ol0003o/lCWok?4i`0:ok?4i`03o`000?nc`^Go/l;U00So/l;U0_l0000Noooo
o`009?ooool00ol0003oooooooooo`0/ooooo`?o0000BOooool00ol0003oT;C_oi2dk`07oi2dk`03
o`000?nA]_3oTKK`00OoTKK`00?o0000oiBhl?nD^?002?nD^?000ol0003oV;[`oiRjl007oiRjl003
o`000?nL_NooW;g_00KoW;g_1?l0000:oj;2l003o`000?nWa>ko000000WoYlC^00?o0000ojc6kOn/
a^d02_n/a^d01?l0003o/<O[o`000?l00009ojk8k@03o`000?nab>_o/LS[00Wo/LS[00?o0000okC8
jOndb>T01_ndb>T3o`000003ok78jol0003o//KY00[o//KY00?o0000ok?4ionca>L02_nca>L00ol0
003o/l;Uok?2i@04ok?2i@?o000000?o[l7Wo`000?l000007Oooool002Cooooo00?o0000oooooooo
ool0:Oooool3o`0004gooooo00?o0000oi2dkon@]>l01on@]>l00ol0003oTKK`oi6fl007oi6fl003
o`000?nD^?3oU;S`00SoU;S`00?o0000oiRjl?nH^_001onH^_000ol0003oW;g_oibmk`05o`0000Co
W[o`00?o0000oj;2l?nR`_002?nR`_000ol0003oYlC^o`000009ojO4kP03o`000?n/a^go[<K]00So
[<K]0ol0000<ojk8k@03o`000?nab>_o/LS[00Wo/LS[00?o0000okC8jOndb>T00ondb>T2o`0000Go
/LS[00?o0000ok;6jOnba^T02Onba^T00ol0003o/lCWok?4i`0:ok?4i`03o`000?nc`^Go/l;U00?o
00001On_`NL2o`0001cooooo000Tooooo`03o`000?oooooooooo02Kooooo0ol0001Aooooo`03o`00
0?n@]>ooT;C_00OoT;C_00?o0000oi6fl?nA]_001onA]_000ol0003oU;S`oiBhl008oiBhl003o`00
0?nH^_3oV;[`00?oV;[`1_l0000:oijol003o`000?nR`_3oX/;`00SoX/;`00?o0000ojO4k_l00000
2OnWa>h00ol0003o[<K]ojc6k@04ojc6k@?o00000on[anh00ol0003o[/S]ojk8k@0:ojk8k@03o`00
0?nab>_o/LS[00Wo/LS[00?o0000okC8jOl000000_l00008ok78j`03o`000?nba^Wo//KY00Wo//KY
00?o0000ok?4ionca>L02Onca>L3o`0000Wo[l7W0_l0000Kooooo`008oooool2o`0002Gooooo0ol0
001Eooooo`03o`000?n@]>ooT;C_00OoT;C_00?o0000oi6fl?nA]_001onA]_000ol0003oU;S`oiBh
l006oiBhl0Oo00001_nJ_O000ol0003oW[o`oijol008oijol003o`000?nR`_3oX/;`00SoX/;`0_l0
000:ojO4kP03o`000?n/a^go[<K]00?o00001on[anh00ol0003o[/S]ojk8k@0:ojk8k@03o`000?na
b>_o/LS[00So/LS[0_l0000<ok78j`03o`000?nba^Wo//KY00Wo//KY00?o0000ok?4ionca>L01_nc
a>L2o`000003ojo3jOl0003o[l7W00[o[l7W00?o0000ooooooooool06Oooool002Cooooo00?o0000
ooooooooool08?ooool3o`0005Wooooo00?o0000oi2dkon@]>l01on@]>l00ol0003oTKK`oi6fl007
oi6fl003o`000?nD^?3oU;S`00Go00000onG^_000ol0003oV[g`oiZml008oiZml003o`000?nN_o3o
W[o`00SoW[o`00?o0000oj;2l?nR`_002?nR`_02o`0000WoYlC^0ol0000;oj_7kP03o`000?n^b>go
[/S]00[o[/S]00?o0000ok78jonab>/01?nab>/3o`0000;o[lW]00?o0000ok78jonab>/02_nab>/0
0ol0003o//KYok;6j@09ok;6j@03o`000?nca>Oo/lCW00;o/lCW0ol00004ojo3j@03o`000?n_`NOo
[l7W00Wo[l7W00?o0000ooooooooool06?ooool002?ooooo00?o0000ooooooooool07_ooool3o`00
05gooooo00?o0000oi2dkon@]>l01on@]>l00ol0003oTKK`oi6fl003oi6fl0Ko00002OnG^_000ol0
003oV[g`oiZml008oiZml003o`000?nN_o3oW[o`00SoW[o`00?o0000oj;2l?nR`_002?nR`_02o`00
00GoYlC^0ol00003ojO6k`03o`000?n[ankoZlO^00WoZlO^00?o0000ojk8kOn^b>d02_n^b>d00ol0
003o/LS[ok78j`03o`0000Ko[lW]00?o0000ok78jonab>/02Onab>/00ol0003o//KYok;6j@0:ok;6
j@04o`000?nca>Oo0000o`0000So[l?Y00?o0000ojo1ion_`NL02On_`NL00ol0003oooooooooo`0G
ooooo`008oooool00ol0003oooooooooo`0Kooooo`?o0000HOooool00ol0003oT;C_oi2dk`03oi2d
k`Wo00001OnE]nl00ol0003oUk[`oiNjl008oiNjl003o`000?nJ_O3oV[g`00SoV[g`00?o0000oijo
l?nN_o002?nN_o000ol0003oX/;`oj;2l008oj;2l0;o000000CoYlC^o`000?l0003o00001onWa^l0
0ol0003oZlO^oj_7kP09oj_7kP03o`000?n^b>go[/S]00Wo[/S]0ol0000:ojo9k@03o`000?nab>_o
/LS[00Wo/LS[00?o0000ok;6jOnba^T02?nba^T3o`0000_o[l?Y00?o0000ojo1ion_`NL02?n_`NL2
o`0001Sooooo000Sooooo`03o`000?oooooooooo01Sooooo0ol0001Uooooo`Go00001OnD]Nh00ol0
003oUKO_oiFgk`07oiFgk`03o`000?nG^_3oUk[`00SoUk[`00?o0000oiZml?nJ_O002?nJ_O000ol0
003oW[o`oijol008oijol003o`000?nR`_3oX/;`00KoX/;`1?l0000;ojO6k`03o`000?n[ankoZlO^
00WoZlO^00?o0000ojk8kOn^b>d01_n^b>d2o`0000;o[LW^00?o0000ojo9kOn_bNd02On_bNd00ol0
003o/LS[ok78j`09ok78j`03o`000?nba^Wo//KY00Co//KY0ol00002ojk5j`03o`000?n_`nWo[l?Y
00[o[l?Y00?o0000ojo1ion_`NL02?n_`NL00ol0003oooooooooo`0Fooooo`008oooool00ol0003o
ooooooooo`0Eooooo`?o0000J?ooool00ol0003oU;G^oiBekP08oiBekP03o`000?nE]nooUKO_00Oo
UKO_00?o0000oiNjl?nG^_002?nG^_000ol0003oV[g`oiZml008oiZml003o`000?nN_o3oW[o`00So
W[o`00?o0000oj;2l?nR`_001Ol00004ojC4l003o`000?nWa^ooYlK_00WoYlK_00?o0000oj_7k_n[
anh02On[anh00ol0003o[/S]ojk8k@02ojk8k@?o00001On]bNh00ol0003o[lW]ojo9k@09ojo9k@03
o`000?nab>_o/LS[00Wo/LS[00?o0000ok;6jOnba^T00ol00006ojk5j`03o`000?n_`nWo[l?Y00Wo
[l?Y00?o0000ojo1ion_`NL02On_`NL00ol0003oooooooooo`0Eooooo`008oooool00ol0003ooooo
ooooo`0Booooo`?o0000K?ooool00ol0003oU;G^oiBekP08oiBekP03o`000?nE]nooUKO_00OoUKO_
00?o0000oiNjl?nG^_002?nG^_000ol0003oV[g`oiZml008oiZml003o`000?nN_o3oW[o`00KoW[o`
1?l0000:ojC4l003o`000?nWa^ooYlK_00WoYlK_00?o0000oj_7k_n[anh02On[anh01?l0003o[/S]
o`000?l00009ojg9kP03o`000?n_bNgo[lW]00Wo[lW]00?o0000ok78jonab>/02?nab>/3o`0000[o
[/G[00?o0000ojo3jOn_`nT02On_`nT00ol0003o[l7Wojo1i`09ojo1i`03o`000?oooooooooo01Co
oooo000Rooooo`?o00004?ooool3o`00073ooooo00?o0000oiBek_nD]Nh02?nD]Nh00ol0003oUKO_
oiFgk`07oiFgk`03o`000?nG^_3oUk[`00SoUk[`00?o0000oiZml?nJ_O002?nJ_O000ol0003oW[o`
oijol005o`0000?oX<;`00?o0000ojC4l?nTa?002OnTa?000ol0003oYlK_ojO6k`09ojO6k`03o`00
0?n[ankoZlO^00SoZlO^0ol0000;ojg9kP03o`000?n_bNgo[lW]00Wo[lW]00?o0000ok78jonab>/0
1?nab>/3o`0000;o[LO]00?o0000ojk5jon^aN/02On^aN/00ol0003o[l?Yojo3j@09ojo3j@03o`00
0?n_`NOo[l7W00Oo[l7W0ol0000Eooooo`008oooool00ol0003oooooooooo`0<ooooo`?o0000M?oo
ool00ol0003oU;G^oiBekP08oiBekP03o`000?nE]nooUKO_00OoUKO_00?o0000oiNjl?nG^_002?nG
^_000ol0003oV[g`oiZml006oiZml0Co00002OnP`_000ol0003oY<C`ojC4l008ojC4l0;o00002onW
a^l00ol0003oZlO^oj_7kP04oj_7kP?o00000onZb>l00ol0003o[LW^ojg9kP09ojg9kP03o`000?n_
bNgo[lW]00Wo[lW]00?o0000ok78jonab>/00ol00006ojg7k@03o`000?n^aN_o[/G[00Wo[/G[00?o
0000ojo3jOn_`nT02On_`nT01?l0003o[l7Wojo1ion_`NL5o`0000;ooooo00?o0000ooooooooool0
4oooool002?ooooo00?o0000ooooooooool02Oooool3o`0007Sooooo00?o0000oiBek_nD]Nh02?nD
]Nh00ol0003oUKO_oiFgk`07oiFgk`03o`000?nG^_3oUk[`00SoUk[`00?o0000oiZml?nJ_O001Ol0
0003oifol003o`000?nP`_3oX<;`00SoX<;`00?o0000ojC4l?nTa?002?nTa?02o`0000_oYlK_00?o
0000oj_7k_n[anh00ol00007oj[8k`03o`000?n]bNko[LW^00Wo[LW^00?o0000ojo9kOn_bNd02?n_
bNd3o`0000[o[LO]00?o0000ojk5jon^aN/02On^aN/00ol0003o[l?Yojo3j@08ojo3j@Ko00001Ooo
ool00ol0003oooooooooo`0Cooooo`008oooool00ol0003oooooooooo`06ooooo`?o0000O?ooool0
0ol0003oU;G^oiBekP08oiBekP03o`000?nE]nooUKO_00OoUKO_00?o0000oiNjl?nG^_001_nG^_04
o`0000WoWKo`00?o0000oj32l?nP`_002?nP`_000ol0003oY<C`ojC4l008ojC4l0;o00002OnWa^l4
o`0000_oZ/S_00?o0000ojg9k_n]bNh02On]bNh00ol0003o[lW]ojo9k@04ojo9k@?o000000?o[<S^
o`000?n]and02on]and00ol0003o[/G[ojk5j`09ojk5j`03o`000?n_`nWo[l?Y00Co[l?Y1_l00008
ooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo00Cooooo0ol00020oooo
o`03o`000?nD]NkoU;G^00SoU;G^00?o0000oiFgkonE]nl01onE]nl00ol0003oUk[`oiNjl005o`00
00?oVkc_00?o0000oifol?nM_o002?nM_o000ol0003oX<;`oj32l008oj32l003o`000?nTa?3oY<C`
00SoY<C`0_l00003ojO6k`Go00000onXao000ol0003oZ/S_oj[8k`0:oj[8k`03o`000?n]bNko[LW^
00Wo[LW^00?o0000ojo9kOn_bNd00ol00005ojc8kP03o`000?n]ango[LO]00[o[LO]00?o0000ojk5
jon^aN/02On^aN/00ol0003o[l?Yojo3j@05o`0000cooooo00?o0000ooooooooool04oooool002;o
oooo00Co0000oooooooooooooooo0ol00024ooooo`03o`000?nD]NkoU;G^00SoU;G^00?o0000oiFg
konE]nl00onE]nl6o`0000WoVkc_00?o0000oifol?nM_o002?nM_o000ol0003oX<;`oj32l008oj32
l003o`000?nTa?3oY<C`00SoY<C`1?l00009ojS7l003o`000?nZb>ooZ/S_00[oZ/S_00?o0000ojg9
k_n]bNh02?n]bNh3o`0000Wo[<S^00?o0000ojg7kOn]and02_n]and00ol0003o[/G[ojk5j`08ojk5
j`Go00003oooool00ol0003oooooooooo`0Cooooo`008_ooool4o`0008Sooooo00?o0000oiBek_nD
]Nh01_nD]Nh7o`0000KoV[[^00?o0000oi^lkonK_>l01onK_>l00ol0003oWKo`oifol008oifol003
o`000?nP`_3oX<;`00SoX<;`00?o0000ojC4l?nTa?001?nTa?03o`000003ojG6l?l0003o000000_o
Z<O`00?o0000oj[8konZb>l02_nZb>l00ol0003o[LW^ojg9kP04ojg9kP?o000000?oZlW_o`000?n/
b>h02_n/b>h00ol0003o[LO]ojg7k@0:ojg7k@03o`000?n^aN_o[/G[00Co[/G[1Ol0000Booooo`03
o`000?oooooooooo01?ooooo000Rooooo`?o0000R_ooool00ol0003oU;G^oiBekP05o`0000?oVKO]
00?o0000oiZjk_nJ^^h02?nJ^^h00ol0003oVkc_oi^lk`07oi^lk`03o`000?nM_o3oWKo`00SoWKo`
00?o0000oj32l?nP`_002?nP`_000ol0003oY<C`ojC4l003o`0000GoYLK`0_l0000;ojS7l003o`00
0?nZb>ooZ/S_00[oZ/S_00?o0000ojg9k_n]bNh00ol00005oj_9k`03o`000?n/b>ko[<S^00Wo[<S^
00?o0000ojg7kOn]and02_n]and00ol0003o[/G[ojk5j`04o`0001Oooooo00?o0000ooooooooool0
4_ooool002Cooooo00?o0000ooooooooool0ROooool2o`0000WoVKO]00?o0000oiZjk_nJ^^h02?nJ
^^h00ol0003oVkc_oi^lk`07oi^lk`03o`000?nM_o3oWKo`00SoWKo`00?o0000oj32l?nP`_001_nP
`_04o`0000SoYLK`00?o0000ojG6l?l000002onXao000ol0003oZ/S_oj[8k`08oj[8k`Co00002On[
bNl00ol0003o[<S^ojc8kP09ojc8kP03o`000?n]ango[LO]00So[LO]1Ol0000Jooooo`03o`000?oo
oooooooo01;ooooo000Fooooo`03onk^k_l0003o000000;o000000?o410@ooooooooool01oooool0
0ol0003oooooooooo`29ooooo`03o`000?nI]ngoVKO]00SoVKO]00?o0000oiZjk_nJ^^h02?nJ^^h0
0ol0003oVkc_oi^lk`07oi^lk`03o`000?nM_o3oWKo`00SoWKo`00?o0000oj32l?nP`_001Ol00003
oj?4l003o`000?nUa_3oYLK`00OoYLK`00?o0000ojG6l?l000002onXao000ol0003oZ/S_oj[8k`04
oj[8k`?o00000onYbO000ol0003oZlW_oj_9k`08oj_9k`03o`000?n/b>ko[<S^00Wo[<S^00?o0000
ojg7kOn]and01?n]and5o`0001gooooo00?o0000ooooooooool04_ooool001Kooooo00GoMgMgoiRH
V?oooooo0000ogMgM`0;ooooo`03o`000?oooooooooo08Wooooo00?o0000oiVgkOnI]nd02?nI]nd0
0ol0003oV[[^oiZjkP08oiZjkP03o`000?nK_>ooVkc_00OoVkc_00?o0000oifol?nM_o001_nM_o04
o`0000WoXlC`00?o0000ojG6l?nUa_001onUa_000ol0003oYLK`o`00000;ojS7l003o`000?nZb>oo
Z/S_00?o00001onYbO000ol0003oZlW_oj_9k`08oj_9k`03o`000?n/b>ko[<S^00Wo[<S^00?o0000
ojg7kOn]and01?l0000Qooooo`03o`000?oooooooooo01;ooooo000Fooooo`05oa0@4?oooooooooo
o`000?l@41003?ooool00ol0003oooooooooo`29ooooo`03o`000?nI]ngoVKO]00SoVKO]00?o0000
oiZjk_nJ^^h02?nJ^^h00ol0003oVkc_oi^lk`07oi^lk`03o`000?nM_o3oWKo`00Go00001?nQ`Nl0
0ol0003oXlC`oj?4l007oj?4l003o`000?nUa_3oYLK`00OoYLK`00?o0000ojG6l?l000002_nXao03
o`0000_oZLW`00?o0000oj_9kon[bNl02?n[bNl00ol0003o[<S^ojc8kP08ojc8kPCo00009?ooool0
0ol0003oooooooooo`0Booooo`005_ooool00ol0003oooooooooo`02o`0000gooooo00?o0000oooo
ooooool0ROooool00ol0003oVKO]oiVgk@08oiVgk@03o`000?nJ^^koV[[^00SoV[[^00?o0000oi^l
konK_>l01OnK_>l4o`0000[oXL7_00?o0000oj?4l?nSa?001onSa?000ol0003oYLK`ojG6l007ojG6
l003o`000?nUa_3o000000KoZ<O`0ol00003ojS8l003o`000?nYbO3oZLW`00WoZLW`00?o0000oj_9
kon[bNl02?n[bNl00ol0003o[<S^ojc8kP04ojc8kPCo00009oooool00ol0003oooooooooo`0Boooo
o`005_ooool00ol0003oooooooooo`02o`0000kooooo00?o0000ooooooooool0ROooool00ol0003o
VKO]oiVgk@08oiVgk@03o`000?nJ^^koV[[^00SoV[[^00?o0000oi^lkonK_>l01?l00004oj2nkP03
o`000?nQ`NooXL7_00SoXL7_00?o0000oj?4l?nSa?001onSa?000ol0003oYLK`ojG6l007ojG6l003
o`000?nUa_3o000000;oZ<O`0ol00007ojS8l003o`000?nYbO3oZLW`00WoZLW`00?o0000oj_9kon[
bNl02?n[bNl00ol0003o[<S^ojc8kP04o`0002[ooooo00?o0000ooooooooool04_ooool001Kooooo
00Go410@oooooooooooo0000oa0@400?ooooo`03o`000?oooooooooo08Wooooo00?o0000oiVgkOnI
]nd02?nI]nd00ol0003oV[[^oiZjkP06oiZjkPCo00002OnP_^h00ol0003oXL7_oj71k`08oj71k`03
o`000?nSa?3oXlC`00OoXlC`00?o0000ojG6l?nUa_001onUa_04o`0000_oZ<S`00?o0000ojW9l?nY
bO002OnYbO000ol0003oZlW_oj_9k`06oj_9k`Co0000;_ooool00ol0003oooooooooo`0Booooo`00
5_ooool01OmgMgOoV9RHooooool0003oMgMg013ooooo0_l0002:ooooo`03o`000?nI]ngoVKO]00So
VKO]00?o0000oiZjk_nJ^^h01Ol00002oinlk@03o`000?nP_^koX;k^00WoX;k^00?o0000oj71konQ
`Nl02?nQ`Nl00ol0003oXlC`oj?4l007oj?4l003o`000?nUa_3oYLK`00CoYLK`1?l00002ojO7l003
o`000?nXb?3oZ<S`00WoZ<S`00?o0000ojW9l?nYbO002OnYbO000ol0003oZlW_oj_9k`06o`00037o
oooo00?o0000ooooooooool04_ooool001Kooooo00Gok^k^o`<30ol0003o0000onk^kP0Booooo`03
o`000?oooooooooo08Sooooo00?o0000oiVgkOnI]nd01_nI]nd4o`0000SoWkc]00?o0000oj2nk_nP
_^h02OnP_^h00ol0003oXL7_oj71k`08oj71k`03o`000?nSa?3oXlC`00OoXlC`00?o0000ojG6l?nU
a_000ol00003ojO7l005o`000?nWao3oYlO`ojO7l?l000002onXb?000ol0003oZLW`ojW9l008ojW9
l0Ko0000=?ooool00ol0003oooooooooo`0Booooo`00;?ooool00ol0003oooooo`00002:ooooo`03
o`000?nI]ngoVKO]00Go00000_nO^N/00ol0003oWkc]oinlk@08oinlk@03o`000?nP_^koX;k^00Wo
X;k^00?o0000oj71konQ`Nl02?nQ`Nl00ol0003oXlC`oj?4l005oj?4l0Co00001onWao001Ol0003o
YlO`ojO7l?nWao3o000000_oZ<S`00?o0000ojW9l?nYbO001?nYbO05o`0003Sooooo00?o0000oooo
ooooool04_ooool002oooooo00?o0000ooooooooool0R?ooool2o`0000SoWkW[00?o0000oinlkOnO
_>d02?nO_>d00ol0003oX;k^oj2nkP09oj2nkP03o`000?nQ`NooXL7_00SoXL7_00?o0000oj?4l?nS
a?001?l00004ojK5k`03o`000?nWao3oYlO`00GoYlO`00Go0000ojO7l?nWao3oYlO`o`00000;ojS8
l003o`000?nYbO3oZLW`00Go0000??ooool00ol0003oooooooooo`0Aooooo`00<?ooool00ol0003o
ooooooooo`27ooooo`;o00002OnO^N/00ol0003oWkc]oinlk@08oinlk@03o`000?nP_^koX;k^00Wo
X;k^00?o0000oj71konQ`Nl01_nQ`Nl4o`0000WoY/G_00?o0000ojO7l?nWao001OnWao001Ol0003o
YlO`ojO7l?nWao3o000000[oZ<S`1Ol0000oooooo`03o`000?oooooooooo017ooooo000aooooo`03
o`000?oooooooooo08Oooooo0_l00009oinij`03o`000?nO_>goWkc]00SoWkc]00?o0000oj2nk_nP
_^h02OnP_^h00ol0003oXL7_oj71k`05o`0000?oYL?^00?o0000ojK5konVaNl02?nVaNl00ol0003o
YlO`ojO7l005ojO7l005o`000?nWao3oYlO`ojO7l?l000001_nXb?04o`0004?ooooo00?o0000oooo
ooooool04Oooool003;ooooo00?o0000ooooooooool0Qoooool2o`0000WoWkW[00?o0000oinlkOnO
_>d02?nO_>d00ol0003oX;k^oj2nkP08oj2nkP?o00002OnU`nh00ol0003oY/G_ojK5k`08ojK5k`03
o`000?nWao3oYlO`00GoYlO`00Go0000ojO7l?nWao3oYlO`o`000002ojS8l0Co0000A_ooool00ol0
003oooooooooo`0Aooooo`00<oooool00ol0003oooooooooo`27ooooo`;o00002OnO^N/00ol0003o
Wkc]oinlk@08oinlk@03o`000?nP_^koX;k^00CoX;k^0ol00002ojG0k@03o`000?nU`nkoYL?^00So
YL?^00?o0000ojK5konVaNl02?nVaNl00ol0003oYlO`ojO7l005ojO7l003o`000?nWao3oYlO`00Co
0000BOooool00ol0003oooooooooo`0Aooooo`00=?ooool2o`0008Sooooo0_l00009oinij`03o`00
0?nO_>goWkc]00SoWkc]00?o0000oj2nk_nP_^h00ol00006ojG0k@03o`000?nU`nkoYL?^00SoYL?^
00?o0000ojK5konVaNl02?nVaNl00ol0003oYlO`ojO7l004ojO7l0?o0000COooool00ol0003ooooo
ooooo`0Aooooo`00=_ooool00ol0003oooooooooo`26ooooo`;o00002OnO^N/00ol0003oWkc]oinl
k@06oinlk@Co00002_nU`>d00ol0003oYL?^ojG3kP08ojG3kP03o`000?nVaNooY/G_00SoY/G_00?o
0000ojO7l?nWao000ol000000ooooooo0000ooooo`1=ooooo`03o`000?oooooooooo017ooooo000g
ooooo`;o0000Qoooool2o`0000WoWkW[00?o0000oinlkOnO_>d01Ol00003ojBmj`03o`000?nU`>go
YL3]00WoYL3]00?o0000ojG3k_nU`nh02?nU`nh00ol0003oY/G_ojK5k`06ojK5k`Co00001Oooool0
0ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo000fooooo`03o`000?oooooo0000
08Sooooo0_l00007oinij`Co00002OnT_N/00ol0003oYL3]ojG0k@09ojG0k@03o`000?nU`nkoYL?^
00SoYL?^00?o0000ojK5konVaNl01Ol0000:ooooo`03o`000?oooooooooo04[ooooo00?o0000oooo
ooooool04Oooool003Wooooo00?o0000ooooooooool0Q_ooool2o`0000;oWkW[1?l00003ojBkj@03
o`000?nT_N_oY;g[00SoY;g[00?o0000ojG0kOnU`>d02OnU`>d00ol0003oYL?^ojG3kP07ojG3kPGo
00003_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo017ooooo000jooooo`03o`00
0?oooooooooo08Kooooo0ol00008ojBkj@03o`000?nT_N_oY;g[00SoY;g[00?o0000ojG0kOnU`>d0
2OnU`>d00ol0003oYL?^ojG3kP03ojG3kPGo00004_ooool00ol0003oooooooooo`18ooooo`03o`00
0?oooooooooo017ooooo000kooooo`03o`000?oooooooooo08Kooooo00?o0000ojBkjOnT^nT02?nT
^nT00ol0003oY;g[ojBmj`08ojBmj`03o`000?nU`>goYL3]00WoYL3]00?o0000ojG3k_l000000ol0
000Gooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool04?ooool003cooooo00?o0000
ooooooooool0Q_ooool00ol0003oY;_YojBkj@08ojBkj@03o`000?nT_N_oY;g[00SoY;g[00?o0000
ojG0kOnU`>d02?nU`>d3o`0001_ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0@
ooooo`00?Oooool2o`0008Oooooo00?o0000ojBkjOnT^nT02?nT^nT00ol0003oY;g[ojBmj`08ojBm
j`03o`000?nU`>goYL3]00CoYL3]0ol0000Oooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool04?ooool003oooooo00?o0000ooooooooool0QOooool00ol0003oY;_YojBkj@08ojBkj@03
o`000?nT_N_oY;g[00SoY;g[00?o0000ojG0kOnU`>d00ol0000Rooooo`03o`000?oooooooooo04Ko
oooo00?o0000ooooooooool04?ooool0043ooooo00?o0000ooooooooool0QOooool00ol0003oY;_Y
ojBkj@08ojBkj@03o`000?nT_N_oY;g[00KoY;g[1?l0000Vooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool04?ooool0047ooooo0_l00026ooooo`03o`000?nT^nWoY;_Y00SoY;_Y00?o
0000ojBmjonT_N/01Ol0000[ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool04?oo
ool0043ooooo00?o0000ooooool00000Qoooool00ol0003oY;_YojBkj@07ojBkj@Go0000;oooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo013ooooo0013ooooo`03o`000?oooooooooo
08Gooooo00?o0000ojBkjOnT^nT00onT^nT4o`0003Cooooo00?o0000ooooooooool0@_ooool00ol0
003oooooooooo`0@ooooo`00A?ooool00ol0003oooooooooo`25ooooo`03o`000?nT^nWo000000?o
0000>?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo013ooooo0015ooooo`03o`00
0?oooooooooo08Gooooo0_l0000looooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0
4?ooool004Kooooo0_l00025ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`0@ooooo`00B?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0?ooooo`00BOooool00ol0
003oooooooooo`21ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`0?ooooo`00B_ooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0?ooooo`00B_ooool2o`00087ooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00oooooo
001<ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0@?ooool00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo00oooooo001=ooooo`03o`000?oooooooooo07gooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00oooooo001>oooo
o`03o`000?oooooooooo07cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo00oooooo001?ooooo`;o0000O?ooool00ol0003oooooooooo`12ooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool03oooool0057ooooo00?o0000ooooooooool0
NOooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
3oooool005;ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`14ooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool03oooool005?ooooo00?o0000ooooooooool0Moooool0
0ol0003oooooooooo`15ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03oooool0
05Cooooo0ol0001fooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0?ooooo`00E?ooool2o`0007Oooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo00kooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@08ooooo`03o`000?oooooooooo
07Cooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
00kooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool02?ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo04Wooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0>ooooo`00>?ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool02?ooool2o`0007?ooooo00?o0000ooooooooool0BOooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo00kooooo000hooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`0;ooooo`03o`000?oooooooooo073ooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00kooooo000hooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00gooooo00?o0000
ooooooooool0Koooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool03_ooool003Sooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool03_ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03_ooool003Sooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool2o`0006kooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00kooooo001Oooooo`03o`000?oooooooooo
06_ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
00kooooo001Pooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0D?ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo00kooooo001Qooooo`;o0000J_ooool00ol0003ooooo
ooooo`1@ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool03Oooool006?ooooo00?o
0000ooooooooool0Ioooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool03Oooool006Cooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`1B
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03Oooool006Gooooo00?o0000oooo
ooooool0IOooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool03Oooool006Kooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1Dooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool03Oooool006Kooooo0ol0001Tooooo`03o`00
0?oooooooooo05Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0=ooooo`00J?oo
ool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0=ooooo`00JOooool00ol0003oooooooooo`1Qooooo`03o`000?oooooo
oooo05Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0=ooooo`00J_ooool2o`00
067ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
00gooooo001/ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0F?ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo00gooooo001]ooooo`03o`000?oooooooooo05gooooo
00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00gooooo
001^ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00cooooo001_ooooo`03o`000?oooooooooo05_ooooo00?o0000
ooooooooool0Foooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00cooooo001_oooo
o`?o0000Foooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool03?ooool0077ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`1Mooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool03?ooool007;ooooo00?o0000ooooooooool0
F?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
3?ooool007?ooooo0_l0001Hooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0<ooooo`00MOooool00ol0003oooooooooo`1Eooooo`03o`000?oooooo
oooo05oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0<ooooo`00M_ooool00ol0
003oooooooooo`1Dooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0<ooooo`00Moooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo067o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0<ooooo`00N?ooool2o`0005?ooooo
00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00cooooo
001hooooo`;o0000Doooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool03?ooool007[ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03?ooool007_ooooo00?o0000oooo
ooooool0Coooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool02oooool007cooooo0_l0001?ooooo`03o`000?oooooooooo06Gooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0;ooooo`00O_ooool00ol0003oooooooooo`1<ooooo`03o`00
0?oooooooooo06Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0;ooooo`00Oooo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0;ooooo`00P?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo06Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0;ooooo`00POooool3o`00
04Wooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00_ooooo001fooooo`Co000000?o410@ooooooooool01Oooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo06[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`00
N?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
Joooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo001hooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1[ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool02oooool007Sooooo00?o0000ooooooooool02_ooool2
o`0004Kooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00_ooooo001Looooo`?o000000?o410@ooooooooool05_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00_ooooo001Nooooo`03oa0@4?nj^[[ooooo01Oooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo06kooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0:ooooo`00G_ooool00onHV9So<S8booooo`0Gooooo`03o`00
0?oooooooooo00kooooo0_l00012ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0:ooooo`00G_ooool00ooMgMgo0000okZj^P0Eooooo`03oeEEEOmV
IVKo0000013ooooo0_l00012ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0:ooooo`00G_ooool00omEEEGoMgMgodA4A00Zooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00[ooooo001Mooooo`05omgMgOl@413oooooob4Q8OoMgMd0:_ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0:
ooooo`00GOooool01OmVIVKoQhN7oooooonHV9SoEEEE02_ooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool0
05cooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`0Zooooo`;o0000?Oooool00ol0
003oooooooooo`1cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool005co
oooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0[ooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00[ooooo002Aooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0MOooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo002Aooooo`;o0000>_ooool00ol0003ooooo
ooooo`1fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool009?ooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02_ooool009Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1h
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool009Gooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool009Kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1iooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool009Oooooo0_l0000dooooo`03o`00
0?oooooooooo07[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`00VOoo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`09ooooo`00VOooool3o`00037ooooo00?o0000ooooooooool0O?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo002Kooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Wooooo002Looooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0O_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Wooooo002Mooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool0Ooooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo
002Nooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Ooooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Wooooo002Oooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool0P?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo002Poooo
o`;o0000:oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02?ooool00:7ooooo0_l0000Zooooo`03o`000?oooooooooo08;ooooo00Go0000oooooooo
ooooooooo`00000:ooooo`00Xoooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo08?o
oooo00Co0000oooooooooooo00002_ooool00:Cooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`24ooooo`03o`000?oooooo000000[ooooo002Uooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0QOooool2o`0000[ooooo002Vooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0Q?ooool3o`0000[ooooo002Wooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool0P?ooool4o`0000gooooo002Xooooo`04o`000?oooooo0000o`00027ooooo00?o0000
ooooooooool0O?ooool4o`00017ooooo002>ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@06ooooo`;o00008_ooool00ol0003oooooooooo`1h
ooooo`Co00005Oooool0093ooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo07Cooooo1?l0000Ioooo
o`00T?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`1`ooooo`Co00007Oooool0093ooooo00?o0000ooooooooool0
3_ooool00omgMgOo<S8booooo`09ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
KOooool3o`00027ooooo002@ooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00;ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0JOooool4o`0002Cooooo
002@ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo06Gooooo1?l0000Xooooo`00T?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00oooooo0ol0000Jooooo`03o`000?oooooooooo067ooooo1?l0000/
ooooo`00S_ooool00omEEEGoIVIVo`00000=ooooo`Co00003_ooool2o`0001_ooooo00?o0000oooo
ooooool0GOooool4o`00033ooooo002booooo`;o00006Oooool00ol0003oooooooooo`1Iooooo`Co
0000=?ooool00;Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Eooooo`Co0000
>?ooool00;Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Aooooo`Co0000??oo
ool00;Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1=ooooo`Co0000@?ooool0
0;Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`19ooooo`Co0000A?ooool00;So
oooo0_l0000Cooooo`03o`000?oooooooooo04Gooooo1?l00018ooooo`00^Oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo047ooooo1?l0001<ooooo`00^_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo03kooooo0ol0001@ooooo`00^oooool2o`00013ooooo00?o0000
ooooooooool0>_ooool4o`0005?ooooo002mooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0=_ooool4o`0005Oooooo002nooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0<_ooool4o`0005_ooooo002oooooo`;o00003?ooool00ol0003oooooooooo`0^ooooo`Co0000
Goooool00;oooooo0_l0000<ooooo`03o`000?oooooooooo02[ooooo1?l0001Sooooo`00`Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Kooooo1?l0001Wooooo`00`_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo02;ooooo1?l0001[ooooo`00`oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01kooooo1?l0001_ooooo`00a?ooool2o`0000Oooooo
00?o0000ooooooooool06_ooool4o`0007?ooooo0036ooooo`?o00001?ooool00ol0003ooooooooo
o`0Fooooo`Co0000Moooool00<Kooooo0_l00005ooooo`03o`000?oooooooooo01?ooooo0ol0001k
ooooo`00b?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo1?l0001noooo
o`00bOooool01Ol0003ooooooooooooooooo000000gooooo1?l00022ooooo`00b_ooool01?l0003o
ooooooooool00009ooooo`Co0000Q_ooool00<_ooooo00?o0000ooooool000001Oooool4o`0008[o
oooo003<ooooo`Oo0000S_ooool00<;ooooo1Ol00006ooooo`;o0000T_ooool00<;ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A02Jooooo`00`oooool00onHV9So8B4Qonk^kP2Kooooo`00a?ooool00onH
V9So8B4Qonk^kP2Jooooo`00aOooool00omgMgOoIVIVooooo`2Iooooo`00a_ooool00ol0003ooooo
ooooo`2Hooooo`00`_ooool01Ol0003o^[ZjoooooonHV9So410@09[ooooo0032ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`0V_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?oo
ooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?oo
ooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00:Go
oooo0ol000000ol@413oooooooooo`2fooooo`00Toooool2o`0000_ooooo00?o0000okZj^_ooool0
1?ooool00ol@413o^[Zjooooo`05ooooo`03o`000?nj^[[ooooo00cooooo0_l00005ooooo`03o`00
0?nj^[[ooooo09Wooooo002Cooooo`03o`000?oooooooooo00[ooooo0_lb<S85ooooo`03oiRHV?lb
<S;ooooo00Gooooo0_lb<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:Jooooo`00R?ooool0
1Ol@413o0000o`000?l0003o410@00Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o0000
0oooool00on7QhOo0000okZj^P04ooooo`03omgMgOl0003o^[Zj00Gooooo00?oQhN7o`000?nj^[X0
1?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7QhOo
0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0LOooool008[ooooo00?o0000
ooooooooool01_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3oooo
o`03olc<c?l0003o410@00Cooooo00?oEEEEogMgMom4A4@01Oooool00oo<c<co0000oa0@4004oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o
410@00Gooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q077ooooo002:ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`:oooo
o`05omgMgOl@413oooooob4Q8OoMgMd02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00001aooooo`00R_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2_ooool01OmVIVKoQhN7oooooonHV9SoEEEE00_o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?o
oooo1_l00002ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b077ooooo002:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?lQ
8B7oMgMgogMgMolb<S89ooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool02Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c01aooooo`00Qooo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
oooo0_l00002ooooo`;o00002?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo
00Kooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo00Wooooo00?o410@o`00
0?l000000ol0000:ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj
^[[o410@077ooooo0027ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonj^[[o0000077ooooo0027ooooo`Oo00001Oooool2o`00027ooooo00?o0000ooooooooool0
1Oooool2o`0000gooooo00?o0000ooooooooool02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@1aooooo`00oooooomRooooo`00oooooomRooooo`00oooo
oomRooooo`00\
\>"],
  ImageRangeCache->{{{0, 352.438}, {392.188, 0}} -> {-0.0365789, -0.0401404, \
0.00334761, 0.00334761}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11253 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.066106 1.21212 -1.11022e-16 1.21212 [
[.5 1.12503 -44 0 ]
[.5 1.12503 44 24.5 ]
[.03831 .17557 -5.85635 -9 ]
[.03831 .17557 .14365 0 ]
[.12814 .13981 -17.2021 -9 ]
[.12814 .13981 .79789 0 ]
[.22015 .10319 -16.8352 -9 ]
[.22015 .10319 1.16484 0 ]
[.31441 .06568 -16.4682 -9 ]
[.31441 .06568 1.53178 0 ]
[.411 .02725 -16.1013 -9 ]
[.411 .02725 1.89873 0 ]
[.51 -0.01213 -5.24477 -9 ]
[.51 -0.01213 .75523 0 ]
[.21792 .02683 -9.25094 -12 ]
[.21792 .02683 .74906 0 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[.1484 .76875 -18 -3.08128 ]
[.1484 .76875 0 5.91872 ]
[.29382 .89692 -6 -3.18183 ]
[.29382 .89692 0 5.81817 ]
[.42456 1.01215 -18 -3.26907 ]
[.42456 1.01215 0 5.73093 ]
[.54272 1.11629 -6 -3.34548 ]
[.54272 1.11629 0 5.65452 ]
[.22112 .91822 -10 -4.24244 ]
[.22112 .91822 0 7.75756 ]
[.03467 .19213 -6 -2.71522 ]
[.03467 .19213 0 6.28478 ]
[.02559 .27239 -18 -2.7611 ]
[.02559 .27239 0 6.2389 ]
[.01617 .35567 -18 -2.80881 ]
[.01617 .35567 0 6.19119 ]
[.00638 .44212 -18 -2.85847 ]
[.00638 .44212 0 6.14153 ]
[-0.00378 .53194 -18 -2.9102 ]
[-0.00378 .53194 0 6.0898 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 1.11253 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.12503 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
.04875 .18654 m
.0558 .18375 L
s
[(0)] .03467 .19213 1 -0.39662 Mshowa
.03972 .26693 m
.04679 .2642 L
s
[(0.2)] .02559 .27239 1 -0.38642 Mshowa
.03035 .35034 m
.03744 .34767 L
s
[(0.4)] .01617 .35567 1 -0.37582 Mshowa
.02062 .43693 m
.02774 .43433 L
s
[(0.6)] .00638 .44212 1 -0.36478 Mshowa
.01051 .52689 m
.01765 .52437 L
s
[(0.8)] -0.00378 .53194 1 -0.35329 Mshowa
0 .62042 m
.00717 .61797 L
s
[(1)] -0.01434 .62532 1 -0.3413 Mshowa
.125 Mabswid
.04653 .20636 m
.05076 .2047 L
s
.04428 .22637 m
.04851 .22471 L
s
.04201 .24656 m
.04625 .24491 L
s
.03741 .28749 m
.04165 .28587 L
s
.03508 .30825 m
.03933 .30663 L
s
.03272 .32919 m
.03698 .32759 L
s
.02795 .37168 m
.03221 .37009 L
s
.02553 .39322 m
.02979 .39164 L
s
.02309 .41497 m
.02735 .4134 L
s
.01813 .45909 m
.0224 .45755 L
s
.01561 .48147 m
.01989 .47994 L
s
.01307 .50407 m
.01736 .50255 L
s
.00792 .54993 m
.01221 .54843 L
s
.00531 .5732 m
.0096 .5717 L
s
.00267 .59669 m
.00696 .59521 L
s
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
.5561 .7194 m
.04875 .18654 L
s
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.5561 .7194 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
0 0 m
1 0 L
1 1.11253 L
0 1.11253 L
closepath
clip
newpath
.5 Mabswid
.65 .734 .91 r
.52593 .68772 .5561 .7194 .58394 .7109 .55403 .68015 Metetra
.65 .741 .916 r
.55403 .68015 .58394 .7109 .61197 .70234 .58233 .67247 Metetra
.651 .749 .921 r
.58233 .67247 .61197 .70234 .64019 .69372 .61084 .66461 Metetra
.653 .756 .925 r
.61084 .66461 .64019 .69372 .66861 .68504 .63957 .65654 Metetra
.655 .762 .928 r
.63957 .65654 .66861 .68504 .69723 .6763 .6685 .6482 Metetra
.658 .768 .93 r
.6685 .6482 .69723 .6763 .72605 .6675 .69764 .63956 Metetra
.662 .771 .931 r
.69764 .63956 .72605 .6675 .75507 .65863 .72698 .6306 Metetra
.665 .773 .93 r
.72698 .6306 .75507 .65863 .7843 .6497 .75652 .62131 Metetra
.669 .774 .928 r
.75652 .62131 .7843 .6497 .81374 .64071 .78627 .6117 Metetra
.672 .772 .925 r
.78627 .6117 .81374 .64071 .84339 .63166 .8162 .60178 Metetra
.675 .769 .921 r
.8162 .60178 .84339 .63166 .87325 .62254 .84634 .59158 Metetra
.678 .764 .916 r
.84634 .59158 .87325 .62254 .90333 .61335 .87667 .58115 Metetra
.679 .758 .911 r
.87667 .58115 .90333 .61335 .93362 .6041 .9072 .57053 Metetra
.68 .751 .905 r
.9072 .57053 .93362 .6041 .96413 .59478 .93794 .55978 Metetra
.634 .729 .916 r
.49498 .6552 .52593 .68772 .55403 .68015 .52332 .64852 Metetra
.635 .736 .921 r
.52332 .64852 .55403 .68015 .58233 .67247 .55189 .64166 Metetra
.637 .744 .925 r
.55189 .64166 .58233 .67247 .61084 .66461 .58068 .63453 Metetra
.641 .751 .929 r
.58068 .63453 .61084 .66461 .63957 .65654 .6097 .62702 Metetra
.647 .758 .93 r
.6097 .62702 .63957 .65654 .6685 .6482 .63895 .61905 Metetra
.653 .764 .931 r
.63895 .61905 .6685 .6482 .69764 .63956 .6684 .61055 Metetra
.66 .769 .93 r
.6684 .61055 .69764 .63956 .72698 .6306 .69806 .60148 Metetra
.667 .772 .928 r
.69806 .60148 .72698 .6306 .75652 .62131 .72793 .59182 Metetra
.674 .773 .925 r
.72793 .59182 .75652 .62131 .78627 .6117 .75798 .58159 Metetra
.68 .773 .921 r
.75798 .58159 .78627 .6117 .8162 .60178 .78822 .57082 Metetra
.685 .77 .916 r
.78822 .57082 .8162 .60178 .84634 .59158 .81865 .55957 Metetra
.689 .766 .91 r
.81865 .55957 .84634 .59158 .87667 .58115 .84925 .54792 Metetra
.692 .761 .905 r
.84925 .54792 .87667 .58115 .9072 .57053 .88005 .53596 Metetra
.693 .755 .899 r
.88005 .53596 .9072 .57053 .93794 .55978 .91103 .52381 Metetra
.619 .724 .921 r
.4632 .62183 .49498 .6552 .52332 .64852 .49178 .61592 Metetra
.621 .731 .925 r
.49178 .61592 .52332 .64852 .55189 .64166 .5206 .60979 Metetra
.625 .738 .928 r
.5206 .60979 .55189 .64166 .58068 .63453 .54967 .60328 Metetra
.631 .746 .93 r
.54967 .60328 .58068 .63453 .6097 .62702 .57898 .59626 Metetra
.639 .753 .931 r
.57898 .59626 .6097 .62702 .63895 .61905 .60853 .58859 Metetra
.648 .76 .93 r
.60853 .58859 .63895 .61905 .6684 .61055 .6383 .58019 Metetra
.659 .765 .928 r
.6383 .58019 .6684 .61055 .69806 .60148 .66829 .57099 Metetra
.669 .769 .925 r
.66829 .57099 .69806 .60148 .72793 .59182 .69847 .56096 Metetra
.679 .771 .921 r
.69847 .56096 .72793 .59182 .75798 .58159 .72885 .55014 Metetra
.687 .772 .916 r
.72885 .55014 .75798 .58159 .78822 .57082 .75941 .53856 Metetra
.694 .77 .91 r
.75941 .53856 .78822 .57082 .81865 .55957 .79014 .52631 Metetra
.699 .767 .905 r
.79014 .52631 .81865 .55957 .84925 .54792 .82104 .51351 Metetra
.702 .763 .899 r
.82104 .51351 .84925 .54792 .88005 .53596 .85211 .50031 Metetra
.703 .758 .894 r
.85211 .50031 .88005 .53596 .91103 .52381 .88337 .48685 Metetra
.606 .719 .925 r
.43058 .58756 .4632 .62183 .49178 .61592 .45938 .58226 Metetra
.608 .725 .928 r
.45938 .58226 .49178 .61592 .5206 .60979 .48845 .5767 Metetra
.614 .732 .93 r
.48845 .5767 .5206 .60979 .54967 .60328 .51778 .57068 Metetra
.622 .74 .931 r
.51778 .57068 .54967 .60328 .57898 .59626 .54738 .56402 Metetra
.633 .747 .93 r
.54738 .56402 .57898 .59626 .60853 .58859 .57722 .55657 Metetra
.645 .754 .929 r
.57722 .55657 .60853 .58859 .6383 .58019 .6073 .5482 Metetra
.658 .76 .925 r
.6073 .5482 .6383 .58019 .66829 .57099 .63761 .53884 Metetra
.671 .765 .921 r
.63761 .53884 .66829 .57099 .69847 .56096 .66812 .52845 Metetra
.682 .768 .916 r
.66812 .52845 .69847 .56096 .72885 .55014 .69883 .51707 Metetra
.692 .769 .91 r
.69883 .51707 .72885 .55014 .75941 .53856 .72972 .50475 Metetra
.701 .769 .905 r
.72972 .50475 .75941 .53856 .79014 .52631 .76077 .4916 Metetra
.707 .767 .899 r
.76077 .4916 .79014 .52631 .82104 .51351 .79199 .47778 Metetra
.71 .764 .894 r
.79199 .47778 .82104 .51351 .85211 .50031 .82337 .46346 Metetra
.712 .76 .89 r
.82337 .46346 .85211 .50031 .88337 .48685 .85493 .44884 Metetra
.595 .716 .928 r
.39706 .55236 .43058 .58756 .45938 .58226 .42609 .54746 Metetra
.599 .721 .93 r
.42609 .54746 .45938 .58226 .48845 .5767 .4554 .54227 Metetra
.605 .727 .931 r
.4554 .54227 .48845 .5767 .51778 .57068 .48499 .53656 Metetra
.616 .734 .93 r
.48499 .53656 .51778 .57068 .54738 .56402 .51486 .53011 Metetra
.628 .741 .929 r
.51486 .53011 .54738 .56402 .57722 .55657 .54499 .52275 Metetra
.643 .748 .926 r
.54499 .52275 .57722 .55657 .6073 .5482 .57538 .51433 Metetra
.657 .754 .921 r
.57538 .51433 .6073 .5482 .63761 .53884 .60601 .50478 Metetra
.672 .759 .916 r
.60601 .50478 .63761 .53884 .66812 .52845 .63685 .49404 Metetra
.685 .763 .911 r
.63685 .49404 .66812 .52845 .69883 .51707 .6679 .48215 Metetra
.696 .765 .905 r
.6679 .48215 .69883 .51707 .72972 .50475 .69912 .46919 Metetra
.705 .766 .899 r
.69912 .46919 .72972 .50475 .76077 .4916 .73052 .45527 Metetra
.712 .765 .894 r
.73052 .45527 .76077 .4916 .79199 .47778 .76207 .44058 Metetra
.716 .763 .889 r
.76207 .44058 .79199 .47778 .82337 .46346 .79379 .42533 Metetra
.718 .76 .886 r
.79379 .42533 .82337 .46346 .85493 .44884 .82567 .40974 Metetra
.589 .713 .929 r
.36263 .5162 .39706 .55236 .42609 .54746 .39188 .51145 Metetra
.593 .717 .93 r
.39188 .51145 .42609 .54746 .4554 .54227 .42143 .50639 Metetra
.601 .722 .93 r
.42143 .50639 .4554 .54227 .48499 .53656 .45127 .50077 Metetra
.612 .728 .928 r
.45127 .50077 .48499 .53656 .51486 .53011 .48141 .49435 Metetra
.626 .735 .925 r
.48141 .49435 .51486 .53011 .54499 .52275 .51183 .48694 Metetra
.641 .741 .922 r
.51183 .48694 .54499 .52275 .57538 .51433 .54252 .47839 Metetra
.657 .747 .917 r
.54252 .47839 .57538 .51433 .60601 .50478 .57346 .4686 Metetra
.672 .753 .911 r
.57346 .4686 .60601 .50478 .63685 .49404 .60464 .45752 Metetra
.686 .757 .905 r
.60464 .45752 .63685 .49404 .6679 .48215 .63602 .4452 Metetra
.698 .76 .9 r
.63602 .4452 .6679 .48215 .69912 .46919 .66759 .4317 Metetra
.708 .761 .894 r
.66759 .4317 .69912 .46919 .73052 .45527 .69934 .41718 Metetra
.715 .762 .889 r
.69934 .41718 .73052 .45527 .76207 .44058 .73125 .40181 Metetra
.72 .761 .886 r
.73125 .40181 .76207 .44058 .79379 .42533 .76333 .38584 Metetra
.722 .76 .883 r
.76333 .38584 .79379 .42533 .82567 .40974 .79557 .36951 Metetra
.586 .712 .93 r
.32723 .47902 .36263 .5162 .39188 .51145 .35671 .47416 Metetra
.591 .715 .93 r
.35671 .47416 .39188 .51145 .42143 .50639 .3865 .46897 Metetra
.599 .719 .928 r
.3865 .46897 .42143 .50639 .45127 .50077 .4166 .46321 Metetra
.611 .724 .925 r
.4166 .46321 .45127 .50077 .48141 .49435 .447 .45663 Metetra
.626 .729 .922 r
.447 .45663 .48141 .49435 .51183 .48694 .47771 .44901 Metetra
.641 .735 .917 r
.47771 .44901 .51183 .48694 .54252 .47839 .5087 .44022 Metetra
.657 .741 .912 r
.5087 .44022 .54252 .47839 .57346 .4686 .53995 .43015 Metetra
.672 .746 .906 r
.53995 .43015 .57346 .4686 .60464 .45752 .57146 .41875 Metetra
.686 .75 .9 r
.57146 .41875 .60464 .45752 .63602 .4452 .60318 .40606 Metetra
.698 .754 .895 r
.60318 .40606 .63602 .4452 .66759 .4317 .63511 .39216 Metetra
.708 .756 .89 r
.63511 .39216 .66759 .4317 .69934 .41718 .66722 .3772 Metetra
.715 .758 .886 r
.66722 .3772 .69934 .41718 .73125 .40181 .6995 .36137 Metetra
.72 .759 .883 r
.6995 .36137 .73125 .40181 .76333 .38584 .73195 .34492 Metetra
.723 .759 .881 r
.73195 .34492 .76333 .38584 .79557 .36951 .76458 .32809 Metetra
.589 .713 .929 r
.29083 .44079 .32723 .47902 .35671 .47416 .32055 .43553 Metetra
.593 .714 .928 r
.32055 .43553 .35671 .47416 .3865 .46897 .35059 .42995 Metetra
.602 .716 .925 r
.35059 .42995 .3865 .46897 .4166 .46321 .38095 .42379 Metetra
.613 .72 .921 r
.38095 .42379 .4166 .46321 .447 .45663 .41162 .41683 Metetra
.627 .724 .917 r
.41162 .41683 .447 .45663 .47771 .44901 .44261 .40885 Metetra
.642 .729 .912 r
.44261 .40885 .47771 .44901 .5087 .44022 .4739 .39971 Metetra
.657 .734 .906 r
.4739 .39971 .5087 .44022 .53995 .43015 .50546 .38931 Metetra
.672 .739 .901 r
.50546 .38931 .53995 .43015 .57146 .41875 .53729 .3776 Metetra
.685 .743 .896 r
.53729 .3776 .57146 .41875 .60318 .40606 .56936 .36462 Metetra
.696 .747 .891 r
.56936 .36462 .60318 .40606 .63511 .39216 .60164 .35046 Metetra
.706 .751 .887 r
.60164 .35046 .63511 .39216 .66722 .3772 .63412 .33524 Metetra
.713 .753 .884 r
.63412 .33524 .66722 .3772 .6995 .36137 .66679 .31917 Metetra
.718 .756 .882 r
.66679 .31917 .6995 .36137 .73195 .34492 .69963 .30249 Metetra
.721 .757 .881 r
.69963 .30249 .73195 .34492 .76458 .32809 .73265 .28543 Metetra
.595 .716 .928 r
.25338 .40146 .29083 .44079 .32055 .43553 .28337 .39552 Metetra
.6 .715 .925 r
.28337 .39552 .32055 .43553 .35059 .42995 .31367 .38927 Metetra
.608 .716 .921 r
.31367 .38927 .35059 .42995 .38095 .42379 .3443 .38248 Metetra
.618 .718 .917 r
.3443 .38248 .38095 .42379 .41162 .41683 .37525 .37492 Metetra
.631 .72 .912 r
.37525 .37492 .41162 .41683 .44261 .40885 .40652 .36642 Metetra
.644 .724 .907 r
.40652 .36642 .44261 .40885 .4739 .39971 .4381 .35682 Metetra
.657 .728 .901 r
.4381 .35682 .4739 .39971 .50546 .38931 .46998 .34605 Metetra
.671 .732 .896 r
.46998 .34605 .50546 .38931 .53729 .3776 .50213 .33405 Metetra
.683 .736 .891 r
.50213 .33405 .53729 .3776 .56936 .36462 .53453 .32086 Metetra
.693 .741 .888 r
.53453 .32086 .56936 .36462 .60164 .35046 .56717 .30656 Metetra
.702 .745 .884 r
.56717 .30656 .60164 .35046 .63412 .33524 .60002 .29127 Metetra
.709 .748 .882 r
.60002 .29127 .63412 .33524 .66679 .31917 .63307 .27518 Metetra
.714 .752 .882 r
.63307 .27518 .66679 .31917 .69963 .30249 .66632 .2585 Metetra
.717 .754 .882 r
.66632 .2585 .69963 .30249 .73265 .28543 .69976 .24147 Metetra
.606 .719 .925 r
.21484 .36098 .25338 .40146 .28337 .39552 .24512 .3541 Metetra
.61 .717 .921 r
.24512 .3541 .28337 .39552 .31367 .38927 .27571 .34693 Metetra
.616 .716 .917 r
.27571 .34693 .31367 .38927 .3443 .38248 .30662 .33927 Metetra
.625 .716 .912 r
.30662 .33927 .3443 .38248 .37525 .37492 .33786 .33093 Metetra
.636 .718 .907 r
.33786 .33093 .37525 .37492 .40652 .36642 .36942 .32174 Metetra
.647 .72 .901 r
.36942 .32174 .40652 .36642 .4381 .35682 .4013 .31159 Metetra
.658 .723 .897 r
.4013 .31159 .4381 .35682 .46998 .34605 .43348 .3004 Metetra
.669 .726 .892 r
.43348 .3004 .46998 .34605 .50213 .33405 .46595 .28812 Metetra
.68 .73 .888 r
.46595 .28812 .50213 .33405 .53453 .32086 .49868 .27479 Metetra
.689 .734 .885 r
.49868 .27479 .53453 .32086 .56717 .30656 .53167 .26047 Metetra
.697 .739 .883 r
.53167 .26047 .56717 .30656 .60002 .29127 .56489 .24528 Metetra
.703 .743 .882 r
.56489 .24528 .60002 .29127 .63307 .27518 .59833 .22936 Metetra
.708 .747 .883 r
.59833 .22936 .63307 .27518 .66632 .2585 .63199 .21293 Metetra
.711 .751 .884 r
.63199 .21293 .66632 .2585 .69976 .24147 .66586 .19616 Metetra
.619 .724 .921 r
.17516 .3193 .21484 .36098 .24512 .3541 .20576 .31124 Metetra
.622 .72 .917 r
.20576 .31124 .24512 .3541 .27571 .34693 .23666 .30292 Metetra
.627 .718 .912 r
.23666 .30292 .27571 .34693 .30662 .33927 .26787 .29419 Metetra
.634 .716 .907 r
.26787 .29419 .30662 .33927 .33786 .33093 .29941 .28488 Metetra
.642 .716 .902 r
.29941 .28488 .33786 .33093 .36942 .32174 .33128 .27488 Metetra
.65 .716 .897 r
.33128 .27488 .36942 .32174 .4013 .31159 .36346 .26408 Metetra
.659 .718 .892 r
.36346 .26408 .4013 .31159 .43348 .3004 .39594 .25242 Metetra
.668 .721 .889 r
.39594 .25242 .43348 .3004 .46595 .28812 .42873 .23987 Metetra
.676 .724 .886 r
.42873 .23987 .46595 .28812 .49868 .27479 .46179 .22646 Metetra
.683 .728 .884 r
.46179 .22646 .49868 .27479 .53167 .26047 .49512 .21223 Metetra
.69 .733 .883 r
.49512 .21223 .53167 .26047 .56489 .24528 .52871 .19727 Metetra
.695 .737 .883 r
.52871 .19727 .56489 .24528 .59833 .22936 .56253 .18172 Metetra
.699 .742 .885 r
.56253 .18172 .59833 .22936 .63199 .21293 .59659 .16572 Metetra
.702 .747 .887 r
.59659 .16572 .63199 .21293 .66586 .19616 .63089 .14942 Metetra
.634 .729 .916 r
.13429 .27638 .17516 .3193 .20576 .31124 .16524 .26693 Metetra
.636 .724 .911 r
.16524 .26693 .20576 .31124 .23666 .30292 .19648 .25727 Metetra
.639 .72 .906 r
.19648 .25727 .23666 .30292 .26787 .29419 .22803 .24729 Metetra
.643 .717 .901 r
.22803 .24729 .26787 .29419 .29941 .28488 .25989 .23688 Metetra
.648 .715 .897 r
.25989 .23688 .29941 .28488 .33128 .27488 .29207 .22594 Metetra
.654 .714 .893 r
.29207 .22594 .33128 .27488 .36346 .26408 .32455 .21442 Metetra
.66 .715 .889 r
.32455 .21442 .36346 .26408 .39594 .25242 .35735 .20226 Metetra
.666 .717 .886 r
.35735 .20226 .39594 .25242 .42873 .23987 .39044 .18944 Metetra
.672 .719 .885 r
.39044 .18944 .42873 .23987 .46179 .22646 .42383 .17599 Metetra
.677 .723 .884 r
.42383 .17599 .46179 .22646 .49512 .21223 .45749 .16193 Metetra
.682 .727 .884 r
.45749 .16193 .49512 .21223 .52871 .19727 .49143 .14732 Metetra
.686 .732 .885 r
.49143 .14732 .52871 .19727 .56253 .18172 .52563 .13226 Metetra
.689 .737 .888 r
.52563 .13226 .56253 .18172 .59659 .16572 .56009 .11685 Metetra
.691 .743 .891 r
.56009 .11685 .59659 .16572 .63089 .14942 .59481 .1012 Metetra
.65 .734 .91 r
.09217 .23214 .13429 .27638 .16524 .26693 .12351 .22117 Metetra
.651 .728 .906 r
.12351 .22117 .16524 .26693 .19648 .25727 .15512 .21003 Metetra
.652 .723 .901 r
.15512 .21003 .19648 .25727 .22803 .24729 .18703 .19868 Metetra
.653 .719 .896 r
.18703 .19868 .22803 .24729 .25989 .23688 .21924 .18705 Metetra
.656 .716 .892 r
.21924 .18705 .25989 .23688 .29207 .22594 .25174 .17509 Metetra
.658 .714 .889 r
.25174 .17509 .29207 .22594 .32455 .21442 .28455 .16278 Metetra
.661 .713 .887 r
.28455 .16278 .32455 .21442 .35735 .20226 .31765 .15009 Metetra
.664 .713 .885 r
.31765 .15009 .35735 .20226 .39044 .18944 .35106 .137 Metetra
.667 .715 .884 r
.35106 .137 .39044 .18944 .42383 .17599 .38475 .12352 Metetra
.67 .718 .885 r
.38475 .12352 .42383 .17599 .45749 .16193 .41874 .10968 Metetra
.673 .722 .886 r
.41874 .10968 .45749 .16193 .49143 .14732 .45302 .0955 Metetra
.675 .726 .888 r
.45302 .0955 .49143 .14732 .52563 .13226 .48758 .08103 Metetra
.677 .732 .891 r
.48758 .08103 .52563 .13226 .56009 .11685 .52242 .06632 Metetra
.679 .738 .895 r
.52242 .06632 .56009 .11685 .59481 .1012 .55756 .05142 Metetra
.666 .738 .904 r
.04875 .18654 .09217 .23214 .12351 .22117 .08051 .17394 Metetra
.665 .732 .9 r
.08051 .17394 .12351 .22117 .15512 .21003 .11254 .16124 Metetra
.664 .726 .896 r
.11254 .16124 .15512 .21003 .18703 .19868 .14483 .14843 Metetra
.664 .721 .892 r
.14483 .14843 .18703 .19868 .21924 .18705 .1774 .13551 Metetra
.663 .717 .889 r
.1774 .13551 .21924 .18705 .25174 .17509 .21025 .12249 Metetra
.663 .714 .886 r
.21025 .12249 .25174 .17509 .28455 .16278 .24339 .10934 Metetra
.662 .712 .885 r
.24339 .10934 .28455 .16278 .31765 .15009 .27681 .09609 Metetra
.662 .712 .885 r
.27681 .09609 .31765 .15009 .35106 .137 .31052 .08272 Metetra
.662 .712 .885 r
.31052 .08272 .35106 .137 .38475 .12352 .34452 .06923 Metetra
.663 .714 .886 r
.34452 .06923 .38475 .12352 .41874 .10968 .37882 .05563 Metetra
.663 .717 .889 r
.37882 .05563 .41874 .10968 .45302 .0955 .41342 .04191 Metetra
.664 .721 .892 r
.41342 .04191 .45302 .0955 .48758 .08103 .44833 .02806 Metetra
.664 .726 .896 r
.44833 .02806 .48758 .08103 .52242 .06632 .48355 .01409 Metetra
.665 .732 .9 r
.48355 .01409 .52242 .06632 .55756 .05142 .51908 0 Metetra
0 g
.25 Mabswid
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282.75, 314.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005Q0001RB000`400?l00000o`00003ooooooomR
ooooo`00oooooomRooooo`00oooooomRooooo`00^_ooool4o`000003oa0@4?oooooooooo0:3ooooo
002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002loooo
o`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`00
0?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002jooooo`03oeEEEOmVIVKo
00000:Cooooo003oooooof;ooooo003oooooof;ooooo001Mooooo`;o00000_ooool2o`000?kooooo
001Mooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgMo_ooool005kooooo00CogMgMo`000?l@413o
c<c<:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`07oooool2o`0009oooooo001Nooooo`04onk^k_lQ8B7o410@onk^kR[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01cooooo
0ol000000onZ^nKo0000o`00002Nooooo`00G_ooool01?lQ8B7oMgMgogMgMolb<S8Zooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001[ooooo0ol00003ojZk
iP?o0000WOooool005gooooo0_l00002ooooo`;o0000:Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`?o00001_nZ^nH00ol0003oZ[_Vo`00002M
ooooo`00S?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00Eooooo`?o00000_nZ^nH00ol0003oZ[_VojZkiP03ojZkiP04o`000?nZ^nKoZ[_Vo`0009cooooo
002<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@01;o
oooo1?l0000:ojZkiP04o`000?nZ^nKoZ[_Vo`0009cooooo002<ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000013ooooo1?l000000onY^NGo0000ojZkiP09
ojZkiP05o`000?nZ^nKoZ[_VojZki_l00000Voooool008cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT03Oooool4o`000003ojViiOl0003oZKWU00;oZKWU
00?o0000ojZki_nZ^nH01onZ^nH00ol0003oZ[_VojZkiP02ojZkiP03o`000?oooooooooo09Sooooo
002/ooooo`Co00002?nY^ND00ol0003oZ[_VojZkiP06ojZkiP03o`000?nZ^nKoZ[_V00?oZ[_V00?o
0000ooooooooool0Uoooool00:Wooooo1?l0000<ojVii@03o`000?nZ^nKoZ[_V00GoZ[_V00?o0000
ojZki_nZ^nH00onZ^nH00ol0003oooooooooo`2Gooooo`00Yoooool6o`0000coZKWU00?o0000ojZk
i_nZ^nH01OnZ^nH00ol0003oZ[_VojZkiP04ojZkiP03o`000?oooooooooo09Kooooo002Tooooo`Co
00001OnY^>@00ol0003oZKWUojVii@0:ojVii@03o`000?nZ^nKoZ[_V00CoZ[_V00?o0000ojZki_nZ
^nH01OnZ^nH00ol0003oooooooooo`2Eooooo`00KOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`08?ooool3o`0000WoZKST00?o0000ojVi
iOnY^ND02_nY^ND00ol0003oZ[_VojZkiP03ojZkiP03o`000?nZ^nKoZ[_V00KoZ[_V00?o0000oooo
ooooool0U?ooool006gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q01gooooo0ol000000onY^>Co0000ojVhi00:ojVhi003o`000?nY^NGo
ZKWU00[oZKWU00?o0000ojZki_nZ^nH00_nZ^nH00ol0003oZ[_VojZkiP06ojZkiP03o`000?oooooo
oooo09Cooooo001]ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000001_ooooo0ol000001OnY]n?o0000ojVhi?nY^>Co000000[oZKST00?o0000ojViiOnY^ND0
2_nY^ND00ol0003oZ[_VojZkiP02ojZkiP03o`000?nZ^nKoZ[_V00OoZ[_V00?o0000ooooooooool0
Toooool006gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B406?ooool3o`0000GoZKOS00?o0000ojVhi?nY^>@02onY^>@00ol0003oZKWUojVii@0:ojVii@05
o`000?nZ^nKoZ[_VojZki_l000002_nZ^nH00ol0003oooooooooo`2Booooo`00KOooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Eooooo`Co000000?oZKOS
o`000?nY]n<01OnY]n<00ol0003oZKSTojVhi00;ojVhi003o`000?nY^NGoZKWU00[oZKWU00Co0000
ojZki_nZ^nKo00002_nZ^nH2o`0009?ooooo001]ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool00omEEEGoQhN7ooooo`0Eooooo`?o00002onY]n<00ol0003oZKSTojVhi00<ojVhi003o`000?nY
^NGoZKWU00[oZKWU00?o0000ojZki_l000002?nZ^nH2o`000003ojfliOl0003ooooo09;ooooo001]
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00Cooooo`Co00003OnY
]n<00ol0003oZKSTojVhi00;ojVhi003o`000?nY^NGoZKWU00[oZKWU00?o0000ojZki_l000001OnZ
^nH3o`0000Co[KcU00?o0000ooooooooool0T?ooool006gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`04olc<c?m4A4Co0000oa0@40oooooo0_l00002ojVfhP03o`000?nY]^;o000000goZKOS
00?o0000ojVhi?nY^>@02onY^>@00ol0003oZKWUojVii@0:ojVii@;o00000onZ^nH2o`0000So[KcU
00?o0000ooooooooool0Soooool008kooooo0ol00007ojVfhP03o`000?nY]n?oZKOS00_oZKOS00?o
0000ojVhi?nY^>@02onY^>@00ol0003oZKWUojVii@0:ojVii@04o`000?nZ^nKo0000o`0000_o[KcU
00?o0000ooooooooool0S_ooool008cooooo0ol0000:ojVfhP03o`000?nY]n?oZKOS00[oZKOS00?o
0000ojVhi?nY^>@03?nY^>@00ol0003oZKWUojVii@09ojVii@;o00003On]_>D2o`0008oooooo0029
ooooo`Co000000?oZKKRo`000?nY]^802OnY]^800ol0003oZKOSojVgh`0;ojVgh`03o`000?nY^>Co
ZKST00_oZKST00?o0000ojViiOnY^ND01_nY^ND5o`0000ko[KcU00?o0000ooooooooool0SOooool0
053ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooo
oooo023ooooo1?l000000onY]^;o0000ojVfhP0<ojVfhP03o`000?nY]n?oZKOS00_oZKOS00?o0000
ojVhi?nY^>@02onY^>@00ol0003oZKWUojVii@03ojVii@;o00000on]^n@00ol0003o[K_To`00000>
ojfli@03o`000?oooooooooo08cooooo001@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool07_ooool4o`0000GoZKKR00?o0000ojVfh_nY]^802onY]^80
0ol0003oZKOSojVgh`0:ojVgh`03o`000?nY^>CoZKST00coZKST00?o0000ojViiOl000000_l00005
ojfki004o`000?n]^nCo[K_To`0000ko[KcU00?o0000ooooooooool0Roooool0053ooooo00Go410@
oooooooooooooooooa0@400;ooooo`Go00007Oooool3o`000003ojVfh_l0003oZKKR00KoZKKR00?o
0000ojVfh_nY]^802onY]^800ol0003oZKOSojVgh`0:ojVgh`03o`000?nY^>CoZKST00_oZKST0_l0
0008ojfki005o`000?n]^nCo[K_Tojfki?l000003On]_>D2o`0008cooooo001@ooooo`05o`000?oo
ooooooooooooool000002oooool01?m4A4CogMgMooooool0000Kooooo`?o00001OnY]^800ol0003o
ZKKRojVfhP05ojVfhP03o`000?nY]^;oZKKR00_oZKKR00?o0000ojVghonY]n<02_nY]n<00ol0003o
ZKSTojVhi008ojVhi0;o000000?o[;WSo`000?n]^n@01on]^n@00ol0003o[K_Tojfki002ojfki003
o`000?n]_>Go[KcU00_o[KcU0_l0002;ooooo`00D?ooool01Ol0003ooooooooooooooooo000000_o
oooo00CogMgMoeEEEOoooooo00006Oooool3o`000003ojVfh_l0003oZKKR00coZKKR00?o0000ojVf
h_nY]^802onY]^800ol0003oZKOSojVgh`0;ojVgh`03o`000?nY^>CoZKST00CoZKST0ol00004ojbi
h`03o`000?n]^nCo[K_T00Go[K_T00?o0000ojfki?n]^n@00_n]^n@00ol0003o[KcUojfli@0<ojfl
i@03o`000?oooooooooo08Wooooo001@ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omg
MgOoc<c<o`00000Fooooo`?o00000_nY]^801?l0003oZKKRojVfh_l0000=ojVfhP03o`000?nY]^;o
ZKKR00_oZKKR00?o0000ojVghonY]n<02_nY]n<00ol0003oZKSTojVhi002ojVhi0;o00002?n/^N<0
0ol0003o[K_Tojfki004ojfki003o`000?n]^nCo[K_T00?o[K_T00?o0000ojfliOn]_>D03?n]_>D0
0ol0003oooooooooo`28ooooo`00D?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000005?ooool3o`0000SoZKKR00?o0000ojVfh_nY]^802onY]^800ol0003oZKKRojVfhP0;
ojVfhP03o`000?nY]n?oZKOS00[oZKOS00Co0000ojVhi?l0003o00002_n/^N<00ol0003o[K_Tojfk
i004ojfki003o`000?n]^nCo[K_T00Co[K_T00?o0000ojfliOn]_>D02on]_>D2o`0008Wooooo001@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0@ooooo`?o00003?nY
]^800ol0003oZKKRojVfhP0;ojVfhP03o`000?nY]^;oZKKR00_oZKKR00?o0000ojVghonY]n<02OnY
]n<2o`0000go[;WS00?o0000ojfki?n]^n@00on]^n@00ol0003o[K_Tojfki005ojfki003o`000?n]
_>Go[KcU00_o[KcU0_l00028ooooo`00Loooool3o`000003ojVfh_l0003o000000_oZKKR00?o0000
ojVfh_nY]^802onY]^800ol0003oZKKRojVfhP0;ojVfhP03o`000?nY]n?oZKOS00KoZKOS0ol00000
0on/^>;o0000ojbih`0=ojbih`03o`000?n]^nCo[K_T00;o[K_T00?o0000ojfki?n]^n@01_n]^n@0
0ol0003o[KcUojfli@0;ojfli@;o0000Qoooool0073ooooo0ol00005ojVfhP03o`000?nY]^;oZKKR
00[oZKKR00?o0000ojVfh_nY]^802onY]^800ol0003oZKKRojVfhP0;ojVfhP03o`000?nY]n?oZKOS
00?oZKOS0_l00005ojbhhP03o`000?n/^N?o[;WS00_o[;WS00?o0000ojfki?n]^n@00_n]^n@00ol0
003o[K_Tojfki006ojfki003o`000?n]_>Go[KcU00Wo[KcU0_l000000on`_^Co0000ooooo`26oooo
o`00K_ooool3o`0000SoZKKR00?o0000ojVfh_nY]^802_nY]^800ol0003oZKKRojVfhP0;ojVfhP03
o`000?nY]^;oZKKR00_oZKKR00?o0000ojVghol000000_l00008ojbhhP03o`000?n/^N?o[;WS00_o
[;WS00Go0000ojfki?n]^nCo[K_To`000009ojfki003o`000?n]_>Go[KcU00Go[KcU0ol00003ok2n
i0;o0000Q_ooool003?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00
02?ooooo0ol00002ojVfhP03o`000?nY]^;oZKKR00KoZKKR00?o0000ojVfh_nY]^802onY]^800ol0
003oZKKRojVfhP0;ojVfhP03o`000?nY]^;oZKKR00[oZKKR0_l0000<ojbhhP03o`000?n/^N?o[;WS
00_o[;WS00Co0000ojfki?n]^nCo00002_n]^n@00ol0003o[KcUojfli@02ojfli@;o00001on`_^@2
o`0008Gooooo000cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Qooooo`?o000000?oZKKRo`000?nY]^802onY]^800ol0003oZKKRojVf
hP0;ojVfhP03o`000?nY]^;oZKKR00[oZKKR00?o0000ojVfh_nY]^801onY]^83o`000003oj^gh_l0
003o[;SR00_o[;SR00?o0000ojbihon/^N<03?n/^N<00ol0003o[K_To`00000;ojfki004o`000?n]
_>Go0000o`0000[o/;kT0_l00024ooooo`00<oooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h07oooool4o`0000CoZKKR00?o0000ojVfh_nY]^802_nY]^800ol0003oZKKR
ojVfhP0:ojVfhP03o`000?nY]^;oZKKR00_oZKKR00?o0000ojVfh_nY]^800onY]^83o`0000GoZkOR
00?o0000ojbhh_n/^>802_n/^>800ol0003o[;WSojbih`0;ojbih`03o`000?n]^nCo000000_o[K_T
0_l0000=ok2ni003o`000?oooooooooo08;ooooo000cooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP0Kooooo`?o00001?nY]^800ol0003oZKKRojVfhP02ojVfhP03o`00
0?nY]^;oZKKR00[oZKKR00?o0000ojVfh_nY]^802_nY]^800ol0003oZKKRojVfhP0;ojVfhP03o`00
0?nY]^;o000000;o00002On[]n800ol0003o[;SRojbhhP0:ojbhhP03o`000?n/^N?o[;WS00_o[;WS
0_l00009ojfki0;o000000?o/;cSo`000?n`_^@03?n`_^@2o`0008?ooooo000cooooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Hooooo`?o00003?nY]^800ol0003oZKKR
ojVfhP09ojVfhP03o`000?nY]^;oZKKR00_oZKKR00?o0000ojVfh_nY]^802_nY]^82o`0000coZkOR
00?o0000ojbhh_n/^>802on/^>800ol0003o[;WSojbih`0;ojbih`03o`000?n]^nCo[K_T00Co[K_T
0ol00004ok2lh`03o`000?n`_^Co/;kT00_o/;kT0_l00022ooooo`00<oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool05?ooool3o`000003ojVghol0003oZKKR00coZKKR
00?o0000ojVfh_nY]^802_nY]^800ol0003oZKKRojVfhP0;ojVfhP03o`000?nY]^;oZKKR00OoZKKR
0_l000000onZ]n;o0000oj^ghP0<oj^ghP03o`000?n/^>;o[;SR00[o[;SR00?o0000ojbihon/^N<0
2on/^N<00ol0003o[K_Tojfki002ojfki0;o00002?n`_><00ol0003o/;kTok2ni00;ok2ni0;o0000
POooool003?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41005?ooool3o`0000CoZKOS00?o0000ojVfh_nY]^802onY]^800ol0003oZKKRojVfhP0:ojVfhP03
o`000?nY]^;oZKKR00[oZKKR00?o0000ojVfh_nY]^801OnY]^82o`0000CoZ[OR00?o0000oj^gh_n[
]n802on[]n800ol0003o[;SRojbhhP0:ojbhhP03o`000?n/^N?o[;WS00[o[;WS0_l000000on]^nCo
0000o`00000;ok2lh`03o`000?n`_^Co/;kT00_o/;kT00?o0000ooooooooool0Ooooool003?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool3o`00
00SoZKOS00?o0000ojVfh_nY]^802onY]^800ol0003oZKKRojVfhP09ojVfhP03o`000?nY]^;oZKKR
00_oZKKR00?o0000ojVfh_nY]^800_nY]^82o`0000OoZ[OR00?o0000oj^gh_n[]n802_n[]n800ol0
003o[;SRojbhhP0;ojbhhP03o`000?n/^N?o[;WS00Wo[;WS0ol0000=ok2lh`03o`000?n`_^Co/;kT
00_o/;kT0_l00020ooooo`00Eoooool3o`000003ojVghol0003oZKOS00SoZKOS00?o0000ojVfh_nY
]^802onY]^800ol0003oZKKRojVfhP09ojVfhP03o`000?nY]^;oZKKR00_oZKKR00Co0000ojVfh_l0
003o00002OnZ]n800ol0003oZkORoj^ghP0;oj^ghP03o`000?n/^>;o[;SR00_o[;SR00?o0000ojbi
hon/^N<01on/^N<2o`000003ojnkh_l0003o/;cS00go/;cS00?o0000ok2ni?n`_^@02on`_^@2o`00
07oooooo001Dooooo`?o000000?oZKSTo`000?nY]n<03?nY]n<00ol0003oZKKRojVfhP0:ojVfhP03
o`000?nY]^;oZKKR00[oZKKR00?o0000ojVfh_nY]^802_nY]^82o`0000coZ[OR00?o0000oj^gh_n[
]n802on[]n800ol0003o[;SRojbhhP0:ojbhhP03o`000?n/^N?o[;WS00Go[;WS0_l000001On_^n;o
0000ojnkh_n_^n;o000000ko/;cS00?o0000ok2ni?n`_^@02on`_^@00ol0003oooooooooo`1moooo
o`00D_ooool3o`0000CoZKST00?o0000ojVghonY]n<02_nY]n<00ol0003oZKKRojVfhP0;ojVfhP03
o`000?nY]^;oZKKR00[oZKKR00?o0000ojVfh_nY]^801_nY]^83o`000003ojVfh_l0003oZ[OR00co
Z[OR00?o0000oj^gh_n[]n802on[]n800ol0003o[;SRojbhhP0:ojbhhP03o`000?n/^N?o[;WS00;o
[;WS0_l00003ojnkhP05o`000?n_^n;o[k_Rojnkh_l000003_n`_><00ol0003o/;kTok2ni00;ok2n
i003o`000?oooooooooo07cooooo000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool4o`00
0003ojVhi?l0003oZKST00CoZKST00?o0000ojVghonY]n<02_nY]n<00ol0003oZKKRojVfhP0;ojVf
hP03o`000?nY]^;oZKKR00WoZKKR00?o0000ojVfh_nY]^800onY]^83o`0000GoZKKR00?o0000ojZg
h_nZ]n802onZ]n800ol0003oZkORoj^ghP0:oj^ghP03o`000?n/^>;o[;SR00_o[;SR00Co0000ojbi
hol0003o00001On_^n800ol0003o[k_RojnkhP02ojnkhP03o`000?n`_>?o/;cS00_o/;cS00?o0000
ok2ni?n`_^@02on`_^@2o`0007gooooo000Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL08Oooool3
o`0000_oZKST00?o0000ojVghonY]n<02_nY]n<00ol0003oZKKRojVfhP0;ojVfhP03o`000?nY]^;o
ZKKR00WoZKKR00?o0000ojVfh_l000000_l00009ojVfhP03o`000?nZ]n;oZ[OR00[oZ[OR00?o0000
oj^gh_n[]n802on[]n800ol0003o[;SRojbhhP0:ojbhhP;o00001on_^n800ol0003o[k_RojnkhP03
ojnkhP03o`000?n`_>?o/;cS00_o/;cS00?o0000ok2ni?n`_^@02on`_^@2o`0007cooooo000Woooo
o`05oa0@4?ooooooooooooooool@41007_ooool5o`0000goZKST00?o0000ojVghonY]n<02_nY]n<0
0ol0003oZKKRojVfhP0:ojVfhP03o`000?nY]^;oZKKR00SoZKKR0ol0000=ojVfhP03o`000?nZ]n;o
Z[OR00[oZ[OR00?o0000oj^gh_n[]n802on[]n800ol0003o[;SRojbhhP06ojbhhP?o000000?o[[[R
o`000?n_^n801_n_^n800ol0003o[k_RojnkhP03ojnkhP03o`000?n`_>?o/;cS00co/;cS00?o0000
ok2ni?n`_^@02?n`_^@2o`000003ok>ohol0003ooooo07_ooooo000Wooooo`05o`000?oooooooooo
ooooool000007?ooool3o`0000;oZKWU00?o0000ojViiOl000003?nY^>@00ol0003oZKOSojVgh`0;
ojVgh`03o`000?nY]^;oZKKR00[oZKKR00?o0000ojVfh_nY]^801?nY]^83o`0000;oZKKS00?o0000
ojVfh_nY]^802onY]^800ol0003oZ[ORojZghP0;ojZghP03o`000?n[]n;oZkOR00[oZkOR00?o0000
ojbhh_n/^>800on/^>83o`0000Go[[[R00?o0000ojnkh_n_^n801?n_^n800ol0003o[k_RojnkhP04
ojnkhP03o`000?n`_>?o/;cS00_o/;cS00?o0000ok2ni?n`_^@01On`_^@3o`0000Co/koS00?o0000
ooooooooool0NOooool002Oooooo00Go0000ooooooooooooooooo`00000Iooooo`Co00001OnY^ND0
0ol0003oZKWUo`00000<ojVhi003o`000?nY]n?oZKOS00_oZKOS00?o0000ojVfh_nY]^802_nY]^80
0ol0003oZKKRojVfhP03o`0000KoZKKS00?o0000ojVfh_nY]^802onY]^800ol0003oZ[ORojZghP0:
ojZghP03o`000?n[]n;oZkOR00_oZkOR00?o0000ojbhh_l000000_l00009ojjjhP03o`000?n_^n;o
[k_R00?o[k_R00?o0000ojnkh_n_^n801On_^n800ol0003o/;cSok2lh`0;ok2lh`03o`000?n`_^Co
/;kT00;o/;kT0_l00007ok>oh`;o0000N_ooool002Oooooo00Go410@oooooooooooooooooa0@400G
ooooo`?o00002onY^ND00ol0003oZKSTojVhi00:ojVhi003o`000?nY]n?oZKOS00[oZKOS00?o0000
ojVfh_nY]^802_nY]^83o`0000[oZKKS00?o0000ojVfh_nY]^802onY]^800ol0003oZ[ORojZghP0:
ojZghP03o`000?n[]n;oZkOR00[oZkOR0_l0000=ojjjhP03o`000?n_^n;o[k_R00;o[k_R00?o0000
ojnkh_n_^n801_n_^n800ol0003o/;cSok2lh`0;ok2lh`04o`000?n`_^Co0000o`0000[o/koS0_l0
001iooooo`009oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo1Ol000000onY^NGo0000ojVi
i@0:ojVii@03o`000?nY^>CoZKST00[oZKST00?o0000ojVghonY]n<02_nY]n<00ol0003oZKKRojVf
hP06ojVfhP?o000000?oZ;KSo`000?nY]^<02onY]^<00ol0003oZKKRojVfhP0;ojVfhP03o`000?nZ
]n;oZ[OR00[oZ[OR00?o0000oj^gh_n[]n801on[]n82o`000003ojfih_l0003o[[[R00co[[[R00?o
0000ojnkh_n_^n800_n_^n800ol0003o[k_RojnkhP07ojnkhP03o`000?n`_>?o/;cS00[o/;cS0_l0
000=ok>oh`03o`000?oooooooooo07Oooooo000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_oo
ool3o`0000CoZ[_V00?o0000ojViiOnY^ND02_nY^ND00ol0003oZKSTojVhi00;ojVhi003o`000?nY
]n?oZKOS00[oZKOS00?o0000ojVfh_nY]^800onY]^82o`0000GoZ;KS00?o0000ojVfhonY]^<02_nY
]^<00ol0003oZKKRojVfhP0:ojVfhP03o`000?nZ]n;oZ[OR00_oZ[OR00?o0000oj^gh_n[]n801?n[
]n82o`0000Co[KWR00?o0000ojjjh_n^^^802on^^^801Ol0003o[k_Rojnkh_n_^n;o000000Wo[k_R
00?o0000ok2lhon`_><02?n`_><2o`000003ok:mh_l0003o/koS00go/koS00?o0000ooooooooool0
M_ooool003_ooooo1Ol00006ojZkiP03o`000?nY^NGoZKWU00[oZKWU00?o0000ojVhi?nY^>@02onY
^>@00ol0003oZKOSojVgh`0:ojVgh`03o`000?nY]^;o000000;o00002?nX]^<00ol0003oZKKSojVf
h`09ojVfh`03o`000?nY]^;oZKKR00_oZKKR00?o0000ojZgh_nZ]n802_nZ]n800ol0003oZkORoj^g
hP02oj^ghP;o00001on]^N800ol0003o[[[RojjjhP0;ojjjhP04o`000?n_^n;o[k_Ro`0000[o[k_R
00?o0000ok2lhon`_><01On`_><2o`0000Co/[gR00?o0000ok>ohonc_n<02onc_n<2o`0007Oooooo
000iooooo`?o00002onZ^nH00ol0003oZKWUojVii@0:ojVii@03o`000?nY^>CoZKST00[oZKST00?o
0000ojVghonY]n<02_nY]n<2o`0000coZ;KS00?o0000ojVfhonY]^<02OnY]^<00ol0003oZKKRojVf
hP0;ojVfhP03o`000?nZ]n;oZ[OR00[oZ[OR00Co0000oj^gh_l0003o00002_n]^N800ol0003o[[[R
ojjjhP0;ojjjhP03o`000?n_^n;o000000_o[k_R00?o0000ok2lhon`_><00_n`_><2o`0000Oo/[gR
00?o0000ok>ohonc_n<02onc_n<2o`0007Kooooo000gooooo`?o000000?oZ[cWo`000?nZ^nH02onZ
^nH00ol0003oZKWUojVii@0:ojVii@03o`000?nY^>CoZKST00[oZKST00?o0000ojVghonY]n<01_nY
]n<3o`000003ojNgi?l0003oZ;KS00coZ;KS00?o0000ojVfhonY]^<02OnY]^<00ol0003oZKKRojVf
hP0;ojVfhP03o`000?nZ]n;oZ[OR00WoZ[OR0_l0000<ojfihP03o`000?n^^^;o[[[R00_o[[[R00?o
0000ojnkh_l000003?n_^n801?l0003o/;cSo`000?l0000:ok:mhP03o`000?nc_n?o/koS00_o/koS
00?o0000ooooooooool0M?ooool003Cooooo0ol000000onZ_>Oo0000ojZli`02ojZli`03o`000?nZ
^nKoZ[_V00[oZ[_V00?o0000ojViiOnY^ND02_nY^ND00ol0003oZKSTojVhi00:ojVhi003o`000?nY
]n?oZKOS00?oZKOS0_l00005ojNgi003o`000?nX]^?oZ;KS00[oZ;KS00?o0000ojVfhonY]^<02_nY
]^<00ol0003oZKKRojVfhP0:ojVfhP03o`000?nZ]n;oZ[OR00KoZ[OR0ol000000on/^>;o0000ojfi
hP0<ojfihP03o`000?n^^^;o[[[R00_o[[[R0_l0000<ojnkhP;o00003?nb_N800ol0003o/koSok>o
h`0<ok>oh`03o`000?oooooooooo07?ooooo000booooo`?o00002?nZ_>L00ol0003oZ[_VojZkiP0:
ojZkiP03o`000?nY^NGoZKWU00[oZKWU00?o0000ojVhi?nY^>@02_nY^>@00ol0003oZKOSo`000002
o`0000SoYkOT00?o0000ojRfhonX]^<02_nX]^<00ol0003oZKKSojVfh`0:ojVfh`03o`000?nY]^;o
ZKKR00[oZKKR00?o0000ojZgh_nZ]n800onZ]n82o`0000Go[;SR00?o0000ojfih_n]^N802on]^N80
0ol0003o[[[RojjjhP0;ojjjhP03o`000?n_^n;o[k_R00So[k_R0_l000000ona_>;o0000ok:mhP0<
ok:mhP03o`000?nc_n?o/koS00_o/koS0_l0001dooooo`00<Oooool00ol0003oZ[cWojZli`0:ojZl
i`03o`000?nZ^nKoZ[_V00[oZ[_V00?o0000ojViiOnY^ND02OnY^ND00ol0003oZKSTojVhi00:ojVh
i0;o00003?nW]n@00ol0003oZ;KSojRfh`0:ojRfh`03o`000?nY]^?oZKKS00[oZKKS00?o0000ojVf
h_nY]^802_nY]^800ol0003oZ[ORo`000002o`0000So[;SR00?o0000ojfih_n]^N802on]^N800ol0
003o[[[RojjjhP0:ojjjhP03o`000?n_^n;o[k_R00Go[k_R0ol00004ok6lhP03o`000?nb_N;o/[gR
00_o/[gR00?o0000ok>ohonc_n<02onc_n<00ol0003oooooooooo`1booooo`00<Oooool2o`0000co
Z[cW00?o0000ojZki_nZ^nH02OnZ^nH00ol0003oZKWUojVii@0:ojVii@03o`000?nY^>CoZKST00Ko
ZKST0ol000000onW^>Go0000ojNgi00;ojNgi003o`000?nX]^?oZ;KS00_oZ;KS00?o0000ojVfhonY
]^<02OnY]^<00ol0003oZKKRojVfhP0:ojVfhP;o00003?n/^>800ol0003o[KWRojfihP0:ojfihP03
o`000?n^^^;o[[[R00[o[[[R0_l00004ojnkhP;o00002?na_>800ol0003o/[gRok:mhP0;ok:mhP03
o`000?nc_n?o/koS00_o/koS00?o0000ooooooooool0LOooool002Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP07ooooo`;o00003OnZ_>L00ol0003oZ[_VojZkiP09ojZkiP03o`000?nY^NGoZKWU00[o
ZKWU00?o0000ojVhi?nY^>@00onY^>@2o`0000GoYkSU00?o0000ojNgi?nW]n@02_nW]n@00ol0003o
Z;KSojRfh`0;ojRfh`03o`000?nY]^?oZKKS00WoZKKS00?o0000ojVfh_nY]^801_nY]^83o`000003
ojZgh_l0003o[;SR00co[;SR00?o0000ojfih_n]^N802_n]^N800ol0003o[[[RojjjhP09ojjjhP04
o`000?n^^^;o0000ojnkhP;o00002ona_>800ol0003o/[gRok:mhP0:ok:mhP03o`000?nc_n?o/koS
00co/koS00?o0000ooooooooool0L?ooool002Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07oooo
o`03o`000?oooooo000000goZ[cW00?o0000ojZki_nZ^nH02OnZ^nH00ol0003oZKWUojVii@0:ojVi
i@03o`000?nY^>Co000000;o00002?nW^>D00ol0003oYkOTojNgi00:ojNgi003o`000?nX]^?oZ;KS
00_oZ;KS00?o0000ojVfhonY]^<02OnY]^<00ol0003oZKKRojVfhP03ojVfhP;o00001OnZ]n800ol0
003o[;SRojbhhP0:ojbhhP03o`000?n]^N;o[KWR00_o[KWR00?o0000ojjjh_n^^^802?n^^^801?l0
003o[[[Ro`000?l0000=ok6lhP03o`000?nb_N;o/[gR00_o/[gR00?o0000ok>ohonc_n<02onc_n<2
o`00077ooooo000Uooooo`05oa0@4?ooooooooooooooool@41001oooool01?l0003oooooooooool0
000=ojZli`03o`000?nZ^nKoZ[_V00WoZ[_V00?o0000ojViiOnY^ND02?nY^ND3o`0000coYkSU00?o
0000ojNgi?nW]n@02_nW]n@00ol0003oZ;KSojRfh`0:ojRfh`03o`000?nY]^?oZKKS00[oZKKS00?o
0000ojVfh_l000000_l00008ojZghP03o`000?n/^>;o[;SR00[o[;SR00?o0000ojfih_n]^N802on]
^N800ol0003o[[[RojjjhP07ojjjhP;o000000?o/;_Ro`000?na_>803Ona_>800ol0003o/[gRok:m
hP0;ok:mhP03o`000?nc_n?o/koS00So/koS0_l000000onf`>;o0000ooooo`1`ooooo`009Oooool0
1Ol0003ooooooooooooooooo000000Kooooo0_l00003ooooo`03o`000?nZ_>OoZ[cW00_oZ[cW00?o
0000ojZki_nZ^nH02OnZ^nH00ol0003oZKWUojVii@04ojVii@?o00000_nV^NH00ol0003oYkSUojNh
i@0;ojNhi@03o`000?nW]nCoYkOT00WoYkOT00?o0000ojRfhonX]^<02onX]^<00ol0003oZKKSojVf
h`08ojVfh`?o00003?nZ]n800ol0003o[;SRojbhhP0:ojbhhP03o`000?n]^N;o[KWR00[o[KWR00?o
0000ojjjh_n^^^801On^^^83o`0000?o/;_R00?o0000ok6lh_na_>803?na_>800ol0003o/[gRok:m
hP0:ok:mhP03o`000?nc_n?o/koS00Go/koS0ol00004okK0hP03o`000?oooooooooo06kooooo000U
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`03o`000?nZ
_>OoZ[cW00_oZ[cW00?o0000ojZki_nZ^nH02OnZ^nH00ol0003oZKWUojVii@03o`0000KoY[WV00?o
0000ojNhiOnW^>D02onW^>D00ol0003oYkOTojNgi009ojNgi003o`000?nX]^?oZ;KS00_oZ;KS00?o
0000ojVfhonY]^<01?nY]^<3o`0000;oZ;OS00?o0000ojZgh_nZ]n802onZ]n800ol0003o[;SRojbh
hP0:ojbhhP03o`000?n]^N;o[KWR00[o[KWR00?o0000ojjjh_n^^^800_n^^^82o`0000;o/;_R00?o
0000ok2kh_n`^n800_n`^n800ol0003o/KcRok6lhP0<ok6lhP03o`000?nb_N;o/[gR00[o/[gR00?o
0000ok>ohonc_n<00_nc_n<2o`0000So]/3R00?o0000ooooooooool0KOooool002Gooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo00?o0000ojZlionZ_>L02onZ
_>L00ol0003oZ[_VojZkiP08ojZkiP?o00002_nV^NH00ol0003oYkSUojNhi@0;ojNhi@03o`000?nW
]nCoYkOT00WoYkOT00?o0000ojRfhonX]^<02onX]^<00ol0003oZKKSojVfh`03o`0000KoZ;OS00?o
0000ojZgh_nZ]n802_nZ]n800ol0003o[;SRojbhhP0;ojbhhP03o`000?n]^N;o[KWR00[o[KWR00Co
0000ojjjh_l0003o00001?n`^n800ol0003o/;_Rok2khP03ok2khP03o`000?na_>;o/KcR00_o/KcR
00?o0000ok:mh_nb_N802onb_N801?l0003o/koSo`000?l0000:okK0hP;o0000K_ooool002Gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ojZlionZ
_>L02onZ_>L00ol0003oZ[_VojZkiP04ojZkiP?o000000?oY[[Wo`000?nV^NH02onV^NH00ol0003o
YkSUojNhi@0;ojNhi@03o`000?nW]nCoYkOT00WoYkOT00?o0000ojRfhonX]^<02_nX]^<3o`0000[o
Z;OS00?o0000ojZgh_nZ]n802_nZ]n800ol0003o[;SRojbhhP0:ojbhhP03o`000?n]^N;o[KWR00[o
[KWR0_l00006ok2khP03o`000?n`^n;o/;_R00Co/;_R00?o0000ok6lh_na_>802ona_>800ol0003o
/[gRok:mhP0:ok:mhP;o00003Onf`>800ol0003oooooooooo`1/ooooo`009Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01_ooool00ol0003oZ[cWojZli`0;ojZli`03
o`000?nZ^nKoZ[_V00?o00001OnV^^L00ol0003oY[WVojJiiP0:ojJiiP03o`000?nW^>GoYkSU00[o
YkSU00?o0000ojNgi?nW]n@02OnW]n@00ol0003oZ;KSojRfh`07ojRfh`?o000000?oYkKTo`000?nX
]n<02onX]n<00ol0003oZ[ORojZghP0:ojZghP03o`000?n/^>;o[;SR00[o[;SR00?o0000ojfih_n]
^N801_n]^N83o`000003ojjjh_l0003o/;_R00Go/;_R00?o0000ok2kh_n`^n801?n`^n800ol0003o
/KcRok6lhP0<ok6lhP03o`000?nb_N;o/[gR00Oo/[gR0_l000000one_n;o0000okK0hP0=okK0hP03
o`000?oooooooooo06_ooooo000`ooooo`03o`000?oooooooooo00Oooooo00?o0000ojZlionZ_>L0
2_nZ_>L3o`0000WoY[[W00?o0000ojJii_nV^NH02_nV^NH00ol0003oYkSUojNhi@0:ojNhi@03o`00
0?nW]nCoYkOT00WoYkOT00?o0000ojRfhonX]^<00onX]^<3o`0000GoYkKT00?o0000ojRghonX]n<0
2OnX]n<00ol0003oZ[ORojZghP0;ojZghP03o`000?n/^>;o[;SR00[o[;SR00?o0000ojfih_n]^N80
0on]^N82o`0000Go[[[R00?o0000ok2kh_n`^n800on`^n800ol0003o/;_Rok2khP05ok2khP03o`00
0?na_>;o/KcR00_o/KcR00?o0000ok:mh_nb_N801Onb_N82o`0000Co]KoR00?o0000okK0h_nf`>80
3?nf`>800ol0003oooooooooo`1Zooooo`00<?ooool00ol0003oooooooooo`08ooooo`03o`000?nZ
_>OoZ[cW00KoZ[cW0ol000000onV^nSo0000ojJji`0:ojJji`03o`000?nV^NKoY[WV00[oY[WV00?o
0000ojNhiOnW^>D02_nW^>D00ol0003oYkOTojNgi009ojNgi003o`000?nX]^?o000000;o00002OnW
]^@00ol0003oZ;OSojRgh`09ojRgh`03o`000?nZ]n;oZ[OR00_oZ[OR00?o0000ojbhh_n/^>802_n/
^>800ol0003o[KWRo`000002o`0000So[[[R00?o0000ok2kh_n`^n800_n`^n800ol0003o/;_Rok2k
hP06ok2khP03o`000?na_>;o/KcR00_o/KcR00?o0000ok:mh_nb_N800_nb_N82o`0000Oo]KoR00?o
0000okK0h_nf`>802onf`>800ol0003oooooooooo`1Zooooo`00;oooool2o`0000_ooooo00?o0000
ojZlionZ_>L00onZ_>L2o`0000GoY[_X00?o0000ojJjionV^^L02OnV^^L00ol0003oY[WVojJiiP0:
ojJiiP03o`000?nW^>GoYkSU00[oYkSU00?o0000ojNgi?nW]n@02?nW]n@2o`0000coYkKT00?o0000
ojRghonX]n<02_nX]n<00ol0003oZ[ORojZghP0:ojZghP03o`000?n/^>;o[;SR00[o[;SR0_l0000<
ojjjhP05o`000?n`^n;o/;_Rok2kh_l000002On`^n800ol0003o/KcRok6lhP0;ok6lhP04o`000?nb
_N;o0000o`0000[o]KoR00?o0000okK0h_nf`>802onf`>800ol0003oooooooooo`1Yooooo`00<?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?nZ_>Oo000000;o00002?nV^nP00ol0003oY[[WojJj
i`09ojJji`03o`000?nV^NKoY[WV00[oY[WV00?o0000ojNhiOnW^>D02_nW^>D00ol0003oYkOTojNg
i004ojNgi0?o000000?oYKOUo`000?nW]^@03?nW]^@00ol0003oZ;OSojRgh`0:ojRgh`03o`000?nZ
]n;oZ[OR00[oZ[OR00?o0000ojbhh_n/^>801_n/^>83o`000003ojfih_l0003o[[[R00_o[[[R00Go
0000ok2kh_n`^n;o/;_Ro`00000:ok2khP03o`000?na_>;o/KcR00[o/KcR0_l0000=okFohP03o`00
0?nf`>;o]/3R00_o]/3R00?o0000ooooooooool0J?ooool002oooooo00?o0000ooooooooool03?oo
ool00ol0003oY[_XojJkj00:ojJkj003o`000?nV^^OoY[[W00WoY[[W00?o0000ojJii_nV^NH02_nV
^NH00ol0003oYkSUojNhi@0:ojNhi@03o`000?nW]nCoYkOT00?o00001OnU]nD00ol0003oYkKTojNf
i00;ojNfi003o`000?nX]n?oZ;OS00WoZ;OS00?o0000ojZgh_nZ]n802onZ]n800ol0003o[;SRojbh
hP03ojbhhP;o00001On]^N800ol0003o[[[RojjjhP0:ojjjhP04o`000?n`^n;o/;_Ro`0000[o/;_R
00?o0000ok6lh_na_>802?na_>82o`000003ok>nhOl0003o]KoR00co]KoR00?o0000okK0h_nf`>80
3?nf`>800ol0003oooooooooo`1Wooooo`00;oooool00ol0003oooooooooo`0=ooooo`03o`000?nV
^nSoY[_X00[oY[_X00?o0000ojJjionV^^L02OnV^^L00ol0003oY[WVojJiiP0:ojJiiP03o`000?nW
^>GoYkSU00SoYkSU1?l00009ojFgi@03o`000?nW]^CoYkKT00[oYkKT00?o0000ojRghonX]n<02_nX
]n<00ol0003oZ[ORojZghP0;ojZghP03o`000?n/^>;o000000;o00002?n]^N800ol0003o[[[Rojjj
hP0:ojjjhP03o`000?n`^n;o000000_o/;_R00?o0000ok6lh_na_>801Ona_>82o`0000Co/kkQ00?o
0000okFoh_ne_n802one_n800ol0003o]/3RokK0hP0;okK0hP03o`000?oooooooooo06Oooooo000_
ooooo`03o`000?oooooooooo00kooooo00?o0000ojJkj?nV^nP02OnV^nP00ol0003oY[[WojJji`09
ojJji`03o`000?nV^NKoY[WV00_oY[WV00?o0000ojNhiOnW^>D01?nW^>D3o`0000;oY;OV00?o0000
ojFgiOnU]nD02OnU]nD00ol0003oYkKTojNfi00:ojNfi003o`000?nX]n?oZ;OS00[oZ;OS00?o0000
ojZgh_nZ]n802_nZ]n82o`0000co[KWR00?o0000ojjjh_n^^^802_n^^^82o`0000co/;_R00?o0000
ok6lh_na_>800_na_>82o`0000Oo/kkQ00?o0000okFoh_ne_n802one_n800ol0003o]/3RokK0hP0;
okK0hP03o`000?oooooooooo06Kooooo000_ooooo`03o`000?oooooooooo00oooooo00?o0000ojJk
j?nV^nP02OnV^nP00ol0003oY[[WojJji`09ojJji`03o`000?nV^NKoY[WV00_oY[WV00?o0000ojNh
iOnW^>D00ol00006ojBgiP03o`000?nU]nGoYKOU00WoYKOU00?o0000ojNfi?nW]^@02_nW]^@00ol0
003oZ;OSojRgh`09ojRgh`03o`000?nZ]n;oZ[OR00OoZ[OR0ol000000on[^>?o0000ojfihP0;ojfi
hP03o`000?n^^^;o[[[R00[o[[[R0_l0000=ok2khP04o`000?na_>;o0000o`0000[o/kkQ00?o0000
okFoh_ne_n802one_n800ol0003o]/3RokK0hP0:okK0hP;o0000Ioooool002kooooo0ol0000Aoooo
o`03o`000?nV^nSoY[_X00WoY[_X00?o0000ojJjionV^^L02OnV^^L00ol0003oY[WVojJiiP0:ojJi
iP?o00002_nT]nH00ol0003oYKOUojFgi@09ojFgi@03o`000?nW]^CoYkKT00[oYkKT00?o0000ojRg
honX]n<02OnX]n<00ol0003oZ[ORojZghP03ojZghP?o00001On[^><00ol0003o[KWRojfihP0:ojfi
hP03o`000?n^^^;o[[[R00[o[[[R00?o0000ok2kh_n`^n802on`^n82o`0000go/kkQ00?o0000okFo
h_ne_n802_ne_n800ol0003o]/3RokK0hP08okK0hP;o000000?o]l7Qo`000?l00000I_ooool002oo
oooo00?o0000ooooooooool04Oooool00ol0003oY[_XojJkj009ojJkj003o`000?nV^^OoY[[W00Wo
Y[[W00?o0000ojJii_nV^NH01_nV^NH3o`000003oj>hiol0003oY;OV00_oY;OV00?o0000ojFgiOnU
]nD02OnU]nD00ol0003oYkKTojNfi009ojNfi003o`000?nX]n?oZ;OS00[oZ;OS00?o0000ojZgh_l0
00000_l00009oj^hh`03o`000?n]^N;o[KWR00[o[KWR00?o0000ojjjh_n^^^802On^^^82o`0000[o
/;_R0_l000000onb_N;o0000ok>nh@0<ok>nh@03o`000?ne_n;o]KoR00_o]KoR00?o0000okK0h_nf
`>801Onf`>82o`0000Co]l7Q00?o0000ooooooooool0I?ooool002oooooo00?o0000ooooooooool0
4_ooool00ol0003oY[_XojJkj009ojJkj003o`000?nV^^OoY[[W00WoY[[W00?o0000ojJii_nV^NH0
0onV^NH2o`0000GoXkSW00?o0000ojBgi_nT]nH02_nT]nH00ol0003oYKOUojFgi@09ojFgi@03o`00
0?nW]^CoYkKT00WoYkKT00?o0000ojRghonX]n<02OnX]n<2o`0000goZkSS00?o0000ojfih_n]^N80
2_n]^N800ol0003o[[[RojjjhP08ojjjhP;o00001on`^n83o`0000Co/[gR00?o0000ok>nhOnc_^40
2onc_^400ol0003o]KoRokFohP0;okFohP03o`000?nf`>;o]/3R00;o]/3R0_l00007okO1h@03o`00
0?oooooooooo06?ooooo000_ooooo`03o`000?oooooooooo01?ooooo00?o0000ojJkj?nV^nP02?nV
^nP00ol0003oY[[WojJji`0:ojJji`03o`000?nV^NKo000000;o00002?nS^>L00ol0003oY;OVojBg
iP09ojBgiP03o`000?nU]nGoYKOU00WoYKOU00?o0000ojNfi?nW]^@02_nW]^@00ol0003oZ;OSojRg
h`05ojRgh`?o000000?oZ;OTo`000?n[^><03?n[^><00ol0003o[KWRojfihP0:ojfihP03o`000?n^
^^;o[[[R00So[[[R00?o0000ojjjh_l000001?n`^n82o`0000So/[gR00?o0000ok>nhOnc_^402onc
_^400ol0003o]KoRokFohP0;okFohP04o`000?nf`>;o0000o`0000[o]l7Q00?o0000ooooooooool0
H_ooool002oooooo00?o0000ooooooooool04oooool2o`0000[oY[_X00?o0000ojJjionV^^L02?nV
^^L3o`0000coXkSW00?o0000ojBgi_nT]nH02OnT]nH00ol0003oYKOUojFgi@09ojFgi@03o`000?nW
]^CoYkKT00WoYkKT00?o0000ojRghonX]n<00onX]n<2o`0000GoZ;OT00?o0000oj^hhon[^><02on[
^><00ol0003o[KWRojfihP0:ojfihP03o`000?n^^^;o[[[R00Oo[[[R00Go0000ojjjh_n^^^;o0000
ok2khP02o`0000_o/[gR00?o0000ok>nhOnc_^402onc_^400ol0003o]KoRokFohP0:okFohP;o0000
3?ng`N42o`0006?ooooo000^ooooo`03o`000?oooooooooo01Gooooo0_l0000:ojJkj003o`000?nV
^^OoY[[W00CoY[[W0ol00002oj:ij@03o`000?nS^>OoXkSW00_oXkSW00?o0000ojBgi_nT]nH02OnT
]nH00ol0003oYKOUojFgi@09ojFgi@03o`000?nW]^CoYkKT00WoYkKT00?o0000ojRghol000000_l0
0008ojRgi003o`000?n[^>?oZkSS00_oZkSS00?o0000ojfih_n]^N802_n]^N800ol0003o[[[Rojjj
hP06ojjjhP03o`000?n^^^;o[[[R00;o00003Onb_N800ol0003o/kkQok>nh@0;ok>nh@03o`000?ne
_n;o]KoR00So]KoR0_l000000onf`>7o0000okO1h@0<okO1h@03o`000?oooooooooo067ooooo000^
ooooo`?o00005_ooool2o`0000[oY[_X00?o0000ojJjionV^^L00ol00006oj:ij@03o`000?nS^>Oo
XkSW00[oXkSW00?o0000ojBgi_nT]nH02_nT]nH00ol0003oYKOUojFgi@09ojFgi@03o`000?nW]^Co
YkKT00SoYkKT0_l0000<ojRgi003o`000?n[^>?oZkSS00_oZkSS00?o0000ojfih_n]^N802On]^N80
0ol0003o[[[RojjjhP06ojjjhP?o000000?o/;_Ro`000?nb_N803Onb_N800ol0003o/kkQok>nh@0;
ok>nh@03o`000?ne_n;o]KoR00Go]KoR0_l00004okK0h@03o`000?ng`N7o]l7Q00_o]l7Q00?o0000
ooooooooool0H?ooool002kooooo00?o0000ooooooooool05oooool2o`0000SoY[_X1?l0000:oj:i
j@03o`000?nS^>OoXkSW00[oXkSW00?o0000ojBgi_nT]nH02_nT]nH00ol0003oYKOUojFgi@09ojFg
i@03o`000?nW]^CoYkKT00CoYkKT0ol000000onV]nGo0000ojRgi00<ojRgi003o`000?n[^>?oZkSS
00[oZkSS00?o0000ojfih_n]^N802_n]^N800ol0003o[[[RojjjhP03ojjjhP?o00001?n`^n800ol0
003o/[gRok:mhP0<ok:mhP03o`000?nc_^7o/kkQ00_o/kkQ00?o0000okFoh_ne_n800_ne_n82o`00
00Oo]/3Q00?o0000okO1hOng`N402ong`N400ol0003oooooooooo`1Oooooo`004_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001oooool00ol0003oooooooooo`0Hoooo
o`;o00000_nV^nP5o`0000?oX[[Z00?o0000oj:ijOnR^NT02OnR^NT00ol0003oXkSWoj>hi`0:oj>h
i`03o`000?nT]nKoY;OV00WoY;OV00?o0000ojFgiOnU]nD02_nU]nD00ol0003oYkKTojNfi003o`00
00GoY[OU00?o0000ojRgi?nX]n@02_nX]n@00ol0003oZkSSoj^hh`0;oj^hh`03o`000?n]^N;o[KWR
00[o[KWR00?o0000ojjjh_l000000_l00002ok2khP03o`000?n`^n;o/;_R00?o/;_R00?o0000ok:m
h_nb_N802onb_N800ol0003o/kkQok>nh@0<ok>nh@04o`000?ne_n;o0000o`0000[o]/3Q00?o0000
okO1hOng`N402ong`N400ol0003oooooooooo`1Nooooo`004_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00ol0003ooooooooo
o`0Iooooo`?o00002OnR^^X00ol0003oX[WYoj:ij@09oj:ij@03o`000?nS^>OoXkSW00[oXkSW00?o
0000ojBgi_nT]nH02OnT]nH00ol0003oYKOUojFgi@08ojFgi@Co00002OnV]nD00ol0003oZ;OTojRg
i00:ojRgi003o`000?n[^>?oZkSS00_oZkSS00?o0000ojfih_n]^N802On]^N82o`0000Go/;_R00?o
0000ok2kh_n`^n801?n`^n800ol0003o/[gRok:mhP0;ok:mhP03o`000?nc_^7o/kkQ00_o/kkQ0_l0
000<okK0h@03o`000?ng`N7o]l7Q00_o]l7Q00?o0000ooooooooool0G_ooool001;ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Sooooo00?o0000ooooooooool06_oo
ool00ol0003oX[[Zoj:jjP09oj:jjP03o`000?nR^NWoX[WY00WoX[WY00?o0000oj>hionS^>L02_nS
^>L00ol0003oY;OVojBgiP09ojBgiP03o`000?nU]nGoYKOU00CoYKOU0ol00002ojBgiP03o`000?nV
]nGoY[OU00WoY[OU00?o0000ojRgi?nX]n@02_nX]n@00ol0003oZkSSoj^hh`0:oj^hh`03o`000?n]
^N;o[KWR00Ko[KWR0ol000000on^^^?o0000ok2khP04ok2khP03o`000?n`^n;o/;_R00Go/;_R00?o
0000ok:mh_nb_N802onb_N800ol0003o/kkQok>nh@08ok>nh@;o000000?o]KoQo`000?nf`>403?nf
`>400ol0003o]l7QokO1h@0;okO1h@03o`000?oooooooooo05gooooo000Booooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo01_ooooo00?o
0000oj:jj_nR^^X02OnR^^X00ol0003oX[WYoj:ij@09oj:ij@03o`000?nS^>OoXkSW00WoXkSW00?o
0000ojBgi_nT]nH02_nT]nH00ol0003oYKOUojFgi@03o`0000KoY;OV00?o0000ojJgiOnV]nD02OnV
]nD00ol0003oZ;OTojRgi00:ojRgi003o`000?n[^>?oZkSS00[oZkSS00?o0000ojfih_n]^N800on]
^N82o`0000Go[[[S00?o0000ok2kh_n`^n800_n`^n800ol0003o/;_Rok2khP05ok2khP03o`000?nb
_N;o/[gR00co/[gR00?o0000ok>nhOnc_^401?nc_^43o`0000Co]KoQ00?o0000okK0hOnf`>402onf
`>400ol0003o]l7QokO1h@0;okO1h@03o`000?oooooooooo05cooooo000Booooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`06ooooo`03o`000?oooooooooo01cooooo00?o
0000oj:jj_nR^^X02OnR^^X00ol0003oX[WYoj:ij@08oj:ij@03o`000?nS^>OoXkSW00[oXkSW00?o
0000ojBgi_nT]nH02?nT]nH4o`0000[oY;OV00?o0000ojJgiOnV]nD02OnV]nD00ol0003oZ;OTojRg
i00:ojRgi003o`000?n[^>?oZkSS00[oZkSS00?o0000ojfih_l000000_l00008ojjjh`05o`000?n`
^n;o/;_Rok2kh_l000002?n`^n800ol0003o/[gRok:mhP0;ok:mhP03o`000?nc_^7o/kkQ00;o/kkQ
0_l00008okFoh@03o`000?nf`>7o]/3Q00_o]/3Q00?o0000okO1hOng`N402_ng`N42o`0005gooooo
000Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`;o0000
7oooool00ol0003oX[[Zoj:jjP09oj:jjP03o`000?nR^NWoX[WY00SoX[WY00?o0000oj>hionS^>L0
2_nS^>L00ol0003oY;OVojBgiP04ojBgiP?o00000_nR]nP00ol0003oY;OVojBgiP0:ojBgiP03o`00
0?nV]nGoY[OU00WoY[OU00?o0000ojRgi?nX]n@02OnX]n@00ol0003oZkSSoj^hh`0:oj^hh`;o0000
3?n^^^<01?l0003o/;_Rok2kh_l00009ok2khP03o`000?nb_N;o/[gR00_o/[gR00Co0000ok>nhOl0
003o00002one_n400ol0003o]/3QokK0h@0;okK0h@03o`000?ng`N7o]l7Q00Oo]l7Q0_l000000onh
`N7o0000ooooo`1Looooo`004_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo01oooooo00?o0000oj:jj_nR^^X02OnR^^X0
0ol0003oX[WYoj:ij@08oj:ij@03o`000?nS^>OoXkSW00[oXkSW00?o0000ojBgi_nT]nH00ol00006
oj:gj003o`000?nT]nKoY;OV00[oY;OV00?o0000ojJgiOnV]nD02?nV]nD00ol0003oZ;OTojRgi00:
ojRgi003o`000?n[^>?oZkSS00KoZkSS0ol000000on[^NCo0000ojjjh`0<ojjjh`03o`000?n`^n;o
000000[o/;_R00?o0000ok:mh_nb_N802_nb_N82o`0000go]KoQ00?o0000okK0hOnf`>402onf`>40
0ol0003o]l7QokO1h@05okO1h@;o00001?nh`N400ol0003oooooooooo`1Jooooo`004_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oo
oooooooo023ooooo00?o0000oj:jj_nR^^X02OnR^^X00ol0003oX[WYoj:ij@08oj:ij@03o`000?nS
^>OoXkSW00SoXkSW1?l0000:oj:gj003o`000?nT]nKoY;OV00WoY;OV00?o0000ojJgiOnV]nD02OnV
]nD00ol0003oZ;OTojRgi00:ojRgi003o`000?n[^>?oZkSS00?oZkSS0_l00005oj^ii003o`000?n^
^^?o[[[S00[o[[[S00?o0000ok2kh_l000002_n`^n800ol0003o/[gRok:mhP08ok:mhP;o000000?o
/kkRo`000?ne_n403One_n400ol0003o]/3QokK0h@0;okK0h@03o`000?ng`N7o]l7Q00;o]l7Q0_l0
0007okS1h@03o`000?oooooooooo05Wooooo000]ooooo`03o`000?oooooooooo027ooooo00?o0000
oj:jj_nR^^X02OnR^^X00ol0003oX[WYoj:ij@08oj:ij@03o`000?nS^>OoXkSW00CoXkSW0ol00002
oj2gj@03o`000?nR]nSoX[OX00[oX[OX00?o0000ojBgi_nT]nH02OnT]nH00ol0003oY[OUojJgi@09
ojJgi@03o`000?nX]nCoZ;OT00[oZ;OT00?o0000oj^hhol000000_l00008oj^ii003o`000?n^^^?o
[[[S00[o[[[S0_l0000;ok2khP03o`000?nb_N;o/[gR00Go/[gR0_l00004ok>nhP03o`000?ne_n7o
]KoQ00co]KoQ00?o0000okK0hOnf`>402onf`>401?l0003o]l7Qo`000?l0000:okS1h@03o`000?oo
oooooooo05Sooooo000]ooooo`03o`000?oooooooooo027ooooo00?o0000oj:jj_nR^^X02_nR^^X0
0ol0003oX[WYoj:ij@08oj:ij@03o`000?nS^>OoXkSW00?o00001_nP]nT00ol0003oX[OXoj:gj00:
oj:gj003o`000?nT]nKoY;OV00WoY;OV00?o0000ojJgiOnV]nD02OnV]nD00ol0003oZ;OTojRgi008
ojRgi0?o00003?n[^N@00ol0003o[[[Sojjjh`0:ojjjh`03o`000?n`^n;o/;_R00[o/;_R00?o0000
ok:mh_nb_N800_nb_N82o`0000Oo/kkR00?o0000okFohOne_n402one_n400ol0003o]/3QokK0h@0;
okK0h@;o00003?nh`N400ol0003oooooooooo`1Hooooo`00;Oooool00ol0003oooooooooo`0Roooo
o`03o`000?nR^^[oX[[Z00[oX[[Z00?o0000oj:ijOnR^NT01_nR^NT4o`0000[oX;OY00?o0000oj:g
j?nR]nP02_nR]nP00ol0003oY;OVojBgiP09ojBgiP03o`000?nV]nGoY[OU00WoY[OU00?o0000ojRg
i?nX]n@01?nX]n@3o`0000;oZ;WU00?o0000oj^ii?n[^N@02on[^N@00ol0003o[[[Sojjjh`09ojjj
h`;o00003?n`^n801?l0003o/[gRo`000?l0000:ok>nhP03o`000?ne_n7o]KoQ00_o]KoQ00?o0000
okK0hOnf`>402?nf`>42o`000003okO1hOl0003o^<7Q00co^<7Q00?o0000ooooooooool0Eoooool0
02cooooo0ol0000Tooooo`03o`000?nR^^[oX[[Z00[oX[[Z00?o0000oj:ijOnR^NT01Ol00002oinh
jP03o`000?nP]nWoX;OY00[oX;OY00?o0000oj:gj?nR]nP02_nR]nP00ol0003oY;OVojBgiP08ojBg
iP03o`000?nV]nGoY[OU00[oY[OU00?o0000ojRgi?nX]n@00ol00006ojRii@03o`000?n[^NCoZkWT
00[oZkWT00?o0000ojjjhon^^^<02On^^^<2o`0000co/;_R0_l0000=ok>nhP03o`000?ne_n7o]KoQ
00_o]KoQ00?o0000okK0hOnf`>401_nf`>400ol0003o]l7QokO1h@02okO1h@03o`000?nh`N7o^<7Q
00_o^<7Q00?o0000ooooooooool0E_ooool002gooooo00?o0000ooooooooool09?ooool00ol0003o
X[[Zoj:jjP08oj:jjPCo00002?nO^>X00ol0003oX;OYoj2gj@0:oj2gj@03o`000?nR]nSoX[OX00Wo
X[OX00?o0000ojBgi_nT]nH02OnT]nH00ol0003oY[OUojJgi@08ojJgi@Co00002_nX^ND00ol0003o
ZkWToj^ii00:oj^ii003o`000?n^^^?o[[[S00So[[[S00?o0000ojjjhol000002?n`^n83o`000003
ok6mhol0003o/kkR00co/kkR00?o0000okFohOne_n403?ne_n400ol0003o]/3QokK0h@03okK0h@;o
00001_ng`N400ol0003o^<7QokS1h@0;okS1h@03o`000?oooooooooo05Gooooo000]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000oj:jj_nR^^X01?nR^^X3o`0000;oW[W[00?o0000oinhj_nO^>X0
2?nO^>X00ol0003oX;OYoj2gj@0:oj2gj@03o`000?nR]nSoX[OX00WoX[OX00?o0000ojBgi_nT]nH0
2OnT]nH00ol0003oY[OUojJgi@04ojJgi@?o00000_nU^>H00ol0003oZ;WUojRii@0:ojRii@03o`00
0?n[^NCoZkWT00[oZkWT00?o0000ojjjhon^^^<01on^^^<01?l0003o[[[Sojjjhol00005ok2khP;o
00001Ona_N<00ol0003o/kkRok>nhP0;ok>nhP03o`000?ne_n7o]KoQ00_o]KoQ00Co0000okK0hOnf
`>7o]/3Q0_l00009okO1h@03o`000?nh`N7o^<7Q00[o^<7Q0_l0001Fooooo`00;Oooool00ol0003o
ooooooooo`0Vooooo`03o`000?nR^^[oX[[Z00?o00001_nN^N/00ol0003oWkSZoinhjP08oinhjP03
o`000?nP]nWoX;OY00[oX;OY00?o0000oj:gj?nR]nP02OnR]nP00ol0003oY;OVojBgiP09ojBgiP03
o`000?nV]nGoY[OU00?o00001_nU^>H00ol0003oZ;WUojRii@0:ojRii@03o`000?n[^NCoZkWT00[o
ZkWT00?o0000ojjjhon^^^<01_n^^^<01_l0003o[[[Sojjjhon^^^?o0000ok2khP?o00002?na_N<0
0ol0003o/kkRok>nhP0;ok>nhP03o`000?ne_n7o]KoQ00_o]KoQ00?o0000okK0hOl000002ong`N40
0ol0003o^<7QokS1h@0;okS1h@03o`000?oooooooooo05Cooooo000/ooooo`03o`000?oooooooooo
02Sooooo0_l0000:oijij`03o`000?nO^>[oWkSZ00SoWkSZ00?o0000oj2gjOnP]nT02OnP]nT00ol0
003oX[OXoj:gj00:oj:gj003o`000?nT]nKoY;OV00SoY;OV0ol0000:ojFhiP03o`000?nX^NGoZ;WU
00WoZ;WU00?o0000oj^ii?n[^N@02_n[^N@00ol0003o[[[Sojjjh`06ojjjh`04o`000?n^^^?o[[[S
ojjjh`;o00003?na_N<00ol0003o/kkRok>nhP0;ok>nhP03o`000?ne_n7o]KoQ00[o]KoQ0_l0000=
okO1h@03o`000?nh`N7o^<7Q00_o^<7Q00?o0000ooooooooool0Doooool002cooooo00?o0000oooo
ooooool0:Oooool00ol0003oW[W[oijij`09oijij`03o`000?nO^>[oWkSZ00SoWkSZ00?o0000oj2g
jOnP]nT02OnP]nT00ol0003oX[OXoj:gj00:oj:gj003o`000?nT]nKoY;OV00CoY;OV0ol000000onR
]nSo0000ojFhiP0;ojFhiP03o`000?nX^NGoZ;WU00WoZ;WU00?o0000oj^ii?n[^N@02_n[^N@00ol0
003o[[[Sojjjh`05ojjjh`Co000000?o[[cTo`000?na_N<03?na_N<00ol0003o/kkRok>nhP0:ok>n
hP03o`000?ne_n7o]KoQ00So]KoQ0_l000000onf`>;o0000okO1h@0=okO1h@03o`000?nh`N7o^<7Q
00_o^<7Q00?o0000ooooooooool0D_ooool002cooooo0_l0000[ooooo`03o`000?nN^N_oW[W[00Wo
W[W[00?o0000oinhj_nO^>X02?nO^>X00ol0003oX;OYoj2gj@09oj2gj@03o`000?nR]nSoX[OX00[o
X[OX00?o0000ojBgi_nT]nH00ol00005oj:gj003o`000?nU^>KoYKSV00[oYKSV00?o0000ojRiiOnX
^ND02OnX^ND00ol0003oZkWToj^ii00:oj^ii003o`000?n^^^?o[[[S00?o[[[S0_l00005ojjli003
o`000?na_N?o/KgS00_o/KgS00?o0000ok>nh_nc_^802_nc_^800ol0003o]KoQokFoh@05okFoh@;o
00001?nf`>800ol0003o]l7QokO1h@0;okO1h@03o`000?nh`N7o^<7Q00_o^<7Q0_l0001Cooooo`00
;?ooool00ol0003oooooooooo`0[ooooo`03o`000?nN^N_oW[W[00WoW[W[00?o0000oinhj_nO^>X0
2?nO^>X00ol0003oX;OYoj2gj@09oj2gj@03o`000?nR]nSoX[OX00SoX[OX1?l00009oj:gj003o`00
0?nU^>KoYKSV00WoYKSV00?o0000ojRiiOnX^ND02_nX^ND00ol0003oZkWToj^ii00:oj^ii003o`00
0?n^^^?o000000;o000000?o[[cTo`000?n^_>@01On^_>@00ol0003o/KgSok6mh`0;ok6mh`03o`00
0?nc_^;o/kkR00[o/kkR00?o0000okFohOne_n400_ne_n42o`0000Oo]/3R00?o0000okO1hOng`N40
2ong`N400ol0003o^<7QokS1h@08okS1h@;o000000?o^L;Qo`000?ooool0D_ooool002cooooo00?o
0000ooooooooool0;?ooool00ol0003oW[W[oijij`09oijij`03o`000?nO^>[oWkSZ00SoWkSZ00?o
0000oj2gjOnP]nT02OnP]nT00ol0003oX[OXoj:gj004oj:gj0?o00000_nO]nT00ol0003oX[OXoj:g
j009oj:gj003o`000?nU^>KoYKSV00WoYKSV00?o0000ojRiiOnX^ND02OnX^ND00ol0003oZkWToj^i
i00:oj^ii0;o00001?n^_>@00ol0003o[[cTojjli005ojjli003o`000?na_N?o/KgS00[o/KgS00?o
0000ok>nh_nc_^802onc_^801?l0003o]KoQo`000?l0000:okK0hP03o`000?ng`N7o]l7Q00_o]l7Q
00?o0000okS1hOnh`N401_nh`N400ol0003o^L;QokW2h@02okW2h@03o`000?oooooooooo053ooooo
000/ooooo`03o`000?oooooooooo02gooooo00?o0000oijijonN^N/02OnN^N/00ol0003oWkSZoinh
jP08oinhjP03o`000?nP]nWoX;OY00WoX;OY00?o0000oj:gj?nR]nP00ol00006oingj@03o`000?nR
]nSoX[OX00WoX[OX00?o0000ojFhi_nU^>H02OnU^>H00ol0003oZ;WUojRii@09ojRii@03o`000?n[
^NCoZkWT00KoZkWT0ol000000on[^nGo0000ojjli003ojjli003o`000?n^_>Co[[cT00Ko[[cT00?o
0000ok6mhona_N<02_na_N<00ol0003o/kkRok>nhP0:ok>nhP;o00003?nf`>800ol0003o]l7QokO1
h@0<okO1h@03o`000?nh`N7o^<7Q00?o^<7Q0_l00006okW2h@03o`000?oooooooooo04oooooo000/
ooooo`03o`000?oooooooooo02kooooo00?o0000oijijonN^N/02OnN^N/00ol0003oWkSZoinhjP08
oinhjP03o`000?nP]nWoX;OY00OoX;OY1?l0000:oingj@03o`000?nR]nSoX[OX00WoX[OX00?o0000
ojFhi_nU^>H02OnU^>H00ol0003oZ;WUojRii@09ojRii@03o`000?n[^NCoZkWT00?oZkWT0_l00005
oj^ki@05o`000?n^_>Co[[cTojjli?l000002?n^_>@00ol0003o/KgSok6mh`0;ok6mh`03o`000?nc
_^;o/kkR00Ko/kkR0ol000000ond`>?o0000okK0hP0<okK0hP03o`000?ng`N7o]l7Q00_o]l7Q00Co
0000okS1hOnh`N7o^<7Q0_l00008okW2h@;o0000D?ooool002cooooo00?o0000ooooooooool0;ooo
ool00ol0003oW[W[oijij`09oijij`03o`000?nO^>[oWkSZ00SoWkSZ00Co0000oj2gjOnP]nWoX;OY
1Ol00002oifgjP03o`000?nO]nWoWkOY00[oWkOY00?o0000oj:gj?nR]nP02OnR]nP00ol0003oYKSV
ojFhiP08ojFhiP03o`000?nX^NGoZ;WU00[oZ;WU00?o0000oj^ii?l000000_l00008oj^ki@04o`00
0?n^_>Co[[cTo`0000Wo[[cT00?o0000ok6mhona_N<02ona_N<00ol0003o/kkRok>nhP03ok>nhP;o
00001Ond`><00ol0003o]/3RokK0hP0;okK0hP03o`000?ng`N7o]l7Q00_o]l7Q00?o0000okS1hOl0
00002oni`^400ol0003oooooooooo`1>ooooo`00;?ooool2o`00037ooooo00?o0000oijijonN^N/0
2OnN^N/00ol0003oWkSZoinhjP06oinhjPGo00002?nM]nX00ol0003oWkOYoingj@0:oingj@03o`00
0?nR]nSoX[OX00SoX[OX00?o0000ojFhi_nU^>H02OnU^>H00ol0003oZ;WUojRii@08ojRii@?o0000
3?n[^nD00ol0003o[[cTo`00000:ojjli003o`000?na_N?o/KgS00_o/KgS00?o0000ok>nh_l00000
0_l00008okC0h`03o`000?nf`>;o]/3R00_o]/3R00?o0000okO1hOng`N402_ng`N42o`0000go^L;Q
00?o0000ooooooooool0COooool002_ooooo00?o0000ooooooooool0<_ooool00ol0003oW[W[oiji
j`09oijij`03o`000?nO^>[oWkSZ00Go00000_nL]n/00ol0003oWKOZoifgjP09oifgjP03o`000?nO
]nWoWkOY00WoWkOY00?o0000oj:gj?nR]nP02OnR]nP00ol0003oYKSVojFhiP09ojFhiP03o`000?nX
^NGoZ;WU00CoZ;WU0ol00002ojRjiP03o`000?n[^nGoZk_U00_oZk_U0_l0000;ojjli003o`000?na
_N?o/KgS00[o/KgS0_l0000<okC0h`03o`000?nf`>;o]/3R00_o]/3R00?o0000okO1hOng`N401ong
`N42o`000003okS2h_l0003o^L;Q00go^L;Q00?o0000ooooooooool0C?ooool002_ooooo00?o0000
ooooooooool0<oooool00ol0003oW[W[oijij`08oijij`?o00002?nL]n/00ol0003oWKOZoifgjP09
oifgjP03o`000?nO]nWoWkOY00WoWkOY00?o0000oj:gj?nR]nP02OnR]nP00ol0003oYKSVojFhiP09
ojFhiP03o`000?nX^NGoZ;WU00?o00001_nX^^H00ol0003oZk_Uoj^ki@0:oj^ki@;o00002on^_>@0
0ol0003o/KgSok6mh`08ok6mh`;o000000?o/[oTo`000?nd`><03?nd`><00ol0003o]/3RokK0hP0:
okK0hP03o`000?ng`N7o]l7Q00Go]l7Q0_l00004okS2hP03o`000?ni`^7o^L;Q00_o^L;Q0_l0001=
ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool01?ooool00ol0003oooooooooo`0dooooo`03o`000?nN^N_oW[W[00CoW[W[0ol00000
0onK^>co0000oibgj`09oibgj`03o`000?nM]n[oWKOZ00WoWKOZ00?o0000oingjOnO]nT02OnO]nT0
0ol0003oX[OXoj:gj009oj:gj003o`000?nU^>KoYKSV00SoYKSV0ol0000:ojRjiP03o`000?n[^nGo
Zk_U00[oZk_U00?o0000ojjli?n^_>@02_n^_>@00ol0003o/KgSok6mh`05ok6mh`;o00001?nb_n@0
0ol0003o]<3SokC0h`0;okC0h`03o`000?nf`>;o]/3R00[o]/3R00?o0000okO1hOng`N400_ng`N42
o`0000Oo^<;R00?o0000okW2hOni`^402oni`^42o`0004cooooo000@ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0e
ooooo`03o`000?nN^N_oW[W[00?o00001OnK^>`00ol0003oW;O[oibgj`08oibgj`03o`000?nM]n[o
WKOZ00WoWKOZ00?o0000oingjOnO]nT02OnO]nT00ol0003oX[OXoj:gj009oj:gj003o`000?nU^>Ko
YKSV00CoYKSV0ol000000onT^NSo0000ojRjiP0;ojRjiP03o`000?n[^nGoZk_U00WoZk_U0_l0000<
ojjli003o`000?na_N?o/KgS00;o/KgS0_l00007ok:oi003o`000?nd`>?o]<3S00[o]<3S00?o0000
okK0h_nf`>802onf`>801?l0003o]l7Qo`000?l0000:okS2hP03o`000?ni`^7o^L;Q00_o^L;Q00?o
0000ooooooooool0B_ooool0013ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_oo
ool00ol0003oooooooooo`0fooooo`;o00002OnK^>`00ol0003oW;O[oibgj`08oibgj`03o`000?nM
]n[oWKOZ00WoWKOZ00?o0000oingjOnO]nT02?nO]nT00ol0003oX[OXoj:gj00:oj:gj003o`000?nU
^>KoYKSV00?o00001OnT^NP00ol0003oZ;[VojRjiP0:ojRjiP03o`000?n[^nGoZk_U00SoZk_U00?o
0000oj^kiOl000003?n^_>@01?l0003o/KgSo`000?l0000:ok:oi003o`000?nd`>?o]<3S00[o]<3S
00?o0000okK0h_nf`>802_nf`>82o`0000go^<;R00?o0000okW2hOni`^402oni`^400ol0003ooooo
ooooo`19ooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo
00001oooool00ol0003oooooooooo`0gooooo`03o`000?nK^>coVkS/00SoVkS/00?o0000oibgjonL
]n/02?nL]n/00ol0003oWKOZoifgjP09oifgjP03o`000?nO]nWoWkOY00SoWkOY00?o0000oj:gj?nR
]nP02?nR]nP4o`0000WoY;WX00?o0000ojRji_nX^^H02_nX^^H00ol0003oZk_Uoj^ki@07oj^ki@03
o`000?n[^nGo000000co[[cT0_l0000<ok:oi003o`000?nd`>?o]<3S00_o]<3S00?o0000okK0h_nf
`>801_nf`>83o`000003okO2h_l0003o^<;R00go^<;R00?o0000okW2hOni`^402_ni`^42o`0004[o
oooo000@ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007oooo
o`03o`000?oooooooooo03Sooooo00?o0000oi^hk?nK^>`02?nK^>`00ol0003oW;O[oibgj`08oibg
j`03o`000?nM]n[oWKOZ00WoWKOZ00?o0000oingjOnO]nT02?nO]nT00ol0003oX[OXoj:gj004oj:g
j0?o00000_nQ^>T00ol0003oY;WXojBij009ojBij003o`000?nX^^KoZ;[V00[oZ;[V00?o0000oj^k
iOn[^nD01_n[^nD01?l0003oZk_Uoj^kiOl00008ojjli0?o000000?o[kkUo`000?nb_n@03?nb_n@0
0ol0003o]<3SokC0h`0;okC0h`03o`000?nf`>;o]/3R00?o]/3R0_l00005okO2hP03o`000?nh`^;o
^<;R00_o^<;R00?o0000okW2hOni`^402oni`^42o`0004Wooooo000@ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`;o0000>oooool00ol0003oVkS/oi^hk008
oi^hk003o`000?nL]n_oW;O[00SoW;O[00?o0000oifgj_nM]nX02OnM]nX00ol0003oWkOYoingj@08
oingj@03o`000?nR]nSoX[OX00?o00001_nQ^>T00ol0003oY;WXojBij009ojBij003o`000?nX^^Ko
Z;[V00WoZ;[V00?o0000oj^kiOn[^nD01_n[^nD01Ol0003oZk_Uoj^kiOn[^nGo000000Go[[cT0_l0
0005ojnni@03o`000?nb_nCo/[oT00_o/[oT00?o0000okC0hond`><02ond`><00ol0003o]/3Ro`00
0002o`0000So]l;R00?o0000okS2h_nh`^802onh`^800ol0003o^L;QokW2h@08okW2h@;o000000?o
^<;Ro`000?ooool0B?ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000000Oooooo00?o0000ooooooooool0>_ooool00ol0003oVkS/oi^hk008oi^hk003o`000?nL
]n_oW;O[00SoW;O[00?o0000oifgj_nM]nX02OnM]nX00ol0003oWkOYoingj@06oingj@Co00002_nQ
^>T00ol0003oY;WXojBij009ojBij003o`000?nX^^KoZ;[V00WoZ;[V00?o0000oj^kiOn[^nD01On[
^nD00ol0003oZk_Uoj^ki@02oj^ki@03o`000?n^_>Co000000;o00002?n__^D00ol0003o/[oTok:o
i00;ok:oi003o`000?nd`>?o]<3S00[o]<3S0_l0000<okO2hP03o`000?nh`^;o^<;R00_o^<;R00?o
0000okW2hOni`^401Oni`^42o`0000Co^<;R00?o0000ooooooooool0A_ooool0013ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0??oo
ool00ol0003oVkS/oi^hk008oi^hk003o`000?nL]n_oW;O[00SoW;O[00?o0000oifgj_nM]nX02OnM
]nX00ol0003oWkOYoingj@05o`0000;oW[OZ00?o0000oj6hjOnQ^>T02_nQ^>T00ol0003oY;WXojBi
j009ojBij003o`000?nX^^KoZ;[V00WoZ;[V00?o0000oj^kiOn[^nD01?n[^nD01?l0003oZk_Uoj^k
iOn[^nD3o`0000co[kkU00?o0000ok:oi?nb_n@02onb_n@00ol0003o]<3SokC0h`07okC0h`;o0000
00?o]L7So`000?ng`^803?ng`^800ol0003o^<;RokS2hP0;okS2hP03o`000?ni`^7o^L;Q00;o^L;Q
0_l00006okS2hP;o0000Aoooool002[ooooo00?o0000ooooooooool0?Oooool00ol0003oVkS/oi^h
k008oi^hk003o`000?nL]n_oW;O[00SoW;O[00?o0000oifgj_nM]nX01onM]nX4o`0000SoW[OZ00?o
0000oj6hjOnQ^>T02_nQ^>T00ol0003oY;WXojBij009ojBij003o`000?nX^^KoZ;[V00WoZ;[V00?o
0000oj^kiOn[^nD00on[^nD4o`0000;o[;gV00?o0000ojnniOn__^D02on__^D00ol0003o/[oTok:o
i00:ok:oi003o`000?nd`>?o]<3S00Go]<3S0_l00004okG1h`03o`000?ng`^;o]l;R00_o]l;R00?o
0000okS2h_nh`^802onh`^801?l0003o^L;Qo`000?l00009okS2hP03o`000?oooooooooo04Gooooo
000Zooooo`03o`000?oooooooooo03kooooo00?o0000oi^hk?nK^>`02?nK^>`00ol0003oW;O[oibg
j`08oibgj`04o`000?nM]n[oWKOZoifgjPGo00000_nK]n/00ol0003oW[OZoijgjP08oijgjP03o`00
0?nQ^>WoXKSY00[oXKSY00?o0000ojBij?nT^NP02OnT^NP00ol0003oZ;[VojRjiP09ojRjiP03o`00
0?n[^nGoZk_U00?o00001_n/_NH00ol0003o[kkUojnni@0;ojnni@03o`000?nb_nCo/[oT00[o/[oT
00?o0000okC0hond`><00_nd`><2o`0000Oo]L7S00?o0000okO2h_ng`^802_ng`^800ol0003o^<;R
okS2hP0;okS2hP;o00003?nh`^800ol0003oooooooooo`14ooooo`00:_ooool00ol0003ooooooooo
o`0oooooo`03o`000?nK^>coVkS/00SoVkS/00?o0000oibgjonL]n/01_nL]n/5o`0000SoVkO[00?o
0000oijgj_nN]nX02?nN]nX00ol0003oXKSYoj6hj@0:oj6hj@03o`000?nT^NSoY;WX00WoY;WX00?o
0000ojRji_nX^^H02?nX^^H3o`0000;o[;gV00?o0000ojbmi_n/_NH01On/_NH00ol0003o[kkUojnn
i@0:ojnni@03o`000?nb_nCo/[oT00_o/[oT00Co0000okC0hol0003o00002_ne`N<00ol0003o]l;R
okO2hP0:okO2hP03o`000?nh`^;o^<;R00So^<;R0_l000000onh`^;o0000okS2hP0<okS2hP03o`00
0?oooooooooo04?ooooo000Yooooo`?o0000@?ooool2o`0000[oVkS/00?o0000oibgjonL]n/01Ol0
0002oiVgk003o`000?nK]n_oVkO[00WoVkO[00?o0000oijgj_nN]nX02?nN]nX00ol0003oXKSYoj6h
j@09oj6hj@03o`000?nT^NSoY;WX00[oY;WX00?o0000ojRji_nX^^H01?nX^^H3o`000003ojRkiol0
003o[;gV00;o[;gV00?o0000ojbmi_n/_NH01_n/_NH00ol0003o[kkUojnni@0:ojnni@03o`000?nb
_nCo/[oT00[o/[oT0_l0000<okG1h`03o`000?ng`^;o]l;R00_o]l;R00?o0000okS2h_nh`^801Onh
`^82o`0000Co^<;R00?o0000okS2h_nh`^802_nh`^82o`0004Cooooo000Zooooo`03o`000?oooooo
oooo043ooooo0_l00008oi^hk0Co00002?nI]n`00ol0003oVkO[oi^gj`09oi^gj`03o`000?nN]n[o
W[OZ00SoW[OZ00?o0000oj6hjOnQ^>T02OnQ^>T00ol0003oY;WXojBij00:ojBij003o`000?nX^^Ko
Z;[V00?o00001OnX^nL01?l0003o[;gVojbmi_l00009ojbmiP03o`000?n__^Go[kkU00[o[kkU00?o
0000ok:oi?nb_n@01_nb_n@3o`000003ok;1iOl0003o]L7S00co]L7S00?o0000okO2h_ng`^802ong
`^800ol0003o^<;RokS2hP02okS2hP;o00001onh`^800ol0003o^<;RokS2hP0:okS2hP03o`000?oo
oooooooo04;ooooo000Zooooo`03o`000?oooooooooo047ooooo0_l00002oi^hk0Go00000_nH]nd0
0ol0003oVKO/oiVgk008oiVgk003o`000?nK]n_oVkO[00WoVkO[00?o0000oijgj_nN]nX02?nN]nX0
0ol0003oXKSYoj6hj@09oj6hj@03o`000?nT^NSoY;WX00SoY;WX1?l00009ojRki`03o`000?n/_NKo
000000[o[;gV00?o0000ojnniOn__^D02_n__^D00ol0003o/[oTok:oi003ok:oi0;o00001Onb`ND0
0ol0003o]L7SokG1h`0;okG1h`03o`000?ng`^;o]l;R00_o]l;R00Co0000okS2h_l0003o00002_nh
`^800ol0003o^<;RokS2hP0:okS2hP03o`000?oooooooooo047ooooo000Zooooo`03o`000?oooooo
oooo04;ooooo0ol00008oiRgk@03o`000?nI]ncoVKO/00SoVKO/00?o0000oi^gjonK]n/02OnK]n/0
0ol0003oW[OZoijgjP07oijgjP03o`000?nQ^>WoXKSY00[oXKSY00?o0000ojBij?nT^NP01?nT^NP3
o`0000;oY;[Y00?o0000ojRkionX^nL02OnX^nL2o`0000_o[;gV00?o0000ojnniOn__^D02_n__^D0
0ol0003o/[oTo`000002o`0000So//7U00?o0000okG1hone`N<02one`N<00ol0003o]l;RokO2hP0:
okO2hP;o00003?nh`^800ol0003o^<;RokS2hP0;okS2hP03o`000?oooooooooo043ooooo000Yoooo
o`03o`000?oooooooooo04Cooooo00?o0000oiRgkOnH]nd02?nH]nd00ol0003oVKO/oiVgk008oiVg
k003o`000?nK]n_oVkO[00WoVkO[00?o0000oijgj_nN]nX01onN]nX00ol0003oXKSYoj6hj@0:oj6h
j@03o`000?nT^NSoY;WX00?o00001_nT^^T00ol0003oZ;_WojRki`09ojRki`03o`000?n/_NKo[;gV
00[o[;gV00?o0000ojnniOn__^D02On__^D2o`0000co//7U00?o0000okG1hone`N<02one`N<00ol0
003o]l;RokO2hP07okO2hP;o000000?o]l?So`000?nh`^803?nh`^800ol0003o^<;RokS2hP0:okS2
hP03o`000?oooooooooo043ooooo000Yooooo`03o`000?oooooooooo04Gooooo00?o0000oiRgkOnH
]nd02?nH]nd00ol0003oVKO/oiVgk008oiVgk003o`000?nK]n_oVkO[00SoVkO[00?o0000oijgj_nN
]nX02?nN]nX00ol0003oXKSYoj6hj@08oj6hj@Co00002_nT^^T00ol0003oZ;_WojRki`08ojRki`;o
00003?n/_NH00ol0003o[kkUojnni@06ojnni@;o000000?o[koVo`000?nb`ND03?nb`ND00ol0003o
]L7SokG1h`0:okG1h`03o`000?ng`^;o]l;R00Go]l;R0_l00004okO3h`03o`000?nh`^;o^<;R00_o
^<;R00?o0000okS2h_nh`^802_nh`^800ol0003oooooooooo`0oooooo`00:Oooool00ol0003ooooo
ooooo`16ooooo`03o`000?nH]ngoV;O]00SoV;O]00?o0000oiVgk?nI]n`02?nI]n`00ol0003oVkO[
oi^gj`08oi^gj`03o`000?nN]n[oW[OZ00SoW[OZ00?o0000oj6hjOnQ^>T01?nQ^>T3o`0000;oX;WZ
00?o0000ojBjjOnT^^T02_nT^^T00ol0003oZ;_WojRki`07ojRki`03o`000?nX^nOo000000co[;gV
00?o0000ojnniOn__^D00_n__^D3o`0000Co[koV00?o0000ok;1iOnb`ND02onb`ND00ol0003o]L7S
okG1h`0:okG1h`03o`000?ng`^;o]l;R00;o]l;R0_l00007okO3h`03o`000?nh`^;o^<;R00_o^<;R
00?o0000okS2h_nh`^802Onh`^82o`00043ooooo000Yooooo`;o0000B?ooool00ol0003oV;O]oiRg
k@08oiRgk@03o`000?nI]ncoVKO/00SoVKO/00?o0000oi^gjonK]n/02?nK]n/00ol0003oW[OZoijg
jP08oijgjP03o`000?nQ^>WoXKSY00?o00001_nP^NX00ol0003oY;[YojBjj@09ojBjj@03o`000?nX
^nOoZ;_W00OoZ;_W00?o0000ojRkiol000003On/_NH01?l0003o[kkUo`000?l00008ojnoiP03o`00
0?nb`NGo//7U00[o//7U00?o0000okG1hone`N<02one`N<01?l0003o]l;Ro`000?l0000:okO3h`03
o`000?nh`^;o^<;R00[o^<;R00?o0000okS2h_nh`^801_nh`^83o`000003okO2h_l0003o000003oo
oooo000Yooooo`03o`000?oooooooooo04Sooooo00?o0000oiRgkOnH]nd02?nH]nd00ol0003oVKO/
oiVgk008oiVgk003o`000?nK]n_oVkO[00SoVkO[00?o0000oijgj_nN]nX01_nN]nX4o`0000[oX;WZ
00?o0000ojBjjOnT^^T02OnT^^T00ol0003oZ;_WojRki`06ojRki`04o`000?nX^nOoZ;_Wo`0000co
[;gV0_l0000;ojnoiP03o`000?nb`NGo//7U00[o//7U00?o0000okG1hone`N<02_ne`N<2o`0000co
]l?S00?o0000okS2h_nh`^802onh`^800ol0003o^<;RokS2hP03okS2hP;o00001Ong`^800ol0003o
ooooooooo`0mooooo`00:Oooool00ol0003oooooooooo`19ooooo`03o`000?nH]ngoV;O]00SoV;O]
00?o0000oiVgk?nI]n`02?nI]n`00ol0003oVkO[oi^gj`08oi^gj`03o`000?nN]n[oW[OZ00Go0000
0_nL^>/00ol0003oX;WZoj2ijP0:oj2ijP03o`000?nT^^WoY;[Y00WoY;[Y00?o0000ojRkionX^nL0
1OnX^nL01Ol0003oZ;_WojRkionX^nOo000000So[;gV0ol000000on/_^Oo0000ojnoiP0;ojnoiP03
o`000?nb`NGo//7U00[o//7U00?o0000okG1hone`N<01_ne`N<3o`000003okG2i?l0003o]l?S00co
]l?S00?o0000okS2h_nh`^802onh`^800ol0003o^<;Ro`000002o`0000So]l;R00?o0000oooooooo
ool0??ooool002Wooooo00?o0000ooooooooool0B_ooool00ol0003oV;O]oiRgk@08oiRgk@03o`00
0?nI]ncoVKO/00SoVKO/00?o0000oi^gjonK]n/01_nK]n/4o`0000SoW;S[00?o0000oj2ij_nP^NX0
2_nP^NX00ol0003oY;[YojBjj@09ojBjj@03o`000?nX^nOoZ;_W00CoZ;_W00?o0000ojRkionX^nL0
0_nX^nL00ol0003o[;gVojbmiP03ojbmiP;o00001On/_^L00ol0003o[koVojnoiP0:ojnoiP03o`00
0?nb`NGo//7U00[o//7U00?o0000okG1hone`N<00one`N<2o`0000Go]L;T00?o0000okO3hong`n<0
2ong`n<00ol0003o^<;RokS2hP0:okS2hP;o00003?ng`^800ol0003oooooooooo`0kooooo`00:Ooo
ool00ol0003oooooooooo`1;ooooo`03o`000?nH]ngoV;O]00SoV;O]00?o0000oiVgk?nI]n`02?nI
]n`00ol0003oVkO[oi^gj`05o`0000;oV[O/00?o0000oibhjonL^>/02?nL^>/00ol0003oX;WZoj2i
jP0:oj2ijP03o`000?nT^^WoY;[Y00WoY;[Y00?o0000ojRkionX^nL00onX^nL00ol0003oZ;_WojRk
i`03ojRki`03o`000?n/_NKo000000;o00002?n/_^L00ol0003o[koVojnoiP09ojnoiP03o`000?nb
`NGo//7U00_o//7U00?o0000okG1hol000000_l00008okG2i003o`000?ng`n?o]l?S00_o]l?S00?o
0000okS2h_nh`^801onh`^82o`000003okO3hol0003o]l;R00_o]l;R0_l0000looooo`00:Oooool0
0ol0003oooooooooo`1<ooooo`03o`000?nH]ngoV;O]00SoV;O]00?o0000oiVgk?nI]n`00onI]n`7
o`0000SoV[O/00?o0000oibhjonL^>/02?nL^>/00ol0003oX;WZoj2ijP0:oj2ijP03o`000?nT^^Wo
Y;[Y00SoY;[Y00?o0000ojRkionX^nL00onX^nL00ol0003oZ;_WojRki`02ojRki`?o00003?n/_^L0
0ol0003o[koVojnoiP09ojnoiP03o`000?nb`NGo//7U00[o//7U0_l0000<okG2i003o`000?ng`n?o
]l?S00[o]l?S00?o0000okS2h_nh`^801Onh`^82o`0000Co]l?S00?o0000okO2h_ng`^802_ng`^80
0ol0003oooooooooo`0jooooo`00:?ooool3o`0004kooooo00?o0000oiRgkOnH]nd01_nH]nd7o`00
00GoUkK]00?o0000oiZgk?nJ]n`02?nJ]n`00ol0003oW;S[oibhj`08oibhj`03o`000?nP^N[oX;WZ
00WoX;WZ00?o0000ojBjjOnT^^T02OnT^^T00ol0003oZ;_WojRki`02ojRki`03o`000?nX^nOo0000
00;o00000_nX_NT00ol0003o[;kWojbni`0;ojbni`03o`000?n__nKo[koV00Wo[koV00?o0000ok;1
iOnb`ND01_nb`ND3o`000003ok;2i_l0003o]L;T00co]L;T00?o0000okO3hong`n<02_ng`n<00ol0
003o^<;RokS2hP02okS2hP;o00001ong`n<00ol0003o]l;RokO2hP0:okO2hP03o`000?oooooooooo
03Wooooo000Xooooo`03o`000?oooooooooo04oooooo00?o0000oiRgkOnH]nd01Ol00002oiJfk@03
o`000?nG]^goUkK]00SoUkK]00?o0000oiZgk?nJ]n`02?nJ]n`00ol0003oW;S[oibhj`08oibhj`03
o`000?nP^N[oX;WZ00WoX;WZ00?o0000ojBjjOnT^^T02OnT^^T00ol0003oZ;_WojRki`03o`0000Ko
Z;gY00?o0000ojbnion/_^L02on/_^L00ol0003o[koVojnoiP09ojnoiP03o`000?nb`NGo//7U00?o
//7U0_l00005ok;2iP03o`000?ne`^Co]L;T00_o]L;T00?o0000okO3hong`n<02_ng`n<01?l0003o
^<;Ro`000?l0000:okO3h`03o`000?ng`^;o]l;R00[o]l;R00?o0000ooooooooool0>?ooool000co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413o
c<c<00Oooooo00?o0000ooooooooool0D?ooool2o`0000SoU[K]00?o0000oiNfkOnG]^d02?nG]^d0
0ol0003oV[O/oiZgk008oiZgk003o`000?nL^>_oW;S[00SoW;S[00?o0000oj2ij_nP^NX02OnP^NX0
0ol0003oY;[YojBjj@08ojBjj@?o000000?oZ;gYo`000?nX_NT01onX_NT00ol0003o[;kWojbni`0:
ojbni`03o`000?n__nKo[koV00[o[koV00?o0000ok;1iOl000000_l00008ok;2iP03o`000?ne`^Co
]L;T00[o]L;T00?o0000okO3hong`n<02_ng`n<2o`0000co]l?S00?o0000okO2h_ng`^802_ng`^82
o`0003Wooooo000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEE
ogMgMoooooooV9RHob4Q8@07ooooo`03o`000?oooooooooo053ooooo00?o0000oiJfkOnF]^d02?nF
]^d00ol0003oUkK]oiNfk@08oiNfk@03o`000?nJ]ncoV[O/00SoV[O/00?o0000oibhjonL^>/02?nL
^>/00ol0003oX;WZoj2ijP09oj2ijP03o`000?nT^^WoY;[Y00CoY;[Y0ol000000onT_>[o0000ojRm
j@02o`0000WoZ;gY00?o0000ojbnion/_^L02_n/_^L00ol0003o[koVojnoiP09ojnoiP;o00003?nb
`^H00ol0003o]L;TokG2i00:okG2i003o`000?ng`n?o]l?S00Oo]l?S0_l000000onf`nCo0000okO3
h`0<okO3h`03o`000?ng`^;o]l;R00[o]l;R00?o0000ooooooooool0=oooool000cooooo00Go410@
oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`1Aooooo`03o`000?nF]^goU[K]00SoU[K]00?o0000oiNfkOnG]^d02?nG]^d00ol0003oV[O/
oiZgk008oiZgk003o`000?nL^>_oW;S[00SoW;S[00?o0000oj2ij_nP^NX02OnP^NX00ol0003oY;[Y
ojBjj@03o`0000?oY;cZ0ol000000onX_NWo0000ojRmj@09ojRmj@03o`000?n/_^Oo[;kW00[o[;kW
00?o0000ojnoi_n__nH01_n__nH2o`000003ojo1iol0003o//;V00co//;V00?o0000okG2i?ne`^@0
2_ne`^@00ol0003o]l?SokO3h`04okO3h`;o00001?nf`n@00ol0003o]l?SokO3h`0;okO3h`03o`00
0?ng`^;o]l;R00[o]l;R00?o0000ooooooooool0=_ooool000cooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401oooool00ol0003oooooooooo`1Booooo`03
o`000?nF]^goU[K]00SoU[K]00?o0000oiNfkOnG]^d02?nG]^d00ol0003oV[O/oiZgk008oiZgk003
o`000?nL^>_oW;S[00SoW;S[00?o0000oj2ij_nP^NX01onP^NX4o`0000?oY;cZ0ol00003ojBljP03
o`000?nX_NWo000000[oZ;gY00?o0000ojbnion/_^L02_n/_^L00ol0003o[koVojnoiP02ojnoiP?o
00001?n_`NL00ol0003o//;Vok;2iP0;ok;2iP03o`000?ne`^Co]L;T00[o]L;T00?o0000okO3hong
`n<00_ng`n<00ol0003o]/?TokK3i005okK3i003o`000?ng`n?o]l?S00_o]l?S00?o0000okO2h_ng
`^802Ong`^82o`0003Oooooo000<ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003o
EEEEo`000?l@413oc<c<00Oooooo00?o0000ooooooooool0Doooool00ol0003oU[K]oiJfk@08oiJf
k@03o`000?nG]^goUkK]00SoUkK]00?o0000oiZgk?nJ]n`02?nJ]n`00ol0003oW;S[oibhj`08oibh
j`04o`000?nP^N[oX;WZoj2ijPGo00000_nP^^`00ol0003oY;cZo`000002o`0000OoY;cZ00?o0000
ojRmjOl000002OnX_NT00ol0003o[;kWojbni`0;ojbni`04o`000?n__nKo0000o`0000So[l7W00?o
0000ok;2i_nb`^H02_nb`^H00ol0003o]L;TokG2i00;okG2i004o`000?ng`n?o0000o`0000Wo]/?T
00?o0000okO3hong`n<02_ng`n<00ol0003o]l;RokO2hP06okO2hP?o000000?o]/;So`000?l00000
=_ooool000cooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Wooooo
00?o0000ooooooooool0E?ooool00ol0003oU[K]oiJfk@08oiJfk@03o`000?nG]^goUkK]00SoUkK]
00?o0000oiZgk?nJ]n`02?nJ]n`00ol0003oW;S[oibhj`06oibhj`Go00001_nP^^`3o`0000_oY;cZ
00?o0000ojRmjOl000002OnX_NT00ol0003o[;kWojbni`0:ojbni`;o00002on_`NL00ol0003o//;V
ok;2iP0:ok;2iP03o`000?ne`^Co]L;T00[o]L;T0_l0000<okK3i003o`000?ng`n?o]l?S00[o]l?S
00?o0000okO2h_ng`^800ong`^82o`0000Go]/;S00?o0000ooooooooool0=?ooool000cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo0_l0001Gooooo`03o`00
0?nF]^goU[K]00SoU[K]00?o0000oiNfkOnG]^d02?nG]^d00ol0003oV[O/oiZgk008oiZgk003o`00
0?nL^>_oW;S[00Go00000_nL^N`00ol0003oX;[/oj2jk003oj2jk0?o00000onP^^`00ol0003oY;cZ
ojBljP09ojBljP03o`000?nX_NWo000000WoZ;gY00?o0000ojbnion/_^L01_n/_^L3o`000003ojc0
jOl0003o[l7W00_o[l7W00?o0000ok;2i_nb`^H02_nb`^H00ol0003o]L;TokG2i006okG2i0?o0000
00?o]<CVo`000?nf`n@03?nf`n@00ol0003o]l?SokO3h`0:okO3h`03o`000?ng`^;o000000;o0000
2?nf`^<00ol0003oooooooooo`0cooooo`003?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`1Gooooo`03o`000?nF]^goU[K]00So
U[K]00?o0000oiNfkOnG]^d02?nG]^d00ol0003oV[O/oiZgk006oiZgk0Co00002?nL^N`00ol0003o
X;[/o`000002o`0000OoX;[/00?o0000ojBlj_nT_>X02OnT_>X00ol0003oZ;gYo`000009ojRmj@03
o`000?n/_^Oo[;kW00?o[;kW0_l00005ojc0j@03o`000?n_`NOo[l7W00[o[l7W00?o0000ok;2i_nb
`^H02_nb`^H00ol0003o]L;TokG2i003okG2i0;o00001Onda>H00ol0003o]/?TokK3i00;okK3i003
o`000?ng`n?o]l?S00Wo]l?S0_l0000<okK2h`03o`000?oooooooooo03;ooooo000Wooooo`03o`00
0?oooooooooo05Sooooo00?o0000oiJfkOnF]^d02?nF]^d00ol0003oUkK]oiNfk@08oiNfk@03o`00
0?nJ]ncoV[O/00Go00000_nI^>d00ol0003oW;W/oibik006oibik0?o00002onP^^`00ol0003oY;cZ
ojBljP09ojBljP03o`000?nX_NWo000000WoZ;gY00?o0000ojbniol000000_l00008ojc0j@03o`00
0?n_`NOo[l7W00Wo[l7W00?o0000ok;2i_nb`^H02onb`^H00ol0003o]L;To`000002o`0000So]<CV
00?o0000okK3i?nf`n@02onf`n@00ol0003o]l?SokO3h`06okO3h`;o000000?o]L?To`000?nf`^<0
3?nf`^<00ol0003oooooooooo`0aooooo`009oooool00ol0003oooooooooo`1Iooooo`03o`000?nF
]^goU[K]00SoU[K]00?o0000oiNfkOnG]^d00onG]^d7o`0000SoVKS]00?o0000oibik?nL^N`00_nL
^N`3o`0000?oW;W/00?o0000oj2jk?nP^^`02OnP^^`00ol0003oY;cZojBljP09ojBljP03o`000?nX
_NWo000000SoZ;gY0_l0000<ojc0j@03o`000?n_`NOo[l7W00Wo[l7W00?o0000ok;2i_nb`^H02_nb
`^H2o`0000co]<CV00?o0000okK3i?nf`n@02onf`n@00ol0003o]l?SokO3h`02okO3h`?o00001?ne
`n@00ol0003o]/;SokK2h`0:okK2h`;o0000<_ooool002Oooooo00?o0000ooooooooool0F_ooool0
0ol0003oU[K]oiJfk@06oiJfk@Oo00001OnG]nh00ol0003oVKS]oiVhk@08oiVhk@Co00001onL^N`0
0ol0003oX;[/oj2jk009oj2jk003o`000?nT_>[oY;cZ00WoY;cZ0_l00005ojRmj@?o000000?oZ;oZ
o`000?n/`>T03?n/`>T00ol0003o[l7Wojo1i`09ojo1i`03o`000?nb`^Ko//;V00Ko//;V0ol00000
0onb`nOo0000okC4iP0<okC4iP03o`000?nf`nCo]/?T00_o]/?T00Co0000okO3hol0003o00002?ne
`n@00ol0003o]/;SokK2h`0:okK2h`03o`000?oooooooooo033ooooo000Wooooo`03o`000?oooooo
oooo05_ooooo00?o0000oiJfkOnF]^d01Ol00002oiJfkP03o`000?nG]nkoUkO^00SoUkO^00?o0000
oiVhkOnI^>d01OnI^>d4o`0000[oW;W/00?o0000oj2jk?nP^^`02OnP^^`00ol0003oY;cZojBljP09
ojBljP;o000000CoZ;gYo`000?l0003o00001OnX_nX00ol0003o[<3Yojc0j@0;ojc0j@03o`000?n_
`NOo[l7W00Wo[l7W00?o0000ok;2i_nb`^H00onb`^H2o`0000Go//?W00?o0000okC4i_nda>H02ond
a>H00ol0003o]/?TokK3i00:okK3i0;o00002one`n@00ol0003o]/;SokK2h`0:okK2h`03o`000?oo
oooooooo02oooooo000Wooooo`;o0000GOooool2o`0000SoU[K^00?o0000oiNgk_nG]nh02?nG]nh0
1?l0003oVKS]oiVhkOnI^>d3o`0000CoVKS]00?o0000oibik?nL^N`02?nL^N`00ol0003oX;[/oj2j
k009oj2jk003o`000?nT_>[oY;cZ00OoY;cZ1?l00009ojRojP03o`000?n/`>Wo[<3Y00_o[<3Y00?o
0000ojo1ion_`NL02On_`NL00ol0003o//;Vo`000002o`0000So//?W00?o0000okC4i_nda>H02_nd
a>H00ol0003o]/?TokK3i008okK3i0;o000000?o]<CVo`000?ne`n@02one`n@00ol0003o]/;SokK2
h`0:okK2h`03o`000?oooooooooo02kooooo000Vooooo`;o0000Goooool00ol0003oU[K^oiJfkP07
oiJfkP03o`000?nG]nkoUkO^00SoUkO^0ol00008oiVhk@03o`000?nL^NcoW;W/00SoW;W/00?o0000
oj2jk?nP^^`02OnP^^`01?l0003oY;cZojBlj_nT_>X5o`0000;oY;g/00?o0000ojRoj_l000002OnX
_nX00ol0003o[<3Yojc0j@0;ojc0j@03o`000?n_`NOo[l7W00So[l7W0_l0000<ok;3i`03o`000?nd
a>Ko]<CV00[o]<CV00?o0000okK3i?nf`n@01Onf`n@2o`0000Co]<CV00?o0000okG3i?ne`n@02_ne
`n@00ol0003o]/;SokK2h`09okK2h`;o0000;oooool002Oooooo00?o0000ooooooooool0G_ooool0
0ol0003oU[K^oiJfkP07oiJfkP03o`000?nG]nkoUkO^00CoUkO^0ol000000onG]nko0000oiVhk@09
oiVhk@03o`000?nL^NcoW;W/00SoW;W/00?o0000oj2jk?nP^^`02?nP^^`4o`0000SoY;g/00?o0000
ojRoj_l000002OnX_nX00ol0003o[<3Yojc0j@0;ojc0j@03o`000?n_`NOo[l7W00Co[l7W0ol00000
0on_`nWo0000ok;3i`0<ok;3i`03o`000?nda>Ko]<CV00[o]<CV00?o0000okK3i?nf`n@00_nf`n@2
o`0000Oo]<CV00?o0000okG3i?ne`n@02One`n@00ol0003o]/;SokK2h`0:okK2h`;o0000;_ooool0
02Oooooo00?o0000ooooooooool0Goooool00ol0003oU[K^oiJfkP07oiJfkP03o`000?nG]nkoUkO^
00?o00001OnG]nh00ol0003oVKS]oiVhk@08oiVhk@03o`000?nL^NcoW;W/00SoW;W/00?o0000oj2j
k?nP^^`01?nP^^`3o`000003oj2lk?l0003oY;g/00[oY;g/00?o0000ojRoj_l000002OnX_nX00ol0
003o[<3Yojc0j@0;ojc0j@03o`000?n_`NOo[l7W00?o00001On_`nT00ol0003o//?Wok;3i`0;ok;3
i`03o`000?nda>Ko]<CV00[o]<CV00Co0000okK3i?l0003o00002_nda>H00ol0003o]L?TokG3i009
okG3i003o`000?nf`^?o]/;S00Ko]/;S0ol000000onc`^Co0000ooooo`0]ooooo`009_ooool00ol0
003oooooooooo`1Qooooo`03o`000?nF]^koU[K^00KoU[K^0ol00009oiNgkP03o`000?nI^>goVKS]
00SoVKS]00?o0000oibik?nL^N`02?nL^N`00ol0003oX;[/oj2jk003o`0000GoX;c/00?o0000ojBm
k?nT_N`02OnT_N`00ol0003oZ;oZo`000009ojRojP03o`000?n/`>Wo[<3Y00[o[<3Y0ol00009ojo3
j@03o`000?nb`nOo//?W00[o//?W00?o0000okC4i_nda>H02_nda>H2o`0000co]<CV00?o0000okG3
i?ne`n@02_ne`n@00ol0003o]/;SokK2h`03okK2h`;o00001Onc`^@00ol0003oooooooooo`0[oooo
o`009_ooool00ol0003oooooooooo`1Rooooo`03o`000?nF]^koU[K^00;oU[K^0ol00002oiJfkP03
o`000?nG]nkoUkO^00SoUkO^00?o0000oiVhkOnI^>d02?nI^>d00ol0003oW;W/oibik006oibik0Co
00002OnP_>`00ol0003oY;g/ojBmk009ojBmk003o`000?nX_n[o000000WoZ;oZ00?o0000ojc0jOn/
`>T01_n/`>T3o`000003ojc2j_l0003o[l?Y00[o[l?Y00?o0000ok;3ionb`nL02_nb`nL00ol0003o
]<CVokC4iP06okC4iP?o000000?o/lCWo`000?nda>H03?nda>H00ol0003o]L?TokG3i00:okG3i003
o`000?nf`^?o000000;o00001onc`^@2o`0002cooooo000Vooooo`03o`000?oooooooooo06?ooooo
1?l00006oiJfkP03o`000?nG]nkoUkO^00SoUkO^00?o0000oiVhkOnI^>d02?nI^>d00ol0003oW;W/
oibik005o`0000;oW;[]00?o0000oj2lk?nP_>`02OnP_>`00ol0003oY;g/ojBmk009ojBmk0;o0000
2_nX_nX00ol0003o[<3Yojc0j@03ojc0j@;o00001On/`^X00ol0003o[l?Yojo3j@09ojo3j@03o`00
0?nb`nOo//?W00[o//?W00?o0000okC4i_nda>H00onda>H2o`0000Go/lCW00?o0000okC4i_nda>H0
2onda>H00ol0003o]L?TokG3i009okG3i0;o00002onc`^@00ol0003oooooooooo`0Zooooo`009_oo
ool2o`0006?ooooo0ol00009oiJfkP03o`000?nG]nkoUkO^00SoUkO^00?o0000oiVhkOnI^>d00onI
^>d7o`0000SoW;[]00?o0000oj2lk?nP_>`02OnP_>`00ol0003oY;g/ojBmk009ojBmk0;o00002_nX
_nX00ol0003o[<3Yo`000002o`0000So[<;Z00?o0000ojo3jOn_`nT02On_`nT00ol0003o//?Wok;3
i`0:ok;3i`03o`000?nda>Ko000000;o00002?nca>L00ol0003o]<CVokC4iP0:okC4iP03o`000?ne
`nCo]L?T00Ko]L?T0ol000000onc`nKo0000ok?2i00;ok?2i003o`000?oooooooooo02Wooooo000V
ooooo`03o`000?oooooooooo05oooooo0ol00003ooooo`03o`000?nF]^koU[K^00OoU[K^00?o0000
oiNgk_nG]nh01_nG]nh7o`0000GoVKS^00?o0000oibjkOnL^^d02?nL^^d00ol0003oX;c/oj2lk009
oj2lk003o`000?nT_NcoY;g/00WoY;g/0_l00009ojRojP;o00003?n/`^X00ol0003o[l?Yojo3j@09
ojo3j@03o`000?nb`nOo//?W00Wo//?W0_l0000<ok?4i`03o`000?nda>Ko]<CV00[o]<CV00?o0000
okG3i?ne`n@00one`n@2o`0000Go/l?V00?o0000ok?2i?nc`^@02_nc`^@00ol0003oooooooooo`0X
ooooo`009_ooool00ol0003oooooooooo`1Looooo`?o00001oooool00ol0003oU[K^oiJfkP07oiJf
kP03o`000?nG]nkoUkO^00Go00000onG]nh00ol0003oVKS^oiVhkP07oiVhkP03o`000?nL^^goW;[]
00SoW;[]00?o0000oj2lk?nP_>`02OnP_>`00ol0003oY;g/ojBmk009ojBmk0;o00001OnX_nX3o`00
00;oZ<7[00?o0000ojc2j_n/`^X02_n/`^X00ol0003o[l?Yojo3j@09ojo3j@03o`000?nb`nOo//?W
00Ko//?W0_l000000onaa>So0000ok?4i`0<ok?4i`03o`000?nda>Ko]<CV00[o]<CV00?o0000okG3
i?l000000_l00008ok?3iP03o`000?nc`^Co/l;T00Wo/l;T00?o0000ooooooooool0:?ooool002Ko
oooo00?o0000ooooooooool0FOooool3o`0000_ooooo00?o0000oiJfk_nF]^h00onF]^h6o`0000Wo
UkO^00?o0000oiVhk_nI^>h01onI^>h00ol0003oW;[]oibjk@08oibjk@03o`000?nP_>coX;c/00Wo
X;c/00?o0000ojBmk?nT_N`02OnT_N`2o`000004ojRoj_l0003o0000o`0000KoZ<7[00?o0000ojc2
j_n/`^X02_n/`^X00ol0003o[l?Yojo3j@09ojo3j@03o`000?nb`nOo//?W00;o//?W0ol00004ok74
j003o`000?nca>Oo/lCW00_o/lCW00?o0000okC4i_nda>H02Onda>H2o`0000co/l?V00?o0000ok?2
i?nc`^@02Onc`^@00ol0003oooooooooo`0Wooooo`009_ooool00ol0003oooooooooo`1Fooooo`?o
00003oooool5o`0000GoU[K]00?o0000oiNgk_nG]nh02?nG]nh00ol0003oVKS^oiVhkP07oiVhkP03
o`000?nL^^goW;[]00SoW;[]00?o0000oj2lk?nP_>`02OnP_>`00ol0003oY;g/ojBmk007ojBmk0Co
00002_nX`N/00ol0003o[<;Zojc2jP09ojc2jP03o`000?n_`nWo[l?Y00[o[l?Y00Co0000ok;3iol0
003o00002?naa>P00ol0003o/lCWok?4i`0;ok?4i`03o`000?nda>Ko]<CV00Ko]<CV0_l000000onb
a>Oo0000ok?3iP0<ok?3iP03o`000?nc`^Co/l;T00Wo/l;T00?o0000ooooooooool09_ooool002Ko
oooo00?o0000ooooooooool0Doooool3o`0001?ooooo00?o0000oiJfkOnF]^d01onF]^d00ol0003o
UkO^oiNgkP08oiNgkP03o`000?nI^>koVKS^00OoVKS^00?o0000oibjkOnL^^d02?nL^^d00ol0003o
X;c/oj2lk009oj2lk004o`000?nT_NcoY;g/ojBmk0Go00000onT_nd2o`0000[oZ<7[00?o0000ojc2
j_n/`^X02On/`^X00ol0003o[l?Yojo3j@08ojo3j@?o00002onaa>P00ol0003o/lCWok?4i`0;ok?4
i`03o`000?nda>Ko]<CV00;o]<CV0ol00004ok;4i`03o`000?nc`nKo/l?V00_o/l?V00?o0000ok?2
i?nc`^@02?nc`^@2o`0002Oooooo000Uooooo`03o`000?oooooooooo057ooooo0ol0000Gooooo`03
o`000?nF]^goU[K]00OoU[K]00?o0000oiNgk_nG]nh02?nG]nh00ol0003oVKS^oiVhkP07oiVhkP03
o`000?nL^^goW;[]00SoW;[]00?o0000oj2lk?nP_>`02?nP_>`4o`0000WoY;o]00?o0000ojS1jonX
`N/02OnX`N/00ol0003o[<;Zojc2jP09ojc2jP03o`000?n_`nWo[l?Y00Co[l?Y0ol00002ojk4jP03
o`000?naa>So/LCX00[o/LCX00?o0000ok?4ionca>L02onca>L01?l0003o]<CVo`000?l00008ok;4
i`03o`000?nc`nKo/l?V00[o/l?V00?o0000ok?2i?nc`^@02Onc`^@00ol0003oooooooooo`0Uoooo
o`009Oooool3o`0004kooooo0ol0000Jooooo`;o00002OnF]^d00ol0003oUkO^oiNgkP08oiNgkP03
o`000?nI^>koVKS^00OoVKS^00?o0000oibjkOnL^^d02?nL^^d00ol0003oX;c/oj2lk004oj2lk0?o
000000?oX;g]o`000?nT_nd02onT_nd00ol0003oZ<7[ojS1j`09ojS1j`03o`000?n/`^[o[<;Z00Wo
[<;Z00?o0000ojo3jOn_`nT00ol00006ojk4jP03o`000?naa>So/LCX00[o/LCX00?o0000ok?4ionc
a>L02_nca>L2o`0000_o//CW00?o0000ok?3i_nc`nH02_nc`nH00ol0003o/l;Tok?2i008ok?2i0;o
00009_ooool002Gooooo00?o0000ooooooooool0Boooool3o`0001kooooo0_l00009oiJfk@03o`00
0?nG]nkoUkO^00SoUkO^00?o0000oiVhk_nI^>h01onI^>h00ol0003oW;[]oibjk@08oibjk@03o`00
0?nP_>coX;c/00?o00001OnP_Nd00ol0003oY;o]ojBok@0:ojBok@03o`000?nX`N_oZ<7[00WoZ<7[
00?o0000ojc2j_n/`^X02?n/`^X3o`0000[o[/CZ00?o0000ok74j?naa>P02_naa>P00ol0003o/lCW
ok?4i`06ok?4i`?o000000?o/LGXo`000?nba>L02onba>L00ol0003o/l?Vok?3iP0:ok?3iP03o`00
0?nc`^Co/l;T00Co/l;T0ol000000ona`NKo0000o`00000Uooooo`002Oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01oooool00ol0003o
ooooooooo`18ooooo`?o00008_ooool2o`0000WoU[K]00?o0000oiNgk_nG]nh02?nG]nh00ol0003o
VKS^oiVhkP07oiVhkP03o`000?nL^^goW;[]00KoW;[]1?l00009oj2mk@03o`000?nT_ngoY;o]00[o
Y;o]00?o0000ojS1jonX`N/02OnX`N/00ol0003o[<;Zojc2jP04ojc2jP?o00000_n[`n/00ol0003o
[/CZojk4jP09ojk4jP03o`000?naa>So/LCX00[o/LCX00?o0000ok?4ionca>L00onca>L2o`0000Go
/LGX00?o0000ok;4ionba>L02_nba>L00ol0003o/l?Vok?3iP0:ok?3iP03o`000?nc`^Co/l;T00?o
00001Ona`NH2o`0002Cooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00Go8B4QoiRHV?ooooooV9RHob4Q8@07ooooo`03o`000?oooooooooo04Gooooo0ol0000Voooo
o`;o00002OnF]^d00ol0003oUkO^oiNgkP08oiNgkP03o`000?nI^>koVKS^00OoVKS^00?o0000oibj
kOnL^^d01Ol00003oifkkP03o`000?nP_NgoX;g]00SoX;g]00?o0000ojBokOnT_nd02_nT_nd00ol0
003oZ<7[ojS1j`09ojS1j`03o`000?n/`^[o[<;Z00?o00001_n[`n/00ol0003o[/CZojk4jP09ojk4
jP03o`000?naa>So/LCX00[o/LCX00?o0000ok?4iol000000_l00008ok75j003o`000?nba>Oo//CW
00Wo//CW00?o0000ok?3i_nc`nH02_nc`nH3o`0000Wo/L7V00?o0000ooooooooool08_ooool000Wo
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooooooo`12ooooo`?o0000:_ooool2o`0000WoU[K]00?o0000oiNgk_nG]nh02?nG]nh0
0ol0003oVKS^oiVhkP03oiVhkPKo00002OnM^nh00ol0003oX;g]oj2mk@08oj2mk@03o`000?nT_ngo
Y;o]00[oY;o]00?o0000ojS1jonX`N/02?nX`N/3o`0000[oZl?[00?o0000ojk4j_n^a>X02On^a>X0
0ol0003o/LCXok74j009ok74j0;o00003?naaNP00ol0003o//CWok;4i`09ok;4i`03o`000?nc`nKo
/l?V00Ko/l?V0ol000000ona`^Oo0000ok71iP0:ok71iP03o`000?oooooooooo027ooooo0009oooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Oooooo00?o
0000ooooooooool0?oooool3o`0002kooooo0_l00009oiJfk@03o`000?nG]nkoUkO^00KoUkO^1ol0
0005oiZjkP03o`000?nM^nkoWK_^00SoWK_^00?o0000oj2mkOnP_Nd02?nP_Nd00ol0003oY;o]ojBo
k@0:ojBok@03o`000?nX`N_oZ<7[00CoZ<7[0ol000000onX`^co0000oj_3j`0;oj_3j`03o`000?n^
a>[o[/CZ00Wo[/CZ00?o0000ok74j?naa>P01_naa>P2o`000003ojo5j_l0003o/LGX00co/LGX00?o
0000ok;4ionba>L02Onba>L00ol0003o/l?Vok?3iP03ok?3iP;o00001Ona`^L00ol0003o/L7Vok71
iP08ok71iP;o00008_ooool000Wooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0
003o0000o`000?o<c<`01oooool00ol0003oooooooooo`0looooo`?o0000<_ooool2o`0000WoU[K]
00?o0000oiNgk_nG]nh01Ol00002oiVhkP03o`000?nJ^^koV[[^00SoV[[^00?o0000oifkk_nM^nh0
2?nM^nh00ol0003oX;g]oj2mk@08oj2mk@03o`000?nT_ngoY;o]00[oY;o]00?o0000ojS1jonX`N/0
0ol00005ojS2k003o`000?n[`n_oZl?[00[oZl?[00?o0000ojk4j_n^a>X02On^a>X00ol0003o/LCX
ok74j002ok74j0?o00001?n_aNX00ol0003o/LGXok75j00;ok75j003o`000?nba>Oo//CW00Wo//CW
00?o0000ok?3i_l000000_l00008ok72i`03o`000?na`NKo/L7V00So/L7V0_l0000Qooooo`002Ooo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4007ooooo`03
o`000?oooooooooo03Wooooo0ol0000fooooo`;o00001OnF]^d6o`0000SoVKS^00?o0000oiZjk_nJ
^^h02?nJ^^h00ol0003oWK_^oifkkP08oifkkP03o`000?nP_NgoX;g]00SoX;g]00?o0000ojBokOnT
_nd02?nT_nd4o`0000WoZ<;/00?o0000oj_3jon[`n/02_n[`n/00ol0003o[/CZojk4jP09ojk4jP04
o`000?naa>So0000o`0000So[lGZ00?o0000ok75j?naaNP02_naaNP00ol0003o//CWok;4i`09ok;4
i`;o00003?na`^L00ol0003o/L7Vok71iP08ok71iP03o`000?oooooooooo01oooooo0009ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000
ooooooooool0=oooool3o`0003[ooooo1_l00004oiRgk@03o`000?nI^>koVKS^00SoVKS^00?o0000
oiZjk_nJ^^h02?nJ^^h00ol0003oWK_^oifkkP08oifkkP03o`000?nP_NgoX;g]00SoX;g]00?o0000
ojBokOnT_nd01?nT_nd3o`0000;oYL7]00?o0000ojS2k?nX`^`02OnX`^`00ol0003oZl?[oj_3j`0:
oj_3j`03o`000?n^a>[o[/CZ00So[/CZ0_l0000;ojo5jP03o`000?naaNSo/LGX00[o/LGX00?o0000
ok;4ionba>L01_nba>L2o`000003ok34j?l0003o/L;W00_o/L;W00?o0000ok71i_na`NH02?na`NH2
o`00023ooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00Kooooo00?o0000ooooooooool0=?ooool3o`0003kooooo00?o0000oiRgkOnH]nd01onH
]nd00ol0003oVKS^oiVhkP08oiVhkP03o`000?nJ^^koV[[^00SoV[[^00?o0000oifkk_nM^nh02?nM
^nh00ol0003oX;g]oj2mk@08oj2mk@03o`000?nT_ngoY;o]00?o00001_nU`Nd00ol0003oZ<;/ojS2
k009ojS2k003o`000?n[`n_oZl?[00[oZl?[00?o0000ojk4j_n^a>X01?n^a>X3o`0000;o[LG[00?o
0000ojo5j_n_aNX02On_aNX00ol0003o/LGXok75j00:ok75j003o`000?nba>Oo//CW00;o//CW0ol0
0004ok34j003o`000?na`^Oo/L;W00[o/L;W00?o0000ok71i_na`NH02?na`NH2o`0001oooooo000T
ooooo`03o`000?oooooooooo037ooooo0ol00012ooooo`03o`000?nH]ngoV;O]00OoV;O]00?o0000
oiVhk_nI^>h02?nI^>h00ol0003oV[[^oiZjkP08oiZjkP03o`000?nM^nkoWK_^00SoWK_^00?o0000
oj2mkOnP_Nd01_nP_Nd4o`0000[oYL7]00?o0000ojS2k?nX`^`02OnX`^`00ol0003oZl?[oj_3j`0:
oj_3j`03o`000?n^a>[o[/CZ00?o00001_n]aN/00ol0003o[lGZojo5jP09ojo5jP03o`000?naaNSo
/LGX00[o/LGX00Co0000ok;4iol0003o00002?n`a>P00ol0003o/L;Wok72i`0:ok72i`03o`000?na
`NKo/L7V00So/L7V0_l0000Nooooo`009?ooool00ol0003oooooooooo`0_ooooo`;o0000A_ooool0
0ol0003oV;O]oiRgk@07oiRgk@03o`000?nI^>koVKS^00SoVKS^00?o0000oiZjk_nJ^^h02?nJ^^h0
0ol0003oWK_^oifkkP08oifkkP03o`000?nP_NgoX;g]00Go00000onR_nh00ol0003oYL7]ojG1k@09
ojG1k@03o`000?nX`^coZ<;/00WoZ<;/00?o0000oj_3jon[`n/02?n[`n/4o`0000[o[LG[00?o0000
ojo5j_n_aNX02On_aNX00ol0003o/LGXok75j008ok75j0?o00002on`a>P00ol0003o/L;Wok72i`09
ok72i`03o`000?na`NKo/L7V00So/L7V0_l0000Nooooo`009?ooool00ol0003oooooooooo`0/oooo
o`?o0000BOooool00ol0003oV;O]oiRgk@07oiRgk@03o`000?nI^>koVKS^00SoVKS^00?o0000oiZj
k_nJ^^h02?nJ^^h00ol0003oWK_^oifkkP06oifkkPCo00002OnR_nh00ol0003oYL7]ojG1k@09ojG1
k@03o`000?nX`^coZ<;/00WoZ<;/00?o0000oj_3jon[`n/01?n[`n/3o`0000;oZlC/00?o0000ojg5
jon]aN/02_n]aN/00ol0003o[lGZojo5jP09ojo5jP03o`000?naaNSo/LGX00Co/LGX0ol00002ojo5
jP03o`000?n`a>So/<CX00[o/<CX00?o0000ok72iona`^L02Ona`^L00ol0003o/L7Vok71iP04ok71
iP?o000000?o[/3Wo`000?l000007Oooool002Cooooo00?o0000ooooooooool0:Oooool3o`0004go
oooo00?o0000oiRgkOnH]nd01onH]nd00ol0003oVKS^oiVhkP08oiVhkP03o`000?nJ^^koV[[^00So
V[[^00?o0000oifkk_nM^nh01Ol00003oinmkP03o`000?nR_nkoX[o^00SoX[o^00?o0000ojG1kOnU
`Nd02OnU`Nd00ol0003oZ<;/ojS2k009ojS2k003o`000?n[`n_oZl?[00?o00001_n[a>`00ol0003o
[LG[ojg5j`0:ojg5j`03o`000?n_aN[o[lGZ00Wo[lGZ00?o0000ok75j?naaNP00ol00006ojo5jP03
o`000?n`a>So/<CX00[o/<CX00?o0000ok72iona`^L02Ona`^L00ol0003o/L7Vok71iP03o`0000Go
[/3W0_l0000Looooo`009?ooool00ol0003oooooooooo`0Vooooo`?o0000DOooool00ol0003oV;O]
oiRgk@07oiRgk@03o`000?nI^>koVKS^00SoVKS^00?o0000oiZjk_nJ^^h01_nJ^^h4o`0000WoWkg^
00?o0000oj:ok_nR_nh02?nR_nh00ol0003oYL7]ojG1k@09ojG1k@03o`000?nX`^coZ<;/00SoZ<;/
0ol0000:oj_4k003o`000?n]aN_o[LG[00[o[LG[00?o0000ojo5j_n_aNX02?n_aNX3o`0000[o[lGZ
00?o0000ok34j?n`a>P02_n`a>P00ol0003o/L;Wok72i`08ok72i`?o00002On^`>L2o`0001_ooooo
000Sooooo`;o00009Oooool3o`0005Gooooo00?o0000oiRgkOnH]nd01onH]nd00ol0003oVKS^oiVh
kP08oiVhkP03o`000?nJ^^koV[[^00Go00000onM^nh00ol0003oWkg^oinmkP08oinmkP03o`000?nR
_nkoX[o^00SoX[o^00?o0000ojG1kOnU`Nd02?nU`Nd2o`0000KoZ<;/0ol00002ojS3k@03o`000?n[
a>coZlC/00WoZlC/00?o0000ojg5jon]aN/02_n]aN/00ol0003o[lGZojo5jP04ojo5jP?o000000?o
[/G[o`000?n_aNX02on_aNX00ol0003o/<CXok34j00:ok34j003o`000?na`^Oo/L;W00Co/L;W0ol0
00000on]`^Wo0000ojk0i`0:ojk0i`03o`000?oooooooooo01Wooooo000Tooooo`03o`000?oooooo
oooo023ooooo0ol0001Iooooo`03o`000?nH]ngoV;O]00OoV;O]00?o0000oiVhk_nI^>h01_nI^>h4
o`0000WoWK_^00?o0000oinmk_nO_Nh02?nO_Nh00ol0003oX[o^oj:okP08oj:okP03o`000?nU`Ngo
YL7]00SoYL7]0_l00002ojS2k0?o00001_nX`nd00ol0003oZlC/oj_4k009oj_4k003o`000?n]aN_o
[LG[00[o[LG[00?o0000ojo5j_n_aNX00ol00005ojk5j`03o`000?n_aN[o[lGZ00[o[lGZ00?o0000
ok34j?n`a>P02_n`a>P00ol0003o/L;Wok72i`03o`0000Go[L;Y00?o0000ojk0ion^`>L02On^`>L0
0ol0003oooooooooo`0Hooooo`008oooool00ol0003oooooooooo`0Nooooo`?o0000GOooool00ol0
003oV;O]oiRgk@07oiRgk@03o`000?nI^>koVKS^00Go00000onK^Nd00ol0003oWK_^oifkkP08oifk
kP03o`000?nO_NkoWkg^00SoWkg^00?o0000oj:ok_nR_nh02?nR_nh00ol0003oYL7]ojG1k@08ojG1
k@?o00002_nX`nd00ol0003oZlC/oj_4k009oj_4k003o`000?n]aN_o[LG[00Wo[LG[0ol00009ojk5
j`03o`000?n_aN[o[lGZ00Wo[lGZ00?o0000ok34j?n`a>P02_n`a>P3o`0000Wo[L;Y00?o0000ojk0
ion^`>L02On^`>L00ol0003oooooooooo`0Gooooo`008oooool00ol0003oooooooooo`0Kooooo`?o
0000HOooool00ol0003oV;O]oiRgk@03oiRgk@Ko00002OnK^Nd00ol0003oWK_^oifkkP08oifkkP03
o`000?nO_NkoWkg^00SoWkg^00?o0000oj:ok_nR_nh02?nR_nh00ol0003oYL7]ojG1k@04ojG1k@?o
000000?oYL;^o`000?l000002onX`nd00ol0003oZlC/oj_4k009oj_4k003o`000?n]aN_o[LG[00Ko
[LG[0_l000000on/aNco0000ojk5j`0:ojk5j`03o`000?n_aN[o[lGZ00Wo[lGZ00?o0000ok34j?n`
a>P01_n`a>P3o`000003ojg3j_l0003o[L;Y00[o[L;Y00?o0000ojk0ion^`>L02?n^`>L2o`0001So
oooo000Sooooo`03o`000?oooooooooo01Sooooo0ol0001Uooooo`Go00001OnK^>`00ol0003oVkW]
oi^ik@08oi^ik@03o`000?nM^nkoWK_^00SoWK_^00?o0000oinmk_nO_Nh02?nO_Nh00ol0003oX[o^
oj:okP08oj:okP03o`000?nU`NgoYL7]00?o00001OnU`^h2o`0000_oZ<?]00?o0000oj_4k?n[a>`0
2On[a>`00ol0003o[LG[ojg5j`02ojg5j`?o00001?n/aN`00ol0003o[/G[ojk5j`09ojk5j`03o`00
0?n_aN[o[lGZ00Wo[lGZ00?o0000ok34j?n`a>P00on`a>P2o`0000Go[L?Z00?o0000ojg2jOn]`^T0
2On]`^T00ol0003o[/3Wojk0i`08ojk0i`03o`000?oooooooooo01Kooooo000Sooooo`03o`000?oo
oooooooo01Gooooo0ol0001Xooooo`03o`000?nK^>coVkS/00SoVkS/00?o0000oi^ikOnK^Nd02?nK
^Nd00ol0003oWK_^oifkkP08oifkkP03o`000?nO_NkoWkg^00SoWkg^00?o0000oj:ok_nR_nh01_nR
_nh4o`0000WoYL;^0_l0000;ojS3k@03o`000?n[a>coZlC/00WoZlC/00Co0000ojg5jol0003o0000
2?n/aN`00ol0003o[/G[ojk5j`09ojk5j`03o`000?n_aN[o[lGZ00Wo[lGZ00?o0000ok34j?l00000
0_l00008ojg3jP03o`000?n]`^Wo[L;Y00So[L;Y00?o0000ojk0ion^`>L02On^`>L00ol0003ooooo
ooooo`0Eooooo`008oooool00ol0003oooooooooo`0Booooo`?o0000K?ooool00ol0003oVkS/oi^h
k008oi^hk003o`000?nK^NgoVkW]00SoVkW]00?o0000oifkk_nM^nh02?nM^nh00ol0003oWkg^oinm
kP08oinmkP03o`000?nR_nkoX[o^00Go00000onS`>h00ol0003oYL;^ojG2kP08ojG2kP;o00002onX
`nd00ol0003oZlC/oj_4k008oj_4k0;o00002on/aN`00ol0003o[/G[ojk5j`09ojk5j`03o`000?n_
aN[o[lGZ00So[lGZ0_l0000<ojg3jP03o`000?n]`^Wo[L;Y00So[L;Y00?o0000ojk0ion^`>L02On^
`>L00ol0003oooooooooo`0Dooooo`008_ooool3o`00013ooooo0ol0001`ooooo`03o`000?nK^>co
VkS/00SoVkS/00?o0000oi^ikOnK^Nd02?nK^Nd00ol0003oWK_^oifkkP08oifkkP03o`000?nO_Nko
Wkg^00KoWkg^1?l00009oj?0kP03o`000?nU`^koYL;^00SoYL;^0_l0000;ojS3k@03o`000?n[a>co
ZlC/00CoZlC/0ol00002oj[5k@03o`000?n/aNco[<G/00Wo[<G/00?o0000ojk5jon^aN/02On^aN/0
0ol0003o[lGZojo5jP04ojo5jP?o00000_n/a>/00ol0003o[L?Zojg3jP0:ojg3jP03o`000?n]`^Wo
[L;Y00So[L;Y00?o0000ojk0ion^`>L01on^`>L3o`0001Gooooo000Sooooo`03o`000?oooooooooo
00cooooo0ol0001dooooo`03o`000?nK^>coVkS/00SoVkS/00?o0000oi^ikOnK^Nd02?nK^Nd00ol0
003oWK_^oifkkP08oifkkP03o`000?nO_NkoWkg^00Go00000onQ_^h00ol0003oXl3^oj?0kP08oj?0
kP03o`000?nU`^koYL;^00OoYL;^00?o0000ojG2k_l000002onX`nd00ol0003oZlC/oj_4k003o`00
00KoZ/G]00?o0000ojc5k?n/aN`02On/aN`00ol0003o[/G[ojk5j`09ojk5j`03o`000?n_aN[o[lGZ
00?o00001_n/a>/00ol0003o[L?Zojg3jP09ojg3jP03o`000?n]`^Wo[L;Y00Wo[L;Y00Co0000ojk0
ion^`>Oo[/3W1Ol00002ooooo`03o`000?oooooooooo01?ooooo000Sooooo`03o`000?oooooooooo
00Wooooo0ol0001hooooo`03o`000?nK^>coVkS/00SoVkS/00?o0000oi^ikOnK^Nd02?nK^Nd00ol0
003oWK_^oifkkP06oifkkPCo00002OnQ_^h00ol0003oXl3^oj?0kP08oj?0kP03o`000?nU`^koYL;^
00OoYL;^00?o0000ojG2k_l000002OnX`nd4o`0000[oZ/G]00?o0000ojc5k?n/aN`02On/aN`00ol0
003o[/G[ojk5j`08ojk5j`?o00002_n/a>/00ol0003o[L?Zojg3jP09ojg3jP03o`000?n]`^Wo[L;Y
00So[L;Y1_l00005ooooo`03o`000?oooooooooo01?ooooo000Sooooo`03o`000?oooooooooo00Ko
oooo0ol0001looooo`03o`000?nK^>coVkS/00SoVkS/00?o0000oi^ikOnK^Nd02?nK^Nd00ol0003o
WK_^oifkkP05o`0000;oWkc]00?o0000oj6nk_nQ_^h02OnQ_^h00ol0003oXl3^oj?0kP08oj?0kP03
o`000?nU`^koYL;^00OoYL;^00?o0000ojG2k_l000000onX`nd5o`0000;oZ<C^00?o0000oj[5kOnZ
aNd02_nZaNd00ol0003o[<G/ojc5k009ojc5k003o`000?n^aN_o[/G[00Co[/G[0ol000000on/aNco
0000ojc4j`0;ojc4j`03o`000?n]`n[o[L?Z00Wo[L?Z00?o0000ojg2jOn]`^T01?n]`^T6o`0000So
oooo00?o0000ooooooooool04oooool002;ooooo00?o0000ooooooooool01?ooool3o`00083ooooo
00?o0000oi^hk?nK^>`02?nK^>`00ol0003oVkW]oi^ik@06oi^ik@Co00002?nO_>d00ol0003oXKk^
oj6nkP09oj6nkP03o`000?nS`>koXl3^00SoXl3^00?o0000ojG2k_nU`^h01onU`^h5o`0000SoZ<C^
00?o0000oj[5kOnZaNd02_nZaNd00ol0003o[<G/ojc5k009ojc5k003o`000?n^aN_o[/G[00?o0000
1On/aN`00ol0003o[<C[ojc4j`0:ojc4j`03o`000?n]`n[o[L?Z00Wo[L?Z00?o0000ojg2jOn]`^T0
1Ol0000<ooooo`03o`000?oooooooooo01?ooooo000Rooooo`04o`000?ooooooooooooooo`?o0000
Q?ooool00ol0003oVkS/oi^hk008oi^hk003o`000?nK^NgoVkW]00Go00000onN^n`00ol0003oWkc]
oinlk@07oinlk@03o`000?nQ_^koXKk^00WoXKk^00?o0000oj?0k_nS`>h02?nS`>h00ol0003oYL;^
ojG2kP04ojG2kPCo000000?oYl?^o`000?nXa>h02OnXa>h00ol0003oZ/G]oj[5k@0:oj[5k@03o`00
0?n/aNco[<G/00So[<G/0ol00009ojc5k003o`000?n/a>_o[<C[00[o[<C[00?o0000ojg3j_n]`nX0
2?n]`nX5o`0000oooooo00?o0000ooooooooool04oooool002;ooooo1?l00028ooooo`03o`000?nK
^>coVkS/00KoVkS/1?l00009oijkk003o`000?nO_>goWkc]00OoWkc]00?o0000oj6nk_nQ_^h02OnQ
_^h00ol0003oXl3^oj?0kP08oj?0kP03o`000?nU`^koYL;^00?o00001?nW`nh00ol0003oYl?^o`00
000:ojS4kP03o`000?nZaNgoZ/G]00[oZ/G]00?o0000ojc5k?n/aN`01?n/aN`3o`000003oj_6kOl0
003o[<G/00[o[<G/00?o0000ojc4jon/a>/02_n/a>/00ol0003o[L?Zojg3jP04ojg3jPGo00004_oo
ool00ol0003oooooooooo`0Cooooo`008_ooool3o`0008[ooooo00?o0000oi^hk?nK^>`01Ol00003
oijij`03o`000?nN^ncoW[_/00SoW[_/00?o0000oinlkOnO_>d01onO_>d00ol0003oXKk^oj6nkP09
oj6nkP03o`000?nS`>koXl3^00KoXl3^1?l00008ojO3kP03o`000?nW`nko000000[oZ<C^00?o0000
oj[5kOnZaNd02_nZaNd00ol0003o[<G/ojc5k003o`0000GoZlK]00?o0000ojc5k?n/aN`02On/aN`0
0ol0003o[<C[ojc4j`0:ojc4j`03o`000?n]`n[o[L?Z00Co00005oooool00ol0003oooooooooo`0B
ooooo`009?ooool00ol0003oooooooooo`29ooooo`;o00002OnN^N/00ol0003oW[_/oijkk008oijk
k003o`000?nO_>goWkc]00OoWkc]00?o0000oj6nk_nQ_^h02OnQ_^h00ol0003oXl3^oj?0kP05o`00
00?oYL;^00?o0000ojO3k_nW`nh01_nW`nh01?l0003oYl?^ojO3k_l0000:ojS4kP03o`000?nZaNgo
Z/G]00SoZ/G]1?l00009oj_6k@03o`000?n/aNco[<G/00Wo[<G/00?o0000ojc4jon/a>/02?n/a>/5
o`0001[ooooo00?o0000ooooooooool04_ooool001Kooooo00?ok^k^o`000?l000000_l000000ol@
413oooooooooo`07ooooo`03o`000?oooooooooo08Wooooo00?o0000oijijonN^N/02?nN^N/00ol0
003oW[_/oijkk008oijkk003o`000?nO_>goWkc]00OoWkc]00?o0000oj6nk_nQ_^h02?nQ_^h3o`00
00WoYL;^00?o0000ojO3k_nW`nh01_nW`nh01?l0003oYl?^ojO3k_l0000:ojS4kP03o`000?nZaNgo
Z/G]00CoZ/G]0ol00003oj[5kP03o`000?n[a^goZlK]00SoZlK]00?o0000ojc5k?n/aN`02On/aN`0
0ol0003o[<C[ojc4j`04ojc4j`Go00007Oooool00ol0003oooooooooo`0Booooo`005_ooool01Omg
MgOoV9RHooooool0003oMgMg00_ooooo00?o0000ooooooooool0ROooool00ol0003oW[W[oijij`08
oijij`03o`000?nN^ncoW[_/00SoW[_/00?o0000oinlkOnO_>d01onO_>d00ol0003oXKk^oj6nkP04
oj6nkP?o00000_nT`>d00ol0003oYL;^ojG2kP08ojG2kP03o`000?nW`nkoYl?^00KoYl?^00Co0000
ojO3k_nW`nko00002_nXa>h00ol0003oZ/G]oj[5k@03o`0000OoZ/G^00?o0000oj_6kOn[a^d02?n[
a^d00ol0003o[<G/ojc5k009ojc5k003o`000?n/a>_o[<C[00Co00008Oooool00ol0003ooooooooo
o`0Booooo`005_ooool01Ol@413oooooooooool0003o410@00cooooo00?o0000ooooooooool0ROoo
ool00ol0003oW[W[oijij`08oijij`03o`000?nN^ncoW[_/00SoW[_/00?o0000oinlkOnO_>d01onO
_>d00ol0003oXKk^oj6nkP03o`0000KoY<3]00?o0000ojG2k_nU`^h02?nU`^h00ol0003oYl?^ojO3
kP06ojO3kP04o`000?nW`nkoYl?^o`0000SoZ<C^1?l0000;oj[5kP03o`000?n[a^goZlK]00SoZlK]
00?o0000ojc5k?n/aN`02?n/aN`4o`0002Cooooo00?o0000ooooooooool04_ooool001Kooooo00?o
0000ooooooooool00_l0000=ooooo`03o`000?oooooooooo08Wooooo00?o0000oijijonN^N/02?nN
^N/00ol0003oW[_/oijkk008oijkk003o`000?nO_>goWkc]00GoWkc]1?l0000:ojC0k@03o`000?nU
`^koYL;^00SoYL;^00?o0000ojO3k_nW`nh01_nW`nh01?l0003oYl?^ojO3k_l00002ojS4kPGo0000
1?nYaNh00ol0003oZ/G^oj[5kP09oj[5kP03o`000?n[a^goZlK]00SoZlK]00?o0000ojc5k?n/aN`0
1?n/aN`4o`0002Oooooo00?o0000ooooooooool04_ooool001Kooooo00?o0000ooooooooool00_l0
000>ooooo`03o`000?oooooooooo08Wooooo00?o0000oijijonN^N/02?nN^N/00ol0003oW[_/oijk
k008oijkk003o`000?nO_>goWkc]00Co00001?nS_^`00ol0003oY<3]ojC0k@08ojC0k@03o`000?nU
`^koYL;^00SoYL;^00?o0000ojO3k_nW`nh01_nW`nh00ol0003oYl?^o`000002o`0000[oZLG^00?o
0000oj[5k_nZaNh02OnZaNh00ol0003oZlK]oj_6k@08oj_6k@03o`000?n/aNco[<G/00Co0000:_oo
ool00ol0003oooooooooo`0Booooo`005_ooool01Ol@413oooooooooool0003o410@00oooooo00?o
0000ooooooooool0ROooool00ol0003oW[W[oijij`08oijij`03o`000?nN^ncoW[_/00KoW[_/1?l0
0009oj>nk003o`000?nT`>goY<3]00SoY<3]00?o0000ojG2k_nU`^h02?nU`^h00ol0003oYl?^ojO3
kP04ojO3kP?o00000_nXa>h00ol0003oZLG^ojW5kP09ojW5kP03o`000?nZaNkoZ/G^00WoZ/G^00?o
0000oj_6kOn[a^d01_n[a^d4o`0002kooooo00?o0000ooooooooool04_ooool001Kooooo00GoMgMg
oiRHV?oooooo0000ogMgM`0@ooooo`;o0000R_ooool00ol0003oW[W[oijij`08oijij`03o`000?nN
^ncoW[_/00Go00000onR_>/00ol0003oXkk/oj>nk008oj>nk003o`000?nT`>goY<3]00SoY<3]00?o
0000ojG2k_nU`^h02?nU`^h00ol0003oYl?^ojO3kP03o`0000?oZ<C^00Co0000ojS4k_nXa>ko0000
2onYaNh00ol0003oZ/G^oj[5kP09oj[5kP03o`000?n[a^goZlK]00Ko0000<Oooool00ol0003ooooo
ooooo`0Booooo`005_ooool01Oo^k^ko0`<3o`000?l0003ok^k^01;ooooo00?o0000ooooooooool0
R?ooool00ol0003oW[W[oijij`06oijij`Co00002OnR_>/00ol0003oXkk/oj>nk008oj>nk003o`00
0?nT`>goY<3]00SoY<3]00?o0000ojG2k_nU`^h01onU`^h3o`0000KoZ<C^00Go0000ojS4k_nXa>ko
Z<C^o`00000;ojW5kP03o`000?nZaNkoZ/G^00SoZ/G^1_l0000dooooo`03o`000?oooooooooo01;o
oooo000/ooooo`03o`000?oooooo000008[ooooo00?o0000oijijonN^N/01Ol00002oj:jjP03o`00
0?nR_>_oX[c[00WoX[c[00?o0000oj>nk?nS_^`02?nS_^`00ol0003oY<3]ojC0k@08ojC0k@03o`00
0?nU`^koYL;^00?oYL;^0ol00002ojO3k@03o`000?nXa>koZ<C^00GoZ<C^00Go0000ojS4k_nXa>ko
Z<C^o`00000;ojW5kP03o`000?nZaNkoZ/G^00CoZ/G^1Ol0000hooooo`03o`000?oooooooooo01;o
oooo000_ooooo`03o`000?oooooooooo08Sooooo0_l00008oj:jjP03o`000?nR_>_oX[c[00WoX[c[
00?o0000oj>nk?nS_^`02?nS_^`00ol0003oY<3]ojC0k@08ojC0k@03o`000?nU`^ko000000;o0000
1_nW`nd00ol0003oZ<C^ojS4kP05ojS4kP05o`000?nXa>koZ<C^ojS4k_l000002onYaNh00ol0003o
Z/G^oj[5kP05o`0003cooooo00?o0000ooooooooool04Oooool0033ooooo00?o0000ooooooooool0
Qoooool2o`0000WoX[[Z00?o0000oj:ljonR_>/02OnR_>/00ol0003oXkk/oj>nk008oj>nk003o`00
0?nT`>goY<3]00KoY<3]0ol0000:ojO3k@03o`000?nXa>koZ<C^00GoZ<C^00Go0000ojS4k_nXa>ko
Z<C^o`00000:ojW5kPGo0000?oooool00ol0003oooooooooo`0Aooooo`00<Oooool00ol0003ooooo
ooooo`27ooooo`;o00002OnR^^X00ol0003oX[c[oj:lj`09oj:lj`03o`000?nS_^coXkk/00SoXkk/
00?o0000ojC0kOnT`>d01Ol00003ojO1k003o`000?nW`ngoYl?]00SoYl?]00?o0000ojS4k_nXa>h0
1OnXa>h01Ol0003oZ<C^ojS4k_nXa>ko000000KoZLG^1?l00013ooooo`03o`000?oooooooooo017o
oooo000booooo`03o`000?oooooooooo08Oooooo0_l00009oj:jjP03o`000?nR_>_oX[c[00WoX[c[
00?o0000oj>nk?nS_^`01_nS_^`4o`0000WoYl7/00?o0000ojO3kOnW`nd02?nW`nd00ol0003oZ<C^
ojS4kP05ojS4kP05o`000?nXa>koZ<C^ojS4k_l000000_nYaNh4o`0004Kooooo00?o0000oooooooo
ool04Oooool003?ooooo00?o0000ooooooooool0Qoooool2o`0000WoX[[Z00?o0000oj:ljonR_>/0
2OnR_>/00ol0003oXkk/oj>nk005o`0000?oY[o[00?o0000ojO1k?nW`N`02?nW`N`00ol0003oYl?]
ojO3k@08ojO3k@03o`000?nXa>koZ<C^00GoZ<C^00?o0000ojS4k_nXa>h01?l00019ooooo`03o`00
0?oooooooooo017ooooo000dooooo`;o0000R?ooool2o`0000WoX[[Z00?o0000oj:ljonR_>/02?nR
_>/3o`0000WoY[o[00?o0000ojO1k?nW`N`02?nW`N`00ol0003oYl?]ojO3k@08ojO3k@03o`000?nX
a>koZ<C^00CoZ<C^0ol0001=ooooo`03o`000?oooooooooo017ooooo000fooooo`03o`000?oooooo
oooo08Kooooo0_l00009oj:jjP03o`000?nR_>_oX[c[00CoX[c[0ol000000onV_N[o0000ojJoj`0:
ojJoj`03o`000?nW`NcoYl7/00SoYl7/00?o0000ojO3kOnW`nd02?nW`nd00ol0003oZ<C^ojS4kP03
o`000003ooooool0003ooooo04gooooo00?o0000ooooooooool04Oooool003Oooooo0_l00027oooo
o`;o00002OnR^^X00ol0003oX[c[oj:lj`03o`0000GoY[gZ00?o0000ojJojonV_n/02OnV_n/00ol0
003oYl7/ojO1k008ojO1k003o`000?nW`ngoYl?]00KoYl?]1?l00005ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool04Oooool003Kooooo00?o0000ooooool00000R?ooool2o`0000Oo
X[[Z1?l00009ojJmjP03o`000?nV_n_oY[o[00WoY[o[00?o0000ojO1k?nW`N`02?nW`N`00ol0003o
Yl?]ojO3k@05o`0000[ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Aooooo`00
>Oooool00ol0003oooooooooo`26ooooo`;o00000_nR^^X4o`0000?oY[_X00?o0000ojJmj_nV_NX0
2?nV_NX00ol0003oY[o[ojJoj`09ojJoj`03o`000?nW`NcoYl7/00OoYl7/1Ol0000>ooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool04Oooool003[ooooo00?o0000ooooooooool0Q_oo
ool3o`0000SoY[_X00?o0000ojJmj_nV_NX02?nV_NX00ol0003oY[o[ojJoj`09ojJoj`03o`000?nW
`NcoYl7/00?oYl7/1Ol0000Booooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool04Ooo
ool003_ooooo00?o0000ooooooooool0Q_ooool00ol0003oY[_XojJkj008ojJkj003o`000?nV_N[o
Y[gZ00SoY[gZ00?o0000ojJojonV_n/02OnV_n/00ol0003oYl7/o`000003o`0001Oooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`0@ooooo`00??ooool00ol0003oooooooooo`26oooo
o`03o`000?nV^nSoY[_X00SoY[_X00?o0000ojJmj_nV_NX02?nV_NX00ol0003oY[o[ojJoj`08ojJo
j`?o00006oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo013ooooo000mooooo`;o
0000Qoooool00ol0003oY[_XojJkj008ojJkj003o`000?nV_N[oY[gZ00SoY[gZ00?o0000ojJojonV
_n/01?nV_n/3o`0001oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0@ooooo`00
?oooool00ol0003oooooooooo`25ooooo`03o`000?nV^nSoY[_X00SoY[_X00?o0000ojJmj_nV_NX0
2?nV_NX00ol0003oY[o[ojJoj`03o`0002;ooooo00?o0000ooooooooool0A_ooool00ol0003ooooo
ooooo`0@ooooo`00@?ooool00ol0003oooooooooo`25ooooo`03o`000?nV^nSoY[_X00SoY[_X00?o
0000ojJmj_nV_NX01_nV_NX4o`0002Kooooo00?o0000ooooooooool0AOooool00ol0003ooooooooo
o`0@ooooo`00@Oooool2o`0008Kooooo00?o0000ojJkj?nV^nP02?nV^nP00ol0003oY[gZojJmjP05
o`0002_ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0@ooooo`00@?ooool00ol0
003oooooo`000027ooooo`03o`000?nV^nSoY[_X00OoY[_X1Ol0000_ooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool04?ooool004?ooooo00?o0000ooooooooool0QOooool00ol0003o
Y[_XojJkj003ojJkj0Co0000=?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo013o
oooo0014ooooo`03o`000?oooooooooo08Gooooo00?o0000ojJkj?l000000ol0000hooooo`03o`00
0?oooooooooo047ooooo00?o0000ooooooooool04?ooool004Gooooo00?o0000ooooooooool0QOoo
ool2o`0003cooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0@ooooo`00A_ooool2
o`0008Gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0oooooo`03o`000?oooooo
oooo013ooooo0018ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo00oooooo0019ooooo`03o`000?oooooooooo087o
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oo
oooo001:ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo00oooooo001:ooooo`;o0000POooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool03oooool004cooooo00?o0000
ooooooooool0O_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool03oooool004gooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03oooool004kooooo00?o0000oooooooo
ool0O?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool03oooool004oooooo0_l0001looooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`0?ooooo`00DOooool00ol0003oooooooooo`1iooooo`03o`000?oo
oooooooo04?ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0?ooooo`00D_ooool0
0ol0003oooooooooo`1hooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`0?ooooo`00Doooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0?ooooo`00E?ooool3o`0007Ko
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00oo
oooo001Dooooo`;o0000Moooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool03_ooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Sooooo00?o0000ooooooooool0M?ooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03_ooool003Sooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`08ooooo`03
o`000?oooooooooo07?ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo00kooooo000hooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003o
ooooooooo`08ooooo`;o0000Loooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool03_ooool003Sooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo00_ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool03_ooool003Sooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03Oooool00ol0003oooooooooo`1_oooo
o`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0>oooo
o`00>?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`1^ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0>ooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo04gooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`0>ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l0000@ooooo`;o0000K_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool03_ooool005oooooo00?o0000ooooooooool0Joooool00ol0003o
ooooooooo`1?ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool03_ooool0063ooooo
00?o0000ooooooooool0J_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool03_ooool0067ooooo0_l0001Zooooo`03o`000?oooooooooo053ooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`0=ooooo`00Hoooool00ol0003oooooooooo`1W
ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0=
ooooo`00I?ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo05;ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0=ooooo`00IOooool00ol0003oooooooooo`1Uooooo`03
o`000?oooooooooo05?ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0=ooooo`00
I_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0=ooooo`00I_ooool3o`0006Cooooo00?o0000ooooooooool0EOoo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00gooooo001Xooooo`03o`000?oooooo
oooo06;ooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00gooooo001Yooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0Eoooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo00gooooo001Zooooo`;o0000HOooool00ol0003o
ooooooooo`1Gooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03Oooool006cooooo
00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool03Oooool006gooooo00?o0000ooooooooool0GOooool00ol0003ooooooooo
o`1Iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03Oooool006kooooo00?o0000
ooooooooool0G?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool03?ooool006oooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`1Koooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03?ooool006oooooo0ol0001Kooooo`03
o`000?oooooooooo05cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0<ooooo`00
LOooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0<ooooo`00L_ooool00ol0003oooooooooo`1Hooooo`03o`000?oo
oooooooo05gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0<ooooo`00Loooool2
o`0005Sooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo00cooooo001eooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0Goooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00cooooo001fooooo`03o`000?oooooooooo05Co
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00co
oooo001gooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0HOooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo00cooooo001hooooo`;o0000Doooool00ol0003ooooooooo
o`1Rooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03?ooool007Sooooo0_l0001C
ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0<
ooooo`00N_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo06Cooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0<ooooo`00Noooool00ol0003oooooooooo`1?ooooo`03
o`000?oooooooooo06Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0;ooooo`00
O?ooool2o`0004oooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo00_ooooo001nooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0I_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo001oooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00_ooooo0020ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0J?ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00_ooooo0021ooooo`?o0000BOooool00ol0003o
ooooooooo`1Yooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02oooool007Kooooo
1?l000000ol@413oooooooooo`05ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
J_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo001hooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1[ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool02oooool007Sooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`16ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0;ooooo`00N?ooool00ol0003oooooooooo`0:ooooo`;o0000A_ooool00ol0
003oooooooooo`1/ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02oooool005co
oooo0ol000000ol@413oooooooooo`0Fooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0@oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool02oooool005kooooo00?o410@okZj^_ooool05oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00[ooooo001Nooooo`03oiRHV?lb<S;ooooo01Oooooo00?o0000ooooooooool03_oo
ool2o`0004;ooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00[ooooo001Nooooo`03omgMgOl0003o^[Zj01Gooooo00?oEEEEofIVI_l000004?ooool2
o`0004;ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00[ooooo001Nooooo`03oeEEEOmgMgOoA4A402[ooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02_ooool005go
oooo00GogMgMoa0@4?oooooo8B4QomgMg@0Zooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo001Mooooo`05
ofIVI_n7QhOooooooiRHV?mEEED0:oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`00G?ooool00oo^k^ko
0000onk^kP02ooooo`03o`000?oMgMgooooo02[ooooo0_l0000mooooo`03o`000?oooooooooo07?o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`00G?ooool01?l@413o0000
o`000?ooool2o`000003oa0@4?oooooooooo02_ooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`1dooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool0097ooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02_ooool0097ooooo0_l0000jooooo`03o`000?oooooooooo07Kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`00Toooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`00U?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo07Sooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`00UOooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`00
U_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`00Uoooool2o`0003Cooooo00?o0000ooooooooool0N_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo002Iooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Wooooo002Iooooo`?o0000<Oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02Oooool009_ooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`1mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool009cooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02Oooool009gooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool009kooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02Oooool009oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`20oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00:3ooooo0_l0000[ooooo`03
o`000?oooooooooo087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`00
XOooool2o`0002[ooooo00?o0000ooooooooool0P_ooool01Ol0003ooooooooooooooooo000000[o
oooo002Sooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Poooool01?l0003ooooo
ooooool0000:ooooo`00Y?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo08Cooooo
00?o0000ooooool000002_ooool00:Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`25ooooo`;o00002_ooool00:Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`24
ooooo`?o00002_ooool00:Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`20oooo
o`Co00003Oooool00:Sooooo00Co0000ooooool0003o00008Oooool00ol0003oooooooooo`1loooo
o`Co00004Oooool008kooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Kooooo0_l0000Rooooo`03o`000?oooooooooo07Sooooo1?l0000Eoooo
o`00T?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`07ooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0M?ooool4o`0001Wooooo002@ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo073ooooo1?l0000Mooooo`00T?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo00Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1]ooooo`?o00008Ooo
ool0093ooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00_ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`1Yooooo`Co00009?ooool0093ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0IOooool4o`0002Sooooo002@ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03oooool3o`0001[ooooo00?o0000ooooooooool0HOooool4o`0002cooooo002>ooooo`03
oeEEEOmVIVKo000000gooooo1?l0000>ooooo`;o00006oooool00ol0003oooooooooo`1Mooooo`Co
0000<?ooool00;;ooooo0_l0000Iooooo`03o`000?oooooooooo05Wooooo1?l0000dooooo`00]?oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo05Gooooo1?l0000hooooo`00]Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo057ooooo1?l0000looooo`00]_ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo04gooooo1?l00010ooooo`00]oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo04Wooooo1?l00014ooooo`00^?ooool2o`0001?ooooo
00?o0000ooooooooool0AOooool4o`0004Sooooo002iooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0@Oooool4o`0004cooooo002jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0?_ooool3o`00053ooooo002kooooo`;o00004?ooool00ol0003oooooooooo`0joooo
o`Co0000Doooool00;gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0fooooo`Co
0000Eoooool00;kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0booooo`Co0000
Foooool00;oooooo0_l0000<ooooo`03o`000?oooooooooo02kooooo1?l0001Oooooo`00_oooool2
o`0000cooooo00?o0000ooooooooool0:_ooool4o`0006?ooooo0031ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool09_ooool4o`0006Oooooo0032ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool08_ooool4o`0006_ooooo0033ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool07_ooool4o`0006oooooo0034ooooo`;o00001oooool00ol0003ooooooooo
o`0Jooooo`Co0000Loooool00<Kooooo0ol00004ooooo`03o`000?oooooooooo01Kooooo1?l0001g
ooooo`00a_ooool2o`0000Gooooo00?o0000ooooooooool04oooool3o`0007_ooooo0038ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool4o`0007kooooo0039ooooo`05o`00
0?ooooooooooooooool000003Oooool4o`0008;ooooo003:ooooo`04o`000?ooooooooooo`0000Wo
oooo1?l00026ooooo`00boooool00ol0003oooooo`000005ooooo`Co0000R_ooool00<cooooo1ol0
002>ooooo`00`_ooool5o`0000Kooooo0_l0002Booooo`00`_ooool01OnHV9So8B4Qonk^k_oooooo
A4A409[ooooo0033ooooo`03oiRHV?lQ8B7ok^k^09_ooooo0034ooooo`03oiRHV?lQ8B7ok^k^09[o
oooo0035ooooo`03ogMgMomVIVKooooo09Wooooo0036ooooo`03o`000?oooooooooo09Sooooo0032
ooooo`05o`000?nj^[[ooooooiRHV?l@4100V_ooool00<;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c02Jooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00oooo
oomRooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00oooo
oomRooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00YOooool3o`000003oa0@
4?oooooooooo0;Kooooo002Cooooo`;o00002oooool00ol0003o^[Zjooooo`04ooooo`03oa0@4?nj
^[[ooooo00Gooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0VOoo
ool009?ooooo00?o0000ooooooooool02_ooool2oc8b<PGooooo00?oV9RHoc8b<_ooool01Oooool2
oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<Y[ooooo0028ooooo`05oa0@4?l0003o0000
o`000?l@41001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0
003o^[Zj00Cooooo00?ogMgMo`000?nj^[X01Oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0
003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`03ooooo`03ohN7Qol0003o^[Zj00Gooooo
00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo00Co410@o`000?m4A4Coc<c<L_ooool008[ooooo00?o0000ooooooooool01_ooool02_l0
003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Co
oooo00?oEEEEogMgMom4A4@01Oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMg
Mol@41001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko410@okZj
^_o^k^koMgMgoa0@4?ooool6o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1_ooool00onHV9So410@omgMg@1aooooo`00R_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00CogMgMo`000?l@413oc<c<2_ooool01OoMgMgo410@oooooolQ8B7ogMgM00_o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_o
oooo00Go410@oooooooooooooooooa0@400>ooooo`03ohN7QomEEEGooooo073ooooo002:ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h:oooo
o`05ofIVI_n7QhOooooooiRHV?mEEED02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00oooool6o`0000;ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05olc<c?lQ8B7o0000oeEEEOl00000LOooool008[ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<PWooooo00?ok^k^o`000?o^k^h0
0_ooool00ol0003ogMgMooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000002oooool01OlQ8B7o
QhN7oooooonHV9So0000077ooooo0027ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool01_ooool00ol@413o0000o`000003o`0000Gooooo00?o
0000ooooooooool02Oooool00ol@413o0000o`000003o`0000[ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool00000LOooool008Oooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05ob4Q8OnHV9SoooooogMgMomEEED0LOooool008Oooooo1ol00005oooo
o`;o00008Oooool00ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003oooooooooo`0;oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo<c<co410@o`000?lb<S;ok^k^077ooooo003o
ooooof;ooooo003oooooof;ooooo003oooooof;ooooo0000\
\>"],
  ImageRangeCache->{{{0, 352.438}, {392.188, 0}} -> {-0.0365789, -0.0401404, \
0.00334761, 0.00334761}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11253 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.066106 1.21212 -1.11022e-16 1.21212 [
[.5 1.12503 -41 0 ]
[.5 1.12503 41 24.5 ]
[.03831 .17557 -5.85635 -9 ]
[.03831 .17557 .14365 0 ]
[.12814 .13981 -17.2021 -9 ]
[.12814 .13981 .79789 0 ]
[.22015 .10319 -16.8352 -9 ]
[.22015 .10319 1.16484 0 ]
[.31441 .06568 -16.4682 -9 ]
[.31441 .06568 1.53178 0 ]
[.411 .02725 -16.1013 -9 ]
[.411 .02725 1.89873 0 ]
[.51 -0.01213 -5.24477 -9 ]
[.51 -0.01213 .75523 0 ]
[.21792 .02683 -9.25094 -12 ]
[.21792 .02683 .74906 0 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[.1484 .76875 -18 -3.08128 ]
[.1484 .76875 0 5.91872 ]
[.29382 .89692 -6 -3.18183 ]
[.29382 .89692 0 5.81817 ]
[.42456 1.01215 -18 -3.26907 ]
[.42456 1.01215 0 5.73093 ]
[.54272 1.11629 -6 -3.34548 ]
[.54272 1.11629 0 5.65452 ]
[.22112 .91822 -10 -4.24244 ]
[.22112 .91822 0 7.75756 ]
[.03467 .19213 -6 -2.71522 ]
[.03467 .19213 0 6.28478 ]
[.02559 .27239 -18 -2.7611 ]
[.02559 .27239 0 6.2389 ]
[.01617 .35567 -18 -2.80881 ]
[.01617 .35567 0 6.19119 ]
[.00638 .44212 -18 -2.85847 ]
[.00638 .44212 0 6.14153 ]
[-0.00378 .53194 -18 -2.9102 ]
[-0.00378 .53194 0 6.0898 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 1.11253 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.12503 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
.04875 .18654 m
.0558 .18375 L
s
[(0)] .03467 .19213 1 -0.39662 Mshowa
.03972 .26693 m
.04679 .2642 L
s
[(0.2)] .02559 .27239 1 -0.38642 Mshowa
.03035 .35034 m
.03744 .34767 L
s
[(0.4)] .01617 .35567 1 -0.37582 Mshowa
.02062 .43693 m
.02774 .43433 L
s
[(0.6)] .00638 .44212 1 -0.36478 Mshowa
.01051 .52689 m
.01765 .52437 L
s
[(0.8)] -0.00378 .53194 1 -0.35329 Mshowa
0 .62042 m
.00717 .61797 L
s
[(1)] -0.01434 .62532 1 -0.3413 Mshowa
.125 Mabswid
.04653 .20636 m
.05076 .2047 L
s
.04428 .22637 m
.04851 .22471 L
s
.04201 .24656 m
.04625 .24491 L
s
.03741 .28749 m
.04165 .28587 L
s
.03508 .30825 m
.03933 .30663 L
s
.03272 .32919 m
.03698 .32759 L
s
.02795 .37168 m
.03221 .37009 L
s
.02553 .39322 m
.02979 .39164 L
s
.02309 .41497 m
.02735 .4134 L
s
.01813 .45909 m
.0224 .45755 L
s
.01561 .48147 m
.01989 .47994 L
s
.01307 .50407 m
.01736 .50255 L
s
.00792 .54993 m
.01221 .54843 L
s
.00531 .5732 m
.0096 .5717 L
s
.00267 .59669 m
.00696 .59521 L
s
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
.5561 .7194 m
.04875 .18654 L
s
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.5561 .7194 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
0 0 m
1 0 L
1 1.11253 L
0 1.11253 L
closepath
clip
newpath
.5 Mabswid
.654 .735 .909 r
.52593 .68772 .5561 .7194 .58394 .7109 .55403 .67985 Metetra
.655 .741 .913 r
.55403 .67985 .58394 .7109 .61197 .70234 .58232 .67187 Metetra
.655 .746 .917 r
.58232 .67187 .61197 .70234 .64019 .69372 .61083 .66376 Metetra
.657 .751 .92 r
.61083 .66376 .64019 .69372 .66861 .68504 .63955 .65546 Metetra
.658 .756 .922 r
.63955 .65546 .66861 .68504 .69723 .6763 .66847 .64695 Metetra
.661 .76 .923 r
.66847 .64695 .69723 .6763 .72605 .6675 .6976 .63821 Metetra
.663 .762 .924 r
.6976 .63821 .72605 .6675 .75507 .65863 .72693 .62921 Metetra
.666 .764 .923 r
.72693 .62921 .75507 .65863 .7843 .6497 .75646 .61996 Metetra
.668 .764 .922 r
.75646 .61996 .7843 .6497 .81374 .64071 .7862 .61044 Metetra
.671 .763 .92 r
.7862 .61044 .81374 .64071 .84339 .63166 .81614 .60069 Metetra
.673 .76 .916 r
.81614 .60069 .84339 .63166 .87325 .62254 .84628 .59071 Metetra
.674 .757 .913 r
.84628 .59071 .87325 .62254 .90333 .61335 .87663 .58054 Metetra
.675 .753 .909 r
.87663 .58054 .90333 .61335 .93362 .6041 .90718 .57022 Metetra
.676 .748 .905 r
.90718 .57022 .93362 .6041 .96413 .59478 .93794 .55978 Metetra
.643 .732 .913 r
.49498 .6552 .52593 .68772 .55403 .67985 .52332 .64792 Metetra
.644 .737 .917 r
.52332 .64792 .55403 .67985 .58232 .67187 .55188 .64049 Metetra
.646 .742 .92 r
.55188 .64049 .58232 .67187 .61083 .66376 .58067 .63285 Metetra
.648 .748 .922 r
.58067 .63285 .61083 .66376 .63955 .65546 .60967 .62491 Metetra
.652 .753 .923 r
.60967 .62491 .63955 .65546 .66847 .64695 .63889 .6166 Metetra
.657 .757 .924 r
.63889 .6166 .66847 .64695 .6976 .63821 .66833 .6079 Metetra
.662 .761 .923 r
.66833 .6079 .6976 .63821 .72693 .62921 .69798 .59876 Metetra
.667 .763 .922 r
.69798 .59876 .72693 .62921 .75646 .61996 .72782 .58916 Metetra
.672 .764 .919 r
.72782 .58916 .75646 .61996 .7862 .61044 .75787 .57913 Metetra
.676 .763 .916 r
.75787 .57913 .7862 .61044 .81614 .60069 .78811 .56868 Metetra
.68 .762 .913 r
.78811 .56868 .81614 .60069 .84628 .59071 .81855 .55786 Metetra
.683 .759 .909 r
.81855 .55786 .84628 .59071 .87663 .58054 .84918 .54673 Metetra
.685 .755 .905 r
.84918 .54673 .87663 .58054 .90718 .57022 .88 .53535 Metetra
.686 .751 .901 r
.88 .53535 .90718 .57022 .93794 .55978 .91103 .52381 Metetra
.632 .728 .917 r
.4632 .62183 .49498 .6552 .52332 .64792 .49179 .61505 Metetra
.634 .733 .92 r
.49179 .61505 .52332 .64792 .55188 .64049 .52061 .6081 Metetra
.637 .739 .922 r
.52061 .6081 .55188 .64049 .58067 .63285 .54967 .60085 Metetra
.641 .744 .923 r
.54967 .60085 .58067 .63285 .60967 .62491 .57896 .5932 Metetra
.647 .749 .924 r
.57896 .5932 .60967 .62491 .63889 .6166 .60848 .58505 Metetra
.654 .754 .923 r
.60848 .58505 .63889 .6166 .66833 .6079 .63822 .57635 Metetra
.661 .758 .922 r
.63822 .57635 .66833 .6079 .69798 .59876 .66818 .56705 Metetra
.668 .761 .92 r
.66818 .56705 .69798 .59876 .72782 .58916 .69834 .55712 Metetra
.675 .762 .916 r
.69834 .55712 .72782 .58916 .75787 .57913 .72871 .54657 Metetra
.681 .763 .913 r
.72871 .54657 .75787 .57913 .78811 .56868 .75926 .53546 Metetra
.687 .762 .909 r
.75926 .53546 .78811 .56868 .81855 .55786 .79001 .52384 Metetra
.69 .76 .905 r
.79001 .52384 .81855 .55786 .84918 .54673 .82094 .51179 Metetra
.693 .757 .901 r
.82094 .51179 .84918 .54673 .88 .53535 .85206 .49942 Metetra
.694 .753 .897 r
.85206 .49942 .88 .53535 .91103 .52381 .88337 .48685 Metetra
.623 .725 .92 r
.43058 .58756 .4632 .62183 .49179 .61505 .4594 .58117 Metetra
.625 .73 .922 r
.4594 .58117 .49179 .61505 .52061 .6081 .48847 .57456 Metetra
.629 .735 .923 r
.48847 .57456 .52061 .6081 .54967 .60085 .5178 .5676 Metetra
.635 .74 .924 r
.5178 .5676 .54967 .60085 .57896 .5932 .54737 .56015 Metetra
.642 .745 .923 r
.54737 .56015 .57896 .5932 .60848 .58505 .57719 .5521 Metetra
.651 .75 .922 r
.57719 .5521 .60848 .58505 .63822 .57635 .60723 .54335 Metetra
.66 .754 .92 r
.60723 .54335 .63822 .57635 .66818 .56705 .63751 .53386 Metetra
.669 .758 .917 r
.63751 .53386 .66818 .56705 .69834 .55712 .66799 .52359 Metetra
.678 .76 .913 r
.66799 .52359 .69834 .55712 .72871 .54657 .69868 .51257 Metetra
.685 .761 .909 r
.69868 .51257 .72871 .54657 .75926 .53546 .72956 .50084 Metetra
.692 .761 .905 r
.72956 .50084 .75926 .53546 .79001 .52384 .76062 .48848 Metetra
.696 .76 .901 r
.76062 .48848 .79001 .52384 .82094 .51179 .79187 .47561 Metetra
.699 .757 .897 r
.79187 .47561 .82094 .51179 .85206 .49942 .82331 .46234 Metetra
.7 .754 .894 r
.82331 .46234 .85206 .49942 .88337 .48685 .85493 .44884 Metetra
.616 .723 .922 r
.39706 .55236 .43058 .58756 .4594 .58117 .42612 .5462 Metetra
.618 .726 .923 r
.42612 .5462 .4594 .58117 .48847 .57456 .45545 .53979 Metetra
.623 .731 .924 r
.45545 .53979 .48847 .57456 .5178 .5676 .48503 .53299 Metetra
.63 .736 .923 r
.48503 .53299 .5178 .5676 .54737 .56015 .51488 .52562 Metetra
.639 .741 .922 r
.51488 .52562 .54737 .56015 .57719 .5521 .54499 .51756 Metetra
.649 .745 .92 r
.54499 .51756 .57719 .5521 .60723 .54335 .57534 .50871 Metetra
.66 .75 .917 r
.57534 .50871 .60723 .54335 .63751 .53386 .60593 .499 Metetra
.67 .753 .913 r
.60593 .499 .63751 .53386 .66799 .52359 .63674 .4884 Metetra
.68 .756 .909 r
.63674 .4884 .66799 .52359 .69868 .51257 .66775 .47693 Metetra
.688 .758 .905 r
.66775 .47693 .69868 .51257 .72956 .50084 .69897 .46465 Metetra
.695 .759 .901 r
.69897 .46465 .72956 .50084 .76062 .48848 .73037 .45166 Metetra
.7 .758 .897 r
.73037 .45166 .76062 .48848 .79187 .47561 .76195 .43807 Metetra
.704 .757 .894 r
.76195 .43807 .79187 .47561 .82331 .46234 .79372 .42404 Metetra
.705 .755 .891 r
.79372 .42404 .82331 .46234 .85493 .44884 .82567 .40974 Metetra
.611 .721 .923 r
.36263 .5162 .39706 .55236 .42612 .5462 .39192 .51007 Metetra
.614 .724 .924 r
.39192 .51007 .42612 .5462 .45545 .53979 .4215 .50369 Metetra
.62 .727 .923 r
.4215 .50369 .45545 .53979 .48503 .53299 .45135 .49688 Metetra
.628 .732 .922 r
.45135 .49688 .48503 .53299 .51488 .52562 .48147 .48947 Metetra
.637 .736 .92 r
.48147 .48947 .51488 .52562 .54499 .51756 .51186 .48129 Metetra
.648 .741 .917 r
.51186 .48129 .54499 .51756 .57534 .50871 .54252 .47226 Metetra
.659 .745 .913 r
.54252 .47226 .57534 .50871 .60593 .499 .57342 .4623 Metetra
.67 .749 .909 r
.57342 .4623 .60593 .499 .63674 .4884 .60455 .45138 Metetra
.681 .752 .905 r
.60455 .45138 .63674 .4884 .66775 .47693 .6359 .43951 Metetra
.69 .754 .901 r
.6359 .43951 .66775 .47693 .69897 .46465 .66746 .42677 Metetra
.697 .756 .897 r
.66746 .42677 .69897 .46465 .73037 .45166 .69921 .41324 Metetra
.703 .756 .894 r
.69921 .41324 .73037 .45166 .76195 .43807 .73114 .39907 Metetra
.706 .756 .891 r
.73114 .39907 .76195 .43807 .79372 .42404 .76326 .38444 Metetra
.708 .755 .889 r
.76326 .38444 .79372 .42404 .82567 .40974 .79557 .36951 Metetra
.61 .721 .924 r
.32723 .47902 .36263 .5162 .39192 .51007 .35677 .47274 Metetra
.613 .722 .923 r
.35677 .47274 .39192 .51007 .4215 .50369 .38659 .46619 Metetra
.619 .725 .922 r
.38659 .46619 .4215 .50369 .45135 .49688 .4167 .4592 Metetra
.627 .728 .92 r
.4167 .4592 .45135 .49688 .48147 .48947 .4471 .45158 Metetra
.637 .732 .917 r
.4471 .45158 .48147 .48947 .51186 .48129 .47779 .44318 Metetra
.648 .736 .914 r
.47779 .44318 .51186 .48129 .54252 .47226 .50874 .4339 Metetra
.659 .74 .91 r
.50874 .4339 .54252 .47226 .57342 .4623 .53995 .42365 Metetra
.67 .744 .905 r
.53995 .42365 .57342 .4623 .60455 .45138 .57141 .4124 Metetra
.681 .747 .901 r
.57141 .4124 .60455 .45138 .6359 .43951 .6031 .40019 Metetra
.69 .75 .897 r
.6031 .40019 .6359 .43951 .66746 .42677 .635 .38707 Metetra
.697 .752 .894 r
.635 .38707 .66746 .42677 .69921 .41324 .6671 .37314 Metetra
.703 .753 .891 r
.6671 .37314 .69921 .41324 .73114 .39907 .6994 .35854 Metetra
.707 .754 .889 r
.6994 .35854 .73114 .39907 .76326 .38444 .73189 .34347 Metetra
.709 .754 .888 r
.73189 .34347 .76326 .38444 .79557 .36951 .76458 .32809 Metetra
.611 .721 .923 r
.29083 .44079 .32723 .47902 .35677 .47274 .32062 .43413 Metetra
.615 .722 .922 r
.32062 .43413 .35677 .47274 .38659 .46619 .35071 .42722 Metetra
.62 .723 .92 r
.35071 .42722 .38659 .46619 .4167 .4592 .38108 .41986 Metetra
.628 .725 .917 r
.38108 .41986 .4167 .4592 .4471 .45158 .41176 .41188 Metetra
.638 .728 .914 r
.41176 .41188 .4471 .45158 .47779 .44318 .44273 .40313 Metetra
.648 .732 .91 r
.44273 .40313 .47779 .44318 .50874 .4339 .47399 .39351 Metetra
.659 .735 .906 r
.47399 .39351 .50874 .4339 .53995 .42365 .50551 .38294 Metetra
.67 .739 .902 r
.50551 .38294 .53995 .42365 .57141 .4124 .53729 .37138 Metetra
.68 .742 .898 r
.53729 .37138 .57141 .4124 .6031 .40019 .56932 .35887 Metetra
.689 .745 .894 r
.56932 .35887 .6031 .40019 .635 .38707 .60157 .34546 Metetra
.696 .748 .891 r
.60157 .34546 .635 .38707 .6671 .37314 .63404 .33126 Metetra
.702 .75 .889 r
.63404 .33126 .6671 .37314 .6994 .35854 .66671 .3164 Metetra
.706 .752 .888 r
.66671 .3164 .6994 .35854 .73189 .34347 .69958 .30107 Metetra
.708 .753 .887 r
.69958 .30107 .73189 .34347 .76458 .32809 .73265 .28543 Metetra
.616 .723 .922 r
.25338 .40146 .29083 .44079 .32062 .43413 .28344 .39422 Metetra
.619 .722 .92 r
.28344 .39422 .32062 .43413 .35071 .42722 .3138 .38674 Metetra
.624 .722 .917 r
.3138 .38674 .35071 .42722 .38108 .41986 .34445 .37883 Metetra
.632 .724 .914 r
.34445 .37883 .38108 .41986 .41176 .41188 .37541 .37033 Metetra
.64 .725 .91 r
.37541 .37033 .41176 .41188 .44273 .40313 .40668 .36111 Metetra
.65 .728 .906 r
.40668 .36111 .44273 .40313 .47399 .39351 .43823 .35107 Metetra
.66 .731 .902 r
.43823 .35107 .47399 .39351 .50551 .38294 .47007 .34013 Metetra
.669 .734 .898 r
.47007 .34013 .50551 .38294 .53729 .37138 .50218 .32828 Metetra
.678 .737 .895 r
.50218 .32828 .53729 .37138 .56932 .35887 .53454 .31552 Metetra
.686 .74 .892 r
.53454 .31552 .56932 .35887 .60157 .34546 .56714 .30192 Metetra
.693 .743 .89 r
.56714 .30192 .60157 .34546 .63404 .33126 .59997 .28757 Metetra
.699 .746 .888 r
.59997 .28757 .63404 .33126 .66671 .3164 .63302 .27261 Metetra
.702 .749 .888 r
.63302 .27261 .66671 .3164 .69958 .30107 .66628 .25719 Metetra
.705 .751 .888 r
.66628 .25719 .69958 .30107 .73265 .28543 .69976 .24147 Metetra
.623 .725 .92 r
.21484 .36098 .25338 .40146 .28344 .39422 .24519 .35297 Metetra
.626 .723 .917 r
.24519 .35297 .28344 .39422 .3138 .38674 .27584 .34472 Metetra
.63 .722 .914 r
.27584 .34472 .3138 .38674 .34445 .37883 .30678 .33608 Metetra
.636 .722 .91 r
.30678 .33608 .34445 .37883 .37541 .37033 .33803 .32692 Metetra
.644 .723 .906 r
.33803 .32692 .37541 .37033 .40668 .36111 .36959 .31711 Metetra
.652 .725 .902 r
.36959 .31711 .40668 .36111 .43823 .35107 .40145 .30657 Metetra
.66 .727 .899 r
.40145 .30657 .43823 .35107 .47007 .34013 .4336 .29524 Metetra
.668 .729 .895 r
.4336 .29524 .47007 .34013 .50218 .32828 .46603 .28309 Metetra
.676 .732 .892 r
.46603 .28309 .50218 .32828 .53454 .31552 .49873 .27013 Metetra
.683 .735 .89 r
.49873 .27013 .53454 .31552 .56714 .30192 .53168 .25643 Metetra
.689 .739 .889 r
.53168 .25643 .56714 .30192 .59997 .28757 .56487 .24205 Metetra
.694 .742 .888 r
.56487 .24205 .59997 .28757 .63302 .27261 .5983 .22712 Metetra
.698 .745 .888 r
.5983 .22712 .63302 .27261 .66628 .25719 .63197 .21178 Metetra
.7 .748 .889 r
.63197 .21178 .66628 .25719 .69976 .24147 .66586 .19616 Metetra
.632 .728 .917 r
.17516 .3193 .21484 .36098 .24519 .35297 .20582 .31033 Metetra
.634 .725 .914 r
.20582 .31033 .24519 .35297 .27584 .34472 .23678 .30115 Metetra
.638 .723 .91 r
.23678 .30115 .27584 .34472 .30678 .33608 .26803 .29163 Metetra
.642 .722 .906 r
.26803 .29163 .30678 .33608 .33803 .32692 .29959 .28167 Metetra
.648 .722 .902 r
.29959 .28167 .33803 .32692 .36959 .31711 .33145 .27117 Metetra
.654 .722 .899 r
.33145 .27117 .36959 .31711 .40145 .30657 .36362 .26006 Metetra
.661 .723 .896 r
.36362 .26006 .40145 .30657 .4336 .29524 .39608 .24829 Metetra
.667 .725 .893 r
.39608 .24829 .4336 .29524 .46603 .28309 .42883 .23584 Metetra
.673 .728 .891 r
.42883 .23584 .46603 .28309 .49873 .27013 .46186 .22273 Metetra
.679 .731 .889 r
.46186 .22273 .49873 .27013 .53168 .25643 .49515 .20899 Metetra
.684 .734 .889 r
.49515 .20899 .53168 .25643 .56487 .24205 .52871 .19469 Metetra
.688 .738 .889 r
.52871 .19469 .56487 .24205 .5983 .22712 .56252 .17992 Metetra
.691 .742 .89 r
.56252 .17992 .5983 .22712 .63197 .21178 .59658 .16479 Metetra
.693 .745 .891 r
.59658 .16479 .63197 .21178 .66586 .19616 .63089 .14942 Metetra
.643 .732 .913 r
.13429 .27638 .17516 .3193 .20582 .31033 .16529 .2663 Metetra
.644 .728 .91 r
.16529 .2663 .20582 .31033 .23678 .30115 .19658 .25604 Metetra
.646 .725 .906 r
.19658 .25604 .23678 .30115 .26803 .29163 .22815 .24551 Metetra
.649 .723 .902 r
.22815 .24551 .26803 .29163 .29959 .28167 .26003 .23464 Metetra
.653 .721 .899 r
.26003 .23464 .29959 .28167 .33145 .27117 .29221 .22336 Metetra
.657 .721 .896 r
.29221 .22336 .33145 .27117 .36362 .26006 .32469 .21161 Metetra
.661 .721 .893 r
.32469 .21161 .36362 .26006 .39608 .24829 .35747 .19938 Metetra
.666 .722 .891 r
.35747 .19938 .39608 .24829 .42883 .23584 .39054 .18663 Metetra
.67 .724 .89 r
.39054 .18663 .42883 .23584 .46186 .22273 .4239 .17338 Metetra
.674 .727 .889 r
.4239 .17338 .46186 .22273 .49515 .20899 .45753 .15967 Metetra
.678 .73 .889 r
.45753 .15967 .49515 .20899 .52871 .19469 .49145 .14552 Metetra
.681 .734 .89 r
.49145 .14552 .52871 .19469 .56252 .17992 .52563 .13101 Metetra
.683 .738 .892 r
.52563 .13101 .56252 .17992 .59658 .16479 .56008 .11621 Metetra
.685 .742 .894 r
.56008 .11621 .59658 .16479 .63089 .14942 .59481 .1012 Metetra
.654 .735 .909 r
.09217 .23214 .13429 .27638 .16529 .2663 .12354 .22084 Metetra
.655 .731 .905 r
.12354 .22084 .16529 .2663 .19658 .25604 .15518 .2094 Metetra
.655 .727 .902 r
.15518 .2094 .19658 .25604 .22815 .24551 .18711 .19776 Metetra
.657 .724 .899 r
.18711 .19776 .22815 .24551 .26003 .23464 .21932 .18589 Metetra
.658 .722 .896 r
.21932 .18589 .26003 .23464 .29221 .22336 .25183 .17376 Metetra
.66 .72 .893 r
.25183 .17376 .29221 .22336 .32469 .21161 .28463 .16134 Metetra
.662 .719 .891 r
.28463 .16134 .32469 .21161 .35747 .19938 .31773 .1486 Metetra
.665 .72 .89 r
.31773 .1486 .35747 .19938 .39054 .18663 .35112 .13555 Metetra
.667 .721 .89 r
.35112 .13555 .39054 .18663 .4239 .17338 .3848 .12219 Metetra
.669 .723 .89 r
.3848 .12219 .4239 .17338 .45753 .15967 .41877 .10852 Metetra
.671 .726 .891 r
.41877 .10852 .45753 .15967 .49145 .14552 .45303 .09458 Metetra
.673 .73 .892 r
.45303 .09458 .49145 .14552 .52563 .13101 .48759 .08039 Metetra
.674 .734 .895 r
.48759 .08039 .52563 .13101 .56008 .11621 .52243 .06599 Metetra
.675 .738 .897 r
.52243 .06599 .56008 .11621 .59481 .1012 .55756 .05142 Metetra
.666 .738 .904 r
.04875 .18654 .09217 .23214 .12354 .22084 .08051 .17394 Metetra
.665 .734 .901 r
.08051 .17394 .12354 .22084 .15518 .2094 .11254 .16124 Metetra
.665 .73 .898 r
.11254 .16124 .15518 .2094 .18711 .19776 .14483 .14843 Metetra
.664 .726 .895 r
.14483 .14843 .18711 .19776 .21932 .18589 .1774 .13551 Metetra
.664 .723 .893 r
.1774 .13551 .21932 .18589 .25183 .17376 .21025 .12249 Metetra
.664 .72 .891 r
.21025 .12249 .25183 .17376 .28463 .16134 .24339 .10934 Metetra
.663 .719 .89 r
.24339 .10934 .28463 .16134 .31773 .1486 .27681 .09609 Metetra
.663 .718 .89 r
.27681 .09609 .31773 .1486 .35112 .13555 .31052 .08272 Metetra
.663 .719 .89 r
.31052 .08272 .35112 .13555 .3848 .12219 .34452 .06923 Metetra
.664 .72 .891 r
.34452 .06923 .3848 .12219 .41877 .10852 .37882 .05563 Metetra
.664 .723 .893 r
.37882 .05563 .41877 .10852 .45303 .09458 .41342 .04191 Metetra
.664 .726 .895 r
.41342 .04191 .45303 .09458 .48759 .08039 .44833 .02806 Metetra
.665 .73 .898 r
.44833 .02806 .48759 .08039 .52243 .06599 .48355 .01409 Metetra
.665 .734 .901 r
.48355 .01409 .52243 .06599 .55756 .05142 .51908 0 Metetra
0 g
.25 Mabswid
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282.75, 314.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005Q0001RB000`400?l00000o`00003ooooooomR
ooooo`00oooooomRooooo`00oooooomRooooo`00^_ooool4o`000003oa0@4?oooooooooo0:3ooooo
002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002loooo
o`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`00
0?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002jooooo`03oeEEEOmVIVKo
00000:Cooooo003oooooof;ooooo003oooooof;ooooo001Mooooo`;o00000_ooool2o`000?kooooo
001Mooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgMo_ooool005kooooo00CogMgMo`000?l@413o
c<c<:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`07oooool2o`0009oooooo001Nooooo`04onk^k_lQ8B7o410@onk^kR[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01cooooo
0ol000000onZ^nKo0000o`00002Nooooo`00G_ooool01?lQ8B7oMgMgogMgMolb<S8Zooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001[ooooo0ol00003ojZk
iP?o0000WOooool005gooooo0_l00002ooooo`;o0000:Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`?o00001_nZ^nH00ol0003oZ[_Vo`00002M
ooooo`00S?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00Eooooo`?o00000_nZ^nH00ol0003oZ[_VojZkiP03ojZkiP04o`000?nZ^nKoZ[_Vo`0009cooooo
002<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@01;o
oooo1?l0000:ojZkiP04o`000?nZ^nKoZ[_Vo`0009cooooo002<ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000013ooooo1?l000000onZ^^Go0000ojZkiP09
ojZkiP05o`000?nZ^nKoZ[_VojZki_l00000Voooool008cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT03Oooool4o`000003ojZjiOl0003oZ[[U00;oZ[[U
00?o0000ojZki_nZ^nH01onZ^nH00ol0003oZ[_VojZkiP02ojZkiP03o`000?oooooooooo09Sooooo
002/ooooo`Co00002?nZ^^D00ol0003oZ[_VojZkiP06ojZkiP03o`000?nZ^nKoZ[_V00?oZ[_V00?o
0000ooooooooool0Uoooool00:Wooooo1?l0000<ojZji@03o`000?nZ^nKoZ[_V00GoZ[_V00?o0000
ojZki_nZ^nH00onZ^nH00ol0003oooooooooo`2Gooooo`00Yoooool6o`0000coZ[[U00?o0000ojZk
i_nZ^nH01OnZ^nH00ol0003oZ[_VojZkiP04ojZkiP03o`000?oooooooooo09Kooooo002Tooooo`Co
00001OnY^ND00ol0003oZ[[UojZji@0:ojZji@03o`000?nZ^nKoZ[_V00CoZ[_V00?o0000ojZki_nZ
^nH01OnZ^nH00ol0003oooooooooo`2Eooooo`00KOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`08?ooool3o`0000WoZKWU00?o0000ojZj
iOnZ^^D02_nZ^^D00ol0003oZ[_VojZkiP03ojZkiP03o`000?nZ^nKoZ[_V00KoZ[_V00?o0000oooo
ooooool0U?ooool006gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q01gooooo0ol000000onY^NGo0000ojVii@0:ojVii@03o`000?nZ^^Go
Z[[U00[oZ[[U00?o0000ojZki_nZ^nH00_nZ^nH00ol0003oZ[_VojZkiP06ojZkiP03o`000?oooooo
oooo09Cooooo001]ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000001_ooooo0ol000001OnY^NCo0000ojViiOnY^NGo000000[oZKWU00?o0000ojZjiOnZ^^D0
2_nZ^^D00ol0003oZ[_VojZkiP02ojZkiP03o`000?nZ^nKoZ[_V00OoZ[_V00?o0000ooooooooool0
Toooool006gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B406?ooool3o`0000GoZKWT00?o0000ojViiOnY^ND02onY^ND00ol0003oZ[[UojZji@0:ojZji@05
o`000?nZ^nKoZ[_VojZki_l000002_nZ^nH00ol0003oooooooooo`2Booooo`00KOooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Eooooo`Co000000?oZKWT
o`000?nY^N@01OnY^N@00ol0003oZKWUojVii@0;ojVii@03o`000?nZ^^GoZ[[U00[oZ[[U00Co0000
ojZki_nZ^nKo00002_nZ^nH2o`0009?ooooo001]ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool00omEEEGoQhN7ooooo`0Eooooo`?o00003?nY^N@00ol0003oZKWUojVii@0;ojVii@03o`000?nZ
^^GoZ[[U00[oZ[[U00?o0000ojZki_l000002?nZ^nH2o`000003ojbliOl0003ooooo09;ooooo001]
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00Cooooo`Co00003OnY
^N@00ol0003oZKWUojVii@0;ojVii@03o`000?nZ^^GoZ[[U00[oZ[[U00?o0000ojZki_l000001OnZ
^nH3o`0000Co[;cU00?o0000ooooooooool0T?ooool006gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`04olc<c?m4A4Co0000oa0@40oooooo0_l00002ojVhi003o`000?nY^>Co000000goZKWT
00?o0000ojViiOnY^ND02onY^ND00ol0003oZ[[UojZji@0:ojZji@;o00000onZ^nH2o`0000So[;cU
00?o0000ooooooooool0Soooool008kooooo0ol00007ojVhi003o`000?nY^NCoZKWT00_oZKWT00?o
0000ojViiOnY^ND02onY^ND00ol0003oZ[[UojZji@0:ojZji@04o`000?nZ^nKo0000o`0000_o[;cU
00?o0000ooooooooool0S_ooool008cooooo0ol0000:ojVhi003o`000?nY^NCoZKWT00_oZKWT00?o
0000ojViiOnY^ND02onY^ND00ol0003oZ[[UojZji@09ojZji@;o00003On/_>D2o`0008oooooo0029
ooooo`Co000000?oZKSTo`000?nY^>@02OnY^>@00ol0003oZKWTojVii00;ojVii003o`000?nY^NGo
ZKWU00_oZKWU00?o0000ojZjiOnZ^^D01_nZ^^D5o`0000ko[;cU00?o0000ooooooooool0SOooool0
053ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooo
oooo023ooooo1?l000000onY^>?o0000ojVhi00<ojVhi003o`000?nY^NCoZKWT00_oZKWT00?o0000
ojViiOnY^ND02onY^ND00ol0003oZ[[UojZji@03ojZji@;o00000on/^nD00ol0003o[;_Uo`00000>
ojbli@03o`000?oooooooooo08cooooo001@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool07_ooool4o`0000GoZKSS00?o0000ojVhi?nY^>@02onY^>@0
0ol0003oZKWTojVii00;ojVii003o`000?nY^NGoZKWU00_oZKWU00?o0000ojZjiOl000000_l00005
ojbki@04o`000?n/^nGo[;_Uo`0000ko[;cU00?o0000ooooooooool0Roooool0053ooooo00Go410@
oooooooooooooooooa0@400;ooooo`Go00007Oooool3o`000003ojVhhol0003oZKSS00KoZKSS00?o
0000ojVhi?nY^>@02onY^>@00ol0003oZKWTojVii00;ojVii003o`000?nY^NGoZKWU00[oZKWU0_l0
0008ojbki@05o`000?n/^nGo[;_UojbkiOl000003On/_>D2o`0008cooooo001@ooooo`05o`000?oo
ooooooooooooool000002oooool01?m4A4CogMgMooooool0000Kooooo`?o00001OnY^><00ol0003o
ZKSSojVhh`05ojVhh`03o`000?nY^>CoZKST00_oZKST00?o0000ojVii?nY^N@02_nY^N@00ol0003o
ZKWUojVii@07ojVii@?o000000?o[;[To`000?n/^nD01on/^nD00ol0003o[;_Uojbki@02ojbki@03
o`000?n/_>Go[;cU00_o[;cU0_l0002;ooooo`00D?ooool01Ol0003ooooooooooooooooo000000_o
oooo00CogMgMoeEEEOoooooo00006Oooool3o`000003ojVghol0003oZKSS00coZKSS00?o0000ojVh
i?nY^>@02onY^>@00ol0003oZKWTojVii00;ojVii003o`000?nY^NGoZKWU00?oZKWU0ol00005ojbj
i003o`000?n/^nGo[;_U00Go[;_U00?o0000ojbkiOn/^nD00_n/^nD00ol0003o[;cUojbli@0<ojbl
i@03o`000?oooooooooo08Wooooo001@ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omg
MgOoc<c<o`00000Fooooo`?o00000_nY]n<01?l0003oZKOSojVghol0000=ojVhh`03o`000?nY^>Co
ZKST00_oZKST00?o0000ojVii?nY^N@02onY^N@00ol0003oZKWUo`000002o`0000Wo[;[T00?o0000
ojbkiOn/^nD01?n/^nD00ol0003o[;_Uojbki@03ojbki@03o`000?n/_>Go[;cU00co[;cU00?o0000
ooooooooool0R?ooool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co
000001Cooooo0ol00008ojVgh`03o`000?nY^>?oZKSS00_oZKSS00?o0000ojVhi?nY^>@02onY^>@0
0ol0003oZKWTojVii00:ojVii0;o00003?n/^^@00ol0003o[;_Uojbki@04ojbki@03o`000?n/^nGo
[;_U00Co[;_U00?o0000ojbliOn/_>D02on/_>D2o`0008Wooooo001@ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0@ooooo`?o00003?nY]n<00ol0003oZKSSojVhh`0;
ojVhh`03o`000?nY^>CoZKST00_oZKST00?o0000ojVii?nY^N@01onY^N@2o`000003oj^ii?l0003o
[;[T00co[;[T00?o0000ojbkiOn/^nD00on/^nD00ol0003o[;_Uojbki@05ojbki@03o`000?n/_>Go
[;cU00_o[;cU0_l00028ooooo`00Loooool3o`000003ojVhhol0003o000000coZKOS00?o0000ojVh
honY^><02_nY^><00ol0003oZKSTojVhi00;ojVhi003o`000?nY^NCoZKWT00GoZKWT0_l00004oj^i
i003o`000?n/^^Co[;[T00_o[;[T00?o0000ojbkiOn/^nD00_n/^nD00ol0003o[;_Uojbki@06ojbk
i@03o`000?n/_>Go[;cU00_o[;cU0_l00027ooooo`00L?ooool3o`0000GoZKSS00?o0000ojVghonY
]n<02_nY]n<00ol0003oZKSSojVhh`0;ojVhh`03o`000?nY^>CoZKST00_oZKST00?o0000ojVii?nY
^N@00_nY^N@2o`0000OoZkWT00?o0000ojbji?n/^^@02_n/^^@00ol0003o[;_Uojbki@02ojbki@03
o`000?n/^nGo[;_U00Ko[;_U00?o0000ojbliOn/_>D02On/_>D2o`000003ojnmi?l0003ooooo08Ko
oooo001^ooooo`?o00002?nY^><00ol0003oZKOSojVgh`0:ojVgh`03o`000?nY^>?oZKSS00_oZKSS
00?o0000ojVhi?nY^>@02onY^>@01?l0003oZKWTo`000?l0000:oj^ii003o`000?n/^^Co[;[T00[o
[;[T00Go0000ojbkiOn/^nGo[;_Uo`000009ojbki@03o`000?n/_>Go[;cU00Go[;cU0ol00003ojnm
i0;o0000Q_ooool003?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00
02?ooooo0ol00002ojVhh`03o`000?nY^>?oZKSS00OoZKSS00?o0000ojVghonY]n<02_nY]n<00ol0
003oZKSSojVhh`0;ojVhh`03o`000?nY^>CoZKST00[oZKST0_l0000<oj^ii003o`000?n/^^Co[;[T
00_o[;[T00Co0000ojbkiOn/^nGo00002_n/^nD00ol0003o[;cUojbli@02ojbli@;o00001on__N@2
o`0008Gooooo000cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Qooooo`?o000000?oZKSTo`000?nY^><02onY^><00ol0003oZKOSojVg
h`0;ojVgh`03o`000?nY^>?oZKSS00[oZKSS00?o0000ojVhi?nY^>@01onY^>@3o`000003oj^ihol0
003oZkWT00coZkWT00?o0000ojbji?n/^^@02on/^^@00ol0003o[;_Uo`00000;ojbki@04o`000?n/
_>Go0000o`0000[o[kgT0_l00024ooooo`00<oooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h07oooool4o`0000CoZKST00?o0000ojVhhonY^><02_nY^><00ol0003oZKOS
ojVgh`0;ojVgh`03o`000?nY^>?oZKSS00[oZKSS00?o0000ojVhi?nY^>@00onY^>@3o`0000GoZkWS
00?o0000oj^ii?n[^N@02on[^N@00ol0003o[;[Tojbji00:ojbji003o`000?n/^nGo000000_o[;_U
0_l0000=ojnmi003o`000?oooooooooo08;ooooo000cooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP0Kooooo`?o00001?nY^>@00ol0003oZKSTojVhi002ojVhi003o`00
0?nY^>?oZKSS00[oZKSS00?o0000ojVghonY]n<02onY]n<00ol0003oZKSSojVhh`0:ojVhh`03o`00
0?nY^>Co000000;o00002On[^N<00ol0003oZkWToj^ii00;oj^ii003o`000?n/^^Co[;[T00[o[;[T
0_l00009ojbki@;o000000?o[[cTo`000?n__N@03?n__N@2o`0008?ooooo000cooooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Hooooo`?o00003?nY^>@00ol0003oZKSS
ojVhh`0:ojVhh`03o`000?nY]n?oZKOS00[oZKOS00?o0000ojVhhonY^><02_nY^><2o`0000goZkWS
00?o0000oj^ii?n[^N@02_n[^N@00ol0003o[;[Tojbji00;ojbji003o`000?n/^nGo[;_U00Co[;_U
0ol00004ojjli003o`000?n__NCo[kgT00_o[kgT0_l00022ooooo`00<oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool05?ooool3o`000003ojVii?l0003oZKST00coZKST
00?o0000ojVhhonY^><02_nY^><00ol0003oZKOSojVgh`0;ojVgh`03o`000?nY^>?oZKSS00KoZKSS
0ol000000onZ^>?o0000oj^ih`0<oj^ih`03o`000?n[^NCoZkWT00_oZkWT00?o0000ojbji?n/^^@0
2_n/^^@00ol0003o[;_Uojbki@02ojbki@;o00002?n^_>@00ol0003o[kgTojnmi00;ojnmi0;o0000
POooool003?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41005?ooool3o`0000CoZKWT00?o0000ojVhi?nY^>@02onY^>@00ol0003oZKSSojVhh`0:ojVhh`03
o`000?nY]n?oZKOS00_oZKOS00?o0000ojVhhonY^><00onY^><2o`0000GoZ[SS00?o0000oj^ihon[
^N<02on[^N<00ol0003oZkWToj^ii00;oj^ii003o`000?n/^^Co[;[T00Wo[;[T0_l000000on/^nGo
0000o`00000;ojjli003o`000?n__NCo[kgT00_o[kgT00?o0000ooooooooool0Ooooool003?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool3o`00
00SoZKWT00?o0000ojVhi?nY^>@02onY^>@00ol0003oZKSSojVhh`0:ojVhh`03o`000?nY]n?oZKOS
00_oZKOS00?o0000ojVhhol000000_l00008ojZhh`03o`000?n[^N?oZkWS00_oZkWS00?o0000oj^i
i?n[^N@02on[^N@00ol0003o[;[Tojbji008ojbji0?o00003On^_>@00ol0003o[kgTojnmi00;ojnm
i0;o0000P?ooool005Oooooo0ol000000onY^NCo0000ojVii008ojVii003o`000?nY^>CoZKST00_o
ZKST00?o0000ojVhhonY^><02_nY^><00ol0003oZKOSojVgh`0:ojVgh`;o00003?nZ^><00ol0003o
ZkWSoj^ih`0;oj^ih`03o`000?n[^NCoZkWT00[oZkWT00?o0000ojbji?n/^^@01_n/^^@3o`000003
ojjkhol0003o[[cT00go[[cT00?o0000ojnmi?n__N@02on__N@2o`0007oooooo001Dooooo`?o0000
00?oZKWUo`000?nY^N@03?nY^N@00ol0003oZKSTojVhi00:ojVhi003o`000?nY^>?oZKSS00[oZKSS
00?o0000ojVghonY]n<01onY]n<3o`000003ojZhhol0003oZ[SS00_oZ[SS00?o0000oj^ihon[^N<0
2on[^N<00ol0003oZkWToj^ii00;oj^ii003o`000?n/^^Co[;[T00?o[;[T0_l00002ojjkh`04o`00
0?n^^n?o[[_So`0000ko[[cT00?o0000ojnmi?n__N@02on__N@00ol0003oooooooooo`1mooooo`00
D_ooool3o`0000CoZKWU00?o0000ojVii?nY^N@02_nY^N@00ol0003oZKSTojVhi00;ojVhi003o`00
0?nY^>?oZKSS00[oZKSS00?o0000ojVghonY]n<00onY]n<3o`0000GoZ[SS00?o0000ojZhhonZ^><0
2_nZ^><00ol0003oZkWSoj^ih`0;oj^ih`03o`000?n[^NCoZkWT00_oZkWT00?o0000ojbji?l00000
0_l00004ojjkh`05o`000?n^^n?o[[_Sojjkhol000003_n^_>@00ol0003o[kgTojnmi00;ojnmi003
o`000?oooooooooo07cooooo000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool4o`000003
ojViiOl0003oZKWU00CoZKWU00?o0000ojVii?nY^N@02_nY^N@00ol0003oZKSTojVhi00;ojVhi003
o`000?nY^>?oZKSS00[oZKSS00?o0000ojVghol000000_l00009ojZhh`03o`000?nZ^>?oZ[SS00[o
Z[SS00?o0000oj^ihon[^N<02on[^N<00ol0003oZkWToj^ii00:oj^ii0;o00001on^^n<00ol0003o
[[_Sojjkh`02ojjkh`03o`000?n^_>Co[[cT00_o[[cT00?o0000ojnmi?n__N@02on__N@2o`0007go
oooo000Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL08Oooool3o`0000_oZKWU00?o0000ojVii?nY
^N@02_nY^N@00ol0003oZKSTojVhi00;ojVhi003o`000?nY^>?oZKSS00WoZKSS0_l0000=ojZhh`03
o`000?nZ^>?oZ[SS00[oZ[SS00?o0000oj^ihon[^N<02_n[^N<00ol0003oZkWToj^ii007oj^ii0?o
000000?o[K[So`000?n^^n<01_n^^n<00ol0003o[[_Sojjkh`03ojjkh`03o`000?n^_>Co[[cT00_o
[[cT00?o0000ojnmi?n__N@02on__N@2o`0007cooooo000Wooooo`05oa0@4?ooooooooooooooool@
41007_ooool5o`0000goZKWU00?o0000ojVii?nY^N@02_nY^N@00ol0003oZKSTojVhi00:ojVhi003
o`000?nY^>?oZKSS00KoZKSS0ol000000onY^>Co0000ojZhh`0<ojZhh`03o`000?nZ^>?oZ[SS00[o
Z[SS00?o0000oj^ihon[^N<02on[^N<00ol0003oZkWToj^ii003oj^ii0?o00001On]^^<00ol0003o
[[_Sojjkh`04ojjkh`03o`000?n^^n?o[[_S00?o[[_S00?o0000ojjli?n^_>@03?n^_>@00ol0003o
[kgTojnmi008ojnmi0;o000000?o/KkTo`000?ooool0Noooool002Oooooo00Go0000oooooooooooo
ooooo`00000Looooo`?o00000_nZ^^D00ol0003oZ[[Uo`00000<ojVii@03o`000?nY^NCoZKWT00_o
ZKWT00?o0000ojVhi?nY^>@02_nY^>@00ol0003oZKSSojVhh`03ojVhh`;o00001OnY^>@00ol0003o
Z[SSojZhh`0;ojZhh`03o`000?nZ^>?oZ[SS00[oZ[SS00?o0000oj^ihon[^N<02on[^N<00ol0003o
ZkWTo`000002o`0000Wo[K[S00?o0000ojjkhon^^n<00on^^n<00ol0003o[[_Sojjkh`04ojjkh`03
o`000?n^_>Co[[cT00_o[[cT00?o0000ojnmi?n__N@01On__N@3o`0000Co/KkT00?o0000oooooooo
ool0NOooool002Oooooo00Go0000ooooooooooooooooo`00000Iooooo`Co00001OnZ^^D00ol0003o
Z[[Uo`00000<ojVii@03o`000?nY^NCoZKWT00_oZKWT00?o0000ojVhi?nY^>@02_nY^>@00ol0003o
ZKSSo`000002o`0000SoZKST00?o0000ojZhhonZ^><02onZ^><00ol0003oZ[SSojZhh`0:ojZhh`03
o`000?n[^N?oZkWS00[oZkWS0_l0000=ojfjh`03o`000?n^^n?o[[_S00;o[[_S00?o0000ojjkhon^
^n<01On^^n<00ol0003o[[cTojjli00;ojjli003o`000?n__NCo[kgT00;o[kgT0_l00007ok6ni0;o
0000N_ooool002Oooooo00Go410@oooooooooooooooooa0@400Gooooo`?o00002onZ^^D00ol0003o
ZKWUojVii@0:ojVii@03o`000?nY^NCoZKWT00[oZKWT00?o0000ojVhi?nY^>@02_nY^>@2o`0000co
ZKST00?o0000ojZhhonZ^><02onZ^><00ol0003oZ[SSojZhh`0:ojZhh`03o`000?n[^N?oZkWS00Oo
ZkWS0_l000000on/^^?o0000ojfjh`0<ojfjh`03o`000?n^^n?o[[_S00;o[[_S00?o0000ojjkhon^
^n<01_n^^n<00ol0003o[[cTojjli00;ojjli004o`000?n__NCo0000o`0000[o/KkT0_l0001ioooo
o`009oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo1Ol000000onZ^^Go0000ojZji@0:ojZj
i@03o`000?nY^NGoZKWU00[oZKWU00?o0000ojVii?nY^N@02_nY^N@00ol0003oZKSTojVhi006ojVh
i0?o000000?oZ;STo`000?nY^>@03?nY^>@00ol0003oZ[SSojZhh`0:ojZhh`03o`000?nZ^>?oZ[SS
00[oZ[SS00?o0000oj^ihon[^N<01On[^N<2o`0000Co[;[S00?o0000ojfjhon]^^<02on]^^<01Ol0
003o[[_Sojjkhon^^n?o000000Wo[[_S00?o0000ojjli?n^_>@02_n^_>@2o`0000go/KkT00?o0000
ooooooooool0Moooool002Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`?o00001?nZ^nH0
0ol0003oZ[[UojZji@0;ojZji@03o`000?nY^NGoZKWU00[oZKWU00?o0000ojVii?nY^N@02_nY^N@0
0ol0003oZKSTojVhi003ojVhi0;o00001OnX^>@00ol0003oZKSTojVhi00:ojVhi003o`000?nZ^>?o
Z[SS00_oZ[SS00?o0000ojZhhonZ^><02_nZ^><00ol0003oZkWSoj^ih`02oj^ih`;o00001on/^^<0
0ol0003o[K[Sojfjh`0;ojfjh`04o`000?n^^n?o[[_So`0000Wo[[_S00?o0000ojjli?n^_>@02?n^
_>@2o`000003ok2mhol0003o/KkT00go/KkT00?o0000ooooooooool0M_ooool003_ooooo1Ol00006
ojZkiP03o`000?nZ^^GoZ[[U00_oZ[[U00?o0000ojViiOnY^ND02_nY^ND00ol0003oZKWTojVii00:
ojVii003o`000?nY^>Co000000;o00002?nX^>@00ol0003oZKSTojVhi00:ojVhi003o`000?nZ^>?o
Z[SS00_oZ[SS00?o0000ojZhhonZ^><02_nZ^><01?l0003oZkWSo`000?l0000:ojbjh`03o`000?n]
^^?o[K[S00_o[K[S00?o0000ojjkhol000002_n^^n<00ol0003o[[cTojjli005ojjli0;o00001?n`
_N<00ol0003o/KkTok6ni00;ok6ni0;o0000Moooool003Wooooo0ol0000;ojZkiP03o`000?nZ^^Go
Z[[U00_oZ[[U00?o0000ojViiOnY^ND02OnY^ND00ol0003oZKWTojVii00:ojVii0;o00003?nX^>@0
0ol0003oZKSTojVhi00:ojVhi003o`000?nZ^>?oZ[SS00_oZ[SS00?o0000ojZhhonZ^><02OnZ^><2
o`0000co[;[S00?o0000ojfjhon]^^<02on]^^<00ol0003o[[_So`00000;ojjkh`03o`000?n^_>Co
[[cT00;o[[cT0_l00007ok2mh`03o`000?na_^Co/KkT00_o/KkT0_l0001fooooo`00=oooool3o`00
0003ojZliol0003oZ[_V00_oZ[_V00?o0000ojZjiOnZ^^D02_nZ^^D00ol0003oZKWUojVii@0:ojVi
i@03o`000?nY^NCoZKWT00KoZKWT0ol000000onX^>Go0000ojRhi00<ojRhi003o`000?nY^>CoZKST
00[oZKST00?o0000ojZhhonZ^><02_nZ^><00ol0003oZ[SSojZhh`06ojZhh`?o000000?oZkWSo`00
0?n/^^<03?n/^^<00ol0003o[K[Sojfjh`0;ojfjh`;o00003?n^^n<01?l0003o[[cTo`000?l0000:
ok2mh`03o`000?na_^Co/KkT00_o/KkT00?o0000ooooooooool0M?ooool003Cooooo0ol000000onZ
_>Oo0000ojZli`02ojZli`03o`000?nZ^nKoZ[_V00[oZ[_V00?o0000ojZjiOnZ^^D02_nZ^^D00ol0
003oZKWUojVii@0:ojVii@03o`000?nY^NCoZKWT00?oZKWT0_l00005ojRhi@03o`000?nX^>CoZ;ST
00_oZ;ST00?o0000ojVhi?nY^>@02_nY^>@00ol0003oZ[SSojZhh`0:ojZhh`03o`000?nZ^>?oZ[SS
00?oZ[SS0_l00005oj^ih`03o`000?n/^^?o[;[S00_o[;[S00?o0000ojfjhon]^^<02on]^^<00ol0
003o[[_Sojjkh`0:ojjkh`;o00003?n`_N<00ol0003o/KkTok6ni00<ok6ni003o`000?oooooooooo
07?ooooo000booooo`?o00002?nZ_>L00ol0003oZ[_VojZkiP0:ojZkiP03o`000?nZ^^GoZ[[U00[o
Z[[U00?o0000ojViiOnY^ND02_nY^ND00ol0003oZKWTo`000002o`0000SoZ;SU00?o0000ojRhi?nX
^>@02onX^>@00ol0003oZKSTojVhi00:ojVhi003o`000?nZ^>?oZ[SS00[oZ[SS00?o0000ojZhhol0
00000_l00008oj^ih`03o`000?n/^^?o[;[S00_o[;[S00?o0000ojfjhon]^^<02_n]^^<00ol0003o
[[_Sojjkh`07ojjkh`?o000000?o/;cSo`000?n`_N<03?n`_N<00ol0003o/KkTok6ni00;ok6ni0;o
0000M?ooool0037ooooo00?o0000ojZlionZ_>L02_nZ_>L00ol0003oZ[_VojZkiP0:ojZkiP03o`00
0?nZ^^GoZ[[U00[oZ[[U00?o0000ojViiOnY^ND02?nY^ND3o`0000coZ;SU00?o0000ojRhi?nX^>@0
2onX^>@00ol0003oZKSTojVhi009ojVhi003o`000?nZ^>?oZ[SS00[oZ[SS0_l0000<oj^ih`03o`00
0?n/^^?o[;[S00[o[;[S00?o0000ojfjhon]^^<02_n]^^<2o`0000Go[[_S0ol00005ok2lh`03o`00
0?n`_N?o/;gS00_o/;gS00?o0000ok6ni?na_^@02ona_^@00ol0003oooooooooo`1booooo`00<Ooo
ool2o`0000coZ[cW00?o0000ojZki_nZ^nH02OnZ^nH00ol0003oZ[[UojZji@0;ojZji@03o`000?nY
^NGoZKWU00CoZKWU0ol00002ojRiiP03o`000?nX^>GoZ;SU00_oZ;SU00?o0000ojRhi?nX^>@02_nX
^>@00ol0003oZKSTojVhi00:ojVhi003o`000?nZ^>?oZ[SS00KoZ[SS0ol000000onZ^>Co0000oj^i
h`0<oj^ih`03o`000?n/^^?o[;[S00[o[;[S00?o0000ojfjhon]^^<02On]^^<01?l0003o[K[So`00
0?n^^n<3o`0000Wo/;cS00?o0000ok2mhon`_N<02on`_N<00ol0003o/KkTok6ni00;ok6ni003o`00
0?oooooooooo077ooooo000Uooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool2o`0000goZ[cW
00?o0000ojZki_nZ^nH02OnZ^nH00ol0003oZ[[UojZji@0;ojZji@03o`000?nY^NGoZKWU00?o0000
1_nX^NH00ol0003oZ;SUojRhi@0;ojRhi@03o`000?nX^>CoZ;ST00[oZ;ST00?o0000ojVhi?nY^>@0
2_nY^>@00ol0003oZ[SSojZhh`03ojZhh`;o00001OnZ^>@00ol0003oZkWSoj^ih`0:oj^ih`03o`00
0?n/^^?o[;[S00_o[;[S00?o0000ojfjhon]^^<02?n]^^<01?l0003o[K[So`000?l0000=ok2lh`03
o`000?n`_N?o/;gS00[o/;gS00?o0000ok6ni?na_^@03?na_^@00ol0003oooooooooo`1`ooooo`00
9Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?o0000ooooool000003OnZ_>L00ol0003o
Z[_VojZkiP09ojZkiP03o`000?nZ^^GoZ[[U00[oZ[[U0ol0000:ojRiiP03o`000?nX^>GoZ;SU00_o
Z;SU00?o0000ojRhi?nX^>@02_nX^>@00ol0003oZKSTojVhi00:ojVhi003o`000?nZ^>?o000000;o
00002?nZ^>@00ol0003oZkWSoj^ih`0:oj^ih`03o`000?n/^^?o[;[S00_o[;[S00?o0000ojfjhon]
^^<01on]^^<2o`000003ojnkhol0003o/;cS00go/;cS00?o0000ok2mhon`_N<02_n`_N<00ol0003o
/KkTok6ni00;ok6ni0;o0000LOooool002Gooooo00Go410@oooooooooooooooooa0@4007ooooo`04
o`000?ooooooooooo`0000goZ[cW00?o0000ojZki_nZ^nH02OnZ^nH00ol0003oZ[[UojZji@06ojZj
i@?o000000?oYk[Vo`000?nX^NH02onX^NH00ol0003oZ;SUojRhi@0;ojRhi@03o`000?nX^>CoZ;ST
00[oZ;ST00?o0000ojVhi?nY^>@02?nY^>@3o`0000coZ[ST00?o0000oj^ihon[^N<02_n[^N<00ol0
003o[;[Sojbjh`0:ojbjh`03o`000?n]^^?o[K[S00Go[K[S0ol00003ojnkh`03o`000?n`_>?o/;cS
00_o/;cS00?o0000ok2mhon`_N<02on`_N<00ol0003o/KkTok6ni008ok6ni0;o000000?o/koSo`00
0?ooool0L?ooool002Gooooo00Go0000ooooooooooooooooo`000006ooooo`;o00000oooool00ol0
003oZ[cWojZli`0;ojZli`03o`000?nZ^nKoZ[_V00WoZ[_V00?o0000ojZjiOnZ^^D00onZ^^D2o`00
00GoYk[V00?o0000ojRii_nX^NH02_nX^NH00ol0003oZ;SUojRhi@0:ojRhi@03o`000?nX^>CoZ;ST
00_oZ;ST00?o0000ojVhi?nY^>@01?nY^>@3o`0000;oZKST00?o0000ojZhi?nZ^>@02onZ^>@00ol0
003oZkWSoj^ih`0:oj^ih`03o`000?n/^^?o[;[S00[o[;[S00?o0000ojfjhon]^^<00_n]^^<2o`00
00;o[k_S00?o0000ojnkhon_^n<00_n_^n<00ol0003o/;cSok2lh`0;ok2lh`03o`000?n`_N?o/;gS
00[o/;gS00?o0000ok6ni?na_^@01Ona_^@3o`0000Co/koS00?o0000ooooooooool0K_ooool002Go
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo00?o0000ojZl
ionZ_>L02onZ_>L00ol0003oZ[_VojZkiP09ojZkiP03o`000?nZ^^Go000000;o00002?nW^^H00ol0
003oZ;WVojRiiP0:ojRiiP03o`000?nX^>GoZ;SU00[oZ;SU00?o0000ojRhi?nX^>@02onX^>@00ol0
003oZKSTojVhi003o`0000KoZKST00?o0000ojZhi?nZ^>@02_nZ^>@00ol0003oZkWSoj^ih`0;oj^i
h`03o`000?n/^^?o[;[S00[o[;[S00Co0000ojfjhol0003o00001?n_^n<00ol0003o[k_Sojnkh`03
ojnkh`03o`000?n`_>?o/;cS00_o/;cS00?o0000ok2mhon`_N<02_n`_N<00ol0003o/KkTok6ni002
ok6ni0;o00002?nc_n<00ol0003oooooooooo`1]ooooo`009Oooool01Ol@413ooooooooooooooooo
410@00Kooooo00?o0000ooooooooool01?ooool00ol0003oZ[cWojZli`0;ojZli`03o`000?nZ^nKo
Z[_V00SoZ[_V0_l0000<ojNjiP03o`000?nX^NKoZ;WV00[oZ;WV00?o0000ojRhiOnX^>D02_nX^>D0
0ol0003oZ;STojRhi00:ojRhi0?o00002_nY^>@00ol0003oZ[STojZhi00:ojZhi003o`000?n[^N?o
ZkWS00[oZkWS00?o0000ojbjhon/^^<02_n/^^<2o`0000Ko[k_S00?o0000ojnkhon_^n<01?n_^n<0
0ol0003o/;cSok2lh`0;ok2lh`03o`000?n`_N?o/;gS00[o/;gS00Co0000ok6ni?l0003o00002_nc
_n<2o`0006kooooo000Uooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?nZ_>OoZ[cW00_oZ[cW00?o0000ojZki_nZ^nH01?nZ^nH3o`000003ojNkiol0
003oYk[V00coYk[V00?o0000ojRii_nX^NH02_nX^NH00ol0003oZ;SUojRhi@0:ojRhi@03o`000?nX
^>CoZ;ST00KoZ;ST0ol000000onX^>Go0000ojVhi00;ojVhi003o`000?nZ^>CoZ[ST00[oZ[ST00?o
0000oj^ihon[^N<02_n[^N<00ol0003o[;[Sojbjh`06ojbjh`?o000000?o[K_So`000?n_^n<01On_
^n<00ol0003o[k_Sojnkh`04ojnkh`03o`000?n`_>?o/;cS00_o/;cS00?o0000ok2mhon`_N<02_n`
_N<2o`0000go/koS00?o0000ooooooooool0K?ooool002Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooooooo00Kooooo00?o0000ojZlionZ_>L02onZ_>L00ol0003oZ[_VojZk
iP03o`0000GoYk_W00?o0000ojNji_nW^^H02onW^^H00ol0003oZ;WVojRiiP09ojRiiP03o`000?nX
^>GoZ;SU00_oZ;SU00?o0000ojRhi?nX^>@00onX^>@2o`0000GoZ;SU00?o0000ojVhi?nY^>@02_nY
^>@00ol0003oZ[STojZhi00:ojZhi003o`000?n[^N?oZkWS00[oZkWS00?o0000ojbjhon/^^<00on/
^^<2o`0000Go[K_S00?o0000ojnkhon_^n<00on_^n<00ol0003o[k_Sojnkh`05ojnkh`03o`000?n`
_>?o/;cS00_o/;cS00?o0000ok2mhon`_N<01_n`_N<3o`000003ok:nhol0003o/koS00go/koS00?o
0000ooooooooool0Joooool0033ooooo00?o0000ooooooooool01oooool00ol0003oZ[cWojZli`0:
ojZli`?o00002OnW^nL00ol0003oYk[VojNjiP0;ojNjiP03o`000?nX^NKoZ;WV00WoZ;WV00?o0000
ojRhiOnX^>D02onX^>D00ol0003oZ;STo`000002o`0000SoZ;SU00?o0000ojVhi?nY^>@02OnY^>@0
0ol0003oZ[STojZhi00;ojZhi003o`000?n[^N?oZkWS00[oZkWS00?o0000ojbjhol000000_l00008
ojfkh`03o`000?n_^n?o[k_S00;o[k_S00?o0000ojnkhon_^n<01_n_^n<00ol0003o/;cSok2lh`0;
ok2lh`03o`000?n`_N?o/;gS00?o/;gS0_l00005ok:nh`03o`000?nc_n?o/koS00co/koS00?o0000
ooooooooool0J_ooool0033ooooo00?o0000ooooooooool02?ooool00ol0003oZ[cWojZli`06ojZl
i`?o000000?oYkcXo`000?nW^nL02_nW^nL00ol0003oYk[VojNjiP0;ojNjiP03o`000?nX^NKoZ;WV
00WoZ;WV00?o0000ojRhiOnX^>D02_nX^>D2o`0000coZ;SU00?o0000ojVhi?nY^>@02OnY^>@00ol0
003oZ[STojZhi00:ojZhi003o`000?n[^N?oZkWS00[oZkWS0_l0000<ojfkh`05o`000?n_^n?o[k_S
ojnkhol000002On_^n<00ol0003o/;cSok2lh`0;ok2lh`03o`000?n`_N?o000000;o00002?nb_^<0
0ol0003o/koSok>oh`0;ok>oh`03o`000?oooooooooo06[ooooo000_ooooo`;o00002oooool00ol0
003oZ[cWojZli`03ojZli`;o00001OnW_>P00ol0003oYk_WojNki`09ojNki`03o`000?nW^^KoYk[V
00[oYk[V00?o0000ojRii_nX^NH02_nX^NH00ol0003oZ;SUojRhi@06ojRhi@?o000000?oYkSVo`00
0?nX^>D03?nX^>D00ol0003oZKSTojVhi009ojVhi003o`000?nZ^>CoZ[ST00[oZ[ST00?o0000oj^i
hon[^N<01_n[^N<3o`000003ojbji?l0003o[K_S00co[K_S00Co0000ojnkhon_^n?o00002_n_^n<0
0ol0003o/;cSok2lh`0:ok2lh`;o00003?nb_^<00ol0003o/koSok>oh`0;ok>oh`03o`000?oooooo
oooo06Wooooo000`ooooo`03o`000?oooooooooo00[ooooo00?o0000ojZliol000000_l00008ojNl
j003o`000?nW^nOoYk_W00WoYk_W00?o0000ojNji_nW^^H02_nW^^H00ol0003oZ;WVojRiiP0:ojRi
iP03o`000?nX^>GoZ;SU00?oZ;SU0_l00005ojNhiP03o`000?nX^>GoZ;SU00[oZ;SU00?o0000ojVh
i?nY^>@02_nY^>@00ol0003oZ[STojZhi00:ojZhi003o`000?n[^N?oZkWS00?oZkWS0_l00005ojbj
i003o`000?n]^n?o[K_S00[o[K_S00Co0000ojnkhon_^n?o00002_n_^n<00ol0003o/;cSok2lh`08
ok2lh`;o000000?o/KgSo`000?nb_^<03?nb_^<00ol0003o/koSok>oh`0;ok>oh`03o`000?oooooo
oooo06Sooooo000_ooooo`03o`000?oooooooooo00cooooo00?o0000ojNlj?nW_>P02_nW_>P00ol0
003oYk_WojNki`09ojNki`03o`000?nW^^KoYk[V00[oYk[V00?o0000ojRii_nX^NH02_nX^NH00ol0
003oZ;SUo`000002o`0000SoYkSV00?o0000ojRhiOnX^>D02_nX^>D00ol0003oZKSTojVhi00:ojVh
i003o`000?nZ^>CoZ[ST00[oZ[ST00?o0000oj^ihol000000_l00008ojbji003o`000?n]^n?o[K_S
00[o[K_S00?o0000ojnkhol000002on_^n<00ol0003o/;cSok2lh`05ok2lh`;o00001?na_N<00ol0
003o/[kSok:nh`0:ok:nh`03o`000?nc_n?o/koS00co/koS00?o0000ooooooooool0Ioooool002oo
oooo00?o0000ooooooooool03Oooool00ol0003oYkcXojNlj00:ojNlj003o`000?nW^nOoYk_W00Wo
Yk_W00?o0000ojNji_nW^^H02_nW^^H00ol0003oZ;WVojRiiP08ojRiiP?o00003?nW^>H00ol0003o
Z;SUojRhi@0:ojRhi@03o`000?nY^>CoZKST00WoZKST00?o0000ojZhi?nZ^>@02_nZ^>@2o`0000co
[;[T00?o0000ojfkhon]^n<02_n]^n<2o`0000co[k_S00?o0000ok2lhon`_><00_n`_><2o`0000Oo
/KgS00?o0000ok:nhonb_^<02_nb_^<00ol0003o/koSok>oh`0;ok>oh`03o`000?oooooooooo06Oo
oooo000_ooooo`03o`000?oooooooooo00kooooo00?o0000ojNlj?nW_>P02_nW_>P00ol0003oYk_W
ojNki`09ojNki`03o`000?nW^^KoYk[V00[oYk[V00?o0000ojRii_nX^NH01?nX^NH3o`0000;oY[WV
00?o0000ojNhi_nW^>H02onW^>H00ol0003oZ;SUojRhi@0:ojRhi@03o`000?nY^>CoZKST00WoZKST
00?o0000ojZhi?nZ^>@01_nZ^>@3o`000003ojZii?l0003o[;[T00_o[;[T00?o0000ojfkhon]^n<0
2on]^n<00ol0003o[k_Sojnkh`0;ojnkh`04o`000?n`_>?o0000o`0000[o/KgS00?o0000ok:nhonb
_^<02_nb_^<00ol0003o/koSok>oh`0;ok>oh`03o`000?oooooooooo06Kooooo000_ooooo`03o`00
0?oooooooooo00oooooo00?o0000ojNlj?nW_>P02_nW_>P00ol0003oYk_WojNki`09ojNki`03o`00
0?nW^^KoYk[V00[oYk[V00?o0000ojRii_nX^NH00ol00006ojJiiP03o`000?nW^>KoYkSV00[oYkSV
00?o0000ojRhiOnX^>D02onX^>D00ol0003oZKSTojVhi009ojVhi003o`000?nZ^>CoZ[ST00?oZ[ST
0_l00005ojZii003o`000?n/^^Co[;[T00[o[;[T00?o0000ojfkhon]^n<02_n]^n<00ol0003o[k_S
ojnkh`0;ojnkh`;o00003Ona_N<00ol0003o/[kSok:nh`0:ok:nh`03o`000?nc_n?o/koS00[o/koS
0_l0001Wooooo`00;_ooool3o`00017ooooo00?o0000ojNlj?nW_>P02OnW_>P00ol0003oYk_WojNk
i`0:ojNki`03o`000?nW^^KoYk[V00SoYk[V1?l0000:ojJiiP03o`000?nW^>KoYkSV00[oYkSV00?o
0000ojRhiOnX^>D02_nX^>D00ol0003oZKSTojVhi00:ojVhi003o`000?nZ^>Co000000;o00002?nZ
^N@00ol0003o[;[Tojbji00:ojbji003o`000?n]^n?o[K_S00Wo[K_S0_l00009ojnkh`?o000000?o
/;gSo`000?na_N<03?na_N<00ol0003o/[kSok:nh`0:ok:nh`03o`000?nc_n?o/koS00So/koS0_l0
00000ond`>?o0000o`00001Vooooo`00;oooool00ol0003oooooooooo`0Aooooo`03o`000?nW_>So
YkcX00WoYkcX00?o0000ojNkionW^nL02_nW^nL00ol0003oYk[VojNjiP04ojNjiP?o00000_nU^NL0
0ol0003oY[WVojJiiP0:ojJiiP03o`000?nW^>KoYkSV00[oYkSV00?o0000ojRhiOnX^>D02_nX^>D0
0ol0003oZKSTojVhi008ojVhi0?o00003?nZ^N@00ol0003o[;[Tojbji00:ojbji003o`000?n]^n?o
[K_S00So[K_S00?o0000ojfkhol000001On_^n<3o`0000Go/;gS00?o0000ok6mhona_N<02ona_N<0
0ol0003o/[kSok:nh`0:ok:nh`03o`000?nc_n?o/koS00Go/koS0_l00004okC0h`03o`000?oooooo
oooo06Cooooo000_ooooo`03o`000?oooooooooo01;ooooo00?o0000ojNlj?nW_>P02OnW_>P00ol0
003oYk_WojNki`0:ojNki`03o`000?nW^^KoYk[V00?o00001_nU^NL00ol0003oY[WVojJiiP0:ojJi
iP03o`000?nW^>KoYkSV00[oYkSV00?o0000ojRhiOnX^>D02_nX^>D00ol0003oZKSTojVhi004ojVh
i0?o00000_nY^ND00ol0003oZ[WTojZii00:ojZii003o`000?n/^^Co[;[T00[o[;[T00?o0000ojfk
hon]^n<02?n]^n<01Ol0003o[K_Sojfkhol0003o[k_S00?o00002On`_N<00ol0003o/KgSok6mh`0;
ok6mh`03o`000?nb_^?o/[kS00[o/[kS00?o0000ok>ohonc_n<00_nc_n<2o`0000Oo]<3S00?o0000
ooooooooool0Hoooool002oooooo00?o0000ooooooooool04oooool00ol0003oYkcXojNlj009ojNl
j003o`000?nW^nOoYk_W00SoYk_W1?l0000:ojFii`03o`000?nV^NKoY[WV00[oY[WV00?o0000ojNh
i_nW^>H02_nW^>H00ol0003oZ;SUojRhi@0:ojRhi@03o`000?nY^>CoZKST00?o00001_nY^ND00ol0
003oZ[WTojZii00:ojZii003o`000?n/^^Co[;[T00[o[;[T00?o0000ojfkhon]^n<01on]^n<00ol0
003o[K_Sojfkh`02o`0000go/;gS00?o0000ok6mhona_N<02ona_N<00ol0003o/[kSok:nh`0:ok:n
h`04o`000?nc_n?o0000o`0000[o]<3S00?o0000ooooooooool0H_ooool002oooooo00?o0000oooo
ooooool04oooool2o`0000_oYkcX00?o0000ojNkionW^nL01?nW^nL3o`0000;oY;[X00?o0000ojFi
ionU^NL02_nU^NL00ol0003oY[WVojJiiP0:ojJiiP03o`000?nW^>KoYkSV00WoYkSV00?o0000ojRh
iOnX^>D02_nX^>D3o`0000[oZKWU00?o0000ojZii?nZ^N@02_nZ^N@00ol0003o[;[Tojbji00:ojbj
i003o`000?n]^n?o[K_S00Ko[K_S0ol000000on^_>?o0000ok2mh`0<ok2mh`03o`000?na_N?o/KgS
00_o/KgS00?o0000ok:nhonb_^<02_nb_^<2o`0000co]<3S0_l0001Sooooo`00;_ooool00ol0003o
ooooooooo`0Eooooo`;o00002onW_>P00ol0003oYk_WojNki`03o`0000KoY;[X00?o0000ojFiionU
^NL02_nU^NL00ol0003oY[WVojJiiP09ojJiiP03o`000?nW^>KoYkSV00[oYkSV00?o0000ojRhiOnX
^>D01_nX^>D3o`000003ojNhi_l0003oZKWU00_oZKWU00?o0000ojZii?nZ^N@02_nZ^N@00ol0003o
[;[Tojbji009ojbji003o`000?n]^n?o[K_S00Go[K_S0_l00004ojjlh`03o`000?n`_N?o/;gS00_o
/;gS00?o0000ok6mhona_N<02ona_N<00ol0003o/[kSok:nh`06ok:nh`?o000000?o/koSo`000?nd
`><03?nd`><00ol0003oooooooooo`1Qooooo`00;_ooool3o`0001Kooooo0_l0000:ojNlj0?o0000
2_nT^^P00ol0003oYKWWojFii`0:ojFii`03o`000?nV^NKoY[WV00WoY[WV00?o0000ojNhi_nW^>H0
2_nW^>H00ol0003oZ;SUojRhi@03ojRhi@;o00001OnW^>H00ol0003oZKWUojVii@0:ojVii@03o`00
0?nZ^NCoZ[WT00WoZ[WT00?o0000ojbji?n/^^@02_n/^^@00ol0003o[K_Sojfkh`02ojfkh`;o0000
00?o[[cSo`000?n^_><01?n^_><00ol0003o/;gSok2mh`0;ok2mh`03o`000?na_N?o/KgS00_o/KgS
00?o0000ok:nhonb_^<00onb_^<2o`0000Go/koS00?o0000okC0hond`><02ond`><00ol0003ooooo
ooooo`1Pooooo`00;_ooool00ol0003oooooooooo`0Gooooo`;o00001_nW_>P3o`000003ojBkjOl0
003oY;[X00_oY;[X00?o0000ojFiionU^NL02_nU^NL00ol0003oY[WVojJiiP09ojJiiP03o`000?nW
^>KoYkSV00[oYkSV00?o0000ojRhiOl000000_l00008ojNhiP03o`000?nY^NGoZKWU00WoZKWU00?o
0000ojZii?nZ^N@02_nZ^N@00ol0003o[;[Tojbji00:ojbji004o`000?n]^n?o0000o`0000?o[[cS
00?o0000ojjlhon^_><01?n^_><00ol0003o/;gSok2mh`0:ok2mh`03o`000?na_N?o/KgS00co/KgS
00?o0000ok:nhol000000_l00008ok>oh`03o`000?nd`>?o]<3S00_o]<3S00?o0000ooooooooool0
Goooool001;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Oooooo
00?o0000ooooooooool06?ooool2o`0000;oYkcX0ol00005ojBkj@03o`000?nT^^SoY;[X00[oY;[X
00?o0000ojFiionU^NL02OnU^NL00ol0003oY[WVojJiiP0:ojJiiP03o`000?nW^>KoYkSV00SoYkSV
0ol0000<ojNhiP03o`000?nY^NGoZKWU00WoZKWU00?o0000ojZii?nZ^N@02_nZ^N@00ol0003o[;[T
ojbji009ojbji0;o00001On^_><00ol0003o[[cSojjlh`05ojjlh`03o`000?n`_N?o/;gS00[o/;gS
00?o0000ok6mhona_N<02ona_N<2o`0000co/koS00?o0000okC0hond`><02ond`><00ol0003ooooo
ooooo`1Nooooo`004_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01oooool00ol0003oooooooooo`0Iooooo`?o00002OnT^nT00ol0003o
Y;[XojBjj00:ojBjj003o`000?nU^NOoYKWW00WoYKWW00?o0000ojJii_nV^NH02_nV^NH00ol0003o
YkSVojNhiP04ojNhiP?o00000_nU^>H00ol0003oYkSVojNhiP0:ojNhiP03o`000?nY^NGoZKWU00[o
ZKWU00?o0000ojZii?nZ^N@02OnZ^N@00ol0003o[;[Tojbji006ojbji0?o000000?o[K_To`000?n^
_><01?n^_><00ol0003o[[cSojjlh`05ojjlh`03o`000?n`_N?o/;gS00_o/;gS00?o0000ok6mhona
_N<02?na_N<2o`000003ok:nhol0003o/koS00_o/koS00?o0000okC0hond`><02ond`><00ol0003o
ooooooooo`1Nooooo`004_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h02?ooool00ol0003oooooooooo`0Jooooo`03o`000?nT^nWoY;_Y00WoY;_Y00?o0000ojBjj?nT
^^P02_nT^^P00ol0003oYKWWojFii`09ojFii`03o`000?nV^NKoY[WV00[oY[WV00?o0000ojNhi_nW
^>H00ol00006ojFhiP03o`000?nW^>KoYkSV00[oYkSV00?o0000ojViiOnY^ND02_nY^ND00ol0003o
Z[WTojZii009ojZii003o`000?n/^^Co[;[T00?o[;[T0_l00005ojfki003o`000?n^_>?o[[cS00;o
[[cS00?o0000ojjlhon^_><01_n^_><00ol0003o/;gSok2mh`0;ok2mh`03o`000?na_N?o/KgS00Co
/KgS0ol00004ok:nh`03o`000?nc_n?o/koS00[o/koS00?o0000okC0hond`><02ond`><00ol0003o
ooooooooo`1Mooooo`004_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^
k^h01oooool00ol0003oooooooooo`0Kooooo`03o`000?nT^nWoY;_Y00WoY;_Y00?o0000ojBjj?nT
^^P02OnT^^P00ol0003oYKWWojFii`0:ojFii`03o`000?nV^NKoY[WV00SoY[WV1?l0000:ojFhiP03
o`000?nW^>KoYkSV00[oYkSV00?o0000ojViiOnY^ND02OnY^ND00ol0003oZ[WTojZii00:ojZii003
o`000?n/^^Co000000;o00002?n]^n@01Ol0003o[[cSojjlhon^_>?o000000Wo[[cS00?o0000ok2m
hon`_N<02_n`_N<00ol0003o/KgSok6mh`02ok6mh`;o00002?nb_^<00ol0003o/koSok>oh`0:ok>o
h`03o`000?nd`>?o]<3S00_o]<3S00?o0000ooooooooool0G?ooool001;ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Kooooo00?o0000ooooooooool07?ooool00ol0
003oY;_YojBkj@09ojBkj@03o`000?nT^^SoY;[X00WoY;[X00?o0000ojFiionU^NL02_nU^NL00ol0
003oY[WVojJiiP04ojJiiP?o00000_nT^>L00ol0003oYKSVojFhiP0:ojFhiP03o`000?nW^>KoYkSV
00[oYkSV00?o0000ojViiOnY^ND02OnY^ND00ol0003oZ[WTojZii008ojZii0?o00003?n]^n@01?l0
003o[[cSojjlhol0000:ojjlh`03o`000?n`_N?o/;gS00[o/;gS00Co0000ok6mhol0003o00002onb
_^<00ol0003o/koSok>oh`0:ok>oh`03o`000?nd`>?o]<3S00[o]<3S0_l0001Mooooo`004_ooool0
1Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool2o`0001oooooo00?o
0000ojBkjOnT^nT02OnT^nT00ol0003oY;[XojBjj009ojBjj003o`000?nU^NOoYKWW00[oYKWW00?o
0000ojJii_nV^NH00ol00006ojBhi`03o`000?nU^>KoYKSV00[oYKSV00?o0000ojNhi_nW^>H02OnW
^>H00ol0003oZKWUojVii@0:ojVii@03o`000?nZ^NCoZ[WT00CoZ[WT0ol00002oj^ji@03o`000?n]
^nCo[K_T00_o[K_T00?o0000ojjlhol000002_n^_><00ol0003o/;gSok2mh`0:ok2mh`;o00003Onb
_^<00ol0003o/koSok>oh`0;ok>oh`03o`000?nd`>?o]<3S00Oo]<3S0_l000000one`>?o0000oooo
o`1Looooo`004_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RH
oa0@4006ooooo`03o`000?oooooooooo01oooooo00?o0000ojBkjOnT^nT02OnT^nT00ol0003oY;[X
ojBjj009ojBjj003o`000?nU^NOoYKWW00SoYKWW1?l0000:ojBhi`03o`000?nU^>KoYKSV00WoYKSV
00?o0000ojNhi_nW^>H02_nW^>H00ol0003oZKWUojVii@0:ojVii@03o`000?nZ^NCoZ[WT00?o0000
1_n[^^D00ol0003o[K_Tojfki00;ojfki0;o00002on^_><00ol0003o/;gSok2mh`06ok2mh`?o0000
00?o/KkSo`000?nb_^<03Onb_^<00ol0003o/koSok>oh`0:ok>oh`03o`000?nd`>?o]<3S00Go]<3S
0_l00004okG0h`03o`000?oooooooooo05[ooooo000Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool08?ooool00ol0003o
Y;_YojBkj@09ojBkj@03o`000?nT^^SoY;[X00WoY;[X00?o0000ojFiionU^NL01?nU^NL3o`0000;o
XkWX00?o0000ojBhionT^>L02_nT^>L00ol0003oYKSVojFhiP09ojFhiP03o`000?nW^>KoYkSV00[o
YkSV00?o0000ojViiOnY^ND02OnY^ND3o`0000[oZk[U00?o0000ojfki?n]^n@02on]^n@00ol0003o
[[cSojjlh`0:ojjlh`03o`000?n`_N?o/;gS00?o/;gS0_l00005ok6nh`03o`000?nb_^?o/[kS00co
/[kS00?o0000ok>ohonc_n<02_nc_n<00ol0003o]<3SokC0h`02okC0h`;o00001one`><00ol0003o
ooooooooo`1Iooooo`00;Oooool00ol0003oooooooooo`0Qooooo`03o`000?nT^nWoY;_Y00WoY;_Y
00?o0000ojBjj?nT^^P02OnT^^P00ol0003oYKWWojFii`03o`0000KoXkWX00?o0000ojBhionT^>L0
2_nT^>L00ol0003oYKSVojFhiP09ojFhiP03o`000?nW^>KoYkSV00WoYkSV00?o0000ojViiOnY^ND0
1_nY^ND3o`000003ojRji_l0003oZk[U00_oZk[U00?o0000ojfki?n]^n@02_n]^n@00ol0003o[[cS
ojjlh`0;ojjlh`03o`000?n`_N?o000000;o00002?na_^<00ol0003o/[kSok:nh`0;ok:nh`03o`00
0?nc_n?o/koS00_o/koS00Co0000okC0hol0003o00002_ne`><00ol0003oooooooooo`1Hooooo`00
;Oooool00ol0003oooooooooo`0Qooooo`03o`000?nT^nWoY;_Y00[oY;_Y00?o0000ojBjj?nT^^P0
2?nT^^P3o`0000[oXkWX00?o0000ojBhionT^>L02_nT^>L00ol0003oYKSVojFhiP09ojFhiP03o`00
0?nW^>KoYkSV00WoYkSV00?o0000ojViiOnY^ND00onY^ND2o`0000GoZ;[V00?o0000oj^jiOn[^^D0
2_n[^^D00ol0003o[K_Tojfki009ojfki0;o00003?n^_><2o`0000co/KkS00?o0000ok:nhonb_^<0
2onb_^<00ol0003o/koSok>oh`0:ok>oh`;o00003?ne`><00ol0003oooooooooo`1Hooooo`00;Ooo
ool00ol0003oooooooooo`0Rooooo`03o`000?nT^nWoY;_Y00[oY;_Y00?o0000ojBjj?nT^^P01?nT
^^P3o`000003oj:ijOl0003oXkWX00_oXkWX00?o0000ojBhionT^>L02_nT^>L00ol0003oYKSVojFh
iP08ojFhiP03o`000?nW^>KoYkSV00[oYkSV00?o0000ojViiOl000000_l00008ojRjiP03o`000?n[
^^GoZk[U00[oZk[U00?o0000ojfki?n]^n@02?n]^n@00ol0003o[K_To`000008ojjlh`?o000000?o
[kgTo`000?na_^<03?na_^<00ol0003o/[kSok:nh`0;ok:nh`03o`000?nc_n?o/koS00Oo/koS0_l0
00000ond`>?o0000okG0h`0<okG0h`03o`000?oooooooooo05Oooooo000/ooooo`?o00009?ooool0
0ol0003oY;_YojBkj@0:ojBkj@03o`000?nT^^SoY;[X00?o00001OnR^NT00ol0003oXkWXoj>ij00:
oj>ij003o`000?nT^>OoY;SW00WoY;SW00?o0000ojFhi_nU^>H02OnU^>H00ol0003oYkSVojNhiP08
ojNhiP?o00003?nX^^H00ol0003oZk[Uoj^ji@0:oj^ji@03o`000?n]^nCo[K_T00Oo[K_T00Co0000
ojfki?n]^nCo00001On^_><2o`0000Go[kgT00?o0000ok6nhona_^<02ona_^<00ol0003o/[kSok:n
h`0;ok:nh`03o`000?nc_n?o/koS00Co/koS0_l00004okC0h`03o`000?ne`>?o]L3S00_o]L3S00?o
0000ooooooooool0E_ooool002gooooo00?o0000ooooooooool09?ooool00ol0003oY;_YojBkj@08
ojBkj@Co00002OnR^NT00ol0003oXkWXoj>ij00:oj>ij003o`000?nT^>OoY;SW00WoY;SW00?o0000
ojFhi_nU^>H02OnU^>H00ol0003oYkSVojNhiP04ojNhiP?o00000_nV^NH00ol0003oZ;[VojRjiP0;
ojRjiP03o`000?n[^^GoZk[U00WoZk[U00?o0000ojfki?n]^n@01on]^n@01_l0003o[K_Tojfki?n]
^nCo0000ojjlh`?o00002?n__N@00ol0003o/KkSok6nh`0;ok6nh`03o`000?nb_^?o/[kS00[o/[kS
00?o0000ok>ohonc_n<00_nc_n<2o`0000Oo]<3S00?o0000okG0hone`><02one`><00ol0003ooooo
ooooo`1Eooooo`00;Oooool00ol0003oooooooooo`0Uooooo`03o`000?nT^nWoY;_Y00CoY;_Y0ol0
0002oj6jjP03o`000?nR^NWoX[WY00WoX[WY00?o0000oj>ij?nS^NP02_nS^NP00ol0003oY;SWojBh
i`09ojBhi`03o`000?nU^>KoYKSV00WoYKSV00?o0000ojNhi_nW^>H00ol00006ojJiiP03o`000?nX
^^KoZ;[V00[oZ;[V00?o0000oj^jiOn[^^D02_n[^^D00ol0003o[K_Tojfki006ojfki004o`000?n]
^nCo[K_Tojfki0;o00003?n__N@00ol0003o/KkSok6nh`0:ok6nh`03o`000?nb_^?o/[kS00_o/[kS
00Co0000ok>ohol0003o00002_nd`><00ol0003o]L3SokG0h`0:okG0h`;o0000E_ooool002gooooo
00?o0000ooooooooool09_ooool00ol0003oY;_YojBkj@03o`0000KoXK[Z00?o0000oj:ijOnR^NT0
2OnR^NT00ol0003oXkWXoj>ij009oj>ij003o`000?nT^>OoY;SW00[oY;SW00?o0000ojFhi_nU^>H0
2?nU^>H3o`0000[oY[WV00?o0000ojRji_nX^^H02_nX^^H00ol0003oZk[Uoj^ji@0:oj^ji@03o`00
0?n]^nCo[K_T00Go[K_T1?l000000on]_>Go0000ojnmi00<ojnmi003o`000?na_^?o/KkS00[o/KkS
00?o0000ok:nhonb_^<02_nb_^<2o`0000co]<3S00?o0000okG0hone`><02one`><00ol0003ooooo
ooooo`1Dooooo`00;?ooool00ol0003oooooooooo`0Xooooo`;o00002_nQ^^X00ol0003oX[WYoj:i
j@09oj:ij@03o`000?nS^NSoXkWX00WoXkWX00?o0000ojBhionT^>L02_nT^>L00ol0003oYKSVojFh
iP04ojFhiP?o000000?oY;WWo`000?nV^NH02onV^NH00ol0003oZ;[VojRjiP0:ojRjiP03o`000?n[
^^GoZk[U00[oZk[U00?o0000ojfki?n]^n@00on]^n@2o`0000Go[KcU00?o0000ojnmi?n__N@02_n_
_N@00ol0003o/KkSok6nh`0;ok6nh`03o`000?nb_^?o/[kS00Ko/[kS0ol000000onc_n?o0000okC0
h`0<okC0h`03o`000?ne`>?o]L3S00_o]L3S00?o0000ooooooooool0Doooool002cooooo00?o0000
ooooooooool0:Oooool00ol0003oXK[Zoj6jjP09oj6jjP03o`000?nR^NWoX[WY00WoX[WY00?o0000
oj>ij?nS^NP02OnS^NP00ol0003oY;SWojBhi`0:ojBhi`03o`000?nU^>KoYKSV00?o00001OnT^NL0
0ol0003oY[WVojJiiP0:ojJiiP03o`000?nX^^KoZ;[V00[oZ;[V00?o0000oj^jiOn[^^D02_n[^^D0
0ol0003o[K_To`000002o`000003ojfliOl0003o[KcU00Go[KcU00?o0000ojnmi?n__N@02_n__N@0
0ol0003o/KkSok6nh`0;ok6nh`03o`000?nb_^?o/[kS00?o/[kS0_l00005ok>oh`03o`000?nd`>?o
]<3S00_o]<3S00?o0000okG0hone`><02one`><00ol0003oooooooooo`1Booooo`00;?ooool2o`00
02_ooooo00?o0000oj6jj_nQ^^X02OnQ^^X00ol0003oX[WYoj:ij@09oj:ij@03o`000?nS^NSoXkWX
00WoXkWX00?o0000ojBhionT^>L02?nT^>L4o`0000WoY;WW00?o0000ojJii_nV^NH02_nV^NH00ol0
003oZ;[VojRjiP09ojRjiP03o`000?n[^^GoZk[U00[oZk[U0_l00004ojfli@03o`000?n]_>Go[KcU
00Go[KcU00?o0000ojnmi?n__N@02_n__N@00ol0003o/KkSok6nh`0;ok6nh`03o`000?nb_^?o0000
00;o00002?nc_n<00ol0003o]<3SokC0h`0;okC0h`03o`000?ne`>?o]L3S00[o]L3S0_l0001Coooo
o`00;?ooool00ol0003oooooooooo`0[ooooo`03o`000?nQ^^[oXK[Z00WoXK[Z00?o0000oj:ijOnR
^NT02OnR^NT00ol0003oXkWXoj>ij009oj>ij003o`000?nT^>OoY;SW00CoY;SW0ol00002oj:hj003
o`000?nT^NOoY;WW00WoY;WW00?o0000ojJii_nV^NH02_nV^NH00ol0003oZ;[VojRjiP09ojRjiP03
o`000?n[^^GoZk[U00KoZk[U0ol000000on[^nGo0000ojfli@03ojfli@03o`000?n]_>Go[KcU00Ko
[KcU00?o0000ojnmi?n__N@02_n__N@00ol0003o/KkSok6nh`0:ok6nh`;o00003?nc_n<00ol0003o
]<3SokC0h`0;okC0h`03o`000?ne`>?o]L3S00Oo]L3S0_l000000one`N?o0000ooooo`1Booooo`00
;?ooool00ol0003oooooooooo`0/ooooo`03o`000?nQ^^[oXK[Z00WoXK[Z00?o0000oj:ijOnR^NT0
2OnR^NT00ol0003oXkWXoj>ij009oj>ij003o`000?nT^>OoY;SW00?o00001_nR^>P00ol0003oY;WW
ojBii`09ojBii`03o`000?nV^NKoY[WV00[oY[WV00?o0000ojRji_nX^^H02OnX^^H00ol0003oZk[U
oj^ji@03oj^ji@;o00001On[^nD01Ol0003o[KcUojfliOn]_>Go000000So[KcU00?o0000ojnmi?n_
_N@02_n__N@00ol0003o/KkSok6nh`08ok6nh`;o000000?o/[oTo`000?nc_n<02onc_n<00ol0003o
]<3SokC0h`0;okC0h`03o`000?ne`>?o]L3S00Go]L3S0_l00004okG1h`03o`000?oooooooooo053o
oooo000/ooooo`03o`000?oooooooooo02gooooo00?o0000oj6jj_nQ^^X02OnQ^^X00ol0003oX[WY
oj:ij@09oj:ij@03o`000?nS^NSoXkWX00OoXkWX1?l0000:oj:hj003o`000?nT^NOoY;WW00WoY;WW
00?o0000ojJii_nV^NH02_nV^NH00ol0003oZ;[VojRjiP09ojRjiP03o`000?n[^^Go000000;o0000
2?n[^nD01?l0003o[KcUojfliOl00009ojfli@03o`000?n__NCo[kgT00[o[kgT00?o0000ok6nhona
_^<01Ona_^<2o`0000Co/[oT00?o0000ok>ohonc_n<02_nc_n<00ol0003o]<3SokC0h`0;okC0h`03
o`000?ne`>?o]L3S00;o]L3S0_l00007okG1h`03o`000?oooooooooo04oooooo000/ooooo`03o`00
0?oooooooooo02kooooo00?o0000oj6jj_nQ^^X02OnQ^^X00ol0003oX[WYoj:ij@09oj:ij@04o`00
0?nS^NSoXkWXoj>ij0Go00000_nQ^>T00ol0003oX[SXoj:hj00:oj:hj003o`000?nT^NOoY;WW00Wo
Y;WW00?o0000ojJii_nV^NH02_nV^NH00ol0003oZ;[VojRjiP08ojRjiP;o00003?n[^nD00ol0003o
[KcUo`00000:ojfli@03o`000?n__NCo[kgT00[o[kgT00?o0000ok6nhona_^<00_na_^<2o`0000Oo
/[oT00?o0000ok>ohonc_n<02_nc_n<00ol0003o]<3SokC0h`0;okC0h`04o`000?ne`>?o0000o`00
00Wo]L7S0_l0001@ooooo`00;?ooool00ol0003oooooooooo`0_ooooo`03o`000?nQ^^[oXK[Z00Wo
XK[Z00?o0000oj:ijOnR^NT02?nR^NT4o`0000SoXKSY00?o0000oj:hj?nR^>P02_nR^>P00ol0003o
Y;WWojBii`08ojBii`03o`000?nV^NKoY[WV00_oY[WV00?o0000ojRji_nX^^H01?nX^^H3o`000003
ojRki_l0003oZk_U00coZk_U0_l0000;ojfli@03o`000?n__NCo[kgT00[o[kgT00Co0000ok6nhol0
003o00002_nb_n@00ol0003o/koSok>oh`0:ok>oh`03o`000?nd`>?o]<3S00[o]<3S0_l0000<okG1
h`03o`000?oooooooooo04kooooo000/ooooo`;o0000<Oooool00ol0003oXK[Zoj6jjP09oj6jjP03
o`000?nR^NWoX[WY00CoX[WY0ol000000onP^N[o0000oj6hj@0:oj6hj@03o`000?nR^>SoX[SX00[o
X[SX00?o0000ojBiionT^NL02?nT^NL00ol0003oY[WVojJiiP0;ojJiiP03o`000?nX^^KoZ;[V00?o
00001OnX^nH00ol0003oZk_Uoj^ki@0:oj^ki@;o00002on]_>D00ol0003o[kgTojnmi00:ojnmi0;o
00003?nb_n@00ol0003o/koSok>oh`0;ok>oh`03o`000?nd`>?o]<3S00Oo]<3S0_l000000ond`N?o
0000okG1h`0<okG1h`03o`000?oooooooooo04gooooo000[ooooo`03o`000?oooooooooo03;ooooo
00?o0000oj6jj_nQ^^X02OnQ^^X00ol0003oX[WYoj:ij@03o`0000GoX;WZ00?o0000oj6hjOnQ^>T0
2OnQ^>T00ol0003oX[SXoj:hj00:oj:hj003o`000?nT^NOoY;WW00SoY;WW00?o0000ojJii_nV^NH0
2_nV^NH3o`0000WoZ;_V00?o0000oj^kiOn[^nD02_n[^nD00ol0003o[KcUojfli@0:ojfli@03o`00
0?n__NCo[kgT00Ko[kgT0ol000000on`_^Co0000ok:oi00<ok:oi003o`000?nc_n?o/koS00[o/koS
00?o0000okC0hond`><01Ond`><2o`0000Co]<7S00?o0000okG1hone`N<02one`N<00ol0003ooooo
ooooo`1<ooooo`00:oooool00ol0003oooooooooo`0cooooo`03o`000?nQ^^[oXK[Z00SoXK[Z0ol0
0009oj2ijP03o`000?nQ^>WoXKSY00WoXKSY00?o0000oj:hj?nR^>P02OnR^>P00ol0003oY;WWojBi
i`09ojBii`03o`000?nV^NKoY[WV00KoY[WV0ol000000onV^^Oo0000ojRkiP0:ojRkiP03o`000?n[
^nGoZk_U00WoZk_U0_l0000<ojfli@03o`000?n__NCo[kgT00?o[kgT0_l00005ok2ni003o`000?nb
_nCo/[oT00_o/[oT00?o0000ok>ohonc_n<02_nc_n<00ol0003o]<3SokC0h`02okC0h`;o00001ond
`N<00ol0003o]L7SokG1h`0:okG1h`;o0000COooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0=?oo
ool00ol0003oXK[Zoj6jjP04oj6jjP?o000000?oWkW[o`000?nP^NX02_nP^NX00ol0003oXKSYoj6h
j@09oj6hj@03o`000?nR^>SoX[SX00WoX[SX00?o0000ojBiionT^NL02OnT^NL00ol0003oY[WVojJi
iP03ojJiiP;o00001OnV^^L00ol0003oZ;_VojRkiP09ojRkiP03o`000?n[^nGoZk_U00SoZk_U00?o
0000oj^kiOl000003?n]_>D00ol0003o[kgTo`000002o`0000So/;kT00?o0000ok:oi?nb_n@02onb
_n@00ol0003o/koSok>oh`0:ok>oh`04o`000?nd`>?o0000o`0000[o]<7S00?o0000okG1hone`N<0
2_ne`N<2o`0004cooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0eooooo`03o`000?nQ^^[oXK[Z00?o0000
1OnO^N/00ol0003oX;WZoj2ijP09oj2ijP03o`000?nQ^>WoXKSY00WoXKSY00?o0000oj:hj?nR^>P0
2OnR^>P00ol0003oY;WWojBii`09ojBii`03o`000?nV^NKo000000;o00002?nV^^L00ol0003oZ;_V
ojRkiP09ojRkiP03o`000?n[^nGoZk_U00OoZk_U00?o0000oj^kiOl000003?n]_>D2o`0000co/;kT
00?o0000ok:oi?nb_n@02onb_n@00ol0003o/koSok>oh`09ok>oh`;o00003?nd`N<00ol0003o]L7S
okG1h`0;okG1h`03o`000?oooooooooo04[ooooo000@ooooo`05oa0@4?ooooooooooooooool@4100
2oooool5o`0000Kooooo00?o0000ooooooooool0=_ooool2o`0000WoWkW[00?o0000oj2ij_nP^NX0
2OnP^NX00ol0003oXKSYoj6hj@09oj6hj@03o`000?nR^>SoX[SX00WoX[SX00?o0000ojBiionT^NL0
1onT^NL3o`0000coY[[W00?o0000ojRki_nX^nH02OnX^nH00ol0003oZk_Uoj^ki@06oj^ki@04o`00
0?n[^nGoZk_Uo`0000So[KcU0ol000000on^_NGo0000ok2ni00;ok2ni003o`000?nb_nCo/[oT00_o
/[oT00?o0000ok>ohonc_n<01_nc_n<3o`000003ok?0i?l0003o]<7S00co]<7S00?o0000okG1hone
`N<02one`N<00ol0003oooooooooo`19ooooo`004?ooool01Ol0003ooooooooooooooooo000000_o
oooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`0gooooo`03o`000?nO^N_oWkW[
00SoWkW[00?o0000oj2ij_nP^NX02OnP^NX00ol0003oXKSYoj6hj@09oj6hj@03o`000?nR^>SoX[SX
00WoX[SX00Co0000ojBiionT^NOoY;WW1Ol00002oj>ij003o`000?nV^^OoY[[W00_oY[[W00?o0000
ojRki_nX^nH02?nX^nH00ol0003oZk_Uoj^ki@06oj^ki@05o`000?n[^nGoZk_Uoj^kiOl000001On]
_>D2o`0000Go[[gU00?o0000ok2ni?n`_^@02_n`_^@00ol0003o/[oTok:oi00;ok:oi003o`000?nc
_n?o/koS00?o/koS0_l00005ok?0i003o`000?nd`N?o]<7S00_o]<7S00?o0000okG1hone`N<02_ne
`N<2o`0004[ooooo000@ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEoooo
ool00007ooooo`03o`000?oooooooooo03Sooooo00?o0000oinijonO^N/02?nO^N/00ol0003oX;WZ
oj2ijP09oj2ijP03o`000?nQ^>WoXKSY00WoXKSY00?o0000oj:hj?nR^>P02?nR^>P4o`0000SoXkWX
00?o0000ojJjionV^^L02_nV^^L00ol0003oZ;_VojRkiP09ojRkiP03o`000?n[^nGoZk_U00GoZk_U
00?o0000oj^kiOn[^nD00_n[^nD00ol0003o[KcUo`000002o`0000So[[gU00?o0000ok2ni?n`_^@0
2_n`_^@00ol0003o/[oTok:oi00;ok:oi003o`000?nc_n?o000000;o00002?nc`>@00ol0003o]<7S
okC1h`0;okC1h`03o`000?ne`N?o]L7S00[o]L7S0_l00019ooooo`004?ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool2o`0003_ooooo00?o0000oinijonO^N/0
2?nO^N/00ol0003oX;WZoj2ijP09oj2ijP03o`000?nQ^>WoXKSY00WoXKSY00?o0000oj:hj?nR^>P0
1?nR^>P3o`000003oj6ijOl0003oXkWX00[oXkWX00?o0000ojJjionV^^L02_nV^^L00ol0003oZ;_V
ojRkiP09ojRkiP03o`000?n[^nGoZk_U00CoZk_U00Co0000oj^kiOn[^nGoZk_U0ol0000<ojjmi@03
o`000?n`_^Co/;kT00[o/;kT00?o0000ok:oi?nb_n@02_nb_n@2o`0000co/l3T00?o0000okC1hond
`N<02ond`N<00ol0003o]L7SokG1h`07okG1h`;o000000?o]L7So`000?ooool0B?ooool0013ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000oooooooo
ool0>_ooool00ol0003oWkW[oinij`08oinij`03o`000?nP^N[oX;WZ00WoX;WZ00?o0000oj6hjOnQ
^>T02OnQ^>T00ol0003oX[SXoj:hj003o`0000GoXKWY00?o0000oj>ij?nS^NP02OnS^NP00ol0003o
Y[[WojJji`0:ojJji`03o`000?nX^nKoZ;_V00WoZ;_V00?o0000oj^kiOn[^nD00on[^nD4o`0000;o
ZkgV00?o0000ojjmiOn^_ND02_n^_ND00ol0003o/;kTok2ni00;ok2ni003o`000?nb_nCo/[oT00Oo
/[oT0_l000000onb`>Co0000ok?0i00<ok?0i003o`000?nd`N?o]<7S00[o]<7S00?o0000okG1hone
`N<01One`N<2o`0000Co]L7S00?o0000ooooooooool0A_ooool0013ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0??ooool00ol0003o
WkW[oinij`08oinij`03o`000?nP^N[oX;WZ00WoX;WZ00?o0000oj6hjOnQ^>T01onQ^>T4o`0000Wo
XKWY00?o0000oj>ij?nS^NP02OnS^NP00ol0003oY[[WojJji`0:ojJji`03o`000?nX^nKoZ;_V00Wo
Z;_V00?o0000oj^kiOn[^nD00ol00006oj^miP03o`000?n^_NGo[[gU00[o[[gU00?o0000ok2ni?n`
_^@02_n`_^@00ol0003o/[oTok:oi005ok:oi0;o00001?nb`>@00ol0003o/l3Tok?0i00;ok?0i003
o`000?nd`N?o]<7S00[o]<7S00?o0000okG1hone`N<00_ne`N<2o`0000Ko]L7S0_l00017ooooo`00
:_ooool00ol0003oooooooooo`0mooooo`03o`000?nO^N_oWkW[00SoWkW[00?o0000oj2ij_nP^NX0
2OnP^NX01?l0003oXKSYoj6hjOnQ^>T5o`0000;oWkSZ00?o0000oj6ijOnQ^NT02OnQ^NT00ol0003o
XkWXoj>ij009oj>ij003o`000?nV^^OoY[[W00WoY[[W00?o0000ojRki_nX^nH02OnX^nH3o`0000;o
ZkgV00?o0000oj^mi_n[_NH01On[_NH00ol0003o[[gUojjmi@0:ojjmi@03o`000?n`_^Co/;kT00[o
/;kT00?o0000ok:oi?nb_n@00_nb_n@2o`0000Oo//3T00?o0000ok?0i?nc`>@02_nc`>@00ol0003o
]<7SokC1h`0;okC1h`04o`000?ne`N?o0000o`0000Wo]L7S00?o0000ooooooooool0AOooool002[o
oooo00?o0000ooooooooool0?_ooool00ol0003oWkW[oinij`08oinij`03o`000?nP^N[oX;WZ00So
X;WZ1?l00008oinhjP03o`000?nQ^NWoXKWY00WoXKWY00?o0000oj>ij?nS^NP02OnS^NP00ol0003o
Y[[WojJji`09ojJji`03o`000?nX^nKoZ;_V00KoZ;_V0_l000000onX_>Oo0000oj^miP02oj^miP03
o`000?n[_NKoZkgV00KoZkgV00?o0000ojjmiOn^_ND02_n^_ND00ol0003o/;kTok2ni00:ok2ni004
o`000?nb_nCo0000o`0000[o//3T00?o0000ok?0i?nc`>@02_nc`>@00ol0003o]<7SokC1h`0:okC1
h`;o00003?ne`N<00ol0003oooooooooo`14ooooo`00:_ooool00ol0003oooooooooo`0oooooo`03
o`000?nO^N_oWkW[00SoWkW[00?o0000oj2ij_nP^NX01?nP^NX3o`000003oijhjol0003oWkSZ00[o
WkSZ00?o0000oj6ijOnQ^NT02OnQ^NT00ol0003oXkWXoj>ij009oj>ij003o`000?nV^^OoY[[W00Wo
Y[[W00?o0000ojRki_nX^nH00_nX^nH3o`0000CoZ;cW00Co0000oj^mi_n[_NKo00002On[_NH00ol0
003o[[gUojjmi@0:ojjmi@03o`000?n`_^Co/;kT00Wo/;kT0_l0000<ok;0i003o`000?nc`>Co/l3T
00_o/l3T00?o0000okC1hond`N<01_nd`N<3o`000003okC1i?l0003o]L7S00co]L7S00?o0000oooo
ooooool0@oooool002Wooooo0ol00010ooooo`;o00002_nO^N/00ol0003oX;WZoj2ijP03o`0000Go
W[S[00?o0000oinhj_nO^>X02OnO^>X00ol0003oXKWYoj6ij@09oj6ij@03o`000?nS^NSoXkWX00Wo
XkWX00?o0000ojJjionV^^L02OnV^^L01?l0003oZ;_Vo`000?l00008ojRli`03o`000?n[_NKo0000
00[oZkgV00?o0000ojjmiOn^_ND02On^_ND00ol0003o/;kTok2ni006ok2ni0?o000000?o/;oUo`00
0?nb`>@03?nb`>@00ol0003o/l3Tok?0i00;ok?0i003o`000?nd`N?o]<7S00?o]<7S0_l00005okC1
i003o`000?ne`N?o]L7S00[o]L7S0_l00014ooooo`00:_ooool00ol0003oooooooooo`10ooooo`;o
00002?nO^N/4o`0000WoW[S[00?o0000oinhj_nO^>X02OnO^>X00ol0003oXKWYoj6ij@08oj6ij@03
o`000?nS^NSoXkWX00[oXkWX00?o0000ojJjionV^^L01onV^^L3o`0000_oZ;cW0_l0000;oj^miP03
o`000?n^_NGo[[gU00Wo[[gU00?o0000ok2ni?n`_^@00on`_^@2o`0000Go/;oU00?o0000ok;0i?nb
`>@02onb`>@00ol0003o/l3Tok?0i00;ok?0i003o`000?nd`N?o000000;o00002?nd`N@00ol0003o
]L7SokG1h`0:okG1h`03o`000?oooooooooo04;ooooo000Zooooo`03o`000?oooooooooo047ooooo
0_l00002oinij`Go00000_nM^N`00ol0003oW[S[oijhj`09oijhj`03o`000?nO^>[oWkSZ00WoWkSZ
00?o0000oj6ijOnQ^NT02?nQ^NT00ol0003oXkWXoj>ij00:oj>ij004o`000?nV^^OoY[[WojJji`Go
00000_nU^nP00ol0003oZ;cWojRli`0:ojRli`03o`000?n[_NKoZkgV00[oZkgV00?o0000ojjmiOn^
_ND02On^_ND00ol0003o/;kTo`000002o`0000So/;oU00?o0000ok;0i?nb`>@02onb`>@00ol0003o
/l3Tok?0i00:ok?0i0;o00003?nd`N@00ol0003o]L7SokG1h`0:okG1h`03o`000?oooooooooo047o
oooo000Zooooo`03o`000?oooooooooo04;ooooo0ol00008oifik003o`000?nN^>_oW[S[00WoW[S[
00?o0000oinhj_nO^>X02OnO^>X00ol0003oXKWYoj6ij@08oj6ij@03o`000?nS^NSoXkWX00SoXkWX
1Ol00008ojFkj003o`000?nX_>OoZ;cW00WoZ;cW0_l0000<oj^miP03o`000?n^_NGo[[gU00So[[gU
0_l0000<ok2oi@03o`000?nb`>Co//3T00_o//3T00?o0000ok?0i?nc`>@01onc`>@2o`000003ok?1
i?l0003o]<7T00_o]<7T00?o0000okG1hone`N<02one`N<00ol0003oooooooooo`10ooooo`00:Ooo
ool00ol0003oooooooooo`14ooooo`03o`000?nM^NcoWKW/00SoWKW/00?o0000oijhjonN^>/02OnN
^>/00ol0003oWkSZoinhjP08oinhjP03o`000?nQ^NWoXKWY00WoXKWY00?o0000oj>ij?nS^NP01?nS
^NP3o`0000;oXk[Y00?o0000ojFkj?nU^nP02OnU^nP00ol0003oZ;cWojRli`08ojRli`03o`000?nX
_>Oo000000coZkgV00?o0000ojjmiOn^_ND01?n^_ND3o`000003ojjoi_l0003o/;oU00co/;oU00?o
0000ok;0i?nb`>@02_nb`>@00ol0003o/l3Tok?0i005ok?0i0;o00001?nc`N@00ol0003o]<7TokC1
i00:okC1i003o`000?ne`N?o]L7S00[o]L7S00?o0000ooooooooool0@?ooool002Wooooo00?o0000
ooooooooool0AOooool00ol0003oWKW/oifik008oifik003o`000?nN^>_oW[S[00WoW[S[00?o0000
oinhj_nO^>X02?nO^>X00ol0003oXKWYoj6ij@09oj6ij@03o`000?nS^NSoXkWX00?o00001_nS^^T0
0ol0003oYK_XojFkj009ojFkj003o`000?nX_>OoZ;cW00OoZ;cW00?o0000ojRliol000003On[_NH0
0ol0003o[[gUojjmi@03o`0000Go[[oV00?o0000ok2oiOn`_nD02on`_nD00ol0003o//3Tok;0i00:
ok;0i003o`000?nc`>Co/l3T00;o/l3T0_l00007ok?1i003o`000?nd`NCo]<7T00[o]<7T00?o0000
okG1hone`N<02_ne`N<00ol0003oooooooooo`0oooooo`00:Oooool00ol0003oooooooooo`16oooo
o`03o`000?nM^NcoWKW/00SoWKW/00?o0000oijhjonN^>/02OnN^>/00ol0003oWkSZoinhjP08oinh
jP03o`000?nQ^NWoXKWY00SoXKWY0ol0000:oj>jj@03o`000?nU^nSoYK_X00WoYK_X00?o0000ojRl
ionX_>L01_nX_>L01?l0003oZ;cWojRliol0000<oj^miP?o00002On^_nH00ol0003o/;oUok2oi@0:
ok2oi@03o`000?nb`>Co//3T00_o//3T00Co0000ok?0i?l0003o00002_nc`N@00ol0003o]<7TokC1
i00:okC1i003o`000?ne`N?o]L7S00Wo]L7S0_l00010ooooo`00:Oooool2o`0004Sooooo00?o0000
oifik?nM^N`02?nM^N`00ol0003oW[S[oijhj`09oijhj`03o`000?nO^>[oWkSZ00SoWkSZ00?o0000
oj6ijOnQ^NT01?nQ^NT3o`000003oj2ij_l0003oXk[Y00_oXk[Y00?o0000ojFkj?nU^nP02OnU^nP0
0ol0003oZ;cWojRli`05ojRli`05o`000?nX_>OoZ;cWojRliol000002?n[_NH3o`000003oj^niol0
003o[[oV00[o[[oV00?o0000ok2oiOn`_nD02_n`_nD00ol0003o//3Tok;0i00:ok;0i0;o00003?nc
`N@00ol0003o]<7TokC1i00:okC1i003o`000?ne`N?o]L7S00Ko]L7S0ol000000ond`NCo0000o`00
000oooooo`00:Oooool00ol0003oooooooooo`18ooooo`03o`000?nM^NcoWKW/00SoWKW/00?o0000
oijhjonN^>/02OnN^>/00ol0003oWkSZoinhjP08oinhjP03o`000?nQ^NWoXKWY00?o00001OnP^NX0
0ol0003oXk[Yoj>jj@0:oj>jj@03o`000?nU^nSoYK_X00SoYK_X00?o0000ojRlionX_>L01OnX_>L0
0ol0003oZ;cWojRli`02ojRli`03o`000?n[_NKoZkgV00?oZkgV0_l00005oj^ni`03o`000?n^_nKo
[[oV00Wo[[oV00?o0000ok2oiOn`_nD02_n`_nD00ol0003o//3Tok;0i006ok;0i0?o000000?o//7U
o`000?nc`N@03?nc`N@00ol0003o]<7TokC1i00:okC1i003o`000?ne`N?o]L7S00?o]L7S0_l00005
okC1i003o`000?oooooooooo03gooooo000Yooooo`03o`000?oooooooooo04Wooooo00?o0000oifi
k?nM^N`02?nM^N`00ol0003oW[S[oijhj`09oijhj`03o`000?nO^>[oWkSZ00KoWkSZ1?l00009oj2i
jP03o`000?nS^^WoXk[Y00[oXk[Y00?o0000ojFkj?nU^nP02?nU^nP00ol0003oZ;cWojRli`04ojRl
i`03o`000?nX_>OoZ;cW00?oZ;cW00?o0000oj^mi_l000000_l00008oj^ni`03o`000?n^_nKo[[oV
00Wo[[oV00?o0000ok2oiOn`_nD02_n`_nD00ol0003o//3Tok;0i003ok;0i0;o00001Onb`ND00ol0
003o/l7Tok?1i00;ok?1i003o`000?nd`NCo]<7T00[o]<7T00?o0000okG1hol000000_l00008okC1
i003o`000?oooooooooo03cooooo000Yooooo`03o`000?oooooooooo04[ooooo00?o0000oifik?nM
^N`02?nM^N`00ol0003oW[S[oijhj`09oijhj`03o`000?nO^>[oWkSZ00Go00000_nN^N/00ol0003o
X;WZoj2ijP09oj2ijP03o`000?nS^^WoXk[Y00[oXk[Y00?o0000ojFkj?nU^nP02?nU^nP00ol0003o
Z;cWojRli`03ojRli`03o`000?nX_>OoZ;cW00;oZ;cW0ol0000<oj^ni`03o`000?n^_nKo[[oV00So
[[oV00?o0000ok2oiOn`_nD02on`_nD00ol0003o//3To`000002o`0000So//7U00?o0000ok?1i?nc
`N@02onc`N@00ol0003o]<7TokC1i009okC1i0;o00003?nd`N@00ol0003oooooooooo`0kooooo`00
:Oooool00ol0003oooooooooo`1;ooooo`03o`000?nM^NcoWKW/00SoWKW/00?o0000oijhjonN^>/0
1onN^>/4o`0000SoW[W[00?o0000oj2ij_nP^NX02OnP^NX00ol0003oXk[Yoj>jj@09oj>jj@03o`00
0?nU^nSoYK_X00WoYK_X00?o0000ojRlionX_>L00_nX_>L00ol0003oZ;cWo`000002o`0000;oZ;gX
00?o0000oj^nion[_^L02on[_^L00ol0003o[[oVojjoiP08ojjoiP03o`000?n`_nGo/;oU00[o/;oU
0_l0000<ok;1i@03o`000?nc`NCo/l7T00[o/l7T00?o0000okC1i?nd`N@01_nd`N@3o`000003okC1
i?l0003o]<7T00_o]<7T0_l0000looooo`00:Oooool00ol0003oooooooooo`1<ooooo`03o`000?nM
^NcoWKW/00SoWKW/00Co0000oijhjonN^>_oW[S[1Ol00002oifhk003o`000?nN^N_oW[W[00SoW[W[
00?o0000oj2ij_nP^NX02OnP^NX00ol0003oXk[Yoj>jj@09oj>jj@03o`000?nU^nSoYK_X00WoYK_X
00?o0000ojRlionX_>L00ol00006ojRmj003o`000?n[_^OoZkkW00_oZkkW00?o0000ojjoi_n^_nH0
2?n^_nH00ol0003o/;oUok2oi@06ok2oi@?o000000?o/<7Vo`000?nb`ND03?nb`ND00ol0003o/l7T
ok?1i00:ok?1i003o`000?nd`NCo]<7T00?o]<7T0_l00005okC1i003o`000?nd`NCo]<7T00[o]<7T
00?o0000ooooooooool0>_ooool002Sooooo0ol0001>ooooo`03o`000?nM^NcoWKW/00KoWKW/1Ol0
0008oifhk003o`000?nN^N_oW[W[00SoW[W[00?o0000oj2ij_nP^NX02OnP^NX00ol0003oXk[Yoj>j
j@09oj>jj@03o`000?nU^nSoYK_X00SoYK_X0ol000000onX_NSo0000ojRmj007ojRmj003o`000?n[
_^OoZkkW00[oZkkW00?o0000ojjoi_n^_nH02On^_nH00ol0003o/;oUok2oi@03ok2oi@;o00001On`
`NH00ol0003o//7Uok;1i@0;ok;1i@03o`000?nc`NCo/l7T00[o/l7T00?o0000okC1i?l000000_l0
0008okC1i003o`000?nd`NCo]<7T00[o]<7T00?o0000ooooooooool0>Oooool002Sooooo00?o0000
ooooooooool0Coooool00ol0003oWKW/oifik005o`0000;oW;S/00?o0000oifhk?nM^>`02OnM^>`0
0ol0003oW[W[oijij`08oijij`03o`000?nP^N[oX;WZ00WoX;WZ00?o0000oj>jjOnS^^T02OnS^^T0
0ol0003oYK_XojFkj004ojFkj0?o000000GoYKcYo`000?nX_NSoZ;gXo`000009ojRmj003o`000?n[
_^OoZkkW00[oZkkW00?o0000ojjoi_n^_nH02On^_nH00ol0003o/;oUo`000002o`0000So/<7V00?o
0000ok;1iOnb`ND02onb`ND00ol0003o/l7Tok?1i009ok?1i0;o00003?nd`N@00ol0003o]<7TokC1
i00:okC1i003o`000?oooooooooo03Sooooo000<ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c007ooooo`03o`000?oooooooooo053ooooo
0_l00008oibhk003o`000?nM^>coWKS/00WoWKS/00?o0000oijijonN^N/02?nN^N/00ol0003oX;WZ
oj2ijP09oj2ijP03o`000?nS^^WoXk[Y00WoXk[Y00?o0000ojFkj?nU^nP00ol00005ojFlj@03o`00
0?nX_NSo000000[oZ;gX00?o0000oj^nion[_^L02_n[_^L00ol0003o[[oVojjoiP08ojjoiP;o0000
3?n``NH00ol0003o//7Uok;1i@0;ok;1i@03o`000?nc`NCo/l7T00Ko/l7T0_l000000onc`^Go0000
okC1i00;okC1i003o`000?nd`NCo]<7T00[o]<7T0_l0000iooooo`003?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401oooool00ol0003o
ooooooooo`1@ooooo`03o`000?nL^>coW;S/00SoW;S/00?o0000oifhk?nM^>`02OnM^>`00ol0003o
W[W[oijij`08oijij`03o`000?nP^N[oX;WZ00WoX;WZ00?o0000oj>jjOnS^^T01onS^^T4o`0000Wo
YKcY0_l0000;ojRmj003o`000?n[_^OoZkkW00[oZkkW00?o0000ojjoi_n^_nH01?n^_nH3o`000003
ojk0iol0003o/<7V00co/<7V00?o0000ok;1iOnb`ND02onb`ND00ol0003o/l7Tok?1i002ok?1i0?o
00001?nc`^D00ol0003o]<7TokC1i00:okC1i003o`000?nd`NCo]<7T00[o]<7T00?o0000oooooooo
ool0=oooool000cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`1Aooooo`03o`000?nL^>coW;S/00SoW;S/00?o0000oifh
k?nM^>`02OnM^>`00ol0003oW[W[oijij`08oijij`03o`000?nP^N[oX;WZ00WoX;WZ00Co0000oj>j
jOnS^^WoXk[Y1Ol00002oj>kjP03o`000?nU_>WoYKcY00GoYKcY0ol000000onU_>Wo0000ojRmj00:
ojRmj003o`000?n[_^OoZkkW00_oZkkW00?o0000ojjoi_n^_nH00ol00005ojk0i`03o`000?n``NKo
/<7V00_o/<7V00?o0000ok;1iOnb`ND02onb`ND01?l0003o/l7To`000?l00008ok?2i@03o`000?nd
`NCo]<7T00[o]<7T00?o0000okC1i?nd`N@02_nd`N@00ol0003oooooooooo`0fooooo`003?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@07ooooo`03o`00
0?oooooooooo05;ooooo00?o0000oibhk?nL^>`02?nL^>`00ol0003oWKS/oifhk009oifhk003o`00
0?nN^N_oW[W[00SoW[W[00?o0000oj2ij_nP^NX02?nP^NX4o`0000SoXk_Z00Co0000ojFljOnU_>Wo
YKcY0ol00005ojFlj@03o`000?nX_NSoZ;gX00WoZ;gX00?o0000oj^nion[_^L02_n[_^L3o`0000Wo
[/3W00?o0000ok31i_n``NH02on``NH00ol0003o//7Uok;1i@0:ok;1i@;o00002onc`^D00ol0003o
]<7TokC1i00:okC1i003o`000?nd`NCo]<7T00Wo]<7T0_l0000gooooo`003?ooool01Ol0003ooooo
oooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c007ooooo`03o`000?oooooooooo
05?ooooo00?o0000oibhk?nL^>`02?nL^>`00ol0003oWKS/oifhk009oifhk003o`000?nN^N_oW[W[
00SoW[W[00?o0000oj2ij_nP^NX01?nP^NX3o`000003oj2jjol0003oXk_Z00[oXk_Z0ol00009ojFl
j@03o`000?nX_NSoZ;gX00WoZ;gX00?o0000oj^nion[_^L01_n[_^L3o`000003oj^oj?l0003o[/3W
00[o[/3W00?o0000ok31i_n``NH02on``NH00ol0003o//7Uok;1i@06ok;1i@?o000000?o/L;Vo`00
0?nc`^D02_nc`^D00ol0003o]<7TokC1i00:okC1i003o`000?nd`NCo]<7T00Ko]<7T0ol000000onc
`NCo0000o`00000fooooo`003?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7
Qoooool02Oooool00ol0003oooooooooo`1Dooooo`03o`000?nL^>coW;S/00SoW;S/00?o0000oifh
k?nM^>`02OnM^>`00ol0003oW[W[oijij`08oijij`03o`000?nP^N[oX;WZ00?o00001OnP^^/00ol0
003oXk_Zoj>kjP05oj>kjP?o000000?oXk_Zo`000?nU_>T02_nU_>T00ol0003oZ;gXojRmj009ojRm
j003o`000?n[_^OoZkkW00?oZkkW0_l00005oj^oj003o`000?n^`>Oo[/3W00Wo[/3W00?o0000ok31
i_n``NH02on``NH00ol0003o//7Uok;1i@03ok;1i@;o00001Ona`^H00ol0003o/l;Uok?2i@09ok?2
i@03o`000?nd`NCo]<7T00[o]<7T00?o0000okC1i?nd`N@00ond`N@2o`0000Go/l7T00?o0000oooo
ooooool0=?ooool000cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH
00Sooooo0_l0001Gooooo`03o`000?nL^>coW;S/00SoW;S/00?o0000oifhk?nM^>`02OnM^>`00ol0
003oW[W[oijij`06oijij`Co00002OnP^^/01?l0003oXk_Zoj>kj_nS^nX3o`0000GoXk_Z00?o0000
ojFljOnU_>T02OnU_>T00ol0003oZ;gXojRmj009ojRmj003o`000?n[_^Oo000000;o00002?n[_nP0
0ol0003o[/3Wojk0i`09ojk0i`03o`000?n``NKo/<7V00_o/<7V00?o0000ok;1iOl000000_l00008
ok72iP03o`000?nc`^Go/l;U00Wo/l;U00?o0000okC1i?nd`N@02_nd`N@00ol0003o]<7To`000002
o`0000So/l7T00?o0000ooooooooool0<oooool000cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0Eoooool00ol0003oW;S/oibh
k008oibhk003o`000?nM^>coWKS/00WoWKS/00?o0000oijijonN^N/01Ol00003oijik003o`000?nP
^^_oX;[[00SoX;[[0ol00009oj>kjP03o`000?nU_>WoYKcY00WoYKcY00?o0000ojRmj?nX_NP02?nX
_NP2o`0000coZkoX00?o0000ojk0ion^`>L02On^`>L00ol0003o/<7Vok31iP0:ok31iP;o00003?na
`^H00ol0003o/l;Uok?2i@09ok?2i@03o`000?nd`NCo]<7T00Wo]<7T0_l0000<ok?1i003o`000?oo
oooooooo03;ooooo000Wooooo`03o`000?oooooooooo05Sooooo00?o0000oibhk?nL^>`02?nL^>`0
0ol0003oWKS/oifhk007oifhk0Co00002OnN^N`00ol0003oX;[[oj2jj`04oj2jj`?o000000?oX;[[
o`000?nS^nX02OnS^nX00ol0003oYKcYojFlj@0:ojFlj@03o`000?nX_NSoZ;gX00CoZ;gX0ol00000
0onX_^Wo0000oj^oj00<oj^oj003o`000?n^`>Oo[/3W00Wo[/3W00?o0000ok31i_n``NH01_n``NH3
o`000003ok32iol0003o/L;V00_o/L;V00?o0000ok?2iOnc`^D02Onc`^D00ol0003o]<7TokC1i006
okC1i0?o000000?o//7Uo`000?nc`N@03?nc`N@00ol0003oooooooooo`0aooooo`009oooool00ol0
003oooooooooo`1Iooooo`03o`000?nL^>coW;S/00SoW;S/00Co0000oifhk?nM^>coWKS/1Ol00002
oibhk003o`000?nN^NcoW[W/00WoW[W/00?o0000oj2jjonP^^/00ol00005oj2jj`03o`000?nS^n[o
Xk_Z00SoXk_Z00?o0000ojFljOnU_>T02_nU_>T00ol0003oZ;gXojRmj003o`0000GoZ;kY00?o0000
oj^oj?n[_nP02on[_nP00ol0003o[/3Wojk0i`09ojk0i`03o`000?n``NKo/<7V00?o/<7V0_l00005
ok32i`03o`000?na`^Ko/L;V00[o/L;V00?o0000ok?2iOnc`^D02Onc`^D00ol0003o]<7TokC1i003
okC1i0;o00001Onb`ND00ol0003o/l7Tok?1i00:ok?1i0;o0000<_ooool002Oooooo00?o0000oooo
ooooool0F_ooool00ol0003oW;S/oibhk006oibhk0Go00002?nL^>`00ol0003oW[W/oijik008oiji
k0?o00002OnP^^/00ol0003oXk_Zoj>kjP08oj>kjP03o`000?nU_>WoYKcY00SoYKcY1?l00009ojRn
j@03o`000?n[_nSoZkoX00[oZkoX00?o0000ojk0ion^`>L02_n^`>L00ol0003o/<7Vo`000002o`00
00So/<;W00?o0000ok72i_na`^H02_na`^H00ol0003o/l;Uok?2i@09ok?2i@03o`000?nd`NCo0000
00;o00002?nb`ND00ol0003o/l7Tok?1i00:ok?1i003o`000?oooooooooo033ooooo000Wooooo`03
o`000?oooooooooo05_ooooo00?o0000oibhk?nL^>`01Ol00003oibhk003o`000?nL^>coW;S/00So
W;S/00?o0000oijik?nN^N`01?nN^N`3o`0000;oW[W/00?o0000oj2jjonP^^/02?nP^^/00ol0003o
Xk_Zoj>kjP08oj>kjP03o`000?nU_>WoYKcY00CoYKcY0ol00002ojFmjP03o`000?nX_^WoZ;kY00Wo
Z;kY00?o0000oj^oj?n[_nP02_n[_nP00ol0003o[/3Wojk0i`09ojk0i`;o00003?n``^L00ol0003o
/L;Vok72iP0:ok72iP03o`000?nc`^Go/l;U00So/l;U0_l0000<ok;1i@03o`000?nc`NCo/l7T00[o
/l7T00?o0000ooooooooool0;oooool002Oooooo0_l0001Mooooo`;o00002OnL^>`00ol0003oW;S/
oibhk008oibhk003o`000?nN^NcoW[W/00?o00001_nN^N`00ol0003oX;[[oj2jj`08oj2jj`03o`00
0?nS^n[oXk_Z00SoXk_Z00?o0000ojFljOnU_>T00ol00006ojFmjP03o`000?nX_^WoZ;kY00WoZ;kY
00?o0000oj^oj?n[_nP02_n[_nP00ol0003o[/3Wojk0i`06ojk0i`;o000000?o[/7Xo`000?n``^L0
2on``^L00ol0003o/L;Vok72iP0:ok72iP03o`000?nc`^Go/l;U00Ko/l;U0_l000000onb`^Ko0000
ok;1i@0<ok;1i@03o`000?nc`NCo/l7T00[o/l7T00?o0000ooooooooool0;_ooool002Kooooo0_l0
001Oooooo`03o`000?nL^>coW;S/00SoW;S/00?o0000oibhk?nL^>`01onL^>`3o`0000[oW[W/00?o
0000oj2jjonP^^/02?nP^^/00ol0003oXk_Zoj>kjP06oj>kjPCo00002_nU_NX00ol0003oZ;kYojRn
j@09ojRnj@03o`000?n[_nSoZkoX00[oZkoX00?o0000ojk0ion^`>L00_n^`>L3o`0000Co[/7X00?o
0000ok32ion``^L02_n``^L00ol0003o/L;Vok72iP0:ok72iP03o`000?nc`^Go/l;U00;o/l;U0ol0
0004ok;2iP03o`000?nb`NGo//7U00_o//7U00?o0000ok?1i?nc`N@02Onc`N@2o`0002oooooo000W
ooooo`03o`000?oooooooooo05kooooo00?o0000oibhk?nL^>`02?nL^>`00ol0003oW;S/oibhk003
oibhk0?o00000_nL^>`00ol0003oW[W/oijik009oijik003o`000?nP^^_oX;[[00SoX;[[00?o0000
oj>kj_nS^nX01Ol00002oj>lj`03o`000?nU_N[oYKgZ00[oYKgZ00?o0000ojRnjOnX_^T02OnX_^T0
0ol0003oZkoXoj^oj00:oj^oj004o`000?n^`>Oo0000o`0000So[/7X00?o0000ok32ion``^L02_n`
`^L00ol0003o/L;Vok72iP0:ok72iP04o`000?nc`^Go0000o`0000So//;V00?o0000ok;1iOnb`ND0
2_nb`ND00ol0003o/l7Tok?1i00:ok?1i0;o0000;_ooool002Oooooo00?o0000ooooooooool0Gooo
ool00ol0003oW;S/oibhk008oibhk003o`000?nL^>co000000;o00001_nL^>`00ol0003oW[W/oiji
k009oijik003o`000?nP^^_oX;[[00KoX;[[1?l00008oj>lj`03o`000?nU_N[oYKgZ00[oYKgZ00?o
0000ojRnjOnX_^T02OnX_^T00ol0003oZkoXoj^oj008oj^oj0?o00002on^`NP00ol0003o/<;Wok32
i`0:ok32i`03o`000?na`^Ko/L;V00Wo/L;V0_l0000;ok;2iP03o`000?nb`NGo//7U00[o//7U00?o
0000ok?1i?nc`N@01_nc`N@3o`000003ok70iOl0003ooooo02gooooo000Vooooo`03o`000?oooooo
oooo067ooooo00?o0000oibhk?nL^>`01_nL^>`3o`0000[oW;S/00?o0000oijik?nN^N`02OnN^N`0
0ol0003oX;[[oj2jj`05o`0000;oX;_/00?o0000oj>ljonS_>/02?nS_>/00ol0003oYKgZojFmjP0:
ojFmjP03o`000?nX_^WoZ;kY00WoZ;kY00?o0000oj^oj?n[_nP01?n[_nP3o`0000;oZl3Y00?o0000
ojk1j?n^`NP02_n^`NP00ol0003o/<;Wok32i`09ok32i`03o`000?na`^Ko/L;V00Ko/L;V0ol00000
0ona`^Oo0000ok;2iP0;ok;2iP03o`000?nb`NGo//7U00[o//7U00?o0000ok?1i?nc`N@00onc`N@2
o`0000Go/L3U00?o0000ooooooooool0:oooool002Kooooo00?o0000ooooooooool0H_ooool00ol0
003oW;S/oibhk002oibhk0?o00000onL^>`00ol0003oW;S/oibhk008oibhk003o`000?nN^NcoW[W/
00OoW[W/1?l00008oj2kk003o`000?nS_>_oXkc[00SoXkc[00?o0000ojFmj_nU_NX02_nU_NX00ol0
003oZ;kYojRnj@09ojRnj@03o`000?n[_nSoZkoX00?o00001_n[`>T00ol0003o[/7Xojk1j00:ojk1
j003o`000?n``^Oo/<;W00Wo/<;W00?o0000ok72i_na`^H00ona`^H2o`0000Go/L;W00?o0000ok;2
i_nb`^H02_nb`^H00ol0003o//7Uok;1i@0:ok;1i@03o`000?nc`NCo000000;o00001ona`>D2o`00
02cooooo000Vooooo`03o`000?oooooooooo06?ooooo1?l00007oibhk003o`000?nL^>coW;S/00So
W;S/00Co0000oijik?nN^NcoW[W/1Ol00002oijjk003o`000?nP^ncoX;_/00SoX;_/00?o0000oj>l
jonS_>/02?nS_>/00ol0003oYKgZojFmjP09ojFmjP;o00002_nX_^T3o`0000[oZl3Y00?o0000ojk1
j?n^`NP02_n^`NP00ol0003o/<;Wok32i`09ok32i`03o`000?na`^Ko000000;o00002?na`^L00ol0
003o//;Vok;2iP09ok;2iP03o`000?nb`NGo//7U00[o//7U0_l0000;ok70i@03o`000?oooooooooo
02[ooooo000Vooooo`;o0000Hoooool3o`0000[oW;S/00?o0000oibhk?nL^>`01_nL^>`5o`0000So
W[[/00?o0000oj2kk?nP^n`02?nP^n`00ol0003oXkc[oj>lj`08oj>lj`03o`000?nU_N[oYKgZ00Wo
YKgZ0_l00006ojRnj@?o000000?oZ;oZo`000?n[`>T02on[`>T00ol0003o[/7Xojk1j00:ojk1j003
o`000?n``^Oo/<;W00So/<;W0_l0000<ok72i`03o`000?nb`^Ko//;V00Wo//;V00?o0000ok;1iOnb
`ND01_nb`ND3o`000003ok71i_l0003o/L3U00_o/L3U00?o0000ooooooooool0:Oooool002Kooooo
00?o0000ooooooooool0Goooool3o`0000?ooooo00?o0000oibhk?nL^>`02?nL^>`00ol0003oW;S/
oibhk005o`0000;oWKW/00?o0000oijjk?nN^^`02OnN^^`00ol0003oX;_/oj2kk008oj2kk003o`00
0?nS_>_oXkc[00SoXkc[00?o0000ojFmj_nU_NX02OnU_NX2o`0000;oZ;kY0ol00005ojRojP03o`00
0?n[`>WoZl3Y00[oZl3Y00?o0000ojk1j?n^`NP02_n^`NP00ol0003o/<;Wok32i`04ok32i`?o0000
00?o[l;Xo`000?na`^L03?na`^L00ol0003o//;Vok;2iP09ok;2iP03o`000?nb`NGo//7U00?o//7U
0_l00005ok71iP03o`000?na`>Go/L3U00[o/L3U00?o0000ooooooooool0:?ooool002Kooooo00?o
0000ooooooooool0G?ooool3o`0000Oooooo00?o0000oibhk?nL^>`01_nL^>`4o`0000SoWKW/00?o
0000oijjk?nN^^`02OnN^^`00ol0003oX;_/oj2kk008oj2kk003o`000?nS_>_oXkc[00SoXkc[00?o
0000ojFmj_nU_NX02?nU_NX4o`0000WoZ;oZ00?o0000oj_0jOn[`>T02_n[`>T00ol0003o[/7Xojk1
j00:ojk1j003o`000?n``^Oo/<;W00?o00001On_`^P00ol0003o/L;Wok72i`0;ok72i`03o`000?nb
`^Ko//;V00Wo//;V00?o0000ok;1iOl000000_l00008ok71iP03o`000?na`>Go/L3U00Wo/L3U00?o
0000ooooooooool0:?ooool002Kooooo00?o0000ooooooooool0FOooool3o`0000_ooooo00?o0000
oibhk?nL^>`01Ol00002oibhk003o`000?nM^NcoWKW/00SoWKW/00?o0000oijjk?nN^^`02OnN^^`0
0ol0003oX;_/oj2kk008oj2kk003o`000?nS_>_oXkc[00SoXkc[00?o0000ojFmj_nU_NX01?nU_NX3
o`0000;oY[k[00?o0000ojRoj_nX_nX02OnX_nX00ol0003oZl3Yoj_0j@09oj_0j@03o`000?n^`NSo
[/7X00[o[/7X0ol00009ojo2j003o`000?na`^Oo/L;W00[o/L;W00?o0000ok;2i_nb`^H02Onb`^H2
o`0000co/L7V00?o0000ok70iOna`>D02Ona`>D00ol0003oooooooooo`0Wooooo`009_ooool00ol0
003oooooooooo`1Fooooo`?o00003oooool2o`0000SoW;S/00?o0000oifik?nM^N`02?nM^N`00ol0
003oW[[/oijjk009oijjk003o`000?nP^ncoX;_/00SoX;_/00?o0000oj>ljonS_>/02?nS_>/00ol0
003oYKgZojFmjP03o`0000KoY[k[00?o0000ojRoj_nX_nX02OnX_nX00ol0003oZl3Yoj_0j@09oj_0
j@03o`000?n^`NSo[/7X00Ko[/7X0ol000000on]`^Wo0000ojo2j00:ojo2j003o`000?na`^Oo/L;W
00[o/L;W00?o0000ok;2i_nb`^H01_nb`^H2o`000003ok32iol0003o/L7V00co/L7V00?o0000ok70
iOna`>D02Ona`>D00ol0003oooooooooo`0Vooooo`009_ooool00ol0003oooooooooo`1Cooooo`?o
00004oooool00ol0003oW;S/oibhk007oibhk003o`000?nM^NcoWKW/00SoWKW/00?o0000oijjk?nN
^^`02OnN^^`00ol0003oX;_/oj2kk008oj2kk003o`000?nS_>_oXkc[00KoXkc[1?l0000:ojJnj`03
o`000?nX_n[oZ;oZ00WoZ;oZ00?o0000oj_0jOn[`>T02On[`>T00ol0003o[/7Xojk1j003ojk1j0;o
00001On]`^T00ol0003o[l;Xojo2j009ojo2j003o`000?na`^Oo/L;W00[o/L;W00?o0000ok;2i_nb
`^H00_nb`^H3o`0000Co/<;W00?o0000ok71i_na`NH02ona`NH00ol0003o/L3Uok70i@08ok70i@;o
00009oooool002Gooooo00?o0000ooooooooool0DOooool3o`0001Oooooo00?o0000oibhk?nL^>`0
1onL^>`00ol0003oWKW/oifik008oifik003o`000?nN^^coW[[/00WoW[[/00?o0000oj2kk?nP^n`0
2?nP^n`00ol0003oXkc[oj>lj`05o`0000?oXkg/00?o0000ojJnjonV_^/02?nV_^/2o`0000_oZ;oZ
00?o0000oj_0jOn[`>T02On[`>T00ol0003o[/7Xo`000002o`0000So[L;Y00?o0000ojo2j?n_`^P0
2On_`^P00ol0003o/L;Wok72i`0:ok72i`04o`000?nb`^Ko0000o`0000So/<;W00?o0000ok71i_na
`NH02_na`NH00ol0003o/L3Uok70i@09ok70i@03o`000?oooooooooo02Gooooo000Uooooo`?o0000
C_ooool3o`0001[ooooo0_l00009oibhk003o`000?nM^NcoWKW/00SoWKW/00?o0000oijjk?nN^^`0
2OnN^^`00ol0003oX;_/oj2kk006oj2kk0Co00002OnS_N`00ol0003oY[k[ojJnj`08ojJnj`;o0000
2onX_nX00ol0003oZl3Yoj_0j@08oj_0j@;o00003?n]`^T00ol0003o[l;Xojo2j009ojo2j003o`00
0?na`^Oo/L;W00So/L;W0ol0000;ok32i`03o`000?na`NKo/L7V00[o/L7V00?o0000ok70iOna`>D0
2?na`>D2o`0002Kooooo000Uooooo`03o`000?oooooooooo04_ooooo0ol0000Nooooo`;o00002OnL
^>`00ol0003oWKW/oifik008oifik003o`000?nN^^coW[[/00WoW[[/00?o0000oj2kk?nP^n`01Ol0
0002oj6lk003o`000?nS_NcoXkg/00WoXkg/00?o0000ojJnjonV_^/02?nV_^/2o`0000_oZ;oZ00?o
0000oj_0jOn[`>T01?n[`>T3o`0000;oZl;Z00?o0000ojg2jOn]`^T02_n]`^T00ol0003o[l;Xojo2
j009ojo2j003o`000?na`^Oo/L;W00Co/L;W0ol00002ojo3j003o`000?n``^Oo/<;W00[o/<;W00?o
0000ok71i_na`NH02_na`NH00ol0003o/L3Uok70i@04ok70i@?o000000?o[l3Vo`000?l000009Ooo
ool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`00
0?lQ8B7oc<c<00Oooooo00?o0000ooooooooool0B?ooool3o`0002;ooooo0_l00009oibhk003o`00
0?nM^NcoWKW/00SoWKW/00?o0000oijjk?nN^^`02?nN^^`3o`0000SoXKc/00?o0000oj>mk?nS_N`0
2OnS_N`00ol0003oY[k[ojJnj`08ojJnj`;o00002onX_nX00ol0003oZl3Yoj_0j@03o`0000KoZl;Z
00?o0000ojg2jOn]`^T02_n]`^T00ol0003o[l;Xojo2j009ojo2j003o`000?na`^Oo/L;W00?o0000
1_n_`nP00ol0003o/<;Wok32i`0:ok32i`03o`000?na`NKo/L7V00[o/L7V00?o0000ok70iOna`>D0
0ol00005ojo0iP;o00009?ooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Oooooo00?o0000ooooooooool0AOooool3o`0002Ko
oooo0_l00009oibhk003o`000?nM^NcoWKW/00SoWKW/00?o0000oijjk?nN^^`01?nN^^`3o`000003
oinkk?l0003oXKc/00WoXKc/00?o0000oj>mk?nS_N`02OnS_N`00ol0003oY[k[ojJnj`08ojJnj`;o
00002_nX_nX3o`0000[oZl;Z00?o0000ojg2jOn]`^T02On]`^T00ol0003o[l;Xojo2j009ojo2j0?o
00002_n_`nP00ol0003o/<;Wok32i`09ok32i`03o`000?na`NKo/L7V00[o/L7V0ol00009ojo0iP03
o`000?oooooooooo02;ooooo0009ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool0@_ooool3o`0002[ooooo0_l00009oibh
k003o`000?nM^NcoWKW/00SoWKW/00?o0000oijjk?nN^^`00ol00005oinkk003o`000?nQ_>coXKc/
00SoXKc/00?o0000oj>mk?nS_N`02OnS_N`00ol0003oY[k[ojJnj`08ojJnj`;o00001_nX_nX3o`00
0003ojS1jol0003oZl;Z00_oZl;Z00?o0000ojg2jOn]`^T02On]`^T00ol0003o[l;Xojo2j006ojo2
j0;o000000?o[/?Yo`000?n_`nP02on_`nP00ol0003o/<;Wok32i`09ok32i`03o`000?na`NKo/L7V
00Ko/L7V0ol000000on_`NOo0000ojo0iP0:ojo0iP03o`000?oooooooooo027ooooo0009ooooo`05
o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Oooooo00?o0000
ooooooooool0?oooool3o`0002kooooo0_l00009oibhk003o`000?nM^NcoWKW/00KoWKW/1?l00009
oinkk003o`000?nQ_>coXKc/00SoXKc/00?o0000oj>mk?nS_N`02OnS_N`00ol0003oY[k[ojJnj`08
ojJnj`;o00000_nX_nX3o`0000GoZ<7[00?o0000oj_2j_n[`^X02_n[`^X00ol0003o[L;Yojg2j@09
ojg2j@03o`000?n_`^So[l;X00;o[l;X0ol00004ojk3j@03o`000?n_`nSo[l?X00[o[l?X00?o0000
ok32ion``^L02On``^L00ol0003o/L7Vok71iP03ok71iP;o00001On_`NL00ol0003o[l3Vojo0iP08
ojo0iP;o00008_ooool000Wooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o
0000o`000?o<c<`01oooool00ol0003oooooooooo`0looooo`?o0000<_ooool2o`0000WoW;S/00?o
0000oifik?nM^N`01Ol00003oijik003o`000?nO^ncoWk_/00SoWk_/00?o0000oj6lk?nQ_>`02?nQ
_>`00ol0003oXkg/oj>mk009oj>mk003o`000?nV_^_oY[k[00OoY[k[1?l00009ojS1j`03o`000?n[
`^[oZl;Z00[oZl;Z00?o0000ojg2jOn]`^T02On]`^T01?l0003o[l;Xo`000?l00008ojk3j@03o`00
0?n_`nSo[l?X00[o[l?X00?o0000ok32ion``^L02On``^L00ol0003o/L7Vo`000002o`0000So[l7W
00?o0000ojo0i_n_`>H02?n_`>H2o`00027ooooo0009ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol@413o^[Zjoooooonj^[[o410@00Oooooo00?o0000ooooooooool0>Oooool3o`0003Ko
oooo0_l00005oibhk0Ko00002OnN^N`00ol0003oWk_/oinkk008oinkk003o`000?nQ_>coXKc/00So
XKc/00?o0000oj>mk?nS_N`02OnS_N`01?l0003oY[k[ojJnjonV_^/5o`000003ojJok?l0003o0000
00_oZ<7[00?o0000oj_2j_n[`^X02_n[`^X00ol0003o[L;Yojg2j@08ojg2j@;o00002on^`nT00ol0
003o[l?Xojo3j00:ojo3j003o`000?n``^Oo/<;W00So/<;W0_l0000<ojo1i`03o`000?n_`>Ko[l3V
00So[l3V00?o0000ooooooooool07oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`0gooooo`?o0000>_ooool6
o`0000GoWKW/00?o0000oijik?nN^N`02?nN^N`00ol0003oWk_/oinkk008oinkk003o`000?nQ_>co
XKc/00SoXKc/00?o0000oj>mk?nS_N`02?nS_N`4o`0000OoY[o/0_l0000;ojS1j`03o`000?n[`^[o
Zl;Z00[oZl;Z00?o0000ojg2jOn]`^T01?n]`^T3o`000003ojc3j_l0003o[/?Y00_o[/?Y00?o0000
ojo3j?n_`nP02_n_`nP00ol0003o/<;Wok32i`04ok32i`?o000000?o[/;Xo`000?n_`NL02on_`NL0
0ol0003o[l3Vojo0iP08ojo0iP;o00008?ooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0dooooo`?o0000?_oo
ool00ol0003oWKW/oifik008oifik003o`000?nN^NcoW[W/00SoW[W/00?o0000oinkk?nO^n`02?nO
^n`00ol0003oXKc/oj6lk008oj6lk003o`000?nS_NcoXkg/00CoXkg/0ol000000onT_^co0000ojJo
k009ojJok0;o00002onX`N/00ol0003oZl;Zoj_2jP0:oj_2jP03o`000?n]`^Wo[L;Y00?o00001On/
`nX00ol0003o[/?Yojk3j@0:ojk3j@03o`000?n_`nSo[l?X00[o[l?X00?o0000ok32ion``^L00ol0
0005ojk2j003o`000?n_`NOo[l7W00[o[l7W00?o0000ojo0i_n_`>H02?n_`>H2o`0001oooooo000T
ooooo`03o`000?oooooooooo037ooooo0ol00012ooooo`03o`000?nM^NcoWKW/00SoWKW/00?o0000
oijik?nN^N`02?nN^N`00ol0003oWk_/oinkk008oinkk003o`000?nQ_>coXKc/00SoXKc/00?o0000
oj>mk?nS_N`00ol00005ojBnk003o`000?nV_ncoY[o/00SoY[o/0_l0000;ojS1j`03o`000?n[`^[o
Zl;Z00SoZl;Z1?l00009ojc3jP03o`000?n^`nWo[/?Y00[o[/?Y00?o0000ojo3j?n_`nP02?n_`nP4
o`0000Wo[/;X00?o0000ojo1ion_`NL02_n_`NL00ol0003o[l3Vojo0iP08ojo0iP;o00007_ooool0
02Cooooo00?o0000ooooooooool0;oooool2o`0004Kooooo00?o0000oifik?nM^N`02?nM^N`00ol0
003oW[W/oijik008oijik003o`000?nO^ncoWk_/00SoWk_/00?o0000oj6lk?nQ_>`01_nQ_>`4o`00
00WoY;k/00?o0000ojJok?nV_n`02?nV_n`2o`0000_oZ<7[00?o0000oj_2j_n[`^X01?n[`^X3o`00
00;oZl;[00?o0000ojc3j_n/`nX02On/`nX00ol0003o[/?Yojk3j@0:ojk3j@03o`000?n_`nSo[l?X
00Co[l?X0ol00002ojk3j@03o`000?n^`^So[/;X00Wo[/;X00?o0000ojo1ion_`NL02On_`NL00ol0
003o[l3Vojo0iP08ojo0iP;o00007_ooool002Cooooo00?o0000ooooooooool0;?ooool3o`0004Wo
oooo00?o0000oifik?nM^N`02?nM^N`00ol0003oW[W/oijik008oijik003o`000?nO^ncoWk_/00So
Wk_/00?o0000oj6lk?nQ_>`01Ol00003oj:mk003o`000?nT_^coY;k/00SoY;k/00?o0000ojJok?nV
_n`02?nV_n`2o`0000_oZ<7[00?o0000oj_2j_n[`^X00ol00006oj_2j`03o`000?n/`n[o[<?Z00Wo
[<?Z00?o0000ojk3jOn^`nT02_n^`nT00ol0003o[l?Xojo3j003o`0000Ko[/?Y00?o0000ojk2j?n^
`^P02On^`^P00ol0003o[l7Wojo1i`09ojo1i`03o`000?n_`>Ko[l3V00Co[l3V0ol000000on]_nOo
0000o`00000Mooooo`009?ooool00ol0003oooooooooo`0Yooooo`?o0000COooool00ol0003oWKW/
oifik008oifik003o`000?nN^NcoW[W/00SoW[W/00?o0000oinkk?nO^n`01_nO^n`4o`0000WoX[g/
00?o0000ojBnk?nT_^`02?nT_^`00ol0003oY[o/ojJok008ojJok0;o00002_nX`N/3o`0000[oZl;[
00?o0000ojc3j_n/`nX02On/`nX00ol0003o[/?Yojk3j@09ojk3j@?o00002_n^`nT00ol0003o[/;X
ojk2j009ojk2j003o`000?n_`NOo[l7W00Wo[l7W00?o0000ojo0i_n_`>H00ol00005ojfoi`;o0000
7?ooool002Cooooo00?o0000ooooooooool09_ooool3o`00057ooooo00?o0000oifik?nM^N`02?nM
^N`00ol0003oW[W/oijik008oijik003o`000?nO^ncoWk_/00Go00000onQ_>`00ol0003oX[g/oj:m
k008oj:mk003o`000?nT_^coY;k/00SoY;k/00?o0000ojJok?nV_n`02?nV_n`2o`0000KoZ<7[0ol0
0002ojW2k003o`000?n[`^_oZl;[00WoZl;[00?o0000ojc3j_n/`nX02On/`nX00ol0003o[/?Yojk3
j@06ojk3j@;o000000?o[L?Zo`000?n^`nT02on^`nT00ol0003o[/;Xojk2j009ojk2j003o`000?n_
`NOo[l7W00So[l7W0ol00009ojfoi`;o00006oooool002?ooooo0_l0000Uooooo`?o0000EOooool0
0ol0003oWKW/oifik008oifik003o`000?nN^NcoW[W/00KoW[W/1?l00009oj6lk003o`000?nR_Nco
X[g/00SoX[g/00?o0000ojBnk?nT_^`02?nT_^`00ol0003oY[o/ojJok007ojJok003o`000?nV_nco
000000;oZ<7[0ol00006ojW2k003o`000?n[`^_oZl;[00WoZl;[00?o0000ojc3j_n/`nX02On/`nX0
0ol0003o[/?Yojk3j@02ojk3j@?o00001?n]`nX00ol0003o[/?Yojk3j@0:ojk3j@03o`000?n^`^So
[/;X00Wo[/;X00?o0000ojo1ion_`NL01?n_`NL3o`000003ojc0j?l0003o[KoW00[o[KoW00?o0000
ooooooooool06Oooool002Cooooo00?o0000ooooooooool08?ooool3o`0005Wooooo00?o0000oifi
k?nM^N`02?nM^N`00ol0003oW[W/oijik005o`0000;oWk[/00?o0000oj6lk?nQ_>`02OnQ_>`00ol0
003oX[g/oj:mk008oj:mk003o`000?nT_^coY;k/00SoY;k/00?o0000ojJok?nV_n`01onV_n`4o`00
00[oZL;/00?o0000oj_2jon[`^/02On[`^/00ol0003o[<?Zojc3jP09ojc3jP04o`000?n^`nWo0000
o`0000So[L?Z00?o0000ojk3jOn^`nT02On^`nT00ol0003o[/;Xojk2j00:ojk2j003o`000?n_`NOo
[l7W00?o00001On/`>P00ol0003o[KoWojfoi`09ojfoi`03o`000?oooooooooo01Sooooo000Soooo
o`03o`000?oooooooooo01kooooo0ol0001Mooooo`03o`000?nM^NcoWKW/00KoWKW/1?l00008oinj
k003o`000?nQ_>coXKc/00WoXKc/00?o0000oj:mk?nR_N`02?nR_N`00ol0003oY;k/ojBnk008ojBn
k003o`000?nV_ncoY[o/00CoY[o/1Ol0000<ojW2k003o`000?n[`^_oZl;[00WoZl;[00?o0000ojc3
j_n/`nX02?n/`nX2o`0000_o[L?Z00?o0000ojk3jOn^`nT02On^`nT00ol0003o[/;Xojk2j008ojk2
j0Co00002On/`>P00ol0003o[KoWojfoi`09ojfoi`03o`000?oooooooooo01Oooooo000Sooooo`03
o`000?oooooooooo01_ooooo0ol0001Qooooo`03o`000?nM^NcoWKW/00Go00000_nO^N/00ol0003o
Wk[/oinjk008oinjk003o`000?nQ_>coXKc/00WoXKc/00?o0000oj:mk?nR_N`02?nR_N`00ol0003o
Y;k/ojBnk008ojBnk003o`000?nV_ncoY[o/00?o00001?nW`N`2o`0000coZL;/00?o0000oj_2jon[
`^/02On[`^/00ol0003o[<?Zojc3jP04ojc3jP?o00000_n/`n/00ol0003o[L?Zojg3jP09ojg3jP03
o`000?n^`nWo[/?Y00Wo[/?Y00?o0000ojk2j?n^`^P01?n^`^P3o`0000;o[<7Y00?o0000ojc0j?n/
`>P02On/`>P00ol0003o[KoWojfoi`08ojfoi`;o00006?ooool002?ooooo00?o0000ooooooooool0
6?ooool3o`0006Gooooo0_l00008oinij`03o`000?nO^^coWk[/00SoWk[/00?o0000oj6lk?nQ_>`0
2OnQ_>`00ol0003oX[g/oj:mk008oj:mk003o`000?nT_^coY;k/00KoY;k/1?l00008ojO1k0;o0000
3?nY`^`00ol0003oZl;[oj_2j`09oj_2j`03o`000?n/`n[o[<?Z00?o00001_n/`n/00ol0003o[L?Z
ojg3jP09ojg3jP03o`000?n^`nWo[/?Y00Wo[/?Y00?o0000ojk2j?n^`^P00ol00006ojc1j@03o`00
0?n/`>So[<3X00Wo[<3X00?o0000ojfoion]_nL02?n]_nL00ol0003oooooooooo`0Fooooo`008ooo
ool00ol0003oooooooooo`0Eooooo`?o0000J?ooool00ol0003oWkW[oinij`08oinij`03o`000?nO
^^coWk[/00SoWk[/00?o0000oj6lk?nQ_>`02OnQ_>`00ol0003oX[g/oj:mk008oj:mk003o`000?nT
_^coY;k/00Go00000onU_n`00ol0003oYl7/ojO1k007ojO1k0;o00003?nY`^`00ol0003oZl;[oj_2
j`08oj_2j`?o00002_n/`n/00ol0003o[L?Zojg3jP09ojg3jP03o`000?n^`nWo[/?Y00So[/?Y0ol0
000:ojc1j@03o`000?n/`>So[<3X00So[<3X00?o0000ojfoion]_nL02On]_nL00ol0003ooooooooo
o`0Eooooo`008oooool00ol0003oooooooooo`0Booooo`?o0000K?ooool00ol0003oWkW[oinij`08
oinij`03o`000?nO^^coWk[/00SoWk[/00?o0000oj6lk?nQ_>`02OnQ_>`00ol0003oX[g/oj:mk006
oj:mk0Co00002OnU_n`00ol0003oYl7/ojO1k007ojO1k0;o00003?nY`^`00ol0003oZl;[oj_2j`04
oj_2j`?o00000_nZ`n`00ol0003o[<?[ojc3j`09ojc3j`03o`000?n]`n[o[L?Z00Wo[L?Z00?o0000
ojk3jOn^`nT01?n^`nT3o`000003ojc2j_l0003o[<7Y00_o[<7Y00?o0000ojc0j?n/`>P02?n/`>P0
0ol0003o[KoWojfoi`09ojfoi`03o`000?oooooooooo01Cooooo000Rooooo`?o00004?ooool3o`00
073ooooo00?o0000oinijonO^N/02?nO^N/00ol0003oWk[/oinjk008oinjk003o`000?nQ_>coXKc/
00WoXKc/00?o0000oj:mk?nR_N`01Ol00002ojBnk003o`000?nU_ncoYKo/00WoYKo/00?o0000ojO1
k?nW`N`01onW`N`2o`0000coZL;/00?o0000oj_2jon[`^/00ol00006oj[3k003o`000?n/`n_o[<?[
00Wo[<?[00?o0000ojg3j_n]`nX02On]`nX00ol0003o[/?Yojk3j@03o`0000Go[<;Z00?o0000ojc1
jOn/`NT02_n/`NT00ol0003o[<3Xojc0j008ojc0j003o`000?n]_nOo[KoW00Oo[KoW0ol0000Eoooo
o`008oooool00ol0003oooooooooo`0<ooooo`?o0000M?ooool00ol0003oWkW[oinij`08oinij`03
o`000?nO^^coWk[/00SoWk[/00?o0000oj6lk?nQ_>`02?nQ_>`3o`0000SoY;k/00?o0000ojFok?nU
_n`02OnU_n`00ol0003oYl7/ojO1k006ojO1k003o`000?nW`Nco000000[oZL;/1?l0000:oj[3k003
o`000?n/`n_o[<?[00Wo[<?[00?o0000ojg3j_n]`nX02?n]`nX3o`0000Wo[<;Z00?o0000ojc1jOn/
`NT02On/`NT00ol0003o[<3Xojc0j009ojc0j004o`000?n]_nOo[KoWojfoi`Go00000_ooool00ol0
003oooooooooo`0Cooooo`008oooool00ol0003oooooooooo`09ooooo`?o0000N?ooool00ol0003o
WkW[oinij`08oinij`03o`000?nO^^coWk[/00SoWk[/00?o0000oj6lk?nQ_>`01?nQ_>`3o`000003
oj>mk?l0003oY;k/00WoY;k/00?o0000ojFok?nU_n`02OnU_n`00ol0003oYl7/ojO1k006ojO1k003
o`000?nW`Nco000000KoZL;/0ol00002ojW2k003o`000?nZ`ncoZ/?/00[oZ/?/00?o0000ojc3jon/
`n/02On/`n/00ol0003o[L?Zojg3jP04ojg3jP?o000000?oZl?[o`000?n/`^X02_n/`^X00ol0003o
[<7Yojc1j@09ojc1j@03o`000?n/`>So[<3X00So[<3X1_l00005ooooo`03o`000?oooooooooo01?o
oooo000Sooooo`03o`000?oooooooooo00Kooooo0ol0001looooo`03o`000?nO^N_oWkW[00SoWkW[
00?o0000oinjk?nO^^`02?nO^^`00ol0003oXKc/oj6lk003o`0000GoXkg/00?o0000ojBnk?nT_^`0
2?nT_^`00ol0003oYKo/ojFok009ojFok003o`000?nW`NcoYl7/00KoYl7/00?o0000ojO1k?l00000
0_nY`^`3o`0000KoZL;/00?o0000oj[3k?nZ`n`02_nZ`n`00ol0003o[<?[ojc3j`09ojc3j`03o`00
0?n]`n[o[L?Z00?o00001On[`n/00ol0003o[<;Zojc2jP09ojc2jP03o`000?n/`NWo[<7Y00Wo[<7Y
00?o0000ojc0j?n/`>P01?n/`>P6o`0000Sooooo00?o0000ooooooooool04oooool002;ooooo00?o
0000ooooooooool01?ooool3o`00083ooooo00?o0000oinijonO^N/02?nO^N/00ol0003oWk[/oinj
k006oinjk0Co00002OnS_N`00ol0003oY;k/ojBnk008ojBnk003o`000?nU_ncoYKo/00WoYKo/00?o
0000ojO1k?nW`N`01_nW`N`4o`0000[oZL;/00?o0000oj[3k?nZ`n`02_nZ`n`00ol0003o[<?[ojc3
j`08ojc3j`?o00002On[`n/00ol0003o[<;Zojc2jP09ojc2jP03o`000?n/`NWo[<7Y00Wo[<7Y00?o
0000ojc0j?n/`>P01Ol0000<ooooo`03o`000?oooooooooo01?ooooo000Rooooo`04o`000?oooooo
ooooooooo`?o0000Q?ooool00ol0003oWkW[oinij`08oinij`03o`000?nO^^coWk[/00Go00000onR
^n/00ol0003oXkg/oj>mk008oj>mk003o`000?nT_^coY;k/00SoY;k/00?o0000ojFok?nU_n`02OnU
_n`00ol0003oYl7/ojO1k005o`000004ojS1k?l0003oZ<7/o`0000_oZL;/00?o0000oj[3k?nZ`n`0
2_nZ`n`00ol0003o[<?[ojc3j`04ojc3j`?o000000?oZl?/o`000?n[`n/02_n[`n/00ol0003o[<;Z
ojc2jP09ojc2jP03o`000?n/`NWo[<7Y00So[<7Y1Ol0000?ooooo`03o`000?oooooooooo01?ooooo
000Rooooo`Co0000R?ooool00ol0003oWkW[oinij`06oinij`Co00002OnR^n/00ol0003oXkg/oj>m
k008oj>mk003o`000?nT_^coY;k/00SoY;k/00?o0000ojFok?nU_n`02?nU_n`3o`0000OoZ<7/00?o
0000ojS1k?l000002onY`^`00ol0003oZ/?/oj[3k00:oj[3k003o`000?n/`n_o[<?[00?o00001On[
`n`00ol0003oZl?[oj_3j`09oj_3j`03o`000?n/`^[o[<;Z00Wo[<;Z00?o0000ojc1jOn/`NT01?n/
`NT5o`0001;ooooo00?o0000ooooooooool04oooool002;ooooo0ol0002:ooooo`03o`000?nO^N_o
WkW[00Go00000onQ^^X00ol0003oX[_[oj:kj`08oj:kj`03o`000?nS_NcoXkg/00SoXkg/00?o0000
ojBnk?nT_^`02?nT_^`00ol0003oYKo/ojFok004ojFok0?o000000?oY/3/o`000?nX`N`02?nX`N`0
0ol0003oZ<7/o`00000;ojW2k003o`000?nZ`ncoZ/?/00SoZ/?/1?l00009oj_3k003o`000?n[`n_o
Zl?[00SoZl?[00?o0000ojc2j_n/`^X02_n/`^X00ol0003o[<7Yojc1j@04o`0001Oooooo00?o0000
ooooooooool04_ooool002Cooooo00?o0000ooooooooool0ROooool2o`0000WoXK[Z00?o0000oj:k
jonR^n/02?nR^n/00ol0003oXkg/oj>mk008oj>mk003o`000?nT_^coY;k/00SoY;k/00?o0000ojFo
k?nU_n`00ol00005ojK0k003o`000?nX`NcoZ<7/00KoZ<7/00Co0000ojS1k?nX`Nco00002onY`^`0
0ol0003oZ/?/oj[3k004oj[3k0?o00000_nZ`n`00ol0003oZl?/oj_3k009oj_3k003o`000?n[`n_o
Zl?[00SoZl?[00?o0000ojc2j_n/`^X02?n/`^X5o`0001[ooooo00?o0000ooooooooool04_ooool0
01Kooooo00?ok^k^o`000?l000000_l000000ol@413oooooooooo`07ooooo`03o`000?oooooooooo
08Wooooo00?o0000oj6jj_nQ^^X02?nQ^^X00ol0003oX[_[oj:kj`08oj:kj`03o`000?nS_NcoXkg/
00SoXkg/00?o0000ojBnk?nT_^`01_nT_^`4o`0000WoY/3/00?o0000ojS1k?nX`N`01_nX`N`01?l0
003oZ<7/ojS1k?l0000;ojW2k003o`000?nZ`ncoZ/?/00?o00001_nZ`n`00ol0003oZl?/oj_3k009
oj_3k003o`000?n[`n_oZl?[00SoZl?[00?o0000ojc2j_n/`^X01?n/`^X5o`0001gooooo00?o0000
ooooooooool04_ooool001Kooooo00GoMgMgoiRHV?oooooo0000ogMgM`0;ooooo`03o`000?oooooo
oooo08Wooooo00?o0000oj6jj_nQ^^X02?nQ^^X00ol0003oX[_[oj:kj`08oj:kj`03o`000?nS_Nco
Xkg/00SoXkg/00?o0000ojBnk?nT_^`01Ol00004ojFok003o`000?nV`>coY/3/00OoY/3/00?o0000
ojS1k?nX`N`01_nX`N`01?l0003oZ<7/ojS1k?l0000:ojW2k0?o00002_nZ`n`00ol0003oZl?/oj_3
k008oj_3k003o`000?n[`n_oZl?[00WoZl?[00?o0000ojc2j_n/`^X01?l0000Qooooo`03o`000?oo
oooooooo01;ooooo000Fooooo`05oa0@4?ooooooooooo`000?l@41003?ooool00ol0003ooooooooo
o`29ooooo`03o`000?nQ^^[oXK[Z00SoXK[Z00?o0000oj:kjonR^n/02?nR^n/00ol0003oXkg/oj>m
k007oj>mk0?o00002_nU_n`00ol0003oY/3/ojK0k007ojK0k003o`000?nX`NcoZ<7/00KoZ<7/00Co
0000ojS1k?nX`Nco00001_nY`^`3o`0000;oZL?/00?o0000oj[3k?nZ`n`02OnZ`n`00ol0003oZl?/
oj_3k008oj_3k003o`000?n[`n_oZl?[00SoZl?[1?l0000Tooooo`03o`000?oooooooooo01;ooooo
000Fooooo`03o`000?oooooooooo00;o00003Oooool00ol0003oooooooooo`29ooooo`03o`000?nQ
^^[oXK[Z00SoXK[Z00?o0000oj:kjonR^n/02?nR^n/00ol0003oXkg/oj>mk003oj>mk0?o00000_nU
_N/00ol0003oYKo/ojFok009ojFok003o`000?nV`>coY/3/00OoY/3/00?o0000ojS1k?nX`N`01_nX
`N`01?l0003oZ<7/ojS1k?l00002ojW2k0?o00001_nY`n`00ol0003oZ/?/oj[3k009oj[3k003o`00
0?n[`ncoZl?/00SoZl?/00?o0000oj_3jon[`n/01?n[`n/4o`0002Oooooo00?o0000ooooooooool0
4_ooool001Kooooo00?o0000ooooooooool00_l0000>ooooo`03o`000?oooooooooo08Wooooo00?o
0000oj6jj_nQ^^X02?nQ^^X00ol0003oX[_[oj:kj`08oj:kj`03o`000?nS_Nco000000;o00001_nU
_N/00ol0003oYKo/ojFok009ojFok003o`000?nV`>coY/3/00OoY/3/00?o0000ojS1k?nX`N`01_nX
`N`00ol0003oZ<7/o`000002o`0000[oZL?/00?o0000oj[3k?nZ`n`02OnZ`n`00ol0003oZl?/oj_3
k008oj_3k003o`000?n[`n_oZl?[00Co0000:_ooool00ol0003oooooooooo`0Booooo`005_ooool0
1Ol@413oooooooooool0003o410@00oooooo00?o0000ooooooooool0ROooool00ol0003oXK[Zoj6j
jP08oj6jjP03o`000?nR^n_oX[_[00KoX[_[0ol0000:ojFmj`03o`000?nU_ncoYKo/00WoYKo/00?o
0000ojK0k?nV`>`01onV`>`00ol0003oZ<7/ojS1k004ojS1k0?o00000_nY`^`00ol0003oZL?/ojW3
k009ojW3k003o`000?nZ`ncoZ/?/00WoZ/?/00?o0000oj_3k?n[`n`01_n[`n`4o`0002kooooo00?o
0000ooooooooool04_ooool001Kooooo00GoMgMgoiRHV?oooooo0000ogMgM`0@ooooo`;o0000R_oo
ool00ol0003oXK[Zoj6jjP08oj6jjP03o`000?nR^n_oX[_[00Go00000onT_>X00ol0003oYKg[ojFm
j`08ojFmj`03o`000?nU_ncoYKo/00WoYKo/00?o0000ojK0k?nV`>`01onV`>`00ol0003oZ<7/ojS1
k003o`0000?oZL;/00Co0000ojW2k?nY`^co00002onY`n`00ol0003oZ/?/oj[3k009oj[3k003o`00
0?n[`ncoZl?/00Ko0000<Oooool00ol0003oooooooooo`0Booooo`005_ooool01Oo^k^ko0`<3o`00
0?l0003ok^k^01;ooooo00?o0000ooooooooool0R?ooool00ol0003oXK[Zoj6jjP06oj6jjPCo0000
2OnT_>X00ol0003oYKg[ojFmj`08ojFmj`03o`000?nU_ncoYKo/00WoYKo/00?o0000ojK0k?nV`>`0
1OnV`>`4o`0000KoZL;/00Go0000ojW2k?nY`^coZL;/o`00000;ojW3k003o`000?nZ`ncoZ/?/00So
Z/?/1_l0000dooooo`03o`000?oooooooooo01;ooooo000/ooooo`03o`000?oooooo000008[ooooo
00?o0000oj6jj_nQ^^X01Ol00002ojBkj@03o`000?nT_>[oY;cZ00WoY;cZ00?o0000ojFmjonU_N/0
2?nU_N/00ol0003oYKo/ojFok009ojFok003o`000?nV`>coY/3/00Co00000onX`N`00ol0003oZL;/
ojW2k005ojW2k005o`000?nY`^coZL;/ojW2k?l000002onY`n`00ol0003oZ/?/oj[3k004oj[3k0Go
0000>?ooool00ol0003oooooooooo`0Booooo`00;oooool00ol0003oooooooooo`28ooooo`;o0000
2?nT^nT00ol0003oY;cZojBljP09ojBljP03o`000?nU_N_oYKg[00SoYKg[00?o0000ojFok?nU_n`0
2?nU_n`3o`0000SoZ<7/00?o0000ojW2k?nY`^`01OnY`^`01Ol0003oZL;/ojW2k?nY`^co000000_o
ZL?/00?o0000oj[3k?nZ`n`01Ol0000looooo`03o`000?oooooooooo017ooooo000`ooooo`03o`00
0?oooooooooo08Oooooo0_l00009ojBkj@03o`000?nT_>[oY;cZ00WoY;cZ00?o0000ojFmjonU_N/0
2?nU_N/00ol0003oYKo/ojFok004ojFok0?o000000?oZ<3[o`000?nX`N`02OnX`N`00ol0003oZL;/
ojW2k005ojW2k005o`000?nY`^coZL;/ojW2k?l000002_nY`n`5o`0003oooooo00?o0000oooooooo
ool04Oooool0037ooooo00?o0000ooooooooool0Qoooool2o`0000WoY;_Y00?o0000ojBlj_nT_>X0
2OnT_>X00ol0003oYKg[ojFmj`08ojFmj`03o`000?nU_ncoYKo/00?o00001OnX`>/00ol0003oZ<7/
ojS1k008ojS1k003o`000?nY`^coZL;/00GoZL;/00Go0000ojW2k?nY`^coZL;/o`000006ojW3k0Co
0000@oooool00ol0003oooooooooo`0Aooooo`00<_ooool00ol0003oooooooooo`27ooooo`;o0000
2OnT^nT00ol0003oY;cZojBljP09ojBljP03o`000?nU_N_oYKg[00KoYKg[1?l00009ojS0j`03o`00
0?nX`NcoZ<7/00SoZ<7/00?o0000ojW2k?nY`^`01OnY`^`01Ol0003oZL;/ojW2k?nY`^co000000;o
ZL?/1?l00016ooooo`03o`000?oooooooooo017ooooo000cooooo`03o`000?oooooooooo08Oooooo
0_l00009ojBkj@03o`000?nT_>[oY;cZ00WoY;cZ00?o0000ojFmjonU_N/01Ol00003ojNnjP03o`00
0?nX`>_oZ<3[00SoZ<3[00?o0000ojS1k?nX`N`02?nX`N`00ol0003oZL;/ojW2k005ojW2k003o`00
0?nY`^coZL;/00Co0000BOooool00ol0003oooooooooo`0Aooooo`00=?ooool2o`0008Sooooo0_l0
0009ojBkj@03o`000?nT_>[oY;cZ00SoY;cZ0ol00009ojNnjP03o`000?nX`>_oZ<3[00SoZ<3[00?o
0000ojS1k?nX`N`02?nX`N`00ol0003oZL;/ojW2k004ojW2k0?o0000COooool00ol0003ooooooooo
o`0Aooooo`00=_ooool00ol0003oooooooooo`26ooooo`;o00002OnT^nT00ol0003oY;cZojBljP04
ojBljP?o000000?oYkgYo`000?nW_^X02_nW_^X00ol0003oZ<3[ojS0j`08ojS0j`03o`000?nX`Nco
Z<7/00SoZ<7/00?o0000ojW2k?nY`^`00ol000000ooooooo0000ooooo`1=ooooo`03o`000?oooooo
oooo017ooooo000gooooo`;o0000Qoooool2o`0000WoY;_Y00?o0000ojBlj_nT_>X00ol00005ojNm
j@03o`000?nW_^[oYkkZ00WoYkkZ00?o0000ojS0jonX`>/02?nX`>/00ol0003oZ<7/ojS1k006ojS1
k0Co00001Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo000fooooo`03
o`000?oooooo000008Sooooo0_l00007ojBkj@Co00002OnW_NT00ol0003oYkkZojNnjP09ojNnjP03
o`000?nX`>_oZ<3[00SoZ<3[00?o0000ojS1k?nX`N`01Ol0000:ooooo`03o`000?oooooooooo04[o
oooo00?o0000ooooooooool04Oooool003Wooooo00?o0000ooooooooool0Q_ooool2o`0000;oY;_Y
1?l00003ojNlj003o`000?nW_NWoYkgY00SoYkgY00?o0000ojNnj_nW_^X02OnW_^X00ol0003oZ<3[
ojS0j`07ojS0j`Go00003_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo017ooooo
000jooooo`03o`000?oooooooooo08Kooooo0ol00008ojNlj003o`000?nW_NWoYkgY00SoYkgY00?o
0000ojNnj_nW_^X02OnW_^X00ol0003oZ<3[ojS0j`03ojS0j`Go00004_ooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo017ooooo000kooooo`03o`000?oooooooooo08Kooooo00?o0000
ojNlj?nW_>P02?nW_>P00ol0003oYkgYojNmj@08ojNmj@03o`000?nW_^[oYkkZ00WoYkkZ00?o0000
ojS0jol000000ol0000Gooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool04?ooool0
03cooooo00?o0000ooooooooool0Q_ooool00ol0003oYkcXojNlj008ojNlj003o`000?nW_NWoYkgY
00SoYkgY00?o0000ojNnj_nW_^X02?nW_^X3o`0001_ooooo00?o0000ooooooooool0Aoooool00ol0
003oooooooooo`0@ooooo`00?Oooool2o`0008Oooooo00?o0000ojNlj?nW_>P02?nW_>P00ol0003o
YkgYojNmj@08ojNmj@03o`000?nW_^[oYkkZ00CoYkkZ0ol0000Oooooo`03o`000?oooooooooo04Ko
oooo00?o0000ooooooooool04?ooool003oooooo00?o0000ooooooooool0QOooool00ol0003oYkcX
ojNlj008ojNlj003o`000?nW_NWoYkgY00SoYkgY00?o0000ojNnj_nW_^X00ol0000Rooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool04?ooool0043ooooo00?o0000ooooooooool0QOoo
ool00ol0003oYkcXojNlj008ojNlj003o`000?nW_NWoYkgY00KoYkgY1?l0000Vooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool04?ooool0047ooooo0_l00026ooooo`03o`000?nW_>So
YkcX00SoYkcX00?o0000ojNmjOnW_NT01Ol0000[ooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool04?ooool0043ooooo00?o0000ooooool00000Qoooool00ol0003oYkcXojNlj007ojNl
j0Go0000;oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo013ooooo0013ooooo`03
o`000?oooooooooo08Gooooo00?o0000ojNlj?nW_>P00onW_>P4o`0003Cooooo00?o0000oooooooo
ool0@_ooool00ol0003oooooooooo`0@ooooo`00A?ooool00ol0003oooooooooo`25ooooo`03o`00
0?nW_>So000000?o0000>?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo013ooooo
0015ooooo`03o`000?oooooooooo08Gooooo0_l0000looooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool04?ooool004Kooooo0_l00025ooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`0@ooooo`00B?ooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0?oooo
o`00BOooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`0?ooooo`00B_ooool00ol0003oooooooooo`20ooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0?ooooo`00B_oo
ool2o`00087ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo00oooooo001<ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo00oooooo001=ooooo`03o`000?oooooooooo
07gooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00oooooo001>ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0@_ooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo00oooooo001?ooooo`;o0000O?ooool00ol0003ooooo
ooooo`12ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool03oooool0057ooooo00?o
0000ooooooooool0NOooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool03oooool005;ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool03oooool005?ooooo00?o0000oooo
ooooool0Moooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool03oooool005Cooooo0ol0001fooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`0?ooooo`00E?ooool2o`0007Oooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00kooooo000hooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@08ooooo`03
o`000?oooooooooo07Cooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo00kooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool02?ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo04Wo
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0>ooooo`00>?ooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o0000ooooooooool02?ooool2o`0007?ooooo00?o0000oooooooo
ool0BOooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00kooooo000hooooo`05o`00
0?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0;ooooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00ko
oooo000hooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00gooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool03_ooool003Sooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1<oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool03_ooool003Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03_ooool003So
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool2o`0006kooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00kooooo001Oooooo`03
o`000?oooooooooo06_ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo00kooooo001Pooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00kooooo001Qooooo`;o0000J_oo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool03Ooo
ool006?ooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool03Oooool006Cooooo00?o0000ooooooooool0I_ooool00ol0
003oooooooooo`1Booooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03Oooool006Go
oooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool03Oooool006Kooooo00?o0000ooooooooool0I?ooool00ol0003ooooo
ooooo`1Dooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool03Oooool006Kooooo0ol0
001Tooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0=ooooo`00J?ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo05Kooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0=ooooo`00JOooool00ol0003oooooooooo`1Qoooo
o`03o`000?oooooooooo05Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0=oooo
o`00J_ooool2o`00067ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00gooooo001/ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0
F?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00gooooo001]ooooo`03o`000?oo
oooooooo05gooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00gooooo001^ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0F_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00cooooo001_ooooo`03o`000?oooooooooo
05_ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
00cooooo001_ooooo`?o0000Foooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool03?ooool0077ooooo00?o0000ooooooooool0FOooool00ol0003ooooo
ooooo`1Mooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03?ooool007;ooooo00?o
0000ooooooooool0F?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool03?ooool007?ooooo0_l0001Hooooo`03o`000?oooooooooo05kooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0<ooooo`00MOooool00ol0003oooooooooo`1Eoooo
o`03o`000?oooooooooo05oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0<oooo
o`00M_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0<ooooo`00Moooool00ol0003oooooooooo`1Cooooo`03o`00
0?oooooooooo067ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0<ooooo`00N?oo
ool2o`0005?ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00cooooo001hooooo`;o0000Doooool00ol0003oooooooooo`1Sooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool03?ooool007[ooooo00?o0000ooooooooool0D?ooool00ol0
003oooooooooo`1Tooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03?ooool007_o
oooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool02oooool007cooooo0_l0001?ooooo`03o`000?oooooooooo06Gooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0;ooooo`00O_ooool00ol0003ooooooooo
o`1<ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0;ooooo`00Ooooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo06Oooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0;ooooo`00P?ooool00ol0003oooooooooo`1:oooo
o`03o`000?oooooooooo06Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0;oooo
o`00POooool3o`0004Wooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00_ooooo001fooooo`Co000000?o410@ooooooooool01Oooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0;ooooo`00N?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Oooooo00?o
0000ooooooooool0Joooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo001h
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1[
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool007Sooooo00?o0000oooo
ooooool02_ooool2o`0004Kooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00_ooooo001Looooo`?o000000?o410@ooooooooool05_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo001Nooooo`03oa0@4?nj^[[ooooo01Oooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo06kooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0:ooooo`00G_ooool00onHV9So<S8boooo
o`0Gooooo`03o`000?oooooooooo00kooooo0_l00012ooooo`03o`000?oooooooooo06oooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`00G_ooool00ooMgMgo0000okZj^P0E
ooooo`03oeEEEOmVIVKo0000013ooooo0_l00012ooooo`03o`000?oooooooooo073ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0:ooooo`00G_ooool00omEEEGoMgMgodA4A00Zoooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00[ooooo001Mooooo`05omgMgOl@413oooooob4Q8OoMgMd0:_ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0:ooooo`00GOooool01OmVIVKoQhN7oooooonHV9SoEEEE02_ooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool02_ooool005cooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`0Zooooo`;o
0000?Oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool02_ooool005cooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0[ooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00[ooooo002Aooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
MOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo002Aooooo`;o0000>_oo
ool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_oo
ool009?ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`1gooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool009Cooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`1hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool009Go
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool009Kooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`1iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool009Oooooo0_l0
000dooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`09ooooo`00VOooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo07_ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`09ooooo`00VOooool3o`00037ooooo00?o0000oooo
ooooool0O?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo002Kooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Wooooo002Looooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
O_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo002Mooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Wooooo002Nooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Ooooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo002Oooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Wooooo002Pooooo`;o0000:oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02?ooool00:7ooooo0_l0000Zooooo`03o`000?oooooooooo08;ooooo
00Go0000ooooooooooooooooo`00000:ooooo`00Xoooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo08?ooooo00Co0000oooooooooooo00002_ooool00:Cooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`24ooooo`03o`000?oooooo000000[ooooo002Uooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0QOooool2o`0000[ooooo002Vooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0Q?ooool3o`0000[ooooo002Wooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0P?ooool4o`0000gooooo002Xooooo`04o`000?oooooo0000o`00
027ooooo00?o0000ooooooooool0O?ooool4o`00017ooooo002>ooooo`Co000000?o410@oooooooo
ool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@06ooooo`;o00008_ooool00ol0
003oooooooooo`1hooooo`Co00005Oooool0093ooooo00?o0000ooooooooool01?ooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo07Co
oooo1?l0000Iooooo`00T?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`1`ooooo`Co00007Oooool0093ooooo00?o
0000ooooooooool03_ooool00omgMgOo<S8booooo`09ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0KOooool3o`00027ooooo002@ooooo`03o`000?oooooooooo00_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00;ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0JOoo
ool4o`0002Cooooo002@ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo06Gooooo1?l0000Xooooo`00T?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo0ol0000Jooooo`03o`000?oooooooooo
067ooooo1?l0000/ooooo`00S_ooool00omEEEGoIVIVo`00000=ooooo`Co00003_ooool2o`0001_o
oooo00?o0000ooooooooool0GOooool4o`00033ooooo002booooo`;o00006Oooool00ol0003ooooo
ooooo`1Iooooo`Co0000=?ooool00;Cooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`1Eooooo`Co0000>?ooool00;Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1A
ooooo`Co0000??ooool00;Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1=oooo
o`Co0000@?ooool00;Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`19ooooo`Co
0000A?ooool00;Sooooo0_l0000Cooooo`03o`000?oooooooooo04Gooooo1?l00018ooooo`00^Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo047ooooo1?l0001<ooooo`00^_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03kooooo0ol0001@ooooo`00^oooool2o`00
013ooooo00?o0000ooooooooool0>_ooool4o`0005?ooooo002mooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0=_ooool4o`0005Oooooo002nooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0<_ooool4o`0005_ooooo002oooooo`;o00003?ooool00ol0003ooooooooo
o`0^ooooo`Co0000Goooool00;oooooo0_l0000<ooooo`03o`000?oooooooooo02[ooooo1?l0001S
ooooo`00`Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Kooooo1?l0001Woooo
o`00`_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02;ooooo1?l0001[ooooo`00
`oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01kooooo1?l0001_ooooo`00a?oo
ool2o`0000Oooooo00?o0000ooooooooool06_ooool4o`0007?ooooo0036ooooo`?o00001?ooool0
0ol0003oooooooooo`0Fooooo`Co0000Moooool00<Kooooo0_l00005ooooo`03o`000?oooooooooo
01?ooooo0ol0001kooooo`00b?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oo
oooo1?l0001nooooo`00bOooool01Ol0003ooooooooooooooooo000000gooooo1?l00022ooooo`00
b_ooool01?l0003oooooooooool00009ooooo`Co0000Q_ooool00<_ooooo00?o0000ooooool00000
1Oooool4o`0008[ooooo003<ooooo`Oo0000S_ooool00<;ooooo1Ol00006ooooo`;o0000T_ooool0
0<;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A02Jooooo`00`oooool00onHV9So8B4Qonk^kP2Koooo
o`00a?ooool00onHV9So8B4Qonk^kP2Jooooo`00aOooool00omgMgOoIVIVooooo`2Iooooo`00a_oo
ool00ol0003oooooooooo`2Hooooo`00`_ooool01Ol0003o^[ZjoooooonHV9So410@09[ooooo0032
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0V_ooool00?ooooooH_ooool00?ooooooH_ooool00?oo
ooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?oo
ooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?oo
ooooH_ooool00:Wooooo0ol000000ol@413oooooooooo`2booooo`00U_ooool2o`0000_ooooo00?o
0000okZj^_ooool01Oooool00ol@413o^[Zjooooo`04ooooo`03o`000?nj^[[ooooo00cooooo0_l0
0006ooooo`03o`000?nj^[[ooooo09Gooooo002Fooooo`03o`000?oooooooooo00[ooooo0_lb<S86
ooooo`03oiRHV?lb<S;ooooo00Cooooo0_lb<S8>ooooo`03o`000?oooooooooo00Cooooo0_lb<S:F
ooooo`00S?ooool01Ol@413o0000o`000?l0003o410@00Gooooo00?o0000ooooooooool00_ooool2
o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00Gooooo00?ogMgMo`000?nj^[X01?ooool0
0on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool00ol0003ooooooooo
o`04ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`Co0000
00?o410@ooooooooool00_ooool2ob4Q8GOooooo002>ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@
41001Oooool00omEEEGoMgMgodA4A004ooooo`03olc<c?l0003o410@00Gooooo00Go410@okZj^_o^
k^koMgMgoa0@4003ooooo`03o`000?oooooooooo00Cooooo00?oc<c<o`000?l@41001?ooool01Ol@
413o^[Zjonk^k_mgMgOo410@00;ooooo1_l00004ooooo`03o`000?oooooooooo00Cooooo0_lQ8B5g
ooooo`00S_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00CogMgMo`00
0?l@413oc<c<2_ooool01OoMgMgo410@oooooolQ8B7ogMgM00_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0OOoo
ool008kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04onk^k_lQ8B7o
410@onk^kP[ooooo00GoIVIVohN7QoooooooV9RHoeEEE@0;ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`Ko00001?ooool00ol0003ooooo
ooooo`1mooooo`00S_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Co
8B4QogMgMomgMgOo<S8b2Oooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo00Wooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0OOooool008_ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00002?ooool01?l@413o0000
o`000?ooool2o`000003oa0@4?oooooooooo00Kooooo00?o410@o`000?l000000ol00004ooooo`03
o`000?oooooooooo00Wooooo00?o410@o`000?l000000ol0000=ooooo`03o`000?oooooooooo07go
oooo002;ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo07gooooo002;ooooo`Oo00001?ooool2o`0002;ooooo
00?o0000ooooooooool01?ooool2o`0000gooooo00?o0000ooooooooool03?ooool00omEEEGoIVIV
o`00001oooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00\
\>"],
  ImageRangeCache->{{{0, 352.438}, {392.188, 0}} -> {-0.0365789, -0.0401404, \
0.00334761, 0.00334761}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "In Cell ",
  ButtonBox["6.85",
    ButtonData:>"Cell 6.85",
    ButtonStyle->"Hyperlink"],
  ", we compare the Crank-Nicolson solution with the exact solution, Eq. ",
  ButtonBox["(6.2.32)",
    ButtonData:>"(6.2.32)",
    ButtonStyle->"Hyperlink"],
  ", along a cut at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 1/2\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(CrankNicolson = 
        Table[Plot[Tsol[1/2, y, t], {y, 0, L\_y}, PlotRange \[Rule] {0, 1}, 
            AxesLabel \[Rule] {"\<y\>", "\<\>"}, 
            DisplayFunction \[Rule] Identity, 
            PlotLabel \[Rule] \*"\"\<T[\!\(1\/2\),y,t],t=\>\"" <> 
                ToString[t]], {t, 0, 1,  .1}];\)\), "\n", 
    \(\(exact\  = 
        Table[Plot[
            Evaluate[\(\[ExponentialE]\^\(\(-\[Pi]\^\(\(2\)\(\ \)\)\) \[Chi]\ \
t\ \((1\ /L\_x\^2 + 1\ /L\_y\^2)\)\)\) Sin[Pi\ 5\ \[CapitalDelta]x/L\_x] 
                Sin[Pi\ y/L\_y]], {y, 0, L\_y}, 
            DisplayFunction \[Rule] Identity, 
            PlotStyle \[Rule] {RGBColor[1, 0, 0], 
                Dashing[{0.05, 0.05}]}], {t, 0, 
            1,  .1}];\)\ \[IndentingNewLine]\), "\n", 
    \(\(Table[
        Show[CrankNicolson[\([n]\)], exact[\([n]\)], 
          DisplayFunction \[Rule] $DisplayFunction], {n, 1, 
          Length[exact]}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.85"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0 0.618034 [
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .12361 -18 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -18 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -18 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -18 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -41.0938 0 ]
[.5 .63053 41.0938 20.6875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .12361 m
.03006 .12361 L
s
[(0.2)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(0.4)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(0.6)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(0.8)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0309 m
.02756 .0309 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .58713 m
.02756 .58713 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -102.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 17.438 moveto
(@) show
78.062 11.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
76.750 17.438 moveto
(\\200\\200) show
81.000 17.438 moveto
(\\200) show
83.062 17.438 moveto
(\\200) show
78.062 23.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
87.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
93.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
99.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.188 17.438 moveto
(D) show
117.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
123.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.188 17.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
135.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
141.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .07865 L
.10458 .16276 L
.14415 .2389 L
.18221 .30837 L
.22272 .37701 L
.26171 .43664 L
.30316 .49224 L
.34309 .53696 L
.3815 .57132 L
.40095 .58532 L
.42237 .5978 L
.44268 .60689 L
.45178 .61009 L
.46172 .61298 L
.4671 .61427 L
.4721 .61531 L
.47727 .6162 L
.48196 .61686 L
.48658 .61737 L
.49093 .61771 L
.49332 .61785 L
.49552 .61794 L
.49667 .61798 L
.49794 .61801 L
.49926 .61803 L
.50049 .61803 L
.50175 .61801 L
.50239 .618 L
.50309 .61799 L
.50433 .61795 L
.50549 .6179 L
.50811 .61777 L
.51094 .61758 L
.5161 .61709 L
.52084 .61648 L
.52988 .61492 L
.5394 .61269 L
.55914 .60618 L
.57751 .59787 L
.61655 .57283 L
.65805 .53582 L
.69803 .49077 L
.7365 .43922 L
.77742 .37679 L
.81682 .31009 L
.85471 .24105 L
.89505 .16349 L
.93387 .0861 L
.97515 .00214 L
Mistroke
.97619 0 L
Mfstroke
1 0 0 r
[ .05 .05 ] 0 setdash
.02381 0 m
.06244 .07855 L
.10458 .16272 L
.14415 .23895 L
.18221 .30843 L
.22272 .37703 L
.26171 .43673 L
.30316 .49226 L
.34309 .53707 L
.3815 .57141 L
.40095 .58533 L
.42237 .59788 L
.44268 .60702 L
.45178 .61023 L
.46172 .61311 L
.4671 .6144 L
.4721 .61542 L
.47727 .6163 L
.48196 .61694 L
.48658 .61743 L
.4887 .6176 L
.49093 .61776 L
.49332 .61788 L
.49438 .61793 L
.49552 .61797 L
.49675 .618 L
.49789 .61802 L
.49859 .61803 L
.49925 .61803 L
.50049 .61803 L
.50163 .61803 L
.50286 .61801 L
.50401 .61798 L
.50508 .61795 L
.50754 .61784 L
.51014 .61769 L
.51268 .61749 L
.51504 .61727 L
.5204 .61664 L
.5293 .61515 L
.53882 .61297 L
.54906 .60996 L
.56016 .6059 L
.58032 .59647 L
.62123 .56927 L
.66064 .53328 L
.69852 .49018 L
.73886 .43591 L
.77769 .37638 L
.81897 .30636 L
Mistroke
.85873 .23353 L
.89697 .15967 L
.93767 .07832 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00I?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd0=oooool4o`000003oa0@4?oooooooooo03Gooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03Kooooo1Ol0
000[ooooo`00I?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo03Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0eooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0:oooool006Cooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Gooooo00?oV9RHob4Q8Oo^k^h0
;?ooool006Cooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo03Sooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03Oooooo
00?oV9RHob4Q8Oo^k^h0:oooool006Cooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0>Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`03ogMgMomVIVKooooo02[ooooo001Tooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
02Wooooo001Tooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hoooo
o`05o`000?nj^[[ooooooiRHV?l@4100:oooool006Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co0000>?ooool00omEEEGoIVIVo`00000iooooo`03oeEEEOmVIVKo000000gooooo1?l0000g
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03oooool3o`000003oa0@4?oooooooooo01Kooooo003o
ooooodoooooo00?o410@okZj^_ooool05oooool00?ooooooCoooool00onHV9So<S8booooo`0Goooo
o`00oooooom?ooooo`03omgMgOl0003o^[Zj01Oooooo003oooooodoooooo00?oEEEEogMgMom4A4@0
5oooool00?ooooooC_ooool01OoMgMgo410@oooooolQ8B7ogMgM01Kooooo000Toooooooo00006?l0
00000ooo003o0000o`000005o`0000[ooooo00GoIVIVohN7QoooooooV9RHoeEEE@0Fooooo`00:_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?oo`00ooooooooool03_oo
ool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo01Cooooo000Zooooo`;o0000@oooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0@?ooool0
0ooo003o0000ooooo`0?ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool04ooo
ool002[ooooo0_l0003oooooo`oooooo00?oo`00ooooooooool0:oooool002[ooooo00?o0000oooo
ool00000ooooool=ooooo`03ool00?l0003ooooo02cooooo000Zooooo`03o`000?oooooo00000?oo
oooo3Oooool00ol0003oooooooooo`0/ooooo`00:_ooool01?l0003oooooooooool0003oooooo`co
oooo00?o0000ooooooooool0;?ooool002[ooooo00Go0000oooooooooooo0000ool0003oooooo`[o
oooo00?o0000ooooooooool0;Oooool002[ooooo00Go0000ooooooooooooooooool0003oooooo`[o
oooo00?o0000ooooooooool0;Oooool002[ooooo0_l00002ooooo`03o`000?oo003ooooo0?oooooo
1oooool00ol0003oooooooooo`0^ooooo`00:_ooool00ol0003oooooooooo`02ooooo`03ool00?oo
oooooooo0?oooooo1_ooool00ol0003oooooooooo`0^ooooo`00:_ooool00ol0003oooooooooo`02
ooooo`03o`000?oo003ooooo0?oooooo1Oooool00ol0003oooooooooo`0_ooooo`00:_ooool00ol0
003oooooooooo`03ooooo`03ool00?oooooooooo0?oooooo1?ooool00ol0003oooooooooo`0_oooo
o`00:_ooool00ol0003oooooooooo`03ooooo`03o`000?oo003ooooo0?oooooo0oooool00ol0003o
ooooooooo`0`ooooo`00:_ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo0?oooooo
0_ooool00ol0003oooooooooo`0`ooooo`00:_ooool00ol0003oooooooooo`04ooooo`03ool00?oo
oooooooo0?oooooo0Oooool00ol0003oooooooooo`0aooooo`00:_ooool00ol0003oooooooooo`05
ooooo`03ool00?oooooooooo0?oooooo00?o0000ooooooooool0<Oooool002[ooooo00?o0000oooo
ooooool01Oooool00ooo003oooooooooo`3nooooo`03ool00?oooooooooo03;ooooo000Zooooo`;o
00001oooool00ooo003oooooooooo`3mooooo`03ool00?oooooooooo03;ooooo000Zooooo`03o`00
0?oooooooooo00Kooooo00?oo`00ooooooooool0o?ooool00ooo003oooooooooo`0cooooo`00:_oo
ool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo0?[ooooo00?oo`00o`000?ooool0=?oo
ool002[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3jooooo`03ool00?oooooo
oooo03Cooooo000Zooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0n?ooool00ooo
003o0000ooooo`0eooooo`00:_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?So
oooo00?oo`00ooooooooool0=Oooool002[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`3fooooo`03ool00?l0003ooooo03Kooooo000Zooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0m_ooool00ooo003oooooooooo`0fooooo`00:_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo0?Cooooo00?oo`00o`000?ooool0=oooool002[ooooo0_l0000;oooo
o`03o`000?oooooooooo0?Cooooo00?oo`00ooooooooool0=oooool002[ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`3booooo`03ool00?l0003ooooo03Sooooo000Zooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0l_ooool00ooo003oooooooooo`0hooooo`00:_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0?3ooooo00?oo`00o`000?ooool0>Ooo
ool002[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3`ooooo`03o`000?oooooo
oooo03Wooooo000Zooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0koooool00ol0
003oooooooooo`0iooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo003ooooo0>kooooo00?o0000oooo
ooooool0>_ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`3]
ooooo`03o`000?oooooooooo03[ooooo000@ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0onHV9So8B4Qonk^kP06ooooo`?o00003_ooool00ol0003oo`00ooooo`3/ooooo`03o`000?oooooo
oooo03_ooooo000@ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05
ooooo`03o`000?oooooooooo00kooooo00?o0000ool00?ooool0k?ooool00ol0003oooooooooo`0k
ooooo`004?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oo003ooooo0>[ooooo00?o0000ooooooooool0??ooool0
013ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool03oooool00ol0003oo`00ooooo`3Zooooo`03o`000?oooooooooo03cooooo000@oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o
0000ooooooooool04?ooool00ol0003oo`00ooooo`3Xooooo`03o`000?oooooooooo03gooooo000@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo
00?o0000ooooooooool04?ooool00ol0003oo`00ooooo`3Xooooo`03o`000?oooooooooo03gooooo
000Zooooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool0i_ooool00ol0003ooooooooo
o`0nooooo`00:_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo003ooooo0>Kooooo00?o0000
ooooooooool0?_ooool002[ooooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`3Toooo
o`03ool00?oooooooooo03oooooo000Zooooo`;o00004oooool00ol0003oo`00ooooo`3Tooooo`03
ool00?oooooooooo03oooooo000Zooooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool0
h_ooool00ooo003oooooooooo`10ooooo`00:_ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
003ooooo0>;ooooo00?oo`00ooooooooool0@?ooool002[ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`3Pooooo`03o`000?oo003ooooo047ooooo000Zooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0h?ooool00ooo003oooooooooo`11ooooo`00:_ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo0=kooooo00?oo`00ooooooooool0@_ooool002[ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`3Nooooo`03ool00?oooooooooo04;ooooo
000Zooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0g?ooool00ooo003ooooooooo
o`13ooooo`00:_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0=[ooooo00?oo`00
o`000?ooool0A?ooool002[ooooo0_l0000Hooooo`03o`000?oooooooooo0=[ooooo00?oo`00oooo
ooooool0A?ooool002[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`3Hooooo`03
ool00?oooooooooo04Gooooo000Zooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
eoooool00ooo003o0000ooooo`16ooooo`00:_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo0=Kooooo00?o0000ooooooooool0A_ooool002[ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`3Fooooo`03o`000?oooooooooo04Kooooo000Zooooo`03o`000?oooooooooo
01[ooooo00?o0000ool00?ooool0e?ooool00ol0003oooooooooo`17ooooo`00:_ooool00ol0003o
ooooooooo`0Kooooo`03ool00?oooooooooo0=?ooooo00?o0000ooooooooool0Aoooool002[ooooo
00?o0000ooooooooool06oooool00ol0003oo`00ooooo`3Booooo`03o`000?oooooooooo04Sooooo
000Zooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0dOooool00ol0003ooooooooo
o`18ooooo`00:_ooool2o`0001gooooo00?o0000ool00?ooool0d?ooool00ol0003oooooooooo`19
ooooo`00:_ooool00ol0003oooooooooo`0Mooooo`03ool00?oooooooooo0<oooooo00?o0000oooo
ooooool0BOooool002[ooooo00?o0000ooooooooool07Oooool00ol0003oo`00ooooo`3>ooooo`03
o`000?oooooooooo04[ooooo000Zooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool0
c?ooool00ol0003oooooooooo`1;ooooo`00:_ooool00ol0003oooooooooo`0Oooooo`03ool00?oo
oooooooo0<_ooooo00?o0000ooooooooool0Boooool002[ooooo00?o0000ooooooooool07oooool0
0ooo003oooooooooo`3:ooooo`03o`000?oooooooooo04cooooo000@ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo023ooooo00?oo`00ooooooooool0bOooool00ooo003oooooooooo`1<ooooo`004?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool08?ooool00ooo003oooooooooo`38ooooo`03o`000?oo003ooooo04gooooo000@oooo
o`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o0000ooooooooool08Oooool0
0ooo003oooooooooo`37ooooo`03ool00?oooooooooo04gooooo000@ooooo`05o`000?oooooooooo
ooooool000002oooool01?m4A4CogMgMooooool00006ooooo`?o00008Oooool00ooo003ooooooooo
o`36ooooo`03o`000?oo003ooooo04kooooo000@ooooo`05o`000?ooooooooooooooool000002ooo
ool01?oMgMgoEEEEooooool00006ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
aOooool00ooo003oooooooooo`1>ooooo`004?ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oMgMgolc<c?l000001_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo0<Cooooo
00?o0000ool00?ooool0Coooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^
k_m4A4Co000000Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`33ooooo`03ool0
0?oooooooooo04oooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000
ooooo`05ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0`Oooool00ooo003ooooo
ooooo`1@ooooo`00:_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0<7ooooo00?o
o`00ooooooooool0D?ooool002[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`2o
ooooo`03ool00?oooooooooo057ooooo000Zooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0_oooool00ooo003oooooooooo`1Aooooo`00:_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo0;gooooo00?oo`00ooooooooool0D_ooool002[ooooo0_l0000Wooooo`03o`00
0?oooooooooo0;gooooo00?oo`00ooooooooool0D_ooool002[ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`2kooooo`03ool00?oooooooooo05?ooooo000Zooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`1Cooooo`00:_ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo0;Wooooo00?o0000ooooooooool0E?ooool002[o
oooo00?o0000ooooooooool0:?ooool00ooo003o0000ooooo`2iooooo`03o`000?oooooooooo05Co
oooo000Zooooo`03o`000?oooooooooo02Sooooo00?oo`00o`000?ooool0^?ooool00ol0003ooooo
ooooo`1Eooooo`00:_ooool00ol0003oooooooooo`0Yooooo`03ool00?l0003ooooo0;Oooooo00?o
0000ooooooooool0EOooool002[ooooo00?o0000ooooooooool0:_ooool00ooo003oooooooooo`2e
ooooo`03o`000?oooooooooo05Kooooo000Zooooo`03o`000?oooooooooo02_ooooo00?oo`00oooo
ooooool0/oooool00ooo003o0000ooooo`1Gooooo`00:_ooool2o`0002cooooo00?oo`00oooooooo
ool0/oooool00ooo003oooooooooo`1Gooooo`00:_ooool00ol0003oooooooooo`0/ooooo`03ool0
0?oooooooooo0;7ooooo00?oo`00o`000?ooool0F?ooool002[ooooo00?o0000ooooooooool0;?oo
ool00ooo003oooooooooo`2aooooo`03ool00?oooooooooo05Sooooo000Zooooo`03o`000?oooooo
oooo02gooooo00?oo`00ooooooooool0[oooool00ooo003oooooooooo`1Iooooo`00:_ooool00ol0
003oooooooooo`0]ooooo`03ool00?oooooooooo0:oooooo00?oo`00ooooooooool0FOooool002[o
oooo00?o0000ooooooooool0;_ooool00ooo003oooooooooo`2]ooooo`03ool00?oooooooooo05[o
oooo000Zooooo`03o`000?oooooooooo02kooooo00?oo`00o`000?ooool0[?ooool00ooo003o0000
ooooo`1Kooooo`00:_ooool00ol0003oooooooooo`0_ooooo`03ool00?oooooooooo0:_ooooo00?o
o`00ooooooooool0Foooool002[ooooo0_l0000aooooo`03o`000?oooooooooo0:Wooooo00?oo`00
ooooooooool0G?ooool002[ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2Yoooo
o`03ool00?oooooooooo05cooooo000Zooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool0Yoooool00ooo003oooooooooo`1Mooooo`00:_ooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo0:Kooooo00?o0000ooooooooool0G_ooool002[ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo05kooooo000Zooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`1Oooooo`00:_ooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool0H?ooool0013o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413o
c<c<00Gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2Qooooo`03o`000?oooooo
oooo063ooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEE
ogMgMoooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0X?oo
ool00ol0003oooooooooo`1Qooooo`004?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`000005ooooo`?o0000=Oooool00ol0003oooooooooo`2Oooooo`03o`00
0?oooooooooo067ooooo000@ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RH
oooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2Nooooo`03
o`000?oooooooooo06;ooooo000@ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003o
EEEEo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0=_ooool00ol0003oo`00ooooo`2Loooo
o`03o`000?oooooooooo06?ooooo000@ooooo`05oa0@4?ooooooooooooooool@41002oooool00omE
EEGoQhN7ooooo`07ooooo`03o`000?oooooooooo03Kooooo00?o0000ool00?ooool0W?ooool00ol0
003oooooooooo`1Sooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@
4?nHV9P01oooool00ol0003oooooooooo`0gooooo`03o`000?oo003ooooo09[ooooo00?o0000oooo
ooooool0I?ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000
oa0@40Gooooo00?o0000ooooooooool0>?ooool00ooo003oooooooooo`2Hooooo`03ool00?oooooo
oooo06Gooooo000Zooooo`03o`000?oooooooooo03Sooooo00?o0000ool00?ooool0V?ooool00ooo
003oooooooooo`1Uooooo`00:_ooool00ol0003oooooooooo`0iooooo`03o`000?oo003ooooo09Ko
oooo00?oo`00ooooooooool0I_ooool002[ooooo00?o0000ooooooooool0>_ooool00ooo003ooooo
ooooo`2Dooooo`03ool00?l0003ooooo06Oooooo000Zooooo`;o0000??ooool00ooo003ooooooooo
o`2Cooooo`03ool00?oooooooooo06Oooooo000Zooooo`03o`000?oooooooooo03_ooooo00?oo`00
ooooooooool0T_ooool00ooo003oooooooooo`1Xooooo`00:_ooool00ol0003oooooooooo`0loooo
o`03ool00?oooooooooo093ooooo00?oo`00o`000?ooool0JOooool002[ooooo00?o0000oooooooo
ool0?Oooool00ooo003oooooooooo`2?ooooo`03ool00?oooooooooo06Wooooo000Zooooo`03o`00
0?oooooooooo03gooooo00?oo`00ooooooooool0S_ooool00ooo003o0000ooooo`1Zooooo`00:_oo
ool00ol0003oooooooooo`0nooooo`03ool00?oooooooooo08cooooo00?oo`00o`000?ooool0Jooo
ool002[ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`2;ooooo`03ool00?oooooo
oooo06_ooooo000Zooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0ROooool00ooo
003o0000ooooo`1/ooooo`00:_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo08So
oooo00?oo`00o`000?ooool0KOooool002[ooooo0_l00012ooooo`03o`000?oooooooooo08Sooooo
00?o0000ooooooooool0K?ooool002[ooooo00?o0000ooooooooool0@_ooool00ol0003ooooooooo
o`26ooooo`03o`000?oooooooooo06gooooo000Zooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool0QOooool00ol0003oooooooooo`1^ooooo`00:_ooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo08Cooooo00?o0000ooooooooool0K_ooool002[ooooo00?o0000oooooooo
ool0A?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo06oooooo000Zooooo`03o`00
0?oooooooooo04Cooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`1`ooooo`00:_oo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0LOoo
ool002[ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1nooooo`03o`000?oooooo
oooo077ooooo000Zooooo`03o`000?oooooooooo04Kooooo00?o0000ool00?ooool0OOooool00ol0
003oooooooooo`1booooo`00:_ooool2o`0004Sooooo00?oo`00ooooooooool0Noooool00ol0003o
ooooooooo`1cooooo`00:_ooool00ol0003oooooooooo`18ooooo`03ool00?oooooooooo07Wooooo
00?o0000ooooooooool0M?ooool002[ooooo00?o0000ooooooooool0BOooool00ooo003ooooooooo
o`1gooooo`03ool00?l0003ooooo07Gooooo000Zooooo`03o`000?oooooooooo04Wooooo00?oo`00
ooooooooool0Moooool00ooo003oooooooooo`1eooooo`00:_ooool00ol0003oooooooooo`1:oooo
o`03ool00?oooooooooo07Gooooo00?oo`00ooooooooool0M_ooool002[ooooo00?o0000oooooooo
ool0Boooool00ooo003oooooooooo`1cooooo`03ool00?l0003ooooo07Oooooo000@ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c005oooo
o`03o`000?oooooooooo04_ooooo00?oo`00ooooooooool0L_ooool00ooo003o0000ooooo`1hoooo
o`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B401Oooool00ol0003oooooooooo`1<ooooo`03ool00?oooooooooo073ooooo00?oo`00
o`000?ooool0NOooool0013ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`1=ooooo`03ool00?oooooooooo06oooooo00?o
o`00ooooooooool0NOooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nH
V9SooooooiRHV?lb<S801Oooool3o`0004gooooo00?o0000ool00?ooool0K_ooool00ooo003ooooo
ooooo`1jooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o
0000olc<c005ooooo`03o`000?oooooooooo04kooooo00?o0000ool00?ooool0K?ooool00ooo003o
ooooooooo`1kooooo`004?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oo
oooo^[Zjoa0@4005ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0J_ooool00ooo
003oooooooooo`1looooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`000005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0J?ooool0
0ooo003oooooooooo`1mooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@05ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0I_oo
ool00ooo003oooooooooo`1nooooo`00:_ooool00ol0003oooooooooo`1Booooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool0Ooooool002[ooooo00?o0000ooooooooool0Doooool00ol0
003oooooooooo`1Rooooo`03o`000?oooooooooo083ooooo000Zooooo`03o`000?oooooooooo05Co
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`21ooooo`00:_ooool2o`0005Kooooo
00?o0000ooooooooool0G_ooool00ol0003oooooooooo`22ooooo`00:_ooool00ol0003ooooooooo
o`1Fooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0Poooool002[ooooo00?o0000
ooooooooool0Eoooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo08Cooooo000Zoooo
o`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0Eoooool2o`0008Oooooo000Zooooo`03
o`000?oooooooooo05Wooooo0_oo001Fooooo`03o`000?oooooooooo08Oooooo000Zooooo`03o`00
0?oooooooooo05_ooooo00?oo`00ooooooooool0D_ooool00ol0003oooooooooo`28ooooo`00:_oo
ool00ol0003oooooooooo`1Looooo`03ool00?oooooooooo053ooooo00?o0000ool00?ooool0ROoo
ool002[ooooo00?o0000ooooooooool0GOooool00ooo003oooooooooo`1>ooooo`03o`000?oo003o
oooo08[ooooo000Zooooo`03o`000?oooooooooo05kooooo00?oo`00ooooooooool0C?ooool00ol0
003oo`00ooooo`2;ooooo`00:_ooool2o`00063ooooo00?oo`00ooooooooool0B_ooool00ol0003o
o`00ooooo`2<ooooo`00:_ooool00ol0003oooooooooo`1Pooooo`03ool00?oooooooooo04Sooooo
00?o0000ool00?ooool0SOooool002[ooooo00?o0000ooooooooool0HOooool00ooo003ooooooooo
o`16ooooo`03o`000?oo003ooooo08kooooo000Zooooo`03o`000?oooooooooo06;ooooo00?oo`00
ooooooooool0A?ooool00ol0003oo`00ooooo`2?ooooo`00:_ooool00ol0003oooooooooo`1Soooo
o`03ool00?oooooooooo04;ooooo0_oo002Aooooo`00:_ooool00ol0003oooooooooo`1Tooooo`03
ool00?l0003ooooo03oooooo0_oo002Cooooo`00:_ooool00ol0003oooooooooo`1Vooooo`03o`00
0?oooooooooo03cooooo00?oo`00ooooooooool0Toooool002[ooooo00?o0000ooooooooool0Iooo
ool00ol0003oooooooooo`0iooooo`;o0000U_ooool002[ooooo00?o0000ooooooooool0J?ooool0
0ol0003oooooooooo`0fooooo`;o0000V?ooool002[ooooo0_l0001Zooooo`;o0000=Oooool00ol0
003oooooooooo`2Hooooo`00:_ooool00ol0003oooooooooo`1[ooooo`?o0000<?ooool2o`0009_o
oooo000Zooooo`03o`000?oooooooooo06kooooo0_l0000]ooooo`03o`000?oooooooooo09_ooooo
000Zooooo`03o`000?oooooooooo073ooooo0_oo000Yooooo`;o0000W_ooool002[ooooo00?o0000
ooooooooool0L_ooool2ool002Gooooo0_l0002Pooooo`00:_ooool00ol0003oooooooooo`1doooo
o`03ool00?oooooooooo027ooooo0_oo002Qooooo`00:_ooool00ol0003oooooooooo`1eooooo`?o
o`007_ooool2ool00:?ooooo000Qooooo`Co000000?o410@ooooooooool00_ooool00ol0003ooooo
ooooo`1hooooo`?oo`006?ooool3ool00:Gooooo000Sooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0Noooool3ool00003o`000?oooooooooo00cooooo1_oo002Xooooo`008oooool0
0ol0003oooooooooo`04ooooo`?o0000Ooooool<o`0000;oo`00[_ooool002?ooooo00?o0000oooo
ooooool0oooooom3ooooo`008oooool00ol0003oooooooooo`3ooooood?ooooo000Sooooo`03o`00
0?oooooooooo0?oooooo@oooool002?ooooo00?o0000ooooooooool0oooooom3ooooo`008Oooool0
0omEEEGoIVIVo`00003oooooodGooooo002Fooooo`Go0000cOooool009Kooooo00GoV9RHob4Q8Oo^
k^koooooodA4A03=ooooo`00Uoooool00onHV9So8B4Qonk^kP3>ooooo`00V?ooool00onHV9So8B4Q
onk^kP3=ooooo`00VOooool00omgMgOoIVIVooooo`3<ooooo`00V_ooool00ol0003oooooooooo`0;
ooooo`?o000000?o410@ooooooooool0^_ooool008gooooo0_l00007ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001oooool00ol0003o^[Zjooooo`05ooooo`03oa0@4?nj^[[ooooo00Cooooo00?o0000
okZj^_ooool03?ooool2o`0000Kooooo00?o0000okZj^_ooool0WOooool008gooooo00?o0000oooo
ooooool01_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Oooooo0_lb<S86ooooo`03oiRHV?lb<S;o
oooo00Cooooo0_lb<S8>ooooo`03o`000?oooooooooo00Cooooo0_lb<S:Nooooo`00Poooool01Ol@
413o0000o`000?l0003o410@00Gooooo00?o0000ooooooooool04_ooool00on7QhOo0000okZj^P05
ooooo`03omgMgOl0003o^[Zj00Cooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4
A4Co^[Zj00?ooooo00?o0000ooooooooool01?ooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0
003o0000odA4A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo0025ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool04_ooool00oo<c<co0000oa0@4005ooooo`03oeEE
EOmgMgOoA4A400Cooooo00?oc<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?o
oooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMg
Mol@41000_ooool6o`000006oooooomgMgOoV9RHoooooonHV9SoMgMgQ_ooool008Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`_o00002oooool01OoMgMgo410@oooooolQ
8B7ogMgM00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00Go410@oooooooooooooooooa0@4026ooooo`00QOooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Wooooo00GoIVIVohN7QoooooooV9RHoeEEE@0;ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`Ko0000
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`24ooooo`00QOooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Sooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMoooo
o`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0;ooooo`05o`000?ooooooooooooooool00000Q_ooool008;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo00Co410@o`000?l0003o
oooo0_l000000ol@413oooooooooo`06ooooo`03oa0@4?l0003o000000?o00001?ooool00ol0003o
ooooooooo`09ooooo`03oa0@4?l0003o000000?o00002_ooool01Ol@413ooooooooooooooooo410@
08Kooooo0022ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool008;ooooo1ol00004oooo
o`;o00002?ooool4o`000003oa0@4?oooooooooo01_ooooo00?o0000ooooooooool01?ooool2o`00
00gooooo00?o0000ooooooooool02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Ioooo
o`03o`000?oooooooooo0<cooooo002Iooooo`03o`000?oooooooooo0<cooooo002Iooooo`03o`00
0?oooooooooo0<cooooo002Iooooo`03o`000?oooooooooo0<cooooo002Iooooo`03o`000?oooooo
oooo0<cooooo002Iooooo`03o`000?oooooooooo0<cooooo002Gooooo`03oeEEEOmVIVKo00000<ko
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.313969, -0.0837537, \
0.00916054, 0.00705812}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0 0.618034 [
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .12361 -18 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -18 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -18 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -18 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -47.0938 0 ]
[.5 .63053 47.0938 20.6875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .12361 m
.03006 .12361 L
s
[(0.2)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(0.4)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(0.6)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(0.8)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0309 m
.02756 .0309 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .58713 m
.02756 .58713 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -108.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 17.438 moveto
(@) show
78.062 11.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
76.750 17.438 moveto
(\\200\\200) show
81.000 17.438 moveto
(\\200) show
83.062 17.438 moveto
(\\200) show
78.062 23.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
87.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
93.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
99.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.188 17.438 moveto
(D) show
117.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
123.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.188 17.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
135.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
153.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .0579 L
.10458 .11983 L
.14415 .17589 L
.18221 .22704 L
.22272 .27756 L
.26171 .32147 L
.30316 .3624 L
.34309 .39533 L
.3815 .42063 L
.40095 .43093 L
.42237 .44012 L
.44268 .44681 L
.45178 .44917 L
.46172 .4513 L
.4671 .45225 L
.4721 .45301 L
.47727 .45367 L
.48196 .45415 L
.48658 .45453 L
.49093 .45478 L
.49332 .45488 L
.49552 .45495 L
.49667 .45498 L
.49794 .455 L
.49926 .45501 L
.50049 .45502 L
.50175 .455 L
.50239 .45499 L
.50309 .45498 L
.50433 .45496 L
.50549 .45492 L
.50811 .45483 L
.51094 .45468 L
.5161 .45432 L
.52084 .45388 L
.52988 .45272 L
.5394 .45108 L
.55914 .44629 L
.57751 .44017 L
.61655 .42174 L
.65805 .39449 L
.69803 .36132 L
.7365 .32337 L
.77742 .27741 L
.81682 .2283 L
.85471 .17747 L
.89505 .12037 L
.93387 .06339 L
.97515 .00157 L
Mistroke
.97619 0 L
Mfstroke
1 0 0 r
[ .05 .05 ] 0 setdash
.02381 0 m
.06244 .0577 L
.10458 .11954 L
.14415 .17553 L
.18221 .22657 L
.22272 .27697 L
.26171 .32083 L
.30316 .36161 L
.34309 .39454 L
.3815 .41976 L
.40095 .42999 L
.42237 .4392 L
.44268 .44592 L
.45178 .44828 L
.46172 .45039 L
.4671 .45134 L
.4721 .45209 L
.47727 .45273 L
.48196 .45321 L
.48658 .45356 L
.4887 .45369 L
.49093 .45381 L
.49332 .4539 L
.49438 .45393 L
.49552 .45396 L
.49675 .45398 L
.49789 .454 L
.49859 .454 L
.49925 .45401 L
.50049 .45401 L
.50163 .454 L
.50286 .45399 L
.50401 .45397 L
.50508 .45395 L
.50754 .45387 L
.51014 .45376 L
.51268 .45361 L
.51504 .45345 L
.5204 .45298 L
.5293 .45189 L
.53882 .45029 L
.54906 .44808 L
.56016 .4451 L
.58032 .43817 L
.62123 .41819 L
.66064 .39175 L
.69852 .36009 L
.73886 .32022 L
.77769 .27649 L
.81897 .22505 L
Mistroke
.85873 .17155 L
.89697 .1173 L
.93767 .05754 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00I?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd0=oooool4o`000003oa0@4?oooooooooo03Gooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03Kooooo1Ol0
000[ooooo`00I?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo03Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0eooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0:oooool006Cooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Gooooo00?oV9RHob4Q8Oo^k^h0
;?ooool006Cooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo03Sooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03Oooooo
00?oV9RHob4Q8Oo^k^h0:oooool006Cooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0>Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`03ogMgMomVIVKooooo02[ooooo001Tooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
02Wooooo001Tooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hoooo
o`05o`000?nj^[[ooooooiRHV?l@4100:oooool006Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co0000>?ooool00omEEEGoIVIVo`00000iooooo`03oeEEEOmVIVKo000000gooooo1?l0000g
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03oooool3o`000003oa0@4?oooooooooo01Kooooo003o
ooooodoooooo00?o410@okZj^_ooool05oooool00?ooooooCoooool00onHV9So<S8booooo`0Goooo
o`00oooooom?ooooo`03omgMgOl0003o^[Zj01Oooooo003oooooodoooooo00?oEEEEogMgMom4A4@0
5oooool00?ooooooC_ooool01OoMgMgo410@oooooolQ8B7ogMgM01Kooooo000Toooooooo00008?l0
000:ooooo`05ofIVI_n7QhOooooooiRHV?mEEED05_ooool002[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?ok^k^o`000?o^k^h00_oo
ool00ol0003ogMgMooooo`0Dooooo`00:_ooool2o`0004?ooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo043ooooo0_l0000@ooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool04oooool002[ooooo00Co0000ooooool0003oo`00oooo
ool<ooooo`03o`000?oo003ooooo02cooooo000Zooooo`04o`000?oooooo0000ool00?oooooo3?oo
ool00ol0003oo`00ooooo`0/ooooo`00:_ooool01Ol0003oooooooooool0003oo`000?oooooo2_oo
ool00ol0003oo`00ooooo`0]ooooo`00:_ooool01Ol0003oooooooooooooooooo`000?oooooo2Ooo
ool00ol0003oo`00ooooo`0^ooooo`00:_ooool01_l0003ooooooooooooooooo0000ool00?oooooo
2?ooool00ooo003oooooooooo`0^ooooo`00:_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
003ooooo0?oooooo1Oooool00ol0003oo`00ooooo`0_ooooo`00:_ooool2o`0000Cooooo00?oo`00
ooooooooool0ooooool3ooooo`03o`000?oo003ooooo033ooooo000Zooooo`03o`000?oooooooooo
00?ooooo00?o0000ool00?ooool0ooooool3ooooo`03ool00?oooooooooo033ooooo000Zooooo`03
o`000?oooooooooo00Cooooo00?oo`00ooooooooool0ooooool1ooooo`03o`000?oo003ooooo037o
oooo000Zooooo`03o`000?oooooooooo00Cooooo00?o0000ool00?ooool0ooooool00ol0003oo`00
ooooo`0booooo`00:_ooool00ol0003oooooooooo`05ooooo`03o`000?oo003ooooo0?kooooo00?o
o`00ooooooooool0<_ooool002[ooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`3l
ooooo`03ool00?oooooooooo03?ooooo000Zooooo`03o`000?oooooooooo00Kooooo00?o0000ool0
0?ooool0noooool00ol0003oooooooooo`0dooooo`00:_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0?[ooooo00?o0000ooooooooool0=?ooool002[ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`3hooooo`03o`000?oooooooooo03Gooooo000Zooooo`;o00002Ooo
ool00ol0003oooooooooo`3gooooo`03o`000?oooooooooo03Kooooo000Zooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0m_ooool00ol0003oooooooooo`0fooooo`00:_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool0=oooool002[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3cooooo`03o`000?oooooooooo03So
oooo000Zooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0l_ooool00ol0003ooooo
ooooo`0hooooo`00:_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0?3ooooo00?o
0000ooooooooool0>Oooool002[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3^
ooooo`03o`000?oooooooooo03[ooooo000Zooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0k_ooool00ol0003oooooooooo`0jooooo`00:_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo0>_ooooo00?oo`00o`000?ooool0??ooool002[ooooo0_l0000@ooooo`03o`00
0?oo003ooooo0>[ooooo00?oo`00ooooooooool0??ooool002[ooooo00?o0000ooooooooool03ooo
ool00ol0003oo`00ooooo`3Yooooo`03ool00?oooooooooo03gooooo000Zooooo`03o`000?oooooo
oooo013ooooo00?o0000ool00?ooool0j?ooool00ooo003oooooooooo`0mooooo`00:_ooool00ol0
003oooooooooo`0Aooooo`03ool00?oooooooooo0>Kooooo00?oo`00ooooooooool0?_ooool002[o
oooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`3Tooooo`03o`000?oo003ooooo03oo
oooo000Zooooo`03o`000?oooooooooo01;ooooo00?o0000ool00?ooool0i?ooool00ooo003ooooo
ooooo`0oooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
1Oooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo0>;ooooo00?o0000ool00?ooool0
@?ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Gooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`3Pooooo`03
o`000?oo003ooooo047ooooo000@ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP06ooooo`?o00005?ooool00ooo003oooooooooo`3Pooooo`03ool00?oooooooooo047o
oooo000@ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05ooooo`03
o`000?oooooooooo01Gooooo00?oo`00ooooooooool0g_ooool00ooo003oooooooooo`12ooooo`00
4?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01?ooool00ol0003o
ooooooooo`0Fooooo`03ool00?oooooooooo0=cooooo00?oo`00ooooooooool0@oooool0013ooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool05oooool00ooo003oooooooooo`3Jooooo`03ool00?l0003ooooo04Cooooo000@ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooo
ooooool05oooool00ol0003oo`00ooooo`3Jooooo`03o`000?oooooooooo04Cooooo000@ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`3Hooooo`03o`000?oooooooooo04Gooooo000Zoooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0e_ooool00ol0003oooooooooo`16oooo
o`00:_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0=Gooooo00?o0000oooooooo
ool0A_ooool002[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`3Dooooo`03o`00
0?oooooooooo04Oooooo000Zooooo`;o00007?ooool00ol0003oooooooooo`3Booooo`03o`000?oo
oooooooo04Sooooo000Zooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0dOooool0
0ol0003oooooooooo`18ooooo`00:_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
0<oooooo00?o0000ooooooooool0BOooool002[ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`3>ooooo`03o`000?oooooooooo04[ooooo000Zooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool0c?ooool00ol0003oooooooooo`1;ooooo`00:_ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0Boooool002[ooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`39ooooo`03ool00?oooooooooo04cooooo000Zoooo
o`03o`000?oooooooooo023ooooo00?oo`00ooooooooool0b?ooool00ol0003oo`00ooooo`1=oooo
o`00:_ooool00ol0003oooooooooo`0Pooooo`03ool00?l0003ooooo0<Sooooo00?oo`00oooooooo
ool0COooool002[ooooo0_l0000Rooooo`03ool00?l0003ooooo0<Kooooo00?oo`00ooooooooool0
C_ooool002[ooooo00?o0000ooooooooool08_ooool00ooo003o0000ooooo`34ooooo`03ool00?oo
oooooooo04oooooo000Zooooo`03o`000?oooooooooo02?ooooo00?oo`00ooooooooool0`_ooool0
0ol0003oo`00ooooo`1@ooooo`00:_ooool00ol0003oooooooooo`0Tooooo`03ool00?oooooooooo
0<7ooooo00?oo`00ooooooooool0D?ooool002[ooooo00?o0000ooooooooool09Oooool00ooo003o
ooooooooo`2oooooo`03ool00?oooooooooo057ooooo000Zooooo`03o`000?oooooooooo02Gooooo
00?oo`00o`000?ooool0__ooool00ol0003oo`00ooooo`1Booooo`00:_ooool00ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo0;gooooo00?oo`00ooooooooool0D_ooool002[ooooo00?o0000
ooooooooool09oooool00ooo003oooooooooo`2kooooo`03ool00?oooooooooo05?ooooo000Zoooo
o`03o`000?oooooooooo02Sooooo00?oo`00ooooooooool0^Oooool00ooo003oooooooooo`1Doooo
o`00:_ooool2o`0002Wooooo00?o0000ool00?ooool0^?ooool00ol0003oooooooooo`1Eooooo`00
:_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0;Oooooo00?o0000ooooooooool0
EOooool002[ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2eooooo`03o`000?oo
oooooooo05Kooooo000Zooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0/oooool0
0ol0003oooooooooo`1Gooooo`00:_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
0;?ooooo00?o0000ooooooooool0Eoooool002[ooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`2aooooo`03o`000?oooooooooo05Sooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool0[oooool00ol0003oooooooooo`1Iooooo`004?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo05[ooooo000@ooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`2[ooooo`03ool00?oooooooooo05_ooooo000@ooooo`05o`000?ooooooooooooooool0
00002oooool01?m4A4CogMgMooooool00006ooooo`?o0000;oooool00ol0003oooooooooo`2Zoooo
o`03o`000?oo003ooooo05cooooo000@ooooo`05o`000?ooooooooooooooool000002oooool01?oM
gMgoEEEEooooool00006ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0Z?ooool0
0ol0003oo`00ooooo`1Mooooo`004?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMg
olc<c?l000001_ooool00ol0003oooooooooo`0aooooo`03ool00?oooooooooo0:Oooooo00?oo`00
ooooooooool0GOooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co
000000Kooooo00?o0000ooooooooool0<Oooool00ooo003o0000ooooo`2Vooooo`03ool00?oooooo
oooo05kooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05
ooooo`03o`000?oooooooooo03;ooooo00?oo`00ooooooooool0Y?ooool00ooo003oooooooooo`1O
ooooo`00:_ooool00ol0003oooooooooo`0cooooo`03ool00?oooooooooo0:;ooooo00?oo`00oooo
ooooool0H?ooool002[ooooo00?o0000ooooooooool0=?ooool00ooo003oooooooooo`2Pooooo`03
ool00?oooooooooo067ooooo000Zooooo`03o`000?oooooooooo03Gooooo00?oo`00ooooooooool0
W_ooool00ooo003oooooooooo`1Rooooo`00:_ooool00ol0003oooooooooo`0fooooo`03ool00?oo
oooooooo09cooooo00?oo`00ooooooooool0Hoooool002[ooooo0_l0000gooooo`03o`000?oo003o
oooo09cooooo00?oo`00ooooooooool0Hoooool002[ooooo00?o0000ooooooooool0=oooool00ol0
003oo`00ooooo`2Jooooo`03ool00?oooooooooo06Cooooo000Zooooo`03o`000?oooooooooo03So
oooo00?o0000ool00?ooool0V?ooool00ol0003oooooooooo`1Uooooo`00:_ooool00ol0003ooooo
ooooo`0iooooo`03o`000?oo003ooooo09Kooooo00?o0000ooooooooool0I_ooool002[ooooo00?o
0000ooooooooool0>_ooool00ol0003oo`00ooooo`2Dooooo`03o`000?oooooooooo06Oooooo000Z
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0Toooool00ol0003oooooooooo`1W
ooooo`00:_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo097ooooo00?o0000oooo
ooooool0J?ooool002[ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`2?ooooo`03
o`000?oooooooooo06Wooooo000Zooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
SOooool00ol0003oooooooooo`1Zooooo`00:_ooool2o`00043ooooo00?o0000ooooooooool0S?oo
ool00ol0003oooooooooo`1Zooooo`00:_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo08[ooooo00?o0000ooooooooool0Joooool002[ooooo00?o0000ooooooooool0@Oooool00ol0
003oooooooooo`27ooooo`03ool00?l0003ooooo06gooooo000Zooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool0Q?ooool2ool00003o`000?oooooooooo06gooooo000Zooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool0Poooool00ooo003o0000o`00001`ooooo`00:_oo
ool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo087ooooo00?oo`00o`000?ooool0LOoo
ool002[ooooo00?o0000ooooooooool0A?ooool00ooo003oooooooooo`1oooooo`03ool00?l0003o
oooo07;ooooo000Zooooo`03o`000?oooooooooo04Gooooo00?oo`00ooooooooool0OOooool00ooo
003o0000ooooo`1cooooo`00:_ooool2o`0004Oooooo00?oo`00ooooooooool0Noooool00ooo003o
0000ooooo`1dooooo`00:_ooool00ol0003oooooooooo`17ooooo`03ool00?oooooooooo07Wooooo
00?oo`00o`000?ooool0MOooool002[ooooo00?o0000ooooooooool0B?ooool00ooo003ooooooooo
o`1gooooo`03ool00?l0003ooooo07Kooooo000Zooooo`03o`000?oooooooooo04Wooooo00?oo`00
ooooooooool0MOooool00ooo003o0000ooooo`1gooooo`00:_ooool00ol0003oooooooooo`1:oooo
o`03ool00?oooooooooo07?ooooo00?oo`00o`000?ooool0N?ooool002[ooooo00?o0000oooooooo
ool0Boooool00ooo003oooooooooo`1booooo`03o`000?oooooooooo07Sooooo000Zooooo`03o`00
0?oooooooooo04cooooo00?oo`00ooooooooool0Koooool2o`0007_ooooo000@ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c005ooooo`03
o`000?oooooooooo04gooooo0_oo001^ooooo`03o`000?oooooooooo07_ooooo000@ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@05oooo
o`03o`000?oooooooooo04oooooo00?oo`00ooooooooool0J_ooool00ol0003oooooooooo`1loooo
o`004?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000005
ooooo`?o0000D?ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo07gooooo000@oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Gooooo00?o
0000ooooooooool0DOooool2o`0006Oooooo00?o0000ooooooooool0O_ooool0013ooooo00Go0000
ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01Oooool00ol0003ooooo
ooooo`1Cooooo`03o`000?oooooooooo06;ooooo0_l00021ooooo`004?ooool01Ol@413ooooooooo
oooooooo410@00_ooooo00?oEEEEohN7Qoooool01oooool00ol0003oooooooooo`1Dooooo`03o`00
0?oooooooooo063ooooo00?o0000ooooooooool0POooool0013ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`03omgMgOl@413oV9RH00Oooooo00?o0000ooooooooool0EOooool2o`0005oooooo
00?o0000ooooooooool0P_ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<
c?m4A4Co0000oa0@40Gooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`1Kooooo`;o
o`00Q?ooool002[ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1Hooooo`;oo`00
Q_ooool002[ooooo00?o0000ooooooooool0FOooool2o`0005Oooooo00?oo`00o`000?ooool0Q_oo
ool002[ooooo00?o0000ooooooooool0F_ooool2ool005Cooooo0_oo0029ooooo`00:_ooool2o`00
05gooooo0_oo001Aooooo`03ool00?l0003ooooo08Wooooo000Zooooo`03o`000?oooooooooo05ko
oooo00?oo`00o`000?ooool0COooool00ooo003oooooooooo`2:ooooo`00:_ooool00ol0003ooooo
ooooo`1Oooooo`;oo`00Boooool2ool008gooooo000Zooooo`03o`000?oooooooooo067ooooo0_oo
0018ooooo`03ool00?oooooooooo08gooooo000Zooooo`03o`000?oooooooooo06?ooooo00?oo`00
ooooooooool0@oooool00ol0003oo`00ooooo`2?ooooo`00:_ooool00ol0003oooooooooo`1Toooo
o`;oo`00@_ooool00ol0003oooooooooo`2@ooooo`00:_ooool00ol0003oooooooooo`1Vooooo`03
ool00?l0003ooooo03gooooo0_l0002Cooooo`00:_ooool00ol0003oooooooooo`1Xooooo`03o`00
0?oooooooooo03Wooooo0_l0002Eooooo`00:_ooool00ol0003oooooooooo`1Yooooo`;o0000=_oo
ool3o`0009Oooooo000Zooooo`;o0000K?ooool3o`00037ooooo0_l0002Jooooo`00:_ooool00ol0
003oooooooooo`1^ooooo`;o0000;Oooool00ooo003o0000ooooo`2Kooooo`00:_ooool00ol0003o
ooooooooo`1`ooooo`;o0000:Oooool00ol0003oo`00ool0002Mooooo`00:_ooool00ol0003ooooo
ooooo`1booooo`03o`000?oo003oo`0002?ooooo00Co0000ool00?oo003oo`00Woooool002[ooooo
00?o0000ooooooooool0MOooool6ool001Sooooo1_oo002Rooooo`00:_ooool00ol0003ooooooooo
o`1hooooo`?o00000ooo000Aooooo`Coo`0000?o0000ooooooooool0YOooool002[ooooo00?o0000
ooooooooool0O?ooool2o`0000Coo`003_l0002[ooooo`00:_ooool00ol0003oooooooooo`3ooooo
occooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo0_l0003oooooocgooooo
000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0ooooooll
ooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oo
oooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`004?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool00ol0003o
ooooooooo`3ooooooccooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00Go8B4QoiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?oooooo??ooool0013o
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`3ooooooccooooo000@ooooo`05o`000?ooooooooooooooool000002oooool0
1Olb<S;oV9RHoooooonHV9So<S8b00Gooooo0ol0003ooooooccooooo000@ooooo`05o`000?oooooo
ooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Gooooo00?o0000ooooooooool0
oooooollooooo`004?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo
^[Zjoa0@4005ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001Oooool00ol0003oooooooooo`3ooooo
occooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413o
ZJVY00Gooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooo
occooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0
oooooollooooo`00:_ooool2o`000?oooooo?Oooool002[ooooo00?o0000ooooooooool0ooooooll
ooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oo
oooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooooooo
o`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooo
ooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`;o0000
oooooolmooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooo
oooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003o
ooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o
0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zoooo
o`03o`000?oooooooooo0?oooooo??ooool002[ooooo0_l0003oooooocgooooo000Zooooo`03o`00
0?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool0
0ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[o
oooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo
000Qooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3ooooooccooooo000S
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooollooooo`008oooool00ol0
003oooooooooo`04ooooo`?o0000oooooollooooo`008oooool00ol0003oooooooooo`3ooooood?o
oooo000Sooooo`03o`000?oooooooooo0?oooooo@oooool002?ooooo00?o0000ooooooooool0oooo
oom3ooooo`008oooool00ol0003oooooooooo`3ooooood?ooooo000Qooooo`03oeEEEOmVIVKo0000
0?ooooooAOooool008kooooo1Ol0003Eooooo`00S_ooool01OnHV9So8B4Qonk^k_ooooooA4A40=Go
oooo002?ooooo`03oiRHV?lQ8B7ok^k^0=Kooooo002@ooooo`03oiRHV?lQ8B7ok^k^0=Gooooo002A
ooooo`03ogMgMomVIVKooooo0=Cooooo002Booooo`03o`000?oooooooooo00_ooooo0ol000000ol@
413oooooooooo`32ooooo`00Q_ooool2o`0000Kooooo00Go0000okZj^_ooooooV9RHoa0@4008oooo
o`03o`000?nj^[[ooooo00Cooooo00?o410@okZj^_ooool01Oooool00ol0003o^[Zjooooo`0<oooo
o`;o00001Oooool00ol0003o^[Zjooooo`2Uooooo`00Q_ooool00ol0003oooooooooo`05ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`02?ooool2oc8b<PGooooo00?oV9RHoc8b<_ooool01Oooool2oc8b
<Pkooooo00?o0000ooooooooool00oooool2oc8b<ZKooooo001kooooo`05oa0@4?l0003o0000o`00
0?l@41001_ooool00ol0003oooooooooo`0Booooo`03ohN7Qol0003o^[Zj00Cooooo00?ogMgMo`00
0?nj^[X01Oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool0
0ol0003oooooooooo`03ooooo`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj
^P09ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413ooooo
ooooo`1jooooo`00OOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o
c<c<o`000?l@41001?ooool00omEEEGoMgMgodA4A005ooooo`03olc<c?l0003o410@00Cooooo00Go
410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@4100
1Oooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00000_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo07cooooo001mooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00oooool:o`0000_ooooo00GogMgMoa0@4?oooooo8B4QomgMg@0;
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`1looooo`00OOooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo00GoIVIVohN7QoooooooV9RHoeEE
E@0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`03ooooo`Ko00000_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool0
O?ooool007gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Gooooo`03onk^k_l0
003ok^k^00;ooooo00?o0000omgMgOooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000kooooo
00?o0000ooooooooool0O?ooool007[ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01Oooooo00Co410@o`000?l0003ooooo0_l000000ol@413o
ooooooooo`06ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`09ooooo`03
oa0@4?l0003o000000?o00002_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000oooo
ooooool0O?ooool007[ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooo
oooo07cooooo001jooooo`Oo00001Oooool2o`0000Oooooo1?l000000ol@413oooooooooo`0Koooo
o`03o`000?oooooooooo00Gooooo0_l0000=ooooo`03o`000?oooooooooo00_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000007kooooo002Aooooo`03o`000?oooooooooo
0=Cooooo002Aooooo`03o`000?oooooooooo0=Cooooo002Aooooo`03o`000?oooooooooo0=Cooooo
002Aooooo`03o`000?oooooooooo0=Cooooo002Aooooo`03o`000?oooooooooo0=Cooooo002Aoooo
o`03o`000?oooooooooo0=Cooooo002?ooooo`03oeEEEOmVIVKo00000=Kooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.313969, -0.0837537, \
0.00916054, 0.00705812}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0 0.618034 [
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .12361 -18 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -18 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -18 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -18 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -47.0938 0 ]
[.5 .63053 47.0938 20.6875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .12361 m
.03006 .12361 L
s
[(0.2)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(0.4)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(0.6)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(0.8)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0309 m
.02756 .0309 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .58713 m
.02756 .58713 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -108.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 17.438 moveto
(@) show
78.062 11.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
76.750 17.438 moveto
(\\200\\200) show
81.000 17.438 moveto
(\\200) show
83.062 17.438 moveto
(\\200) show
78.062 23.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
87.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
93.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
99.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.188 17.438 moveto
(D) show
117.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
123.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.188 17.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
135.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
153.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .04263 L
.10458 .08822 L
.14415 .12949 L
.18221 .16715 L
.22272 .20435 L
.26171 .23667 L
.30316 .26681 L
.34309 .29105 L
.3815 .30968 L
.40095 .31727 L
.42237 .32403 L
.44268 .32896 L
.45178 .3307 L
.46172 .33226 L
.4671 .33296 L
.4721 .33352 L
.47727 .33401 L
.48196 .33436 L
.48658 .33464 L
.49093 .33483 L
.49332 .3349 L
.49552 .33495 L
.49667 .33497 L
.49794 .33499 L
.49926 .335 L
.50049 .335 L
.50175 .33499 L
.50239 .33498 L
.50309 .33497 L
.50433 .33495 L
.50549 .33493 L
.50811 .33486 L
.51094 .33475 L
.5161 .33449 L
.52084 .33416 L
.52988 .33331 L
.5394 .3321 L
.55914 .32858 L
.57751 .32407 L
.61655 .3105 L
.65805 .29043 L
.69803 .26602 L
.7365 .23807 L
.77742 .20424 L
.81682 .16808 L
.85471 .13066 L
.89505 .08862 L
.93387 .04667 L
.97515 .00116 L
Mistroke
.97619 0 L
Mfstroke
1 0 0 r
[ .05 .05 ] 0 setdash
.02381 0 m
.06244 .04239 L
.10458 .08781 L
.14415 .12895 L
.18221 .16644 L
.22272 .20346 L
.26171 .23568 L
.30316 .26564 L
.34309 .28983 L
.3815 .30836 L
.40095 .31587 L
.42237 .32264 L
.44268 .32757 L
.45178 .32931 L
.46172 .33086 L
.4671 .33155 L
.4721 .3321 L
.47727 .33258 L
.48196 .33293 L
.48658 .33319 L
.4887 .33328 L
.49093 .33337 L
.49332 .33344 L
.49438 .33346 L
.49552 .33348 L
.49675 .3335 L
.49789 .33351 L
.49859 .33351 L
.49925 .33352 L
.50049 .33352 L
.50163 .33351 L
.50286 .3335 L
.50401 .33349 L
.50508 .33347 L
.50754 .33341 L
.51014 .33333 L
.51268 .33323 L
.51504 .33311 L
.5204 .33276 L
.5293 .33196 L
.53882 .33079 L
.54906 .32916 L
.56016 .32697 L
.58032 .32188 L
.62123 .3072 L
.66064 .28778 L
.69852 .26452 L
.73886 .23523 L
.77769 .20311 L
.81897 .16532 L
Mistroke
.85873 .12602 L
.89697 .08617 L
.93767 .04227 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00I?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd0=oooool4o`000003oa0@4?oooooooooo03Gooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03Kooooo1Ol0
000[ooooo`00I?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo03Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0eooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0:oooool006Cooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Gooooo00?oV9RHob4Q8Oo^k^h0
;?ooool006Cooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo03Sooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03Oooooo
00?oV9RHob4Q8Oo^k^h0:oooool006Cooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0>Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`03ogMgMomVIVKooooo02[ooooo001Tooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
02Wooooo001Tooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hoooo
o`05o`000?nj^[[ooooooiRHV?l@4100:oooool006Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co0000>?ooool00omEEEGoIVIVo`00000iooooo`03oeEEEOmVIVKo000000gooooo1?l0000g
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03oooool3o`000003oa0@4?oooooooooo01Kooooo003o
ooooodoooooo00?o410@okZj^_ooool05oooool00?ooooooCoooool00onHV9So<S8booooo`0Goooo
o`00oooooom?ooooo`03omgMgOl0003o^[Zj01Oooooo003oooooodoooooo00?oEEEEogMgMom4A4@0
5oooool00?ooooooC_ooool01OoMgMgo410@oooooolQ8B7ogMgM01Kooooo000Toooooooo00008?l0
000:ooooo`05ofIVI_n7QhOooooooiRHV?mEEED05_ooool002[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?ok^k^o`000?o^k^h00_oo
ool00ol0003ogMgMooooo`0Dooooo`00:_ooool2o`0004?ooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo043ooooo0_l0000@ooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool04oooool002[ooooo00?o0000ooooool00000ooooool=
ooooo`03o`000?oooooooooo02cooooo000Zooooo`04o`000?ooooooooooo`000?oooooo2oooool0
0ol0003oooooooooo`0]ooooo`00:_ooool01Ol0003ooooooooooooooooo00000?oooooo2Oooool0
0ol0003oooooooooo`0^ooooo`00:_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
0?oooooo1Oooool00ol0003oooooooooo`0_ooooo`00:_ooool00ol0003oooooooooo`03ooooo`03
o`000?oo003ooooo0?oooooo0oooool00ol0003oooooooooo`0`ooooo`00:_ooool00ol0003ooooo
ooooo`04ooooo`03ool00?oooooooooo0?oooooo0Oooool00ol0003oooooooooo`0aooooo`00:_oo
ool2o`0000Kooooo00?oo`00ooooooooool0o_ooool00ol0003oooooooooo`0booooo`00:_ooool0
0ol0003oooooooooo`06ooooo`03ool00?oooooooooo0?cooooo00?oo`00ooooooooool0<oooool0
02[ooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`3jooooo`03ool00?oooooooooo
03Cooooo000Zooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool0n?ooool00ooo003o
ooooooooo`0eooooo`00:_ooool00ol0003oooooooooo`08ooooo`03o`000?oo003ooooo0?Oooooo
00?o0000ool00?ooool0=_ooool002[ooooo00?o0000ooooooooool02Oooool00ol0003oo`00oooo
o`3fooooo`03ool00?oooooooooo03Kooooo000Zooooo`03o`000?oooooooooo00[ooooo00?o0000
ool00?ooool0m?ooool00ooo003oooooooooo`0gooooo`00:_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oo003ooooo0?;ooooo00?oo`00ooooooooool0>?ooool002[ooooo00?o0000oooooooo
ool03?ooool00ol0003oo`00ooooo`3`ooooo`03ool00?oooooooooo03Wooooo000Zooooo`;o0000
3_ooool00ol0003oooooooooo`3^ooooo`03ool00?oooooooooo03[ooooo000Zooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0k?ooool00ooo003oooooooooo`0kooooo`00:_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0>[ooooo00?oo`00ooooooooool0??ooool0
02[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`3Xooooo`03o`000?oooooooooo
03gooooo000Zooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0i_ooool00ol0003o
ooooooooo`0nooooo`00:_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0>Cooooo
00?o0000ooooooooool0?oooool002[ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`3Rooooo`03o`000?oooooooooo043ooooo000Zooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0h?ooool00ol0003oooooooooo`11ooooo`00:_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo0=kooooo00?o0000ooooooooool0@_ooool002[ooooo0_l0000Gooooo`03
o`000?oooooooooo0=cooooo00?o0000ooooooooool0@oooool002[ooooo00?o0000ooooooooool0
5oooool00ooo003oooooooooo`3Jooooo`03o`000?oooooooooo04Cooooo000Zooooo`03o`000?oo
oooooooo01Sooooo00?oo`00ooooooooool0f?ooool00ol0003oooooooooo`15ooooo`00:_ooool0
0ol0003oooooooooo`0Iooooo`03ool00?oooooooooo0=Kooooo00?o0000ooooooooool0A_ooool0
02[ooooo00?o0000ooooooooool06_ooool00ooo003oooooooooo`3Dooooo`03o`000?oo003ooooo
04Oooooo000Zooooo`03o`000?oooooooooo01_ooooo00?oo`00ooooooooool0d_ooool00ol0003o
o`00ooooo`18ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go
00001Oooool00ol0003oooooooooo`0Looooo`03ool00?oooooooooo0=3ooooo00?o0000ool00?oo
ool0BOooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Gooooo00?o0000ooooooooool07Oooool00ooo003oooooooooo`3>oooo
o`03o`000?oo003ooooo04[ooooo000@ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onH
V9So8B4Qonk^kP06ooooo`?o00007_ooool00ooo003oooooooooo`3<ooooo`03o`000?oo003ooooo
04_ooooo000@ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05oooo
o`03o`000?oooooooooo01oooooo00?oo`00ooooooooool0b_ooool00ol0003oo`00ooooo`1<oooo
o`004?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01?ooool00ol0
003oooooooooo`0Pooooo`03ool00?oooooooooo0<Sooooo00?o0000ool00?ooool0COooool0013o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool08Oooool00ooo003oooooooooo`37ooooo`03ool00?oooooooooo04gooooo000@ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`35ooooo`03ool00?oooooooooo04kooooo000@oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`33ooooo`03ool00?oooooooooo04oooooo000Z
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0`Oooool00ooo003oooooooooo`1@
ooooo`00:_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo0;oooooo00?o0000oooo
ooooool0DOooool002[ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2mooooo`03
o`000?oooooooooo05;ooooo000Zooooo`;o0000:?ooool00ol0003oooooooooo`2kooooo`03o`00
0?oooooooooo05?ooooo000Zooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0^Ooo
ool00ol0003oooooooooo`1Dooooo`00:_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo0;Oooooo00?o0000ooooooooool0EOooool002[ooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`2dooooo`03ool00?l0003ooooo05Oooooo000Zooooo`03o`000?oooooooooo02_o
oooo0_oo002cooooo`03ool00?l0003ooooo05Sooooo000Zooooo`03o`000?oooooooooo02cooooo
00?o0000ool00?ooool0/?ooool00ooo003oooooooooo`1Iooooo`00:_ooool00ol0003ooooooooo
o`0]ooooo`03o`000?oo003ooooo0:kooooo00?oo`00ooooooooool0F_ooool002[ooooo00?o0000
ooooooooool0;_ooool00ol0003oo`00ooooo`2/ooooo`03ool00?oooooooooo05_ooooo000Zoooo
o`03o`000?oooooooooo02oooooo00?o0000ool00?ooool0Z_ooool00ooo003oooooooooo`1Loooo
o`00:_ooool2o`00037ooooo00?o0000ool00?ooool0Yoooool00ol0003oo`00ooooo`1Nooooo`00
:_ooool00ol0003oooooooooo`0aooooo`03o`000?oo003ooooo0:Gooooo00?o0000ool00?ooool0
Goooool002[ooooo00?o0000ooooooooool0<_ooool00ol0003oo`00ooooo`2Sooooo`03o`000?oo
oooooooo063ooooo000Zooooo`03o`000?oooooooooo03?ooooo00?o0000ool00?ooool0XOooool0
0ol0003oooooooooo`1Qooooo`00:_ooool00ol0003oooooooooo`0dooooo`03o`000?oo003ooooo
09oooooo00?o0000ooooooooool0H_ooool002[ooooo00?o0000ooooooooool0=Oooool00ol0003o
o`00ooooo`2Looooo`;o0000IOooool002[ooooo00?o0000ooooooooool0=_ooool2o`0009_ooooo
00?o0000ooooooooool0IOooool002[ooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`2Gooooo`03o`000?oooooooooo06Kooooo000Zooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool0UOooool00ol0003oooooooooo`1Wooooo`00:_ooool2o`0003_ooooo0_l0002Doooo
o`03o`000?oooooooooo06Sooooo000Zooooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool0Soooool2ool006_ooooo000Zooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
SOooool00ooo003o0000ooooo`1[ooooo`00:_ooool00ol0003oooooooooo`0nooooo`;o0000S?oo
ool00ooo003o0000ooooo`1/ooooo`00:_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo08Sooooo00?oo`00o`000?ooool0KOooool002[ooooo00?o0000ooooooooool0@Oooool3ool0
08Gooooo0_oo00000ol0003oooooooooo`1]ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool00oooool00ol0003oooooooooo`12oooo
o`;o000000?oo`00ooooooooool0POooool00ooo003o0000o`00001`ooooo`004?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0A?ooool00ol0003oo`00ooooo`20ooooo`03ool00?l0003ooooo077ooooo000@ooooo`05
oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o0000ooooooooool0AOooool00ol0
003oo`00ooooo`1nooooo`03ool00?l0003ooooo07;ooooo000@ooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool00006ooooo`?o0000A_ooool00ol0003oo`00ool0001l
ooooo`03ool00?l0003ooooo07?ooooo000@ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool00006ooooo`03o`000?oooooooooo04Sooooo00?o0000ool00?ooool0NOoo
ool00ooo003oooooooooo`1dooooo`004?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l000001_ooool00ol0003oooooooooo`19ooooo`03o`000?oo003ooooo07Kooooo0_l0
001gooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001_oo
ool00ol0003oooooooooo`1;ooooo`03ool00?oooooooooo07?ooooo00?o0000ooooooooool0Mooo
ool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o
0000ooooooooool0C?ooool00ooo003oooooooooo`1aooooo`03o`000?oooooooooo07Sooooo000Z
ooooo`03o`000?oooooooooo04gooooo00?oo`00o`000?ooool0K_ooool2o`0007_ooooo000Zoooo
o`03o`000?oooooooooo04oooooo0_l0001[ooooo`;o0000OOooool002[ooooo00?o0000oooooooo
ool0DOooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo07gooooo000Zooooo`03o`00
0?oooooooooo05;ooooo0_l0001Uooooo`;o0000P?ooool002[ooooo0_l0001Eooooo`;o0000HOoo
ool2ool008;ooooo000Zooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0G?ooool2
ool008Cooooo000Zooooo`03o`000?oooooooooo05Oooooo0_l0001Jooooo`;oo`0000?o0000oooo
ooooool0Poooool002[ooooo00?o0000ooooooooool0FOooool2ool005Kooooo0_oo00000ol0003o
ooooooooo`25ooooo`00:_ooool00ol0003oooooooooo`1Kooooo`;oo`00D_ooool2ool00003o`00
0?oooooooooo08Oooooo000Zooooo`03o`000?oooooooooo05gooooo0ooo001>ooooo`03ool00?l0
003ooooo08[ooooo000Zooooo`03o`000?oooooooooo05oooooo00?o0000ool00?oo0000B_ooool2
ool008gooooo000Zooooo`03o`000?oooooooooo063ooooo0_l00002ool004Kooooo00?o0000ool0
0?ooool0S_ooool002[ooooo00?o0000ooooooooool0H_ooool2o`0000;oo`00@_ooool2o`00097o
oooo000Zooooo`;o0000IOooool2o`000003ool00?oooooooooo03gooooo0_l0002Cooooo`00:_oo
ool00ol0003oooooooooo`1Vooooo`?o0000>_ooool3o`0009Gooooo000Zooooo`03o`000?oooooo
oooo06Wooooo0ol0000dooooo`?o0000V?ooool002[ooooo00?o0000ooooooooool0K?ooool3o`00
02gooooo0ooo00000ol0003oooooooooo`2Iooooo`00:_ooool00ol0003oooooooooo`1_ooooo`Co
00000_oo000Tooooo`?oo`0000?o0000ooooooooool0W?ooool002[ooooo00?o0000ooooooooool0
M?ooool00ol0003oo`00ool00004ool001Sooooo1_oo00000ol0003oooooooooo`2Oooooo`00:_oo
ool00ol0003oooooooooo`1hooooo`?o00002?oo000:ooooo`?o00000ooo00000ol0003ooooooooo
o`2Uooooo`00:_ooool00ol0003oooooooooo`1nooooo`oo0000[_ooool002[ooooo0_l0003ooooo
ocgooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0
oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooo
oooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003o
ooooooooo`3ooooooccooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00Gok^k^oc8b<_l0003o410@olc<c005ooooo`03o`000?oooooooooo0?oooooo??ooool0013o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So
8B4Q00Gooooo00?o0000ooooooooool0oooooollooooo`004?ooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go0000ooooooooooooooooo`000005ooooo`?o0000oooooollooooo`004?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@05ooooo`03o`00
0?oooooooooo0?oooooo??ooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`01Oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05oa0@
4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`07ooooo`03o`000?oooooooooo0?oo
oooo??ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Oo
oooo00?o0000ooooooooool0oooooollooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo00Coc<c<odA4A?l0003o410@1Oooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03
o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_oo
ool00ol0003oooooooooo`3ooooooccooooo000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0
003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo
00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Z
ooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooolloooo
o`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo
??ooool002[ooooo0_l0003oooooocgooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool0
02[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3oooooocco
oooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooo
oollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo
0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool2o`000?oooooo
?Oooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3o
oooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooooooo
ool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c005ooooo`03
o`000?oooooooooo0?oooooo??ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0oooooolloooo
o`004?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000005
ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801Oooool3o`000?oooooo??ooool0013ooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01Oooool00ol0003ooooo
ooooo`3ooooooccooooo000@ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zj
oooooonj^[[o410@00Gooooo00?o0000ooooooooool0oooooollooooo`004?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000005ooooo`03o`000?oooooooooo
0?oooooo??ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000
oa0@4?nYZJT01Oooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo
0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooo
ooooo`3ooooooccooooo000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0003oooooooooo`3o
oooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooooooo
ool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oo
oooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0
003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo
0_l0003oooooocgooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000
ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03
o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_oo
ool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool0
02[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool2o`000?oooooo?Oooool002[ooooo
00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Z
ooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooolloooo
o`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo
??ooool0027ooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo??oo
ool002?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooooccooooo000Soooo
o`03o`000?oooooooooo00Cooooo0ol0003ooooooccooooo000Sooooo`03o`000?oooooooooo0?oo
oooo@oooool002?ooooo00?o0000ooooooooool0oooooom3ooooo`008oooool00ol0003ooooooooo
o`3ooooood?ooooo000Sooooo`03o`000?oooooooooo0?oooooo@oooool0027ooooo00?oEEEEofIV
I_l00000oooooom5ooooo`00S_ooool5o`000=Gooooo002>ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@0eOooool008oooooo00?oV9RHob4Q8Oo^k^h0e_ooool0093ooooo00?oV9RHob4Q8Oo^k^h0eOoo
ool0097ooooo00?oMgMgofIVI_ooool0e?ooool009;ooooo00?o0000ooooooooool02oooool3o`00
0003oa0@4?oooooooooo0<;ooooo0026ooooo`;o00001_ooool01Ol0003o^[ZjoooooonHV9So410@
00Sooooo00?o0000okZj^_ooool01?ooool00ol@413o^[Zjooooo`05ooooo`03o`000?nj^[[ooooo
00cooooo0_l00005ooooo`03o`000?nj^[[ooooo0:Gooooo0026ooooo`03o`000?oooooooooo00Go
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c008ooooo`;o<S8b1Oooool00onHV9So<S8booooo`05oooo
o`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8bY_ooool007_ooooo00Go410@o`000?l0
003o0000oa0@4006ooooo`03o`000?oooooooooo01;ooooo00?oQhN7o`000?nj^[X01?ooool00ooM
gMgo0000okZj^P05ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04
ooooo`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4
A4Co^[Zj00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0007gooooo
001mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00oo<c<co0000oa0@
4004ooooo`03oeEEEOmgMgOoA4A400Gooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^
k_mgMgOo410@00Cooooo00?o0000ooooooooool00oooool00oo<c<co0000oa0@4005ooooo`06oa0@
4?nj^[[ok^k^ogMgMol@413ooooo1_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A01mooooo`00OOooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00?ooooo2_l0000;ooooo`05omgMgOl@413oooooob4Q8OoMgMd02ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0O_ooool007gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Hooooo`05ofIVI_n7QhOooooooiRHV?mEEED0
2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
0oooool6o`0000;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^07go
oooo001mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05oooool00oo^k^ko0000
onk^kP02ooooo`03o`000?oMgMgooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo07cooooo001jooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Gooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooo
ooooool01_ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool02Oooool00ol@
413o0000o`000003o`0000[ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooo
oooo07_ooooo001jooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@07gooooo001jooooo`Oo00001Oooool2o`0000Oooooo1?l000000ol@413ooooooooo
o`0Kooooo`03o`000?oooooooooo00Gooooo0_l0000=ooooo`03o`000?oooooooooo00_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0OOooool0097ooooo
00?o0000ooooooooool0e?ooool0097ooooo00?o0000ooooooooool0e?ooool0097ooooo00?o0000
ooooooooool0e?ooool0097ooooo00?o0000ooooooooool0e?ooool0097ooooo00?o0000oooooooo
ool0e?ooool0097ooooo00?o0000ooooooooool0e?ooool008oooooo00?oEEEEofIVI_l00000e_oo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.313969, -0.0837537, \
0.00916054, 0.00705812}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0 0.618034 [
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .12361 -18 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -18 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -18 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -18 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -47.0938 0 ]
[.5 .63053 47.0938 20.6875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .12361 m
.03006 .12361 L
s
[(0.2)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(0.4)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(0.6)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(0.8)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0309 m
.02756 .0309 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .58713 m
.02756 .58713 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -108.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 17.438 moveto
(@) show
78.062 11.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
76.750 17.438 moveto
(\\200\\200) show
81.000 17.438 moveto
(\\200) show
83.062 17.438 moveto
(\\200) show
78.062 23.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
87.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
93.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
99.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.188 17.438 moveto
(D) show
117.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
123.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.188 17.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
135.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
153.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .03139 L
.10458 .06495 L
.14415 .09534 L
.18221 .12306 L
.22272 .15045 L
.26171 .17425 L
.30316 .19644 L
.34309 .21428 L
.3815 .228 L
.40095 .23358 L
.42237 .23856 L
.44268 .24219 L
.45178 .24347 L
.46172 .24462 L
.4671 .24514 L
.4721 .24555 L
.47727 .24591 L
.48196 .24617 L
.48658 .24637 L
.49093 .24651 L
.49332 .24656 L
.49552 .2466 L
.49667 .24662 L
.49794 .24663 L
.49926 .24664 L
.50049 .24664 L
.50175 .24663 L
.50239 .24663 L
.50309 .24662 L
.50433 .2466 L
.50549 .24659 L
.50811 .24653 L
.51094 .24646 L
.5161 .24626 L
.52084 .24602 L
.52988 .24539 L
.5394 .2445 L
.55914 .24191 L
.57751 .23859 L
.61655 .2286 L
.65805 .21383 L
.69803 .19585 L
.7365 .17528 L
.77742 .15037 L
.81682 .12375 L
.85471 .09619 L
.89505 .06525 L
.93387 .03436 L
.97515 .00085 L
Mistroke
.97619 0 L
Mfstroke
1 0 0 r
[ .05 .05 ] 0 setdash
.02381 0 m
.06244 .03114 L
.10458 .06451 L
.14415 .09472 L
.18221 .12227 L
.22272 .14946 L
.26171 .17313 L
.30316 .19514 L
.34309 .21291 L
.3815 .22652 L
.40095 .23204 L
.42237 .23701 L
.44268 .24064 L
.45178 .24191 L
.46172 .24305 L
.4671 .24356 L
.4721 .24397 L
.47727 .24431 L
.48196 .24457 L
.48658 .24476 L
.4887 .24483 L
.49093 .24489 L
.49332 .24494 L
.49438 .24496 L
.49552 .24498 L
.49675 .24499 L
.49789 .245 L
.49859 .245 L
.49925 .245 L
.50049 .245 L
.50163 .245 L
.50286 .24499 L
.50401 .24498 L
.50508 .24497 L
.50754 .24493 L
.51014 .24487 L
.51268 .24479 L
.51504 .2447 L
.5204 .24445 L
.5293 .24386 L
.53882 .243 L
.54906 .2418 L
.56016 .24019 L
.58032 .23645 L
.62123 .22567 L
.66064 .2114 L
.69852 .19432 L
.73886 .1728 L
.77769 .14921 L
.81897 .12145 L
Mistroke
.85873 .09257 L
.89697 .0633 L
.93767 .03105 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00I?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd0=oooool4o`000003oa0@4?oooooooooo03Gooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03Kooooo1Ol0
000[ooooo`00I?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo03Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0eooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0:oooool006Cooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Gooooo00?oV9RHob4Q8Oo^k^h0
;?ooool006Cooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo03Sooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03Oooooo
00?oV9RHob4Q8Oo^k^h0:oooool006Cooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0>Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`03ogMgMomVIVKooooo02[ooooo001Tooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
02Wooooo001Tooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hoooo
o`05o`000?nj^[[ooooooiRHV?l@4100:oooool006Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co0000>?ooool00omEEEGoIVIVo`00000iooooo`03oeEEEOmVIVKo000000gooooo1?l0000g
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03oooool3o`000003oa0@4?oooooooooo01Kooooo003o
ooooodoooooo00?o410@okZj^_ooool05oooool00?ooooooCoooool00onHV9So<S8booooo`0Goooo
o`00oooooom?ooooo`03omgMgOl0003o^[Zj01Oooooo003oooooodoooooo00?oEEEEogMgMom4A4@0
5oooool00?ooooooC_ooool01OoMgMgo410@oooooolQ8B7ogMgM01Kooooo000Toooooooo00008?l0
000:ooooo`05ofIVI_n7QhOooooooiRHV?mEEED05_ooool002[ooooo00Co0000oooooooo003oo`00
2_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo0000013ooooo00?ok^k^o`000?o^k^h0
0_ooool00ol0003ogMgMooooo`0Dooooo`00:_ooool01Ol0003oooooooooool0003oo`00043ooooo
00?o0000ooooooooool0@Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo03kooooo
00Co0000oooooooooooo00004?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo
01?ooooo000Zooooo`06o`000?ooooooooooooooool0003oo`00ooooool8ooooo`03o`000?oooooo
oooo02kooooo000Zooooo`03o`000?oooooooooo00;ooooo00?o0000ool00?ooool0ooooool5oooo
o`03o`000?oooooooooo02oooooo000Zooooo`03o`000?oooooooooo00Cooooo00?oo`00oooooooo
ool0ooooool1ooooo`;o0000<_ooool002[ooooo00?o0000ooooooooool01Oooool00ooo003ooooo
ooooo`3nooooo`03o`000?oooooooooo03;ooooo000Zooooo`03o`000?oooooooooo00Kooooo00?o
o`00ooooooooool0o?ooool00ol0003oooooooooo`0cooooo`00:_ooool00ol0003oooooooooo`07
ooooo`03ool00?oooooooooo0?[ooooo0_oo000eooooo`00:_ooool2o`0000Wooooo0_oo003hoooo
o`;oo`00=oooool002[ooooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`3dooooo`03
ool00?l0003ooooo03Oooooo000Zooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
l_ooool00ooo003oooooooooo`0hooooo`00:_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo0?3ooooo00?oo`00ooooooooool0>Oooool002[ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`3]ooooo`;oo`00??ooool002[ooooo00?o0000ooooooooool03_ooool2o`00
0>cooooo00?oo`00o`000?ooool0??ooool002[ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`3Xooooo`03ool00?oooooooooo03gooooo000Zooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0i_ooool00ooo003oooooooooo`0nooooo`00:_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo0>Cooooo00?oo`00ooooooooool0?oooool002[ooooo0_l0000D
ooooo`03o`000?oooooooooo0>;ooooo00?o0000ooooooooool0@?ooool002[ooooo00?o0000oooo
ooooool05?ooool00ol0003oo`00ool0003Oooooo`;o0000@oooool002[ooooo00?o0000oooooooo
ool05_ooool00ol0003oo`00ooooo`3Looooo`03o`000?oooooooooo04?ooooo000Zooooo`03o`00
0?oooooooooo01Oooooo00?o0000ool00?ooool0f_ooool00ol0003oooooooooo`14ooooo`00:_oo
ool00ol0003oooooooooo`0Iooooo`;oo`00eoooool2o`0004Oooooo000Zooooo`03o`000?oooooo
oooo01[ooooo00?o0000ool00?ooool0e?ooool00ol0003oooooooooo`17ooooo`00:_ooool00ol0
003oooooooooo`0Looooo`;oo`00d_ooool00ol0003oooooooooo`18ooooo`00:_ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oo003ooooo0<kooooo00?oo`00o`000?ooool0B_ooool002[ooooo
00?o0000ooooooooool07oooool00ooo003oooooooooo`3:ooooo`;oo`00COooool002[ooooo0_l0
000Qooooo`03ool00?l0003ooooo0<Sooooo00?oo`00o`000?ooool0COooool002[ooooo00?o0000
ooooooooool08Oooool00ooo003o0000ooooo`36ooooo`03ool00?l0003ooooo04kooooo000Zoooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0`oooool00ooo003oooooooooo`1?oooo
o`00:_ooool00ol0003oooooooooo`0Tooooo`;o0000`Oooool2ool005;ooooo000Zooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0_Oooool00ooo003oooooooooo`1Booooo`00:_oo
ool00ol0003oooooooooo`0Wooooo`;o0000_?ooool00ooo003oooooooooo`1Cooooo`004?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo0;Oooooo00?o0000ool00?ooool0EOooool0013ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2eooooo`03o`000?oo003ooooo05Kooooo
000@ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP06ooooo`?o0000
:oooool2o`000;?ooooo0_l0001Iooooo`004?ooool01Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`0/ooooo`;oo`00/Oooool00ol0003ooooo
ooooo`1Iooooo`004?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0
1?ooool00ol0003oooooooooo`0^ooooo`03ool00?oooooooooo0:cooooo0_l0001Looooo`004?oo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0_ooooo`;oo`00Zoooool00ol0003oooooooooo`1Looooo`004?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo037o
oooo00?oo`00ooooooooool0Y_ooool2o`0005oooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0<_ooool00ooo
003o0000ooooo`2Tooooo`03o`000?oooooooooo05oooooo000Zooooo`03o`000?oooooooooo03?o
oooo0_oo002Rooooo`;oo`00H_ooool002[ooooo00?o0000ooooooooool0=Oooool00ooo003ooooo
ooooo`2Nooooo`03ool00?oooooooooo06;ooooo000Zooooo`03o`000?oooooooooo03Kooooo0_oo
002Looooo`;oo`00IOooool002[ooooo0_l0000iooooo`03ool00?l0003ooooo09Oooooo0_oo001W
ooooo`00:_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo09?ooooo0_oo00000ol0
003oooooooooo`1Vooooo`00:_ooool00ol0003oooooooooo`0kooooo`;o0000T_ooool00ooo003o
0000ooooo`1Yooooo`00:_ooool00ol0003oooooooooo`0mooooo`;o0000S_ooool2ool006cooooo
000Zooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0R_ooool00ooo003o0000oooo
o`1/ooooo`00:_ooool00ol0003oooooooooo`10ooooo`;o0000ROooool00ol0003oooooooooo`1]
ooooo`00:_ooool00ol0003oooooooooo`12ooooo`;o0000QOooool2o`00073ooooo000Zooooo`03
o`000?oooooooooo04Cooooo0_oo0021ooooo`;o0000L_ooool002[ooooo00?o0000ooooooooool0
A_ooool2ool007gooooo0_l0001dooooo`00:_ooool2o`0004Wooooo0_oo001jooooo`03o`000?oo
oooooooo07Cooooo000Zooooo`03o`000?oooooooooo04Wooooo00?o0000ool00?ooool0M_ooool2
o`0007Oooooo000Zooooo`03o`000?oooooooooo04_ooooo0_oo001booooo`03ool00?l0003o0000
07Wooooo000Zooooo`03o`000?oooooooooo04gooooo0_oo001_ooooo`;oo`00Noooool002[ooooo
00?o0000ooooooooool0Coooool2ool00003o`000?oooooooooo06Oooooo00?o0000ool00?oo0000
OOooool002[ooooo00?o0000ooooooooool0DOooool00ooo003o0000o`00001Uooooo`?oo`00Oooo
ool002[ooooo00?o0000ooooooooool0E?ooool2o`00067ooooo0_oo0022ooooo`00:_ooool00ol0
003oooooooooo`1Fooooo`?o0000Foooool00ol0003oo`00ool00024ooooo`00:_ooool00ol0003o
ooooooooo`1Iooooo`;o0000Eoooool3ool008Kooooo000Zooooo`;o0000G?ooool3o`00057ooooo
0ol00029ooooo`00:_ooool00ol0003oooooooooo`1Nooooo`?oo`00Boooool3o`0008cooooo000Z
ooooo`03o`000?oooooooooo067ooooo0ooo0015ooooo`?o0000Soooool002[ooooo00?o0000oooo
ooooool0I?ooool4ool003gooooo1?l0002Booooo`00:_ooool00ol0003oooooooooo`1Vooooo`;o
00001?oo000eooooo`;o00000ooo002Eooooo`00:_ooool00ol0003oooooooooo`1Yooooo`?o0000
00?oo`00o`000?ooool0;oooool00ol0003oo`00ool00002ool009Sooooo000@ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03ooooo`03o`00
0?oooooooooo06kooooo1_l0000Vooooo`Goo`00W?ooool0013ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Cooooo
1?l0000Looooo`?o00000ooo002Qooooo`004?ooool01Ol@413ooooooooooooooooo410@00_ooooo
1Ol00005ooooo`03o`000?oooooooooo07Sooooo0_l0000@ool00003ooooool0003o000000Oo0000
Yoooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Ko
oooo0ol00022ooooo`Wo0000/?ooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooollooooo`004?ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003oooooooooo`3ooooo
occooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000006oooo
o`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=oooo
o`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003o
ooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o
0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zoooo
o`;o0000oooooolmooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`00
0?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool0
0ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[o
oooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo
000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo0_l0003oooooocgooooo000Zoooo
o`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00
:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??oo
ool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooo
occooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo0_l0003oooooocgooooo
000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0ooooooll
ooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oo
oooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooooooo
o`3ooooooccooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Go
k^k^oc8b<_l0003o410@olc<c005ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Go
oooo00?o0000ooooooooool0oooooollooooo`004?ooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go0000ooooooooooooooooo`000005ooooo`?o0000oooooollooooo`004?ooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooo
oooo0?oooooo??ooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo
0000oa0@4?o<c<`01Oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05oa0@4?oooooo
ooooooooool@41002oooool00omEEEGoQhN7ooooo`07ooooo`03o`000?oooooooooo0?oooooo??oo
ool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Oooooo00?o
0000ooooooooool0oooooollooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Co
c<c<odA4A?l0003o410@1Oooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oo
oooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0
003oooooooooo`3ooooooccooooo000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0003ooooo
ooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000
ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03
o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_oo
ool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool0
02[ooooo0_l0003oooooocgooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo
00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Z
ooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooolloooo
o`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo
??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool2o`000?oooooo?Oooool0
02[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3oooooocco
oooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooo
oollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c005ooooo`03o`000?oo
oooooooo0?oooooo??ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OlQ8B7oV9RHoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0oooooollooooo`004?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo0?oooooo??ooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
oc8b<_nHV9SooooooiRHV?lb<S801Oooool3o`000?oooooo??ooool0013ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01Oooool00ol0003oooooooooo`3o
oooooccooooo000@ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj
^[[o410@00Gooooo00?o0000ooooooooool0oooooollooooo`004?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000005ooooo`03o`000?oooooooooo0?oooooo
??ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT01Oooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo
??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3o
oooooccooooo000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0003oooooooooo`3oooooocco
oooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooo
oollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo
0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooo
ooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo0_l0003o
ooooocgooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooooooo
ool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oo
oooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0
003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo
00?o0000ooooooooool0oooooollooooo`00:_ooool2o`000?oooooo?Oooool002[ooooo00?o0000
ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03
o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_oo
ool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool0
027ooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo??ooool002?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooooccooooo000Sooooo`03o`00
0?oooooooooo00Cooooo0ol0003ooooooccooooo000Sooooo`03o`000?oooooooooo0?oooooo@ooo
ool002?ooooo00?o0000ooooooooool0oooooom3ooooo`008oooool00ol0003oooooooooo`3ooooo
od?ooooo000Sooooo`03o`000?oooooooooo0?oooooo@oooool0027ooooo00?oEEEEofIVI_l00000
oooooom5ooooo`00S_ooool5o`000=Gooooo002>ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0eOoo
ool008oooooo00?oV9RHob4Q8Oo^k^h0e_ooool0093ooooo00?oV9RHob4Q8Oo^k^h0eOooool0097o
oooo00?oMgMgofIVI_ooool0e?ooool009;ooooo00?o0000ooooooooool02oooool3o`000003oa0@
4?oooooooooo0<;ooooo0026ooooo`;o00001_ooool01Ol0003o^[ZjoooooonHV9So410@00Sooooo
00?o0000okZj^_ooool01?ooool00ol@413o^[Zjooooo`05ooooo`03o`000?nj^[[ooooo00cooooo
0_l00005ooooo`03o`000?nj^[[ooooo0:Gooooo0026ooooo`03o`000?oooooooooo00Gooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c008ooooo`;o<S8b1Oooool00onHV9So<S8booooo`05ooooo`;o<S8b
3_ooool00ol0003oooooooooo`03ooooo`;o<S8bY_ooool007_ooooo00Go410@o`000?l0003o0000
oa0@4006ooooo`03o`000?oooooooooo01;ooooo00?oQhN7o`000?nj^[X01?ooool00ooMgMgo0000
okZj^P05ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03
o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj
00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb
<S;oc<c<07gooooo001mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool0
0oo<c<co0000oa0@4004ooooo`03oeEEEOmgMgOoA4A400Gooooo00?oc<c<o`000?l@41001?ooool0
1Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool00oooool00oo<c<co0000oa0@
4005ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l00002ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P1mooooo`00OOooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo2_l0000;ooooo`05omgMgOl@413ooooo
ob4Q8OoMgMd02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0Nooo
ool007gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Hooooo`05ofIVI_n7QhOo
oooooiRHV?mEEED02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool00oooool6o`0000;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVY
ZOl@413ooooo07cooooo001mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05ooo
ool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo00Wooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooooooooooo
o`00000=ooooo`03oa0@4?l0003o^[Zj07gooooo001jooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Gooooo`04oa0@4?l0003o0000ooooo`;o
000000?o410@ooooooooool01_ooool00ol@413o0000o`000003o`0000Gooooo00?o0000oooooooo
ool02Oooool00ol@413o0000o`000003o`0000[ooooo00Go410@oooooooooooooooooa0@400>oooo
o`03okZj^_lQ8B7ooooo07cooooo001jooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol@413oV9RHoooooonj^[[o000007gooooo001jooooo`Oo00001Oooool2o`0000Oooooo1?l00000
0ol@413oooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo0_l0000=ooooo`03o`000?oooooo
oooo00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
OOooool0097ooooo00?o0000ooooooooool0e?ooool0097ooooo00?o0000ooooooooool0e?ooool0
097ooooo00?o0000ooooooooool0e?ooool0097ooooo00?o0000ooooooooool0e?ooool0097ooooo
00?o0000ooooooooool0e?ooool0097ooooo00?o0000ooooooooool0e?ooool008oooooo00?oEEEE
ofIVI_l00000e_ooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.313969, -0.0837537, \
0.00916054, 0.00705812}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0 0.618034 [
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .12361 -18 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -18 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -18 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -18 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -47.0938 0 ]
[.5 .63053 47.0938 20.6875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .12361 m
.03006 .12361 L
s
[(0.2)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(0.4)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(0.6)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(0.8)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0309 m
.02756 .0309 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .58713 m
.02756 .58713 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -108.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 17.438 moveto
(@) show
78.062 11.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
76.750 17.438 moveto
(\\200\\200) show
81.000 17.438 moveto
(\\200) show
83.062 17.438 moveto
(\\200) show
78.062 23.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
87.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
93.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
99.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.188 17.438 moveto
(D) show
117.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
123.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.188 17.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
135.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
153.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .02311 L
.10458 .04782 L
.14415 .07019 L
.18221 .0906 L
.22272 .11077 L
.26171 .12829 L
.30316 .14462 L
.34309 .15776 L
.3815 .16786 L
.40095 .17197 L
.42237 .17564 L
.44268 .17831 L
.45178 .17925 L
.46172 .1801 L
.4671 .18048 L
.4721 .18078 L
.47727 .18104 L
.48196 .18124 L
.48658 .18139 L
.49093 .18149 L
.49332 .18153 L
.49552 .18156 L
.49667 .18157 L
.49794 .18158 L
.49926 .18158 L
.50049 .18158 L
.50175 .18158 L
.50239 .18157 L
.50309 .18157 L
.50433 .18156 L
.50549 .18155 L
.50811 .18151 L
.51094 .18145 L
.5161 .18131 L
.52084 .18113 L
.52988 .18067 L
.5394 .18001 L
.55914 .1781 L
.57751 .17566 L
.61655 .1683 L
.65805 .15743 L
.69803 .14419 L
.7365 .12904 L
.77742 .1107 L
.81682 .09111 L
.85471 .07082 L
.89505 .04804 L
.93387 .0253 L
.97515 .00063 L
Mistroke
.97619 0 L
Mfstroke
1 0 0 r
[ .05 .05 ] 0 setdash
.02381 0 m
.06244 .02288 L
.10458 .04739 L
.14415 .06958 L
.18221 .08982 L
.22272 .1098 L
.26171 .12718 L
.30316 .14335 L
.34309 .1564 L
.3815 .1664 L
.40095 .17046 L
.42237 .17411 L
.44268 .17677 L
.45178 .17771 L
.46172 .17855 L
.4671 .17892 L
.4721 .17922 L
.47727 .17947 L
.48196 .17966 L
.48658 .1798 L
.4887 .17985 L
.49093 .1799 L
.49332 .17994 L
.49438 .17995 L
.49552 .17996 L
.49675 .17997 L
.49789 .17998 L
.49859 .17998 L
.49925 .17998 L
.50049 .17998 L
.50163 .17998 L
.50286 .17997 L
.50401 .17996 L
.50508 .17995 L
.50754 .17992 L
.51014 .17988 L
.51268 .17982 L
.51504 .17976 L
.5204 .17957 L
.5293 .17914 L
.53882 .17851 L
.54906 .17763 L
.56016 .17645 L
.58032 .1737 L
.62123 .16578 L
.66064 .1553 L
.69852 .14275 L
.73886 .12694 L
.77769 .10961 L
.81897 .08921 L
Mistroke
.85873 .06801 L
.89697 .0465 L
.93767 .02281 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00I?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd0=oooool4o`000003oa0@4?oooooooooo03Gooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03Kooooo1Ol0
000[ooooo`00I?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo03Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0eooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0:oooool006Cooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Gooooo00?oV9RHob4Q8Oo^k^h0
;?ooool006Cooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo03Sooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03Oooooo
00?oV9RHob4Q8Oo^k^h0:oooool006Cooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0>Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`03ogMgMomVIVKooooo02[ooooo001Tooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
02Wooooo001Tooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hoooo
o`05o`000?nj^[[ooooooiRHV?l@4100:oooool006Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co0000>?ooool00omEEEGoIVIVo`00000iooooo`03oeEEEOmVIVKo000000gooooo1?l0000g
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03oooool3o`000003oa0@4?oooooooooo01Kooooo003o
ooooodoooooo00?o410@okZj^_ooool05oooool00?ooooooCoooool00onHV9So<S8booooo`0Goooo
o`00oooooom?ooooo`03omgMgOl0003o^[Zj01Oooooo003oooooodoooooo00?oEEEEogMgMom4A4@0
5oooool00?ooooooC_ooool01OoMgMgo410@oooooolQ8B7ogMgM01Kooooo000Toooooooo00005ol0
0002ool000Oo00002_ooool01OmVIVKoQhN7oooooonHV9SoEEEE01Kooooo000Zooooo`03o`000?oo
oooo000000_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01oooool01?l0003oo`00ooooool0000@ooooo`03onk^
k_l0003ok^k^00;ooooo00?o0000omgMgOooool05?ooool002[ooooo00?o0000ooooooooool00_l0
0010ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0@Oooool00ol0003ooooooooo
o`0mooooo`;oo`000_ooool00ol0003oooooooooo`0>ooooo`04oa0@4?l0003o0000ooooo`;o0000
00?o410@ooooooooool04oooool002[ooooo00?o0000ooooooooool00_ooool2o`000?oooooo1Ooo
ool2ool0037ooooo000Zooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool0
0ol0003oo`00ooooo`0booooo`00:_ooool00ol0003oooooooooo`05ooooo`;o0000o_ooool00ol0
003oo`00ooooo`0cooooo`00:_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?Wo
oooo0_l0000fooooo`00:_ooool00ol0003oooooooooo`08ooooo`03o`000?oo003oo`000?Kooooo
0_l0000hooooo`00:_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo003ooooo0??ooooo00?o
0000ooooooooool0>?ooool002[ooooo0_l0000=ooooo`;oo`00l?ooool2o`0003_ooooo000Zoooo
o`03o`000?oooooooooo00gooooo00?o0000ool00?oo0000k?ooool2o`0003gooooo000Zooooo`03
o`000?oooooooooo00oooooo00?o0000ool00?ooool0jOooool00ol0003oooooooooo`0mooooo`00
:_ooool00ol0003oooooooooo`0Aooooo`;oo`00i_ooool2ool0043ooooo000Zooooo`03o`000?oo
oooooooo01;ooooo00?o0000ool00?ooool0h_ooool2ool004;ooooo000Zooooo`03o`000?oooooo
oooo01Cooooo0ooo003Nooooo`;oo`0000?o0000ooooooooool0@Oooool002[ooooo00?o0000oooo
ooooool05_ooool2o`000=cooooo00?oo`00o`000?ooool0A?ooool002[ooooo00?o0000oooooooo
ool06?ooool2o`000=Sooooo0_oo0017ooooo`00:_ooool00ol0003oooooooooo`0Jooooo`;o0000
e?ooool2ool004Wooooo000Zooooo`;o00007Oooool2o`000=3ooooo00?o0000ool00?ooool0B_oo
ool002[ooooo00?o0000ooooooooool07_ooool2o`000<cooooo0_l000000ooo003oooooooooo`1:
ooooo`00:_ooool00ol0003oooooooooo`0Pooooo`;o0000b?ooool2o`0004oooooo000Zooooo`03
o`000?oooooooooo02;ooooo0_oo0034ooooo`;o0000DOooool002[ooooo00?o0000ooooooooool0
9?ooool2ool00<7ooooo00?o0000ooooooooool0DOooool002[ooooo00?o0000ooooooooool09_oo
ool2ool00;gooooo0_l0001Dooooo`00:_ooool00ol0003oooooooooo`0Wooooo`03o`000?oo003o
oooo0;Wooooo0_l0001Fooooo`00:_ooool00ol0003oooooooooo`0Yooooo`;oo`00]oooool00ol0
003oooooooooo`1Fooooo`00:_ooool00ol0003oooooooooo`0[ooooo`;oo`00/oooool00ol0003o
o`00ooooo`1Hooooo`00:_ooool2o`0002kooooo0_oo002_ooooo`;o0000Foooool002[ooooo00?o
0000ooooooooool0;oooool00ooo003o0000ooooo`2Zooooo`;o0000GOooool002[ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`2Vooooo`;o0000Goooool002[ooooo00?o0000oooo
ooooool0<_ooool2o`000:Cooooo0_l0001Qooooo`00:_ooool00ol0003oooooooooo`0dooooo`;o
0000X?ooool2o`0006?ooooo000Zooooo`03o`000?oooooooooo03Kooooo0_l0002Kooooo`;oo`00
00?o0000ooooooooool0Hoooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Gooooo00?o0000ooooooooool0>?ooool3o`0009Gooooo0ooo00000ol0003ooooo
ooooo`1Uooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003oooooooooo`0kooooo`04o`000?oo003oo`00ool0
08oooooo0_oo0002o`0006Wooooo000@ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onH
V9So8B4Qonk^kP06ooooo`?o0000?Oooool2o`0000?oo`00ROooool3ool00003o`000?oooooooooo
06[ooooo000@ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05oooo
o`03o`000?oooooooooo03oooooo0ol00002ool008Gooooo0_oo0002o`0006kooooo000@ooooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo
04;ooooo0_l00003ool0087ooooo00?oo`00o`000?l00000L?ooool0013ooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0A?ooool3o`00
00;oo`00OOooool00ol0003oo`00o`00001booooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo04Oooooo0_l00000
0ooo003oooooooooo`1gooooo`?o0000MOooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`1:ooooo`?o0000Looo
ool3o`0007Sooooo000Zooooo`03o`000?oooooooooo04gooooo0ol0001^ooooo`;o0000Noooool0
02[ooooo00?o0000ooooooooool0D?ooool3o`0006Sooooo0ol0001mooooo`00:_ooool00ol0003o
ooooooooo`1Cooooo`?o0000HOooool3ool00003o`000?oooooooooo07kooooo000Zooooo`;o0000
Eoooool00ol0003oo`00ool0001Jooooo`Coo`0000?o0000ooooooooool0POooool002[ooooo00?o
0000ooooooooool0FOooool3ool005Cooooo0ooo0002o`0008Kooooo000Zooooo`03o`000?oooooo
oooo05cooooo1?oo001=ooooo`?oo`0000?o0000ooooooooool0R?ooool002[ooooo00?o0000oooo
ooooool0H?ooool3ool004Kooooo0ol000000ooo003oooooooooo`2<ooooo`00:_ooool00ol0003o
ooooooooo`1Sooooo`?oo`000_l0000looooo`Go0000T_ooool002[ooooo00?o0000ooooooooool0
J?ooool6o`00037ooooo1Ol0002Gooooo`00:_ooool00ol0003oooooooooo`1^ooooo`Go00000_oo
000Uooooo`Goo`00W?ooool002[ooooo00?o0000ooooooooool0M?ooool00ol0003oo`00ool0000;
ool000gooooo2ooo002Qooooo`00:_ooool00ol0003oooooooooo`1koooooaWo0000Yoooool002[o
oooo0_l0003oooooocgooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o
0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zoooo
o`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00
:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??oo
ool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool2o`000?oooooo?Oooool002[o
oooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo
000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0ooooooll
ooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?oooooo??ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go00001Oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05
o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00006ooooo`?o0000ooooooll
ooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001_oo
ool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00omgMgOoc<c<o`000006ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo00?o0000ooooooooool0oooo
oollooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01Ooo
ool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool0
02[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3oooooocco
oooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo0_l0003oooooocgooooo000Z
ooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooolloooo
o`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo
??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3o
oooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooooooo
ool0oooooollooooo`00:_ooool2o`000?oooooo?Oooool002[ooooo00?o0000ooooooooool0oooo
oollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo
0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooo
ooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000
ooooooooool0oooooollooooo`00:_ooool2o`000?oooooo?Oooool002[ooooo00?o0000oooooooo
ool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oo
oooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0
003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
00Gooooo00?o0000ooooooooool0oooooollooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401Oooool00ol0003oooooooooo`3o
oooooccooooo000@ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000000Gooooo0ol0003ooooooccooooo000@ooooo`05o`000?ooooooooooooooool000002ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0oooooollooooo`004?oo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c005ooooo`03
o`000?oooooooooo0?oooooo??ooool0013ooooo00Go410@oooooooooooooooooa0@400;ooooo`03
oeEEEOn7QhOooooo00Oooooo00?o0000ooooooooool0oooooollooooo`004?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P01oooool00ol0003oooooooooo`3oooooocco
oooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4105oooo
o`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00
:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??oo
ool002[ooooo0_l0003oooooocgooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[o
oooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo
000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0ooooooll
ooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oo
oooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool2o`000?oooooo?Ooo
ool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooo
occooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0
oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooo
oooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003o
ooooooooo`3ooooooccooooo000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0003ooooooooo
o`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooo
ooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`00
0?oooooooooo0?oooooo??ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0oooooollooooo`00
4?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B401Oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0ooooooll
ooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P05ooooo`?o0000oooooollooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go
c<c<o`000?l0003o0000olc<c005ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Go
410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001Oooool00ol0003o
ooooooooo`3ooooooccooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[Zjoooooonj^[[o000000Gooooo00?o0000ooooooooool0oooooollooooo`004?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@05ooooo`03o`000?oooooo
oooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003o
ooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo0_l0
003oooooocgooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooo
ooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`00
0?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool0
0ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[o
oooo00?o0000ooooooooool0oooooollooooo`00:_ooool2o`000?oooooo?Oooool002[ooooo00?o
0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zoooo
o`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00
:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??oo
ool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooo
occooooo000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo
000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0ooooooll
ooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oo
oooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`008Oooool4o`000003oa0@4?oo
oooooooo00;ooooo00?o0000ooooooooool0oooooollooooo`008oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?oooooo??ooool002?ooooo00?o0000ooooooooool01?ooool3o`00
0?oooooo??ooool002?ooooo00?o0000ooooooooool0oooooom3ooooo`008oooool00ol0003ooooo
ooooo`3ooooood?ooooo000Sooooo`03o`000?oooooooooo0?oooooo@oooool002?ooooo00?o0000
ooooooooool0oooooom3ooooo`008Oooool00omEEEGoIVIVo`00003oooooodGooooo002>ooooo`Go
0000eOooool008kooooo00GoV9RHob4Q8Oo^k^koooooodA4A03Eooooo`00Soooool00onHV9So8B4Q
onk^kP3Fooooo`00T?ooool00onHV9So8B4Qonk^kP3Eooooo`00TOooool00omgMgOoIVIVooooo`3D
ooooo`00T_ooool00ol0003oooooooooo`0;ooooo`?o000000?o410@ooooooooool0`_ooool008Ko
oooo0_l00006ooooo`05o`000?nj^[[ooooooiRHV?l@41002?ooool00ol0003o^[Zjooooo`04oooo
o`03oa0@4?nj^[[ooooo00Gooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj
^_ooool0YOooool008Kooooo00?o0000ooooooooool01Oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Sooooo0_lb<S85ooooo`03oiRHV?lb<S;ooooo00Gooooo0_lb<S8>ooooo`03o`000?oooooooooo
00?ooooo0_lb<S:Vooooo`00Noooool01Ol@413o0000o`000?l0003o410@00Kooooo00?o0000oooo
ooooool04_ooool00on7QhOo0000okZj^P04ooooo`03omgMgOl0003o^[Zj00Gooooo00?oQhN7o`00
0?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool0
0on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0Noooool007gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03olc<c?l0003o410@00Cooooo00?o
EEEEogMgMom4A4@01Oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@4100
1?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko410@okZj^_o^k^ko
MgMgoa0@4?ooool6o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`1looooo`00OOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00?ooooo2_l0000;ooooo`05omgMgOl@413oooooob4Q8OoMgMd02oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol0001mooooo`00OOooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01Sooooo00GoIVIVohN7QoooooooV9RHoeEEE@0;ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`Ko00000_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00CoA4A4omgMgOoooooo0000O_ooool007gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Gooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool0
2Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo0000O_ooool007[o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Oooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`06ooooo`03oa0@4?l0003o
000000?o00001Oooool00ol0003oooooooooo`09ooooo`03oa0@4?l0003o000000?o00002_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000O_ooool007[ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000007kooooo001jooooo`Oo00001Ooo
ool2o`0000Oooooo1?l000000ol@413oooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo0_l0
000=ooooo`03o`000?oooooooooo00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMg
Mol0003ooooo07gooooo002Aooooo`03o`000?oooooooooo0=Cooooo002Aooooo`03o`000?oooooo
oooo0=Cooooo002Aooooo`03o`000?oooooooooo0=Cooooo002Aooooo`03o`000?oooooooooo0=Co
oooo002Aooooo`03o`000?oooooooooo0=Cooooo002Aooooo`03o`000?oooooooooo0=Cooooo002?
ooooo`03oeEEEOmVIVKo00000=Kooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.313969, -0.0837537, \
0.00916054, 0.00705812}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0 0.618034 [
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .12361 -18 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -18 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -18 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -18 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -47.0938 0 ]
[.5 .63053 47.0938 20.6875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .12361 m
.03006 .12361 L
s
[(0.2)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(0.4)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(0.6)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(0.8)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0309 m
.02756 .0309 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .58713 m
.02756 .58713 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -108.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 17.438 moveto
(@) show
78.062 11.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
76.750 17.438 moveto
(\\200\\200) show
81.000 17.438 moveto
(\\200) show
83.062 17.438 moveto
(\\200) show
78.062 23.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
87.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
93.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
99.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.188 17.438 moveto
(D) show
117.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
123.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.188 17.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
135.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
153.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .01701 L
.10458 .03521 L
.14415 .05168 L
.18221 .0667 L
.22272 .08155 L
.26171 .09445 L
.30316 .10648 L
.34309 .11615 L
.3815 .12358 L
.40095 .12661 L
.42237 .12931 L
.44268 .13128 L
.45178 .13197 L
.46172 .13259 L
.4671 .13287 L
.4721 .1331 L
.47727 .13329 L
.48196 .13343 L
.48658 .13354 L
.49093 .13362 L
.49332 .13365 L
.49552 .13367 L
.49667 .13368 L
.49794 .13368 L
.49926 .13369 L
.50049 .13369 L
.50175 .13368 L
.50239 .13368 L
.50309 .13368 L
.50433 .13367 L
.50549 .13366 L
.50811 .13363 L
.51094 .13359 L
.5161 .13348 L
.52084 .13335 L
.52988 .13301 L
.5394 .13253 L
.55914 .13112 L
.57751 .12932 L
.61655 .12391 L
.65805 .1159 L
.69803 .10616 L
.7365 .09501 L
.77742 .0815 L
.81682 .06708 L
.85471 .05214 L
.89505 .03537 L
.93387 .01862 L
.97515 .00046 L
Mistroke
.97619 0 L
Mfstroke
1 0 0 r
[ .05 .05 ] 0 setdash
.02381 0 m
.06244 .0168 L
.10458 .03481 L
.14415 .05112 L
.18221 .06598 L
.22272 .08066 L
.26171 .09343 L
.30316 .10531 L
.34309 .11489 L
.3815 .12224 L
.40095 .12522 L
.42237 .1279 L
.44268 .12986 L
.45178 .13054 L
.46172 .13116 L
.4671 .13144 L
.4721 .13165 L
.47727 .13184 L
.48196 .13198 L
.48658 .13208 L
.4887 .13212 L
.49093 .13215 L
.49332 .13218 L
.49438 .13219 L
.49552 .1322 L
.49675 .13221 L
.49789 .13221 L
.49859 .13221 L
.49925 .13221 L
.50049 .13221 L
.50163 .13221 L
.50286 .13221 L
.50401 .1322 L
.50508 .13219 L
.50754 .13217 L
.51014 .13214 L
.51268 .1321 L
.51504 .13205 L
.5204 .13191 L
.5293 .1316 L
.53882 .13113 L
.54906 .13049 L
.56016 .12962 L
.58032 .1276 L
.62123 .12178 L
.66064 .11408 L
.69852 .10486 L
.73886 .09325 L
.77769 .08052 L
.81897 .06554 L
Mistroke
.85873 .04996 L
.89697 .03416 L
.93767 .01676 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00I?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd0=oooool4o`000003oa0@4?oooooooooo03Gooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03Kooooo1Ol0
000[ooooo`00I?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo03Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0eooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0:oooool006Cooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Gooooo00?oV9RHob4Q8Oo^k^h0
;?ooool006Cooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo03Sooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03Oooooo
00?oV9RHob4Q8Oo^k^h0:oooool006Cooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0>Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`03ogMgMomVIVKooooo02[ooooo001Tooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
02Wooooo001Tooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hoooo
o`05o`000?nj^[[ooooooiRHV?l@4100:oooool006Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co0000>?ooool00omEEEGoIVIVo`00000iooooo`03oeEEEOmVIVKo000000gooooo1?l0000g
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03oooool3o`000003oa0@4?oooooooooo01Kooooo003o
ooooodoooooo00?o410@okZj^_ooool05oooool00?ooooooCoooool00onHV9So<S8booooo`0Goooo
o`00oooooom?ooooo`03omgMgOl0003o^[Zj01Oooooo003oooooodoooooo00?oEEEEogMgMom4A4@0
5oooool00?ooooooC_ooool01OoMgMgo410@oooooolQ8B7ogMgM01Kooooo000Tooooo`Ko00000_oo
003oo`0001So00002_ooool01OmVIVKoQhN7oooooonHV9SoEEEE01Kooooo000Zooooo`03o`000?oo
ooooo`0000;oo`002Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`?o000000?oooooo`000?ooool03ooo
ool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo01Cooooo000Zooooo`05o`000?oooooo
ooooooooool000000_oo000nooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0@Ooo
ool00ol0003oooooooooo`0kooooo`;o00001?ooool00ol0003oooooooooo`0>ooooo`04oa0@4?l0
003o0000ooooo`;o000000?o410@ooooooooool04oooool002[ooooo00?o0000ooooooooool01?oo
ool00ooo003o0000ooooo`3oooooo`;o0000<oooool002[ooooo00?o0000ooooooooool01_ooool2
o`000?_ooooo0ol0000eooooo`00:_ooool00ol0003oooooooooo`08ooooo`;o0000moooool2ool0
03Sooooo000Zooooo`03o`000?oooooooooo00[ooooo0ol0003booooo`;oo`00>_ooool002[ooooo
00?o0000ooooooooool03Oooool2o`000>gooooo00?o0000ool00?oo0000??ooool002[ooooo00?o
0000ooooooooool03oooool2o`0000;oo`00ioooool00ol0003oo`00ool0000nooooo`00:_ooool2
o`0001;ooooo0_l000000ooo003oooooooooo`3Rooooo`03o`000?oo003oo`00043ooooo000Zoooo
o`03o`000?oooooooooo01Cooooo0_oo003Pooooo`03o`000?oo003oo`0004;ooooo000Zooooo`03
o`000?oooooooooo01Kooooo0ooo003Jooooo`;o00000_oo0014ooooo`00:_ooool00ol0003ooooo
ooooo`0Iooooo`;oo`00e_ooool2o`0004Sooooo000Zooooo`03o`000?oooooooooo01_ooooo0ooo
003Aooooo`;o0000B_ooool002[ooooo00?o0000ooooooooool07Oooool00ol0003oo`00o`00003<
ooooo`?o0000C?ooool002[ooooo00?o0000ooooooooool08?ooool2o`000<Sooooo0_l0001?oooo
o`00:_ooool00ol0003oooooooooo`0Rooooo`?o0000`_ooool2ool00003o`000?oooooooooo04oo
oooo000Zooooo`03o`000?oooooooooo02Gooooo0ol0002looooo`?oo`00E?ooool002[ooooo0_l0
000Yooooo`?o0000]oooool2ool00003o`000?oooooooooo05Cooooo000Zooooo`03o`000?oooooo
oooo02_ooooo0_oo002cooooo`;oo`00FOooool002[ooooo00?o0000ooooooooool0;Oooool3ool0
0:gooooo0ooo001Kooooo`00:_ooool00ol0003oooooooooo`0`ooooo`?oo`00Yoooool3ool005ko
oooo000Zooooo`03o`000?oooooooooo03?ooooo0ooo002Qooooo`?oo`00HOooool002[ooooo00?o
0000ooooooooool0=_ooool3ool009_ooooo0ooo001Tooooo`00:_ooool00ol0003oooooooooo`0i
ooooo`03ool00?l0003o000009Gooooo0_l000000ooo003oooooooooo`1Uooooo`00:_ooool00ol0
003oooooooooo`0looooo`?o0000Soooool3o`0006[ooooo000Zooooo`03o`000?oooooooooo03oo
oooo0ol00029ooooo`?o0000KOooool002[ooooo0_l00013ooooo`?o0000Poooool3o`00073ooooo
000Zooooo`03o`000?oooooooooo04Gooooo0_l00003ool007[ooooo0ooo00000ol0003ooooooooo
o`1aooooo`00:_ooool00ol0003oooooooooo`19ooooo`04o`000?oo003oo`00ool007Cooooo0ooo
001gooooo`00:_ooool00ol0003oooooooooo`1<ooooo`04o`000?oo003oo`00ool006gooooo1?oo
001jooooo`00:_ooool00ol0003oooooooooo`1@ooooo`?oo`0000?o0000ooooooooool0Hoooool0
1?l0003oo`00ool00?oo001nooooo`00:_ooool00ol0003oooooooooo`1Cooooo`;oo`000ol0001M
ooooo`?o00000_oo0021ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`Go00001Oooool00ol0003oooooooooo`1Hooooo`Go0000Doooool5o`0008Kooooo000@oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A005ooooo`03o`000?oooooooooo05gooooo1Ol00018ooooo`Ko0000Roooool0013ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001Rooooo`Koo`00??oo
ool2o`0000Goo`00T?ooool0013ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Gooooo00?o0000ooooooooool0J?ooool6ool0037ooooo00?o0000ool00?oo00001?oo
002Eooooo`004?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01?oo
ool00ol0003oooooooooo`1^ooooo`Coo`000_l0000Vooooo`;o00001?oo002Kooooo`004?ooool0
1Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1dooooo`_o00003ooo000<o`000:7ooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0oooooollooooo`004?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03
o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_oo
ool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool0
02[ooooo0_l0003oooooocgooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo
00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Z
ooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooolloooo
o`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo
??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool2o`000?oooooo?Oooool0
02[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3oooooocco
oooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooo
oollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo
0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooo
ooooo`3ooooooccooooo000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0003oooooooooo`3o
oooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooooooo
ool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oo
oooooooo0?oooooo??ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooollooooo`004?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0oooooollooooo`004?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
0005ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo0ol0003ooooooccooooo000@ooooo`05o`000?oo
ooooooooooooool000002oooool01?oMgMgoEEEEooooool00006ooooo`03o`000?oooooooooo0?oo
oooo??ooool0013ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Ko
oooo00?o0000ooooooooool0oooooollooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?ok^k^odA4A?l000001_ooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05ooooo`03o`000?oooooooooo0?oo
oooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooooooo
o`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooo
ooooool0oooooollooooo`00:_ooool2o`000?oooooo?Oooool002[ooooo00?o0000ooooooooool0
oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooo
oooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003o
ooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o
0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zoooo
o`;o0000oooooolmooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`00
0?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool0
0ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[o
oooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo
000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zoooo
o`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00
:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??oo
ool002[ooooo00?o0000ooooooooool0oooooollooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01Oooool00ol0003ooooooooo
o`3ooooooccooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
EEEEogMgMoooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Go
410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool3o`000?oo
oooo??ooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRH
V?lQ8B401Oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05o`000?oooooooooooooo
ool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0ooooooll
ooooo`004?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool01oooool0
0ol0003oooooooooo`3ooooooccooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
0ooMgMgo410@oiRHV007ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?o0000ooooooooool0oooo
oollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo
0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool2o`000?oooooo
?Oooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3o
oooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooooooo
ool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oo
oooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0
003oooooooooo`3ooooooccooooo000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0003ooooo
ooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000
ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03
o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_oo
ool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool0
02[ooooo0_l0003oooooocgooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo
00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Z
ooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooolloooo
o`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oo
oooooooo0?oooooo??ooool0013ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oo
ooooooooooooool000001Oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05o`000?oo
ooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Gooooo0ol0003oooooocco
oooo000@ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<
00Gooooo00?o0000ooooooooool0oooooollooooo`004?ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4005ooooo`03o`000?oooooooooo0?oooooo??ooool0
013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001Ooo
ool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY00Gooooo00?o0000ooooooooool0oooooollooooo`00:_oo
ool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool0
02[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool2o`000?oooooo?Oooool002[ooooo
00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Z
ooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooolloooo
o`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo
??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3o
oooooccooooo000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0003oooooooooo`3oooooocco
oooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooo
oollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo
0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooo
ooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo0_l0003o
ooooocgooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooooooo
ool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oo
oooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0
003oooooooooo`3ooooooccooooo000Qooooo`Co000000?o410@ooooooooool00_ooool00ol0003o
ooooooooo`3ooooooccooooo000Sooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooollooooo`008oooool00ol0003oooooooooo`04ooooo`?o0000oooooollooooo`008oooool0
0ol0003oooooooooo`3ooooood?ooooo000Sooooo`03o`000?oooooooooo0?oooooo@oooool002?o
oooo00?o0000ooooooooool0oooooom3ooooo`008oooool00ol0003oooooooooo`3ooooood?ooooo
000Qooooo`03oeEEEOmVIVKo00000?ooooooAOooool008kooooo1Ol0003Eooooo`00S_ooool01OnH
V9So8B4Qonk^k_ooooooA4A40=Gooooo002?ooooo`03oiRHV?lQ8B7ok^k^0=Kooooo002@ooooo`03
oiRHV?lQ8B7ok^k^0=Gooooo002Aooooo`03ogMgMomVIVKooooo0=Cooooo002Booooo`03o`000?oo
oooooooo00_ooooo0ol000000ol@413oooooooooo`32ooooo`00Q_ooool2o`0000Kooooo00Go0000
okZj^_ooooooV9RHoa0@4008ooooo`03o`000?nj^[[ooooo00Cooooo00?o410@okZj^_ooool01Ooo
ool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2Uooooo`00Q_ooool0
0ol0003oooooooooo`05ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`02?ooool2oc8b<PGooooo00?o
V9RHoc8b<_ooool01Oooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<ZKooooo001k
ooooo`05oa0@4?l0003o0000o`000?l@41001_ooool00ol0003oooooooooo`0Booooo`03ohN7Qol0
003o^[Zj00Cooooo00?ogMgMo`000?nj^[X01Oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0
003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`03ooooo`03ohN7Qol0003o^[Zj00Gooooo
00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@1looooo`00OOooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01;ooooo00?oc<c<o`000?l@41001?ooool00omEEEGoMgMgodA4A005oooo
o`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooo
oooo00?ooooo00?oc<c<o`000?l@41001Oooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko0000
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo07_o
oooo001mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool:o`0000_ooooo
00GogMgMoa0@4?oooooo8B4QomgMg@0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`1jooooo`00OOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01So
oooo00GoIVIVohN7QoooooooV9RHoeEEE@0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`03ooooo`Ko00000_ooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool0Noooool007gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Gooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool02Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c01looooo`00N_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05ooo
ool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00Kooooo00?o410@o`000?l00000
0ol00005ooooo`03o`000?oooooooooo00Wooooo00?o410@o`000?l000000ol0000:ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`1nooooo`00N_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0O_ooool007[ooooo1ol00005ooooo`;o
00001oooool4o`000003oa0@4?oooooooooo01_ooooo00?o0000ooooooooool01Oooool2o`0000go
oooo00?o0000ooooooooool02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0001moooo
o`00TOooool00ol0003oooooooooo`3Dooooo`00TOooool00ol0003oooooooooo`3Dooooo`00TOoo
ool00ol0003oooooooooo`3Dooooo`00TOooool00ol0003oooooooooo`3Dooooo`00TOooool00ol0
003oooooooooo`3Dooooo`00TOooool00ol0003oooooooooo`3Dooooo`00Soooool00omEEEGoIVIV
o`00003Fooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.313969, -0.0837537, \
0.00916054, 0.00705812}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0 0.618034 [
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .12361 -18 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -18 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -18 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -18 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -47.0938 0 ]
[.5 .63053 47.0938 20.6875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .12361 m
.03006 .12361 L
s
[(0.2)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(0.4)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(0.6)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(0.8)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0309 m
.02756 .0309 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .58713 m
.02756 .58713 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -108.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 17.438 moveto
(@) show
78.062 11.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
76.750 17.438 moveto
(\\200\\200) show
81.000 17.438 moveto
(\\200) show
83.062 17.438 moveto
(\\200) show
78.062 23.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
87.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
93.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
99.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.188 17.438 moveto
(D) show
117.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
123.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.188 17.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
135.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
153.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .01253 L
.10458 .02592 L
.14415 .03805 L
.18221 .04911 L
.22272 .06004 L
.26171 .06954 L
.30316 .07839 L
.34309 .08551 L
.3815 .09099 L
.40095 .09321 L
.42237 .0952 L
.44268 .09665 L
.45178 .09716 L
.46172 .09762 L
.4671 .09783 L
.4721 .09799 L
.47727 .09813 L
.48196 .09824 L
.48658 .09832 L
.49093 .09837 L
.49332 .0984 L
.49552 .09841 L
.49667 .09842 L
.49794 .09842 L
.49926 .09842 L
.50049 .09842 L
.50175 .09842 L
.50239 .09842 L
.50309 .09842 L
.50433 .09841 L
.50549 .0984 L
.50811 .09838 L
.51094 .09835 L
.5161 .09827 L
.52084 .09818 L
.52988 .09793 L
.5394 .09757 L
.55914 .09654 L
.57751 .09521 L
.61655 .09123 L
.65805 .08533 L
.69803 .07816 L
.7365 .06995 L
.77742 .06001 L
.81682 .04938 L
.85471 .03839 L
.89505 .02604 L
.93387 .01371 L
.97515 .00034 L
Mistroke
.97619 0 L
Mfstroke
1 0 0 r
[ .05 .05 ] 0 setdash
.02381 0 m
.06244 .01234 L
.10458 .02557 L
.14415 .03755 L
.18221 .04847 L
.22272 .05925 L
.26171 .06863 L
.30316 .07736 L
.34309 .0844 L
.3815 .0898 L
.40095 .09199 L
.42237 .09396 L
.44268 .09539 L
.45178 .0959 L
.46172 .09635 L
.4671 .09655 L
.4721 .09671 L
.47727 .09685 L
.48196 .09695 L
.48658 .09703 L
.4887 .09706 L
.49093 .09708 L
.49332 .0971 L
.49438 .09711 L
.49552 .09711 L
.49675 .09712 L
.49789 .09712 L
.49859 .09712 L
.49925 .09712 L
.50049 .09712 L
.50163 .09712 L
.50286 .09712 L
.50401 .09712 L
.50508 .09711 L
.50754 .09709 L
.51014 .09707 L
.51268 .09704 L
.51504 .097 L
.5204 .0969 L
.5293 .09667 L
.53882 .09633 L
.54906 .09586 L
.56016 .09522 L
.58032 .09374 L
.62123 .08946 L
.66064 .08381 L
.69852 .07703 L
.73886 .0685 L
.77769 .05915 L
.81897 .04814 L
Mistroke
.85873 .0367 L
.89697 .02509 L
.93767 .01231 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00I?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd0=oooool4o`000003oa0@4?oooooooooo03Gooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03Kooooo1Ol0
000[ooooo`00I?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo03Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0eooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0:oooool006Cooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Gooooo00?oV9RHob4Q8Oo^k^h0
;?ooool006Cooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo03Sooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03Oooooo
00?oV9RHob4Q8Oo^k^h0:oooool006Cooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0>Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`03ogMgMomVIVKooooo02[ooooo001Tooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
02Wooooo001Tooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hoooo
o`05o`000?nj^[[ooooooiRHV?l@4100:oooool006Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co0000>?ooool00omEEEGoIVIVo`00000iooooo`03oeEEEOmVIVKo000000gooooo1?l0000g
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03oooool3o`000003oa0@4?oooooooooo01Kooooo003o
ooooodoooooo00?o410@okZj^_ooool05oooool00?ooooooCoooool00onHV9So<S8booooo`0Goooo
o`00oooooom?ooooo`03omgMgOl0003o^[Zj01Oooooo003oooooodoooooo00?oEEEEogMgMom4A4@0
5oooool00?ooooooC_ooool01OoMgMgo410@oooooolQ8B7ogMgM01Kooooo000Tooooo`Ko00000ooo
003oo`0001Oo00002_ooool01OmVIVKoQhN7oooooonHV9SoEEEE01Kooooo000Zooooo`03o`000?oo
oooo000000Coo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`?o000000?oooooo`000?ooool03ooo
ool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo01Cooooo000Zooooo`03o`000?oooooo
oooo00;ooooo0_l00003ool003_ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`11
ooooo`03o`000?oooooooooo03Sooooo0ooo0002o`0000Cooooo00?o0000ooooooooool03_ooool0
1?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01?ooooo000Zooooo`03o`000?oooooo
oooo00Gooooo0_l00002ool00?Wooooo0ooo0002o`0003Cooooo000Zooooo`03o`000?oooooooooo
00Sooooo0ol0003dooooo`?oo`000_l0000gooooo`00:_ooool00ol0003oooooooooo`0;ooooo`Co
0000kOooool01?l0003oo`00ool00?l0000kooooo`00:_ooool00ol0003oooooooooo`0?ooooo`Co
0000i_ooool01?l0003oo`00ool00?oo000nooooo`00:_ooool00ol0003oooooooooo`0Cooooo`Co
0000goooool3o`000003ool00?oooooooooo03oooooo000Zooooo`03o`000?oooooooooo01Gooooo
0ooo0002o`000=Wooooo0ol00015ooooo`00:_ooool2o`0001Wooooo1?oo00000ol0003ooooooooo
o`3Aooooo`?o0000B?ooool002[ooooo00?o0000ooooooooool07?ooool3ool00003o`000?oooooo
oooo0<_ooooo0ol0001;ooooo`00:_ooool00ol0003oooooooooo`0Oooooo`Coo`00a_ooool01?l0
003oo`00ool00?oo001>ooooo`00:_ooool00ol0003oooooooooo`0Sooooo`04ool00?l0003o0000
o`000;oooooo1?oo001Aooooo`00:_ooool00ol0003oooooooooo`0Wooooo`?o0000^Oooool3ool0
05Gooooo000Zooooo`03o`000?oooooooooo02[ooooo1?l0002aooooo`04o`000?oo003oo`00ool0
05Sooooo000Zooooo`03o`000?oooooooooo02kooooo1?l0002Yooooo`;o00000ooo001Kooooo`00
:_ooool00ol0003oooooooooo`0aooooo`Coo`00X_ooool4o`0000;oo`00G_ooool002[ooooo00?o
0000ooooooooool0=Oooool4ool009[ooooo1?l0001Tooooo`00:_ooool2o`0003[ooooo1Ooo002A
ooooo`Co0000J?ooool002[ooooo00?o0000ooooooooool0?Oooool01?l0003oo`00ool00?l0002;
ooooo`;oo`0000?o0000ooooooooool0J_ooool002[ooooo00?o0000ooooooooool0@Oooool5o`00
087ooooo1Ooo001_ooooo`00:_ooool00ol0003oooooooooo`16ooooo`Go0000Moooool5ool007Co
oooo000Zooooo`03o`000?oooooooooo04_ooooo0_l00004ool006_ooooo0ol00003ool007Wooooo
000Zooooo`03o`000?oooooooooo057ooooo1_oo001Oooooo`Ko0000Ooooool002[ooooo00?o0000
ooooooooool0Eoooool5ool00003o`000?oooooooooo053ooooo0ooo0004o`0008Gooooo000Zoooo
o`03o`000?oooooooooo05gooooo1Ol00018ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool0ROooool002[ooooo00?o0000ooooooooool0H_ooool6o`000003oooooooo003oo`0000?o
o`00=?ooool9ool0093ooooo000Zooooo`;o0000JOooool6o`0000[oo`006oooool2ool000Gooooo
2?l0002Iooooo`00:_ooool00ol0003oooooooooo`1doooooa;o00003Ooo0007o`000:7ooooo000Z
ooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooolloooo
o`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo
??ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo
00?o0000ooooooooool0oooooollooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003oooooooooo`3oooooocco
oooo000@ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP06ooooo`?o
0000oooooollooooo`004?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^
k^h01Oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05o`000?ooooooooooooooool0
00003_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0oooooollooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4005ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3o
oooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooooooo
ool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`;o0000oooo
oolmooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo
0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooo
ooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000
ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03
o`000?oooooooooo0?oooooo??ooool002[ooooo0_l0003oooooocgooooo000Zooooo`03o`000?oo
oooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0
003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo
00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Z
ooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooolloooo
o`00:_ooool2o`000?oooooo?Oooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_oo
ool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool0
02[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3oooooocco
oooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oo
oooo??ooool0013ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001Oooool00ol0003o
ooooooooo`3ooooooccooooo000@ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4Co
gMgMooooool00006ooooo`?o0000oooooollooooo`004?ooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003oooooooooo`3ooooooccooooo000@oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`03o`000?oooooo
oooo0?oooooo??ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co
000000Kooooo00?o0000ooooooooool0oooooollooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00gooooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`3ooooooccooooo000Zoooo
o`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00
:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??oo
ool002[ooooo0_l0003oooooocgooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[o
oooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo
000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0ooooooll
ooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oo
oooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool2o`000?oooooo?Ooo
ool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooo
occooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0
oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooo
oooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool2o`000?oo
oooo?Oooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooooooo
o`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooo
ooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`00
0?oooooooooo0?oooooo??ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0oooooollooooo`00
4?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B401Oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000Gooooo0ol0003ooooooccooooo000@oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Gooooo00?o
0000ooooooooool0oooooollooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000oeEEEOl0003o410@olc<c005ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Go
410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Oooooo00?o0000ooooooooool0
oooooollooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0
1oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool01?o<c<coA4A4o`000?l@4105ooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo
00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Z
ooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo0_l0003oooooocgooooo000Zooooo`03
o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_oo
ool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool0
02[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3oooooocco
oooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooo
oollooooo`00:_ooool2o`000?oooooo?Oooool002[ooooo00?o0000ooooooooool0oooooolloooo
o`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo
??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3o
oooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooooooo
ool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`;o0000oooo
oolmooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo
0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooo
ooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Gooooo
00?o0000ooooooooool0oooooollooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401Oooool00ol0003oooooooooo`3oooooocco
oooo000@ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo0000
00Gooooo00?o0000ooooooooool0oooooollooooo`004?ooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P05ooooo`?o0000oooooollooooo`004?ooool01Ol0
003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c005ooooo`03o`000?oo
oooooooo0?oooooo??ooool0013ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj
^[[ooooookZj^_l@41001Oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Gooooo00?o0000oooooooo
ool0oooooollooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@05ooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooooooo
ool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oo
oooooooo0?oooooo??ooool002[ooooo0_l0003oooooocgooooo000Zooooo`03o`000?oooooooooo
0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooo
ooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000
ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03
o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_oo
ool2o`000?oooooo?Oooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0
003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo
00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Z
ooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooolloooo
o`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`;o0000oooooolmooooo`00:_oo
ool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool0
02[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3oooooocco
oooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooo
oollooooo`008Oooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0ooooooll
ooooo`008oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo??ooool002?o
oooo00?o0000ooooooooool01?ooool3o`000?oooooo??ooool002?ooooo00?o0000ooooooooool0
oooooom3ooooo`008oooool00ol0003oooooooooo`3ooooood?ooooo000Sooooo`03o`000?oooooo
oooo0?oooooo@oooool002?ooooo00?o0000ooooooooool0oooooom3ooooo`008Oooool00omEEEGo
IVIVo`00003oooooodGooooo002>ooooo`Go0000eOooool008kooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A03Eooooo`00Soooool00onHV9So8B4Qonk^kP3Fooooo`00T?ooool00onHV9So8B4Qonk^kP3E
ooooo`00TOooool00omgMgOoIVIVooooo`3Dooooo`00T_ooool00ol0003oooooooooo`0;ooooo`?o
000000?o410@ooooooooool0`_ooool008Kooooo0_l00006ooooo`05o`000?nj^[[ooooooiRHV?l@
41002?ooool00ol0003o^[Zjooooo`04ooooo`03oa0@4?nj^[[ooooo00Gooooo00?o0000okZj^_oo
ool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0YOooool008Kooooo00?o0000ooooooooool0
1Oooool01OnHV9So410@o`000?lQ8B7oc<c<00Sooooo0_lb<S85ooooo`03oiRHV?lb<S;ooooo00Go
oooo0_lb<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:Vooooo`00Noooool01Ol@413o0000
o`000?l0003o410@00Kooooo00?o0000ooooooooool04_ooool00on7QhOo0000okZj^P04ooooo`03
omgMgOl0003o^[Zj00Gooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj
00Cooooo00?o0000ooooooooool00oooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000
odA4A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0OOooool007gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Booooo`03olc<c?l0003o410@00Cooooo00?oEEEEogMgMom4A4@01Oooool00oo<c<co0000oa0@
4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`03ooooo`03olc<
c?l0003o410@00Gooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q07gooooo001m
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool:o`0000_ooooo00GogMgM
oa0@4?oooooo8B4QomgMg@0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000007gooooo001mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
6?ooool01OmVIVKoQhN7oooooonHV9SoEEEE00_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo1_l00002ooooo`05o`000?oooooooooooooo
ool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q07gooooo001mooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool05oooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo
00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0OOoo
ool007[ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01Oooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`06ooooo`03oa0@
4?l0003o000000?o00001Oooool00ol0003oooooooooo`09ooooo`03oa0@4?l0003o000000?o0000
2_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0Ooooool007[ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH07oooooo001jooooo`Oo
00001Oooool2o`0000Oooooo1?l000000ol@413oooooooooo`0Kooooo`03o`000?oooooooooo00Go
oooo0_l0000=ooooo`03o`000?oooooooooo00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`04olc<c?m4A4Co0000oa0@47gooooo002Aooooo`03o`000?oooooooooo0=Cooooo002Aooooo`03
o`000?oooooooooo0=Cooooo002Aooooo`03o`000?oooooooooo0=Cooooo002Aooooo`03o`000?oo
oooooooo0=Cooooo002Aooooo`03o`000?oooooooooo0=Cooooo002Aooooo`03o`000?oooooooooo
0=Cooooo002?ooooo`03oeEEEOmVIVKo00000=Kooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.313969, -0.0837537, \
0.00916054, 0.00705812}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0 0.618034 [
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .12361 -18 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -18 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -18 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -18 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -47.0938 0 ]
[.5 .63053 47.0938 20.6875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .12361 m
.03006 .12361 L
s
[(0.2)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(0.4)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(0.6)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(0.8)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0309 m
.02756 .0309 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .58713 m
.02756 .58713 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -108.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 17.438 moveto
(@) show
78.062 11.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
76.750 17.438 moveto
(\\200\\200) show
81.000 17.438 moveto
(\\200) show
83.062 17.438 moveto
(\\200) show
78.062 23.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
87.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
93.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
99.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.188 17.438 moveto
(D) show
117.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
123.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.188 17.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
135.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
153.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .00922 L
.10458 .01908 L
.14415 .02801 L
.18221 .03616 L
.22272 .0442 L
.26171 .0512 L
.30316 .05771 L
.34309 .06296 L
.3815 .06699 L
.40095 .06863 L
.42237 .07009 L
.44268 .07116 L
.45178 .07153 L
.46172 .07187 L
.4671 .07202 L
.4721 .07214 L
.47727 .07225 L
.48196 .07233 L
.48658 .07239 L
.49093 .07243 L
.49332 .07244 L
.49552 .07245 L
.49667 .07246 L
.49794 .07246 L
.49926 .07246 L
.50049 .07246 L
.50175 .07246 L
.50239 .07246 L
.50309 .07246 L
.50433 .07245 L
.50549 .07245 L
.50811 .07243 L
.51094 .07241 L
.5161 .07235 L
.52084 .07228 L
.52988 .0721 L
.5394 .07184 L
.55914 .07107 L
.57751 .0701 L
.61655 .06716 L
.65805 .06282 L
.69803 .05754 L
.7365 .0515 L
.77742 .04418 L
.81682 .03636 L
.85471 .02826 L
.89505 .01917 L
.93387 .01009 L
.97515 .00025 L
Mistroke
.97619 0 L
Mfstroke
1 0 0 r
[ .05 .05 ] 0 setdash
.02381 0 m
.06244 .00907 L
.10458 .01879 L
.14415 .02758 L
.18221 .03561 L
.22272 .04353 L
.26171 .05042 L
.30316 .05683 L
.34309 .062 L
.3815 .06597 L
.40095 .06757 L
.42237 .06902 L
.44268 .07008 L
.45178 .07045 L
.46172 .07078 L
.4671 .07093 L
.4721 .07105 L
.47727 .07115 L
.48196 .07122 L
.48658 .07128 L
.4887 .0713 L
.49093 .07132 L
.49332 .07133 L
.49438 .07134 L
.49552 .07134 L
.49675 .07134 L
.49789 .07135 L
.49859 .07135 L
.49925 .07135 L
.50049 .07135 L
.50163 .07135 L
.50286 .07134 L
.50401 .07134 L
.50508 .07134 L
.50754 .07133 L
.51014 .07131 L
.51268 .07129 L
.51504 .07126 L
.5204 .07119 L
.5293 .07101 L
.53882 .07076 L
.54906 .07042 L
.56016 .06995 L
.58032 .06886 L
.62123 .06572 L
.66064 .06156 L
.69852 .05659 L
.73886 .05032 L
.77769 .04345 L
.81897 .03537 L
Mistroke
.85873 .02696 L
.89697 .01843 L
.93767 .00904 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00I?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd0=oooool4o`000003oa0@4?oooooooooo03Gooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03Kooooo1Ol0
000[ooooo`00I?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo03Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0eooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0:oooool006Cooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Gooooo00?oV9RHob4Q8Oo^k^h0
;?ooool006Cooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo03Sooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03Oooooo
00?oV9RHob4Q8Oo^k^h0:oooool006Cooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0>Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`03ogMgMomVIVKooooo02[ooooo001Tooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
02Wooooo001Tooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hoooo
o`05o`000?nj^[[ooooooiRHV?l@4100:oooool006Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co0000>?ooool00omEEEGoIVIVo`00000iooooo`03oeEEEOmVIVKo000000gooooo1?l0000g
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03oooool3o`000003oa0@4?oooooooooo01Kooooo003o
ooooodoooooo00?o410@okZj^_ooool05oooool00?ooooooCoooool00onHV9So<S8booooo`0Goooo
o`00oooooom?ooooo`03omgMgOl0003o^[Zj01Oooooo003oooooodoooooo00?oEEEEogMgMom4A4@0
5oooool00?ooooooC_ooool01OoMgMgo410@oooooolQ8B7ogMgM01Kooooo000Tooooo`Ko00000ooo
003oo`0001Oo00002_ooool01OmVIVKoQhN7oooooonHV9SoEEEE01Kooooo000Zooooo`03o`000?oo
oooooooo00Coo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`?oo`0000Co0000oooooooooooo0000
4?ooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo01Cooooo000Zooooo`03o`000?oo
oooooooo00Cooooo0ooo000kooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0@Ooo
ool00ol0003oooooooooo`0gooooo`04o`000?oo003oo`00ool000Kooooo00?o0000ooooooooool0
3_ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01?ooooo000Zooooo`03o`00
0?oooooooooo00Oooooo1?oo00000ol0003oooooooooo`3aooooo`03o`000?oo003oo`0000?oo`00
=_ooool002[ooooo00?o0000ooooooooool03?ooool6o`000>Sooooo0_l00004ool003_ooooo000Z
ooooo`03o`000?oooooooooo01;ooooo1Ol0003Nooooo`Go0000@Oooool002[ooooo00?o0000oooo
ooooool05oooool01?l0003oo`00ool00?oo003Fooooo`Co0000A_ooool002[ooooo00?o0000oooo
ooooool06oooool4ool00<kooooo00Co0000ool00?l0003o0000B_ooool002[ooooo00?o0000oooo
ooooool07oooool5ool00<Gooooo00?o0000ool00?oo00000_oo001=ooooo`00:_ooool2o`0002Go
oooo0ooo0002o`000;_ooooo1_oo001Aooooo`00:_ooool00ol0003oooooooooo`0Yooooo`Go0000
/Oooool00ol0003oo`00ool00002ool005Oooooo000Zooooo`03o`000?oooooooooo02kooooo1?l0
002Yooooo`Co000000?oo`00ooooooooool0FOooool002[ooooo00?o0000ooooooooool0<_ooool2
o`0000Koo`00WOooool4o`00063ooooo000Zooooo`03o`000?oooooooooo03Gooooo1Ol00006ool0
08kooooo1?oo0005o`0006Cooooo000Zooooo`03o`000?oooooooooo03[ooooo1_l00003ool008Go
oooo1_oo0004o`0006Wooooo000Zooooo`03o`000?oooooooooo043ooooo0_l000000ooo003o0000
o`000004o`0007cooooo0ooo0005o`0006kooooo000Zooooo`03o`000?oooooooooo04Wooooo2?l0
001[ooooo`Oo00000_oo001fooooo`00:_ooool00ol0003oooooooooo`1@ooooo`Koo`0000?o0000
ooooooooool0GOooool6o`0007oooooo000Zooooo`;o0000Eoooool:ool004gooooo0_l00006ool0
0003o`000?oooooooooo08?ooooo000Zooooo`03o`000?oooooooooo063ooooo2?l0000jooooo`Co
00002Ooo002<ooooo`00:_ooool00ol0003oooooooooo`1Xooooo`Go00003ooo000=oooooa3oo`00
2Ol0002Iooooo`00:_ooool00ol0003oooooooooo`1koooooaWo0000Yoooool002[ooooo00?o0000
ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03
o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_oo
ool00ol0003oooooooooo`3ooooooccooooo000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0
003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo
00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Z
ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooollooooo`004?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Ooo
ool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooollooooo`004?ooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`3ooooooccooooo000@
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oo
oooooooo0?oooooo??ooool0013ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooollooooo`004?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo0?oooooo
??ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01Oooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo
??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3o
oooooccooooo000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0003oooooooooo`3oooooocco
oooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooo
oollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo
0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooo
ooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo0_l0003o
ooooocgooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooooooo
ool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oo
oooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0
003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo
00?o0000ooooooooool0oooooollooooo`00:_ooool2o`000?oooooo?Oooool002[ooooo00?o0000
ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03
o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_oo
ool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo??oo
ool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Go410@oooooooooooooooooa0@
400;ooooo`Go00001Oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05o`000?oooooo
ooooooooool000002oooool01?m4A4CogMgMooooool00006ooooo`?o0000oooooollooooo`004?oo
ool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003o
ooooooooo`3ooooooccooooo000@ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOo
c<c<o`000006ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo00?o0000ooooooooool0oooooollooooo`00
4?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01Oooool00ol0003o
ooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o
0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zoooo
o`03o`000?oooooooooo0?oooooo??ooool002[ooooo0_l0003oooooocgooooo000Zooooo`03o`00
0?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool0
0ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[o
oooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo
000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0ooooooll
ooooo`00:_ooool2o`000?oooooo?Oooool002[ooooo00?o0000ooooooooool0oooooollooooo`00
:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??oo
ool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooo
occooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0
oooooollooooo`00:_ooool2o`000?oooooo?Oooool002[ooooo00?o0000ooooooooool0ooooooll
ooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oo
oooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooooooo
o`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Gooooo00?o
0000ooooooooool0oooooollooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401Oooool00ol0003oooooooooo`3ooooooccooooo
000@ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Go
oooo0ol0003ooooooccooooo000@ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003o
V9RHoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0oooooollooooo`004?ooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c005ooooo`03o`000?oooooo
oooo0?oooooo??ooool0013ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOo
oooo00Oooooo00?o0000ooooooooool0oooooollooooo`004?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00?ogMgMoa0@4?nHV9P01oooool00ol0003oooooooooo`3ooooooccooooo000@oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4105ooooo`03o`000?oo
oooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0
003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo
0_l0003oooooocgooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000
ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03
o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_oo
ool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool0
02[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool2o`000?oooooo?Oooool002[ooooo
00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Z
ooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooolloooo
o`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo
??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3o
oooooccooooo000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0003oooooooooo`3oooooocco
oooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooo
oollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo
0?oooooo??ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<
c<co8B4Qo`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0oooooollooooo`004?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401Ooo
ool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0oooooollooooo`004?oo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P05ooooo`?o
0000oooooollooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0
003o0000olc<c005ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001Oooool00ol0003oooooooooo`3o
oooooccooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj
^[[o000000Gooooo00?o0000ooooooooool0oooooollooooo`004?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@05ooooo`03o`000?oooooooooo0?oooooo
??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3o
oooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo0_l0003oooooocgo
oooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooo
oollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo
0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooo
ooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000
ooooooooool0oooooollooooo`00:_ooool2o`000?oooooo?Oooool002[ooooo00?o0000oooooooo
ool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oo
oooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0
003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo
00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Z
ooooo`;o0000oooooolmooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03
o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_oo
ool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool0
02[ooooo00?o0000ooooooooool0oooooollooooo`008Oooool4o`000003oa0@4?oooooooooo00;o
oooo00?o0000ooooooooool0oooooollooooo`008oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0?oooooo??ooool002?ooooo00?o0000ooooooooool01?ooool3o`000?oooooo??oo
ool002?ooooo00?o0000ooooooooool0oooooom3ooooo`008oooool00ol0003oooooooooo`3ooooo
od?ooooo000Sooooo`03o`000?oooooooooo0?oooooo@oooool002?ooooo00?o0000ooooooooool0
oooooom3ooooo`008Oooool00omEEEGoIVIVo`00003oooooodGooooo002>ooooo`Go0000eOooool0
08kooooo00GoV9RHob4Q8Oo^k^koooooodA4A03Eooooo`00Soooool00onHV9So8B4Qonk^kP3Foooo
o`00T?ooool00onHV9So8B4Qonk^kP3Eooooo`00TOooool00omgMgOoIVIVooooo`3Dooooo`00T_oo
ool00ol0003oooooooooo`0;ooooo`?o000000?o410@ooooooooool0`_ooool008Kooooo0_l00006
ooooo`05o`000?nj^[[ooooooiRHV?l@41002?ooool00ol0003o^[Zjooooo`04ooooo`03oa0@4?nj
^[[ooooo00Gooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0YOoo
ool008Kooooo00?o0000ooooooooool01Oooool01OnHV9So410@o`000?lQ8B7oc<c<00Sooooo0_lb
<S85ooooo`03oiRHV?lb<S;ooooo00Gooooo0_lb<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb
<S:Vooooo`00Noooool01Ol@413o0000o`000?l0003o410@00Kooooo00?o0000ooooooooool04_oo
ool00on7QhOo0000okZj^P04ooooo`03omgMgOl0003o^[Zj00Gooooo00?oQhN7o`000?nj^[X01?oo
ool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7QhOo0000
okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo07gooooo001mooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool04_ooool00oo<c<co0000oa0@4004ooooo`03oeEEEOmgMgOoA4A400Go
oooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000oooo
ooooool00oooool00oo<c<co0000oa0@4005ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l0
0002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool0
OOooool007gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`[o00002ooo
ool01OoMgMgo410@oooooolQ8B7ogMgM00_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go410@oooooooooooooooooa0@400=ooooo`03
ojVYZOmEEEGooooo07gooooo001mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
6?ooool01OmVIVKoQhN7oooooonHV9SoEEEE00_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo1_l00002ooooo`05o`000?oooooooooooooo
ool000003_ooool00olQ8B7oooooooooo`1looooo`00OOooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01Oooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`09ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`05
o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`1looooo`00N_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo00Kooooo00?o410@o`000?l000000ol00005
ooooo`03o`000?oooooooooo00Wooooo00?o410@o`000?l000000ol0000:ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00onYZJWoMgMgooooo`1looooo`00N_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P1mooooo`00N_ooool7o`0000Gooooo
0_l00007ooooo`Co000000?o410@ooooooooool06oooool00ol0003oooooooooo`05ooooo`;o0000
3Oooool00ol0003oooooooooo`0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0007go
oooo002Aooooo`03o`000?oooooooooo0=Cooooo002Aooooo`03o`000?oooooooooo0=Cooooo002A
ooooo`03o`000?oooooooooo0=Cooooo002Aooooo`03o`000?oooooooooo0=Cooooo002Aooooo`03
o`000?oooooooooo0=Cooooo002Aooooo`03o`000?oooooooooo0=Cooooo002?ooooo`03oeEEEOmV
IVKo00000=Kooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.313969, -0.0837537, \
0.00916054, 0.00705812}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0 0.618034 [
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .12361 -18 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -18 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -18 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -18 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -47.0938 0 ]
[.5 .63053 47.0938 20.6875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .12361 m
.03006 .12361 L
s
[(0.2)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(0.4)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(0.6)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(0.8)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0309 m
.02756 .0309 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .58713 m
.02756 .58713 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -108.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 17.438 moveto
(@) show
78.062 11.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
76.750 17.438 moveto
(\\200\\200) show
81.000 17.438 moveto
(\\200) show
83.062 17.438 moveto
(\\200) show
78.062 23.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
87.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
93.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
99.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.188 17.438 moveto
(D) show
117.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
123.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.188 17.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
135.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
153.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .00679 L
.10458 .01405 L
.14415 .02062 L
.18221 .02662 L
.22272 .03254 L
.26171 .03769 L
.30316 .04249 L
.34309 .04635 L
.3815 .04932 L
.40095 .05053 L
.42237 .0516 L
.44268 .05239 L
.45178 .05267 L
.46172 .05291 L
.4671 .05303 L
.4721 .05311 L
.47727 .05319 L
.48196 .05325 L
.48658 .05329 L
.49093 .05332 L
.49332 .05333 L
.49552 .05334 L
.49667 .05335 L
.49794 .05335 L
.49926 .05335 L
.50049 .05335 L
.50175 .05335 L
.50239 .05335 L
.50309 .05335 L
.50433 .05334 L
.50549 .05334 L
.50811 .05333 L
.51094 .05331 L
.5161 .05327 L
.52084 .05322 L
.52988 .05308 L
.5394 .05289 L
.55914 .05233 L
.57751 .05161 L
.61655 .04945 L
.65805 .04625 L
.69803 .04236 L
.7365 .03791 L
.77742 .03253 L
.81682 .02677 L
.85471 .02081 L
.89505 .01411 L
.93387 .00743 L
.97515 .00018 L
Mistroke
.97619 0 L
Mfstroke
1 0 0 r
[ .05 .05 ] 0 setdash
.02381 0 m
.06244 .00666 L
.10458 .0138 L
.14415 .02026 L
.18221 .02616 L
.22272 .03197 L
.26171 .03704 L
.30316 .04175 L
.34309 .04555 L
.3815 .04846 L
.40095 .04964 L
.42237 .0507 L
.44268 .05148 L
.45178 .05175 L
.46172 .05199 L
.4671 .0521 L
.4721 .05219 L
.47727 .05227 L
.48196 .05232 L
.48658 .05236 L
.4887 .05238 L
.49093 .05239 L
.49332 .0524 L
.49438 .0524 L
.49552 .05241 L
.49675 .05241 L
.49789 .05241 L
.49859 .05241 L
.49925 .05241 L
.50049 .05241 L
.50163 .05241 L
.50286 .05241 L
.50401 .05241 L
.50508 .05241 L
.50754 .0524 L
.51014 .05238 L
.51268 .05237 L
.51504 .05235 L
.5204 .05229 L
.5293 .05217 L
.53882 .05198 L
.54906 .05173 L
.56016 .05138 L
.58032 .05058 L
.62123 .04828 L
.66064 .04522 L
.69852 .04157 L
.73886 .03697 L
.77769 .03192 L
.81897 .02598 L
Mistroke
.85873 .0198 L
.89697 .01354 L
.93767 .00664 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00I?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd0=oooool4o`000003oa0@4?oooooooooo03Gooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03Kooooo1Ol0
000[ooooo`00I?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo03Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0eooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0:oooool006Cooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Gooooo00?oV9RHob4Q8Oo^k^h0
;?ooool006Cooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo03Sooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03Oooooo
00?oV9RHob4Q8Oo^k^h0:oooool006Cooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0>Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`03ogMgMomVIVKooooo02[ooooo001Tooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
02Wooooo001Tooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hoooo
o`05o`000?nj^[[ooooooiRHV?l@4100:oooool006Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co0000>?ooool00omEEEGoIVIVo`00000iooooo`03oeEEEOmVIVKo000000gooooo1?l0000g
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03oooool3o`000003oa0@4?oooooooooo01Kooooo003o
ooooodoooooo00?o410@okZj^_ooool05oooool00?ooooooCoooool00onHV9So<S8booooo`0Goooo
o`00oooooom?ooooo`03omgMgOl0003o^[Zj01Oooooo003oooooodoooooo00?oEEEEogMgMom4A4@0
5oooool00?ooooooC_ooool01OoMgMgo410@oooooolQ8B7ogMgM01Kooooo000Tooooo`Ko00001?oo
003oo`0000[o00000ooo0009o`0000[ooooo00GoIVIVohN7QoooooooV9RHoeEEE@0Fooooo`00:_oo
ool01?l0003oooooooooooooool5ool000Gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooooooo1Ooo00001Ol0003o
oooooooooooooooo0000013ooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`0Doooo
o`00:_ooool00ol0003oooooooooo`06ooooo`Koo`00=_ooool00ol0003oooooooooo`11ooooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool0<_ooool00ol0003oo`00ool00003ool000Wo
oooo00?o0000ooooooooool03_ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo
01?ooooo000Zooooo`03o`000?oooooooooo00cooooo1_l0003Xooooo`?o00000ooo000kooooo`00
:_ooool00ol0003oooooooooo`0Booooo`Ko0000g?ooool6o`00047ooooo000Zooooo`03o`000?oo
oooooooo01Sooooo0_l00004ool00=3ooooo0_oo0004o`0004Oooooo000Zooooo`03o`000?oooooo
oooo01kooooo1ooo0032ooooo`Ooo`00COooool002[ooooo00?o0000ooooooooool09?ooool00ol0
003oo`00ool00002ool00;Sooooo1_oo0002o`0005;ooooo000Zooooo`03o`000?oooooooooo02Wo
oooo2Ol0002Yooooo`Wo0000Eoooool002[ooooo0_l0000cooooo`Co00001?oo002Gooooo`?oo`00
1ol0001Pooooo`00:_ooool00ol0003oooooooooo`0jooooo`Koo`00S?ooool5ool00003o`000?oo
oooooooo06Oooooo000Zooooo`03o`000?oooooooooo043ooooo1Ooo0004o`0007cooooo1ooo0000
0ol0003oooooooooo`1/ooooo`00:_ooool00ol0003oooooooooo`19ooooo`Wo00001Ooo001Roooo
o`co0000M_ooool002[ooooo00?o0000ooooooooool0E?ooool3o`0000Ooo`000_l0001=ooooo`;o
00002?oo0002o`0008;ooooo000Zooooo`03o`000?oooooooooo05kooooo1?oo000<o`000003oooo
oooo003oo`0000?oo`00;_ooool6o`0000Ooo`00S?ooool002[ooooo00?o0000ooooooooool0K_oo
ool6o`0000[oo`003_l0000?ool000Oo0000VOooool002[ooooo00?o0000ooooooooool0ooooooll
ooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`;o0000oooooolmooooo`00
:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??oo
ool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooo
occooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0
oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooo
oooo0?oooooo??ooool002[ooooo0_l0003oooooocgooooo000Zooooo`03o`000?oooooooooo0?oo
oooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooooooo
o`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooo
ooooool0oooooollooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001Oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooo
oooo0?oooooo??ooool0013ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7o
k^k^00Kooooo0ol0003ooooooccooooo000@ooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0ooooooll
ooooo`004?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`3ooooooccooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0oooooollooooo`004?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`00
0?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool0
0ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[o
oooo0_l0003oooooocgooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o
0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zoooo
o`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00
:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??oo
ool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool2o`000?oooooo?Oooool002[o
oooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo
000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0ooooooll
ooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oo
oooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooooooo
o`3ooooooccooooo000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0003oooooooooo`3ooooo
occooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0
oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooo
oooo0?oooooo??ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooollooooo`004?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0oooooollooooo`004?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00005
ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Go0000ooooooooooooooooo`00000;
ooooo`04odA4A?oMgMgoooooo`0000Kooooo0ol0003ooooooccooooo000@ooooo`05o`000?oooooo
ooooooooool000002oooool01?oMgMgoEEEEooooool00006ooooo`03o`000?oooooooooo0?oooooo
??ooool0013ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo
00?o0000ooooooooool0oooooollooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?ok^k^odA4A?l000001_ooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05ooooo`03o`000?oooooooooo0?oooooo
??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3o
oooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooooooo
ool0oooooollooooo`00:_ooool2o`000?oooooo?Oooool002[ooooo00?o0000ooooooooool0oooo
oollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo
0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooo
ooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000
ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`;o
0000oooooolmooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oo
oooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0
003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo
00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Z
ooooo`;o0000oooooolmooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03
o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_oo
ool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool0
02[ooooo00?o0000ooooooooool0oooooollooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01Oooool00ol0003oooooooooo`3o
oooooccooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEE
ogMgMoooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Go410@
oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool3o`000?oooooo
??ooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B401Oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05o`000?ooooooooooooooool0
00002oooool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0oooooolloooo
o`004?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool01oooool00ol0
003oooooooooo`3ooooooccooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooM
gMgo410@oiRHV007ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?o0000ooooooooool0ooooooll
ooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oo
oooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool2o`000?oooooo?Ooo
ool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooo
occooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0
oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooo
oooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003o
ooooooooo`3ooooooccooooo000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0003ooooooooo
o`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooo
ooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`00
0?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool0
0ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[o
oooo0_l0003oooooocgooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o
0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zoooo
o`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00
4?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`01Oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooo
oooo0?oooooo??ooool0013ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05o`000?oooooo
ooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Gooooo0ol0003ooooooccooooo
000@ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Go
oooo00?o0000ooooooooool0oooooollooooo`004?ooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go410@okZj^_oooooo^[Zjoa0@4005ooooo`03o`000?oooooooooo0?oooooo??ooool0013o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001Oooool0
0ol0003oooooooooo`3ooooooccooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnYZJWo410@o`000?l@413oZJVY00Gooooo00?o0000ooooooooool0oooooollooooo`00:_ooool0
0ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[o
oooo00?o0000ooooooooool0oooooollooooo`00:_ooool2o`000?oooooo?Oooool002[ooooo00?o
0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zoooo
o`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00
:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??oo
ool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooo
occooooo000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo
000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0ooooooll
ooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oo
oooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooooooo
o`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo0_l0003ooooo
ocgooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0
oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooo
oooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003o
ooooooooo`3ooooooccooooo000Qooooo`Co000000?o410@ooooooooool00_ooool00ol0003ooooo
ooooo`3ooooooccooooo000Sooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oollooooo`008oooool00ol0003oooooooooo`04ooooo`?o0000oooooollooooo`008oooool00ol0
003oooooooooo`3ooooood?ooooo000Sooooo`03o`000?oooooooooo0?oooooo@oooool002?ooooo
00?o0000ooooooooool0oooooom3ooooo`008oooool00ol0003oooooooooo`3ooooood?ooooo000Q
ooooo`03oeEEEOmVIVKo00000?ooooooAOooool008kooooo1Ol0003Eooooo`00S_ooool01OnHV9So
8B4Qonk^k_ooooooA4A40=Gooooo002?ooooo`03oiRHV?lQ8B7ok^k^0=Kooooo002@ooooo`03oiRH
V?lQ8B7ok^k^0=Gooooo002Aooooo`03ogMgMomVIVKooooo0=Cooooo002Booooo`03o`000?oooooo
oooo00_ooooo0ol000000ol@413oooooooooo`32ooooo`00Q_ooool2o`0000Kooooo00Go0000okZj
^_ooooooV9RHoa0@4008ooooo`03o`000?nj^[[ooooo00Cooooo00?o410@okZj^_ooool01Oooool0
0ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2Uooooo`00Q_ooool00ol0
003oooooooooo`05ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`02?ooool2oc8b<PGooooo00?oV9RH
oc8b<_ooool01Oooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<ZKooooo001koooo
o`05oa0@4?l0003o0000o`000?l@41001_ooool00ol0003oooooooooo`0Booooo`03ohN7Qol0003o
^[Zj00Cooooo00?ogMgMo`000?nj^[X01Oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o
0000odA4A?nj^[X01?ooool00ol0003oooooooooo`03ooooo`03ohN7Qol0003o^[Zj00Gooooo00Go
V9RHo`000?l0003oA4A4okZj^P09ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c01mooooo`00OOooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01;ooooo00?oc<c<o`000?l@41001?ooool00omEEEGoMgMgodA4A005ooooo`03
olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo
00?ooooo00?oc<c<o`000?l@41001Oooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00000_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ
8B40OOooool007gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`[o0000
2oooool01OoMgMgo410@oooooolQ8B7ogMgM00_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool00000OOooool007gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Hooooo`05ofIVI_n7QhOooooooiRHV?mEEED02oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool6o`0000;ooooo00Go0000
ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80OOooool007gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Gooooo`03onk^k_l0003ok^k^00;ooooo00?o
0000omgMgOooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o
0000olc<c01mooooo`00N_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool05oooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo
00Kooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo00Wooooo00?o410@o`00
0?l000000ol0000:ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj
^[[o410@07gooooo001jooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonj^[[o000007gooooo001jooooo`Oo00001Oooool2o`0000Oooooo1?l000000ol@413ooooo
ooooo`0Kooooo`03o`000?oooooooooo00Gooooo0_l0000=ooooo`03o`000?oooooooooo00_ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0OOooool0097o
oooo00?o0000ooooooooool0e?ooool0097ooooo00?o0000ooooooooool0e?ooool0097ooooo00?o
0000ooooooooool0e?ooool0097ooooo00?o0000ooooooooool0e?ooool0097ooooo00?o0000oooo
ooooool0e?ooool0097ooooo00?o0000ooooooooool0e?ooool008oooooo00?oEEEEofIVI_l00000
e_ooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.313969, -0.0837537, \
0.00916054, 0.00705812}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0 0.618034 [
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .12361 -18 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -18 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -18 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -18 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -47.0938 0 ]
[.5 .63053 47.0938 20.6875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .12361 m
.03006 .12361 L
s
[(0.2)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(0.4)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(0.6)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(0.8)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0309 m
.02756 .0309 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .58713 m
.02756 .58713 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -108.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 17.438 moveto
(@) show
78.062 11.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
76.750 17.438 moveto
(\\200\\200) show
81.000 17.438 moveto
(\\200) show
83.062 17.438 moveto
(\\200) show
78.062 23.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
87.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
93.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
99.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.188 17.438 moveto
(D) show
117.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
123.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.188 17.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
135.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
153.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .005 L
.10458 .01034 L
.14415 .01518 L
.18221 .0196 L
.22272 .02396 L
.26171 .02775 L
.30316 .03128 L
.34309 .03413 L
.3815 .03631 L
.40095 .0372 L
.42237 .03799 L
.44268 .03857 L
.45178 .03877 L
.46172 .03896 L
.4671 .03904 L
.4721 .03911 L
.47727 .03916 L
.48196 .0392 L
.48658 .03924 L
.49093 .03926 L
.49332 .03927 L
.49552 .03927 L
.49667 .03927 L
.49794 .03928 L
.49926 .03928 L
.50049 .03928 L
.50175 .03928 L
.50239 .03928 L
.50309 .03928 L
.50433 .03927 L
.50549 .03927 L
.50811 .03926 L
.51094 .03925 L
.5161 .03922 L
.52084 .03918 L
.52988 .03908 L
.5394 .03894 L
.55914 .03853 L
.57751 .038 L
.61655 .03641 L
.65805 .03405 L
.69803 .03119 L
.7365 .02791 L
.77742 .02395 L
.81682 .01971 L
.85471 .01532 L
.89505 .01039 L
.93387 .00547 L
.97515 .00014 L
Mistroke
.97619 0 L
Mfstroke
1 0 0 r
[ .05 .05 ] 0 setdash
.02381 0 m
.06244 .00489 L
.10458 .01014 L
.14415 .01489 L
.18221 .01921 L
.22272 .02349 L
.26171 .02721 L
.30316 .03067 L
.34309 .03346 L
.3815 .0356 L
.40095 .03647 L
.42237 .03725 L
.44268 .03782 L
.45178 .03802 L
.46172 .0382 L
.4671 .03828 L
.4721 .03834 L
.47727 .03839 L
.48196 .03843 L
.48658 .03846 L
.4887 .03848 L
.49093 .03849 L
.49332 .03849 L
.49438 .0385 L
.49552 .0385 L
.49675 .0385 L
.49789 .0385 L
.49859 .0385 L
.49925 .0385 L
.50049 .0385 L
.50163 .0385 L
.50286 .0385 L
.50401 .0385 L
.50508 .0385 L
.50754 .03849 L
.51014 .03848 L
.51268 .03847 L
.51504 .03845 L
.5204 .03842 L
.5293 .03832 L
.53882 .03819 L
.54906 .038 L
.56016 .03775 L
.58032 .03716 L
.62123 .03546 L
.66064 .03322 L
.69852 .03054 L
.73886 .02716 L
.77769 .02345 L
.81897 .01909 L
Mistroke
.85873 .01455 L
.89697 .00995 L
.93767 .00488 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00I?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd0=oooool4o`000003oa0@4?oooooooooo03Gooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03Kooooo1Ol0
000[ooooo`00I?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo03Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0eooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0:oooool006Cooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Gooooo00?oV9RHob4Q8Oo^k^h0
;?ooool006Cooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo03Sooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03Oooooo
00?oV9RHob4Q8Oo^k^h0:oooool006Cooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0>Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`03ogMgMomVIVKooooo02[ooooo001Tooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
02Wooooo001Tooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hoooo
o`05o`000?nj^[[ooooooiRHV?l@4100:oooool006Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co0000>?ooool00omEEEGoIVIVo`00000iooooo`03oeEEEOmVIVKo000000gooooo1?l0000g
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03oooool3o`000003oa0@4?oooooooooo01Kooooo003o
ooooodoooooo00?o410@okZj^_ooool05oooool00?ooooooCoooool00onHV9So<S8booooo`0Goooo
o`00oooooom?ooooo`03omgMgOl0003o^[Zj01Oooooo003oooooodoooooo00?oEEEEogMgMom4A4@0
5oooool00?ooooooC_ooool01OoMgMgo410@oooooolQ8B7ogMgM01Kooooo000Tooooo`Oo00001_oo
003oo`0000Go00001Ooo0009o`0000[ooooo00GoIVIVohN7QoooooooV9RHoeEEE@0Fooooo`00:_oo
ool00ol0003oooooooooo`04ooooo`Ooo`0000?o0000ooooooooool02oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00_ooooo1ooo0003o`0000?ooooo00?o0000ooooooooool03_oo
ool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo01Cooooo000Zooooo`03o`000?oooooo
oooo00_ooooo0_oo0005o`00033ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`11
ooooo`03o`000?oooooooooo033ooooo00Co0000ool00?oo003oo`001?l00009ooooo`03o`000?oo
oooooooo00kooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Cooooo`00:_oo
ool00ol0003oooooooooo`0Booooo`Wo0000e_ooool<o`0003kooooo000Zooooo`03o`000?oooooo
oooo01[ooooo3?oo0032ooooo`Woo`00B_ooool002[ooooo00?o0000ooooooooool09?ooool2o`00
00Coo`00^?ooool6ool00003o`000?oooooooooo053ooooo000Zooooo`03o`000?oooooooooo02Wo
oooo2Ol0002Yooooo`Wo0000Eoooool002[ooooo00?o0000ooooooooool0<_ooool5o`0000Ooo`00
TOooool6ool000Ko0000H?ooool002[ooooo00?o0000ooooooooool0?Oooool00ol0003oo`00ool0
0006ool000?o0000O?ooool00ol0003oo`00ool00007ool00003o`000?oooooooooo06Wooooo000Z
ooooo`;o0000B_ooool:o`0000Coo`00F?ooool:ool000co0000M_ooool002[ooooo00?o0000oooo
ooooool0E?ooool3o`0000coo`001Ol0000jooooo`Oo00001_oo000:o`0008;ooooo000Zooooo`03
o`000?oooooooooo06Sooooo2?l0000?ool000ko00003ooo0006o`0009Wooooo000Zooooo`03o`00
0?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool0
0ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[o
oooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo
000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zoooo
o`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00
:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??oo
ool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooo
occooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo0_l0003oooooocgooooo
000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0ooooooll
ooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oo
oooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`004?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool00ol0003oooooooooo`3ooooooccooooo
000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A005ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooooccooooo000@ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo0?oo
oooo??ooool0013ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Co
oooo00?o0000ooooooooool0oooooollooooo`004?ooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooo
ooooool0oooooollooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooo
ooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`00
0?oooooooooo0?oooooo??ooool002[ooooo0_l0003oooooocgooooo000Zooooo`03o`000?oooooo
oooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003o
ooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o
0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zoooo
o`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00
:_ooool2o`000?oooooo?Oooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool0
0ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[o
oooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo
000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0ooooooll
ooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`;o0000oooooolmooooo`00
:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??oo
ool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooo
occooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000oooooooo
ool0oooooollooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooollooooo`004?ooool01Ol@413ooooo
oooooooooooo410@00_ooooo1Ol00005ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo0ol0003ooooo
occooooo000@ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00006
ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000000Kooooo00?o0000ooooooooool0oooooollooooo`004?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001_ooool00ol0003oooooooooo`3o
oooooccooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05
ooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooolloooo
o`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo
??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool2o`000?oooooo?Oooool0
02[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3oooooocco
oooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooo
oollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo
0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooo
ooooo`3ooooooccooooo000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0003oooooooooo`3o
oooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooooooo
ool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oo
oooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0
003oooooooooo`3ooooooccooooo000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0003ooooo
ooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000
ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03
o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`004?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<
c<`01Oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo
0?oooooo??ooool0013ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooo
ooooool000001Oooool3o`000?oooooo??ooool0013ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B401Oooool00ol0003oooooooooo`3ooooooccooooo000@
ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo
00?o0000ooooooooool0oooooollooooo`004?ooool01Ol@413ooooooooooooooooo410@00_ooooo
00?oEEEEohN7Qoooool01oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV007ooooo`03o`000?oooooooooo0?oooooo
??ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Go
oooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo
000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0ooooooll
ooooo`00:_ooool2o`000?oooooo?Oooool002[ooooo00?o0000ooooooooool0oooooollooooo`00
:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??oo
ool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooo
occooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0
oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`;o0000oooooolm
ooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oo
oooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooooooo
o`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooo
ooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`00
0?oooooooooo0?oooooo??ooool002[ooooo0_l0003oooooocgooooo000Zooooo`03o`000?oooooo
oooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003o
ooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o
0000ooooooooool0oooooollooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3ooooooccooooo
000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@05ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`3ooooo
occooooo000@ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b00Gooooo0ol0003ooooooccooooo000@ooooo`05o`000?ooooooooooooooool000002oooool0
1Oo<c<co0000o`000?l0003oc<c<00Gooooo00?o0000ooooooooool0oooooollooooo`004?ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4005ooooo`03o`00
0?oooooooooo0?oooooo??ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l000001Oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Gooooo00?o0000oooo
ooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`00
0?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool2
o`000?oooooo?Oooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003o
ooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o
0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zoooo
o`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00
:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`;o0000oooooolmooooo`00:_ooool0
0ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[o
oooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo
000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0ooooooll
ooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oo
oooo??ooool002[ooooo0_l0003oooooocgooooo000Zooooo`03o`000?oooooooooo0?oooooo??oo
ool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooo
occooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0
oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Qooooo`Co000000?o410@
ooooooooool00_ooool00ol0003oooooooooo`3ooooooccooooo000Sooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooollooooo`008oooool00ol0003oooooooooo`04ooooo`?o
0000oooooollooooo`008oooool00ol0003oooooooooo`3ooooood?ooooo000Sooooo`03o`000?oo
oooooooo0?oooooo@oooool002?ooooo00?o0000ooooooooool0oooooom3ooooo`008oooool00ol0
003oooooooooo`3ooooood?ooooo000Qooooo`03oeEEEOmVIVKo00000?ooooooAOooool008kooooo
1Ol0003Eooooo`00S_ooool01OnHV9So8B4Qonk^k_ooooooA4A40=Gooooo002?ooooo`03oiRHV?lQ
8B7ok^k^0=Kooooo002@ooooo`03oiRHV?lQ8B7ok^k^0=Gooooo002Aooooo`03ogMgMomVIVKooooo
0=Cooooo002Booooo`03o`000?oooooooooo00_ooooo0ol000000ol@413oooooooooo`32ooooo`00
Q_ooool2o`0000Kooooo00Go0000okZj^_ooooooV9RHoa0@4008ooooo`03o`000?nj^[[ooooo00Co
oooo00?o410@okZj^_ooool01Oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o
^[Zjooooo`2Uooooo`00Q_ooool00ol0003oooooooooo`05ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`02?ooool2oc8b<PGooooo00?oV9RHoc8b<_ooool01Oooool2oc8b<Pkooooo00?o0000oooooooo
ool00oooool2oc8b<ZKooooo001kooooo`05oa0@4?l0003o0000o`000?l@41001_ooool00ol0003o
ooooooooo`0Booooo`03ohN7Qol0003o^[Zj00Cooooo00?ogMgMo`000?nj^[X01Oooool00on7QhOo
0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`03oooo
o`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Co410@o`000?m4A4Coc<c<O_ooool007gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03olc<c?l0003o410@00Cooooo00?o
EEEEogMgMom4A4@01Oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@4100
1?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko410@okZj^_o^k^ko
MgMgoa0@4?ooool6o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool0
0onHV9So410@omgMg@1mooooo`00OOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00?ooooo2_l0000;ooooo`05omgMgOl@413oooooob4Q8OoMgMd02oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooo
oooo410@00kooooo00?oQhN7oeEEEOooool0O?ooool007gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Hooooo`05ofIVI_n7QhOooooooiRHV?mEEED02oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool6o`0000;ooooo00Go
0000ooooooooooooooooo`00000;ooooo`05olc<c?lQ8B7o0000oeEEEOl00000OOooool007gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Gooooo`03onk^k_l0003ok^k^00;ooooo
00?o0000omgMgOooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000_ooooo00Go8B4QohN7Qooo
ooooV9RHo`00001mooooo`00N_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool05oooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooo
oooo00Kooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo00Wooooo00?o410@
o`000?l000000ol0000:ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000007gooooo001jooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OlQ8B7o
V9RHoooooomgMgOoEEEE07gooooo001jooooo`Oo00001Oooool2o`0000Oooooo1?l000000ol@413o
ooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo0_l0000=ooooo`03o`000?oooooooooo00_o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05olc<c?l@413o0000oc8b<_o^k^h0OOooool0
097ooooo00?o0000ooooooooool0e?ooool0097ooooo00?o0000ooooooooool0e?ooool0097ooooo
00?o0000ooooooooool0e?ooool0097ooooo00?o0000ooooooooool0e?ooool0097ooooo00?o0000
ooooooooool0e?ooool0097ooooo00?o0000ooooooooool0e?ooool008oooooo00?oEEEEofIVI_l0
0000e_ooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.313969, -0.0837537, \
0.00916054, 0.00705812}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0 0.618034 [
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .12361 -18 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -18 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -18 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -18 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -44.0938 0 ]
[.5 .63053 44.0938 20.6875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .12361 m
.03006 .12361 L
s
[(0.2)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(0.4)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(0.6)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(0.8)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0309 m
.02756 .0309 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .58713 m
.02756 .58713 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -105.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 17.438 moveto
(@) show
78.062 11.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
76.750 17.438 moveto
(\\200\\200) show
81.000 17.438 moveto
(\\200) show
83.062 17.438 moveto
(\\200) show
78.062 23.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
87.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
93.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
99.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.188 17.438 moveto
(D) show
117.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
123.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.188 17.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
135.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
147.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .00368 L
.10458 .00762 L
.14415 .01118 L
.18221 .01443 L
.22272 .01764 L
.26171 .02043 L
.30316 .02303 L
.34309 .02512 L
.3815 .02673 L
.40095 .02739 L
.42237 .02797 L
.44268 .0284 L
.45178 .02855 L
.46172 .02868 L
.4671 .02874 L
.4721 .02879 L
.47727 .02883 L
.48196 .02886 L
.48658 .02889 L
.49093 .0289 L
.49332 .02891 L
.49552 .02891 L
.49667 .02892 L
.49794 .02892 L
.49926 .02892 L
.50049 .02892 L
.50175 .02892 L
.50239 .02892 L
.50309 .02892 L
.50433 .02891 L
.50549 .02891 L
.50811 .02891 L
.51094 .0289 L
.5161 .02887 L
.52084 .02885 L
.52988 .02877 L
.5394 .02867 L
.55914 .02836 L
.57751 .02797 L
.61655 .0268 L
.65805 .02507 L
.69803 .02296 L
.7365 .02055 L
.77742 .01763 L
.81682 .01451 L
.85471 .01128 L
.89505 .00765 L
.93387 .00403 L
.97515 .0001 L
Mistroke
.97619 0 L
Mfstroke
1 0 0 r
[ .05 .05 ] 0 setdash
.02381 0 m
.06244 .00359 L
.10458 .00745 L
.14415 .01094 L
.18221 .01412 L
.22272 .01725 L
.26171 .01999 L
.30316 .02253 L
.34309 .02458 L
.3815 .02615 L
.40095 .02679 L
.42237 .02736 L
.44268 .02778 L
.45178 .02793 L
.46172 .02806 L
.4671 .02812 L
.4721 .02816 L
.47727 .0282 L
.48196 .02823 L
.48658 .02826 L
.4887 .02826 L
.49093 .02827 L
.49332 .02828 L
.49438 .02828 L
.49552 .02828 L
.49675 .02828 L
.49789 .02828 L
.49859 .02828 L
.49925 .02828 L
.50049 .02828 L
.50163 .02828 L
.50286 .02828 L
.50401 .02828 L
.50508 .02828 L
.50754 .02828 L
.51014 .02827 L
.51268 .02826 L
.51504 .02825 L
.5204 .02822 L
.5293 .02815 L
.53882 .02805 L
.54906 .02791 L
.56016 .02773 L
.58032 .0273 L
.62123 .02605 L
.66064 .02441 L
.69852 .02243 L
.73886 .01995 L
.77769 .01722 L
.81897 .01402 L
Mistroke
.85873 .01069 L
.89697 .00731 L
.93767 .00358 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00I?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd0=oooool4o`000003oa0@4?oooooooooo03Gooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03Kooooo1Ol0
000[ooooo`00I?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo03Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0eooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0:oooool006Cooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Gooooo00?oV9RHob4Q8Oo^k^h0
;?ooool006Cooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo03Sooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03Oooooo
00?oV9RHob4Q8Oo^k^h0:oooool006Cooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0>Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`03ogMgMomVIVKooooo02[ooooo001Tooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
02Wooooo001Tooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hoooo
o`05o`000?nj^[[ooooooiRHV?l@4100:oooool006Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co0000>?ooool00omEEEGoIVIVo`00000iooooo`03oeEEEOmVIVKo000000gooooo1?l0000g
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03oooool3o`000003oa0@4?oooooooooo01Kooooo003o
ooooodoooooo00?o410@okZj^_ooool05oooool00?ooooooCoooool00onHV9So<S8booooo`0Goooo
o`00oooooom?ooooo`03omgMgOl0003o^[Zj01Oooooo003oooooodoooooo00?oEEEEogMgMom4A4@0
5oooool00?ooooooC_ooool01OoMgMgo410@oooooolQ8B7ogMgM01Kooooo000Tooooo`Oo00001_oo
003oo`0000Go00001_oo0008o`0000[ooooo00GoIVIVohN7QoooooooV9RHoeEEE@0Fooooo`00:_oo
ool00ol0003oooooooooo`04ooooo`[oo`0000?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Oooooo0_l00009ool000Kooooo00?o0000ooooooooool03_oo
ool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo01Cooooo000Zooooo`03o`000?oooooo
oooo00oooooo3?l0000Wooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`0Tooooo`co00004Oooool00ol0003oooooooooo`0>ooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool04oooool002[ooooo00?o0000ooooooooool06oooool;
ool00003o`000?oooooooooo0;gooooo0_l00009ool004[ooooo000Zooooo`03o`000?oooooooooo
02Kooooo1?oo0008o`000:Wooooo1ol00006ool005?ooooo000Zooooo`03o`000?oooooooooo03;o
oooo1Ol00007ool009;ooooo1_oo0005o`00063ooooo000Zooooo`03o`000?oooooooooo03gooooo
00?o0000ool00?oo00001ooo0002o`0007cooooo0_l00009ool006_ooooo000Zooooo`03o`000?oo
oooooooo04Wooooo2ol0000?ool004Oooooo3ooo000<o`0007Kooooo000Zooooo`03o`000?oooooo
oooo063ooooo4Ol0000?ool000go00004?oo000@o`0008kooooo000Zooooo`;o0000oooooolmoooo
o`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo
??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3o
oooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooooooo
ool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oo
oooooooo0?oooooo??ooool002[ooooo0_l0003oooooocgooooo000Zooooo`03o`000?oooooooooo
0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooo
ooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000
ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03
o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_oo
ool2o`000?oooooo?Oooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0
003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo
00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00005ooooo`03o`000?oo
oooooooo0?oooooo??ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000ooooooooool0oooooollooooo`004?oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?oooooo
??ooool0013ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo
00?o0000ooooooooool0oooooollooooo`004?ooool01Ol0003ooooooooooooooooo000000kooooo
00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
??ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41001Oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0oooooolloooo
o`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo
??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool2o`000?oooooo?Oooool0
02[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3oooooocco
oooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooo
oollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo
0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooo
ooooo`3ooooooccooooo000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0003oooooooooo`3o
oooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooooooo
ool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oo
oooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0
003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo
0_l0003oooooocgooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000
ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03
o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`004?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooooccooooo
000@ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o0000ooooooooool0
oooooollooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo
00001_ooool3o`000?oooooo??ooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooollooooo`004?ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003oooooooooo`3ooooo
occooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000006oooo
o`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=oooo
o`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003o
ooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o
0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zoooo
o`;o0000oooooolmooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`00
0?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool0
0ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[o
oooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo
000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo0_l0003oooooocgooooo000Zoooo
o`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00
:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??oo
ool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooo
occooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo0_l0003oooooocgooooo
000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0ooooooll
ooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oo
oooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooooooo
o`3ooooooccooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Go
k^k^oc8b<_l0003o410@olc<c005ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Go
oooo00?o0000ooooooooool0oooooollooooo`004?ooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go0000ooooooooooooooooo`000005ooooo`?o0000oooooollooooo`004?ooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooo
oooo0?oooooo??ooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo
0000oa0@4?o<c<`01Oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05oa0@4?oooooo
ooooooooool@41002oooool00omEEEGoQhN7ooooo`07ooooo`03o`000?oooooooooo0?oooooo??oo
ool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Oooooo00?o
0000ooooooooool0oooooollooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Co
c<c<odA4A?l0003o410@1Oooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oo
oooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0
003oooooooooo`3ooooooccooooo000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0003ooooo
ooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000
ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03
o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_oo
ool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool0
02[ooooo0_l0003oooooocgooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo
00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Z
ooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooolloooo
o`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo
??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool2o`000?oooooo?Oooool0
02[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3oooooocco
oooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooo
oollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c005ooooo`03o`000?oo
oooooooo0?oooooo??ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OlQ8B7oV9RHoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0oooooollooooo`004?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo0?oooooo??ooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
oc8b<_nHV9SooooooiRHV?lb<S801Oooool3o`000?oooooo??ooool0013ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01Oooool00ol0003oooooooooo`3o
oooooccooooo000@ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj
^[[o410@00Gooooo00?o0000ooooooooool0oooooollooooo`004?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000005ooooo`03o`000?oooooooooo0?oooooo
??ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT01Oooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo
??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3o
oooooccooooo000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0003oooooooooo`3oooooocco
oooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooo
oollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo
0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooo
ooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo0_l0003o
ooooocgooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooooooo
ool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oo
oooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0
003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo
00?o0000ooooooooool0oooooollooooo`00:_ooool2o`000?oooooo?Oooool002[ooooo00?o0000
ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03
o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_oo
ool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool0
027ooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo??ooool002?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooooccooooo000Sooooo`03o`00
0?oooooooooo00Cooooo0ol0003ooooooccooooo000Sooooo`03o`000?oooooooooo0?oooooo@ooo
ool002?ooooo00?o0000ooooooooool0oooooom3ooooo`008oooool00ol0003oooooooooo`3ooooo
od?ooooo000Sooooo`03o`000?oooooooooo0?oooooo@oooool0027ooooo00?oEEEEofIVI_l00000
oooooom5ooooo`00T_ooool5o`000=7ooooo002Booooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0dOoo
ool009?ooooo00?oV9RHob4Q8Oo^k^h0d_ooool009Cooooo00?oV9RHob4Q8Oo^k^h0dOooool009Go
oooo00?oMgMgofIVI_ooool0d?ooool009Kooooo00?o0000ooooooooool02oooool3o`000003oa0@
4?oooooooooo0;kooooo002:ooooo`;o00001_ooool01Ol0003o^[ZjoooooonHV9So410@00Oooooo
00?o0000okZj^_ooool01Oooool00ol@413o^[Zjooooo`04ooooo`03o`000?nj^[[ooooo00cooooo
0_l00006ooooo`03o`000?nj^[[ooooo0:7ooooo002:ooooo`03o`000?oooooooooo00Gooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c007ooooo`;o<S8b1_ooool00onHV9So<S8booooo`04ooooo`;o<S8b
3_ooool00ol0003oooooooooo`04ooooo`;o<S8bX_ooool007oooooo00Go410@o`000?l0003o0000
oa0@4006ooooo`03o`000?oooooooooo017ooooo00?oQhN7o`000?nj^[X01Oooool00ooMgMgo0000
okZj^P04ooooo`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03
o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj
00[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4QPoooool0087ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Aooooo`03olc<c?l0003o410@00Gooooo00?oEEEEogMgMom4
A4@01?ooool00oo<c<co0000oa0@4005ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0
003oooooooooo`04ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4002
ooooo`Ko00001?ooool00ol0003oooooooooo`04ooooo`;o8B4QPoooool0087ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`_o00002oooool01OoMgMgo410@oooooolQ8B7o
gMgM00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0ROooool0087ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Hooooo`05ofIVI_n7QhOooooooiRHV?mEEED02oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool6o`0000Cooooo00?o0000
ooooooooool0ROooool0087ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Goooo
o`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool02Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`29oooo
o`00O_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool05oooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00Kooooo00?o410@
o`000?l000000ol00004ooooo`03o`000?oooooooooo00Wooooo00?o410@o`000?l000000ol0000=
ooooo`03o`000?oooooooooo08Wooooo001nooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo08Wooooo001noooo
o`Oo00001Oooool2o`0000Oooooo1?l000000ol@413oooooooooo`0Kooooo`03o`000?oooooooooo
00Cooooo0_l0000=ooooo`03o`000?oooooooooo00cooooo00?oEEEEofIVI_l00000Roooool009Go
oooo00?o0000ooooooooool0d?ooool009Gooooo00?o0000ooooooooool0d?ooool009Gooooo00?o
0000ooooooooool0d?ooool009Gooooo00?o0000ooooooooool0d?ooool009Gooooo00?o0000oooo
ooooool0d?ooool009Gooooo00?o0000ooooooooool0d?ooool009?ooooo00?oEEEEofIVI_l00000
d_ooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.313969, -0.0837537, \
0.00916054, 0.00705812}}]
}, Closed]]
}, Open  ]],

Cell["\<\
The numerical solution (solid line) is so close to the exact \
solution (dashed line) that the two curves cannot be distinguished. \
\>", \
"Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["6.2.2 Boundary-Value Problems", "Subsubtitle",
  CellTags->{"i:29", "c:22"}],

Cell[CellGroupData[{

Cell["Direct Solution", "Section",
  CellTags->{"i:30", "c:23"}],

Cell["\<\
We now turn to the solution of time-independent boundary-value \
problems using grid techniques. The canonical example of such a problem is \
Poisson's equation in 2 dimensions,\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((\[PartialD]\^2\/\[PartialD]x\^2 + \
\[PartialD]\^2\/\[PartialD]y\^2)\) \(\[Phi](x, y)\) = \[Rho](x, y)\)]],
  ","
}], "NE2",
  CellTags->"(6.2.33)"],

Cell[TextData[{
  "\tWe first consider the problem in a rectangular box with dimensions ",
  Cell[BoxData[
      \(TraditionalForm\`L\_x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`L\_y\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " specified on the boundaries (Dirichlet boundary conditions). As before, \
we construct a grid on which we will determine \[Phi], at positions"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(x\_j\), "=", " ", 
          RowBox[{"j", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0, 1, 2,  ... , M\_x\)]],
  ",\n",
  Cell[BoxData[
      FormBox[
        RowBox[{\(y\_k\), "=", 
          RowBox[{"k", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["y",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`k = 0, 1, 2,  ... , M\_y\)]],
  ","
}], "UNNEQ"],

Cell[TextData[{
  "with ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "=", \(L\_x/M\_x\)}], 
        TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["y",
                FontSlant->"Italic"]}]], "=", \(L\_y/M\_y\)}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "\tOne way to solve this problem is to centered-difference the spatial \
derivatives, defining a spatial grid that turns Eq. ",
  ButtonBox["(6.2.33)",
    ButtonData:>"(6.2.33)",
    ButtonStyle->"Hyperlink"],
  " into a system of coupled linear equations:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[
              
              FormBox[\(\[Phi]\_\(j + 1\ k\) - 
                  2\ \[Phi]\_\(j\ k\) + \ \[Phi]\_\(j - 1\ k\)\),
                "TraditionalForm"], 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"]], "+", 
            FractionBox[
              
              FormBox[\(\[Phi]\_\(j\ k + 1\) - 
                  2\ \[Phi]\_\(j\ k\) + \ \[Phi]\_\(j\ k - 1\)\),
                "TraditionalForm"], 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["y",
                      FontSlant->"Italic"]}]], "2"]]}], 
          "=", \(\[Rho]\_\(j\ k\)\)}], TraditionalForm]]],
  ",     ",
  Cell[BoxData[
      \(TraditionalForm\`j = 1, 2, \(\(...\)\(\ \)\(M\_x\)\) - 1, \ \ k = 1, 
      2,  ... , M\_y\  - 1. \)]]
}], "NE2",
  CellTags->"(6.2.34)"],

Cell[TextData[{
  "These equations for the potential in the interior of the box are \
supplemented by the boundary conditions on the box edges, which directly \
determine ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(j\ k\)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j = M\_x\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(k = 0\)\(,\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k = M\_y\)]],
  "."
}], "Text"],

Cell[TextData[{
  "We can solve this problem directly using ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This  involves the solution of ",
  Cell[BoxData[
      \(TraditionalForm\`\((M\_x - 1)\) \((M\_y - 1)\)\)]],
  " simultaneous equations for the potential at the interior points. This is \
a daunting task, but let's try it anyway to see if ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "can handle it",
  StyleBox[".  ",
    FontSlant->"Italic"],
  "First, we specify the dimensions of the box and the number of grid \
points:"
}], "Text"],

Cell[BoxData[{
    \(M\_x = 10; M\_y = 10;\), "\n", 
    \(\(\(L\_x = \(L\_y = 1. \);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\[CapitalDelta]x = L\_x/M\_x; \ \[CapitalDelta]y = 
      L\_y/M\_y;\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.86"],

Cell["\<\
Next, we specify the boundary conditions. We take homogeneous \
Dirichlet conditions:\
\>", "Text"],

Cell[BoxData[{
    \(\(\[Phi][0, k_]\  = \ 0;\)\), "\n", 
    \(\(\[Phi][M\_x, k_]\  = \ 0;\)\ \), "\n", 
    \(\(\[Phi][j_, 0]\  = \ 0;\)\), "\n", 
    \(\(\[Phi][j_, M\_y]\  = \ 0;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.87"],

Cell[TextData[{
  "For the source, we choose uniform charge density, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] = 1\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(\[Rho][j_, k_]\  = \ 1;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.88"],

Cell[TextData[{
  "We are now ready to create the list of equations using Eq. ",
  ButtonBox["(6.2.34)",
    ButtonData:>"(6.2.34)",
    ButtonStyle->"Hyperlink"],
  " for the interior points:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"eqns", " ", "=", " ", 
        RowBox[{"Flatten", "[", 
          RowBox[{"Table", "[", 
            RowBox[{
              RowBox[{
                RowBox[{
                  FractionBox[
                    FormBox[
                      RowBox[{
                        RowBox[{"\[Phi]", "[", 
                          RowBox[{
                            RowBox[{
                              StyleBox["j",
                                FontSlant->"Plain"], "+", "1"}], ",", 
                            StyleBox["k",
                              FontSlant->"Plain"]}], "]"}], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{"\[Phi]", "[", 
                            RowBox[{
                              StyleBox["j",
                                FontSlant->"Plain"], ",", 
                              StyleBox["k",
                                FontSlant->"Plain"]}], "]"}]}], "+", " ", 
                        RowBox[{"\[Phi]", "[", 
                          RowBox[{
                            RowBox[{
                              StyleBox["j",
                                FontSlant->"Plain"], "-", "1"}], ",", 
                            StyleBox["k",
                              FontSlant->"Plain"]}], "]"}]}],
                      "TraditionalForm"], \(\[CapitalDelta]x\^2\)], "+", 
                  FractionBox[
                    FormBox[
                      RowBox[{
                        RowBox[{"\[Phi]", "[", 
                          RowBox[{
                            StyleBox["j",
                              FontSlant->"Plain"], ",", 
                            RowBox[{
                              StyleBox["k",
                                FontSlant->"Plain"], "+", "1"}]}], "]"}], "-",
                         
                        RowBox[{"2", " ", 
                          RowBox[{"\[Phi]", "[", 
                            RowBox[{
                              StyleBox["j",
                                FontSlant->"Plain"], ",", 
                              StyleBox["k",
                                FontSlant->"Plain"]}], "]"}]}], "+", " ", 
                        RowBox[{"\[Phi]", "[", 
                          RowBox[{
                            StyleBox["j",
                              FontSlant->"Plain"], ",", 
                            RowBox[{
                              StyleBox["k",
                                FontSlant->"Plain"], "-", "1"}]}], "]"}]}],
                      "TraditionalForm"], \(\[CapitalDelta]y\^2\)]}], 
                "\[Equal]", \(\[Rho][j, k]\)}], ",", \({j, 1, M\_x - 1}\), 
              ",", \({k, 1, M\_y - 1}\)}], "]"}], "]"}]}], ";"}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.89"],

Cell["\<\
The list of variables for which we are solving is given by the \
following command:\
\>", "Text"],

Cell[BoxData[
    \(\(vars\  = \ 
        Flatten[Table[\[Phi][j, k], {j, 1, M\_x - 1}, {k, 1, 
              M\_y - 1}]];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.90"],

Cell["Finally, we solve the equations:", "Text"],

Cell[BoxData[
    \(\(sol\  = \ \(Solve[eqns, vars]\)[\([1]\)];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.91"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is able to solve this problem quite quickly.  We can construct an \
interpolation function of the solution in the usual way:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Phi]sol\  = \ 
      Interpolation[
        Flatten[Table[{j\ \[CapitalDelta]x, 
                k\ \[CapitalDelta]y, \[Phi][j, k]}, {j, 0, M\_x}, {k, 0, 
                M\_y}] /. sol, 1]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.92"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.`, 1.`}, {0.`, 1.`}}, "<>"]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "A contour plot of the solution is shown in Cell ",
  ButtonBox["6.93",
    ButtonData:>"Cell 6.93",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ContourPlot[\[Phi]sol[x, y], {x, 0, 1}, {y, 0, 1}, 
        FrameLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotLabel \[Rule] "\<Potential inside a charge-filled square box\>"];\
\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.93"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.21154 -0.0125 -9 -9 ]
[.21154 -0.0125 9 0 ]
[.40385 -0.0125 -9 -9 ]
[.40385 -0.0125 9 0 ]
[.59615 -0.0125 -9 -9 ]
[.59615 -0.0125 9 0 ]
[.78846 -0.0125 -9 -9 ]
[.78846 -0.0125 9 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -18 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -18 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -18 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -18 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -30 -5 ]
[-0.01875 .5 -18 5 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -131 0 ]
[.5 1.0125 131 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.21154 0 m
.21154 .00625 L
s
[(0.2)] .21154 -0.0125 0 1 Mshowa
.40385 0 m
.40385 .00625 L
s
[(0.4)] .40385 -0.0125 0 1 Mshowa
.59615 0 m
.59615 .00625 L
s
[(0.6)] .59615 -0.0125 0 1 Mshowa
.78846 0 m
.78846 .00625 L
s
[(0.8)] .78846 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(1)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.5 0 m
.5 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0.2)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(0.4)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(0.6)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(0.8)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(1)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .25962 m
.00375 .25962 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .45192 m
.00375 .45192 L
s
0 .5 m
.00375 .5 L
s
0 .54808 m
.00375 .54808 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .74038 m
.00375 .74038 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -90 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10 translate
90 rotate
-66 -10 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01923 .99375 m
.01923 1 L
s
.21154 .99375 m
.21154 1 L
s
.40385 .99375 m
.40385 1 L
s
.59615 .99375 m
.59615 1 L
s
.78846 .99375 m
.78846 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.25962 .99625 m
.25962 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.45192 .99625 m
.45192 1 L
s
.5 .99625 m
.5 1 L
s
.54808 .99625 m
.54808 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.74038 .99625 m
.74038 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .5 m
1 .5 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
gsave
.5 1.0125 -192 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Potential) show
123.000 13.000 moveto
(inside) show
165.000 13.000 moveto
(a) show
177.000 13.000 moveto
(charge) show
213.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
219.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(filled) show
261.000 13.000 moveto
(square) show
303.000 13.000 moveto
(box) show
321.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.9 g
.08791 .06242 m
.15659 .04527 L
.22527 .03978 L
.29396 .03716 L
.36264 .03576 L
.43132 .03506 L
.5 .03484 L
.56868 .03506 L
.63736 .03576 L
.70604 .03716 L
.77473 .03978 L
.84341 .04527 L
.91209 .06242 L
.93758 .08791 L
.95473 .15659 L
.96022 .22527 L
.96284 .29396 L
.96424 .36264 L
.96494 .43132 L
.96516 .5 L
.96494 .56868 L
.96424 .63736 L
.96284 .70604 L
.96022 .77473 L
.95473 .84341 L
.93758 .91209 L
.91209 .93758 L
.84341 .95473 L
.77473 .96022 L
.70604 .96284 L
.63736 .96424 L
.56868 .96494 L
.5 .96516 L
.43132 .96494 L
.36264 .96424 L
.29396 .96284 L
.22527 .96022 L
.15659 .95473 L
.08791 .93758 L
.06242 .91209 L
.04527 .84341 L
.03978 .77473 L
.03716 .70604 L
.03576 .63736 L
.03506 .56868 L
.03484 .5 L
.03506 .43132 L
.03576 .36264 L
.03716 .29396 L
.03978 .22527 L
.04527 .15659 L
.06242 .08791 L
F
0 g
.08791 .06242 m
.15659 .04527 L
.22527 .03978 L
.29396 .03716 L
.36264 .03576 L
.43132 .03506 L
.5 .03484 L
.56868 .03506 L
.63736 .03576 L
.70604 .03716 L
.77473 .03978 L
.84341 .04527 L
.91209 .06242 L
.93758 .08791 L
.95473 .15659 L
.96022 .22527 L
.96284 .29396 L
.96424 .36264 L
.96494 .43132 L
.96516 .5 L
.96494 .56868 L
.96424 .63736 L
.96284 .70604 L
.96022 .77473 L
.95473 .84341 L
.93758 .91209 L
.91209 .93758 L
.84341 .95473 L
.77473 .96022 L
.70604 .96284 L
.63736 .96424 L
.56868 .96494 L
.5 .96516 L
.43132 .96494 L
.36264 .96424 L
.29396 .96284 L
.22527 .96022 L
.15659 .95473 L
.08791 .93758 L
.06242 .91209 L
.04527 .84341 L
.03978 .77473 L
.03716 .70604 L
.03576 .63736 L
.03506 .56868 L
.03484 .5 L
.03506 .43132 L
.03576 .36264 L
.03716 .29396 L
.03978 .22527 L
Mistroke
.04527 .15659 L
.06242 .08791 L
.08791 .06242 L
Mfstroke
.8 g
.15659 .08415 m
.22527 .06905 L
.29396 .06233 L
.36264 .05883 L
.43132 .05709 L
.5 .05655 L
.56868 .05709 L
.63736 .05883 L
.70604 .06233 L
.77473 .06905 L
.84341 .08415 L
.85334 .08791 L
.91209 .14666 L
.91585 .15659 L
.93095 .22527 L
.93767 .29396 L
.94117 .36264 L
.94291 .43132 L
.94345 .5 L
.94291 .56868 L
.94117 .63736 L
.93767 .70604 L
.93095 .77473 L
.91585 .84341 L
.91209 .85334 L
.85334 .91209 L
.84341 .91585 L
.77473 .93095 L
.70604 .93767 L
.63736 .94117 L
.56868 .94291 L
.5 .94345 L
.43132 .94291 L
.36264 .94117 L
.29396 .93767 L
.22527 .93095 L
.15659 .91585 L
.14666 .91209 L
.08791 .85334 L
.08415 .84341 L
.06905 .77473 L
.06233 .70604 L
.05883 .63736 L
.05709 .56868 L
.05655 .5 L
.05709 .43132 L
.05883 .36264 L
.06233 .29396 L
.06905 .22527 L
.08415 .15659 L
.08791 .14666 L
.14666 .08791 L
F
0 g
.15659 .08415 m
.22527 .06905 L
.29396 .06233 L
.36264 .05883 L
.43132 .05709 L
.5 .05655 L
.56868 .05709 L
.63736 .05883 L
.70604 .06233 L
.77473 .06905 L
.84341 .08415 L
.85334 .08791 L
.91209 .14666 L
.91585 .15659 L
.93095 .22527 L
.93767 .29396 L
.94117 .36264 L
.94291 .43132 L
.94345 .5 L
.94291 .56868 L
.94117 .63736 L
.93767 .70604 L
.93095 .77473 L
.91585 .84341 L
.91209 .85334 L
.85334 .91209 L
.84341 .91585 L
.77473 .93095 L
.70604 .93767 L
.63736 .94117 L
.56868 .94291 L
.5 .94345 L
.43132 .94291 L
.36264 .94117 L
.29396 .93767 L
.22527 .93095 L
.15659 .91585 L
.14666 .91209 L
.08791 .85334 L
.08415 .84341 L
.06905 .77473 L
.06233 .70604 L
.05883 .63736 L
.05709 .56868 L
.05655 .5 L
.05709 .43132 L
.05883 .36264 L
.06233 .29396 L
.06905 .22527 L
.08415 .15659 L
Mistroke
.08791 .14666 L
.14666 .08791 L
.15659 .08415 L
Mfstroke
.7 g
.36264 .08353 m
.43132 .0805 L
.5 .07958 L
.56868 .0805 L
.63736 .08353 L
.69188 .08791 L
.70604 .08972 L
.77473 .10216 L
.84341 .13305 L
.86695 .15659 L
.89784 .22527 L
.91028 .29396 L
.91209 .30812 L
.91647 .36264 L
.9195 .43132 L
.92042 .5 L
.9195 .56868 L
.91647 .63736 L
.91209 .69188 L
.91028 .70604 L
.89784 .77473 L
.86695 .84341 L
.84341 .86695 L
.77473 .89784 L
.70604 .91028 L
.69188 .91209 L
.63736 .91647 L
.56868 .9195 L
.5 .92042 L
.43132 .9195 L
.36264 .91647 L
.30812 .91209 L
.29396 .91028 L
.22527 .89784 L
.15659 .86695 L
.13305 .84341 L
.10216 .77473 L
.08972 .70604 L
.08791 .69188 L
.08353 .63736 L
.0805 .56868 L
.07958 .5 L
.0805 .43132 L
.08353 .36264 L
.08791 .30812 L
.08972 .29396 L
.10216 .22527 L
.13305 .15659 L
.15659 .13305 L
.22527 .10216 L
.29396 .08972 L
.30812 .08791 L
F
0 g
.36264 .08353 m
.43132 .0805 L
.5 .07958 L
.56868 .0805 L
.63736 .08353 L
.69188 .08791 L
.70604 .08972 L
.77473 .10216 L
.84341 .13305 L
.86695 .15659 L
.89784 .22527 L
.91028 .29396 L
.91209 .30812 L
.91647 .36264 L
.9195 .43132 L
.92042 .5 L
.9195 .56868 L
.91647 .63736 L
.91209 .69188 L
.91028 .70604 L
.89784 .77473 L
.86695 .84341 L
.84341 .86695 L
.77473 .89784 L
.70604 .91028 L
.69188 .91209 L
.63736 .91647 L
.56868 .9195 L
.5 .92042 L
.43132 .9195 L
.36264 .91647 L
.30812 .91209 L
.29396 .91028 L
.22527 .89784 L
.15659 .86695 L
.13305 .84341 L
.10216 .77473 L
.08972 .70604 L
.08791 .69188 L
.08353 .63736 L
.0805 .56868 L
.07958 .5 L
.0805 .43132 L
.08353 .36264 L
.08791 .30812 L
.08972 .29396 L
.10216 .22527 L
.13305 .15659 L
.15659 .13305 L
.22527 .10216 L
Mistroke
.29396 .08972 L
.30812 .08791 L
.36264 .08353 L
Mfstroke
.6 g
.22527 .1415 m
.29396 .12067 L
.36264 .11079 L
.43132 .10605 L
.5 .10463 L
.56868 .10605 L
.63736 .11079 L
.70604 .12067 L
.77473 .1415 L
.80248 .15659 L
.84341 .19752 L
.8585 .22527 L
.87933 .29396 L
.88921 .36264 L
.89395 .43132 L
.89537 .5 L
.89395 .56868 L
.88921 .63736 L
.87933 .70604 L
.8585 .77473 L
.84341 .80248 L
.80248 .84341 L
.77473 .8585 L
.70604 .87933 L
.63736 .88921 L
.56868 .89395 L
.5 .89537 L
.43132 .89395 L
.36264 .88921 L
.29396 .87933 L
.22527 .8585 L
.19752 .84341 L
.15659 .80248 L
.1415 .77473 L
.12067 .70604 L
.11079 .63736 L
.10605 .56868 L
.10463 .5 L
.10605 .43132 L
.11079 .36264 L
.12067 .29396 L
.1415 .22527 L
.15659 .19752 L
.19752 .15659 L
F
0 g
.22527 .1415 m
.29396 .12067 L
.36264 .11079 L
.43132 .10605 L
.5 .10463 L
.56868 .10605 L
.63736 .11079 L
.70604 .12067 L
.77473 .1415 L
.80248 .15659 L
.84341 .19752 L
.8585 .22527 L
.87933 .29396 L
.88921 .36264 L
.89395 .43132 L
.89537 .5 L
.89395 .56868 L
.88921 .63736 L
.87933 .70604 L
.8585 .77473 L
.84341 .80248 L
.80248 .84341 L
.77473 .8585 L
.70604 .87933 L
.63736 .88921 L
.56868 .89395 L
.5 .89537 L
.43132 .89395 L
.36264 .88921 L
.29396 .87933 L
.22527 .8585 L
.19752 .84341 L
.15659 .80248 L
.1415 .77473 L
.12067 .70604 L
.11079 .63736 L
.10605 .56868 L
.10463 .5 L
.10605 .43132 L
.11079 .36264 L
.12067 .29396 L
.1415 .22527 L
.15659 .19752 L
.19752 .15659 L
.22527 .1415 L
s
.5 g
.29396 .1565 m
.36264 .14152 L
.43132 .13451 L
.5 .13242 L
.56868 .13451 L
.63736 .14152 L
.70604 .1565 L
.70636 .15659 L
.77473 .18864 L
.81136 .22527 L
.84341 .29364 L
.8435 .29396 L
.85848 .36264 L
.86549 .43132 L
.86758 .5 L
.86549 .56868 L
.85848 .63736 L
.8435 .70604 L
.84341 .70636 L
.81136 .77473 L
.77473 .81136 L
.70636 .84341 L
.70604 .8435 L
.63736 .85848 L
.56868 .86549 L
.5 .86758 L
.43132 .86549 L
.36264 .85848 L
.29396 .8435 L
.29364 .84341 L
.22527 .81136 L
.18864 .77473 L
.15659 .70636 L
.1565 .70604 L
.14152 .63736 L
.13451 .56868 L
.13242 .5 L
.13451 .43132 L
.14152 .36264 L
.1565 .29396 L
.15659 .29364 L
.18864 .22527 L
.22527 .18864 L
.29364 .15659 L
F
0 g
.29396 .1565 m
.36264 .14152 L
.43132 .13451 L
.5 .13242 L
.56868 .13451 L
.63736 .14152 L
.70604 .1565 L
.70636 .15659 L
.77473 .18864 L
.81136 .22527 L
.84341 .29364 L
.8435 .29396 L
.85848 .36264 L
.86549 .43132 L
.86758 .5 L
.86549 .56868 L
.85848 .63736 L
.8435 .70604 L
.84341 .70636 L
.81136 .77473 L
.77473 .81136 L
.70636 .84341 L
.70604 .8435 L
.63736 .85848 L
.56868 .86549 L
.5 .86758 L
.43132 .86549 L
.36264 .85848 L
.29396 .8435 L
.29364 .84341 L
.22527 .81136 L
.18864 .77473 L
.15659 .70636 L
.1565 .70604 L
.14152 .63736 L
.13451 .56868 L
.13242 .5 L
.13451 .43132 L
.14152 .36264 L
.1565 .29396 L
.15659 .29364 L
.18864 .22527 L
.22527 .18864 L
.29364 .15659 L
.29396 .1565 L
s
.4 g
.29396 .19777 m
.36264 .17608 L
.43132 .16632 L
.5 .16345 L
.56868 .16632 L
.63736 .17608 L
.70604 .19777 L
.75105 .22527 L
.77473 .24895 L
.80223 .29396 L
.82392 .36264 L
.83368 .43132 L
.83655 .5 L
.83368 .56868 L
.82392 .63736 L
.80223 .70604 L
.77473 .75105 L
.75105 .77473 L
.70604 .80223 L
.63736 .82392 L
.56868 .83368 L
.5 .83655 L
.43132 .83368 L
.36264 .82392 L
.29396 .80223 L
.24895 .77473 L
.22527 .75105 L
.19777 .70604 L
.17608 .63736 L
.16632 .56868 L
.16345 .5 L
.16632 .43132 L
.17608 .36264 L
.19777 .29396 L
.22527 .24895 L
.24895 .22527 L
F
0 g
.29396 .19777 m
.36264 .17608 L
.43132 .16632 L
.5 .16345 L
.56868 .16632 L
.63736 .17608 L
.70604 .19777 L
.75105 .22527 L
.77473 .24895 L
.80223 .29396 L
.82392 .36264 L
.83368 .43132 L
.83655 .5 L
.83368 .56868 L
.82392 .63736 L
.80223 .70604 L
.77473 .75105 L
.75105 .77473 L
.70604 .80223 L
.63736 .82392 L
.56868 .83368 L
.5 .83655 L
.43132 .83368 L
.36264 .82392 L
.29396 .80223 L
.24895 .77473 L
.22527 .75105 L
.19777 .70604 L
.17608 .63736 L
.16632 .56868 L
.16345 .5 L
.16632 .43132 L
.17608 .36264 L
.19777 .29396 L
.22527 .24895 L
.24895 .22527 L
.29396 .19777 L
s
.3 g
.36264 .21678 m
.43132 .20253 L
.5 .19841 L
.56868 .20253 L
.63736 .21678 L
.66301 .22527 L
.70604 .2485 L
.7515 .29396 L
.77473 .33699 L
.78322 .36264 L
.79747 .43132 L
.80159 .5 L
.79747 .56868 L
.78322 .63736 L
.77473 .66301 L
.7515 .70604 L
.70604 .7515 L
.66301 .77473 L
.63736 .78322 L
.56868 .79747 L
.5 .80159 L
.43132 .79747 L
.36264 .78322 L
.33699 .77473 L
.29396 .7515 L
.2485 .70604 L
.22527 .66301 L
.21678 .63736 L
.20253 .56868 L
.19841 .5 L
.20253 .43132 L
.21678 .36264 L
.22527 .33699 L
.2485 .29396 L
.29396 .2485 L
.33699 .22527 L
F
0 g
.36264 .21678 m
.43132 .20253 L
.5 .19841 L
.56868 .20253 L
.63736 .21678 L
.66301 .22527 L
.70604 .2485 L
.7515 .29396 L
.77473 .33699 L
.78322 .36264 L
.79747 .43132 L
.80159 .5 L
.79747 .56868 L
.78322 .63736 L
.77473 .66301 L
.7515 .70604 L
.70604 .7515 L
.66301 .77473 L
.63736 .78322 L
.56868 .79747 L
.5 .80159 L
.43132 .79747 L
.36264 .78322 L
.33699 .77473 L
.29396 .7515 L
.2485 .70604 L
.22527 .66301 L
.21678 .63736 L
.20253 .56868 L
.19841 .5 L
.20253 .43132 L
.21678 .36264 L
.22527 .33699 L
.2485 .29396 L
.29396 .2485 L
.33699 .22527 L
.36264 .21678 L
s
.2 g
.36264 .26566 m
.43132 .24514 L
.5 .23945 L
.56868 .24514 L
.63736 .26566 L
.68402 .29396 L
.70604 .31598 L
.73434 .36264 L
.75486 .43132 L
.76055 .5 L
.75486 .56868 L
.73434 .63736 L
.70604 .68402 L
.68402 .70604 L
.63736 .73434 L
.56868 .75486 L
.5 .76055 L
.43132 .75486 L
.36264 .73434 L
.31598 .70604 L
.29396 .68402 L
.26566 .63736 L
.24514 .56868 L
.23945 .5 L
.24514 .43132 L
.26566 .36264 L
.29396 .31598 L
.31598 .29396 L
F
0 g
.36264 .26566 m
.43132 .24514 L
.5 .23945 L
.56868 .24514 L
.63736 .26566 L
.68402 .29396 L
.70604 .31598 L
.73434 .36264 L
.75486 .43132 L
.76055 .5 L
.75486 .56868 L
.73434 .63736 L
.70604 .68402 L
.68402 .70604 L
.63736 .73434 L
.56868 .75486 L
.5 .76055 L
.43132 .75486 L
.36264 .73434 L
.31598 .70604 L
.29396 .68402 L
.26566 .63736 L
.24514 .56868 L
.23945 .5 L
.24514 .43132 L
.26566 .36264 L
.29396 .31598 L
.31598 .29396 L
.36264 .26566 L
s
.1 g
.5 .29086 m
.54084 .29396 L
.56868 .29909 L
.63736 .33086 L
.66914 .36264 L
.70091 .43132 L
.70604 .45916 L
.70914 .5 L
.70604 .54084 L
.70091 .56868 L
.66914 .63736 L
.63736 .66914 L
.56868 .70091 L
.54084 .70604 L
.5 .70914 L
.45916 .70604 L
.43132 .70091 L
.36264 .66914 L
.33086 .63736 L
.29909 .56868 L
.29396 .54084 L
.29086 .5 L
.29396 .45916 L
.29909 .43132 L
.33086 .36264 L
.36264 .33086 L
.43132 .29909 L
.45916 .29396 L
F
0 g
.5 .29086 m
.54084 .29396 L
.56868 .29909 L
.63736 .33086 L
.66914 .36264 L
.70091 .43132 L
.70604 .45916 L
.70914 .5 L
.70604 .54084 L
.70091 .56868 L
.66914 .63736 L
.63736 .66914 L
.56868 .70091 L
.54084 .70604 L
.5 .70914 L
.45916 .70604 L
.43132 .70091 L
.36264 .66914 L
.33086 .63736 L
.29909 .56868 L
.29396 .54084 L
.29086 .5 L
.29396 .45916 L
.29909 .43132 L
.33086 .36264 L
.36264 .33086 L
.43132 .29909 L
.45916 .29396 L
.5 .29086 L
s
.5 .36246 m
.50737 .36264 L
.56868 .37907 L
.62093 .43132 L
.63736 .49263 L
.63754 .5 L
.63736 .50737 L
.62093 .56868 L
.56868 .62093 L
.50737 .63736 L
.5 .63754 L
.49263 .63736 L
.43132 .62093 L
.37907 .56868 L
.36264 .50737 L
.36246 .5 L
.36264 .49263 L
.37907 .43132 L
.43132 .37907 L
.49263 .36264 L
F
.5 .36246 m
.50737 .36264 L
.56868 .37907 L
.62093 .43132 L
.63736 .49263 L
.63754 .5 L
.63736 .50737 L
.62093 .56868 L
.56868 .62093 L
.50737 .63736 L
.5 .63754 L
.49263 .63736 L
.43132 .62093 L
.37907 .56868 L
.36264 .50737 L
.36246 .5 L
.36264 .49263 L
.37907 .43132 L
.43132 .37907 L
.49263 .36264 L
.5 .36246 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`?ooool2o`0000;ooooo0_l0002Rooooo`00`?oo
ool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgJ;ooooo0031ooooo`04omgMgOl0003o410@olc<c:?o
oooo0031ooooo`04onk^k_lQ8B7o410@onk^kZ?ooooo0031ooooo`04ob4Q8OmgMgOoMgMgoc8b<Z?o
oooo0030ooooo`;o00000_ooool2o`000:;ooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000^oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`Go00009_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o0000
00?o410@ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0;oooool4o`000003oa0@4?oooooooooo00kooooo000^
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@09_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02Gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q037ooooo00?o0000oooooooo
ool04?ooool002kooooo00Go410@oooooooooooooooooa0@400]ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00onHV9So8B4Qonk^kP0Wooooo`05oa0@4?ooooooooooooooool@41002oooool5
o`0002Gooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000
9Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000aoooo
o`03o`000?oooooooooo013ooooo000^ooooo`05o`000?ooooooooooooooool00000;Oooool01Ol0
003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h09_ooool01Ol0003ooooooooooooo
oooo000000_ooooo00CoA4A4omgMgOoooooo00009_ooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uooooo`05o`000?ooooooooooooooool000002oooool0
1Olb<S;oV9RHoooooonHV9So<S8b037ooooo00?o0000ooooooooool04?ooool002kooooo00Go0000
ooooooooooooooooo`00000]ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIV
ooooo`0Uooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000Voooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02Gooooo00Go
0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0<Oooool00ol0003o
ooooooooo`0@ooooo`00;_ooool01Ol@413ooooooooooooooooo410@02gooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo02Cooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002Kooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100<Oooool00ol0003oooooooooo`0@ooooo`00;_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41009_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_oooooo^[Zjo`00000aooooo`03o`000?oooooooooo013ooooo000^ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c00Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000
ooooo`0Uooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410Uoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY02oooooo00?o
EEEEofIVI_l000004_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool002_oooooool0000bo`0000cooooo000[ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool0ooooool^ooooo`03
o`000?oooooooooo00[ooooo000Pooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3oooooobkooooo00?o0000ooooooooool02_ooool0023ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo;_ooool00ol0003oooooooooo`0:ooooo`00
8?ooool01Ol@413ooooooooooooooooo410@00Kooooo0ol0003oooooobcooooo0ol0000<ooooo`00
8?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0ooooool^ooooo`03
o`000?oooooooooo00[ooooo000Pooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`3oooooobkooooo00?o0000ooooooooool02_ooool0023ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03o`000?oooooooooo0?oooooo;_ooool00ol0003oooooooooo`0:ooooo`00
8?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0ooooool^ooooo`03
o`000?oooooooooo00[ooooo000Pooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`1QooooofWo0000Hoooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003ooooo
ooooo`1<oooooaGo0000JOoVi^HEo`0004kooooo00?o0000ooooooooool02_ooool002_ooooo00?o
0000ooooooooool0=ooooolEo`0009?oi^KV5Ol0000iooooo`03o`000?oooooooooo00[ooooo000[
ooooo`03o`000?oooooooooo02[ooooo3Ol0002monKViPco0000;Oooool00ol0003oooooooooo`0:
ooooo`00:oooool00ol0003oooooooooo`0Wooooo`?o0000e_oVi^H3o`0002[ooooo00?o0000oooo
ooooool02_ooool002_ooooo00?o0000ooooooooool08oooool4o`000=coi^KV1?l0000Vooooo`03
o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo023ooooo0ol0003TonKViP?o0000
8oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`0Looooo`Co0000A_oV
i^IOo`0004Goi^KV1?l0000Oooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooo
oooo01Wooooo0ol0000oonKViP_o0000Goo<c<`:o`0003ooi^KV0ol0000Looooo`03o`000?oooooo
oooo00[ooooo000[ooooo`03o`000?oooooooooo01Oooooo0_l0000honKViP[o0000M?o<c<`:o`00
03Soi^KV0ol0000Iooooo`03o`000?oooooooooo00[ooooo000[ooooo`;o00005oooool00ol0003o
i^KVonKViP0]onKViP_o0000R?o<c<`;o`00033oi^KV00?o0000ooooooooool05Oooool2o`0000co
oooo000[ooooo`03o`000?oooooooooo01Gooooo00?o0000onKVi_oVi^H09_oVi^H8o`0009koc<c<
2?l0000YonKViP03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool002_ooooo00?o
0000ooooooooool05?ooool00ol0003oi^KVonKViP0RonKViPGo0000[_o<c<`5o`0002Goi^KV00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`0C
ooooo`03o`000?oVi^Koi^KV01koi^KV1Ol0002holc<c0Go00008OoVi^H00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo01;ooooo00?o0000onKV
i_oVi^H06_oVi^H5o`0004;oc<c<@?l00010olc<c0Go00007OoVi^H00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo017ooooo00?o0000onKVi_oV
i^H05ooVi^H4o`0003Coc<c<4ol00010ok>c/a;o0000<oo<c<`5o`0001Woi^KV00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oVi^Koi^KV01Koi^KV0_l0000]olc<c0_o0000IOnc/k<:o`0002koc<c<00?o0000onKVi_oVi^H0
5ooVi^H00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oo
oooooooo013ooooo00?o0000onKVi_oVi^H05OoVi^H00ol0003oc<c<olc<c00Xolc<c0Go0000N_nc
/k<5o`0002[oc<c<00?o0000onKVi_oVi^H05_oVi^H00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00[ooooo000[ooooo`03o`000?oooooooooo013ooooo00?o0000onKVi_oVi^H05?oVi^H0
0ol0003oc<c<olc<c00Tolc<c0Go0000Q?nc/k<5o`0002Koc<c<00?o0000onKVi_oVi^H05OoVi^H0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo
00oooooo00?o0000onKVi_oVi^H05?oVi^H00ol0003oc<c<olc<c00Polc<c0Go0000S_nc/k<5o`00
02;oc<c<00?o0000onKVi_oVi^H05OoVi^H00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00[ooooo000[ooooo`03o`000?oooooooooo00oooooo00?o0000onKVi_oVi^H04ooVi^H00ol0003o
c<c<olc<c00Lolc<c0Go0000V?nc/k<5o`0001koc<c<00?o0000onKVi_oVi^H05?oVi^H00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00oooooo
00?o0000onKVi_oVi^H04_oVi^H00ol0003oc<c<olc<c00Iolc<c0Co0000Aonc/k<Fo`0004Go/k>c
1?l0000Kolc<c003o`000?oVi^Koi^KV01?oi^KV00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0:ooooo`00:oooool00ol0003oooooooooo`0>ooooo`03o`000?oVi^Koi^KV01;oi^KV00?o
0000olc<c?o<c<`05oo<c<`3o`0003Ko/k>c5Ol0000FoiVIVAGo0000=?nc/k<3o`0001Woc<c<00?o
0000onKVi_oVi^H04_oVi^H00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo000[
ooooo`03o`000?oooooooooo00kooooo00?o0000onKVi_oVi^H04OoVi^H00ol0003oc<c<olc<c00F
olc<c0;o0000:onc/k<>o`00043oVIVI3Ol0000Zok>c/`;o00006?o<c<`00ol0003oi^KVonKViP0B
onKViP03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000oooo
ooooool03_ooool00ol0003oi^KVonKViP0@onKViP03o`000?o<c<coc<c<01Goc<c<0_l0000Vok>c
/`Oo0000FonIVIT7o`0002Go/k>c0_l0000Golc<c003o`000?oVi^Koi^KV017oi^KV00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0:ooooo`00:oooool2o`0000oooooo00?o0000onKVi_oV
i^H03ooVi^H00ol0003oc<c<olc<c00Colc<c0?o00008Onc/k<7o`0006WoVIVI1ol0000Pok>c/`?o
00005Oo<c<`00ol0003oi^KVonKViP0@onKViP03o`000?oooooooooo00gooooo0_l0000<ooooo`00
:oooool00ol0003oooooooooo`0=ooooo`03o`000?oVi^Koi^KV00ooi^KV00?o0000olc<c?o<c<`0
4_o<c<`2o`0001oo/k>c1Ol0001goiVIV@Go00007_nc/k<2o`0001Coc<c<00?o0000onKVi_oVi^H0
3ooVi^H00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oo
oooooooo00gooooo00?o0000onKVi_oVi^H03_oVi^H00ol0003oc<c<olc<c00Aolc<c0;o00007_nc
/k<3o`00087oVIVI0ol0000Mok>c/`;o00004oo<c<`00ol0003oi^KVonKViP0?onKViP03o`000?oo
oooooooo00gooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool03Oooool0
0ol0003oi^KVonKViP0=onKViP03o`000?o<c<coc<c<00ooc<c<0ol0000Mok>c/`?o0000QonIVIT3
o`0001co/k>c0ol0000Aolc<c003o`000?oVi^Koi^KV00koi^KV00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`0<ooooo`03o`000?oVi^Koi^KV
00goi^KV00?o0000olc<c?o<c<`03_o<c<`2o`0001go/k>c0ol0002=oiVIV@?o00007?nc/k<2o`00
013oc<c<00?o0000onKVi_oVi^H03OoVi^H00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00[ooooo000[ooooo`03o`000?oooooooooo00cooooo00?o0000onKVi_oVi^H03?oVi^H00ol0003o
c<c<olc<c00>olc<c003o`000?nc/k?o/k>c01[o/k>c0ol0000aoiVIVC;o0000<?nIVIT3o`0001_o
/k>c00?o0000olc<c?o<c<`03_o<c<`00ol0003oi^KVonKViP0<onKViP03o`000?oooooooooo00go
oooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool03?ooool00ol0003oi^KV
onKViP0;onKViP03o`000?o<c<coc<c<00koc<c<00?o0000ok>c/onc/k<06?nc/k<3o`0002goVIVI
1ol0000bogmoO`Oo0000;?nIVIT3o`0001Wo/k>c00?o0000olc<c?o<c<`03_o<c<`00ol0003oi^KV
onKViP0;onKViP03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool002_ooooo00?o
0000ooooooooool03?ooool00ol0003oi^KVonKViP0:onKViP03o`000?o<c<coc<c<00koc<c<00?o
0000ok>c/onc/k<05_nc/k<3o`0002WoVIVI1ol00010ogmoO`Oo0000:?nIVIT3o`0001Oo/k>c00?o
0000olc<c?o<c<`03_o<c<`00ol0003oi^KVonKViP0;onKViP03o`000?oooooooooo00cooooo00?o
0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool02oooool00ol0003oi^KVonKViP0:
onKViP03o`000?o<c<coc<c<00koc<c<00?o0000ok>c/onc/k<05?nc/k<3o`0002GoVIVI1ol0001>
ogmoO`Ko00009OnIVIT2o`0001Ko/k>c00?o0000olc<c?o<c<`03_o<c<`00ol0003oi^KVonKViP0:
onKViP03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000oooo
ooooool02oooool00ol0003oi^KVonKViP09onKViP03o`000?o<c<coc<c<00koc<c<00?o0000ok>c
/onc/k<04onc/k<2o`0002?oVIVI1Ol0001KogmoO`Go00008_nIVIT2o`0001Go/k>c00?o0000olc<
c?o<c<`03_o<c<`00ol0003oi^KVonKViP09onKViP03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02_ooool002_ooooo00?o0000ooooooooool02oooool00ol0003oi^KVonKViP09onKViP03
o`000?o<c<coc<c<00goc<c<00?o0000ok>c/onc/k<04_nc/k<2o`00023oVIVI1Ol0001UogmoO`Go
00007onIVIT3o`0001?o/k>c00?o0000olc<c?o<c<`03Oo<c<`00ol0003oi^KVonKViP09onKViP03
o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool0
2_ooool00ol0003oi^KVonKViP09onKViP03o`000?o<c<coc<c<00goc<c<00?o0000ok>c/onc/k<0
4Onc/k<2o`0001goVIVI1Ol0001_ogmoO`Go00007OnIVIT2o`0001;o/k>c00?o0000olc<c?o<c<`0
3Oo<c<`00ol0003oi^KVonKViP09onKViP03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2_ooool002_ooooo00?o0000ooooooooool02_ooool00ol0003oi^KVonKViP09onKViP03o`000?o<
c<coc<c<00coc<c<00?o0000ok>c/onc/k<04Onc/k<00ol0003oVIVIoiVIV@0IoiVIV@Co0000NOmo
Ogl4o`0001_oVIVI00?o0000ok>c/onc/k<04?nc/k<00ol0003oc<c<olc<c00<olc<c003o`000?oV
i^Koi^KV00Woi^KV00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`00:oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oVi^Koi^KV00Woi^KV00?o0000olc<c?o<c<`03?o<c<`0
0ol0003o/k>cok>c/`0@ok>c/`03o`000?nIVIWoVIVI01SoVIVI0_l00021ogmoO`;o00006OnIVIT0
0ol0003o/k>cok>c/`0@ok>c/`03o`000?o<c<coc<c<00coc<c<00?o0000onKVi_oVi^H02OoVi^H0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo000[ooooo`;o00002oooool00ol0
003oi^KVonKViP09onKViP03o`000?o<c<coc<c<00_oc<c<00?o0000ok>c/onc/k<04?nc/k<00ol0
003oVIVIoiVIV@0GoiVIV@;o0000>?moOglFo`0003OoOgmo0_l0000HoiVIV@03o`000?nc/k?o/k>c
013o/k>c00?o0000olc<c?o<c<`02oo<c<`00ol0003oi^KVonKViP09onKViP03o`000?oooooooooo
00[ooooo0_l0000<ooooo`00:oooool00ol0003oooooooooo`0:ooooo`03o`000?oVi^Koi^KV00Wo
i^KV00?o0000olc<c?o<c<`02oo<c<`00ol0003o/k>cok>c/`0?ok>c/`03o`000?nIVIWoVIVI01Ko
VIVI0_l0000/ogmoO`ko00005_mVIVH>o`0002_oOgmo0_l0000GoiVIV@03o`000?nc/k?o/k>c00oo
/k>c00?o0000olc<c?o<c<`03?o<c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool02_ooool00ol0003oi^KV
onKViP08onKViP03o`000?o<c<coc<c<00_oc<c<00?o0000ok>c/onc/k<03onc/k<00ol0003oVIVI
oiVIV@0EoiVIV@;o00009omoOgl7o`0003;oIVIV1ol0000VogmoO`;o00005_nIVIT00ol0003o/k>c
ok>c/`0?ok>c/`03o`000?o<c<coc<c<00_oc<c<00?o0000onKVi_oVi^H02?oVi^H00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00[ooooo00?o
0000onKVi_oVi^H02?oVi^H00ol0003oc<c<olc<c00;olc<c003o`000?nc/k?o/k>c00ko/k>c00?o
0000oiVIVOnIVIT04onIVIT3o`0002;oOgmo1ol00010ofIVIPOo00008OmoOgl2o`0001GoVIVI00?o
0000ok>c/onc/k<03_nc/k<00ol0003oc<c<olc<c00;olc<c003o`000?oVi^Koi^KV00Soi^KV00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`0:
ooooo`03o`000?oVi^Koi^KV00Soi^KV00?o0000olc<c?o<c<`02oo<c<`00ol0003o/k>cok>c/`0=
ok>c/`03o`000?nIVIWoVIVI01;oVIVI0_l0000PogmoO`Go0000C_mVIVH4o`0001ooOgmo0_l0000D
oiVIV@03o`000?nc/k?o/k>c00ko/k>c00?o0000olc<c?o<c<`02_o<c<`00ol0003oi^KVonKViP09
onKViP03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000oooo
ooooool02_ooool00ol0003oi^KVonKViP08onKViP03o`000?o<c<coc<c<00[oc<c<00?o0000ok>c
/onc/k<03Onc/k<00ol0003oVIVIoiVIV@0AoiVIV@;o00007omoOgl3o`0005OoIVIV0ol0000Nogmo
O`;o00004onIVIT00ol0003o/k>cok>c/`0=ok>c/`03o`000?o<c<coc<c<00_oc<c<00?o0000onKV
i_oVi^H02?oVi^H00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03
o`000?oooooooooo00[ooooo00?o0000onKVi_oVi^H02?oVi^H00ol0003oc<c<olc<c00:olc<c003
o`000?nc/k?o/k>c00co/k>c00?o0000oiVIVOnIVIT04?nIVIT2o`0001koOgmo0ol0001MofIVIP?o
00007OmoOgl2o`0001;oVIVI00?o0000ok>c/onc/k<03Onc/k<00ol0003oc<c<olc<c00:olc<c003
o`000?oVi^Koi^KV00Soi^KV00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`00
:oooool00ol0003oooooooooo`0:ooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<c?o<c<`0
2_o<c<`00ol0003o/k>cok>c/`0<ok>c/`03o`000?nIVIWoVIVI00ooVIVI0_l0000MogmoO`?o0000
HomVIVH3o`0001coOgmo0_l0000AoiVIV@03o`000?nc/k?o/k>c00co/k>c00?o0000olc<c?o<c<`0
2_o<c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool002_ooooo00?o0000ooooooooool02_ooool00ol0003oi^KVonKViP07onKViP03o`000?o<
c<coc<c<00[oc<c<00?o0000ok>c/onc/k<02onc/k<00ol0003oVIVIoiVIV@0?oiVIV@03o`000?mo
OgooOgmo01[oOgmo0ol0001YofIVIP?o00006omoOgl00ol0003oVIVIoiVIV@0?oiVIV@03o`000?nc
/k?o/k>c00co/k>c00?o0000olc<c?o<c<`02Oo<c<`00ol0003oi^KVonKViP08onKViP03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool02Oooool0
0ol0003oi^KVonKViP08onKViP03o`000?o<c<coc<c<00Woc<c<00?o0000ok>c/onc/k<02onc/k<0
0ol0003oVIVIoiVIV@0?oiVIV@03o`000?moOgooOgmo01SoOgmo0ol0001_ofIVIP?o00006OmoOgl0
0ol0003oVIVIoiVIV@0?oiVIV@03o`000?nc/k?o/k>c00_o/k>c00?o0000olc<c?o<c<`02_o<c<`0
0ol0003oi^KVonKViP07onKViP03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
02_ooooo00?o0000ooooooooool02Oooool00ol0003oi^KVonKViP08onKViP03o`000?o<c<coc<c<
00Woc<c<00?o0000ok>c/onc/k<02_nc/k<00ol0003oVIVIoiVIV@0?oiVIV@03o`000?moOgooOgmo
01KoOgmo0ol0001eofIVIP?o00005omoOgl00ol0003oVIVIoiVIV@0?oiVIV@03o`000?nc/k?o/k>c
00[o/k>c00?o0000olc<c?o<c<`02_o<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool02Oooool00ol0003o
i^KVonKViP08onKViP03o`000?o<c<coc<c<00Woc<c<00?o0000ok>c/onc/k<02Onc/k<00ol0003o
VIVIoiVIV@0?oiVIV@03o`000?moOgooOgmo01CoOgmo0ol0000cofIVIQKo0000<_mVIVH2o`0001Ko
Ogmo00?o0000oiVIVOnIVIT03onIVIT00ol0003o/k>cok>c/`0:ok>c/`03o`000?o<c<coc<c<00Wo
c<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03
o`000?oooooooooo00Wooooo00?o0000onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c009olc<c003
o`000?nc/k?o/k>c00[o/k>c00?o0000oiVIVOnIVIT03_nIVIT00ol0003oOgmoogmoO`0CogmoO`;o
0000:?mVIVH>o`0001KoC4a<3Ol0000WofIVIP;o00005OmoOgl00ol0003oVIVIoiVIV@0>oiVIV@03
o`000?nc/k?o/k>c00[o/k>c00?o0000olc<c?o<c<`02Oo<c<`00ol0003oi^KVonKViP07onKViP03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0013ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooo
ooooool02Oooool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00Woc<c<00?o0000ok>c
/onc/k<02Onc/k<00ol0003oVIVIoiVIV@0>oiVIV@03o`000?moOgooOgmo01?oOgmo00?o0000ofIV
I_mVIVH08omVIVH5o`00037oC4a<1Ol0000TofIVIP03o`000?moOgooOgmo01?oOgmo00?o0000oiVI
VOnIVIT03_nIVIT00ol0003o/k>cok>c/`0:ok>c/`03o`000?o<c<coc<c<00Soc<c<00?o0000onKV
i_oVi^H01ooVi^H00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo000@ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo
00Wooooo00?o0000onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c008olc<c003o`000?nc/k?o/k>c
00[o/k>c00?o0000oiVIVOnIVIT03OnIVIT00ol0003oOgmoogmoO`0BogmoO`;o00008OmVIVH5o`00
03_oC4a<1Ol0000PofIVIP;o00005?moOgl00ol0003oVIVIoiVIV@0>oiVIV@03o`000?nc/k?o/k>c
00Wo/k>c00?o0000olc<c?o<c<`02Oo<c<`00ol0003oi^KVonKViP06onKViP03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02_ooool0013ooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00Kooooo0ol00009ooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<
c?o<c<`02?o<c<`00ol0003o/k>cok>c/`09ok>c/`03o`000?nIVIWoVIVI00goVIVI00?o0000ogmo
OomoOgl04OmoOgl2o`0001koIVIV1Ol00015oda<C0Go00007OmVIVH2o`0001?oOgmo00?o0000oiVI
VOnIVIT03OnIVIT00ol0003o/k>cok>c/`0:ok>c/`03o`000?o<c<coc<c<00Soc<c<00?o0000onKV
i_oVi^H01ooVi^H00ol0003oooooooooo`07ooooo`?o00003?ooool0013ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool02Oooool00ol0
003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/onc/k<02_nc/k<00ol0
003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo013oOgmo0_l0000LofIVIPCo0000Com<C4`4o`00
01_oIVIV0_l0000BogmoO`03o`000?nIVIWoVIVI00goVIVI00?o0000ok>c/onc/k<02Onc/k<00ol0
003oc<c<olc<c008olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0:ooooo`004?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000olc<
c?o<c<`02?o<c<`00ol0003o/k>cok>c/`09ok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmo
OomoOgl04?moOgl00ol0003oIVIVofIVIP0IofIVIP?o0000Eom<C4`3o`0001[oIVIV00?o0000ogmo
OomoOgl04?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c00[o/k>c00?o0000olc<
c?o<c<`01oo<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`09ooooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000
olc<c?o<c<`02?o<c<`00ol0003o/k>cok>c/`09ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ogmoOomoOgl03omoOgl2o`0001WoIVIV0ol0001Moda<C0;o00006OmVIVH2o`00017oOgmo00?o0000
oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`09ok>c/`03o`000?o<c<coc<c<00Soc<c<00?o0000
onKVi_oVi^H01_oVi^H00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000@oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o
0000ooooooooool02Oooool00ol0003oi^KVonKViP06onKViP03o`000?o<c<coc<c<00Ooc<c<00?o
0000ok>c/onc/k<02Onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00ooOgmo00?o
0000ofIVI_mVIVH05omVIVH2o`0006;oC4a<0_l0000IofIVIP03o`000?moOgooOgmo00ooOgmo00?o
0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`09ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o
0000onKVi_oVi^H01_oVi^H00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000[
ooooo`03o`000?oooooooooo00Wooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c007
olc<c003o`000?nc/k?o/k>c00Wo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`0>
ogmoO`03o`000?mVIVKoIVIV01KoIVIV0_l0001Voda<C0;o00006?mVIVH00ol0003oOgmoogmoO`0>
ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<02Onc/k<00ol0003oc<c<olc<c007
olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:
ooooo`00:oooool00ol0003oooooooooo`09ooooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000olc<
c?o<c<`01oo<c<`00ol0003o/k>cok>c/`08ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl03_moOgl00ol0003oIVIVofIVIP0EofIVIP;o0000J_m<C4`2o`0001OoIVIV00?o0000ogmo
OomoOgl03_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c00Wo/k>c00?o0000olc<
c?o<c<`01oo<c<`00ol0003oi^KVonKViP06onKViP03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool002_ooooo00?o0000ooooooooool02Oooool00ol0003oi^KVonKViP06onKViP03
o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/onc/k<02?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00goOgmo00?o0000ofIVI_mVIVH05?mVIVH2o`0006koC4a<0_l0000FofIVIP03
o`000?moOgooOgmo00goOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`08ok>c/`03
o`000?o<c<coc<c<00Ooc<c<00?o0000onKVi_oVi^H01_oVi^H00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Wooooo00?o0000onKVi_oVi^H0
1_oVi^H00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00Wo/k>c00?o0000oiVIVOnIVIT0
2_nIVIT00ol0003oOgmoogmoO`0=ogmoO`03o`000?mVIVKoIVIV01CoIVIV00?o0000oda<C?m<C4`0
<_m<C4`;o`0003?oC4a<00?o0000ofIVI_mVIVH05?mVIVH00ol0003oOgmoogmoO`0=ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<02Onc/k<00ol0003oc<c<olc<c006olc<c003o`00
0?oVi^Koi^KV00Koi^KV00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`01_o<
c<`00ol0003o/k>cok>c/`08ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl03?mo
Ogl00ol0003oIVIVofIVIP0CofIVIP;o0000:_m<C4`;o`0000_o<c<c2ol0000Yoda<C0;o00005OmV
IVH00ol0003oOgmoogmoO`0<ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<02Onc
/k<00ol0003oc<c<olc<c006olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`09ooooo`03o`000?oVi^Ko
i^KV00Goi^KV00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>cok>c/`08ok>c/`03o`000?nIVIWo
VIVI00[oVIVI00?o0000ogmoOomoOgl03?moOgl00ol0003oIVIVofIVIP0BofIVIP;o00009Om<C4`7
o`00027o<c<c1ol0000Toda<C0;o00005?mVIVH00ol0003oOgmoogmoO`0<ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<02?nc/k<00ol0003oc<c<olc<c007olc<c003o`000?oVi^Ko
i^KV00Goi^KV00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0
003oooooooooo`09ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01oo<c<`00ol0
003o/k>cok>c/`08ok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02omoOgl00ol0
003oIVIVofIVIP0BofIVIP03o`000?m<C4coC4a<02;oC4a<0ol0000_oc<c<`?o00008om<C4`00ol0
003oIVIVofIVIP0BofIVIP03o`000?moOgooOgmo00_oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`08ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Wo
oooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o/k>c00Oo
/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`0<ogmoO`03o`000?mVIVKoIVIV017o
IVIV00?o0000oda<C?m<C4`07om<C4`4o`0003Go<c<c1?l0000Poda<C003o`000?mVIVKoIVIV017o
IVIV00?o0000ogmoOomoOgl03?moOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c00So
/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003oi^KVonKViP05onKViP03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool02Oooool00ol0003oi^KV
onKViP05onKViP03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<02?nc/k<00ol0003oVIVI
oiVIV@0:oiVIV@03o`000?moOgooOgmo00_oOgmo00?o0000ofIVI_mVIVH04OmVIVH00ol0003oC4a<
oda<C00Moda<C0?o0000?Olc<c<3o`0001koC4a<00?o0000ofIVI_mVIVH04OmVIVH00ol0003oOgmo
ogmoO`0;ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<02Onc/k<00ol0003oc<c<
olc<c006olc<c003o`000?oVi^Koi^KV00Goi^KV00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`00:oooool00ol0003oooooooooo`09ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o
0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`08ok>c/`03o`000?nIVIWoVIVI00WoVIVI00?o
0000ogmoOomoOgl03?moOgl00ol0003oIVIVofIVIP0@ofIVIP03o`000?m<C4coC4a<01[oC4a<1?l0
0013oc<c<`Co00006om<C4`00ol0003oIVIVofIVIP0AofIVIP03o`000?moOgooOgmo00_oOgmo00?o
0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`08ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o
0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000[
ooooo`;o00002Oooool00ol0003oi^KVonKViP06onKViP03o`000?o<c<coc<c<00Koc<c<00?o0000
ok>c/onc/k<01onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00_oOgmo00?o0000
ofIVI_mVIVH04?mVIVH00ol0003oC4a<oda<C00Hoda<C0?o0000Bolc<c<3o`0001WoC4a<00?o0000
ofIVI_mVIVH04?mVIVH00ol0003oOgmoogmoO`0;ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000
ok>c/onc/k<02?nc/k<00ol0003oc<c<olc<c006olc<c003o`000?oVi^Koi^KV00Goi^KV00?o0000
ooooooooool02?ooool2o`0000cooooo000[ooooo`03o`000?oooooooooo00Sooooo00?o0000onKV
i_oVi^H01_oVi^H00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00Oo/k>c00?o0000oiVI
VOnIVIT02_nIVIT00ol0003oOgmoogmoO`0:ogmoO`03o`000?mVIVKoIVIV013oIVIV00?o0000oda<
C?m<C4`05_m<C4`3o`00057o<c<c0ol0000Goda<C003o`000?mVIVKoIVIV013oIVIV00?o0000ogmo
OomoOgl02_moOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c00So/k>c00?o0000olc<
c?o<c<`01_o<c<`00ol0003oi^KVonKViP05onKViP03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool002_ooooo00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP06onKViP03
o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVIoiVIV@09oiVIV@03
o`000?moOgooOgmo00_oOgmo00?o0000ofIVI_mVIVH03omVIVH00ol0003oC4a<oda<C00Foda<C003
o`000?lc<c?o<c<c05Go<c<c00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP0@ofIVIP03
o`000?moOgooOgmo00[oOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`07ok>c/`03
o`000?o<c<coc<c<00Koc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Sooooo00?o0000onKVi_oVi^H0
1_oVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Oo/k>c00?o0000oiVIVOnIVIT0
2_nIVIT00ol0003oOgmoogmoO`0:ogmoO`03o`000?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`0
5Om<C4`2o`0005Wo<c<c0_l0000Foda<C003o`000?mVIVKoIVIV00ooIVIV00?o0000ogmoOomoOgl0
2_moOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c00So/k>c00?o0000olc<c?o<c<`0
1Oo<c<`00ol0003oi^KVonKViP05onKViP03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool002_ooooo00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP06onKViP03o`000?o<
c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?mo
OgooOgmo00_oOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?lc
<c?o<c<c05_o<c<c00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP0?ofIVIP03o`000?mo
OgooOgmo00[oOgmo00?o0000oiVIVOnIVIT02OnIVIT00ol0003o/k>cok>c/`08ok>c/`03o`000?o<
c<coc<c<00Goc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Sooooo00?o0000onKVi_oVi^H01_oVi^H0
0ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Oo/k>c00?o0000oiVIVOnIVIT02OnIVIT0
0ol0003oOgmoogmoO`0:ogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`05?m<C4`2
o`0005oo<c<c0_l0000Eoda<C003o`000?mVIVKoIVIV00koIVIV00?o0000ogmoOomoOgl02_moOgl0
0ol0003oVIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c00So/k>c00?o0000olc<c?o<c<`01Oo<c<`0
0ol0003oi^KVonKViP05onKViP03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
02_ooooo00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<
00Koc<c<00?o0000ok>c/onc/k<01_nc/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?moOgooOgmo
00_oOgmo00?o0000ofIVI_mVIVH03OmVIVH00ol0003oC4a<oda<C00Coda<C0;o0000Holc<c<2o`00
01CoC4a<00?o0000ofIVI_mVIVH03_mVIVH00ol0003oOgmoogmoO`0:ogmoO`03o`000?nIVIWoVIVI
00WoVIVI00?o0000ok>c/onc/k<01onc/k<00ol0003oc<c<olc<c006olc<c003o`000?oVi^Koi^KV
00Coi^KV00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003o
ooooooooo`08ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01_o<c<`00ol0003o
/k>cok>c/`06ok>c/`03o`000?nIVIWoVIVI00WoVIVI00?o0000ogmoOomoOgl02_moOgl00ol0003o
IVIVofIVIP0=ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000oc<c<olc<c<0IOlc<c<00ol0003o
C4a<oda<C00Boda<C003o`000?mVIVKoIVIV00koIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003o
VIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c00Oo/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o
i^KVonKViP04onKViP03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool002_ooooo
00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Goc<c<
00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00[oOgmo
00?o0000ofIVI_mVIVH03OmVIVH00ol0003oC4a<oda<C00Boda<C0;o0000JOlc<c<2o`0001?oC4a<
00?o0000ofIVI_mVIVH03OmVIVH00ol0003oOgmoogmoO`0:ogmoO`03o`000?nIVIWoVIVI00SoVIVI
00?o0000ok>c/onc/k<02?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003ooooooooo
o`08ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c
/`06ok>c/`03o`000?nIVIWoVIVI00WoVIVI00?o0000ogmoOomoOgl02_moOgl00ol0003oIVIVofIV
IP0<ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000oc<c<olc<c<0;_lc<c<=o`00033o<c<c00?o
0000oda<C?m<C4`04Om<C4`00ol0003oIVIVofIVIP0=ofIVIP03o`000?moOgooOgmo00WoOgmo00?o
0000oiVIVOnIVIT02OnIVIT00ol0003o/k>cok>c/`07ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o
0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000[
ooooo`03o`000?oooooooooo00Sooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c005
olc<c003o`000?nc/k?o/k>c00Ko/k>c00?o0000oiVIVOnIVIT02?nIVIT00ol0003oOgmoogmoO`0:
ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003o<c<coc<c<`0V
oc<c<`Wo00003OlI6AT8o`0002Wo<c<c00?o0000oda<C?m<C4`04Om<C4`00ol0003oIVIVofIVIP0=
ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0003o/k>cok>c/`07
ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Sooooo00?o0000onKV
i_oVi^H01OoVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Ko/k>c00?o0000oiVI
VOnIVIT02?nIVIT00ol0003oOgmoogmoO`0:ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<
C?m<C4`04Om<C4`00ol0003o<c<coc<c<`0Soc<c<`Co00007_lI6AT5o`0002Co<c<c00?o0000oda<
C?m<C4`04Om<C4`00ol0003oIVIVofIVIP0=ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVI
VOnIVIT02?nIVIT00ol0003o/k>cok>c/`07ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKV
i_oVi^H01?oVi^H00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03
o`000?oooooooooo00Sooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c005olc<c003
o`000?nc/k?o/k>c00Ko/k>c00?o0000oiVIVOnIVIT02?nIVIT00ol0003oOgmoogmoO`09ogmoO`03
o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`04Om<C4`00ol0003o<c<coc<c<`0Qoc<c<`?o
00009olI6AT3o`0002;o<c<c00?o0000oda<C?m<C4`04Om<C4`00ol0003oIVIVofIVIP0<ofIVIP03
o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0003o/k>cok>c/`07ok>c/`03
o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Sooooo00?o0000onKVi_oVi^H0
1OoVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Oo/k>c00?o0000oiVIVOnIVIT0
2?nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`0
4?m<C4`00ol0003o<c<coc<c<`0Ooc<c<`?o0000;OlI6AT3o`00023o<c<c00?o0000oda<C?m<C4`0
4?m<C4`00ol0003oIVIVofIVIP0=ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT0
1onIVIT00ol0003o/k>cok>c/`07ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H0
1?oVi^H00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000[ooooo`;o00002Ooo
ool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01_nc
/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00[oOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00@oda<C003o`000?lc<c?o<c<c01ko<c<c0_l0000coaTI6@;o00007olc
<c<00ol0003oC4a<oda<C00@oda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oVIVIoiVIV@08oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00?o0000olc<c?o<c<`01Oo<
c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Sooooo0_l0000<ooooo`00:oooool0
0ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01?o<c<`0
0ol0003o/k>cok>c/`06ok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<00ooC4a<00?o0000oc<c<olc<c<07Olc<c<2
o`0003Oo6ATI0_l0000Noc<c<`03o`000?m<C4coC4a<00ooC4a<00?o0000ofIVI_mVIVH03?mVIVH0
0ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00SoVIVI00?o0000ok>c/onc/k<01_nc/k<0
0ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV
00Goi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`06ok>c/`03o`000?nIVIWoVIVI
00SoVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<
00ooC4a<00?o0000oc<c<olc<c<06olc<c<3o`0003_o6ATI0ol0000Loc<c<`03o`000?m<C4coC4a<
00ooC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI
00SoVIVI00?o0000ok>c/onc/k<01_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV
00Coi^KV00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003o
ooooooooo`08ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o
/k>cok>c/`06ok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003o
IVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<00ooC4a<00?o0000oc<c<olc<c<06_lc<c<2o`00047o
6ATI0_l0000Koc<c<`03o`000?m<C4coC4a<00ooC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003o
OgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc/k<01_nc/k<00ol0003o
c<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Goi^KV
00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`06ok>c/`03o`000?nIVIWoVIVI00SoVIVI
00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<00ooC4a<
00?o0000oc<c<olc<c<06?lc<c<2o`0004Go6ATI0_l0000Ioc<c<`03o`000?m<C4coC4a<00ooC4a<
00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00OoVIVI
00?o0000ok>c/onc/k<01_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003ooooooooo
o`08ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c
/`06ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIV
IP0:ofIVIP03o`000?m<C4coC4a<00ooC4a<00?o0000oc<c<olc<c<05_lc<c<3o`0004Wo6ATI0ol0
000Goc<c<`03o`000?m<C4coC4a<00ooC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmo
O`09ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc/k<01_nc/k<00ol0003oc<c<olc<
c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`00:oooool00ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000
olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`06ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000
ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<00koC4a<00?o0000
oc<c<olc<c<05Olc<c<2o`0004oo6ATI0_l0000Foc<c<`03o`000?m<C4coC4a<00koC4a<00?o0000
ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o0000
ok>c/onc/k<01_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`08oooo
o`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`05ok>c
/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0:ofIV
IP03o`000?m<C4coC4a<00ooC4a<00?o0000oc<c<olc<c<05?lc<c<00ol0003o6ATIoaTI6@1AoaTI
6@03o`000?lc<c?o<c<c01?o<c<c00?o0000oda<C?m<C4`03om<C4`00ol0003oIVIVofIVIP0:ofIV
IP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c/`05ok>c
/`03o`000?o<c<coc<c<00Koc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Sooooo00?o0000onKVi_oV
i^H01?oVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnI
VIT02?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<
C4`03_m<C4`00ol0003o<c<coc<c<`0Doc<c<`03o`000?lI6AWo6ATI05;o6ATI00?o0000oc<c<olc
<c<05?lc<c<00ol0003oC4a<oda<C00>oda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<
c<`01_o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02_ooool002_ooooo00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP04onKViP03o`00
0?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01_nc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02OmVIVH00ol0003oC4a<oda<C00>oda<C003o`00
0?lc<c?o<c<c01Co<c<c00?o0000oaTI6OlI6AT0E?lI6AT00ol0003o<c<coc<c<`0Doc<c<`03o`00
0?m<C4coC4a<00koC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`00
0?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc/k<01_nc/k<00ol0003oc<c<olc<c005olc<c003o`00
0?oVi^Koi^KV00Coi^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<
c<`00ol0003o/k>cok>c/`06ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<00koC4a<00?o0000oc<c<olc<c<04olc
<c<00ol0003o6ATIoaTI6@1FoaTI6@03o`000?lc<c?o<c<c01?o<c<c00?o0000oda<C?m<C4`03_m<
C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01onI
VIT00ol0003o/k>cok>c/`06ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H01?oV
i^H00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooo
oooo00Sooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o
/k>c00Ko/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKo
IVIV00[oIVIV00?o0000oda<C?m<C4`03Om<C4`00ol0003o<c<coc<c<`0Coc<c<`03o`000?lI6AWo
6ATI05So6ATI00?o0000oc<c<olc<c<04olc<c<00ol0003oC4a<oda<C00>oda<C003o`000?mVIVKo
IVIV00WoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o
/k>c00Ko/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool02?ooool00ol0
003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01_nc/k<00ol0
003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02OmVIVH00ol0
003oC4a<oda<C00>oda<C003o`000?lc<c?o<c<c01;o<c<c00?o0000oaTI6OlI6AT0F_lI6AT00ol0
003o<c<coc<c<`0Boc<c<`03o`000?m<C4coC4a<00koC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0
003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01_nc/k<00ol0
003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Co
i^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`06ok>c/`03o`000?nIVIWoVIVI00Oo
VIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<00go
C4a<00?o0000oc<c<olc<c<04_lc<c<00ol0003o6ATIoaTI6@1LoaTI6@03o`000?lc<c?o<c<c01;o
<c<c00?o0000oda<C?m<C4`03Om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00So
Ogmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`06ok>c/`03o`000?o<c<coc<c<00Go
c<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[o
oooo000[ooooo`03o`000?oooooooooo00Sooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<
olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT02?nIVIT00ol0003oOgmo
ogmoO`07ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`03?m<C4`00ol0003o<c<c
oc<c<`0Boc<c<`03o`000?lI6AWo6ATI05ko6ATI00?o0000oc<c<olc<c<04_lc<c<00ol0003oC4a<
oda<C00=oda<C003o`000?mVIVKoIVIV00WoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVI
oiVIV@07oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KV
onKViP04onKViP03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool002_ooooo0_l0
0009ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c
/`05ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIV
IP0:ofIVIP03o`000?m<C4coC4a<00coC4a<00?o0000oc<c<olc<c<04Olc<c<00ol0003o6ATIoaTI
6@1PoaTI6@03o`000?lc<c?o<c<c017o<c<c00?o0000oda<C?m<C4`03Om<C4`00ol0003oIVIVofIV
IP09ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c
/`05ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003ooooooooo
o`07ooooo`;o00003?ooool002_ooooo00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP04
onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@07
oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00<
oda<C003o`000?lc<c?o<c<c017o<c<c00?o0000oaTI6OlI6AT0H_lI6AT00ol0003o<c<coc<c<`0A
oc<c<`03o`000?m<C4coC4a<00coC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`08
ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c005
olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:
ooooo`00:oooool00ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<
c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmo
OomoOgl01omoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c
<olc<c<04Olc<c<00ol0003o6ATIoaTI6@0]oaTI6@Wo0000;_lI6AT00ol0003o<c<coc<c<`0Aoc<c
<`03o`000?m<C4coC4a<00coC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`08ogmo
O`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c005olc<
c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:oooo
o`00:oooool00ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<
c<`01?o<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomo
Ogl01omoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc
<c<04Olc<c<00ol0003o6ATIoaTI6@0YoaTI6A7o0000:_lI6AT00ol0003o<c<coc<c<`0Aoc<c<`03
o`000?m<C4coC4a<00coC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`08ogmoO`03
o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003
o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00
:oooool00ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`0
1?o<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl0
1omoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<0
4?lc<c<00ol0003o6ATIoaTI6@0VoaTI6AWo00009olI6AT00ol0003o<c<coc<c<`0@oc<c<`03o`00
0?m<C4coC4a<00coC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`00
0?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003o`00
0?oVi^Koi^KV00Coi^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<
c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl01omo
Ogl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<04Olc
<c<00ol0003o6ATIoaTI6@0SoaTI6Aoo00009?lI6AT00ol0003o<c<coc<c<`0Aoc<c<`03o`000?m<
C4coC4a<00_oC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nI
VIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?oV
i^Koi^KV00Coi^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool0
0ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`0
0ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl01_moOgl0
0ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<04?lc<c<0
0ol0003o6ATIoaTI6@0PoaTI6BOo00008OlI6AT00ol0003o<c<coc<c<`0@oc<c<`03o`000?m<C4co
C4a<00coC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWo
VIVI00KoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Ko
i^KV00Coi^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0
003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0
003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0
003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<04?lc<c<00ol0
003o6ATIoaTI6@0NoaTI6B_o00007olI6AT00ol0003o<c<coc<c<`0@oc<c<`03o`000?m<C4coC4a<
00coC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI
00KoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV
00Coi^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003o
ooooooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o
/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003o
IVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<04Olc<c<00ol0003o
6ATIoaTI6@0MoaTI6Bgo00007olI6AT00ol0003o<c<coc<c<`0@oc<c<`03o`000?m<C4coC4a<00_o
C4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00Ko
VIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Co
i^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>c
ok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIV
ofIVIP09ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<04?lc<c<00ol0003o6ATI
oaTI6@0MoaTI6Boo00007_lI6AT00ol0003o<c<coc<c<`0@oc<c<`03o`000?m<C4coC4a<00_oC4a<
00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI
00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003ooooooooo
o`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c
/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIV
IP09ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<04?lc<c<00ol0003o6ATIoaTI
6@0LoaTI6C7o00007_lI6AT00ol0003o<c<coc<c<`0?oc<c<`03o`000?m<C4coC4a<00_oC4a<00?o
0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o
0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`08
ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05
ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP09
ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<03olc<c<00ol0003o6ATIoaTI6@0L
oaTI6C?o00007OlI6AT00ol0003o<c<coc<c<`0?oc<c<`03o`000?m<C4coC4a<00coC4a<00?o0000
ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000
ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`08
ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05
ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP09
ofIVIP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<04?lc<c<00ol0003o6ATIoaTI6@0K
oaTI6CGo00007OlI6AT00ol0003o<c<coc<c<`0?oc<c<`03o`000?m<C4coC4a<00_oC4a<00?o0000
ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000
ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`004?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool0
0ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<0
0ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02OmVIVH0
0ol0003oC4a<oda<C00;oda<C003o`000?lc<c?o<c<c00oo<c<c00?o0000oaTI6OlI6AT06olI6ATg
o`0001co6ATI00?o0000oc<c<olc<c<03olc<c<00ol0003oC4a<oda<C00;oda<C003o`000?mVIVKo
IVIV00WoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o
/k>c00Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02_ooool0013ooooo00Go410@oooooooooooooooooa0@400;
ooooo`Go00001_ooool3o`0000Oooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004
olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`06
ogmoO`03o`000?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`02om<C4`00ol0003o<c<coc<c<`0?
oc<c<`03o`000?lI6AWo6ATI01[o6ATI>Ol0000KoaTI6@03o`000?lc<c?o<c<c00oo<c<c00?o0000
oda<C?m<C4`02om<C4`00ol0003oIVIVofIVIP09ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000
oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000
onKVi_oVi^H01?oVi^H00ol0003oooooooooo`06ooooo`?o00003?ooool0013ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool01ooo
ool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc
/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02OmV
IVH00ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c013o<c<c00?o0000oaTI6OlI6AT06OlI
6ATko`0001_o6ATI00?o0000oc<c<olc<c<03olc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mV
IVKoIVIV00WoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc
/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02_ooool0013ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool01oooool00ol0003oi^KV
onKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVI
oiVIV@07oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02OmVIVH00ol0003oC4a<
oda<C00:oda<C003o`000?lc<c?o<c<c00oo<c<c00?o0000oaTI6OlI6AT06OlI6ATmo`0001[o6ATI
00?o0000oc<c<olc<c<03olc<c<00ol0003oC4a<oda<C00;oda<C003o`000?mVIVKoIVIV00SoIVIV
00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Go/k>c
00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02_ooool0013ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMg
Moo<c<co000000Oooooo00?o0000ooooooooool01oooool00ol0003oi^KVonKViP04onKViP03o`00
0?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`00
0?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02OmVIVH00ol0003oC4a<oda<C00:oda<C003o`00
0?lc<c?o<c<c00oo<c<c00?o0000oaTI6OlI6AT06?lI6AToo`0001[o6ATI00?o0000oc<c<olc<c<0
3_lc<c<00ol0003oC4a<oda<C00;oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl0
1omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`0
1?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2_ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo
00?o0000ooooooooool01oooool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<
00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00KoOgmo
00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00;oda<C003o`000?lc<c?o<c<c00ko<c<c
00?o0000oaTI6OlI6AT06?lI6AU1o`0001Wo6ATI00?o0000oc<c<olc<c<03_lc<c<00ol0003oC4a<
oda<C00;oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVI
oiVIV@06oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KV
onKViP04onKViP03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool0013ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0
1oooool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<0
1Onc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH0
2?mVIVH00ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c00oo<c<c00?o0000oaTI6OlI6AT0
5olI6AU3o`0001Wo6ATI00?o0000oc<c<olc<c<03_lc<c<00ol0003oC4a<oda<C00:oda<C003o`00
0?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@06oiVIV@03o`00
0?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool01ooo
ool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc
/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02OmV
IVH00ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c00ko<c<c00?o0000oaTI6OlI6AT05olI
6AU5o`0001So6ATI00?o0000oc<c<olc<c<03_lc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mV
IVKoIVIV00WoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc
/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool01oooool0
0ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<0
0ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02OmVIVH0
0ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c00ko<c<c00?o0000oaTI6OlI6AT05_lI6AU7
o`0001So6ATI00?o0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C00;oda<C003o`000?mVIVKo
IVIV00SoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o
/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0
003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0
003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0
003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c00oo<c<c00?o0000oaTI6OlI6AT05OlI6AU9o`00
01Oo6ATI00?o0000oc<c<olc<c<03_lc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV
00SoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c
00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0003o
i^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003o
VIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003o
C4a<oda<C00:oda<C003o`000?lc<c?o<c<c00ko<c<c00?o0000oaTI6OlI6AT05OlI6AU;o`0001Oo
6ATI00?o0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00So
IVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Co
/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00So
oooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0003oi^KV
onKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVI
oiVIV@06oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<
oda<C00:oda<C003o`000?lc<c?o<c<c00ko<c<c00?o0000oaTI6OlI6AT05OlI6AU;o`0001Oo6ATI
00?o0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00SoIVIV
00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Co/k>c
00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0003oi^KVonKV
iP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVI
V@06oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<
C00:oda<C003o`000?lc<c?o<c<c00ko<c<c00?o0000oaTI6OlI6AT05OlI6AU;o`0001Oo6ATI00?o
0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00SoIVIV00?o
0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o
0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0003oi^KVonKViP04
onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@06
oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00:
oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT05OlI6AU=o`0001Ko6ATI00?o0000
oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000
ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000
olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0003oi^KVonKViP04onKV
iP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@06oiVI
V@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00:oda<
C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT05OlI6AU=o`0001Ko6ATI00?o0000oc<c
<olc<c<03Olc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmo
OomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<
c?o<c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0003oi^KVonKViP04onKViP03
o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@06oiVIV@03
o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00:oda<C003
o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT05OlI6AU=o`0001Oo6ATI00?o0000oc<c<olc
<c<03?lc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomo
Ogl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<
c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02_ooool002_ooooo0_l00008ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`0
1?o<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl0
1_moOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<0
3Olc<c<00ol0003o6ATIoaTI6@0DoaTI6Doo00005_lI6AT00ol0003o<c<coc<c<`0=oc<c<`03o`00
0?m<C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`07ogmoO`03o`00
0?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004olc<c003o`00
0?oVi^Koi^KV00Coi^KV00?o0000ooooooooool01oooool2o`0000cooooo000[ooooo`03o`000?oo
oooooooo00Oooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc
/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mV
IVKoIVIV00SoIVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0<oc<c<`03o`000?lI
6AWo6ATI01Go6ATICol0000FoaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02Om<
C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nI
VIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oV
i^H00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooo
oooo00Oooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o
/k>c00Go/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKo
IVIV00SoIVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0<oc<c<`03o`000?lI6AWo
6ATI01Go6ATICol0000FoaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02Om<C4`0
0ol0003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT0
0ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo
00Oooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c
00Go/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV
00SoIVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0<oc<c<`03o`000?lI6AWo6ATI
01Go6ATICol0000FoaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02Om<C4`00ol0
003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0
003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Oo
oooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go
/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00So
IVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0<oc<c<`03o`000?lI6AWo6ATI01Co
6ATIDOl0000EoaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02Om<C4`00ol0003o
IVIVofIVIP08ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o
/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Oooooo
00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c
00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00SoIVIV
00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI01Co6ATI
DOl0000EoaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIV
ofIVIP08ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>c
ok>c/`05ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H00ooVi^H00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o
0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o
0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o
0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI01Co6ATIDOl0
000EoaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIV
IP08ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c
/`05ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H00ooVi^H00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000
onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000
oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000
oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI01Co6ATIDOl0000E
oaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIVIP08
ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`05
ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H00ooVi^H00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000onKV
i_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVI
VOnIVIT01OnIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<
C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI01?o6ATIDol0000DoaTI
6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIVIP08ofIV
IP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`05ok>c
/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H00ooVi^H00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00[ooooo000;ooooo`?o000000?o410@ooooooooool06_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o
/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003o
IVIVofIVIP08ofIVIP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<03?lc<c<00ol0003o
6ATIoaTI6@0DoaTI6E?o00005OlI6AT00ol0003o<c<coc<c<`0<oc<c<`03o`000?m<C4coC4a<00[o
C4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00Go
VIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00?o
i^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`003Oooool00ol@413o^[Zj
ooooo`0Kooooo`03o`000?oooooooooo00Oooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<
olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmo
ogmoO`06ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<c
oc<c<`0<oc<c<`03o`000?lI6AWo6ATI01Co6ATIDol0000EoaTI6@03o`000?lc<c?o<c<c00co<c<c
00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00OoOgmo
00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00Coc<c<
00?o0000onKVi_oVi^H00ooVi^H00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo
000=ooooo`03oiRHV?lb<S;ooooo01_ooooo00?o0000ooooooooool01oooool00ol0003oi^KVonKV
iP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVI
V@05oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<
C00:oda<C003o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT04olI6AUEo`0001Co6ATI00?o
0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C009oda<C003o`000?mVIVKoIVIV00SoIVIV00?o
0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o
0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP03onKViP03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02_ooool000gooooo00?ogMgMo`000?nj^[X06oooool00ol0003oooooooooo`07
ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05
ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP08
ofIVIP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<03?lc<c<00ol0003o6ATIoaTI6@0C
oaTI6EGo00005?lI6AT00ol0003o<c<coc<c<`0=oc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000
ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000
ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00?oi^KV00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`003Oooool00omEEEGoMgMgodA4A00Koooo
o`03o`000?oooooooooo00Oooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<
c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`06ogmo
O`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0<oc<c
<`03o`000?lI6AWo6ATI01?o6ATIEOl0000DoaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<
C?m<C4`02Om<C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVI
VOnIVIT01OnIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKV
i_oVi^H00ooVi^H00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo000<ooooo`05
omgMgOl@413oooooob4Q8OoMgMd06_ooool00ol0003oooooooooo`07ooooo`03o`000?oVi^Koi^KV
00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI
00GoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<
00[oC4a<00?o0000oc<c<olc<c<03?lc<c<00ol0003o6ATIoaTI6@0CoaTI6EGo00005?lI6AT00ol0
003o<c<coc<c<`0=oc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0
003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0
003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00?oi^KV00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0:ooooo`003?ooool01OmVIVKoQhN7oooooonHV9SoEEEE01[ooooo0_l00008oooo
o`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05ok>c
/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP08ofIV
IP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<03?lc<c<00ol0003o6ATIoaTI6@0CoaTI
6EGo00005?lI6AT00ol0003o<c<coc<c<`0=oc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000ofIV
I_mVIVH02?mVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c
/onc/k<01Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00?oi^KV00?o0000oooo
ooooool01oooool2o`0000cooooo000;ooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOoo
ool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<
c<`01?o<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomo
Ogl01_moOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc
<c<03?lc<c<00ol0003o6ATIoaTI6@0CoaTI6EGo00005?lI6AT00ol0003o<c<coc<c<`0=oc<c<`03
o`000?m<C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`07ogmoO`03
o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c004olc<c003
o`000?oVi^Koi^KV00?oi^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00
2oooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Oooooo00?o0000oooooooo
ool01oooool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc
/k<01Onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mV
IVH02?mVIVH00ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI
6AT04olI6AUEo`0001Co6ATI00?o0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C009oda<C003
o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03
o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP03onKViP03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool0
1oooool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<0
1Onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH0
2?mVIVH00ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT0
4olI6AUEo`0001Co6ATI00?o0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C009oda<C003o`00
0?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`00
0?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP03onKViP03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool01ooo
ool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc
/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mV
IVH00ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT04olI
6AUEo`0001Co6ATI00?o0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C009oda<C003o`000?mV
IVKoIVIV00SoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc
/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP03onKViP03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool01oooool0
0ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<0
0ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH0
0ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT05?lI6AUC
o`0001Go6ATI00?o0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C009oda<C003o`000?mVIVKo
IVIV00SoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o
/k>c00Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP03onKViP03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0
003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0
003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0
003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT05?lI6AUCo`00
01Go6ATI00?o0000oc<c<olc<c<03?lc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV
00SoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c
00Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP03onKViP03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0003o
i^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003o
VIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003o
C4a<oda<C00:oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT04olI6AUCo`0001Co
6ATI00?o0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00So
IVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c00Go
/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP03onKViP03o`000?oooooooooo00So
oooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0003oi^KV
onKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVI
oiVIV@05oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<
oda<C00:oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT04olI6AUCo`0001Co6ATI
00?o0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00SoIVIV
00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c00Go/k>c
00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP03onKViP03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0003oi^KVonKV
iP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVI
V@05oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<
C00:oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT05?lI6AUAo`0001Go6ATI00?o
0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00SoIVIV00?o
0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o
0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP03onKViP03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0003oi^KVonKViP04
onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@05
oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00:
oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT05?lI6AUAo`0001Go6ATI00?o0000
oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000
ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000
olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP03onKViP03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0003oi^KVonKViP04onKV
iP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@06oiVI
V@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00:oda<
C003o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT05?lI6AUAo`0001Go6ATI00?o0000oc<c
<olc<c<03Olc<c<00ol0003oC4a<oda<C009oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmo
OomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<
c?o<c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0003oi^KVonKViP04onKViP03
o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@06oiVIV@03
o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00:oda<C003
o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT05OlI6AU?o`0001Ko6ATI00?o0000oc<c<olc
<c<03Olc<c<00ol0003oC4a<oda<C009oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomo
Ogl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<
c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0003oi^KVonKViP04onKViP03o`00
0?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`00
0?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00:oda<C003o`00
0?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT05OlI6AU?o`0001Ko6ATI00?o0000oc<c<olc<c<0
3Olc<c<00ol0003oC4a<oda<C009oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl0
1omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`0
1?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2_ooool002_ooooo0_l00008ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<
c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01_mo
Ogl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<03?lc
<c<00ol0003o6ATIoaTI6@0EoaTI6Doo00005_lI6AT00ol0003o<c<coc<c<`0=oc<c<`03o`000?m<
C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nI
VIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004olc<c003o`000?oV
i^Koi^KV00Coi^KV00?o0000ooooooooool01oooool2o`0000cooooo000[ooooo`03o`000?oooooo
oooo00Oooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o
/k>c00Go/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKo
IVIV00SoIVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo
6ATI01Co6ATICol0000FoaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02Om<C4`0
0ol0003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT0
0ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo
00Oooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c
00Go/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV
00SoIVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI
01Go6ATICOl0000GoaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02Om<C4`00ol0
003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0
003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Oo
oooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go
/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00So
IVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI01Go
6ATICOl0000FoaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003o
IVIVofIVIP08ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o
/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Oooooo
00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c
00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00SoIVIV
00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI01Go6ATI
COl0000FoaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIV
ofIVIP08ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>c
ok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o
0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o
0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o
0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI01Go6ATICOl0
000FoaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIV
IP08ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c
/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000
onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000
oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000
oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0>oc<c<`03o`000?lI6AWo6ATI01Go6ATIBol0000G
oaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIVIP08
ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`04
ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000onKV
i_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVI
VOnIVIT01_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<
C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0>oc<c<`03o`000?lI6AWo6ATI01Go6ATIBol0000GoaTI
6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIVIP08ofIV
IP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`04ok>c
/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000onKVi_oV
i^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnI
VIT01_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<
C4`02_m<C4`00ol0003o<c<coc<c<`0>oc<c<`03o`000?lI6AWo6ATI01Oo6ATIAol0000IoaTI6@03
o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIVIP08ofIVIP03
o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`04ok>c/`03
o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000onKVi_oVi^H0
1?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT0
1_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`0
2_m<C4`00ol0003o<c<coc<c<`0?oc<c<`03o`000?lI6AWo6ATI01Oo6ATIAOl0000IoaTI6@03o`00
0?lc<c?o<c<c00ko<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIVIP08ofIVIP03o`00
0?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`00
0?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000onKVi_oVi^H01?oV
i^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01_nI
VIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`02_m<
C4`00ol0003o<c<coc<c<`0>oc<c<`03o`000?lI6AWo6ATI01So6ATI@ol0000JoaTI6@03o`000?lc
<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIVIP09ofIVIP03o`000?mo
OgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<
c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000onKVi_oVi^H01?oVi^H0
0ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01_nIVIT0
0ol0003oOgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`02_m<C4`0
0ol0003o<c<coc<c<`0?oc<c<`03o`000?lI6AWo6ATI01So6ATI@Ol0000JoaTI6@03o`000?lc<c?o
<c<c00ko<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?moOgoo
Ogmo00SoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<co
c<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00[ooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo00Oooooo00?o0000onKVi_oVi^H01?oV
i^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01_nI
VIT00ol0003oOgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`02_m<
C4`00ol0003o<c<coc<c<`0?oc<c<`03o`000?lI6AWo6ATI01Wo6ATI?ol0000KoaTI6@03o`000?lc
<c?o<c<c00ko<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?mo
OgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<
c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00[ooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
EEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo00Oooooo00?o0000onKVi_oVi^H0
1?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT0
1onIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`0
2om<C4`00ol0003o<c<coc<c<`0>oc<c<`03o`000?lI6AWo6ATI01[o6ATI?Ol0000KoaTI6@03o`00
0?lc<c?o<c<c00ko<c<c00?o0000oda<C?m<C4`02om<C4`00ol0003oIVIVofIVIP08ofIVIP03o`00
0?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`00
0?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00[ooooo000@ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01oooool00ol0003oi^KVonKViP04onKViP03
o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@07oiVIV@03
o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02OmVIVH00ol0003oC4a<oda<C00:oda<C003
o`000?lc<c?o<c<c00oo<c<c00?o0000oaTI6OlI6AT06_lI6ATko`0001co6ATI00?o0000oc<c<olc
<c<03_lc<c<00ol0003oC4a<oda<C00;oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomo
Ogl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<
c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02_ooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRH
V?lQ8B401_ooool3o`0000Oooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<
c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`06ogmo
O`03o`000?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0?oc<c
<`03o`000?lI6AWo6ATI01_o6ATI>Ol0000LoaTI6@03o`000?lc<c?o<c<c00oo<c<c00?o0000oda<
C?m<C4`02_m<C4`00ol0003oIVIVofIVIP09ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVI
VOnIVIT01_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKV
i_oVi^H01?oVi^H00ol0003oooooooooo`06ooooo`?o00003?ooool0013ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05
ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP09
ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<03olc<c<00ol0003o6ATIoaTI6@0K
oaTI6COo00007OlI6AT00ol0003o<c<coc<c<`0>oc<c<`03o`000?m<C4coC4a<00_oC4a<00?o0000
ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000
ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`004?ooool01Ol@413ooooooooooooooooo
410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oVi^Ko
i^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWo
VIVI00OoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4co
C4a<00_oC4a<00?o0000oc<c<olc<c<03olc<c<00ol0003o6ATIoaTI6@0LoaTI6CGo00007OlI6AT0
0ol0003o<c<coc<c<`0?oc<c<`03o`000?m<C4coC4a<00_oC4a<00?o0000ofIVI_mVIVH02OmVIVH0
0ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01Onc/k<0
0ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0:ooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgM
oa0@4?nHV9P02?ooool00ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000
olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000
ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<00[oC4a<00?o0000
oc<c<olc<c<04?lc<c<00ol0003o6ATIoaTI6@0LoaTI6C?o00007_lI6AT00ol0003o<c<coc<c<`0?
oc<c<`03o`000?m<C4coC4a<00_oC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`08
ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c005
olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:
ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<
c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01omo
Ogl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<04?lc
<c<00ol0003o6ATIoaTI6@0MoaTI6C7o00007_lI6AT00ol0003o<c<coc<c<`0@oc<c<`03o`000?m<
C4coC4a<00_oC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nI
VIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oV
i^Koi^KV00Coi^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool0
0ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`0
0ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01omoOgl0
0ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<04?lc<c<0
0ol0003o6ATIoaTI6@0MoaTI6Boo00007olI6AT00ol0003o<c<coc<c<`0?oc<c<`03o`000?m<C4co
C4a<00_oC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWo
VIVI00KoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Ko
i^KV00Coi^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0
003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0
003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0
003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<04?lc<c<00ol0
003o6ATIoaTI6@0NoaTI6Bgo00007olI6AT00ol0003o<c<coc<c<`0@oc<c<`03o`000?m<C4coC4a<
00_oC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI
00KoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV
00Coi^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003o
ooooooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o
/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003o
IVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<04Olc<c<00ol0003o
6ATIoaTI6@0NoaTI6B_o00008?lI6AT00ol0003o<c<coc<c<`0@oc<c<`03o`000?m<C4coC4a<00_o
C4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00Ko
VIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Co
i^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>c
ok>c/`05ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIV
ofIVIP0:ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<04?lc<c<00ol0003o6ATI
oaTI6@0QoaTI6BGo00008_lI6AT00ol0003o<c<coc<c<`0@oc<c<`03o`000?m<C4coC4a<00coC4a<
00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00KoVIVI
00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003ooooooooo
o`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c
/`05ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIV
IP0:ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<04?lc<c<00ol0003o6ATIoaTI
6@0UoaTI6Ago00009_lI6AT00ol0003o<c<coc<c<`0@oc<c<`03o`000?m<C4coC4a<00coC4a<00?o
0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o
0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`08
ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05
ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP09
ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<04Olc<c<00ol0003o6ATIoaTI6@0X
oaTI6AGo0000:OlI6AT00ol0003o<c<coc<c<`0Aoc<c<`03o`000?m<C4coC4a<00_oC4a<00?o0000
ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000
ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`08oooo
o`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05ok>c
/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP0:ofIV
IP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<04?lc<c<00ol0003o6ATIoaTI6@0[oaTI
6@oo0000;?lI6AT00ol0003o<c<coc<c<`0@oc<c<`03o`000?m<C4coC4a<00coC4a<00?o0000ofIV
I_mVIVH02OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c
/onc/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`08ooooo`03
o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05ok>c/`03
o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP0:ofIVIP03
o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<04Olc<c<00ol0003o6ATIoaTI6@0^oaTI6@Oo
0000;olI6AT00ol0003o<c<coc<c<`0Aoc<c<`03o`000?m<C4coC4a<00coC4a<00?o0000ofIVI_mV
IVH02OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc
/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`08ooooo`03o`00
0?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05ok>c/`03o`00
0?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`00
0?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<04_lc<c<00ol0003o6ATIoaTI6@1SoaTI6@03o`00
0?lc<c?o<c<c017o<c<c00?o0000oda<C?m<C4`03?m<C4`00ol0003oIVIVofIVIP09ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`00
0?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00[ooooo000[ooooo`;o00002Oooool00ol0003oi^KVonKViP04onKViP03o`000?o<
c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?mo
OgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02OmVIVH00ol0003oC4a<oda<C00<oda<C003o`000?lc
<c?o<c<c01;o<c<c00?o0000oaTI6OlI6AT0HOlI6AT00ol0003o<c<coc<c<`0Aoc<c<`03o`000?m<
C4coC4a<00coC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nI
VIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?oV
i^Koi^KV00Coi^KV00?o0000ooooooooool01oooool2o`0000cooooo000[ooooo`03o`000?oooooo
oooo00Sooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o
/k>c00Go/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKo
IVIV00[oIVIV00?o0000oda<C?m<C4`03?m<C4`00ol0003o<c<coc<c<`0Boc<c<`03o`000?lI6AWo
6ATI05oo6ATI00?o0000oc<c<olc<c<04Olc<c<00ol0003oC4a<oda<C00=oda<C003o`000?mVIVKo
IVIV00WoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o
/k>c00Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool02?ooool00ol0
003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01_nc/k<00ol0
003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0
003oC4a<oda<C00<oda<C003o`000?lc<c?o<c<c01?o<c<c00?o0000oaTI6OlI6AT0GOlI6AT00ol0
003o<c<coc<c<`0Boc<c<`03o`000?m<C4coC4a<00goC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0
003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01_nc/k<00ol0
003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Co
i^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`06ok>c/`03o`000?nIVIWoVIVI00Oo
VIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<00go
C4a<00?o0000oc<c<olc<c<04olc<c<00ol0003o6ATIoaTI6@1KoaTI6@03o`000?lc<c?o<c<c01;o
<c<c00?o0000oda<C?m<C4`03Om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00So
Ogmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`06ok>c/`03o`000?o<c<coc<c<00Go
c<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[o
oooo000[ooooo`03o`000?oooooooooo00Sooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<
olc<c004olc<c003o`000?nc/k?o/k>c00Ko/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmo
ogmoO`08ogmoO`03o`000?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`03Om<C4`00ol0003o<c<c
oc<c<`0Doc<c<`03o`000?lI6AWo6ATI05Wo6ATI00?o0000oc<c<olc<c<04olc<c<00ol0003oC4a<
oda<C00=oda<C003o`000?mVIVKoIVIV00WoIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVI
oiVIV@06oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KV
onKViP04onKViP03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool002_ooooo00?o
0000ooooooooool02?ooool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o
0000ok>c/onc/k<01_nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00SoOgmo00?o
0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00=oda<C003o`000?lc<c?o<c<c01Co<c<c00?o
0000oaTI6OlI6AT0EolI6AT00ol0003o<c<coc<c<`0Coc<c<`03o`000?m<C4coC4a<00koC4a<00?o
0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o
0000ok>c/onc/k<01_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`08
ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`06
ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP09
ofIVIP03o`000?m<C4coC4a<00koC4a<00?o0000oc<c<olc<c<05?lc<c<00ol0003o6ATIoaTI6@1E
oaTI6@03o`000?lc<c?o<c<c01?o<c<c00?o0000oda<C?m<C4`03_m<C4`00ol0003oIVIVofIVIP0:
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c/`06
ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Sooooo00?o0000onKV
i_oVi^H01?oVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVI
VOnIVIT02?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00WoIVIV00?o0000oda<
C?m<C4`03_m<C4`00ol0003o<c<coc<c<`0Eoc<c<`03o`000?lI6AWo6ATI05?o6ATI00?o0000oc<c
<olc<c<05?lc<c<00ol0003oC4a<oda<C00>oda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmo
OomoOgl02?moOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<
c?o<c<`01_o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02_ooool002_ooooo00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP04onKViP03
o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@08oiVIV@03
o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00>oda<C003
o`000?lc<c?o<c<c01Go<c<c0_l0001AoaTI6@;o00005_lc<c<00ol0003oC4a<oda<C00>oda<C003
o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@07oiVIV@03
o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003oi^KVonKViP04onKViP03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool0
2?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<0
1_nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH0
2OmVIVH00ol0003oC4a<oda<C00>oda<C003o`000?lc<c?o<c<c01Oo<c<c0_l0001=oaTI6@;o0000
6?lc<c<00ol0003oC4a<oda<C00>oda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00?o0000olc<c?o<c<`0
1Oo<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool002_ooooo00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<
c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01_nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?mo
OgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00>oda<C003o`000?lc
<c?o<c<c01So<c<c0_l00019oaTI6@;o00006Olc<c<00ol0003oC4a<oda<C00>oda<C003o`000?mV
IVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc
/k?o/k>c00Ko/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP04onKViP03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool02?ooool0
0ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01_nc/k<0
0ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH0
0ol0003oC4a<oda<C00?oda<C003o`000?lc<c?o<c<c01Wo<c<c0_l00015oaTI6@;o00006_lc<c<0
0ol0003oC4a<oda<C00?oda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00?o0000olc<c?o<c<`01Oo<c<`0
0ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
02_ooooo00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<
00Coc<c<00?o0000ok>c/onc/k<01_nc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo
00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00>oda<C003o`000?lc<c?o<c<c
01_o<c<c0_l00011oaTI6@;o00007?lc<c<00ol0003oC4a<oda<C00>oda<C003o`000?mVIVKoIVIV
00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c
00Ko/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool02?ooool00ol0003o
i^KVonKViP05onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01_nc/k<00ol0003o
VIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00>oda<C0;o00007Olc<c<3o`0003_o6ATI0ol0000Moc<c<`03o`000?m<C4coC4a<00ko
C4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00Oo
VIVI00?o0000ok>c/onc/k<01_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Co
i^KV00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>c
ok>c/`06ok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?m<C4coC4a<013oC4a<00?o0000oc<c<olc<c<07Olc<c<2o`0003Oo6ATI
0_l0000Ooc<c<`03o`000?m<C4coC4a<00ooC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmo
ogmoO`08ogmoO`03o`000?nIVIWoVIVI00SoVIVI00?o0000ok>c/onc/k<01_nc/k<00ol0003oc<c<
olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`00:oooool2o`0000Wooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<
c004olc<c003o`000?nc/k?o/k>c00Ko/k>c00?o0000oiVIVOnIVIT02?nIVIT00ol0003oOgmoogmo
O`0:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`04?m<C4`00ol0003o<c<coc<c
<`0Noc<c<`;o0000<olI6AT2o`00023o<c<c00?o0000oda<C?m<C4`03om<C4`00ol0003oIVIVofIV
IP0<ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0003o/k>cok>c
/`06ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003ooooooooo
o`08ooooo`;o00003?ooool002_ooooo00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP05
onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVIoiVIV@07
oiVIV@03o`000?moOgooOgmo00[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00A
oda<C003o`000?lc<c?o<c<c01oo<c<c0_l0000_oaTI6@;o00008Olc<c<00ol0003oC4a<oda<C00@
oda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@07
oiVIV@03o`000?nc/k?o/k>c00Oo/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP04
onKViP03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000oooo
ooooool02?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c
/onc/k<01onc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIV
I_mVIVH03?mVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?lc<c?o<c<c023o<c<c0_l0000[oaTI
6@;o00008_lc<c<00ol0003oC4a<oda<C00@oda<C003o`000?mVIVKoIVIV00goIVIV00?o0000ogmo
OomoOgl02OmoOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c00Oo/k>c00?o0000olc<
c?o<c<`01Oo<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool002_ooooo00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP05onKViP03
o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01_nc/k<00ol0003oVIVIoiVIV@08oiVIV@03
o`000?moOgooOgmo00[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Boda<C003
o`000?lc<c?o<c<c027o<c<c1Ol0000QoaTI6@Go00008olc<c<00ol0003oC4a<oda<C00Aoda<C003
o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@08oiVIV@03
o`000?nc/k?o/k>c00Oo/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP04onKViP03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool0
2?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<0
1_nc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00[oOgmo00?o0000ofIVI_mVIVH0
3?mVIVH00ol0003oC4a<oda<C00Boda<C0;o00009_lc<c<;o`0000_o6ATI2ol0000Voc<c<`;o0000
4om<C4`00ol0003oIVIVofIVIP0=ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT0
2?nIVIT00ol0003o/k>cok>c/`07ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H0
1?oVi^H00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oo
oooooooo00Sooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc
/k?o/k>c00Ko/k>c00?o0000oiVIVOnIVIT02?nIVIT00ol0003oOgmoogmoO`0:ogmoO`03o`000?mV
IVKoIVIV00goIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003o<c<coc<c<`0^oc<c<`_o0000<?lc
<c<00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV00koIVIV00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oVIVIoiVIV@08oiVIV@03o`000?nc/k?o/k>c00Oo/k>c00?o0000olc<c?o<c<`01Oo<
c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool002_ooooo00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<co
c<c<00Goc<c<00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgoo
Ogmo00[oOgmo00?o0000ofIVI_mVIVH03OmVIVH00ol0003oC4a<oda<C00Coda<C0;o0000Iolc<c<2
o`0001CoC4a<00?o0000ofIVI_mVIVH03_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWo
VIVI00WoVIVI00?o0000ok>c/onc/k<01onc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Ko
i^KV00Coi^KV00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0
003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0
003o/k>cok>c/`07ok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl02_moOgl00ol0
003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000oc<c<olc<c<0Holc<c<00ol0
003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00koIVIV00?o0000ogmoOomoOgl02_moOgl00ol0
003oVIVIoiVIV@08oiVIV@03o`000?nc/k?o/k>c00So/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0
003oi^KVonKViP04onKViP03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool002_o
oooo00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Ko
c<c<00?o0000ok>c/onc/k<01_nc/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?moOgooOgmo00[o
Ogmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<oda<C00Doda<C0;o0000HOlc<c<2o`0001Go
C4a<00?o0000ofIVI_mVIVH03omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00Wo
VIVI00?o0000ok>c/onc/k<01onc/k<00ol0003oc<c<olc<c006olc<c003o`000?oVi^Koi^KV00Co
i^KV00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>c
ok>c/`07ok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl02omoOgl00ol0003oIVIV
ofIVIP0>ofIVIP03o`000?m<C4coC4a<01GoC4a<0_l0001Moc<c<`;o00005_m<C4`00ol0003oIVIV
ofIVIP0?ofIVIP03o`000?moOgooOgmo00[oOgmo00?o0000oiVIVOnIVIT02OnIVIT00ol0003o/k>c
ok>c/`07ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Sooooo00?o
0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Oo/k>c00?o
0000oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmoO`0:ogmoO`03o`000?mVIVKoIVIV00ooIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003o<c<coc<c<`1Ioc<c<`03o`000?m<C4coC4a<01GoC4a<00?o
0000ofIVI_mVIVH03omVIVH00ol0003oOgmoogmoO`0:ogmoO`03o`000?nIVIWoVIVI00WoVIVI00?o
0000ok>c/onc/k<02?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Goi^KV00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`08
ooooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`07
ok>c/`03o`000?nIVIWoVIVI00WoVIVI00?o0000ogmoOomoOgl02omoOgl00ol0003oIVIVofIVIP0?
ofIVIP03o`000?m<C4coC4a<01KoC4a<0_l0001Goc<c<`;o00005om<C4`00ol0003oIVIVofIVIP0@
ofIVIP03o`000?moOgooOgmo00[oOgmo00?o0000oiVIVOnIVIT02OnIVIT00ol0003o/k>cok>c/`08
ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Sooooo00?o0000onKV
i_oVi^H01_oVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00So/k>c00?o0000oiVI
VOnIVIT02OnIVIT00ol0003oOgmoogmoO`0:ogmoO`03o`000?mVIVKoIVIV013oIVIV00?o0000oda<
C?m<C4`05om<C4`00ol0003o<c<coc<c<`1Coc<c<`03o`000?m<C4coC4a<01KoC4a<00?o0000ofIV
I_mVIVH04?mVIVH00ol0003oOgmoogmoO`0:ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c
/onc/k<02?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Goi^KV00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`08ooooo`03
o`000?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`07ok>c/`03
o`000?nIVIWoVIVI00WoVIVI00?o0000ogmoOomoOgl02omoOgl00ol0003oIVIVofIVIP0@ofIVIP03
o`000?m<C4coC4a<01OoC4a<0ol0001?oc<c<`?o00006?m<C4`00ol0003oIVIVofIVIP0AofIVIP03
o`000?moOgooOgmo00[oOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`07ok>c/`03
o`000?o<c<coc<c<00Koc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Sooooo00?o0000onKVi_oVi^H0
1_oVi^H00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00Oo/k>c00?o0000oiVIVOnIVIT0
2_nIVIT00ol0003oOgmoogmoO`0:ogmoO`03o`000?mVIVKoIVIV017oIVIV00?o0000oda<C?m<C4`0
6Om<C4`3o`0004Wo<c<c0ol0000Joda<C003o`000?mVIVKoIVIV017oIVIV00?o0000ogmoOomoOgl0
2_moOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c00So/k>c00?o0000olc<c?o<c<`0
1_o<c<`00ol0003oi^KVonKViP05onKViP03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool002_ooooo0_l0000:ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01_o<
c<`00ol0003o/k>cok>c/`08ok>c/`03o`000?nIVIWoVIVI00WoVIVI00?o0000ogmoOomoOgl02omo
Ogl00ol0003oIVIVofIVIP0AofIVIP03o`000?m<C4coC4a<01_oC4a<1?l00011oc<c<`Co00007?m<
C4`00ol0003oIVIVofIVIP0AofIVIP03o`000?moOgooOgmo00_oOgmo00?o0000oiVIVOnIVIT02_nI
VIT00ol0003o/k>cok>c/`08ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000onKVi_oVi^H01OoV
i^H00ol0003oooooooooo`08ooooo`;o00003?ooool002_ooooo00?o0000ooooooooool02Oooool0
0ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<02?nc/k<0
0ol0003oVIVIoiVIV@09oiVIV@03o`000?moOgooOgmo00coOgmo00?o0000ofIVI_mVIVH04OmVIVH0
0ol0003oC4a<oda<C00Noda<C0?o0000>olc<c<3o`0001ooC4a<00?o0000ofIVI_mVIVH04_mVIVH0
0ol0003oOgmoogmoO`0;ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<02?nc/k<0
0ol0003oc<c<olc<c006olc<c003o`000?oVi^Koi^KV00Goi^KV00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`09ooooo`03o`000?oVi^Koi^KV
00Goi^KV00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`08ok>c/`03o`000?nIVIWoVIVI
00[oVIVI00?o0000ogmoOomoOgl02omoOgl00ol0003oIVIVofIVIP0BofIVIP03o`000?m<C4coC4a<
023oC4a<1?l0000coc<c<`Co00008Om<C4`00ol0003oIVIVofIVIP0BofIVIP03o`000?moOgooOgmo
00_oOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`09ok>c/`03o`000?o<c<coc<c<
00Koc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo000[ooooo`03o`000?oooooooooo00Wooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003o
c<c<olc<c007olc<c003o`000?nc/k?o/k>c00So/k>c00?o0000oiVIVOnIVIT02OnIVIT00ol0003o
OgmoogmoO`0<ogmoO`03o`000?mVIVKoIVIV01;oIVIV0_l0000Toda<C0?o0000;Olc<c<3o`0002?o
C4a<0_l0000DofIVIP03o`000?moOgooOgmo00coOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o
/k>cok>c/`08ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Wooooo
00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o/k>c00So/k>c
00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`0<ogmoO`03o`000?mVIVKoIVIV01?oIVIV
0_l0000Uoda<C0Oo00007olc<c<7o`0002CoC4a<0_l0000EofIVIP03o`000?moOgooOgmo00coOgmo
00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`08ok>c/`03o`000?o<c<coc<c<00Ooc<c<
00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo
000[ooooo`03o`000?oooooooooo00Wooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<
c007olc<c003o`000?nc/k?o/k>c00So/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmo
O`0=ogmoO`03o`000?mVIVKoIVIV01CoIVIV0_l0000Zoda<C0_o00002Olc<c<;o`0002WoC4a<0_l0
000FofIVIP03o`000?moOgooOgmo00goOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c
/`08ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Wooooo00?o0000
onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00Wo/k>c00?o0000
oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`0=ogmoO`03o`000?mVIVKoIVIV01GoIVIV0_l0000c
oda<C0Wo0000<_m<C4`2o`0001OoIVIV00?o0000ogmoOomoOgl03OmoOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c00Wo/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003oi^KVonKViP06
onKViP03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000oooo
ooooool02Oooool00ol0003oi^KVonKViP06onKViP03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c
/onc/k<02Onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00koOgmo00?o0000ofIV
I_mVIVH05_mVIVH00ol0003oC4a<oda<C01Zoda<C003o`000?mVIVKoIVIV01KoIVIV00?o0000ogmo
OomoOgl03_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c00Wo/k>c00?o0000olc<
c?o<c<`01_o<c<`00ol0003oi^KVonKViP06onKViP03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool002_ooooo00?o0000ooooooooool02Oooool00ol0003oi^KVonKViP06onKViP03
o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/onc/k<02?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00koOgmo00?o0000ofIVI_mVIVH05_mVIVH2o`0006SoC4a<0_l0000HofIVIP03
o`000?moOgooOgmo00koOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`08ok>c/`03
o`000?o<c<coc<c<00Ooc<c<00?o0000onKVi_oVi^H01_oVi^H00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Wooooo00?o0000onKVi_oVi^H0
1_oVi^H00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o/k>c00Wo/k>c00?o0000oiVIVOnIVIT0
2_nIVIT00ol0003oOgmoogmoO`0?ogmoO`03o`000?mVIVKoIVIV01OoIVIV0_l0001Toda<C0;o0000
6OmVIVH00ol0003oOgmoogmoO`0?ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0
2Onc/k<00ol0003oc<c<olc<c007olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`09ooooo`03o`000?oV
i^Koi^KV00Koi^KV00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>cok>c/`09ok>c/`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ogmoOomoOgl03omoOgl2o`0001WoIVIV0_l0001Poda<C0;o00006OmV
IVH2o`00017oOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`09ok>c/`03o`000?o<
c<coc<c<00Ooc<c<00?o0000onKVi_oVi^H01_oVi^H00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Wooooo00?o0000onKVi_oVi^H01_oVi^H0
0ol0003oc<c<olc<c007olc<c003o`000?nc/k?o/k>c00Wo/k>c00?o0000oiVIVOnIVIT03?nIVIT0
0ol0003oOgmoogmoO`0@ogmoO`03o`000?mVIVKoIVIV01SoIVIV0ol0001Joda<C0?o00006_mVIVH0
0ol0003oOgmoogmoO`0@ogmoO`03o`000?nIVIWoVIVI00goVIVI00?o0000ok>c/onc/k<02Onc/k<0
0ol0003oc<c<olc<c007olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`09ooooo`03o`000?oV
i^Koi^KV00Koi^KV00?o0000olc<c?o<c<`02?o<c<`00ol0003o/k>cok>c/`09ok>c/`03o`000?nI
VIWoVIVI00coVIVI00?o0000ogmoOomoOgl04?moOgl2o`0001_oIVIV0ol0001Eoda<C0;o00006omV
IVH2o`0001;oOgmo00?o0000oiVIVOnIVIT03OnIVIT00ol0003o/k>cok>c/`09ok>c/`03o`000?o<
c<coc<c<00Soc<c<00?o0000onKVi_oVi^H01_oVi^H00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo00Wooooo00?o0000onKVi_oVi^H0
1_oVi^H00ol0003oc<c<olc<c008olc<c003o`000?nc/k?o/k>c00Wo/k>c00?o0000oiVIVOnIVIT0
3OnIVIT00ol0003oOgmoogmoO`0AogmoO`03o`000?mVIVKoIVIV01_oIVIV1?l0001=oda<C0Co0000
7?mVIVH00ol0003oOgmoogmoO`0AogmoO`03o`000?nIVIWoVIVI00koVIVI00?o0000ok>c/onc/k<0
2Onc/k<00ol0003oc<c<olc<c007olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`004?ooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go0000ooooooooooooooooo`000006ooooo`?o00002Oooool00ol0003oi^KVonKViP07onKViP03
o`000?o<c<coc<c<00Soc<c<00?o0000ok>c/onc/k<02Onc/k<00ol0003oVIVIoiVIV@0=oiVIV@03
o`000?moOgooOgmo017oOgmo0_l0000OofIVIPGo0000@om<C4`5o`0001koIVIV0_l0000CogmoO`03
o`000?nIVIWoVIVI00koVIVI00?o0000ok>c/onc/k<02Onc/k<00ol0003oc<c<olc<c008olc<c003
o`000?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool01oooool3o`0000cooooo000@ooooo`05o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooo
ooooool02Oooool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00Soc<c<00?o0000ok>c
/onc/k<02Onc/k<00ol0003oVIVIoiVIV@0>oiVIV@03o`000?moOgooOgmo01;oOgmo0_l0000RofIV
IPGo0000>Om<C4`5o`00027oIVIV0_l0000DogmoO`03o`000?nIVIWoVIVI00koVIVI00?o0000ok>c
/onc/k<02_nc/k<00ol0003oc<c<olc<c008olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`004?ooool01Ol0003ooooooooooooooooo0000
00_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo00Wooooo00?o0000
onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c008olc<c003o`000?nc/k?o/k>c00Wo/k>c00?o0000
oiVIVOnIVIT03onIVIT00ol0003oOgmoogmoO`0CogmoO`03o`000?mVIVKoIVIV02CoIVIV1Ol0000_
oda<C0Go00009OmVIVH00ol0003oOgmoogmoO`0CogmoO`03o`000?nIVIWoVIVI00ooVIVI00?o0000
ok>c/onc/k<02Onc/k<00ol0003oc<c<olc<c009olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`004?ooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo00Wooooo00?o
0000onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c009olc<c003o`000?nc/k?o/k>c00Wo/k>c00?o
0000oiVIVOnIVIT03onIVIT00ol0003oOgmoogmoO`0CogmoO`;o0000:OmVIVH>o`0001CoC4a<3Ol0
000XofIVIP;o00005OmoOgl00ol0003oVIVIoiVIV@0?oiVIV@03o`000?nc/k?o/k>c00[o/k>c00?o
0000olc<c?o<c<`02?o<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02_ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`09ooooo`03o`000?oVi^Koi^KV00Ooi^KV
00?o0000olc<c?o<c<`02Oo<c<`00ol0003o/k>cok>c/`09ok>c/`03o`000?nIVIWoVIVI013oVIVI
00?o0000ogmoOomoOgl05?moOgl00ol0003oIVIVofIVIP0dofIVIQCo0000=?mVIVH00ol0003oOgmo
ogmoO`0DogmoO`03o`000?nIVIWoVIVI013oVIVI00?o0000ok>c/onc/k<02Onc/k<00ol0003oc<c<
olc<c009olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@06ooooo`03o`000?oooooooooo00Wooooo00?o0000onKVi_oVi^H02?oVi^H00ol0003o
c<c<olc<c009olc<c003o`000?nc/k?o/k>c00Wo/k>c0_l0000AoiVIV@03o`000?moOgooOgmo01Co
Ogmo0ol0001hofIVIP?o00005_moOgl00ol0003oVIVIoiVIV@0@oiVIV@03o`000?nc/k?o/k>c00[o
/k>c00?o0000olc<c?o<c<`02Oo<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool02Oooool00ol0003oi^KV
onKViP08onKViP03o`000?o<c<coc<c<00Woc<c<00?o0000ok>c/onc/k<02onc/k<00ol0003oVIVI
oiVIV@0?oiVIV@03o`000?moOgooOgmo01KoOgmo0ol0001bofIVIP?o00006?moOgl00ol0003oVIVI
oiVIV@0@oiVIV@03o`000?nc/k?o/k>c00[o/k>c00?o0000olc<c?o<c<`02_o<c<`00ol0003oi^KV
onKViP07onKViP03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool002_ooooo00?o
0000ooooooooool02_ooool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00[oc<c<00?o
0000ok>c/onc/k<02onc/k<00ol0003oVIVIoiVIV@0?oiVIV@;o00006OmoOgl4o`0006_oIVIV0ol0
000IogmoO`;o00004_nIVIT00ol0003o/k>cok>c/`0;ok>c/`03o`000?o<c<coc<c<00Woc<c<00?o
0000onKVi_oVi^H02?oVi^H00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo000[
ooooo`03o`000?oooooooooo00[ooooo00?o0000onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c00:
olc<c003o`000?nc/k?o/k>c00co/k>c00?o0000oiVIVOnIVIT04?nIVIT2o`0001_oOgmo0ol0001T
ofIVIPCo00006_moOgl2o`0001?oVIVI00?o0000ok>c/onc/k<03?nc/k<00ol0003oc<c<olc<c009
olc<c003o`000?oVi^Koi^KV00Soi^KV00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`00:oooool00ol0003oooooooooo`0:ooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<
c?o<c<`02_o<c<`00ol0003o/k>cok>c/`0=ok>c/`03o`000?nIVIWoVIVI017oVIVI0_l0000Logmo
O`Co0000GOmVIVH3o`0001coOgmo0_l0000DoiVIV@03o`000?nc/k?o/k>c00co/k>c00?o0000olc<
c?o<c<`02_o<c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02_ooool002_ooooo00?o0000ooooooooool02_ooool00ol0003oi^KVonKViP08onKViP03
o`000?o<c<coc<c<00[oc<c<00?o0000ok>c/onc/k<03Onc/k<00ol0003oVIVIoiVIV@0BoiVIV@;o
00007_moOgl3o`0005OoIVIV0ol0000MogmoO`;o00005OnIVIT00ol0003o/k>cok>c/`0=ok>c/`03
o`000?o<c<coc<c<00[oc<c<00?o0000onKVi_oVi^H02?oVi^H00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00[ooooo00?o0000onKVi_oVi^H0
2?oVi^H00ol0003oc<c<olc<c00:olc<c003o`000?nc/k?o/k>c00ko/k>c00?o0000oiVIVOnIVIT0
4onIVIT2o`0001ooOgmo1_l0001<ofIVIPGo00007_moOgl2o`0001KoVIVI00?o0000ok>c/onc/k<0
3Onc/k<00ol0003oc<c<olc<c00;olc<c003o`000?oVi^Koi^KV00Soi^KV00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`0:ooooo`03o`000?oV
i^Koi^KV00Soi^KV00?o0000olc<c?o<c<`02oo<c<`00ol0003o/k>cok>c/`0>ok>c/`03o`000?nI
VIWoVIVI01CoVIVI0ol0000RogmoO`Oo0000?_mVIVH7o`00027oOgmo0_l0000GoiVIV@03o`000?nc
/k?o/k>c00ko/k>c00?o0000olc<c?o<c<`02_o<c<`00ol0003oi^KVonKViP09onKViP03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool02_ooool0
0ol0003oi^KVonKViP08onKViP03o`000?o<c<coc<c<00_oc<c<00?o0000ok>c/onc/k<03onc/k<0
0ol0003oVIVIoiVIV@0FoiVIV@;o00009omoOgl7o`00033oIVIV1ol0000VogmoO`;o00006?nIVIT0
0ol0003o/k>cok>c/`0>ok>c/`03o`000?o<c<coc<c<00_oc<c<00?o0000onKVi_oVi^H02?oVi^H0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo
00[ooooo00?o0000onKVi_oVi^H02?oVi^H00ol0003oc<c<olc<c00<olc<c003o`000?nc/k?o/k>c
00oo/k>c00?o0000oiVIVOnIVIT05onIVIT2o`0002coOgmo3_l0000DofIVIPko0000:omoOgl2o`00
01WoVIVI00?o0000ok>c/onc/k<03onc/k<00ol0003oc<c<olc<c00;olc<c003o`000?oVi^Koi^KV
00Soi^KV00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`00:oooool2o`0000_o
oooo00?o0000onKVi_oVi^H02OoVi^H00ol0003oc<c<olc<c00;olc<c003o`000?nc/k?o/k>c013o
/k>c00?o0000oiVIVOnIVIT06?nIVIT2o`0003SoOgmo5?l0000gogmoO`;o00006_nIVIT00ol0003o
/k>cok>c/`0?ok>c/`03o`000?o<c<coc<c<00coc<c<00?o0000onKVi_oVi^H02?oVi^H00ol0003o
ooooooooo`0:ooooo`;o00003?ooool002_ooooo00?o0000ooooooooool02_ooool00ol0003oi^KV
onKViP09onKViP03o`000?o<c<coc<c<00_oc<c<00?o0000ok>c/onc/k<04Onc/k<00ol0003oVIVI
oiVIV@0IoiVIV@;o0000OomoOgl2o`0001_oVIVI00?o0000ok>c/onc/k<04?nc/k<00ol0003oc<c<
olc<c00;olc<c003o`000?oVi^Koi^KV00Woi^KV00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0:ooooo`00:oooool00ol0003oooooooooo`0:ooooo`03o`000?oVi^Koi^KV00Woi^KV00?o
0000olc<c?o<c<`03?o<c<`00ol0003o/k>cok>c/`0Aok>c/`;o00006onIVIT3o`0007SoOgmo1?l0
000KoiVIV@;o00004_nc/k<00ol0003oc<c<olc<c00<olc<c003o`000?oVi^Koi^KV00Woi^KV00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`0:
ooooo`03o`000?oVi^Koi^KV00Woi^KV00?o0000olc<c?o<c<`03Oo<c<`00ol0003o/k>cok>c/`0B
ok>c/`03o`000?nIVIWoVIVI01_oVIVI1?l0001`ogmoO`Co00007OnIVIT2o`0001?o/k>c00?o0000
olc<c?o<c<`03Oo<c<`00ol0003oi^KVonKViP09onKViP03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02_ooool002_ooooo00?o0000ooooooooool02_ooool00ol0003oi^KVonKViP0:onKV
iP03o`000?o<c<coc<c<00goc<c<00?o0000ok>c/onc/k<04_nc/k<2o`0001ooVIVI1Ol0001Wogmo
O`Co00007onIVIT2o`0001Co/k>c00?o0000olc<c?o<c<`03Oo<c<`00ol0003oi^KVonKViP0:onKV
iP03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000oooooooo
ool02oooool00ol0003oi^KVonKViP09onKViP03o`000?o<c<coc<c<00koc<c<00?o0000ok>c/onc
/k<04onc/k<2o`0002;oVIVI1?l0001OogmoO`Co00008_nIVIT00ol0003o/k>cok>c/`0Cok>c/`03
o`000?o<c<coc<c<00koc<c<00?o0000onKVi_oVi^H02OoVi^H00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00_ooooo00?o0000onKVi_oVi^H0
2_oVi^H00ol0003oc<c<olc<c00>olc<c003o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT0
8onIVIT4o`0005OoOgmo1?l0000ToiVIV@;o00005Onc/k<00ol0003oc<c<olc<c00>olc<c003o`00
0?oVi^Koi^KV00[oi^KV00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`00:ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oVi^Koi^KV00_oi^KV00?o0000olc<c?o<c<`03_o<
c<`00ol0003o/k>cok>c/`0Dok>c/`?o00009_nIVIT7o`0004WoOgmo1ol0000UoiVIV@?o00005_nc
/k<00ol0003oc<c<olc<c00>olc<c003o`000?oVi^Koi^KV00_oi^KV00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`0<ooooo`03o`000?oVi^Ko
i^KV00_oi^KV00?o0000olc<c?o<c<`03_o<c<`00ol0003o/k>cok>c/`0Fok>c/`?o0000:_nIVIT;
o`0003?oOgmo2ol0000YoiVIV@?o00006?nc/k<00ol0003oc<c<olc<c00>olc<c003o`000?oVi^Ko
i^KV00coi^KV00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0
003oooooooooo`0<ooooo`03o`000?oVi^Koi^KV00coi^KV00?o0000olc<c?o<c<`03_o<c<`2o`00
01Wo/k>c1?l0000aoiVIVC?o0000<?nIVIT4o`0001Wo/k>c0_l0000@olc<c003o`000?oVi^Koi^KV
00coi^KV00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oVi^Koi^KV00goi^KV00?o0000olc<c?o<c<`03oo<c<`2o`0001_o
/k>c0ol0002>oiVIV@?o00006onc/k<2o`00017oc<c<00?o0000onKVi_oVi^H03OoVi^H00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00cooooo
00?o0000onKVi_oVi^H03_oVi^H00ol0003oc<c<olc<c00@olc<c0;o00007?nc/k<4o`0008KoVIVI
1?l0000Lok>c/`;o00004_o<c<`00ol0003oi^KVonKViP0>onKViP03o`000?oooooooooo00gooooo
00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool03Oooool00ol0003oi^KVonKV
iP0>onKViP03o`000?o<c<coc<c<017oc<c<0_l0000Nok>c/`?o0000P?nIVIT3o`0001ko/k>c0_l0
000Colc<c003o`000?oVi^Koi^KV00ooi^KV00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0:ooooo`00:oooool00ol0003oooooooooo`0=ooooo`03o`000?oVi^Koi^KV00ooi^KV00?o0000
olc<c?o<c<`04_o<c<`2o`0001oo/k>c1_l0001eoiVIV@Go00007onc/k<2o`0001Coc<c<00?o0000
onKVi_oVi^H03ooVi^H00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo000[oooo
o`03o`000?oooooooooo00gooooo00?o0000onKVi_oVi^H04?oVi^H00ol0003oc<c<olc<c00Colc<
c0?o00008_nc/k<7o`0006OoVIVI1ol0000Qok>c/`?o00005Oo<c<`00ol0003oi^KVonKViP0@onKV
iP03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool002_ooooo0_l0000?ooooo`03
o`000?oVi^Koi^KV013oi^KV00?o0000olc<c?o<c<`05Oo<c<`2o`0002Oo/k>c1ol0001IoiVIV@Oo
00009_nc/k<2o`0001Ooc<c<00?o0000onKVi_oVi^H04OoVi^H00ol0003oooooooooo`0=ooooo`;o
00003?ooool002_ooooo00?o0000ooooooooool03_ooool00ol0003oi^KVonKViP0AonKViP03o`00
0?o<c<coc<c<01Koc<c<0_l0000/ok>c/`ko0000?_nIVIT=o`0002_o/k>c0_l0000Holc<c003o`00
0?oVi^Koi^KV01;oi^KV00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`00:ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oVi^Koi^KV01;oi^KV00?o0000olc<c?o<c<`05oo<
c<`2o`0003So/k>c5Ol0000DoiVIVAGo0000=_nc/k<2o`0001Woc<c<00?o0000onKVi_oVi^H04ooV
i^H00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooo
oooo00kooooo00?o0000onKVi_oVi^H04ooVi^H00ol0003oc<c<olc<c00Holc<c0;o0000Bonc/k<D
o`0004Wo/k>c0_l0000Jolc<c003o`000?oVi^Koi^KV01?oi^KV00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`0?ooooo`03o`000?oVi^Koi^KV
01?oi^KV00?o0000olc<c?o<c<`06Oo<c<`5o`0009oo/k>c1?l0000Kolc<c003o`000?oVi^Koi^KV
01Coi^KV00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oVi^Koi^KV01Coi^KV00?o0000olc<c?o<c<`07Oo<c<`7o`00097o
/k>c1ol0000Nolc<c003o`000?oVi^Koi^KV01Goi^KV00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`0?ooooo`03o`000?oVi^Koi^KV01Goi^KV
00?o0000olc<c?o<c<`08oo<c<`7o`0008?o/k>c1ol0000Tolc<c003o`000?oVi^Koi^KV01Koi^KV
00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oVi^Koi^KV01Goi^KV00?o0000olc<c?o<c<`0:Oo<c<`5o`0007So/k>c1_l0
000Zolc<c003o`000?oVi^Koi^KV01Koi^KV00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0:ooooo`00:oooool00ol0003oooooooooo`0@ooooo`03o`000?oVi^Koi^KV01Koi^KV0ol0000]
olc<c0_o0000Honc/k<:o`0002koc<c<0_l0000IonKViP03o`000?oooooooooo013ooooo00?o0000
ooooooooool02_ooool002_ooooo00?o0000ooooooooool04?ooool00ol0003oi^KVonKViP0IonKV
iP?o0000=Oo<c<`Co`0003ko/k>c4_l0000dolc<c0Co00006_oVi^H00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo017ooooo00?o0000onKVi_oV
i^H06ooVi^H4o`0004Coc<c<?_l00012olc<c0Co00007OoVi^H00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo01;ooooo00?o0000onKVi_oVi^H0
7_oVi^H5o`000;[oc<c<1Ol0000PonKViP03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
2_ooool002_ooooo00?o0000ooooooooool04oooool00ol0003oi^KVonKViP0RonKViPCo0000/_o<
c<`4o`0002Coi^KV00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:ooooo`00:oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oVi^Koi^KV02Goi^KV1?l0002Zolc<c0Co00009ooVi^H0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00[ooooo000[ooooo`;o00005_ooool00ol0
003oi^KVonKViP0XonKViPOo0000W?o<c<`7o`0002[oi^KV00?o0000ooooooooool05Oooool2o`00
00cooooo000[ooooo`03o`000?oooooooooo01Kooooo00?o0000onKVi_oVi^H0;_oVi^H;o`0008Ko
c<c<2ol0000`onKViP03o`000?oooooooooo01Oooooo00?o0000ooooooooool02_ooool002_ooooo
00?o0000ooooooooool05oooool3o`0003Soi^KV4?l0001Wolc<c0oo0000>?oVi^H3o`0001[ooooo
00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool06_ooool4o`0004Coi^KVIol0
0013onKViPCo00007Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`0N
ooooo`Go0000i?oVi^H5o`00027ooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000oooo
ooooool08oooool4o`000=coi^KV1?l0000Vooooo`03o`000?oooooooooo00[ooooo000[ooooo`03
o`000?oooooooooo02Oooooo1?l0003DonKViPCo0000:_ooool00ol0003oooooooooo`0:ooooo`00
:oooool00ol0003oooooooooo`0[ooooo`Oo0000a_oVi^H7o`0002kooooo00?o0000ooooooooool0
2_ooool002_ooooo00?o0000ooooooooool0<_ooool;o`000;3oi^KV2ol0000eooooo`03o`000?oo
oooooooo00[ooooo000[ooooo`03o`000?oooooooooo03gooooo9Ol0001WonKViRCo0000@?ooool0
0ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`1RooooofOo0000I?ooool00ol0
003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`3oooooobkooooo00?o0000oooooooo
ool02_ooool0027ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
;_ooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo;_ooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo;_ooool00ol0003oooooooooo`0:ooooo`008oooool00ol0
003oooooooooo`05ooooo`?o0000ooooool/ooooo`?o00003?ooool002?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooobkooooo00?o0000ooooooooool02_ooool002?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooobkooooo00?o0000ooooooooool0
2_ooool002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooobkooooo00?o
0000ooooooooool02_ooool0027ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02_ooool002_oooooool0000bo`0000cooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003Booooo`05ob4Q8Ol0003o0000odA4A?oMgMd0C_ooool3o`00
0003oa0@4?oooooooooo03gooooo003Eooooo`03ogMgMolb<S;ooooo04oooooo00?o0000oooooooo
ool0?_ooool00=Kooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0nooooo`008ooo
ool3o`000003oa0@4?oooooooooo00;ooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h3ooooo`05
oiRHV?l0003o0000odA4A?nj^[X00_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P;ooooo00Co
410@o`000?l0003ooooo0_l000001?l@413ooooooooooonHV9P2o`000003odA4A?nj^[[ooooo00;o
oooo1Ol00002ooooo`06oiRHV?l0003o0000ogMgMol@413o00000_ooool5o`0000Oooooo1Ol00002
ooooo`04oa0@4?l0003o0000ooooo`;o000000Co410@ooooool@413o<S8b0_l000000ol@413oZJVY
ooooo`02ooooo`Go00000_ooool02_o^k^koEEEEo`000?l0003oV9RHo`000?l@413oooooonk^k_mE
EED2o`000003odA4A?nj^[[ooooo00Gooooo00KoV9RHo`000?l0003oMgMgoa0@4?l0000:ooooo`05
ofIVI_l0003o0000odA4A?o<c<`00_ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooo
V9RH00;o000000GoMgMgoa0@4?l0003ooooooa0@4005o`0000?ooooo00Kok^k^oeEEEOl0003o410@
olc<c?l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj1oooool00ol@413o0000o`000002
o`000004oa0@4?ooooooooooooooo`Go00000_ooool5o`0000?ooooo1Ol00003ooooo`06onk^k_mE
EEGo0000o`000?m4A4Co^[Zj0_ooool01oo^k^koEEEEo`000?l0003oV9RHo`000?l@41001Oooool0
1_l@413o<S8bo`000?l0003o410@ojVYZ@;ooooo00Kok^k^oeEEEOl0003o0000ogMgMol00003oooo
o`08oiRHV?l0003o0000ogMgMol0003o410@oooooonHV9P2o`000005ogMgMol@413o0000ooooool@
41001Ol00003ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj1oooool00ol@413o0000ohN7Q`02
o`000005ofIVI_o^k^koooooonk^k_mEEED00_l000001?mEEEGok^k^ooooooooool2o`0000;ooooo
0_l00003ooooo`009?ooool00ol0003oooooooooo`04ooooo`06oeEEEOmgMgOooooooooooomgMgOo
EEEE0oooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@
4103ooooo`05o`000?ooooooooooooooool000000oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Go
oooo00?o0000ooooooooool00_ooool01Ol0003oc<c<onk^k_n7QhOo000000Gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool0
1_l0003oZJVYoooooooooooo^[Zjo`0000Gooooo00?o0000ooooooooool00_ooool01_mEEEGoMgMg
ooooooo^k^koEEEEo`0000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4106ooooo`05o`000?o<
c<cok^k^ohN7Qol000002_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@40?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`05o`000?o<c<cok^k^ohN7Qol000001?ooool00ol0003ooooooooo
o`04ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00000_ooool01_mEEEGoMgMgooooooo^k^koMgMg
oa0@40Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo
00KoEEEEogMgMoooooook^k^oeEEEOl00006ooooo`06o`000?nYZJWooooooooooonj^[[o00000_oo
ool01_mEEEGoMgMgooooooo^k^koEEEEo`0000?ooooo00Go0000ojVYZOooooooQhN7o`000002oooo
o`05o`000?o<c<cok^k^ohN7Qol000001?ooool00ol0003oooooooooo`04ooooo`06oeEEEOmgMgOo
ooooonk^k_mgMgOo410@2?ooool02Ol0003oEEEEonk^k_ooooooMgMgofIVI_ooooooEEEEogMgM`02
ooooo`0:ogMgMomEEEGoooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo000Tooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`02ooooo`05oa0@4?n7QhOoooooonk^k_l000001Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05okZj^_n7QhOoIVIVofIVI_l@41001Oooool00ol0003oooooooooo`02ooooo`06
o`000?ooooooooooooooooo^k^ko00000_ooool00ol0003oooooooooo`09ooooo`05oa0@4?n7QhOo
ooooonk^k_l000002_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol@413oQhN7ooooooo^k^ko000000Cooooo00?o0000ooooooooool01?ooool01_l0003o
ooooooooooooooook^k^o`0000;ooooo00?o0000ooooooooool00_ooool6o`0000Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`05ooooo`06o`000?ooooooooooooooooo^k^ko0000
1oooool01Onj^[[oQhN7ofIVI_mVIVKo410@00;ooooo00Ko0000ooooooooooooooooonk^k_l00003
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol@413oQhN7ooooooo^k^ko000000Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?o^k^kooooo00;ooooo
00?o0000ooooool000001?ooool02?l0003ooooooooooooooooogMgMo`000?l@413oc<c<1?ooool0
02Cooooo0ol000001OlQ8B7oc<c<oooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0006ooooo`Ko00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`03okZj^_l@413o000000;o00001Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`06
oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^1Oooool00ol0003oooooooooo`02ooooo`06o`000?oooooo
ooooooooooo^k^ko00000_ooool6o`0000Kooooo00?o^[Zjoa0@4?l000000_l0000:ooooo`03o`00
0?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000002ooooo`03okZj^_l@413o000000;o
00001?ooool00ol0003oooooooooo`04ooooo`06o`000?ooooooooooooooooo^k^ko00000_ooool6
o`0000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool6o`0000;ooooo00Ko0000ooooooooooooooooonk^
k_l00006ooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^0_ooool01_l0003ooooooooooooooooo
k^k^o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`03okZj^_l@413o000000;o0000
1?ooool00ol0003oooooooooo`04ooooo`Ko00002?ooool00ol0003ok^k^ooooo`02ooooo`03o`00
0?oooooo000000Cooooo00So0000ooooooooooooooooonk^k_lQ8B7o410@onk^kPCooooo000Toooo
o`05o`000?ooooooooooohN7Qol@41000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@?ooooo
00?o0000ooooooooool01?ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00Go0000ohN7
QoooooooZJVYo`000003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool0
0oo<c<co0000ooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool0
1Ol0003oQhN7oooooonYZJWo000000;ooooo00Ko0000okZj^_ooooook^k^ogMgMol00005ooooo`03
o`000?oooooooooo00;ooooo00KoIVIVogMgMoooooook^k^oeEEEOl00002ooooo`06oeEEEOn7QhOo
k^k^oooooon7QhOo<S8b2Oooool00oo<c<co0000ooooo`09ooooo`06ofIVI_mgMgOooooooooooon7
QhOo00000oooool01Ol0003oMgMgoooooonYZJWo000000Gooooo00?oc<c<o`000?ooool00oooool0
0ol0003o<S8bomgMg@04ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00000_ooool01_mEEEGoQhN7
onk^k_ooooooQhN7oc8b<PWooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01_mEEEGoQhN7onk^k_oooooo
QhN7oc8b<P;ooooo00KoIVIVogMgMoooooook^k^oeEEEOl00006ooooo`06o`000?nj^[[oooooonk^
k_mgMgOo00000_ooool01_mVIVKoMgMgooooooo^k^koEEEEo`0000?ooooo00Go0000oooooooooooo
ooooo`000005ooooo`03olc<c?l0003ooooo00?ooooo00?o0000oc8b<_oMgMd01?ooool01_mEEEGo
QhN7onk^k_ooooooQhN7oc8b<PSooooo00Wo0000oeEEEOo^k^koooooogMgMomEEEGooooooeEEEOmg
MgL00_ooool00omgMgOoEEEEooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<PCooooo000Tooooo`05
o`000?ooooooooooooooool000000_ooool02?o^k^koEEEEo`000?l0003oEEEEonk^k_oooooo410@
1Ol00003ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool00ol@413o0000ogMgM`02o`00
0003oiRHV?oooooo410@00Go00001?ooool00ol@413o0000o`000005ooooo`04oc8b<_l0003o0000
oiRHV0Gooooo00?o0000ooooooooool01oooool00ol@413o0000o`000004ooooo`03oa0@4?l0003o
MgMg00;o000000GoV9RHooooooooooooZJVYob4Q8@02o`000003oc8b<_l0003ooooo00;ooooo00?o
410@o`000?l000001?ooool01_o^k^koEEEEo`000?l@413oc<c<o`0000;ooooo00Kok^k^oeEEEOl0
003o0000odA4A?o^k^h7ooooo`04oc8b<_l0003o0000oiRHV0[ooooo00Kok^k^ofIVI_l0003o0000
odA4A?l00003ooooo`05o`000?mgMgOo0000o`000?nHV9P00oooool01?lb<S;o0000o`000?nHV9P3
ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool02_o^k^koEEEEo`000?lQ8B7oZJVYo`000?l@
413oooooonk^k_mEEED2o`000003odA4A?o^k^kooooo00Kooooo00?o410@o`000?l000000ol00003
ooooo`03oa0@4?l0003o000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_o^k^koEEEEo`000?l@413oc<c<o`00
00Kooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`0:onk^k_mEEEGo0000o`000?mgMgOo
0000oa0@4?oooooo410@o`0000;ooooo0_l00003ooooo`04oc8b<_l0003o0000oiRHV0?ooooo0_l0
00001?nYZJWo8B4Qo`000?lQ8B42ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^2?ooool02Ol0
003oc<c<oa0@4?l0003oEEEEonk^k_ooooook^k^oeEEE@02o`000004oeEEEOo^k^koooooooooo`;o
00000_ooool2o`0000?ooooo000Tooooo`05o`000?ooooooooooohN7Qol@41002oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`0Eooooo`008oooool4o`000003ob4Q8Oo<c<cooooo00[ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0[ooooo`03oa0@4?nj^[[ooooo00Kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`0Eooooo`00E_ooool00ol@413oooooooooo`0:ooooo`03oa0@4?l0
003o000000_ooooo00?o410@ooooooooool05Oooool00ol@413oooooooooo`06ooooo`;o00009Ooo
ool00ol@413o0000ooooo`0/ooooo`04okZj^_l@413o0000oa0@40Gooooo00?o410@ooooooooool0
0_ooool00ol@413o0000o`000005ooooo`03oa0@4?l0003o0000017ooooo0_l0000kooooo`03oa0@
4?l0003ooooo01Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.167753, -0.133128, \
0.00427501, 0.00427501}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Nonrectangular Boundaries", "Section",
  CellTags->{"i:31", "c:24"}],

Cell["\<\
The same direct method of solution can be used for Poisson's \
equation in domains with nonrectangular boundaries. We will assume for now \
that the boundary can be matched to some rectangular grid, so that grid \
points fall on the boundary. The grid is chosen as\
\>", "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(x\_j\), "=", 
          RowBox[{\(x\_o\), "+", " ", 
            RowBox[{"j", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j = f(k), f(k) + 1,  ... , g(k)\)]],
  ",\n\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(y\_k\), "=", 
          RowBox[{\(y\_o\), "+", 
            RowBox[{"k", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]]}]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`k = 0, 1, 2,  ... , M\_y\)]],
  ","
}], "NE2",
  CellTags->"(6.2.35)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "=", \(L\_x/M\_x\)}], 
        TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["y",
                FontSlant->"Italic"]}]], "=", \(L\_y/M\_y\)}], 
        TraditionalForm]]],
  "; ",
  Cell[BoxData[
      \(TraditionalForm\`f(k)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g(k)\)]],
  " are two integer functions that determine the left and right edges of the \
domain respectively; and ",
  Cell[BoxData[
      \(TraditionalForm\`L\_x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`L\_y\)]],
  " are the dimensions of a rectangular box that is sufficiently large to \
contain the domain of interest. ( This procedure does not work very well for \
smoothly curved boundaries, as we will see. )"
}], "Text"],

Cell[TextData[{
  "\tThe equations for the interior points are the same as Eq. ",
  ButtonBox["(6.2.34)",
    ButtonData:>"(6.2.34)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[
              
              FormBox[\(\[Phi]\_\(j + 1\ k\) - 
                  2\ \[Phi]\_\(j\ k\) + \ \[Phi]\_\(j - 1\ k\)\),
                "TraditionalForm"], 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"]], "+", 
            FractionBox[
              
              FormBox[\(\[Phi]\_\(j\ k + 1\) - 
                  2\ \[Phi]\_\(j\ k\) + \ \[Phi]\_\(j\ k - 1\)\),
                "TraditionalForm"], 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["y",
                      FontSlant->"Italic"]}]], "2"]]}], 
          "=", \(\[Rho]\_\(j\ k\)\)}], TraditionalForm]]],
  ",     ",
  Cell[BoxData[
      \(TraditionalForm\`j = f(k) + 1, \(\(...\)\(\ \)\(g(k)\)\) - 
        1, \[IndentingNewLine]k = 1, 2,  ... , M\_y\  - 1. \)]]
}], "NE2",
  CellTags->"(6.2.36)"],

Cell[TextData[{
  "These equations for the potential in the interior of the box are \
supplemented by the boundary conditions on the box edges, which directly \
determine ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(j\ k\)\)]],
  " on the boundary points."
}], "Text"],

Cell[TextData[{
  "\tWe again solve this problem directly using ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This time we choose a Laplace equation problem, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 \[Phi] = 0\)]],
  ", with boundary conditions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Phi]", "=", 
          RowBox[{\(V\_o\), "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  " on the domain boundary."
}], "Text"],

Cell[BoxData[{
    \(\(\(Clear["\<Global`*\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(M\_x = 30; \ M\_y = 30;\), "\n", 
    \(L\_x = \ 2; \ L\_y = \ 2;\), "\n", 
    \(\[CapitalDelta]x = L\_x/M\_x; \ \[CapitalDelta]y = L\_y/M\_y;\), "\n", 
    \(x0\  = \ \(-1\); \ y0 = \(-1\);\), "\n", 
    \(\(x[j_]\  = \ x0\  + \ j\ \[CapitalDelta]x;\)\), "\n", 
    \(\(y[k_]\  = y0\  + \ k\ \[CapitalDelta]y;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.94"],

Cell["\<\
The boundary conditions are specified by the following statements: \
\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox[\( (*\ boundary\ conditions\ *) \),
        FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
      " ", \(\(\[Phi][j_, k_]\  := \ \ V0[j, k] /; \ 
            j \[LessEqual] \ f[k];\)\[IndentingNewLine]
      \(\[Phi][j_, k_]\  := \ 
          V0[j, k]\  /; \ j \[GreaterEqual] \ g[k];\)\[IndentingNewLine]
      \(\[Phi][j_, 0]\  := \ V0[j, 0];\)\[IndentingNewLine]
      \(\[Phi][j_, M\_y]\  := \ V0[j, M\_y];\)\)}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.95"],

Cell[TextData[{
  "\tLet's choose the following equations for the boundaries : ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2 + y\^2 = 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x\  = \ \(-\(\(|\)\(y\)\(|\)\)\)\)]],
  ". This boundary, shown in Cell ",
  ButtonBox["6.99",
    ButtonData:>"Cell 6.99",
    ButtonStyle->"Hyperlink"],
  ",  is the same as that chosen in Example 3 of Sec. ",
  ButtonBox["6.1",
    ButtonData:>"c:8",
    ButtonStyle->"Hyperlink"],
  ", except that it is rotated by 90 degrees. "
}], "Text"],

Cell[TextData[{
  "We choose boundary conditions ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(V\_o\), "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox[\(1\  - \ r\^2\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  " on the cusp surfaces, and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(V\_o\), "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["0",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " on the circular part of the boundary:"
}], "Text"],

Cell[BoxData[{
    \(\(V0[j_, k_]\  := \ 
        0\  /; \ \ Abs[y[k]] \[GreaterEqual] \ 1/Sqrt[2]\  || \ 
            x[j] > \ 0;\)\), "\n", 
    \(V0[j_, k_]\  := \ 
      1\  - \ x[j]^2\  - \ y[j]^2\  /; \ 
        Abs[\ y[k]]\  < \ 1/Sqrt[2]\  && \ x[j] \[LessEqual] \ 0\)}], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 6.96"],

Cell[TextData[{
  "\tTo determine the integer functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(f(k)\)\ and\ \(g(k)\)\)]],
  " that best fit this boundary, we will first break the boundary up into \
left and right boundaries, ",
  Cell[BoxData[
      \(TraditionalForm\`x(y)\  = \ \(x\_R\)(y)\)]],
  " on the right and ",
  Cell[BoxData[
      \(TraditionalForm\`x(y) = \(x\_L\)(y)\)]],
  " on the left. For our example, equations for the left and right boundaries \
are of the following form:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(x\_R\)(
          y)\  = \@\(1 - y\^2\)\)\(\ \)\(,\)\)\)]]
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_L\)(
          y)\  = \ \(-\@\(1 - y\^2\)\), \ \(\(|\)\(y\)\(|\)\(\(>\)\(1/\@\(\(2\
\)\(,\)\)\)\)\)\)]]
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_L\)(
          y) = \(-\(\(|\)\(y\)\(|\)\)\), \ \(\(|\)\(y\)\(|\)\(\(<\)\(\ \
\)\(\(1/\@2. \)\(\ \)\)\)\)\)]],
  " "
}], "Text"],

Cell[TextData[{
  "Then the integer functions ",
  Cell[BoxData[
      \(TraditionalForm\`f(k)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g(k)\)]],
  " are determined by the values of ",
  Cell[BoxData[
      \(TraditionalForm\`j(k)\)]],
  " corresponding to these boundary equations. Using ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(x(j)\), " ", "=", " ", 
          RowBox[{
            RowBox[{\(x\_o\), " ", "+", " ", 
              RowBox[{"j", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]]}]}], 
            "=", \(\(x\_R\)(y(k))\)}]}], TraditionalForm]]],
  "on the right boundary yields ",
  Cell[BoxData[
      FormBox[
        RowBox[{"j", "=", " ", 
          RowBox[{\((\(x\_R\)(y(k)) - x\_o)\), "/", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ". Rounding down to the nearest integer we obtain the value of ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " corresponding to the right boundary at ",
  Cell[BoxData[
      \(TraditionalForm\`y = y(k)\)]],
  ". This is our function ",
  Cell[BoxData[
      \(TraditionalForm\`g(k)\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(g(k)\), "=", 
          RowBox[{"Floor", "(", 
            FractionBox[\(\(x\_R\)(y(k)) - x\_o\), 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]], ")"}]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.37)"],

Cell[" Similarly, on the left boundary,   ", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(f(k)\), "=", 
          RowBox[{
            RowBox[{"Floor", "(", 
              FractionBox[\(\(x\_L\)(y(k)) - x\_o\), 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]]], ")"}], "."}]}], 
        TraditionalForm]]]
}], "NE2",
  CellTags->"(6.2.38)"],

Cell[TextData[{
  " These integer functions are defined below using the above definitions of \
",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_R\)(y)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_L\)(y)\)]],
  ":\t"
}], "Text"],

Cell[BoxData[{
    \(\(g[k_]\  := 
        Floor[\(1\/\[CapitalDelta]x\) \((\(-x0\)\  + \ 
                Sqrt[1\  - \ y[k]^2])\)\ ];\)\), "\n", 
    \(\(f[k_]\  := \ 
        Floor[\(1\/\[CapitalDelta]x\) \((\(-x0\)\  - \ 
                  Sqrt[1\  - \ y[k]^2]\ )\)] /; \ 
          Abs[y[k]\ ] > \ 1/Sqrt[2];\)\), "\n", 
    \(f[k_]\  := 
      Floor[\(1\/\[CapitalDelta]x\) \((\(-x0\)\  - 
                Abs[y[k]])\)]\  /; \ \ Abs[\ y[k]]\  \[LessEqual] \ \ 1/
            Sqrt[2]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.97"],

Cell[TextData[{
  "The shape of this domain is shown in Cell ",
  ButtonBox["6.98",
    ButtonData:>"Cell 6.98",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[
        Join[Table[{x[f[k]], \ y[k]}, {k, 0, M\_y}], 
          Table[{x[g[k]], \ y[k]}, {k, 0, 
              M\_y}]], \[IndentingNewLine]AspectRatio \[Rule] 1, 
        AxesOrigin \[Rule] {\(-1.2\), \(-1.2\)}, 
        PlotRange \[Rule] {{\(-1.2\), 1.2}, {\(-1.2\), 1.2}}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.98"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.416667 0.5 0.416667 [
[.08333 -0.0125 -6 -9 ]
[.08333 -0.0125 6 0 ]
[.29167 -0.0125 -12 -9 ]
[.29167 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.70833 -0.0125 -9 -9 ]
[.70833 -0.0125 9 0 ]
[.91667 -0.0125 -3 -9 ]
[.91667 -0.0125 3 0 ]
[-0.0125 .08333 -12 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .29167 -24 -4.5 ]
[-0.0125 .29167 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .70833 -18 -4.5 ]
[-0.0125 .70833 0 4.5 ]
[-0.0125 .91667 -6 -4.5 ]
[-0.0125 .91667 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08333 0 m
.08333 .00625 L
s
[(-1)] .08333 -0.0125 0 1 Mshowa
.29167 0 m
.29167 .00625 L
s
[(-0.5)] .29167 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.70833 0 m
.70833 .00625 L
s
[(0.5)] .70833 -0.0125 0 1 Mshowa
.91667 0 m
.91667 .00625 L
s
[(1)] .91667 -0.0125 0 1 Mshowa
.125 Mabswid
.125 0 m
.125 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.875 0 m
.875 .00375 L
s
.04167 0 m
.04167 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08333 m
.00625 .08333 L
s
[(-1)] -0.0125 .08333 1 0 Mshowa
0 .29167 m
.00625 .29167 L
s
[(-0.5)] -0.0125 .29167 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .70833 m
.00625 .70833 L
s
[(0.5)] -0.0125 .70833 1 0 Mshowa
0 .91667 m
.00625 .91667 L
s
[(1)] -0.0125 .91667 1 0 Mshowa
.125 Mabswid
0 .125 m
.00375 .125 L
s
0 .16667 m
.00375 .16667 L
s
0 .20833 m
.00375 .20833 L
s
0 .25 m
.00375 .25 L
s
0 .33333 m
.00375 .33333 L
s
0 .375 m
.00375 .375 L
s
0 .41667 m
.00375 .41667 L
s
0 .45833 m
.00375 .45833 L
s
0 .54167 m
.00375 .54167 L
s
0 .58333 m
.00375 .58333 L
s
0 .625 m
.00375 .625 L
s
0 .66667 m
.00375 .66667 L
s
0 .75 m
.00375 .75 L
s
0 .79167 m
.00375 .79167 L
s
0 .83333 m
.00375 .83333 L
s
0 .875 m
.00375 .875 L
s
0 .04167 m
.00375 .04167 L
s
0 .95833 m
.00375 .95833 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.5 .08333 Mdot
.33333 .11111 Mdot
.27778 .13889 Mdot
.25 .16667 Mdot
.19444 .19444 Mdot
.22222 .22222 Mdot
.25 .25 Mdot
.27778 .27778 Mdot
.30556 .30556 Mdot
.33333 .33333 Mdot
.36111 .36111 Mdot
.38889 .38889 Mdot
.41667 .41667 Mdot
.44444 .44444 Mdot
.47222 .47222 Mdot
.5 .5 Mdot
.47222 .52778 Mdot
.44444 .55556 Mdot
.41667 .58333 Mdot
.38889 .61111 Mdot
.36111 .63889 Mdot
.33333 .66667 Mdot
.30556 .69444 Mdot
.27778 .72222 Mdot
.25 .75 Mdot
.22222 .77778 Mdot
.19444 .80556 Mdot
.25 .83333 Mdot
.27778 .86111 Mdot
.33333 .88889 Mdot
.5 .91667 Mdot
.5 .08333 Mdot
.63889 .11111 Mdot
.69444 .13889 Mdot
.75 .16667 Mdot
.77778 .19444 Mdot
.80556 .22222 Mdot
.83333 .25 Mdot
.83333 .27778 Mdot
.86111 .30556 Mdot
.86111 .33333 Mdot
.88889 .36111 Mdot
.88889 .38889 Mdot
.88889 .41667 Mdot
.88889 .44444 Mdot
.88889 .47222 Mdot
.91667 .5 Mdot
.88889 .52778 Mdot
.88889 .55556 Mdot
.88889 .58333 Mdot
.88889 .61111 Mdot
.88889 .63889 Mdot
.86111 .66667 Mdot
.86111 .69444 Mdot
.83333 .72222 Mdot
.83333 .75 Mdot
.80556 .77778 Mdot
.77778 .80556 Mdot
.75 .83333 Mdot
.69444 .86111 Mdot
.63889 .88889 Mdot
.5 .91667 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00?oooool4o`000003oa0@4?oooooooooo03?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@0fooooo`Co000000?o410@ooooooooool06?ooool0047ooooo
00?o0000ooooooooool0=Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo037ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0gooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0=oooool00ol0003oooooooooo`0J
ooooo`00=_ooool6o`0000Gooooo00?o0000ooooooooool0;Oooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo033ooooo00Go410@oooooooooooooooooa0@
400gooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo01[ooooo0011ooooo`03o`000?oooooooooo03Gooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo037ooooo00Go0000ooooooooooooooooo`00000gooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0gooooo`03o`000?oooooooooo
01[ooooo0011ooooo`03o`000?oooooooooo03Gooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`0<_ooool01Ol0003ooooooooooooooooo000003Oooooo00Go
0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0>?ooool00ol0003o
ooooooooo`0Jooooo`00@Oooool00ol0003oooooooooo`0eooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`0dooooo`05oa0@4?ooooooooooooooool@4100=oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0J
ooooo`00@Oooool00ol0003oooooooooo`0eooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`0dooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Jooooo`00?ooo
ool00omEEEGoIVIVo`00000gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
03Oooooo00?oEEEEofIVI_l000007?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool002;oooooool00017o`0000008_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool002;ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo047ooooo00?o
0000ooooooooool0@Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01[ooooo000R
ooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4oooo
o`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?oooooo
A?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3o
ooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000oooooooo
ool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oo
oooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool2o`00
0?ooooooAOooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003ooooo
ooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000
ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03
o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_oo
ool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool0
02;ooooo00?o0000ooooooooool0oooooom4ooooo`006?ooool4o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool0oooooom4ooooo`006_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?ooooooA?ooool000oooooo1_l00005ooooo`03o`000?oooooooooo00Gooooo0ol0
002Nooooo`;o0000Xoooool001[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2N
ooooo`;o0000Xoooool001[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
odCooooo000Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom4ooooo`00
6_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooA?ooool001Sooooo00?o
EEEEofIVI_l000001oooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooo
oooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003o
ooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo06Sooooo0_l0001Qooooo`;o0000
M_ooool002;ooooo00?o0000ooooooooool0J?ooool2o`00067ooooo0_l0001fooooo`008_ooool0
0ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;o
oooo00?o0000ooooooooool0oooooom4ooooo`008_ooool2o`000?ooooooAOooool002;ooooo00?o
0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Roooo
o`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0E_ooool2o`0008Go
oooo0_l0001Tooooo`008_ooool00ol0003oooooooooo`1Fooooo`;o0000QOooool2o`0006Cooooo
000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4
ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?oo
ooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003ooooooooo
o`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo0_l0001>oooo
o`;o0000XOooool2o`00057ooooo000Rooooo`03o`000?oooooooooo04gooooo0_l0002Qooooo`;o
0000DOooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003ooooooooo
o`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000oooo
ooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`00
0?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool0
0ol0003oooooooooo`0kooooo`;o0000_?ooool2o`0004Sooooo000Rooooo`03o`000?oooooooooo
03_ooooo0_l0002looooo`;o0000B?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`00
8_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?oo
ool002;ooooo0_l0003oooooodGooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;o
oooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo
000Rooooo`03o`000?oooooooooo04Cooooo0_l0002looooo`;o0000?oooool002;ooooo00?o0000
ooooooooool0A?ooool2o`000;cooooo0_l0000oooooo`008_ooool00ol0003oooooooooo`3ooooo
odCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0
oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooo
oooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003o
ooooooooo`3oooooodCooooo000Rooooo`;o0000C_ooool2o`000;cooooo0_l0000fooooo`008_oo
ool00ol0003oooooooooo`1=ooooo`;o0000_?ooool2o`0003Kooooo000Rooooo`03o`000?oooooo
oooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003o
ooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o
0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Roooo
o`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0E_ooool2o`000;?o
oooo0_l0000fooooo`008_ooool00ol0003oooooooooo`1Fooooo`;o0000/oooool2o`0003Kooooo
0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo0?ooooooA?ooool000Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oo
ooooA?ooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`3oooooodCooooo0007ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooom4ooooo`001oooool01Ol0003ooooo
oooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
0?ooooooA?ooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0oooooom4ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooodCooooo0007ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0Goooool2o`00
0;?ooooo0_l0000]ooooo`008_ooool00ol0003oooooooooo`1Oooooo`;o0000/oooool2o`0002go
oooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooo
oom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo
0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003ooooo
ooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo0_l0001Y
ooooo`;o0000Z_ooool2o`0002gooooo000Rooooo`03o`000?oooooooooo06Sooooo0_l0002Zoooo
o`;o0000;Oooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003ooooo
ooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000
ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03
o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_oo
ool00ol0003oooooooooo`1aooooo`;o0000Z_ooool2o`0002Cooooo000Rooooo`03o`000?oooooo
oooo077ooooo0_l0002Zooooo`;o00009?ooool002;ooooo00?o0000ooooooooool0oooooom4oooo
o`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?oooooo
A?ooool002;ooooo0_l0003oooooodGooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool0
02;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCo
oooo000Rooooo`03o`000?oooooooooo07[ooooo0_l0002Qooooo`;o00009?ooool002;ooooo00?o
0000ooooooooool0N_ooool2o`000:7ooooo0_l0000Tooooo`008_ooool00ol0003oooooooooo`3o
ooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000oooooooo
ool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oo
oooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0
003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo08?ooooo0_l0002Hooooo`;o
00009?ooool002;ooooo0_l00024ooooo`;o0000V?ooool2o`0002Cooooo000Rooooo`03o`000?oo
oooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0
003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo
00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000R
ooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0S?ooool2o`00
08oooooo0_l0000Tooooo`008_ooool00ol0003oooooooooo`2<ooooo`;o0000Soooool2o`0002Co
oooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooo
oom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`;o0000oooooom5oooo
o`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?oooooo
A?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`2E
ooooo`;o0000Q_ooool2o`0002Cooooo000Rooooo`03o`000?oooooooooo09Gooooo0_l00026oooo
o`;o00009?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003ooooo
ooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000
ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Gooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3oooooodCooooo000Gooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3oooooodCooooo000Gooooo`05
oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`2Nooooo`;o0000Q_ooool2o`00
01_ooooo000Gooooo`05o`000?ooooooooooooooool000001_ooool3o`0009kooooo0_l00026oooo
o`;o00006oooool001Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
0?ooooooA?ooool001Oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo
0?ooooooA?ooool001Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo
0?ooooooA?ooool001Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo
0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003ooooo
ooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000
ooooooooool0UOooool2o`0008Kooooo0_l0000Tooooo`008_ooool00ol0003oooooooooo`2Eoooo
o`;o0000Q_ooool2o`0002Cooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo
00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000R
ooooo`;o0000oooooom5ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03
o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_oo
ool00ol0003oooooooooo`2<ooooo`;o0000Soooool2o`0002Cooooo000Rooooo`03o`000?oooooo
oooo08cooooo0_l0002?ooooo`;o00009?ooool002;ooooo00?o0000ooooooooool0oooooom4oooo
o`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?oooooo
A?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3o
ooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000oooooooo
ool0oooooom4ooooo`008_ooool00ol0003oooooooooo`23ooooo`;o0000V?ooool2o`0002Cooooo
000Rooooo`;o0000Q?ooool2o`0009Sooooo0_l0000Tooooo`008_ooool00ol0003oooooooooo`3o
ooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000oooooooo
ool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oo
oooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0
003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo
00?o0000ooooooooool0N_ooool2o`000:7ooooo0_l0000Tooooo`008_ooool00ol0003ooooooooo
o`1jooooo`;o0000XOooool2o`0002Cooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool0
02;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool2o`000?ooooooAOooool002;ooooo
00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000R
ooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4oooo
o`008_ooool00ol0003oooooooooo`1aooooo`;o0000Z_ooool2o`0002Cooooo000Rooooo`03o`00
0?oooooooooo077ooooo0_l0002Zooooo`;o00009?ooool002;ooooo00?o0000ooooooooool0oooo
oom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo
0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003ooooo
ooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000
ooooooooool0oooooom4ooooo`008_ooool2o`0006Wooooo0_l0002Zooooo`;o0000;Oooool002;o
oooo00?o0000ooooooooool0J?ooool2o`000:[ooooo0_l0000]ooooo`008_ooool00ol0003ooooo
ooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000
ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03
o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_oo
ool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo05oooooo0_l0002c
ooooo`;o0000;Oooool002;ooooo00?o0000ooooooooool0Goooool2o`000;?ooooo0_l0000]oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooodCooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3o
ooooodCooooo0007ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03
ooooo`?o0000oooooom4ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3oooooodCooooo0007ooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooo
oom4ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooodCooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?ooooooA?ooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`1Fooooo`;o0000/ooo
ool2o`0003Kooooo000Rooooo`03o`000?oooooooooo05Kooooo0_l0002cooooo`;o0000=_ooool0
02;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCo
oooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooo
oom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo
0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool2o`0004kooooo
0_l0002looooo`;o0000=_ooool002;ooooo00?o0000ooooooooool0COooool2o`000;cooooo0_l0
000fooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo
0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003ooooo
ooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000
ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03
o`000?oooooooooo04Cooooo0_l0002looooo`;o0000?oooool002;ooooo00?o0000ooooooooool0
A?ooool2o`000;cooooo0_l0000oooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000R
ooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo0_l0003oooooodGooooo000Rooooo`03
o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_oo
ool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool0
02;ooooo00?o0000ooooooooool0>oooool2o`000;cooooo0_l00018ooooo`008_ooool00ol0003o
ooooooooo`0kooooo`;o0000_?ooool2o`0004Sooooo000Rooooo`03o`000?oooooooooo0?oooooo
A?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3o
ooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000oooooooo
ool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oo
oooooooo0?ooooooA?ooool002;ooooo0_l0001>ooooo`;o0000XOooool2o`00057ooooo000Roooo
o`03o`000?oooooooooo04gooooo0_l0002Qooooo`;o0000DOooool002;ooooo00?o0000oooooooo
ool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oo
oooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0
003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo
00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`1Fooooo`;o0000QOoo
ool2o`0006Cooooo000Rooooo`03o`000?oooooooooo05Kooooo0_l00025ooooo`;o0000I?ooool0
02;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCo
oooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo0_l0003oooooodGooooo000R
ooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4oooo
o`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo06Sooooo
0_l0001Qooooo`;o0000M_ooool002;ooooo00?o0000ooooooooool0J?ooool2o`00067ooooo0_l0
001fooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo
0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003ooooo
ooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool001Sooooo1?l00000
0ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooA?ooool001[ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3oooooodCooooo000Jooooo`03o`000?oooooooooo00Go
oooo0ol0002Nooooo`;o0000Xoooool001[ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2Nooooo`;o0000Xoooool001[ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`3oooooodCooooo000Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom4
ooooo`006_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooA?ooool001So
oooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`00
0?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool0
0ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;o
oooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo
000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4
ooooo`008_ooool2o`000?ooooooAOooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`00
8_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?oo
ool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3ooooo
odCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0
oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooo
oooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003o
ooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o
0000ooooooooool0oooooom4ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.45159, -1.38235, 0.00923261, \
0.00923261}}]
}, Open  ]],

Cell[TextData[{
  "The irregularities in the boundary reflect the difficulty of fitting a \
rectangular grid to a curved boundary. They can be reduced by using a finer \
grid, but this increases the number of coupled equations that we need to \
solve.  They can also be reduced by employing an averaging technique, \
determining the value of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " on the boundary as a weighted average of surrounding grid points. (See \
the exercises for an implementation of this technique.)  Alternatively, a \
nonrectangular grid can be chosen that better matches the edge(s). However, \
this is rather nontrivial, and will not be pursued further here.  An \
excellent introduction to irregular grids, finite element analysis, and the \
like, can be found on the ",
  ButtonBox["web",
    ButtonData:>{
      URL[ "http://www.esc.auckland.ac.nz/Academic/Texts/FEM-BEM-notes.html"],
       None},
    ButtonStyle->"Hyperlink"],
  " in a set of  course notes by Peter Hunter and  Andrew Pullan (2002). A \
recent textbook on the subject is also listed in the references."
}], "Text",
  CellTags->"i:68"],

Cell[TextData[{
  "\tHere we will make do with the coarse fit obtained above.  Since we may \
be off by as much as a grid spacing ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " in the boundary location, we can only expect our solution to be \
first-order accurate in ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ". However, for distances from the boundary much greater than ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ",  the effect of the irregularities in the boundary often average out, and \
the solution can be more accurate than this estimate suggests. "
}], "Text"],

Cell[TextData[{
  "\tContinuing with our example, we take ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] = 0\)]],
  " for the source, "
}], "Text"],

Cell[BoxData[
    \(\(\[Rho][j_, k_]\  = \ 0. ;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.99"],

Cell[TextData[{
  "Then the  list of equations, using Eq. ",
  ButtonBox["(6.2.34)",
    ButtonData:>"(6.2.34)",
    ButtonStyle->"Hyperlink"],
  " for the interior points, is given by"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"eqns", " ", "=", " ", 
        RowBox[{"Flatten", "[", 
          RowBox[{"Table", "[", 
            RowBox[{
              RowBox[{"Table", "[", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      FractionBox[
                        FormBox[
                          RowBox[{
                            RowBox[{"\[Phi]", "[", 
                              RowBox[{
                                RowBox[{
                                  StyleBox["j",
                                    FontSlant->"Plain"], "+", "1"}], ",", 
                                StyleBox["k",
                                  FontSlant->"Plain"]}], "]"}], "-", 
                            RowBox[{"2", " ", 
                              RowBox[{"\[Phi]", "[", 
                                RowBox[{
                                  StyleBox["j",
                                    FontSlant->"Plain"], ",", 
                                  StyleBox["k",
                                    FontSlant->"Plain"]}], "]"}]}], "+", " ", 
                            
                            RowBox[{"\[Phi]", "[", 
                              RowBox[{
                                RowBox[{
                                  StyleBox["j",
                                    FontSlant->"Plain"], "-", "1"}], ",", 
                                StyleBox["k",
                                  FontSlant->"Plain"]}], "]"}]}],
                          "TraditionalForm"], \(\[CapitalDelta]x\^2\)], "+", 
                      FractionBox[
                        FormBox[
                          RowBox[{
                            RowBox[{"\[Phi]", "[", 
                              RowBox[{
                                StyleBox["j",
                                  FontSlant->"Plain"], ",", 
                                RowBox[{
                                  StyleBox["k",
                                    FontSlant->"Plain"], "+", "1"}]}], "]"}], 
                            "-", 
                            RowBox[{"2", " ", 
                              RowBox[{"\[Phi]", "[", 
                                RowBox[{
                                  StyleBox["j",
                                    FontSlant->"Plain"], ",", 
                                  StyleBox["k",
                                    FontSlant->"Plain"]}], "]"}]}], "+", " ", 
                            
                            RowBox[{"\[Phi]", "[", 
                              RowBox[{
                                StyleBox["j",
                                  FontSlant->"Plain"], ",", 
                                RowBox[{
                                  StyleBox["k",
                                    FontSlant->"Plain"], "-", "1"}]}], 
                              "]"}]}],
                          "TraditionalForm"], \(\[CapitalDelta]y\^2\)]}], 
                    "\[Equal]", \(\[Rho][j, k]\)}], 
                  ",", \({j, f[k] + 1, g[k] - 1}\)}], "]"}], 
              ",", \({k, 1, M\_y - 1}\)}], "]"}], "]"}]}], ";"}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.100"],

Cell["and the list of variables is", "Text"],

Cell[BoxData[
    \(\(vars\  = \ 
        Flatten[Table[
            Table[\[Phi][j, k], {j, f[k] + 1, g[k] - 1}], {k, 1, 
              M\_y - 1}]];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.101"],

Cell["Finally, we solve the equations:", "Text"],

Cell[BoxData[
    \(\(sol\  = \ \(Solve[eqns, vars]\)[\([1]\)];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.102"],

Cell["\<\
We can again construct an interpolation function of the solution:\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Phi]sol\  = \ 
      Interpolation[
        Flatten[Table[{x[j], y[k], \[Phi][j, k]}, {j, 0, M\_x}, {k, 0, 
                M\_y}] /. sol, 1]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.103"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{\(-1.`\), 1.`}, {\(-1.`\), 1.`}}, 
        "<>"]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "A contour plot of the solution is shown in Cell ",
  ButtonBox["6.105",
    ButtonData:>"Cell 6.105",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[BoxData[
    \(<< Calculus`\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.104"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ContourPlot[\[Phi]sol[x, y] 
          Boole[1\  - \ x^2\  - \ y^2\  \[GreaterEqual] \ 0\  && \ 
              x\  \[GreaterEqual] \ \(-Abs[y]\)], {x, \(-1\), 
          1. }, {y, \(-1\), 1}, FrameLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotLabel \[Rule] "\<\[Phi](x,y)\>", 
        PlotPoints \[Rule] 60];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.105"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[.01923 -0.0125 -6 -9 ]
[.01923 -0.0125 6 0 ]
[.25962 -0.0125 -12 -9 ]
[.25962 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.74038 -0.0125 -9 -9 ]
[.74038 -0.0125 9 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .01923 -12 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .25962 -24 -4.5 ]
[-0.0125 .25962 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .74038 -18 -4.5 ]
[-0.0125 .74038 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -36 -5 ]
[-0.01875 .5 -24 5 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-1)] .01923 -0.0125 0 1 Mshowa
.25962 0 m
.25962 .00625 L
s
[(-0.5)] .25962 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.74038 0 m
.74038 .00625 L
s
[(0.5)] .74038 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(1)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01923 m
.00625 .01923 L
s
[(-1)] -0.0125 .01923 1 0 Mshowa
0 .25962 m
.00625 .25962 L
s
[(-0.5)] -0.0125 .25962 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .74038 m
.00625 .74038 L
s
[(0.5)] -0.0125 .74038 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(1)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -96 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10 translate
90 rotate
-66 -10 translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(L) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.36147 .06578 m
.37777 .06307 L
.39407 .06126 L
.41037 .06028 L
.42666 .05986 L
.44296 .05988 L
.45926 .06027 L
.47555 .06098 L
.49185 .06202 L
.50815 .06337 L
.52445 .0651 L
.54074 .06725 L
.54644 .06812 L
.55704 .06994 L
.57334 .0733 L
.58963 .07755 L
.60593 .08286 L
.61016 .08442 L
.62223 .08929 L
.63853 .09674 L
.64659 .10072 L
.65482 .10485 L
.67112 .11337 L
.6777 .11701 L
.68742 .12267 L
.70372 .13292 L
.7043 .13331 L
.72001 .14398 L
.72786 .14961 L
.73631 .15601 L
.74833 .16591 L
.75261 .16967 L
.7659 .1822 L
.7689 .18521 L
.78148 .1985 L
.7852 .20267 L
.79543 .2148 L
.8015 .22256 L
.80777 .2311 L
.8178 .24605 L
.81866 .24739 L
.82865 .26369 L
.83409 .27324 L
.8378 .27999 L
.84612 .29628 L
.85039 .30529 L
.85372 .31258 L
.86079 .32888 L
.86669 .34384 L
.86718 .34518 L
.87275 .36147 L
.8774 .37777 L
.88113 .39407 L
.88299 .40385 L
.88407 .41037 L
.88638 .42666 L
.88817 .44296 L
.88955 .45926 L
.8906 .47555 L
.89127 .49185 L
.89127 .50815 L
.8906 .52445 L
.88955 .54074 L
.88817 .55704 L
.88638 .57334 L
.88407 .58963 L
.88299 .59615 L
.88113 .60593 L
.8774 .62223 L
.87275 .63853 L
.86718 .65482 L
.86669 .65616 L
.86079 .67112 L
.85372 .68742 L
.85039 .69471 L
.84612 .70372 L
.8378 .72001 L
.83409 .72676 L
.82865 .73631 L
.81866 .75261 L
.8178 .75395 L
.80777 .7689 L
.8015 .77744 L
.79543 .7852 L
.7852 .79733 L
.78148 .8015 L
.7689 .81479 L
.7659 .8178 L
.75261 .83033 L
.74833 .83409 L
.73631 .84399 L
.72786 .85039 L
.72001 .85602 L
.7043 .86669 L
.70372 .86708 L
.68742 .87733 L
.6777 .88299 L
.67112 .88663 L
.65482 .89515 L
.64659 .89928 L
.63853 .90326 L
.62223 .91071 L
.61016 .91558 L
.60593 .91714 L
.58963 .92245 L
.57334 .9267 L
.55704 .93006 L
.54644 .93188 L
.54074 .93275 L
.52445 .9349 L
.50815 .93663 L
.49185 .93798 L
.47555 .93902 L
.45926 .93973 L
.44296 .94012 L
.42666 .94014 L
.41037 .93972 L
.39407 .93874 L
.37777 .93693 L
.36147 .93422 L
.35231 .93188 L
.34518 .92967 L
.32888 .92317 L
.31258 .91739 L
.30663 .91558 L
.29628 .91207 L
.27999 .90522 L
.27083 .89928 L
.26369 .89454 L
.24739 .88462 L
.24514 .88299 L
.2311 .87205 L
.22402 .86669 L
.2148 .86222 L
.1985 .85596 L
.18484 .85039 L
.1822 .84847 L
.17263 .83409 L
.17473 .8178 L
.1822 .80978 L
.18778 .8015 L
.1985 .79046 L
.20238 .7852 L
.2148 .77264 L
.21799 .7689 L
.2311 .75569 L
.23371 .75261 L
.24739 .73886 L
.24971 .73631 L
.26369 .72228 L
.26572 .72001 L
.27999 .70572 L
.28186 .70372 L
.29628 .68926 L
.29799 .68742 L
.31258 .67281 L
.31419 .67112 L
.32888 .65642 L
.33039 .65482 L
.34518 .64002 L
.34662 .63853 L
.36147 .62366 L
.36285 .62223 L
.37777 .6073 L
.3791 .60593 L
.39407 .59096 L
.39536 .58963 L
.41037 .57462 L
.41163 .57334 L
.42666 .5583 L
.4279 .55704 L
.44296 .54197 L
.44418 .54074 L
.45926 .52566 L
.46046 .52445 L
.47555 .50935 L
.47674 .50815 L
.47674 .49185 L
.47555 .49065 L
.46046 .47555 L
.45926 .47434 L
.44418 .45926 L
.44296 .45803 L
.4279 .44296 L
.42666 .4417 L
.41163 .42666 L
.41037 .42538 L
.39536 .41037 L
.39407 .40904 L
.3791 .39407 L
.37777 .3927 L
.36285 .37777 L
.36147 .37634 L
.34662 .36147 L
.34518 .35998 L
.33039 .34518 L
.32888 .34358 L
.31419 .32888 L
.31258 .32719 L
.29799 .31258 L
.29628 .31074 L
.28186 .29628 L
.27999 .29428 L
.26572 .27999 L
.26369 .27772 L
.24971 .26369 L
.24739 .26114 L
.23371 .24739 L
.2311 .24431 L
.21799 .2311 L
.2148 .22736 L
.20238 .2148 L
.1985 .20954 L
.18778 .1985 L
.1822 .19022 L
.17473 .1822 L
.17263 .16591 L
.1822 .15153 L
.18484 .14961 L
.1985 .14404 L
.2148 .13778 L
.22402 .13331 L
.2311 .12795 L
.24514 .11701 L
.24739 .11538 L
.26369 .10546 L
.27083 .10072 L
.27999 .09478 L
.29628 .08793 L
.30663 .08442 L
.31258 .08261 L
.32888 .07683 L
.34518 .07033 L
.35231 .06812 L
F
0 g
.36147 .06578 m
.37777 .06307 L
.39407 .06126 L
.41037 .06028 L
.42666 .05986 L
.44296 .05988 L
.45926 .06027 L
.47555 .06098 L
.49185 .06202 L
.50815 .06337 L
.52445 .0651 L
.54074 .06725 L
.54644 .06812 L
.55704 .06994 L
.57334 .0733 L
.58963 .07755 L
.60593 .08286 L
.61016 .08442 L
.62223 .08929 L
.63853 .09674 L
.64659 .10072 L
.65482 .10485 L
.67112 .11337 L
.6777 .11701 L
.68742 .12267 L
.70372 .13292 L
.7043 .13331 L
.72001 .14398 L
.72786 .14961 L
.73631 .15601 L
.74833 .16591 L
.75261 .16967 L
.7659 .1822 L
.7689 .18521 L
.78148 .1985 L
.7852 .20267 L
.79543 .2148 L
.8015 .22256 L
.80777 .2311 L
.8178 .24605 L
.81866 .24739 L
.82865 .26369 L
.83409 .27324 L
.8378 .27999 L
.84612 .29628 L
.85039 .30529 L
.85372 .31258 L
.86079 .32888 L
.86669 .34384 L
.86718 .34518 L
Mistroke
.87275 .36147 L
.8774 .37777 L
.88113 .39407 L
.88299 .40385 L
.88407 .41037 L
.88638 .42666 L
.88817 .44296 L
.88955 .45926 L
.8906 .47555 L
.89127 .49185 L
.89127 .50815 L
.8906 .52445 L
.88955 .54074 L
.88817 .55704 L
.88638 .57334 L
.88407 .58963 L
.88299 .59615 L
.88113 .60593 L
.8774 .62223 L
.87275 .63853 L
.86718 .65482 L
.86669 .65616 L
.86079 .67112 L
.85372 .68742 L
.85039 .69471 L
.84612 .70372 L
.8378 .72001 L
.83409 .72676 L
.82865 .73631 L
.81866 .75261 L
.8178 .75395 L
.80777 .7689 L
.8015 .77744 L
.79543 .7852 L
.7852 .79733 L
.78148 .8015 L
.7689 .81479 L
.7659 .8178 L
.75261 .83033 L
.74833 .83409 L
.73631 .84399 L
.72786 .85039 L
.72001 .85602 L
.7043 .86669 L
.70372 .86708 L
.68742 .87733 L
.6777 .88299 L
.67112 .88663 L
.65482 .89515 L
.64659 .89928 L
Mistroke
.63853 .90326 L
.62223 .91071 L
.61016 .91558 L
.60593 .91714 L
.58963 .92245 L
.57334 .9267 L
.55704 .93006 L
.54644 .93188 L
.54074 .93275 L
.52445 .9349 L
.50815 .93663 L
.49185 .93798 L
.47555 .93902 L
.45926 .93973 L
.44296 .94012 L
.42666 .94014 L
.41037 .93972 L
.39407 .93874 L
.37777 .93693 L
.36147 .93422 L
.35231 .93188 L
.34518 .92967 L
.32888 .92317 L
.31258 .91739 L
.30663 .91558 L
.29628 .91207 L
.27999 .90522 L
.27083 .89928 L
.26369 .89454 L
.24739 .88462 L
.24514 .88299 L
.2311 .87205 L
.22402 .86669 L
.2148 .86222 L
.1985 .85596 L
.18484 .85039 L
.1822 .84847 L
.17263 .83409 L
.17473 .8178 L
.1822 .80978 L
.18778 .8015 L
.1985 .79046 L
.20238 .7852 L
.2148 .77264 L
.21799 .7689 L
.2311 .75569 L
.23371 .75261 L
.24739 .73886 L
.24971 .73631 L
.26369 .72228 L
Mistroke
.26572 .72001 L
.27999 .70572 L
.28186 .70372 L
.29628 .68926 L
.29799 .68742 L
.31258 .67281 L
.31419 .67112 L
.32888 .65642 L
.33039 .65482 L
.34518 .64002 L
.34662 .63853 L
.36147 .62366 L
.36285 .62223 L
.37777 .6073 L
.3791 .60593 L
.39407 .59096 L
.39536 .58963 L
.41037 .57462 L
.41163 .57334 L
.42666 .5583 L
.4279 .55704 L
.44296 .54197 L
.44418 .54074 L
.45926 .52566 L
.46046 .52445 L
.47555 .50935 L
.47674 .50815 L
.47674 .49185 L
.47555 .49065 L
.46046 .47555 L
.45926 .47434 L
.44418 .45926 L
.44296 .45803 L
.4279 .44296 L
.42666 .4417 L
.41163 .42666 L
.41037 .42538 L
.39536 .41037 L
.39407 .40904 L
.3791 .39407 L
.37777 .3927 L
.36285 .37777 L
.36147 .37634 L
.34662 .36147 L
.34518 .35998 L
.33039 .34518 L
.32888 .34358 L
.31419 .32888 L
.31258 .32719 L
.29799 .31258 L
Mistroke
.29628 .31074 L
.28186 .29628 L
.27999 .29428 L
.26572 .27999 L
.26369 .27772 L
.24971 .26369 L
.24739 .26114 L
.23371 .24739 L
.2311 .24431 L
.21799 .2311 L
.2148 .22736 L
.20238 .2148 L
.1985 .20954 L
.18778 .1985 L
.1822 .19022 L
.17473 .1822 L
.17263 .16591 L
.1822 .15153 L
.18484 .14961 L
.1985 .14404 L
.2148 .13778 L
.22402 .13331 L
.2311 .12795 L
.24514 .11701 L
.24739 .11538 L
.26369 .10546 L
.27083 .10072 L
.27999 .09478 L
.29628 .08793 L
.30663 .08442 L
.31258 .08261 L
.32888 .07683 L
.34518 .07033 L
.35231 .06812 L
.36147 .06578 L
Mfstroke
.2 g
.39407 .11629 m
.41037 .1158 L
.42666 .11599 L
.44296 .11682 L
.44581 .11701 L
.45926 .11825 L
.47555 .12028 L
.49185 .12289 L
.50815 .12612 L
.52445 .13001 L
.53644 .13331 L
.54074 .1346 L
.55704 .13995 L
.57334 .14612 L
.58164 .14961 L
.58963 .15319 L
.60593 .16119 L
.61471 .16591 L
.62223 .17018 L
.63853 .18023 L
.64152 .1822 L
.65482 .19144 L
.66426 .1985 L
.67112 .20393 L
.68395 .2148 L
.68742 .21791 L
.7012 .2311 L
.70372 .23366 L
.71642 .24739 L
.72001 .25154 L
.72993 .26369 L
.73631 .27211 L
.74195 .27999 L
.75261 .29618 L
.75267 .29628 L
.76224 .31258 L
.7689 .32516 L
.77076 .32888 L
.77832 .34518 L
.78496 .36147 L
.7852 .3621 L
.79075 .37777 L
.79571 .39407 L
.79988 .41037 L
.8015 .41762 L
.80329 .42666 L
.80599 .44296 L
.80798 .45926 L
.80931 .47555 L
.80997 .49185 L
.80997 .50815 L
.80931 .52445 L
.80798 .54074 L
.80599 .55704 L
.80329 .57334 L
.8015 .58238 L
.79988 .58963 L
.79571 .60593 L
.79075 .62223 L
.7852 .6379 L
.78496 .63853 L
.77832 .65482 L
.77076 .67112 L
.7689 .67484 L
.76224 .68742 L
.75267 .70372 L
.75261 .70382 L
.74195 .72001 L
.73631 .72789 L
.72993 .73631 L
.72001 .74846 L
.71642 .75261 L
.70372 .76634 L
.7012 .7689 L
.68742 .78209 L
.68395 .7852 L
.67112 .79607 L
.66426 .8015 L
.65482 .80856 L
.64152 .8178 L
.63853 .81977 L
.62223 .82982 L
.61471 .83409 L
.60593 .83881 L
.58963 .84681 L
.58164 .85039 L
.57334 .85388 L
.55704 .86005 L
.54074 .8654 L
.53644 .86669 L
.52445 .86999 L
.50815 .87388 L
.49185 .87711 L
.47555 .87972 L
.45926 .88175 L
.44581 .88299 L
.44296 .88318 L
.42666 .88401 L
.41037 .8842 L
.39407 .88371 L
.38099 .88299 L
.37777 .88249 L
.36147 .88049 L
.34518 .87768 L
.32888 .87406 L
.31258 .86969 L
.30262 .86669 L
.29628 .8646 L
.27999 .8587 L
.26369 .852 L
.25999 .85039 L
.24739 .84468 L
.2311 .83667 L
.22628 .83409 L
.2148 .82821 L
.1985 .81971 L
.1962 .8178 L
.19511 .8015 L
.1985 .79777 L
.20745 .7852 L
.2148 .77762 L
.22216 .7689 L
.2311 .75978 L
.23717 .75261 L
.24739 .74227 L
.2528 .73631 L
.26369 .72532 L
.26846 .72001 L
.27999 .70842 L
.28439 .70372 L
.29628 .69176 L
.30031 .68742 L
.31258 .67511 L
.31639 .67112 L
.32888 .65859 L
.33245 .65482 L
.34518 .64207 L
.3486 .63853 L
.36147 .62563 L
.36474 .62223 L
.37777 .60918 L
.38094 .60593 L
.39407 .59279 L
.39713 .58963 L
.41037 .5764 L
.41337 .57334 L
.42666 .56004 L
.4296 .55704 L
.44296 .54368 L
.44587 .54074 L
.45926 .52735 L
.46213 .52445 L
.47555 .51102 L
.47839 .50815 L
.47839 .49185 L
.47555 .48898 L
.46213 .47555 L
.45926 .47265 L
.44587 .45926 L
.44296 .45632 L
.4296 .44296 L
.42666 .43996 L
.41337 .42666 L
.41037 .4236 L
.39713 .41037 L
.39407 .40721 L
.38094 .39407 L
.37777 .39082 L
.36474 .37777 L
.36147 .37437 L
.3486 .36147 L
.34518 .35793 L
.33245 .34518 L
.32888 .34141 L
.31639 .32888 L
.31258 .32489 L
.30031 .31258 L
.29628 .30824 L
.28439 .29628 L
.27999 .29158 L
.26846 .27999 L
.26369 .27468 L
.2528 .26369 L
.24739 .25773 L
.23717 .24739 L
.2311 .24022 L
.22216 .2311 L
.2148 .22238 L
.20745 .2148 L
.1985 .20223 L
.19511 .1985 L
.1962 .1822 L
.1985 .18029 L
.2148 .17179 L
.22628 .16591 L
.2311 .16333 L
.24739 .15532 L
.25999 .14961 L
.26369 .148 L
.27999 .1413 L
.29628 .1354 L
.30262 .13331 L
.31258 .13031 L
.32888 .12594 L
.34518 .12232 L
.36147 .11951 L
.37777 .11751 L
.38099 .11701 L
F
0 g
.39407 .11629 m
.41037 .1158 L
.42666 .11599 L
.44296 .11682 L
.44581 .11701 L
.45926 .11825 L
.47555 .12028 L
.49185 .12289 L
.50815 .12612 L
.52445 .13001 L
.53644 .13331 L
.54074 .1346 L
.55704 .13995 L
.57334 .14612 L
.58164 .14961 L
.58963 .15319 L
.60593 .16119 L
.61471 .16591 L
.62223 .17018 L
.63853 .18023 L
.64152 .1822 L
.65482 .19144 L
.66426 .1985 L
.67112 .20393 L
.68395 .2148 L
.68742 .21791 L
.7012 .2311 L
.70372 .23366 L
.71642 .24739 L
.72001 .25154 L
.72993 .26369 L
.73631 .27211 L
.74195 .27999 L
.75261 .29618 L
.75267 .29628 L
.76224 .31258 L
.7689 .32516 L
.77076 .32888 L
.77832 .34518 L
.78496 .36147 L
.7852 .3621 L
.79075 .37777 L
.79571 .39407 L
.79988 .41037 L
.8015 .41762 L
.80329 .42666 L
.80599 .44296 L
.80798 .45926 L
.80931 .47555 L
.80997 .49185 L
Mistroke
.80997 .50815 L
.80931 .52445 L
.80798 .54074 L
.80599 .55704 L
.80329 .57334 L
.8015 .58238 L
.79988 .58963 L
.79571 .60593 L
.79075 .62223 L
.7852 .6379 L
.78496 .63853 L
.77832 .65482 L
.77076 .67112 L
.7689 .67484 L
.76224 .68742 L
.75267 .70372 L
.75261 .70382 L
.74195 .72001 L
.73631 .72789 L
.72993 .73631 L
.72001 .74846 L
.71642 .75261 L
.70372 .76634 L
.7012 .7689 L
.68742 .78209 L
.68395 .7852 L
.67112 .79607 L
.66426 .8015 L
.65482 .80856 L
.64152 .8178 L
.63853 .81977 L
.62223 .82982 L
.61471 .83409 L
.60593 .83881 L
.58963 .84681 L
.58164 .85039 L
.57334 .85388 L
.55704 .86005 L
.54074 .8654 L
.53644 .86669 L
.52445 .86999 L
.50815 .87388 L
.49185 .87711 L
.47555 .87972 L
.45926 .88175 L
.44581 .88299 L
.44296 .88318 L
.42666 .88401 L
.41037 .8842 L
.39407 .88371 L
Mistroke
.38099 .88299 L
.37777 .88249 L
.36147 .88049 L
.34518 .87768 L
.32888 .87406 L
.31258 .86969 L
.30262 .86669 L
.29628 .8646 L
.27999 .8587 L
.26369 .852 L
.25999 .85039 L
.24739 .84468 L
.2311 .83667 L
.22628 .83409 L
.2148 .82821 L
.1985 .81971 L
.1962 .8178 L
.19511 .8015 L
.1985 .79777 L
.20745 .7852 L
.2148 .77762 L
.22216 .7689 L
.2311 .75978 L
.23717 .75261 L
.24739 .74227 L
.2528 .73631 L
.26369 .72532 L
.26846 .72001 L
.27999 .70842 L
.28439 .70372 L
.29628 .69176 L
.30031 .68742 L
.31258 .67511 L
.31639 .67112 L
.32888 .65859 L
.33245 .65482 L
.34518 .64207 L
.3486 .63853 L
.36147 .62563 L
.36474 .62223 L
.37777 .60918 L
.38094 .60593 L
.39407 .59279 L
.39713 .58963 L
.41037 .5764 L
.41337 .57334 L
.42666 .56004 L
.4296 .55704 L
.44296 .54368 L
.44587 .54074 L
Mistroke
.45926 .52735 L
.46213 .52445 L
.47555 .51102 L
.47839 .50815 L
.47839 .49185 L
.47555 .48898 L
.46213 .47555 L
.45926 .47265 L
.44587 .45926 L
.44296 .45632 L
.4296 .44296 L
.42666 .43996 L
.41337 .42666 L
.41037 .4236 L
.39713 .41037 L
.39407 .40721 L
.38094 .39407 L
.37777 .39082 L
.36474 .37777 L
.36147 .37437 L
.3486 .36147 L
.34518 .35793 L
.33245 .34518 L
.32888 .34141 L
.31639 .32888 L
.31258 .32489 L
.30031 .31258 L
.29628 .30824 L
.28439 .29628 L
.27999 .29158 L
.26846 .27999 L
.26369 .27468 L
.2528 .26369 L
.24739 .25773 L
.23717 .24739 L
.2311 .24022 L
.22216 .2311 L
.2148 .22238 L
.20745 .2148 L
.1985 .20223 L
.19511 .1985 L
.1962 .1822 L
.1985 .18029 L
.2148 .17179 L
.22628 .16591 L
.2311 .16333 L
.24739 .15532 L
.25999 .14961 L
.26369 .148 L
.27999 .1413 L
Mistroke
.29628 .1354 L
.30262 .13331 L
.31258 .13031 L
.32888 .12594 L
.34518 .12232 L
.36147 .11951 L
.37777 .11751 L
.38099 .11701 L
.39407 .11629 L
Mfstroke
.3 g
.36147 .16452 m
.37777 .16375 L
.39407 .1637 L
.41037 .16436 L
.42666 .16574 L
.42824 .16591 L
.44296 .16782 L
.45926 .17062 L
.47555 .17414 L
.49185 .17841 L
.50433 .1822 L
.50815 .18346 L
.52445 .18935 L
.54074 .19613 L
.54595 .1985 L
.55704 .20388 L
.57334 .21269 L
.57696 .2148 L
.58963 .22264 L
.60206 .2311 L
.60593 .23389 L
.62223 .24661 L
.62317 .24739 L
.63853 .26103 L
.64131 .26369 L
.65482 .2775 L
.65709 .27999 L
.67093 .29628 L
.67112 .29653 L
.68309 .31258 L
.68742 .31892 L
.69379 .32888 L
.70318 .34518 L
.70372 .34617 L
.71139 .36147 L
.71851 .37777 L
.72001 .38155 L
.7246 .39407 L
.72973 .41037 L
.73394 .42666 L
.73631 .43773 L
.73727 .44296 L
.73974 .45926 L
.74138 .47555 L
.7422 .49185 L
.7422 .50815 L
.74138 .52445 L
.73974 .54074 L
.73727 .55704 L
.73631 .56227 L
.73394 .57334 L
.72973 .58963 L
.7246 .60593 L
.72001 .61845 L
.71851 .62223 L
.71139 .63853 L
.70372 .65383 L
.70318 .65482 L
.69379 .67112 L
.68742 .68108 L
.68309 .68742 L
.67112 .70347 L
.67093 .70372 L
.65709 .72001 L
.65482 .7225 L
.64131 .73631 L
.63853 .73897 L
.62317 .75261 L
.62223 .75339 L
.60593 .76611 L
.60206 .7689 L
.58963 .77736 L
.57696 .7852 L
.57334 .78731 L
.55704 .79612 L
.54595 .8015 L
.54074 .80387 L
.52445 .81065 L
.50815 .81654 L
.50433 .8178 L
.49185 .82159 L
.47555 .82586 L
.45926 .82938 L
.44296 .83218 L
.42824 .83409 L
.42666 .83426 L
.41037 .83564 L
.39407 .8363 L
.37777 .83625 L
.36147 .83548 L
.34588 .83409 L
.34518 .83398 L
.32888 .83176 L
.31258 .82882 L
.29628 .82518 L
.27999 .82085 L
.26985 .8178 L
.26369 .81578 L
.24739 .81006 L
.2311 .80561 L
.21847 .8015 L
.2148 .80053 L
.21259 .7852 L
.2148 .78284 L
.22619 .7689 L
.2311 .7638 L
.24045 .75261 L
.24739 .74552 L
.2557 .73631 L
.26369 .72819 L
.27101 .72001 L
.27999 .71095 L
.28675 .70372 L
.29628 .6941 L
.30248 .68742 L
.31258 .67726 L
.31844 .67112 L
.32888 .66062 L
.33437 .65482 L
.34518 .64398 L
.35045 .63853 L
.36147 .62746 L
.36651 .62223 L
.37777 .61094 L
.38266 .60593 L
.39407 .5945 L
.3988 .58963 L
.41037 .57806 L
.415 .57334 L
.42666 .56166 L
.4312 .55704 L
.44296 .54528 L
.44745 .54074 L
.45926 .52893 L
.46369 .52445 L
.47555 .51259 L
.47994 .50815 L
.47994 .49185 L
.47555 .48741 L
.46369 .47555 L
.45926 .47107 L
.44745 .45926 L
.44296 .45472 L
.4312 .44296 L
.42666 .43834 L
.415 .42666 L
.41037 .42194 L
.3988 .41037 L
.39407 .4055 L
.38266 .39407 L
.37777 .38906 L
.36651 .37777 L
.36147 .37254 L
.35045 .36147 L
.34518 .35602 L
.33437 .34518 L
.32888 .33938 L
.31844 .32888 L
.31258 .32274 L
.30248 .31258 L
.29628 .3059 L
.28675 .29628 L
.27999 .28905 L
.27101 .27999 L
.26369 .27181 L
.2557 .26369 L
.24739 .25448 L
.24045 .24739 L
.2311 .2362 L
.22619 .2311 L
.2148 .21716 L
.21259 .2148 L
.2148 .19947 L
.21847 .1985 L
.2311 .19439 L
.24739 .18994 L
.26369 .18422 L
.26985 .1822 L
.27999 .17915 L
.29628 .17482 L
.31258 .17118 L
.32888 .16824 L
.34518 .16602 L
.34588 .16591 L
F
0 g
.36147 .16452 m
.37777 .16375 L
.39407 .1637 L
.41037 .16436 L
.42666 .16574 L
.42824 .16591 L
.44296 .16782 L
.45926 .17062 L
.47555 .17414 L
.49185 .17841 L
.50433 .1822 L
.50815 .18346 L
.52445 .18935 L
.54074 .19613 L
.54595 .1985 L
.55704 .20388 L
.57334 .21269 L
.57696 .2148 L
.58963 .22264 L
.60206 .2311 L
.60593 .23389 L
.62223 .24661 L
.62317 .24739 L
.63853 .26103 L
.64131 .26369 L
.65482 .2775 L
.65709 .27999 L
.67093 .29628 L
.67112 .29653 L
.68309 .31258 L
.68742 .31892 L
.69379 .32888 L
.70318 .34518 L
.70372 .34617 L
.71139 .36147 L
.71851 .37777 L
.72001 .38155 L
.7246 .39407 L
.72973 .41037 L
.73394 .42666 L
.73631 .43773 L
.73727 .44296 L
.73974 .45926 L
.74138 .47555 L
.7422 .49185 L
.7422 .50815 L
.74138 .52445 L
.73974 .54074 L
.73727 .55704 L
.73631 .56227 L
Mistroke
.73394 .57334 L
.72973 .58963 L
.7246 .60593 L
.72001 .61845 L
.71851 .62223 L
.71139 .63853 L
.70372 .65383 L
.70318 .65482 L
.69379 .67112 L
.68742 .68108 L
.68309 .68742 L
.67112 .70347 L
.67093 .70372 L
.65709 .72001 L
.65482 .7225 L
.64131 .73631 L
.63853 .73897 L
.62317 .75261 L
.62223 .75339 L
.60593 .76611 L
.60206 .7689 L
.58963 .77736 L
.57696 .7852 L
.57334 .78731 L
.55704 .79612 L
.54595 .8015 L
.54074 .80387 L
.52445 .81065 L
.50815 .81654 L
.50433 .8178 L
.49185 .82159 L
.47555 .82586 L
.45926 .82938 L
.44296 .83218 L
.42824 .83409 L
.42666 .83426 L
.41037 .83564 L
.39407 .8363 L
.37777 .83625 L
.36147 .83548 L
.34588 .83409 L
.34518 .83398 L
.32888 .83176 L
.31258 .82882 L
.29628 .82518 L
.27999 .82085 L
.26985 .8178 L
.26369 .81578 L
.24739 .81006 L
.2311 .80561 L
Mistroke
.21847 .8015 L
.2148 .80053 L
.21259 .7852 L
.2148 .78284 L
.22619 .7689 L
.2311 .7638 L
.24045 .75261 L
.24739 .74552 L
.2557 .73631 L
.26369 .72819 L
.27101 .72001 L
.27999 .71095 L
.28675 .70372 L
.29628 .6941 L
.30248 .68742 L
.31258 .67726 L
.31844 .67112 L
.32888 .66062 L
.33437 .65482 L
.34518 .64398 L
.35045 .63853 L
.36147 .62746 L
.36651 .62223 L
.37777 .61094 L
.38266 .60593 L
.39407 .5945 L
.3988 .58963 L
.41037 .57806 L
.415 .57334 L
.42666 .56166 L
.4312 .55704 L
.44296 .54528 L
.44745 .54074 L
.45926 .52893 L
.46369 .52445 L
.47555 .51259 L
.47994 .50815 L
.47994 .49185 L
.47555 .48741 L
.46369 .47555 L
.45926 .47107 L
.44745 .45926 L
.44296 .45472 L
.4312 .44296 L
.42666 .43834 L
.415 .42666 L
.41037 .42194 L
.3988 .41037 L
.39407 .4055 L
.38266 .39407 L
Mistroke
.37777 .38906 L
.36651 .37777 L
.36147 .37254 L
.35045 .36147 L
.34518 .35602 L
.33437 .34518 L
.32888 .33938 L
.31844 .32888 L
.31258 .32274 L
.30248 .31258 L
.29628 .3059 L
.28675 .29628 L
.27999 .28905 L
.27101 .27999 L
.26369 .27181 L
.2557 .26369 L
.24739 .25448 L
.24045 .24739 L
.2311 .2362 L
.22619 .2311 L
.2148 .21716 L
.21259 .2148 L
.2148 .19947 L
.21847 .1985 L
.2311 .19439 L
.24739 .18994 L
.26369 .18422 L
.26985 .1822 L
.27999 .17915 L
.29628 .17482 L
.31258 .17118 L
.32888 .16824 L
.34518 .16602 L
.34588 .16591 L
.36147 .16452 L
Mfstroke
.4 g
.27999 .21228 m
.29628 .20933 L
.31258 .207 L
.32888 .20537 L
.34518 .20442 L
.36147 .20417 L
.37777 .20464 L
.39407 .20582 L
.41037 .20775 L
.42666 .21043 L
.44296 .21389 L
.44674 .2148 L
.45926 .21815 L
.47555 .22325 L
.49185 .22926 L
.49638 .2311 L
.50815 .23623 L
.52445 .24424 L
.53029 .24739 L
.54074 .25342 L
.55675 .26369 L
.55704 .26389 L
.57334 .27584 L
.57851 .27999 L
.58963 .28953 L
.5969 .29628 L
.60593 .30533 L
.61266 .31258 L
.62223 .32379 L
.62627 .32888 L
.63806 .34518 L
.63853 .34587 L
.64826 .36147 L
.65482 .37342 L
.65703 .37777 L
.66451 .39407 L
.67078 .41037 L
.67112 .41134 L
.67592 .42666 L
.67997 .44296 L
.68299 .45926 L
.68498 .47555 L
.68598 .49185 L
.68598 .50815 L
.68498 .52445 L
.68299 .54074 L
.67997 .55704 L
.67592 .57334 L
.67112 .58866 L
.67078 .58963 L
.66451 .60593 L
.65703 .62223 L
.65482 .62658 L
.64826 .63853 L
.63853 .65413 L
.63806 .65482 L
.62627 .67112 L
.62223 .67621 L
.61266 .68742 L
.60593 .69467 L
.5969 .70372 L
.58963 .71047 L
.57851 .72001 L
.57334 .72416 L
.55704 .73611 L
.55675 .73631 L
.54074 .74658 L
.53029 .75261 L
.52445 .75576 L
.50815 .76377 L
.49638 .7689 L
.49185 .77074 L
.47555 .77675 L
.45926 .78185 L
.44674 .7852 L
.44296 .78611 L
.42666 .78957 L
.41037 .79225 L
.39407 .79418 L
.37777 .79536 L
.36147 .79583 L
.34518 .79558 L
.32888 .79463 L
.31258 .793 L
.29628 .79067 L
.27999 .78772 L
.2668 .7852 L
.26369 .78463 L
.24739 .78144 L
.2311 .78049 L
.23058 .7689 L
.2311 .76835 L
.2438 .75261 L
.24739 .7489 L
.25859 .73631 L
.26369 .73108 L
.27352 .72001 L
.27999 .71346 L
.28906 .70372 L
.29628 .69639 L
.30458 .68742 L
.31258 .67935 L
.32042 .67112 L
.32888 .66259 L
.33623 .65482 L
.34518 .64583 L
.35223 .63853 L
.36147 .62924 L
.36821 .62223 L
.37777 .61264 L
.38431 .60593 L
.39407 .59614 L
.4004 .58963 L
.41037 .57965 L
.41657 .57334 L
.42666 .56323 L
.43274 .55704 L
.44296 .54681 L
.44897 .54074 L
.45926 .53044 L
.4652 .52445 L
.47555 .51409 L
.48142 .50815 L
.48142 .49185 L
.47555 .48591 L
.4652 .47555 L
.45926 .46956 L
.44897 .45926 L
.44296 .45319 L
.43274 .44296 L
.42666 .43677 L
.41657 .42666 L
.41037 .42035 L
.4004 .41037 L
.39407 .40386 L
.38431 .39407 L
.37777 .38736 L
.36821 .37777 L
.36147 .37076 L
.35223 .36147 L
.34518 .35417 L
.33623 .34518 L
.32888 .33741 L
.32042 .32888 L
.31258 .32065 L
.30458 .31258 L
.29628 .30361 L
.28906 .29628 L
.27999 .28654 L
.27352 .27999 L
.26369 .26892 L
.25859 .26369 L
.24739 .2511 L
.2438 .24739 L
.2311 .23165 L
.23058 .2311 L
.2311 .21951 L
.24739 .21856 L
.26369 .21537 L
.2668 .2148 L
F
0 g
.27999 .21228 m
.29628 .20933 L
.31258 .207 L
.32888 .20537 L
.34518 .20442 L
.36147 .20417 L
.37777 .20464 L
.39407 .20582 L
.41037 .20775 L
.42666 .21043 L
.44296 .21389 L
.44674 .2148 L
.45926 .21815 L
.47555 .22325 L
.49185 .22926 L
.49638 .2311 L
.50815 .23623 L
.52445 .24424 L
.53029 .24739 L
.54074 .25342 L
.55675 .26369 L
.55704 .26389 L
.57334 .27584 L
.57851 .27999 L
.58963 .28953 L
.5969 .29628 L
.60593 .30533 L
.61266 .31258 L
.62223 .32379 L
.62627 .32888 L
.63806 .34518 L
.63853 .34587 L
.64826 .36147 L
.65482 .37342 L
.65703 .37777 L
.66451 .39407 L
.67078 .41037 L
.67112 .41134 L
.67592 .42666 L
.67997 .44296 L
.68299 .45926 L
.68498 .47555 L
.68598 .49185 L
.68598 .50815 L
.68498 .52445 L
.68299 .54074 L
.67997 .55704 L
.67592 .57334 L
.67112 .58866 L
.67078 .58963 L
Mistroke
.66451 .60593 L
.65703 .62223 L
.65482 .62658 L
.64826 .63853 L
.63853 .65413 L
.63806 .65482 L
.62627 .67112 L
.62223 .67621 L
.61266 .68742 L
.60593 .69467 L
.5969 .70372 L
.58963 .71047 L
.57851 .72001 L
.57334 .72416 L
.55704 .73611 L
.55675 .73631 L
.54074 .74658 L
.53029 .75261 L
.52445 .75576 L
.50815 .76377 L
.49638 .7689 L
.49185 .77074 L
.47555 .77675 L
.45926 .78185 L
.44674 .7852 L
.44296 .78611 L
.42666 .78957 L
.41037 .79225 L
.39407 .79418 L
.37777 .79536 L
.36147 .79583 L
.34518 .79558 L
.32888 .79463 L
.31258 .793 L
.29628 .79067 L
.27999 .78772 L
.2668 .7852 L
.26369 .78463 L
.24739 .78144 L
.2311 .78049 L
.23058 .7689 L
.2311 .76835 L
.2438 .75261 L
.24739 .7489 L
.25859 .73631 L
.26369 .73108 L
.27352 .72001 L
.27999 .71346 L
.28906 .70372 L
.29628 .69639 L
Mistroke
.30458 .68742 L
.31258 .67935 L
.32042 .67112 L
.32888 .66259 L
.33623 .65482 L
.34518 .64583 L
.35223 .63853 L
.36147 .62924 L
.36821 .62223 L
.37777 .61264 L
.38431 .60593 L
.39407 .59614 L
.4004 .58963 L
.41037 .57965 L
.41657 .57334 L
.42666 .56323 L
.43274 .55704 L
.44296 .54681 L
.44897 .54074 L
.45926 .53044 L
.4652 .52445 L
.47555 .51409 L
.48142 .50815 L
.48142 .49185 L
.47555 .48591 L
.4652 .47555 L
.45926 .46956 L
.44897 .45926 L
.44296 .45319 L
.43274 .44296 L
.42666 .43677 L
.41657 .42666 L
.41037 .42035 L
.4004 .41037 L
.39407 .40386 L
.38431 .39407 L
.37777 .38736 L
.36821 .37777 L
.36147 .37076 L
.35223 .36147 L
.34518 .35417 L
.33623 .34518 L
.32888 .33741 L
.32042 .32888 L
.31258 .32065 L
.30458 .31258 L
.29628 .30361 L
.28906 .29628 L
.27999 .28654 L
.27352 .27999 L
Mistroke
.26369 .26892 L
.25859 .26369 L
.24739 .2511 L
.2438 .24739 L
.2311 .23165 L
.23058 .2311 L
.2311 .21951 L
.24739 .21856 L
.26369 .21537 L
.2668 .2148 L
.27999 .21228 L
Mfstroke
.5 g
.26369 .24242 m
.27999 .24175 L
.29628 .24029 L
.31258 .23931 L
.32888 .23887 L
.34518 .23909 L
.36147 .24002 L
.37777 .24168 L
.39407 .24408 L
.41037 .24726 L
.41099 .24739 L
.42666 .25125 L
.44296 .2561 L
.45926 .26187 L
.4639 .26369 L
.47555 .26863 L
.49185 .27646 L
.49848 .27999 L
.50815 .28551 L
.52445 .29591 L
.52499 .29628 L
.54074 .30791 L
.5465 .31258 L
.55704 .3218 L
.56446 .32888 L
.57334 .33808 L
.57964 .34518 L
.58963 .35754 L
.59257 .36147 L
.60356 .37777 L
.60593 .38166 L
.61286 .39407 L
.62061 .41037 L
.62223 .41418 L
.62696 .42666 L
.63196 .44296 L
.63568 .45926 L
.63815 .47555 L
.63853 .47916 L
.63939 .49185 L
.63939 .50815 L
.63853 .52084 L
.63815 .52445 L
.63568 .54074 L
.63196 .55704 L
.62696 .57334 L
.62223 .58582 L
.62061 .58963 L
.61286 .60593 L
.60593 .61834 L
.60356 .62223 L
.59257 .63853 L
.58963 .64246 L
.57964 .65482 L
.57334 .66192 L
.56446 .67112 L
.55704 .6782 L
.5465 .68742 L
.54074 .69209 L
.52499 .70372 L
.52445 .70409 L
.50815 .71449 L
.49848 .72001 L
.49185 .72354 L
.47555 .73137 L
.4639 .73631 L
.45926 .73813 L
.44296 .7439 L
.42666 .74875 L
.41099 .75261 L
.41037 .75274 L
.39407 .75592 L
.37777 .75832 L
.36147 .75998 L
.34518 .76091 L
.32888 .76113 L
.31258 .76069 L
.29628 .75971 L
.27999 .75825 L
.26369 .75758 L
.24784 .75261 L
.26167 .73631 L
.26369 .7342 L
.27611 .72001 L
.27999 .71606 L
.29139 .70372 L
.29628 .69873 L
.30668 .68742 L
.31258 .68145 L
.32239 .67112 L
.32888 .66456 L
.33806 .65482 L
.34518 .64767 L
.35399 .63853 L
.36147 .63099 L
.36988 .62223 L
.37777 .61431 L
.38593 .60593 L
.39407 .59776 L
.40196 .58963 L
.41037 .58122 L
.41811 .57334 L
.42666 .56476 L
.43424 .55704 L
.44296 .54832 L
.45045 .54074 L
.45926 .53192 L
.46666 .52445 L
.47555 .51556 L
.48288 .50815 L
.48288 .49185 L
.47555 .48444 L
.46666 .47555 L
.45926 .46808 L
.45045 .45926 L
.44296 .45168 L
.43424 .44296 L
.42666 .43524 L
.41811 .42666 L
.41037 .41878 L
.40196 .41037 L
.39407 .40224 L
.38593 .39407 L
.37777 .38569 L
.36988 .37777 L
.36147 .36901 L
.35399 .36147 L
.34518 .35233 L
.33806 .34518 L
.32888 .33544 L
.32239 .32888 L
.31258 .31855 L
.30668 .31258 L
.29628 .30127 L
.29139 .29628 L
.27999 .28394 L
.27611 .27999 L
.26369 .2658 L
.26167 .26369 L
.24784 .24739 L
F
0 g
.26369 .24242 m
.27999 .24175 L
.29628 .24029 L
.31258 .23931 L
.32888 .23887 L
.34518 .23909 L
.36147 .24002 L
.37777 .24168 L
.39407 .24408 L
.41037 .24726 L
.41099 .24739 L
.42666 .25125 L
.44296 .2561 L
.45926 .26187 L
.4639 .26369 L
.47555 .26863 L
.49185 .27646 L
.49848 .27999 L
.50815 .28551 L
.52445 .29591 L
.52499 .29628 L
.54074 .30791 L
.5465 .31258 L
.55704 .3218 L
.56446 .32888 L
.57334 .33808 L
.57964 .34518 L
.58963 .35754 L
.59257 .36147 L
.60356 .37777 L
.60593 .38166 L
.61286 .39407 L
.62061 .41037 L
.62223 .41418 L
.62696 .42666 L
.63196 .44296 L
.63568 .45926 L
.63815 .47555 L
.63853 .47916 L
.63939 .49185 L
.63939 .50815 L
.63853 .52084 L
.63815 .52445 L
.63568 .54074 L
.63196 .55704 L
.62696 .57334 L
.62223 .58582 L
.62061 .58963 L
.61286 .60593 L
.60593 .61834 L
Mistroke
.60356 .62223 L
.59257 .63853 L
.58963 .64246 L
.57964 .65482 L
.57334 .66192 L
.56446 .67112 L
.55704 .6782 L
.5465 .68742 L
.54074 .69209 L
.52499 .70372 L
.52445 .70409 L
.50815 .71449 L
.49848 .72001 L
.49185 .72354 L
.47555 .73137 L
.4639 .73631 L
.45926 .73813 L
.44296 .7439 L
.42666 .74875 L
.41099 .75261 L
.41037 .75274 L
.39407 .75592 L
.37777 .75832 L
.36147 .75998 L
.34518 .76091 L
.32888 .76113 L
.31258 .76069 L
.29628 .75971 L
.27999 .75825 L
.26369 .75758 L
.24784 .75261 L
.26167 .73631 L
.26369 .7342 L
.27611 .72001 L
.27999 .71606 L
.29139 .70372 L
.29628 .69873 L
.30668 .68742 L
.31258 .68145 L
.32239 .67112 L
.32888 .66456 L
.33806 .65482 L
.34518 .64767 L
.35399 .63853 L
.36147 .63099 L
.36988 .62223 L
.37777 .61431 L
.38593 .60593 L
.39407 .59776 L
.40196 .58963 L
Mistroke
.41037 .58122 L
.41811 .57334 L
.42666 .56476 L
.43424 .55704 L
.44296 .54832 L
.45045 .54074 L
.45926 .53192 L
.46666 .52445 L
.47555 .51556 L
.48288 .50815 L
.48288 .49185 L
.47555 .48444 L
.46666 .47555 L
.45926 .46808 L
.45045 .45926 L
.44296 .45168 L
.43424 .44296 L
.42666 .43524 L
.41811 .42666 L
.41037 .41878 L
.40196 .41037 L
.39407 .40224 L
.38593 .39407 L
.37777 .38569 L
.36988 .37777 L
.36147 .36901 L
.35399 .36147 L
.34518 .35233 L
.33806 .34518 L
.32888 .33544 L
.32239 .32888 L
.31258 .31855 L
.30668 .31258 L
.29628 .30127 L
.29139 .29628 L
.27999 .28394 L
.27611 .27999 L
.26369 .2658 L
.26167 .26369 L
.24784 .24739 L
.26369 .24242 L
Mfstroke
.6 g
.27999 .26492 m
.29628 .26689 L
.31258 .26893 L
.32888 .26966 L
.34518 .27102 L
.36147 .27306 L
.37777 .27582 L
.39407 .27938 L
.39651 .27999 L
.41037 .28378 L
.42666 .28906 L
.44296 .29529 L
.44533 .29628 L
.45926 .30258 L
.47555 .31103 L
.4783 .31258 L
.49185 .32082 L
.50368 .32888 L
.50815 .33216 L
.5242 .34518 L
.52445 .34539 L
.54074 .36101 L
.54118 .36147 L
.55536 .37777 L
.55704 .37991 L
.5672 .39407 L
.57334 .40386 L
.57703 .41037 L
.58503 .42666 L
.58963 .43803 L
.59136 .44296 L
.59609 .45926 L
.59925 .47555 L
.60087 .49185 L
.60087 .50815 L
.59925 .52445 L
.59609 .54074 L
.59136 .55704 L
.58963 .56197 L
.58503 .57334 L
.57703 .58963 L
.57334 .59614 L
.5672 .60593 L
.55704 .62009 L
.55536 .62223 L
.54118 .63853 L
.54074 .63899 L
.52445 .65461 L
.5242 .65482 L
.50815 .66784 L
.50368 .67112 L
.49185 .67918 L
.4783 .68742 L
.47555 .68897 L
.45926 .69742 L
.44533 .70372 L
.44296 .70471 L
.42666 .71094 L
.41037 .71622 L
.39651 .72001 L
.39407 .72062 L
.37777 .72418 L
.36147 .72694 L
.34518 .72898 L
.32888 .73034 L
.31258 .73107 L
.29628 .73311 L
.27999 .73508 L
.27893 .72001 L
.27999 .71892 L
.29385 .70372 L
.29628 .70122 L
.30886 .68742 L
.31258 .68364 L
.3244 .67112 L
.32888 .66658 L
.33992 .65482 L
.34518 .64953 L
.35576 .63853 L
.36147 .63276 L
.37156 .62223 L
.37777 .61598 L
.38755 .60593 L
.39407 .59938 L
.40353 .58963 L
.41037 .58278 L
.41964 .57334 L
.42666 .56629 L
.43574 .55704 L
.44296 .54981 L
.45193 .54074 L
.45926 .5334 L
.46812 .52445 L
.47555 .51702 L
.48432 .50815 L
.48432 .49185 L
.47555 .48298 L
.46812 .47555 L
.45926 .4666 L
.45193 .45926 L
.44296 .45019 L
.43574 .44296 L
.42666 .43371 L
.41964 .42666 L
.41037 .41722 L
.40353 .41037 L
.39407 .40062 L
.38755 .39407 L
.37777 .38402 L
.37156 .37777 L
.36147 .36724 L
.35576 .36147 L
.34518 .35047 L
.33992 .34518 L
.32888 .33342 L
.3244 .32888 L
.31258 .31636 L
.30886 .31258 L
.29628 .29878 L
.29385 .29628 L
.27999 .28108 L
.27893 .27999 L
F
0 g
.27999 .26492 m
.29628 .26689 L
.31258 .26893 L
.32888 .26966 L
.34518 .27102 L
.36147 .27306 L
.37777 .27582 L
.39407 .27938 L
.39651 .27999 L
.41037 .28378 L
.42666 .28906 L
.44296 .29529 L
.44533 .29628 L
.45926 .30258 L
.47555 .31103 L
.4783 .31258 L
.49185 .32082 L
.50368 .32888 L
.50815 .33216 L
.5242 .34518 L
.52445 .34539 L
.54074 .36101 L
.54118 .36147 L
.55536 .37777 L
.55704 .37991 L
.5672 .39407 L
.57334 .40386 L
.57703 .41037 L
.58503 .42666 L
.58963 .43803 L
.59136 .44296 L
.59609 .45926 L
.59925 .47555 L
.60087 .49185 L
.60087 .50815 L
.59925 .52445 L
.59609 .54074 L
.59136 .55704 L
.58963 .56197 L
.58503 .57334 L
.57703 .58963 L
.57334 .59614 L
.5672 .60593 L
.55704 .62009 L
.55536 .62223 L
.54118 .63853 L
.54074 .63899 L
.52445 .65461 L
.5242 .65482 L
.50815 .66784 L
Mistroke
.50368 .67112 L
.49185 .67918 L
.4783 .68742 L
.47555 .68897 L
.45926 .69742 L
.44533 .70372 L
.44296 .70471 L
.42666 .71094 L
.41037 .71622 L
.39651 .72001 L
.39407 .72062 L
.37777 .72418 L
.36147 .72694 L
.34518 .72898 L
.32888 .73034 L
.31258 .73107 L
.29628 .73311 L
.27999 .73508 L
.27893 .72001 L
.27999 .71892 L
.29385 .70372 L
.29628 .70122 L
.30886 .68742 L
.31258 .68364 L
.3244 .67112 L
.32888 .66658 L
.33992 .65482 L
.34518 .64953 L
.35576 .63853 L
.36147 .63276 L
.37156 .62223 L
.37777 .61598 L
.38755 .60593 L
.39407 .59938 L
.40353 .58963 L
.41037 .58278 L
.41964 .57334 L
.42666 .56629 L
.43574 .55704 L
.44296 .54981 L
.45193 .54074 L
.45926 .5334 L
.46812 .52445 L
.47555 .51702 L
.48432 .50815 L
.48432 .49185 L
.47555 .48298 L
.46812 .47555 L
.45926 .4666 L
.45193 .45926 L
Mistroke
.44296 .45019 L
.43574 .44296 L
.42666 .43371 L
.41964 .42666 L
.41037 .41722 L
.40353 .41037 L
.39407 .40062 L
.38755 .39407 L
.37777 .38402 L
.37156 .37777 L
.36147 .36724 L
.35576 .36147 L
.34518 .35047 L
.33992 .34518 L
.32888 .33342 L
.3244 .32888 L
.31258 .31636 L
.30886 .31258 L
.29628 .29878 L
.29385 .29628 L
.27999 .28108 L
.27893 .27999 L
.27999 .26492 L
Mfstroke
.7 g
.31258 .29395 m
.32778 .29628 L
.32888 .29656 L
.34518 .30073 L
.36147 .30379 L
.37777 .30774 L
.39407 .31241 L
.39461 .31258 L
.41037 .31791 L
.42666 .32442 L
.43654 .32888 L
.44296 .332 L
.45926 .34079 L
.46659 .34518 L
.47555 .35096 L
.49013 .36147 L
.49185 .36281 L
.50815 .37676 L
.50923 .37777 L
.52445 .39356 L
.52488 .39407 L
.53775 .41037 L
.54074 .41469 L
.54819 .42666 L
.55648 .44296 L
.55704 .4442 L
.56274 .45926 L
.56697 .47555 L
.56926 .49185 L
.56926 .50815 L
.56697 .52445 L
.56274 .54074 L
.55704 .5558 L
.55648 .55704 L
.54819 .57334 L
.54074 .58531 L
.53775 .58963 L
.52488 .60593 L
.52445 .60644 L
.50923 .62223 L
.50815 .62324 L
.49185 .63719 L
.49013 .63853 L
.47555 .64904 L
.46659 .65482 L
.45926 .65921 L
.44296 .668 L
.43654 .67112 L
.42666 .67558 L
.41037 .68209 L
.39461 .68742 L
.39407 .68759 L
.37777 .69226 L
.36147 .69621 L
.34518 .69927 L
.32888 .70344 L
.32778 .70372 L
.31258 .70605 L
.29711 .70372 L
.31121 .68742 L
.31258 .68601 L
.32653 .67112 L
.32888 .66873 L
.34186 .65482 L
.34518 .65147 L
.35758 .63853 L
.36147 .63459 L
.37327 .62223 L
.37777 .61771 L
.38921 .60593 L
.39407 .60104 L
.40512 .58963 L
.41037 .58437 L
.42119 .57334 L
.42666 .56784 L
.43725 .55704 L
.44296 .55132 L
.45342 .54074 L
.45926 .53489 L
.4696 .52445 L
.47555 .51849 L
.48577 .50815 L
.48577 .49185 L
.47555 .48151 L
.4696 .47555 L
.45926 .46511 L
.45342 .45926 L
.44296 .44868 L
.43725 .44296 L
.42666 .43216 L
.42119 .42666 L
.41037 .41563 L
.40512 .41037 L
.39407 .39896 L
.38921 .39407 L
.37777 .38229 L
.37327 .37777 L
.36147 .36541 L
.35758 .36147 L
.34518 .34853 L
.34186 .34518 L
.32888 .33127 L
.32653 .32888 L
.31258 .31399 L
.31121 .31258 L
.29711 .29628 L
F
0 g
.31258 .29395 m
.32778 .29628 L
.32888 .29656 L
.34518 .30073 L
.36147 .30379 L
.37777 .30774 L
.39407 .31241 L
.39461 .31258 L
.41037 .31791 L
.42666 .32442 L
.43654 .32888 L
.44296 .332 L
.45926 .34079 L
.46659 .34518 L
.47555 .35096 L
.49013 .36147 L
.49185 .36281 L
.50815 .37676 L
.50923 .37777 L
.52445 .39356 L
.52488 .39407 L
.53775 .41037 L
.54074 .41469 L
.54819 .42666 L
.55648 .44296 L
.55704 .4442 L
.56274 .45926 L
.56697 .47555 L
.56926 .49185 L
.56926 .50815 L
.56697 .52445 L
.56274 .54074 L
.55704 .5558 L
.55648 .55704 L
.54819 .57334 L
.54074 .58531 L
.53775 .58963 L
.52488 .60593 L
.52445 .60644 L
.50923 .62223 L
.50815 .62324 L
.49185 .63719 L
.49013 .63853 L
.47555 .64904 L
.46659 .65482 L
.45926 .65921 L
.44296 .668 L
.43654 .67112 L
.42666 .67558 L
.41037 .68209 L
Mistroke
.39461 .68742 L
.39407 .68759 L
.37777 .69226 L
.36147 .69621 L
.34518 .69927 L
.32888 .70344 L
.32778 .70372 L
.31258 .70605 L
.29711 .70372 L
.31121 .68742 L
.31258 .68601 L
.32653 .67112 L
.32888 .66873 L
.34186 .65482 L
.34518 .65147 L
.35758 .63853 L
.36147 .63459 L
.37327 .62223 L
.37777 .61771 L
.38921 .60593 L
.39407 .60104 L
.40512 .58963 L
.41037 .58437 L
.42119 .57334 L
.42666 .56784 L
.43725 .55704 L
.44296 .55132 L
.45342 .54074 L
.45926 .53489 L
.4696 .52445 L
.47555 .51849 L
.48577 .50815 L
.48577 .49185 L
.47555 .48151 L
.4696 .47555 L
.45926 .46511 L
.45342 .45926 L
.44296 .44868 L
.43725 .44296 L
.42666 .43216 L
.42119 .42666 L
.41037 .41563 L
.40512 .41037 L
.39407 .39896 L
.38921 .39407 L
.37777 .38229 L
.37327 .37777 L
.36147 .36541 L
.35758 .36147 L
.34518 .34853 L
Mistroke
.34186 .34518 L
.32888 .33127 L
.32653 .32888 L
.31258 .31399 L
.31121 .31258 L
.29711 .29628 L
.31258 .29395 L
Mfstroke
.8 g
.34518 .32601 m
.35579 .32888 L
.36147 .33103 L
.37777 .33741 L
.39407 .34302 L
.39943 .34518 L
.41037 .35018 L
.42666 .35784 L
.43377 .36147 L
.44296 .36656 L
.45926 .37679 L
.46071 .37777 L
.47555 .38858 L
.48232 .39407 L
.49185 .40255 L
.49982 .41037 L
.50815 .4194 L
.51411 .42666 L
.52445 .44148 L
.52536 .44296 L
.53406 .45926 L
.5402 .47555 L
.54074 .47746 L
.54361 .49185 L
.54361 .50815 L
.54074 .52254 L
.5402 .52445 L
.53406 .54074 L
.52536 .55704 L
.52445 .55852 L
.51411 .57334 L
.50815 .5806 L
.49982 .58963 L
.49185 .59745 L
.48232 .60593 L
.47555 .61142 L
.46071 .62223 L
.45926 .62321 L
.44296 .63344 L
.43377 .63853 L
.42666 .64216 L
.41037 .64982 L
.39943 .65482 L
.39407 .65698 L
.37777 .66259 L
.36147 .66897 L
.35579 .67112 L
.34518 .67399 L
.3289 .67112 L
.34396 .65482 L
.34518 .65358 L
.35952 .63853 L
.36147 .63654 L
.37508 .62223 L
.37777 .61952 L
.39093 .60593 L
.39407 .60276 L
.40676 .58963 L
.41037 .58602 L
.42279 .57334 L
.42666 .56944 L
.43881 .55704 L
.44296 .55288 L
.45495 .54074 L
.45926 .53642 L
.47111 .52445 L
.47555 .52 L
.48727 .50815 L
.48727 .49185 L
.47555 .48 L
.47111 .47555 L
.45926 .46358 L
.45495 .45926 L
.44296 .44712 L
.43881 .44296 L
.42666 .43056 L
.42279 .42666 L
.41037 .41398 L
.40676 .41037 L
.39407 .39724 L
.39093 .39407 L
.37777 .38048 L
.37508 .37777 L
.36147 .36346 L
.35952 .36147 L
.34518 .34642 L
.34396 .34518 L
.3289 .32888 L
F
0 g
.34518 .32601 m
.35579 .32888 L
.36147 .33103 L
.37777 .33741 L
.39407 .34302 L
.39943 .34518 L
.41037 .35018 L
.42666 .35784 L
.43377 .36147 L
.44296 .36656 L
.45926 .37679 L
.46071 .37777 L
.47555 .38858 L
.48232 .39407 L
.49185 .40255 L
.49982 .41037 L
.50815 .4194 L
.51411 .42666 L
.52445 .44148 L
.52536 .44296 L
.53406 .45926 L
.5402 .47555 L
.54074 .47746 L
.54361 .49185 L
.54361 .50815 L
.54074 .52254 L
.5402 .52445 L
.53406 .54074 L
.52536 .55704 L
.52445 .55852 L
.51411 .57334 L
.50815 .5806 L
.49982 .58963 L
.49185 .59745 L
.48232 .60593 L
.47555 .61142 L
.46071 .62223 L
.45926 .62321 L
.44296 .63344 L
.43377 .63853 L
.42666 .64216 L
.41037 .64982 L
.39943 .65482 L
.39407 .65698 L
.37777 .66259 L
.36147 .66897 L
.35579 .67112 L
.34518 .67399 L
.3289 .67112 L
.34396 .65482 L
Mistroke
.34518 .65358 L
.35952 .63853 L
.36147 .63654 L
.37508 .62223 L
.37777 .61952 L
.39093 .60593 L
.39407 .60276 L
.40676 .58963 L
.41037 .58602 L
.42279 .57334 L
.42666 .56944 L
.43881 .55704 L
.44296 .55288 L
.45495 .54074 L
.45926 .53642 L
.47111 .52445 L
.47555 .52 L
.48727 .50815 L
.48727 .49185 L
.47555 .48 L
.47111 .47555 L
.45926 .46358 L
.45495 .45926 L
.44296 .44712 L
.43881 .44296 L
.42666 .43056 L
.42279 .42666 L
.41037 .41398 L
.40676 .41037 L
.39407 .39724 L
.39093 .39407 L
.37777 .38048 L
.37508 .37777 L
.36147 .36346 L
.35952 .36147 L
.34518 .34642 L
.34396 .34518 L
.3289 .32888 L
.34518 .32601 L
Mfstroke
.9 g
.37777 .36205 m
.39407 .3711 L
.40801 .37777 L
.41037 .37901 L
.42666 .38775 L
.43603 .39407 L
.44296 .39886 L
.45926 .40984 L
.45995 .41037 L
.47555 .42383 L
.47868 .42666 L
.49185 .43894 L
.49556 .44296 L
.50804 .45926 L
.50815 .45941 L
.51929 .47555 L
.52445 .48757 L
.52549 .49185 L
.52549 .50815 L
.52445 .51243 L
.51929 .52445 L
.50815 .54059 L
.50804 .54074 L
.49556 .55704 L
.49185 .56106 L
.47868 .57334 L
.47555 .57617 L
.45995 .58963 L
.45926 .59016 L
.44296 .60114 L
.43603 .60593 L
.42666 .61225 L
.41037 .62099 L
.40801 .62223 L
.39407 .6289 L
.37777 .63795 L
.37704 .62223 L
.37777 .62149 L
.39278 .60593 L
.39407 .60462 L
.40851 .58963 L
.41037 .58777 L
.42447 .57334 L
.42666 .57113 L
.44044 .55704 L
.44296 .55452 L
.45655 .54074 L
.45926 .53803 L
.47269 .52445 L
.47555 .52158 L
.48883 .50815 L
.48883 .49185 L
.47555 .47842 L
.47269 .47555 L
.45926 .46197 L
.45655 .45926 L
.44296 .44548 L
.44044 .44296 L
.42666 .42887 L
.42447 .42666 L
.41037 .41223 L
.40851 .41037 L
.39407 .39538 L
.39278 .39407 L
.37777 .37851 L
.37704 .37777 L
F
0 g
.37777 .36205 m
.39407 .3711 L
.40801 .37777 L
.41037 .37901 L
.42666 .38775 L
.43603 .39407 L
.44296 .39886 L
.45926 .40984 L
.45995 .41037 L
.47555 .42383 L
.47868 .42666 L
.49185 .43894 L
.49556 .44296 L
.50804 .45926 L
.50815 .45941 L
.51929 .47555 L
.52445 .48757 L
.52549 .49185 L
.52549 .50815 L
.52445 .51243 L
.51929 .52445 L
.50815 .54059 L
.50804 .54074 L
.49556 .55704 L
.49185 .56106 L
.47868 .57334 L
.47555 .57617 L
.45995 .58963 L
.45926 .59016 L
.44296 .60114 L
.43603 .60593 L
.42666 .61225 L
.41037 .62099 L
.40801 .62223 L
.39407 .6289 L
.37777 .63795 L
.37704 .62223 L
.37777 .62149 L
.39278 .60593 L
.39407 .60462 L
.40851 .58963 L
.41037 .58777 L
.42447 .57334 L
.42666 .57113 L
.44044 .55704 L
.44296 .55452 L
.45655 .54074 L
.45926 .53803 L
.47269 .52445 L
.47555 .52158 L
Mistroke
.48883 .50815 L
.48883 .49185 L
.47555 .47842 L
.47269 .47555 L
.45926 .46197 L
.45655 .45926 L
.44296 .44548 L
.44044 .44296 L
.42666 .42887 L
.42447 .42666 L
.41037 .41223 L
.40851 .41037 L
.39407 .39538 L
.39278 .39407 L
.37777 .37851 L
.37704 .37777 L
.37777 .36205 L
Mfstroke
1 g
.42666 .41228 m
.44296 .42652 L
.44326 .42666 L
.45926 .44013 L
.4629 .44296 L
.47555 .45233 L
.48375 .45926 L
.49185 .46922 L
.4984 .47555 L
.50815 .4869 L
.51099 .49185 L
.51099 .50815 L
.50815 .5131 L
.4984 .52445 L
.49185 .53078 L
.48375 .54074 L
.47555 .54767 L
.4629 .55704 L
.45926 .55987 L
.44326 .57334 L
.44296 .57348 L
.42666 .58772 L
.42632 .57334 L
.42666 .57299 L
.44222 .55704 L
.44296 .55629 L
.45828 .54074 L
.45926 .53976 L
.47439 .52445 L
.47555 .52328 L
.4905 .50815 L
.4905 .49185 L
.47555 .47672 L
.47439 .47555 L
.45926 .46024 L
.45828 .45926 L
.44296 .44371 L
.44222 .44296 L
.42666 .42701 L
.42632 .42666 L
F
0 g
.42666 .41228 m
.44296 .42652 L
.44326 .42666 L
.45926 .44013 L
.4629 .44296 L
.47555 .45233 L
.48375 .45926 L
.49185 .46922 L
.4984 .47555 L
.50815 .4869 L
.51099 .49185 L
.51099 .50815 L
.50815 .5131 L
.4984 .52445 L
.49185 .53078 L
.48375 .54074 L
.47555 .54767 L
.4629 .55704 L
.45926 .55987 L
.44326 .57334 L
.44296 .57348 L
.42666 .58772 L
.42632 .57334 L
.42666 .57299 L
.44222 .55704 L
.44296 .55629 L
.45828 .54074 L
.45926 .53976 L
.47439 .52445 L
.47555 .52328 L
.4905 .50815 L
.4905 .49185 L
.47555 .47672 L
.47439 .47555 L
.45926 .46024 L
.45828 .45926 L
.44296 .44371 L
.44222 .44296 L
.42666 .42701 L
.42632 .42666 L
.42666 .41228 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{332.375, 332.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006O0001Wb000`400?l00000o`00003ooooooonP
ooooo`00oooooonPooooo`00oooooonPooooo`00oooooonPooooo`00oooooonPooooo`00oooooonP
ooooo`00i_ooool2o`0000;ooooo0_l0002cooooo`00i_ooool01_o^k^ko8B4QohN7Qonj^[[o0000
omgMgK?ooooo003Wooooo`04omgMgOl0003o410@olc<c;Cooooo003Wooooo`04onk^k_lQ8B7o410@
onk^k[Cooooo003Wooooo`04ob4Q8OmgMgOoMgMgoc8b<[Cooooo003Vooooo`;o00000_ooool2o`00
0;?ooooo003ooooooj3ooooo003ooooooj3ooooo003ooooooj3ooooo003ooooooj3ooooo003ooooo
oj3ooooo003ooooooj3ooooo000looooo`Co000000?o410@ooooooooool0Aoooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0A_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^04[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM04[ooooo1?l000000ol@413oooooooooo`03ooooo`00?_oo
ool00ol0003oooooooooo`19ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0AOooool01OmgMgOoV9RHoooooonHV9SoMgMg04[ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`1;ooooo`03o`000?oooooooooo
00Gooooo000cooooo`Ko00001Oooool00ol0003oooooooooo`11ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool0A?ooool01Ol@413ooooooooooooooooo
410@04[ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo04[ooooo00?o
0000ooooooooool01Oooool003kooooo00?o0000ooooooooool0BOooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool0AOooool01Ol0003ooooooooooooooooo000004[ooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo04_ooooo00?o0000oooooooo
ool01Oooool003kooooo00?o0000ooooooooool0BOooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c016ooooo`05o`000?ooooooooooooooool00000B_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c01<ooooo`03o`00
0?oooooooooo00Gooooo000nooooo`03o`000?oooooooooo04Wooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo04Sooooo00Go410@oooooooooooooooooa0@401:ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
00Gooooo000nooooo`03o`000?oooooooooo04Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03o`000?oooooooooo04Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1:ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Gooooo000l
ooooo`03oeEEEOmVIVKo000004_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000Aooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^04[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
0000Boooool00omEEEGoIVIVo`000007ooooo`00oooooonPooooo`00oooooonPooooo`00oooooonP
ooooo`00oooooonPooooo`00oooooonPooooo`00oooooonPooooo`00<oooooooo`0006go0000000c
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Cooooo0Ol0000003?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1Dooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0E?ooool00ol0
003oooooooooo`1Dooooo`03o`000?oooooooooo00Cooooo0Ol0000003?ooooo00?o0000oooooooo
ool0oooooomYooooo`7o0000000Yooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`3oooooofWooooo0Ol0000002_ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`3oooooofWooooo0Ol00000023ooooo1_l00005ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0oooooomYooooo`7o0000000[ooooo`03o`000?oooooooooo00Gooooo1?l0003ooooo
ofKooooo0ol0000002_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooooooo
0000G_l00007ooooo`7o0000000[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooooooo`0005ko00001oooool1o`000000:oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Coooooool0001No`0000Oooooo0Ol0000002Wooooo00?oEEEEofIVI_l000001oooool0
0ol0003oooooooooo`04oooooooo0000G_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo
00Coooooool0001No`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?ooooooo`0005ko
00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooooo0000G_l00007ooooo`7o0000
000cooooo`03o`000?oooooooooo00Coooooool0001No`0000Oooooo0Ol0000003?ooooo00?o0000
ooooooooool01?ooooooo`0005ko00001oooool1o`000000<oooool00ol0003oooooooooo`04oooo
oooo0000G_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Coooooool0001No`0000Oo
oooo0Ol0000003?ooooo00?o0000ooooooooool01?ooooooo`0005ko00001oooool1o`000000<ooo
ool00ol0003oooooooooo`04oooooooo0000G_l00007ooooo`7o0000000cooooo`03o`000?oooooo
oooo00Coooooool0001No`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooonAo`00
00go6ATI_ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooQOl0000[oaTI6Jgo
00001oooool1o`000000<oooool3o`0000CoooooOol0000loaTI6J;o00001Oooool3o`000000<ooo
ool00ol0003oooooooooo`04ooooogSo0000B_lI6AVKo`0000Oooooo0Ol0000003?ooooo00?o0000
ooooooooool01?oooomeo`0005;o6ATIU_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo
00CoooooLol0001IoaTI6I7o00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooog;o
0000GOlI6AV>o`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooom`o`0006;o6ATI
Rol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooKOl0001XoaTI6HSo00001ooo
ool1o`000000<oooool00ol0003oooooooooo`04ooooofOo0000LOlI6AV5o`0000Oooooo0Ol00000
03?ooooo00?o0000ooooooooool01?oooomVo`0007Go6ATIP_l00007ooooo`7o0000000cooooo`03
o`000?oooooooooo00CoooooI?l0001ioaTI6H3o00001oooool1o`000000<oooool00ol0003ooooo
ooooo`04ooooof7o0000O_lI6AUno`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oo
oomNo`0008?o6ATIO?l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooG?l00028
oaTI6GWo00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooe_o0000RolI6AUgo`00
00Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooomJo`0008go6ATIM_l00007ooooo`7o
0000000cooooo`03o`000?oooooooooo00CoooooF?l0002AoaTI6GCo00001oooool1o`000000<ooo
ool00ol0003oooooooooo`04oooooeKo0000UOlI6AUbo`0000Oooooo0Ol0000003?ooooo0ol00004
oooooeCo0000VOlI6AU`o`0000Gooooo0ol0000003?ooooo00?o0000ooooooooool01?oooomCo`00
02co6ATI8?l0001@oaTI6Fko00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooe7o
0000:?lI6AT6o`00023o<c<c2ol00017oaTI6Fco00001oooool1o`000000<oooool00ol0003ooooo
ooooo`04oooooe3o00009?lI6AT5o`00037o<c<c1_l00012oaTI6F_o00001oooool1o`000000<ooo
ool00ol0003oooooooooo`04ooooodoo00008OlI6AT4o`0003co<c<c1?l00010oaTI6FWo00001ooo
ool1o`000000<oooool00ol0003oooooooooo`04ooooodko00007olI6AT3o`0004Co<c<c0ol0000n
oaTI6FSo00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooodgo00007?lI6AT4o`00
04[o<c<c1?l0000loaTI6FKo00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooodco
00006_lI6AT3o`0005;o<c<c1Ol0000hoaTI6FGo00001oooool1o`000000<oooool00ol0003ooooo
ooooo`04oooood[o00006_lI6AT2o`0005[o<c<c0ol0000hoaTI6F;o00001oooool1o`000000<ooo
ool00ol0003oooooooooo`04ooooodSo00006OlI6AT3o`0005oo<c<c0_l0000goaTI6F7o00001ooo
ool1o`000000<oooool00ol0003oooooooooo`04ooooodKo00006?lI6AT3o`0006Co<c<c0_l0000f
oaTI6F3o00001oooool1o`000000<oooool00ol0003oooooooooo`04oooood?o00006?lI6AT3o`00
06Wo<c<c0_l0000eoaTI6Eoo00001oooool1o`000000<oooool00ol0003oooooooooo`04oooood3o
00006OlI6AT2o`0006ko<c<c0ol0000doaTI6Ego00001oooool1o`000000<oooool00ol0003ooooo
ooooo`04ooooocgo00006_lI6AT2o`0007?o<c<c0ol0000boaTI6Eco00001oooool1o`000000<ooo
ool00ol0003oooooooooo`04ooooocco00006?lI6AT3o`0007So<c<c0_l0000boaTI6E[o00001ooo
ool1o`000000<oooool00ol0003oooooooooo`04ooooocco00005_lI6AT2o`0007go<c<c0_l0000a
oaTI6EWo00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooc_o00005OlI6AT2o`00
087o<c<c0_l0000aoaTI6EOo00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooc[o
00005?lI6AT2o`0008Go<c<c0_l0000`oaTI6EKo00001oooool1o`000000<oooool3o`0000Cooooo
>_l0000BoaTI6@;o0000;?lc<c<Ho`0004Go<c<c00?o0000oaTI6OlI6AT0;_lI6AUEo`0000Gooooo
0ol0000003?ooooo00?o0000ooooooooool01?oooolio`00017o6ATI0_l0000Xoc<c<`Ko00006?m<
C4`;o`0003_o<c<c0ol0000^oaTI6ECo00001oooool1o`000000<oooool00ol0003oooooooooo`04
ooooocWo00003olI6AT2o`0002Co<c<c1_l0000Yoda<C0?o0000>olc<c<2o`0002go6ATIDol00007
ooooo`7o0000000cooooo`03o`000?oooooooooo00Cooooo>Ol0000=oaTI6@;o00008?lc<c<6o`00
03;oC4a<1?l0000ioc<c<`03o`000?lI6AWo6ATI02_o6ATID_l00007ooooo`7o0000000cooooo`03
o`000?oooooooooo00Cooooo>Ol0000;oaTI6@;o00007_lc<c<4o`0003coC4a<1_l0000doc<c<`;o
0000;?lI6AUAo`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?ooooljo`0000So6ATI
0_l0000Moc<c<`?o0000A_m<C4`4o`0003;o<c<c00?o0000oaTI6OlI6AT0:_lI6AU@o`0000Oooooo
0Ol0000003?ooooo00?o0000ooooooooool01?ooooljo`0000Oo6ATI00?o0000oc<c<olc<c<06Olc
<c<4o`0004goC4a<0_l0000aoc<c<`03o`000?lI6AWo6ATI02[o6ATICol00007ooooo`7o0000000c
ooooo`03o`000?oooooooooo00Cooooo>_l00006oaTI6@03o`000?lc<c?o<c<c01Go<c<c1Ol0001C
oda<C0Co0000;_lc<c<2o`0002_o6ATIC_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo
00Cooooo>_l00006oaTI6@03o`000?lc<c?o<c<c01?o<c<c0_l0001Loda<C0?o0000;Olc<c<2o`00
02[o6ATICOl00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Cooooo>ol00005oaTI6@03
o`000?lc<c?o<c<c017o<c<c0_l0001Qoda<C0;o0000;Olc<c<00ol0003o6ATIoaTI6@0XoaTI6Dco
00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooocco00001?lI6AT00ol0003o<c<c
oc<c<`0=oc<c<`Co0000IOm<C4`2o`0002co<c<c00?o0000oaTI6OlI6AT0:?lI6AU;o`0000Oooooo
0Ol0000003?ooooo00?o0000ooooooooool01?oooollo`0000Co6ATI00?o0000oc<c<olc<c<02Olc
<c<4o`0006_oC4a<0_l0000[oc<c<`03o`000?lI6AWo6ATI02So6ATIB_l00007ooooo`7o0000000c
ooooo`03o`000?oooooooooo00Cooooo?Ol00003oaTI6@03o`000?lc<c?o<c<c00Ko<c<c0ol0001a
oda<C0;o0000:_lc<c<00ol0003o6ATIoaTI6@0XoaTI6DWo00001oooool1o`000000<oooool00ol0
003oooooooooo`04ooooocko00000_lI6AT00ol0003o<c<coc<c<`04oc<c<`;o0000M_m<C4`2o`00
02Wo<c<c0_l0000YoaTI6DSo00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooocoo
00000_lI6AT00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<07OoC4a<0_l0000Yoc<c<`03
o`000?lI6AWo6ATI02Oo6ATIAol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Cooooo
@?l000000olI6AWo0000oc<c<`04oc<c<`03o`000?m<C4coC4a<02CoC4a<7_l0000goda<C0;o0000
:?lc<c<00ol0003o6ATIoaTI6@0VoaTI6DOo00001oooool1o`000000<oooool00ol0003ooooooooo
o`04oooood7o000000?o6ATIo`000?lc<c<00olc<c<00ol0003oC4a<oda<C00Noda<C0Ko00007_mV
IVH6o`0003?oC4a<0_l0000Woc<c<`03o`000?lI6AWo6ATI02Ko6ATIA_l00007ooooo`7o0000000c
ooooo`?o00001?oooom2o`000005oaTI6Ol0003o<c<coc<c<ol000006om<C4`6o`0002[oIVIV1_l0
000_oda<C0;o00009_lc<c<00ol0003o6ATIoaTI6@0VoaTI6DGo00001Oooool3o`000000<oooool0
0ol0003oooooooooo`04ooooodCo00000_lc<c<00ol0003oC4a<oda<C00Doda<C0Go0000=_mVIVH3
o`0002koC4a<00?o0000oc<c<olc<c<09?lc<c<00ol0003o6ATIoaTI6@0VoaTI6DCo00001oooool1
o`000000<oooool00ol0003oooooooooo`04ooooodSo00003_m<C4`7o`0003koIVIV1?l0000[oda<
C0;o00009Olc<c<00ol0003o6ATIoaTI6@0VoaTI6D?o00001oooool1o`000000<oooool00ol0003o
ooooooooo`04ooooodGo000000?o6ATIo`000?l000001Om<C4`9o`0004WoIVIV1?l0000Yoda<C0?o
00008olc<c<2o`0002Oo6ATI@_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Cooooo
A_l000000olI6AWo0000o`000004oda<C003o`000?mVIVKoIVIV05?oIVIV0ol0000Yoda<C0;o0000
8olc<c<00ol0003o6ATIoaTI6@0UoaTI6D7o00001oooool1o`000000<oooool00ol0003ooooooooo
o`04ooooodOo000000?o6ATIo`000?l000000om<C4`00ol0003oIVIVofIVIP1FofIVIP?o0000:?m<
C4`2o`0002;o<c<c00?o0000oaTI6OlI6AT09?lI6AU1o`0000Oooooo0Ol0000003?ooooo00?o0000
ooooooooool01?oooom8o`000003oaTI6Ol0003o000000;oC4a<00?o0000ofIVI_mVIVH0FOmVIVH3
o`0002OoC4a<00?o0000oc<c<olc<c<08?lc<c<00ol0003o6ATIoaTI6@0ToaTI6D3o00001oooool1
o`000000<oooool00ol0003oooooooooo`04ooooodWo000000Go6ATIo`000?l0003oC4a<o`00001N
ofIVIP?o00009Om<C4`00ol0003o<c<coc<c<`0Poc<c<`03o`000?lI6AWo6ATI02Co6ATI?ol00007
ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooBol000000olc<c?o0000o`00001QofIV
IP;o00009?m<C4`2o`00027o<c<c00?o0000oaTI6OlI6AT08olI6AToo`0000Oooooo0Ol0000003?o
oooo00?o0000ooooooooool01?oooom<o`000003oc<c<ol0003o000006;oIVIV0_l0000Toda<C003
o`000?lc<c?o<c<c01oo<c<c00?o0000oaTI6OlI6AT08olI6ATno`0000Oooooo0Ol0000003?ooooo
00?o0000ooooooooool01?oooom>o`000003oda<C?l0003oIVIV01OoIVIV4_l0000iofIVIP;o0000
8om<C4`00ol0003o<c<coc<c<`0Ooc<c<`03o`000?lI6AWo6ATI02?o6ATI?Ol00007ooooo`7o0000
000cooooo`03o`000?oooooooooo00CoooooCol000000om<C4co0000ofIVIP0:ofIVIPco00004_mo
Ogl<o`0002ooIVIV0_l0000Roda<C003o`000?lc<c?o<c<c01oo<c<c00?o0000oaTI6OlI6AT08_lI
6ATmo`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooom@o`000003oda<C?l0003o
IVIV00?oIVIV1_l0000ZogmoO`Ko0000:omVIVH3o`00023oC4a<00?o0000oc<c<olc<c<07olc<c<0
0ol0003o6ATIoaTI6@0RoaTI6Cco00001oooool1o`000000<oooool00ol0003oooooooooo`04oooo
oe7o000000?oC4a<o`000?l000000_l0000fogmoO`Go0000:OmVIVH00ol0003oC4a<oda<C00Noda<
C0;o00008?lc<c<00ol0003o6ATIoaTI6@0RoaTI6C_o00001oooool1o`000000<oooool00ol0003o
ooooooooo`04oooooeCo0000?OmoOgl3o`0002OoIVIV00?o0000oda<C?m<C4`07om<C4`00ol0003o
<c<coc<c<`0Moc<c<`03o`000?lI6AWo6ATI02;o6ATI>ol00007ooooo`7o0000000Hooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo00CoooooEOl0000oogmoO`Co00009?mVIVH00ol0003oC4a<oda<C00Ooda<
C003o`000?lc<c?o<c<c01go<c<c00?o0000oaTI6OlI6AT08_lI6ATjo`0000Oooooo0Ol0000001So
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo00CoooooE_l00012ogmoO`Co00008OmVIVH2o`00023oC4a<00?o0000oc<c
<olc<c<07Olc<c<00ol0003o6ATIoaTI6@0RoaTI6CWo00001oooool1o`0000004?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?oooomGo`0004GoOgmo0_l0000QofIVIP;o00007om<C4`00ol0003o<c<coc<c<`0Moc<c
<`03o`000?lI6AWo6ATI027o6ATI>Ol00007ooooo`7o0000000Hooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`Co00000ooooomHo`0004KoOgmo0_l0000QofIV
IP;o00007_m<C4`00ol0003o<c<coc<c<`0Moc<c<`03o`000?lI6AWo6ATI027o6ATI>?l00005oooo
o`?o0000000Hooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool01?oooomIo`0004OoOgmo0ol0000PofIVIP;o00007Om<C4`0
0ol0003o<c<coc<c<`0Moc<c<`03o`000?lI6AWo6ATI027o6ATI=ol00007ooooo`7o0000000Hoooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00CoooooF_l00005ogmoO`[o0000>_moOgl3o`0001ooIVIV00?o0000oda<C?m<C4`06om<C4`0
0ol0003o<c<coc<c<`0Loc<c<`03o`000?lI6AWo6ATI027o6ATI=ol00007ooooo`7o0000000Hoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00CoooooF_l00005ogmoO`03o`000?nIVIWoVIVI00OoVIVI3?l0000aogmoO`;o00007_mVIVH0
0ol0003oC4a<oda<C00Koda<C003o`000?lc<c?o<c<c01co<c<c00?o0000oaTI6OlI6AT08OlI6ATf
o`0000Oooooo0Ol0000001Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool0
0ol0003oooooooooo`04oooooe_o00001?moOgl00ol0003oVIVIoiVIV@0CoiVIV@Go0000;_moOgl2
o`0001goIVIV00?o0000oda<C?m<C4`06om<C4`00ol0003o<c<coc<c<`0Loc<c<`03o`000?lI6AWo
6ATI023o6ATI=_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooG?l00002ogmo
O`03o`000?nIVIWoVIVI01WoVIVI1_l0000ZogmoO`;o00007?mVIVH00ol0003oC4a<oda<C00Koda<
C003o`000?lc<c?o<c<c01_o<c<c00?o0000oaTI6OlI6AT08OlI6ATeo`0000Oooooo0Ol0000003?o
oooo00?o0000ooooooooool01?oooomMo`000003ogmoOol0003oVIVI023oVIVI1_l0000VogmoO`;o
00006omVIVH2o`0001coC4a<00?o0000oc<c<olc<c<06olc<c<00ol0003o6ATIoaTI6@0PoaTI6CGo
00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooeoo00009onIVIT5o`0002?oOgmo
0_l0000KofIVIP03o`000?m<C4coC4a<01WoC4a<00?o0000oc<c<olc<c<07?lc<c<00ol0003o6ATI
oaTI6@0PoaTI6CCo00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooof3o0000:onI
VIT3o`0002;oOgmo00?o0000ofIVI_mVIVH06OmVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?lc
<c?o<c<c01co<c<c00?o0000oaTI6OlI6AT08?lI6ATdo`0000Oooooo0Ol0000003?ooooo00?o0000
ooooooooool01?oooomQo`0002goVIVI1?l0000OogmoO`;o00006_mVIVH00ol0003oC4a<oda<C00H
oda<C003o`000?lc<c?o<c<c01co<c<c00?o0000oaTI6OlI6AT08?lI6ATco`0000Oooooo0Ol00000
03?ooooo00?o0000ooooooooool01?oooomRo`00033oVIVI1?l0000MogmoO`03o`000?mVIVKoIVIV
01SoIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003o<c<coc<c<`0Loc<c<`03o`000?lI6AWo6ATI
01oo6ATI<ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooHol0000coiVIV@;o
00007?moOgl2o`0001WoIVIV0_l0000Ioda<C003o`000?lc<c?o<c<c01_o<c<c00?o0000oaTI6OlI
6AT08?lI6ATbo`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooomTo`0000CoVIVI
1ol0000YoiVIV@;o00007?moOgl00ol0003oIVIVofIVIP0HofIVIP03o`000?m<C4coC4a<01OoC4a<
00?o0000oc<c<olc<c<06olc<c<00ol0003o6ATIoaTI6@0OoaTI6C;o00001oooool1o`000000<ooo
ool00ol0003oooooooooo`04ooooofSo00001onc/k<4o`0002OoVIVI0ol0000JogmoO`?o00006?mV
IVH00ol0003oC4a<oda<C00Goda<C0;o00007?lc<c<00ol0003o6ATIoaTI6@0OoaTI6C7o00001ooo
ool1o`000000<oooool00ol0003oooooooooo`04ooooofKo00003Onc/k<3o`0002OoVIVI0ol0000J
ogmoO`03o`000?mVIVKoIVIV01KoIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003o<c<coc<c<`0J
oc<c<`03o`000?lI6AWo6ATI01oo6ATI<Ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo
00CoooooIol0000?ok>c/`Co00009_nIVIT2o`0001WoOgmo00?o0000ofIVI_mVIVH05_mVIVH00ol0
003oC4a<oda<C00Goda<C003o`000?lc<c?o<c<c01[o<c<c00?o0000oaTI6OlI6AT07olI6AT`o`00
00Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooomXo`0001;o/k>c1_l0000RoiVIV@;o
00006?moOgl00ol0003oIVIVofIVIP0FofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000oc<c<olc
<c<06_lc<c<00ol0003o6ATIoaTI6@0OoaTI6Boo00001oooool1o`000000<oooool3o`0000Cooooo
JOl0000Gok>c/`Go00007onIVIT2o`0001OoOgmo00?o0000ofIVI_mVIVH05OmVIVH00ol0003oC4a<
oda<C00Goda<C003o`000?lc<c?o<c<c01[o<c<c00?o0000oaTI6OlI6AT07olI6AT_o`0000Gooooo
0ol0000003?ooooo00?o0000ooooooooool01?oooomZo`0001_o/k>c0ol0000NoiVIV@03o`000?mo
OgooOgmo01GoOgmo00?o0000ofIVI_mVIVH05OmVIVH00ol0003oC4a<oda<C00Goda<C003o`000?lc
<c?o<c<c01[o<c<c00?o0000oaTI6OlI6AT07olI6AT^o`0000Oooooo0Ol0000003?ooooo00?o0000
ooooooooool01?oooom/o`0001co/k>c0ol0000LoiVIV@;o00005_moOgl2o`0001KoIVIV00?o0000
oda<C?m<C4`05om<C4`00ol0003o<c<coc<c<`0Joc<c<`03o`000?lI6AWo6ATI01ko6ATI;_l00007
ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooK?l0000Ook>c/`?o00006onIVIT2o`00
01KoOgmo00?o0000ofIVI_mVIVH05?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?lc<c?o<c<c
01[o<c<c00?o0000oaTI6OlI6AT07_lI6AT^o`0000Oooooo0Ol0000003?ooooo00?o0000oooooooo
ool01?oooom]o`00027o/k>c0ol0000JoiVIV@03o`000?moOgooOgmo01CoOgmo00?o0000ofIVI_mV
IVH05?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?lc<c?o<c<c01[o<c<c00?o0000oaTI6OlI
6AT07_lI6AT]o`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooom^o`0002?o/k>c
0ol0000HoiVIV@;o00005OmoOgl00ol0003oIVIVofIVIP0DofIVIP03o`000?m<C4coC4a<01GoC4a<
00?o0000oc<c<olc<c<06_lc<c<00ol0003o6ATIoaTI6@0NoaTI6Bgo00001oooool1o`000000<ooo
ool00ol0003oooooooooo`04ooooofoo00009Onc/k<2o`0001SoVIVI00?o0000ogmoOomoOgl04omo
Ogl00ol0003oIVIVofIVIP0DofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000oc<c<olc<c<06Olc
<c<00ol0003o6ATIoaTI6@0NoaTI6Bgo00001oooool1o`000000<oooool00ol0003oooooooooo`04
ooooog3o00001?nc/k<5o`0001go/k>c0_l0000GoiVIV@03o`000?moOgooOgmo01?oOgmo00?o0000
ofIVI_mVIVH04omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?lc<c?o<c<c01Wo<c<c00?o0000
oaTI6OlI6AT07_lI6AT/o`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooomdo`00
00Goc<c<0ol0000Lok>c/`;o00005_nIVIT00ol0003oOgmoogmoO`0CogmoO`03o`000?mVIVKoIVIV
01?oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o<c<coc<c<`0Ioc<c<`03o`000?lI6AWo6ATI
01go6ATI;?l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooL_l0000:olc<c0?o
00006onc/k<2o`0001GoVIVI0_l0000DogmoO`03o`000?mVIVKoIVIV01;oIVIV00?o0000oda<C?m<
C4`05_m<C4`00ol0003o<c<coc<c<`0Ioc<c<`03o`000?lI6AWo6ATI01go6ATI;?l00007ooooo`7o
0000000cooooo`03o`000?oooooooooo00CoooooLol0000<olc<c0?o00006_nc/k<2o`0001GoVIVI
00?o0000ogmoOomoOgl04_moOgl00ol0003oIVIVofIVIP0BofIVIP03o`000?m<C4coC4a<01KoC4a<
00?o0000oc<c<olc<c<06Olc<c<00ol0003o6ATIoaTI6@0MoaTI6B_o00001oooool1o`000000<ooo
ool00ol0003oooooooooo`04ooooogCo00003_o<c<`3o`0001Wo/k>c0_l0000DoiVIV@03o`000?mo
OgooOgmo01;oOgmo00?o0000ofIVI_mVIVH04_mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?lc
<c?o<c<c01Wo<c<c00?o0000oaTI6OlI6AT07OlI6AT[o`0000Oooooo0Ol0000003?ooooo00?o0000
ooooooooool01?oooomeo`00013oc<c<0ol0000Hok>c/`03o`000?nIVIWoVIVI01;oVIVI00?o0000
ogmoOomoOgl04OmoOgl00ol0003oIVIVofIVIP0CofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000
oc<c<olc<c<06?lc<c<00ol0003o6ATIoaTI6@0MoaTI6B_o00001oooool1o`000000<oooool00ol0
003oooooooooo`04ooooogKo00004_o<c<`2o`0001Oo/k>c00?o0000oiVIVOnIVIT04_nIVIT00ol0
003oOgmoogmoO`0AogmoO`03o`000?mVIVKoIVIV01?oIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0
003o<c<coc<c<`0Ioc<c<`03o`000?lI6AWo6ATI01go6ATI:_l00007ooooo`7o0000000cooooo`03
o`000?oooooooooo00CoooooMol0000Colc<c0;o00005_nc/k<2o`0001?oVIVI00?o0000ogmoOomo
Ogl04OmoOgl00ol0003oIVIVofIVIP0CofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000oc<c<olc
<c<06?lc<c<00ol0003o6ATIoaTI6@0NoaTI6BWo00001oooool1o`000000<oooool00ol0003ooooo
ooooo`04ooooogSo00005?o<c<`2o`0001Ko/k>c0_l0000BoiVIV@03o`000?moOgooOgmo017oOgmo
00?o0000ofIVI_mVIVH04_mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?lc<c?o<c<c01So<c<c
00?o0000oaTI6OlI6AT07_lI6ATYo`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oo
oomio`0001Goc<c<0ol0000Eok>c/`;o00004OnIVIT00ol0003oOgmoogmoO`0AogmoO`03o`000?mV
IVKoIVIV01;oIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003o<c<coc<c<`0Hoc<c<`03o`000?lI
6AWo6ATI01ko6ATI:?l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooN_l0000G
olc<c0?o00005?nc/k<00ol0003oVIVIoiVIV@0?oiVIV@03o`000?moOgooOgmo017oOgmo00?o0000
ofIVI_mVIVH04OmVIVH00ol0003oC4a<oda<C00Doda<C003o`000?lc<c?o<c<c01So<c<c00?o0000
oaTI6OlI6AT07_lI6ATXo`0000Oooooo0Ol0000003?ooooo0ol00004ooooog_o00006Oo<c<`2o`00
01?o/k>c00?o0000oiVIVOnIVIT03onIVIT00ol0003oOgmoogmoO`0AogmoO`03o`000?mVIVKoIVIV
017oIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003o<c<coc<c<`0Hoc<c<`03o`000?lI6AWo6ATI
01go6ATI:?l00005ooooo`?o0000000cooooo`03o`000?oooooooooo00CoooooO?l0000Jolc<c003
o`000?nc/k?o/k>c017o/k>c00?o0000oiVIVOnIVIT03onIVIT00ol0003oOgmoogmoO`0@ogmoO`03
o`000?mVIVKoIVIV017oIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003o<c<coc<c<`0Hoc<c<`03
o`000?lI6AWo6ATI01ko6ATI9ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Cooooo
OOl00005olc<c0;o00004oo<c<`2o`0001;o/k>c0_l0000@oiVIV@03o`000?moOgooOgmo013oOgmo
00?o0000ofIVI_mVIVH04OmVIVH00ol0003oC4a<oda<C00Doda<C003o`000?lc<c?o<c<c01So<c<c
00?o0000oaTI6OlI6AT07OlI6ATWo`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oo
oommo`0000Goc<c<00Co0000onKVi_l0003o00004oo<c<`00ol0003o/k>cok>c/`0Aok>c/`03o`00
0?nIVIWoVIVI00koVIVI00?o0000ogmoOomoOgl03omoOgl00ol0003oIVIVofIVIP0AofIVIP03o`00
0?m<C4coC4a<01CoC4a<00?o0000oc<c<olc<c<06?lc<c<00ol0003o6ATIoaTI6@0MoaTI6BOo0000
1oooool1o`000000<oooool00ol0003oooooooooo`04ooooogko00001?o<c<`01?l0003oi^KVonKV
i_oVi^H2o`0001;oc<c<0_l0000Bok>c/`03o`000?nIVIWoVIVI00koVIVI00?o0000ogmoOomoOgl0
3omoOgl00ol0003oIVIVofIVIP0AofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000oc<c<olc<c<0
6?lc<c<00ol0003o6ATIoaTI6@0LoaTI6BOo00001oooool1o`000000<oooool00ol0003ooooooooo
o`04ooooogoo00000oo<c<`00ol0003oi^KVonKViP03onKViP;o00004_o<c<`2o`00017o/k>c00?o
0000oiVIVOnIVIT03_nIVIT00ol0003oOgmoogmoO`0?ogmoO`03o`000?mVIVKoIVIV017oIVIV00?o
0000oda<C?m<C4`04om<C4`00ol0003o<c<coc<c<`0Hoc<c<`03o`000?lI6AWo6ATI01co6ATI9ol0
0007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooP?l00002olc<c003o`000?oVi^Ko
i^KV00Goi^KV0_l0000Bolc<c0;o00004?nc/k<00ol0003oVIVIoiVIV@0>oiVIV@03o`000?moOgoo
Ogmo00koOgmo00?o0000ofIVI_mVIVH04_mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?lc<c?o
<c<c01Oo<c<c00?o0000oaTI6OlI6AT07OlI6ATVo`0000Oooooo0Ol0000003?ooooo00?o0000oooo
ooooool01?oooon1o`000003olc<c?l0003oi^KV00Soi^KV00?o0000olc<c?o<c<`04Oo<c<`00ol0
003o/k>cok>c/`0>ok>c/`03o`000?nIVIWoVIVI00koVIVI00?o0000ogmoOomoOgl03_moOgl00ol0
003oIVIVofIVIP0AofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000oc<c<olc<c<06?lc<c<00ol0
003o6ATIoaTI6@0LoaTI6BKo00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooh?o
00002_oVi^H3o`00013oc<c<0_l0000@ok>c/`03o`000?nIVIWoVIVI00koVIVI00?o0000ogmoOomo
Ogl03_moOgl00ol0003oIVIVofIVIP0@ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000oc<c<olc
<c<05olc<c<00ol0003o6ATIoaTI6@0LoaTI6BKo00001oooool1o`000000<oooool00ol0003ooooo
ooooo`04ooooohCo00003?oVi^H2o`00013oc<c<00?o0000ok>c/onc/k<03_nc/k<00ol0003oVIVI
oiVIV@0=oiVIV@03o`000?moOgooOgmo00ooOgmo00?o0000ofIVI_mVIVH03omVIVH00ol0003oC4a<
oda<C00Doda<C003o`000?lc<c?o<c<c01Oo<c<c00?o0000oaTI6OlI6AT07?lI6ATVo`0000Oooooo
0Ol0000003?ooooo00?o0000ooooooooool01?oooon5o`0000goi^KV0_l0000?olc<c0;o00003onc
/k<00ol0003oVIVIoiVIV@0=oiVIV@03o`000?moOgooOgmo00koOgmo00?o0000ofIVI_mVIVH04?mV
IVH00ol0003oC4a<oda<C00Coda<C003o`000?lc<c?o<c<c01So<c<c00?o0000oaTI6OlI6AT07?lI
6ATUo`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooon6o`0000koi^KV00?o0000
olc<c?o<c<`03_o<c<`00ol0003o/k>cok>c/`0=ok>c/`03o`000?nIVIWoVIVI00goVIVI00?o0000
ogmoOomoOgl03_moOgl00ol0003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000
oc<c<olc<c<05olc<c<00ol0003o6ATIoaTI6@0LoaTI6BGo00001oooool1o`000000<oooool00ol0
003oooooooooo`04ooooohOo00003_oVi^H00ol0003oc<c<olc<c00>olc<c003o`000?nc/k?o/k>c
00go/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`0>ogmoO`03o`000?mVIVKoIVIV
013oIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003o<c<coc<c<`0Goc<c<`03o`000?lI6AWo6ATI
01co6ATI9Ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooR?l0000>onKViP03
o`000?o<c<coc<c<00koc<c<00?o0000ok>c/onc/k<03Onc/k<00ol0003oVIVIoiVIV@0<oiVIV@03
o`000?moOgooOgmo00goOgmo00?o0000ofIVI_mVIVH04?mVIVH00ol0003oC4a<oda<C00Coda<C003
o`000?lc<c?o<c<c01So<c<c00?o0000oaTI6OlI6AT07?lI6ATTo`0000Oooooo0Ol0000003?ooooo
00?o0000ooooooooool01?oooon9o`0000koi^KV0ol0000>olc<c0;o00003_nc/k<00ol0003oVIVI
oiVIV@0<oiVIV@03o`000?moOgooOgmo00goOgmo00?o0000ofIVI_mVIVH04?mVIVH00ol0003oC4a<
oda<C00Coda<C003o`000?lc<c?o<c<c01Oo<c<c00?o0000oaTI6OlI6AT07?lI6ATTo`0000Oooooo
0Ol0000003?ooooo00?o0000ooooooooool01?oooon:o`00013oi^KV0_l0000>olc<c003o`000?nc
/k?o/k>c00_o/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`0=ogmoO`03o`000?mV
IVKoIVIV013oIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003o<c<coc<c<`0Goc<c<`03o`000?lI
6AWo6ATI01co6ATI9?l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooRol0000A
onKViP03o`000?o<c<coc<c<00coc<c<00?o0000ok>c/onc/k<02onc/k<00ol0003oVIVIoiVIV@0<
oiVIV@03o`000?moOgooOgmo00goOgmo00?o0000ofIVI_mVIVH04?mVIVH00ol0003oC4a<oda<C00C
oda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT07?lI6ATTo`0000Oooooo0Ol00000
03?ooooo0ol00004ooooohco00004OoVi^H2o`0000goc<c<00?o0000ok>c/onc/k<02onc/k<00ol0
003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00goOgmo00?o0000ofIVI_mVIVH03omVIVH00ol0
003oC4a<oda<C00Coda<C003o`000?lc<c?o<c<c01Oo<c<c00?o0000oaTI6OlI6AT06olI6ATTo`00
00Gooooo0ol0000003?ooooo00?o0000ooooooooool01?oooon=o`0001;oi^KV00?o0000olc<c?o<
c<`02oo<c<`00ol0003o/k>cok>c/`0;ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomo
Ogl03OmoOgl00ol0003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000oc<c<olc
<c<05olc<c<00ol0003o6ATIoaTI6@0KoaTI6BCo00001oooool1o`000000<oooool00ol0003ooooo
ooooo`04ooooohko00004_oVi^H2o`0000coc<c<00?o0000ok>c/onc/k<02onc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00goOgmo00?o0000ofIVI_mVIVH03omVIVH00ol0003oC4a<
oda<C00Coda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT07?lI6ATSo`0000Oooooo
0Ol0000003?ooooo00?o0000ooooooooool01?oooon?o`0000Goi^KV0_l0000<onKViP03o`000?o<
c<coc<c<00Woc<c<00?o0000ok>c/onc/k<02onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00goOgmo00?o0000ofIVI_mVIVH04?mVIVH00ol0003oC4a<oda<C00Boda<C003o`000?lc
<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT07?lI6ATSo`0000Oooooo0Ol0000003?ooooo00?o0000
ooooooooool01?oooon@o`0000Coi^KV00?o0000ooooool000003?oVi^H00ol0003oc<c<olc<c009
olc<c003o`000?nc/k?o/k>c00_o/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`0=
ogmoO`03o`000?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003o<c<coc<c<`0G
oc<c<`03o`000?lI6AWo6ATI01_o6ATI8ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo
00CoooooTOl00003onKViP04o`000?ooooooooooo`0000coi^KV00?o0000olc<c?o<c<`02Oo<c<`0
0ol0003o/k>cok>c/`0:ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl03OmoOgl0
0ol0003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000oc<c<olc<c<05olc<c<0
0ol0003o6ATIoaTI6@0KoaTI6B?o00001oooool1o`000000<oooool00ol0003oooooooooo`04oooo
oi;o00000_oVi^H01Ol0003ooooooooooooooooo000000coi^KV00?o0000olc<c?o<c<`02Oo<c<`2
o`0000_o/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`0=ogmoO`03o`000?mVIVKo
IVIV00ooIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003o<c<coc<c<`0Foc<c<`03o`000?lI6AWo
6ATI01co6ATI8_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooTol000000ooV
i^Ko0000ooooo`03ooooo`03o`000?oVi^Koi^KV00[oi^KV00?o0000olc<c?o<c<`02_o<c<`00ol0
003o/k>cok>c/`09ok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl03OmoOgl00ol0
003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000oc<c<olc<c<05_lc<c<00ol0
003o6ATIoaTI6@0LoaTI6B;o00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooiGo
00001Oooool2o`0000_oi^KV00?o0000olc<c?o<c<`02_o<c<`00ol0003o/k>cok>c/`09ok>c/`03
o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl03OmoOgl00ol0003oIVIVofIVIP0>ofIVIP03
o`000?m<C4coC4a<01;oC4a<00?o0000oc<c<olc<c<05_lc<c<00ol0003o6ATIoaTI6@0LoaTI6B;o
00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooiKo00001_ooool00ol0003oi^KV
onKViP09onKViP03o`000?o<c<coc<c<00Woc<c<00?o0000ok>c/onc/k<02Onc/k<00ol0003oVIVI
oiVIV@0:oiVIV@03o`000?moOgooOgmo00goOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<
oda<C00Boda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT07?lI6ATRo`0000Oooooo
0Ol0000003?ooooo00?o0000ooooooooool01?oooonGo`0000Kooooo00?o0000onKVi_oVi^H02OoV
i^H00ol0003oc<c<olc<c009olc<c003o`000?nc/k?o/k>c00Wo/k>c00?o0000oiVIVOnIVIT02_nI
VIT00ol0003oOgmoogmoO`0<ogmoO`03o`000?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`04Om<
C4`00ol0003o<c<coc<c<`0Foc<c<`03o`000?lI6AWo6ATI01co6ATI8_l00007ooooo`7o0000000c
ooooo`03o`000?oooooooooo00CoooooV?l00006ooooo`03o`000?oVi^Koi^KV00Woi^KV00?o0000
olc<c?o<c<`02?o<c<`00ol0003o/k>cok>c/`09ok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000
ogmoOomoOgl03?moOgl00ol0003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000
oc<c<olc<c<05Olc<c<00ol0003o6ATIoaTI6@0LoaTI6B;o00001oooool1o`000000<oooool00ol0
003oooooooooo`04oooooiWo00001_ooool00ol0003oi^KVonKViP09onKViP03o`000?o<c<coc<c<
00Soc<c<00?o0000ok>c/onc/k<02Onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo
00coOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<oda<C00Boda<C003o`000?lc<c?o<c<c
01Ko<c<c00?o0000oaTI6OlI6AT06olI6ATRo`0000Oooooo0Ol0000003?ooooo00?o0000oooooooo
ool01?oooonJo`0000Kooooo00?o0000onKVi_oVi^H02OoVi^H00ol0003oc<c<olc<c007olc<c003
o`000?nc/k?o/k>c00Wo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`0<ogmoO`03
o`000?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`04Om<C4`00ol0003o<c<coc<c<`0Foc<c<`03
o`000?lI6AWo6ATI01_o6ATI8_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Cooooo
Vol00006ooooo`;o00002_oVi^H00ol0003oc<c<olc<c007olc<c0;o00002_nc/k<00ol0003oVIVI
oiVIV@0:oiVIV@03o`000?moOgooOgmo00_oOgmo00?o0000ofIVI_mVIVH03omVIVH00ol0003oC4a<
oda<C00Boda<C003o`000?lc<c?o<c<c01Go<c<c00?o0000oaTI6OlI6AT06olI6ATRo`0000Oooooo
0Ol0000003?ooooo00?o0000ooooooooool01?oooonKo`0000Sooooo00?o0000onKVi_oVi^H01ooV
i^H00ol0003oc<c<olc<c008olc<c003o`000?nc/k?o/k>c00So/k>c00?o0000oiVIVOnIVIT02_nI
VIT00ol0003oOgmoogmoO`0;ogmoO`03o`000?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`04_m<
C4`00ol0003o<c<coc<c<`0Eoc<c<`03o`000?lI6AWo6ATI01_o6ATI8_l00007ooooo`7o0000000c
ooooo`03o`000?oooooooooo00CoooooW?l00008ooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000
olc<c?o<c<`02?o<c<`00ol0003o/k>cok>c/`07ok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000
ogmoOomoOgl03?moOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000
oc<c<olc<c<05Olc<c<00ol0003o6ATIoaTI6@0KoaTI6B;o00001oooool1o`000000<oooool3o`00
00CoooooWOl00008ooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<c?o<c<`01oo<c<`00ol0
003o/k>cok>c/`08ok>c/`03o`000?nIVIWoVIVI00WoVIVI00?o0000ogmoOomoOgl03?moOgl00ol0
003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000oc<c<olc<c<05Olc<c<00ol0
003o6ATIoaTI6@0KoaTI6B;o00001Oooool3o`000000<oooool00ol0003oooooooooo`04oooooiko
00002?ooool2o`0000Ooi^KV00?o0000olc<c?o<c<`02?o<c<`00ol0003o/k>cok>c/`07ok>c/`03
o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02omoOgl00ol0003oIVIVofIVIP0?ofIVIP03
o`000?m<C4coC4a<017oC4a<00?o0000oc<c<olc<c<05_lc<c<00ol0003o6ATIoaTI6@0KoaTI6B7o
00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooioo00002Oooool00ol0003oi^KV
onKViP05onKViP03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVI
oiVIV@0:oiVIV@03o`000?moOgooOgmo00coOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<
oda<C00Aoda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT06olI6ATQo`0000Oooooo
0Ol0000003?ooooo00?o0000ooooooooool01?oooonQo`0000Sooooo00?o0000onKVi_oVi^H01OoV
i^H00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o/k>c00Oo/k>c00?o0000oiVIVOnIVIT02OnI
VIT00ol0003oOgmoogmoO`0<ogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`04Om<
C4`00ol0003o<c<coc<c<`0Foc<c<`03o`000?lI6AWo6ATI01_o6ATI8Ol00007ooooo`7o0000000c
ooooo`03o`000?oooooooooo00CoooooXOl00008ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000
olc<c?o<c<`01oo<c<`00ol0003o/k>cok>c/`07ok>c/`03o`000?nIVIWoVIVI00WoVIVI00?o0000
ogmoOomoOgl03?moOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000
oc<c<olc<c<05_lc<c<00ol0003o6ATIoaTI6@0KoaTI6B7o00001oooool1o`000000<oooool00ol0
003oooooooooo`04oooooj;o00002?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<
00Ooc<c<00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?moOgooOgmo
00_oOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?lc<c?o<c<c
01Ko<c<c00?o0000oaTI6OlI6AT06olI6ATQo`0000Oooooo0Ol0000003?ooooo00?o0000oooooooo
ool01?oooonSo`0000Sooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c006olc<c003
o`000?nc/k?o/k>c00Oo/k>c00?o0000oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmoO`0;ogmoO`03
o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`04Om<C4`00ol0003o<c<coc<c<`0Foc<c<`03
o`000?lI6AWo6ATI01_o6ATI8Ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Cooooo
Y?l00008ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>c
ok>c/`07ok>c/`03o`000?nIVIWoVIVI00WoVIVI00?o0000ogmoOomoOgl03?moOgl00ol0003oIVIV
ofIVIP0>ofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000oc<c<olc<c<05_lc<c<00ol0003o6ATI
oaTI6@0JoaTI6B7o00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooojGo00002?oo
ool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01onc
/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?moOgooOgmo00_oOgmo00?o0000ofIVI_mVIVH03_mV
IVH00ol0003oC4a<oda<C00Aoda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT06_lI
6ATQo`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooonWo`0000Oooooo00?o0000
onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Oo/k>c00?o0000
oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmoO`0;ogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000
oda<C?m<C4`04Om<C4`00ol0003o<c<coc<c<`0Foc<c<`03o`000?lI6AWo6ATI01[o6ATI8Ol00007
ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooYol00007ooooo`03o`000?oVi^Koi^KV
00Goi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`07ok>c/`03o`000?nIVIWoVIVI
00WoVIVI00?o0000ogmoOomoOgl02omoOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<
017oC4a<00?o0000oc<c<olc<c<05_lc<c<00ol0003o6ATIoaTI6@0JoaTI6B7o00001oooool1o`00
0000<oooool00ol0003oooooooooo`04ooooojSo00001oooool00ol0003oi^KVonKViP04onKViP03
o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVIoiVIV@09oiVIV@03
o`000?moOgooOgmo00_oOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<oda<C00Aoda<C003
o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT06_lI6ATQo`0000Oooooo0Ol0000000_ooooo
0ol000000ol@413oooooooooo`0Rooooo`03o`000?oooooooooo00CoooooZOl00007ooooo`03o`00
0?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`07ok>c/`03o`00
0?nIVIWoVIVI00WoVIVI00?o0000ogmoOomoOgl02omoOgl00ol0003oIVIVofIVIP0>ofIVIP03o`00
0?m<C4coC4a<017oC4a<00?o0000oc<c<olc<c<05_lc<c<00ol0003o6ATIoaTI6@0JoaTI6B7o0000
1oooool1o`0000003Oooool00ol@413o^[Zjooooo`0Sooooo`03o`000?oooooooooo00CoooooZ_l0
0007ooooo`03o`000?oVi^Koi^KV00?oi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c
/`07ok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl02omoOgl00ol0003oIVIVofIV
IP0>ofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000oc<c<olc<c<05_lc<c<00ol0003o6ATIoaTI
6@0JoaTI6B7o00001oooool1o`0000003Oooool00onHV9So<S8booooo`0Sooooo`03o`000?oooooo
oooo00CoooooZol00007ooooo`03o`000?oVi^Koi^KV00;oi^KV00?o0000olc<c?o<c<`01?o<c<`0
0ol0003o/k>cok>c/`07ok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl02omoOgl0
0ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000oc<c<olc<c<05_lc<c<0
0ol0003o6ATIoaTI6@0JoaTI6B7o00001oooool1o`0000003Oooool00ooMgMgo0000okZj^P0Hoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooojco00001oooool0
0ol0003oi^KVonKViP02onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01onc/k<0
0ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00_oOgmo00?o0000ofIVI_mVIVH03_mVIVH0
0ol0003oC4a<oda<C00Aoda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT06_lI6ATQ
o`0000Oooooo0Ol0000000gooooo00?oEEEEogMgMom4A4@06?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool01?oooon/o`0000Oooooo00?o0000onKVi_oVi^H00_oVi^H0
0ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00Oo/k>c00?o0000oiVIVOnIVIT02?nIVIT0
0ol0003oOgmoogmoO`0;ogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`04Om<C4`0
0ol0003o<c<coc<c<`0Foc<c<`03o`000?lI6AWo6ATI01[o6ATI8Ol00007ooooo`7o0000000<oooo
o`05omgMgOl@413oooooob4Q8OoMgMd05oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o
0000ooooooooool01?oooon/o`0000Oooooo00?o0000onKVi_oVi^H00_oVi^H00ol0003oc<c<olc<
c003olc<c003o`000?nc/k?o/k>c00Oo/k>c00?o0000oiVIVOnIVIT02?nIVIT00ol0003oOgmoogmo
O`0;ogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`04Om<C4`00ol0003o<c<coc<c
<`0Foc<c<`03o`000?lI6AWo6ATI01[o6ATI8Ol00007ooooo`7o0000000<ooooo`05ofIVI_n7QhOo
oooooiRHV?mEEED05oooool01Ol0003ooooooooooooooooo000000Kooooo1?l00003ooooojco0000
1oooool00ol0003oi^KVonKViP02onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<0
1onc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00_oOgmo00?o0000ofIVI_mVIVH0
3_mVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT0
6_lI6ATQo`0000Gooooo0ol0000000_ooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMoooo
o`0Eooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`04ooooojco0000
1oooool00ol0003oi^KVonKViP02onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<0
1onc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00_oOgmo00?o0000ofIVI_mVIVH0
3_mVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT0
6_lI6ATQo`0000Oooooo0Ol0000000_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooo
ooooo`0Dooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04ooooojco
00001oooool00ol0003oi^KVonKViP02onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc
/k<01onc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00_oOgmo00?o0000ofIVI_mV
IVH03_mVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI
6AT06_lI6ATQo`0000Oooooo0Ol0000002Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03
o`000?oooooooooo00Cooooo[?l00007ooooo`03o`000?oVi^Koi^KV00;oi^KV00?o0000olc<c?o<
c<`00oo<c<`00ol0003o/k>cok>c/`07ok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomo
Ogl02omoOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000oc<c<olc
<c<05_lc<c<00ol0003o6ATIoaTI6@0JoaTI6B7o00001oooool1o`000000:?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?oooon[o`0000Oooooo00?o0000onKVi_oV
i^H00_oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Oo/k>c00?o0000oiVIVOnI
VIT02?nIVIT00ol0003oOgmoogmoO`0;ogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<
C4`04Om<C4`00ol0003o<c<coc<c<`0Foc<c<`03o`000?lI6AWo6ATI01[o6ATI8Ol00007ooooo`7o
0000000cooooo`03o`000?oooooooooo00CoooooZ_l00007ooooo`03o`000?oVi^Koi^KV00?oi^KV
00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`07ok>c/`03o`000?nIVIWoVIVI00SoVIVI
00?o0000ogmoOomoOgl02omoOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<017oC4a<
00?o0000oc<c<olc<c<05_lc<c<00ol0003o6ATIoaTI6@0JoaTI6B7o00001oooool1o`000000<ooo
ool00ol0003oooooooooo`04ooooojWo00002?ooool00ol0003oi^KVonKViP03onKViP03o`000?o<
c<coc<c<00?oc<c<00?o0000ok>c/onc/k<02?nc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?mo
OgooOgmo00_oOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?lc
<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT06_lI6ATQo`0000Oooooo0Ol0000003?ooooo00?o0000
ooooooooool01?oooonXo`0000Sooooo00?o0000onKVi_oVi^H00ooVi^H00ol0003oc<c<olc<c004
olc<c003o`000?nc/k?o/k>c00Oo/k>c00?o0000oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmoO`0;
ogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`04Om<C4`00ol0003o<c<coc<c<`0F
oc<c<`03o`000?lI6AWo6ATI01[o6ATI8Ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo
00CoooooYol00008ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0
003o/k>cok>c/`07ok>c/`03o`000?nIVIWoVIVI00WoVIVI00?o0000ogmoOomoOgl02omoOgl00ol0
003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000oc<c<olc<c<05_lc<c<00ol0
003o6ATIoaTI6@0JoaTI6B7o00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooojKo
00002?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc
/k<01onc/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?moOgooOgmo00_oOgmo00?o0000ofIVI_mV
IVH03_mVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI
6AT06_lI6ATQo`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooonUo`0000Sooooo
00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Oo/k>c
00?o0000oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmoO`0;ogmoO`03o`000?mVIVKoIVIV00koIVIV
00?o0000oda<C?m<C4`04Om<C4`00ol0003o<c<coc<c<`0Foc<c<`03o`000?lI6AWo6ATI01[o6ATI
8Ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooY?l00008ooooo`03o`000?oV
i^Koi^KV00Koi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`07ok>c/`03o`000?nI
VIWoVIVI00WoVIVI00?o0000ogmoOomoOgl03?moOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<
C4coC4a<017oC4a<00?o0000oc<c<olc<c<05_lc<c<00ol0003o6ATIoaTI6@0JoaTI6B7o00001ooo
ool1o`000000<oooool00ol0003oooooooooo`04oooooj?o00002Oooool00ol0003oi^KVonKViP05
onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVIoiVIV@09
oiVIV@03o`000?moOgooOgmo00coOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<oda<C00A
oda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT06_lI6ATQo`0000Oooooo0Ol00000
03?ooooo00?o0000ooooooooool01?oooonRo`0000Wooooo00?o0000onKVi_oVi^H01OoVi^H00ol0
003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00Oo/k>c00?o0000oiVIVOnIVIT02OnIVIT00ol0
003oOgmoogmoO`0;ogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`04Om<C4`00ol0
003o<c<coc<c<`0Foc<c<`03o`000?lI6AWo6ATI01_o6ATI8Ol00007ooooo`7o0000000cooooo`03
o`000?oooooooooo00CoooooXOl00009ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<
c<`01_o<c<`00ol0003o/k>cok>c/`07ok>c/`03o`000?nIVIWoVIVI00WoVIVI00?o0000ogmoOomo
Ogl03?moOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000oc<c<olc
<c<05_lc<c<00ol0003o6ATIoaTI6@0KoaTI6B7o00001oooool1o`000000<oooool00ol0003ooooo
ooooo`04oooooj3o00002?ooool2o`0000Ooi^KV00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>c
ok>c/`07ok>c/`03o`000?nIVIWoVIVI00WoVIVI00?o0000ogmoOomoOgl03?moOgl00ol0003oIVIV
ofIVIP0>ofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000oc<c<olc<c<05_lc<c<00ol0003o6ATI
oaTI6@0KoaTI6B7o00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooioo00002?oo
ool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/onc/k<01onc
/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?moOgooOgmo00coOgmo00?o0000ofIVI_mVIVH03_mV
IVH00ol0003oC4a<oda<C00Aoda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT06olI
6ATQo`0000Oooooo0Ol0000003?ooooo0ol00004oooooiko00001oooool2o`0000Woi^KV00?o0000
olc<c?o<c<`01oo<c<`00ol0003o/k>cok>c/`07ok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000
ogmoOomoOgl02omoOgl00ol0003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000
oc<c<olc<c<05_lc<c<00ol0003o6ATIoaTI6@0KoaTI6B7o00001Oooool3o`000000<oooool00ol0
003oooooooooo`04oooooigo00001oooool00ol0003oi^KVonKViP08onKViP03o`000?o<c<coc<c<
00Soc<c<00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo
00_oOgmo00?o0000ofIVI_mVIVH03omVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?lc<c?o<c<c
01Ko<c<c00?o0000oaTI6OlI6AT06olI6ATQo`0000Oooooo0Ol0000003?ooooo00?o0000oooooooo
ool01?oooonLo`0000Oooooo00?o0000onKVi_oVi^H02OoVi^H00ol0003oc<c<olc<c007olc<c003
o`000?nc/k?o/k>c00So/k>c00?o0000oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmoO`0<ogmoO`03
o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003o<c<coc<c<`0Eoc<c<`03
o`000?lI6AWo6ATI01_o6ATI8_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Cooooo
Vol00007ooooo`03o`000?oVi^Koi^KV00Woi^KV00?o0000olc<c?o<c<`02?o<c<`00ol0003o/k>c
ok>c/`07ok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02omoOgl00ol0003oIVIV
ofIVIP0?ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000oc<c<olc<c<05Olc<c<00ol0003o6ATI
oaTI6@0KoaTI6B;o00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooi_o00001_oo
ool00ol0003oi^KVonKViP09onKViP03o`000?o<c<coc<c<00Ooc<c<0_l0000:ok>c/`03o`000?nI
VIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02omoOgl00ol0003oIVIVofIVIP0?ofIVIP03o`000?m<
C4coC4a<01;oC4a<00?o0000oc<c<olc<c<05Olc<c<00ol0003o6ATIoaTI6@0KoaTI6B;o00001ooo
ool1o`000000<oooool00ol0003oooooooooo`04oooooiWo00001_ooool2o`0000[oi^KV0_l0000:
olc<c003o`000?nc/k?o/k>c00Wo/k>c00?o0000oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmoO`0<
ogmoO`03o`000?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`04Om<C4`00ol0003o<c<coc<c<`0F
oc<c<`03o`000?lI6AWo6ATI01_o6ATI8_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo
00CoooooV?l00006ooooo`03o`000?oVi^Koi^KV00Woi^KV00?o0000olc<c?o<c<`02Oo<c<`00ol0
003o/k>cok>c/`09ok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl03?moOgl00ol0
003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000oc<c<olc<c<05_lc<c<00ol0
003o6ATIoaTI6@0KoaTI6B;o00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooiOo
00001Oooool2o`0000_oi^KV00?o0000olc<c?o<c<`02Oo<c<`00ol0003o/k>cok>c/`09ok>c/`03
o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl03?moOgl00ol0003oIVIVofIVIP0?ofIVIP03
o`000?m<C4coC4a<01;oC4a<00?o0000oc<c<olc<c<05Olc<c<00ol0003o6ATIoaTI6@0LoaTI6B;o
00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooiKo00001Oooool00ol0003oi^KV
onKViP0:onKViP03o`000?o<c<coc<c<00[oc<c<00?o0000ok>c/onc/k<02Onc/k<00ol0003oVIVI
oiVIV@0:oiVIV@03o`000?moOgooOgmo00coOgmo00?o0000ofIVI_mVIVH03omVIVH00ol0003oC4a<
oda<C00Aoda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT07?lI6ATRo`0000Oooooo
0Ol0000003?ooooo00?o0000ooooooooool01?oooonEo`0000Gooooo00?o0000onKVi_oVi^H02_oV
i^H00ol0003oc<c<olc<c00:olc<c003o`000?nc/k?o/k>c00Wo/k>c00?o0000oiVIVOnIVIT02_nI
VIT00ol0003oOgmoogmoO`0=ogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`04_m<
C4`00ol0003o<c<coc<c<`0Foc<c<`03o`000?lI6AWo6ATI01co6ATI8_l00007ooooo`7o0000000c
ooooo`03o`000?oooooooooo00CoooooUOl00004ooooo`;o00003?oVi^H00ol0003oc<c<olc<c009
olc<c003o`000?nc/k?o/k>c00[o/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`0=
ogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003o<c<coc<c<`0F
oc<c<`03o`000?lI6AWo6ATI01co6ATI8_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo
00CoooooTol000000ooVi^Ko0000ooooo`02ooooo`03o`000?oVi^Koi^KV00[oi^KV0_l0000;olc<
c003o`000?nc/k?o/k>c00[o/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`0=ogmo
O`03o`000?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003o<c<coc<c<`0Foc<c
<`03o`000?lI6AWo6ATI01co6ATI8_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Co
ooooT_l00002onKViP04o`000?ooooooooooo`0000coi^KV00?o0000olc<c?o<c<`02_o<c<`00ol0
003o/k>cok>c/`0:ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl03OmoOgl00ol0
003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000oc<c<olc<c<05_lc<c<00ol0
003o6ATIoaTI6@0LoaTI6B;o00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooi7o
00000ooVi^H00ol0003oooooo`00000;onKViP;o00003?o<c<`00ol0003o/k>cok>c/`0;ok>c/`03
o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl03_moOgl00ol0003oIVIVofIVIP0>ofIVIP03
o`000?m<C4coC4a<01;oC4a<00?o0000oc<c<olc<c<05olc<c<00ol0003o6ATIoaTI6@0KoaTI6B?o
00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooi3o00001?oVi^H2o`0000_oi^KV
00?o0000olc<c?o<c<`02oo<c<`00ol0003o/k>cok>c/`0;ok>c/`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ogmoOomoOgl03OmoOgl00ol0003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<01;oC4a<
00?o0000oc<c<olc<c<05olc<c<00ol0003o6ATIoaTI6@0KoaTI6B?o00001oooool1o`000000<ooo
ool00ol0003oooooooooo`04ooooohoo00001OoVi^H00ol0003oi^KVonKViP09onKViP03o`000?o<
c<coc<c<00_oc<c<00?o0000ok>c/onc/k<02onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00goOgmo00?o0000ofIVI_mVIVH03omVIVH2o`0001CoC4a<00?o0000oc<c<olc<c<05_lc
<c<00ol0003o6ATIoaTI6@0LoaTI6B?o00001oooool1o`000000<oooool00ol0003oooooooooo`04
ooooohko00004OoVi^H2o`0000goc<c<00?o0000ok>c/onc/k<02onc/k<00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?moOgooOgmo00goOgmo00?o0000ofIVI_mVIVH03omVIVH00ol0003oC4a<oda<C00C
oda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT07?lI6ATSo`0000Oooooo0Ol00000
03?ooooo00?o0000ooooooooool01?oooon=o`00017oi^KV00?o0000olc<c?o<c<`03?o<c<`00ol0
003o/k>cok>c/`0;ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl03OmoOgl00ol0
003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000oc<c<olc<c<05olc<c<00ol0
003o6ATIoaTI6@0KoaTI6BCo00001oooool1o`000000<oooool3o`0000CoooooS?l0000@onKViP;o
00003Oo<c<`2o`0000go/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`0=ogmoO`03
o`000?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003o<c<coc<c<`0Goc<c<`03
o`000?lI6AWo6ATI01_o6ATI9?l00005ooooo`?o0000000cooooo`03o`000?oooooooooo00Cooooo
Rol0000@onKViP03o`000?o<c<coc<c<00coc<c<00?o0000ok>c/onc/k<03Onc/k<00ol0003oVIVI
oiVIV@0<oiVIV@03o`000?moOgooOgmo00coOgmo00?o0000ofIVI_mVIVH04?mVIVH00ol0003oC4a<
oda<C00Coda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT07?lI6ATTo`0000Oooooo
0Ol0000003?ooooo00?o0000ooooooooool01?oooon:o`0000ooi^KV0_l0000>olc<c003o`000?nc
/k?o/k>c00go/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`0=ogmoO`03o`000?mV
IVKoIVIV00ooIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003o<c<coc<c<`0Goc<c<`03o`000?lI
6AWo6ATI01co6ATI9?l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooROl0000>
onKViP;o00003oo<c<`00ol0003o/k>cok>c/`0<ok>c/`;o00003_nIVIT00ol0003oOgmoogmoO`0=
ogmoO`03o`000?mVIVKoIVIV013oIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003o<c<coc<c<`0G
oc<c<`03o`000?lI6AWo6ATI01co6ATI9?l00007ooooo`7o0000000cooooo`03o`000?oooooooooo
00CoooooR?l0000>onKViP03o`000?o<c<coc<c<00koc<c<00?o0000ok>c/onc/k<03Onc/k<00ol0
003oVIVIoiVIV@0=oiVIV@03o`000?moOgooOgmo00goOgmo00?o0000ofIVI_mVIVH04?mVIVH00ol0
003oC4a<oda<C00Coda<C003o`000?lc<c?o<c<c01Oo<c<c00?o0000oaTI6OlI6AT07?lI6ATTo`00
00Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooon7o`0000koi^KV00?o0000olc<c?o<
c<`03Oo<c<`2o`0000oo/k>c00?o0000oiVIVOnIVIT03OnIVIT00ol0003oOgmoogmoO`0=ogmoO`03
o`000?mVIVKoIVIV013oIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003o<c<coc<c<`0Goc<c<`03
o`000?lI6AWo6ATI01co6ATI9Ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Cooooo
Q_l0000=onKViP;o00003oo<c<`00ol0003o/k>cok>c/`0>ok>c/`03o`000?nIVIWoVIVI00goVIVI
00?o0000ogmoOomoOgl03_moOgl00ol0003oIVIVofIVIP0@ofIVIP03o`000?m<C4coC4a<01?oC4a<
00?o0000oc<c<olc<c<05olc<c<00ol0003o6ATIoaTI6@0LoaTI6BGo00001oooool1o`000000<ooo
ool00ol0003oooooooooo`04ooooohGo00003?oVi^H2o`0000ooc<c<0_l0000@ok>c/`03o`000?nI
VIWoVIVI00goVIVI00?o0000ogmoOomoOgl03omoOgl00ol0003oIVIVofIVIP0?ofIVIP03o`000?m<
C4coC4a<01CoC4a<00?o0000oc<c<olc<c<05olc<c<00ol0003o6ATIoaTI6@0LoaTI6BGo00001ooo
ool1o`000000<oooool00ol0003oooooooooo`04ooooohCo00002ooVi^H2o`00013oc<c<00?o0000
ok>c/onc/k<03onc/k<00ol0003oVIVIoiVIV@0=oiVIV@03o`000?moOgooOgmo00ooOgmo00?o0000
ofIVI_mVIVH04?mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?lc<c?o<c<c01Oo<c<c00?o0000
oaTI6OlI6AT07?lI6ATVo`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooon3o`00
00Woi^KV0ol0000Aolc<c003o`000?nc/k?o/k>c00oo/k>c00?o0000oiVIVOnIVIT03_nIVIT00ol0
003oOgmoogmoO`0>ogmoO`03o`000?mVIVKoIVIV013oIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0
003o<c<coc<c<`0Goc<c<`03o`000?lI6AWo6ATI01co6ATI9_l00007ooooo`7o0000000cooooo`03
o`000?oooooooooo00CoooooPOl000000oo<c<co0000onKViP06onKViP;o00004oo<c<`2o`00013o
/k>c00?o0000oiVIVOnIVIT03_nIVIT00ol0003oOgmoogmoO`0?ogmoO`03o`000?mVIVKoIVIV013o
IVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003o<c<coc<c<`0Goc<c<`03o`000?lI6AWo6ATI01co
6ATI9_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooP?l00002olc<c003o`00
0?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`04Oo<c<`2o`00017o/k>c00?o0000oiVIVOnIVIT0
3_nIVIT00ol0003oOgmoogmoO`0?ogmoO`03o`000?mVIVKoIVIV017oIVIV00?o0000oda<C?m<C4`0
4om<C4`00ol0003o<c<coc<c<`0Goc<c<`03o`000?lI6AWo6ATI01go6ATI9_l00007ooooo`7o0000
000cooooo`03o`000?oooooooooo00CoooooOol00003olc<c003o`000?oVi^Koi^KV00;oi^KV0_l0
000Bolc<c0;o00004_nc/k<00ol0003oVIVIoiVIV@0>oiVIV@03o`000?moOgooOgmo00ooOgmo00?o
0000ofIVI_mVIVH04_mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?lc<c?o<c<c01Oo<c<c00?o
0000oaTI6OlI6AT07OlI6ATVo`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooomn
o`0000Coc<c<00?o0000onKVi_oVi^H00_l0000Bolc<c0;o00004onc/k<00ol0003oVIVIoiVIV@0>
oiVIV@03o`000?moOgooOgmo013oOgmo00?o0000ofIVI_mVIVH04OmVIVH00ol0003oC4a<oda<C00C
oda<C003o`000?lc<c?o<c<c01So<c<c00?o0000oaTI6OlI6AT07?lI6ATWo`0000Oooooo0Ol00000
03?ooooo00?o0000ooooooooool01?oooommo`0000Goc<c<0ol0000Colc<c003o`000?nc/k?o/k>c
01;o/k>c00?o0000oiVIVOnIVIT03_nIVIT00ol0003oOgmoogmoO`0@ogmoO`03o`000?mVIVKoIVIV
017oIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003o<c<coc<c<`0Goc<c<`03o`000?lI6AWo6ATI
01go6ATI9ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooOOl00005olc<c003
o`000?o<c<coc<c<017oc<c<0_l0000Bok>c/`?o00004?nIVIT00ol0003oOgmoogmoO`0@ogmoO`03
o`000?mVIVKoIVIV017oIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003o<c<coc<c<`0Hoc<c<`03
o`000?lI6AWo6ATI01go6ATI9ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Cooooo
O?l0000Golc<c0?o00004onc/k<00ol0003oVIVIoiVIV@0@oiVIV@03o`000?moOgooOgmo017oOgmo
00?o0000ofIVI_mVIVH04OmVIVH00ol0003oC4a<oda<C00Doda<C003o`000?lc<c?o<c<c01So<c<c
00?o0000oaTI6OlI6AT07OlI6ATWo`0000Oooooo0Ol0000003?ooooo0ol00004ooooog_o00005_o<
c<`2o`0001Go/k>c00?o0000oiVIVOnIVIT04?nIVIT00ol0003oOgmoogmoO`0AogmoO`03o`000?mV
IVKoIVIV017oIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003o<c<coc<c<`0Hoc<c<`03o`000?lI
6AWo6ATI01go6ATI:?l00005ooooo`?o0000000cooooo`03o`000?oooooooooo00CoooooN_l0000E
olc<c0;o00005_nc/k<00ol0003oVIVIoiVIV@0@oiVIV@03o`000?moOgooOgmo017oOgmo00?o0000
ofIVI_mVIVH04_mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?lc<c?o<c<c01So<c<c00?o0000
oaTI6OlI6AT07OlI6ATXo`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooomio`00
01Coc<c<0_l0000Fok>c/`;o00004_nIVIT00ol0003oOgmoogmoO`0AogmoO`03o`000?mVIVKoIVIV
01;oIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003o<c<coc<c<`0Hoc<c<`03o`000?lI6AWo6ATI
01ko6ATI:?l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooN?l0000Colc<c0;o
00005_nc/k<2o`0001?oVIVI00?o0000ogmoOomoOgl04OmoOgl00ol0003oIVIVofIVIP0CofIVIP03
o`000?m<C4coC4a<01CoC4a<00?o0000oc<c<olc<c<06?lc<c<00ol0003o6ATIoaTI6@0MoaTI6BWo
00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooogOo00004_o<c<`2o`0001Oo/k>c
00?o0000oiVIVOnIVIT04OnIVIT2o`0001?oOgmo00?o0000ofIVI_mVIVH04omVIVH00ol0003oC4a<
oda<C00Doda<C003o`000?lc<c?o<c<c01So<c<c00?o0000oaTI6OlI6AT07_lI6ATYo`0000Oooooo
0Ol0000003?ooooo00?o0000ooooooooool01?oooomgo`00013oc<c<0_l0000Hok>c/`03o`000?nI
VIWoVIVI017oVIVI00?o0000ogmoOomoOgl04omoOgl00ol0003oIVIVofIVIP0CofIVIP03o`000?m<
C4coC4a<01CoC4a<00?o0000oc<c<olc<c<06?lc<c<00ol0003o6ATIoaTI6@0MoaTI6B[o00001ooo
ool1o`000000<oooool00ol0003oooooooooo`04ooooogKo00003_o<c<`3o`0001So/k>c0_l0000C
oiVIV@03o`000?moOgooOgmo01?oOgmo00?o0000ofIVI_mVIVH04omVIVH00ol0003oC4a<oda<C00D
oda<C003o`000?lc<c?o<c<c01So<c<c00?o0000oaTI6OlI6AT07_lI6ATZo`0000Oooooo0Ol00000
03?ooooo00?o0000ooooooooool01?oooomeo`0000coc<c<0ol0000Iok>c/`;o00005?nIVIT00ol0
003oOgmoogmoO`0CogmoO`03o`000?mVIVKoIVIV01?oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0
003o<c<coc<c<`0Hoc<c<`03o`000?lI6AWo6ATI01go6ATI:ol00007ooooo`7o0000000cooooo`03
o`000?oooooooooo00CoooooM?l0000:olc<c0?o00006_nc/k<2o`0001GoVIVI00?o0000ogmoOomo
Ogl04omoOgl00ol0003oIVIVofIVIP0CofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000oc<c<olc
<c<06Olc<c<00ol0003o6ATIoaTI6@0MoaTI6B_o00001oooool1o`000000<oooool00ol0003ooooo
ooooo`04ooooog?o00002?o<c<`3o`0001_o/k>c0_l0000FoiVIV@03o`000?moOgooOgmo01?oOgmo
00?o0000ofIVI_mVIVH04omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?lc<c?o<c<c01So<c<c
00?o0000oaTI6OlI6AT07_lI6AT[o`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oo
oomeo`0000?oc<c<0ol0000Lok>c/`;o00005_nIVIT2o`0001CoOgmo0_l0000EofIVIP03o`000?m<
C4coC4a<01KoC4a<00?o0000oc<c<olc<c<06Olc<c<00ol0003o6ATIoaTI6@0MoaTI6Bco00001ooo
ool1o`000000<oooool00ol0003oooooooooo`04ooooog3o00001Onc/k<3o`0001go/k>c0_l0000G
oiVIV@03o`000?moOgooOgmo01?oOgmo00?o0000ofIVI_mVIVH05OmVIVH00ol0003oC4a<oda<C00F
oda<C003o`000?lc<c?o<c<c01So<c<c00?o0000oaTI6OlI6AT07_lI6AT/o`0000Oooooo0Ol00000
03?ooooo00?o0000ooooooooool01?oooom_o`0002Co/k>c0_l0000HoiVIV@03o`000?moOgooOgmo
01?oOgmo00?o0000ofIVI_mVIVH05OmVIVH00ol0003oC4a<oda<C00Foda<C003o`000?lc<c?o<c<c
01Wo<c<c00?o0000oaTI6OlI6AT07OlI6AT]o`0000Oooooo0Ol0000003?ooooo00?o0000oooooooo
ool01?oooom^o`0002;o/k>c0ol0000HoiVIV@;o00005OmoOgl00ol0003oIVIVofIVIP0EofIVIP03
o`000?m<C4coC4a<01KoC4a<00?o0000oc<c<olc<c<06Olc<c<00ol0003o6ATIoaTI6@0NoaTI6Bgo
00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooofgo00008?nc/k<3o`0001WoVIVI
0_l0000FogmoO`03o`000?mVIVKoIVIV01GoIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o<c<c
oc<c<`0Joc<c<`03o`000?lI6AWo6ATI01ko6ATI;Ol00007ooooo`7o0000000cooooo`03o`000?oo
oooooooo00CoooooK?l0000Nok>c/`?o00006onIVIT00ol0003oOgmoogmoO`0EogmoO`03o`000?mV
IVKoIVIV01GoIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003o<c<coc<c<`0Joc<c<`03o`000?lI
6AWo6ATI01go6ATI;_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooJol0000L
ok>c/`?o00006onIVIT3o`0001OoOgmo00?o0000ofIVI_mVIVH05OmVIVH00ol0003oC4a<oda<C00G
oda<C003o`000?lc<c?o<c<c01[o<c<c00?o0000oaTI6OlI6AT07_lI6AT^o`0000Oooooo0Ol00000
03?ooooo00?o0000ooooooooool01?oooom[o`0001Wo/k>c0ol0000LoiVIV@;o00006OmoOgl00ol0
003oIVIVofIVIP0EofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000oc<c<olc<c<06_lc<c<00ol0
003o6ATIoaTI6@0NoaTI6Bko00001oooool1o`000000<oooool3o`0000CoooooJ_l0000Eok>c/`Go
00007OnIVIT2o`0001WoOgmo0_l0000GofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000oc<c<olc
<c<06_lc<c<00ol0003o6ATIoaTI6@0NoaTI6Boo00001Oooool3o`000000<oooool00ol0003ooooo
ooooo`04ooooofWo00004?nc/k<6o`00023oVIVI0_l0000JogmoO`03o`000?mVIVKoIVIV01OoIVIV
00?o0000oda<C?m<C4`05om<C4`00ol0003o<c<coc<c<`0Joc<c<`03o`000?lI6AWo6ATI01oo6ATI
;ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooJ?l0000=ok>c/`Co00009?nI
VIT2o`0001_oOgmo00?o0000ofIVI_mVIVH05omVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?lc
<c?o<c<c01[o<c<c00?o0000oaTI6OlI6AT07_lI6AT`o`0000Oooooo0Ol0000003?ooooo00?o0000
ooooooooool01?oooomWo`0000_o/k>c0ol0000WoiVIV@03o`000?moOgooOgmo01[oOgmo00?o0000
ofIVI_mVIVH05omVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?lc<c?o<c<c01[o<c<c00?o0000
oaTI6OlI6AT07olI6AT`o`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooomYo`00
00Go/k>c1?l0000WoiVIV@?o00006_moOgl3o`0001SoIVIV0_l0000Ioda<C0;o00007?lc<c<00ol0
003o6ATIoaTI6@0OoaTI6C7o00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooofCo
00001OnIVIT5o`0002SoVIVI0ol0000LogmoO`03o`000?mVIVKoIVIV01SoIVIV00?o0000oda<C?m<
C4`06Om<C4`00ol0003o<c<coc<c<`0Koc<c<`03o`000?lI6AWo6ATI01oo6ATI<Ol00007ooooo`7o
0000000cooooo`03o`000?oooooooooo00CoooooHol0000`oiVIV@?o00007OmoOgl2o`0001[oIVIV
00?o0000oda<C?m<C4`06Om<C4`00ol0003o<c<coc<c<`0Koc<c<`03o`000?lI6AWo6ATI01oo6ATI
<_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooH_l0000^oiVIV@?o00007omo
Ogl00ol0003oIVIVofIVIP0IofIVIP03o`000?m<C4coC4a<01WoC4a<00?o0000oc<c<olc<c<06olc
<c<00ol0003o6ATIoaTI6@0PoaTI6C;o00001oooool1o`000000<oooool00ol0003oooooooooo`04
ooooof7o0000;?nIVIT3o`00023oOgmo0_l0000KofIVIP03o`000?m<C4coC4a<01WoC4a<00?o0000
oc<c<olc<c<07?lc<c<00ol0003o6ATIoaTI6@0OoaTI6C?o00001oooool1o`000000<oooool00ol0
003oooooooooo`04ooooof3o0000:_nIVIT3o`0002;oOgmo00?o0000ofIVI_mVIVH06_mVIVH00ol0
003oC4a<oda<C00Ioda<C003o`000?lc<c?o<c<c01co<c<c00?o0000oaTI6OlI6AT08?lI6ATco`00
00Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooomOo`0002KoVIVI1Ol0000SogmoO`;o
00006omVIVH2o`0001_oC4a<00?o0000oc<c<olc<c<07?lc<c<00ol0003o6ATIoaTI6@0PoaTI6CCo
00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooeoo00008?nIVIT6o`0002KoOgmo
0_l0000KofIVIP;o00007Om<C4`00ol0003o<c<coc<c<`0Loc<c<`03o`000?lI6AWo6ATI023o6ATI
=?l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooGOl000000omoOgoo0000oiVI
V@0IoiVIV@Ko0000:_moOgl2o`0001coIVIV00?o0000oda<C?m<C4`07?m<C4`00ol0003o<c<coc<c
<`0Loc<c<`03o`000?lI6AWo6ATI023o6ATI=Ol00007ooooo`7o0000000cooooo`03o`000?oooooo
oooo00CoooooG?l00003ogmoO`03o`000?nIVIWoVIVI00coVIVI2ol0000^ogmoO`;o00007?mVIVH2
o`0001koC4a<00?o0000oc<c<olc<c<07?lc<c<00ol0003o6ATIoaTI6@0QoaTI6CGo00001oooool1
o`000000<oooool00ol0003oooooooooo`04oooooe_o00001?moOgl00ol0003oVIVIoiVIV@0<o`00
03OoOgmo0_l0000MofIVIP03o`000?m<C4coC4a<01goC4a<00?o0000oc<c<olc<c<07Olc<c<00ol0
003o6ATIoaTI6@0PoaTI6CKo00001oooool1o`0000006?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`04
oooooe[o00001OmoOgl3o`00043oOgmo0ol0000NofIVIP03o`000?m<C4coC4a<01goC4a<00?o0000
oc<c<olc<c<07Olc<c<00ol0003o6ATIoaTI6@0QoaTI6CKo00001oooool1o`0000006?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool01?oooomIo`0004KoOgmo0ol0000PofIVIP;o00007_m<C4`00ol0003o<c<coc<c<`0M
oc<c<`03o`000?lI6AWo6ATI027o6ATI=ol00007ooooo`7o0000000Hooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`03ooooo`Co00000ooooomCo`000003oaTI6Ol0003o
000000;o0000A?moOgl3o`00027oIVIV0_l0000Noda<C0;o00007olc<c<00ol0003o6ATIoaTI6@0R
oaTI6COo00001Oooool3o`0000006?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`04oooooeOo0000@_moOgl3o`0002;oIVIV0_l0000O
oda<C003o`000?lc<c?o<c<c01ko<c<c00?o0000oaTI6OlI6AT08_lI6ATho`0000Oooooo0Ol00000
01Sooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`04oooooeKo0000@?moOgl3o`0002?oIVIV0_l0000Ooda<C0;o00008?lc
<c<00ol0003o6ATIoaTI6@0RoaTI6CWo00001oooool1o`0000006?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04oooooe;o000000?o
C4a<o`000?l00000??moOgl5o`0002GoIVIV00?o0000oda<C?m<C4`07_m<C4`00ol0003o<c<coc<c
<`0Ooc<c<`03o`000?lI6AWo6ATI02;o6ATI>_l00007ooooo`7o0000000Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00CoooooDOl0
00000om<C4co0000o`000002o`0003SoOgmo0ol0000XofIVIP;o00008?m<C4`00ol0003o<c<coc<c
<`0Ooc<c<`03o`000?lI6AWo6ATI02;o6ATI>ol00007ooooo`7o0000000Hooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool01?oooomAo`000003oda<C?l0
003oIVIV00;oIVIV0ol0000bogmoO`Co0000:OmVIVH00ol0003oC4a<oda<C00Ooda<C0;o00008?lc
<c<00ol0003o6ATIoaTI6@0SoaTI6C_o00001oooool1o`000000<oooool00ol0003oooooooooo`04
oooooe3o000000?oC4a<o`000?mVIVH01_mVIVH4o`0002SoOgmo1_l0000[ofIVIP;o00008Om<C4`0
0ol0003o<c<coc<c<`0Ooc<c<`03o`000?lI6AWo6ATI02Co6ATI>ol00007ooooo`7o0000000coooo
o`03o`000?oooooooooo00CoooooC?l000001OlI6AWo0000o`000?m<C4co000000coIVIV4_l00005
ogmoOa7o0000;omVIVH2o`00027oC4a<0_l0000Qoc<c<`03o`000?lI6AWo6ATI02Co6ATI??l00007
ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooBol000000olI6AWo0000oc<c<`02o`00
01ooIVIV1Ol0000nofIVIP;o00008_m<C4`00ol0003o<c<coc<c<`0Poc<c<`03o`000?lI6AWo6ATI
02Co6ATI?Ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooB_l000000olI6AWo
0000o`000002o`00063oIVIV0ol0000Soda<C003o`000?lc<c?o<c<c023o<c<c00?o0000oaTI6OlI
6AT09?lI6ATno`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooom9o`000005oaTI
6Ol0003o0000oda<C?l00000GomVIVH2o`0002CoC4a<0_l0000Roc<c<`03o`000?lI6AWo6ATI02Co
6ATI?ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooBOl000001OlI6AWo0000
o`000?m<C4co000005goIVIV0_l0000Toda<C0;o00008olc<c<00ol0003o6ATIoaTI6@0UoaTI6Coo
00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooodSo000000?o6ATIo`000?l00000
0_m<C4`00ol0003oIVIVofIVIP1HofIVIP?o00009Om<C4`00ol0003o<c<coc<c<`0Roc<c<`03o`00
0?lI6AWo6ATI02Go6ATI@?l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooAol0
00000olI6AWo0000o`000003oda<C003o`000?mVIVKoIVIV05GoIVIV0ol0000Voda<C0;o00009?lc
<c<00ol0003o6ATIoaTI6@0UoaTI6D7o00001oooool1o`000000<oooool00ol0003oooooooooo`04
ooooodWo00001?m<C4`00ol0003oIVIVofIVIP1BofIVIP?o00009om<C4`2o`0002Go<c<c00?o0000
oaTI6OlI6AT09_lI6AU1o`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooom6o`00
0003oc<c<ol0003oC4a<00CoC4a<2_l00017ofIVIPCo0000:Om<C4`00ol0003o<c<coc<c<`0Toc<c
<`03o`000?lI6AWo6ATI02Ko6ATI@_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Co
ooooAOl000000olc<c?o0000oda<C00?oda<C0Oo0000?OmVIVH3o`0002coC4a<00?o0000oc<c<olc
<c<09?lc<c<00ol0003o6ATIoaTI6@0VoaTI6D?o00001oooool1o`000000<oooool3o`0000Cooooo
@ol000001?lI6AWo0000oc<c<ol0000Goda<C0Go0000=?mVIVH4o`0002goC4a<0_l0000Voc<c<`03
o`000?lI6AWo6ATI02Oo6ATI@ol00005ooooo`?o0000000cooooo`03o`000?oooooooooo00Cooooo
@_l000001OlI6AWo0000oc<c<olc<c?o000001coC4a<1_l0000XofIVIPKo0000;om<C4`2o`0002Oo
<c<c00?o0000oaTI6OlI6AT09olI6AU4o`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool0
1?oooom1o`000003oaTI6Ol0003o<c<c00;o<c<c00?o0000oda<C?m<C4`08?m<C4`6o`0001coIVIV
1_l0000coda<C0;o0000:?lc<c<00ol0003o6ATIoaTI6@0WoaTI6DGo00001oooool1o`000000<ooo
ool00ol0003oooooooooo`04oooood3o00000_lI6AT00ol0003o<c<coc<c<`02oc<c<`03o`000?m<
C4coC4a<02GoC4a<7?l0000goda<C0;o0000:?lc<c<2o`0002Wo6ATIA_l00007ooooo`7o0000000c
ooooo`03o`000?oooooooooo00Cooooo?ol00002oaTI6@03o`000?lc<c?o<c<c00?o<c<c00?o0000
oda<C?m<C4`0M_m<C4`2o`0002Wo<c<c00?o0000oaTI6OlI6AT0:?lI6AU7o`0000Oooooo0Ol00000
03?ooooo00?o0000ooooooooool01?oooolno`0000;o6ATI00?o0000oc<c<olc<c<01?lc<c<3o`00
07CoC4a<0_l0000Zoc<c<`03o`000?lI6AWo6ATI02So6ATIB?l00007ooooo`7o0000000cooooo`03
o`000?oooooooooo00Cooooo?_l00002oaTI6@03o`000?lc<c?o<c<c00Oo<c<c0ol0001_oda<C0;o
0000:olc<c<00ol0003o6ATIoaTI6@0XoaTI6DWo00001oooool1o`000000<oooool00ol0003ooooo
ooooo`04ooooocgo00000olI6AT00ol0003o<c<coc<c<`0:oc<c<`Co0000JOm<C4`2o`0002co<c<c
00?o0000oaTI6OlI6AT0:?lI6AU:o`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oo
oollo`0000Co6ATI00?o0000oc<c<olc<c<03_lc<c<5o`0006;oC4a<0_l0000/oc<c<`;o0000:_lI
6AU;o`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooollo`0000Co6ATI00?o0000
oc<c<olc<c<04olc<c<3o`0005goC4a<0_l0000/oc<c<`;o0000:olI6AU<o`0000Oooooo0Ol00000
03?ooooo00?o0000ooooooooool01?oooolko`0000Go6ATI00?o0000oc<c<olc<c<05_lc<c<2o`00
05SoC4a<0ol0000]oc<c<`03o`000?lI6AWo6ATI02[o6ATICOl00007ooooo`7o0000000cooooo`03
o`000?oooooooooo00Cooooo>_l00006oaTI6@03o`000?lc<c?o<c<c01So<c<c0ol0001@oda<C0Go
0000;olc<c<00ol0003o6ATIoaTI6@0ZoaTI6Dko00001oooool1o`000000<oooool00ol0003ooooo
ooooo`04oooooc[o00001olI6AT2o`0001_o<c<c1?l00019oda<C0?o0000<_lc<c<2o`0002co6ATI
Col00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Cooooo>_l00009oaTI6@;o00007Olc
<c<3o`0004?oC4a<0ol0000coc<c<`;o0000;OlI6AU@o`0000Oooooo0Ol0000003?ooooo00?o0000
ooooooooool01?ooooljo`0000_o6ATI0_l0000Noc<c<`Co0000>_m<C4`5o`0003Co<c<c0_l0000^
oaTI6E7o00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooocWo00003_lI6AT2o`00
023o<c<c1_l0000^oda<C0Ko0000=olc<c<2o`0002oo6ATID_l00007ooooo`7o0000000cooooo`03
o`000?oooooooooo00Cooooo>Ol0000@oaTI6@;o00009?lc<c<6o`0002?oC4a<1Ol0000loc<c<`03
o`000?lI6AWo6ATI02ko6ATIDol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Cooooo
>Ol0000BoaTI6@;o0000:?lc<c<6o`0001KoC4a<1ol0000ooc<c<`;o0000;olI6AUEo`0000Oooooo
0Ol0000003?ooooo0ol00004ooooocWo00005?lI6AT2o`0002co<c<c5_l00015oc<c<`03o`000?lI
6AWo6ATI02ko6ATIE_l00005ooooo`?o0000000cooooo`03o`000?oooooooooo00Cooooo>_l0000E
oaTI6@;o0000Polc<c<2o`00033o6ATIEol00007ooooo`7o0000000cooooo`03o`000?oooooooooo
00Cooooo>ol0000FoaTI6@;o0000Oolc<c<2o`00037o6ATIF?l00007ooooo`7o0000000cooooo`03
o`000?oooooooooo00Cooooo>ol0000HoaTI6@;o0000Nolc<c<2o`00037o6ATIF_l00007ooooo`7o
0000000cooooo`03o`000?oooooooooo00Cooooo??l0000IoaTI6@?o0000M_lc<c<2o`0003;o6ATI
Fol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Cooooo?_l0000JoaTI6@?o0000L?lc
<c<3o`0003;o6ATIGOl00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Cooooo@Ol0000J
oaTI6@;o0000Jolc<c<3o`0003Co6ATIG_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo
00CoooooA?l0000IoaTI6@;o0000I_lc<c<3o`0003Go6ATIH?l00007ooooo`7o0000000cooooo`03
o`000?oooooooooo00CoooooAol0000HoaTI6@?o0000H?lc<c<3o`0003Oo6ATIHOl00007ooooo`7o
0000000cooooo`03o`000?oooooooooo00CoooooBOl0000IoaTI6@?o0000F_lc<c<3o`0003Wo6ATI
H_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooBol0000JoaTI6@;o0000E_lc
<c<2o`0003_o6ATIHol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooC?l0000K
oaTI6@?o0000D?lc<c<3o`0003[o6ATII_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo
00CoooooCOl0000MoaTI6@Go0000AOlc<c<6o`0003co6ATIIol00007ooooo`7o0000000cooooo`03
o`000?oooooooooo00CoooooCol0000PoaTI6@Co0000?Olc<c<4o`00043o6ATIJOl00007ooooo`7o
0000000cooooo`03o`000?oooooooooo00CoooooD?l0000SoaTI6@?o0000=olc<c<3o`0004?o6ATI
J_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooDOl0000UoaTI6@Co0000;olc
<c<4o`0004Co6ATIK?l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooD_l0000X
oaTI6@Ko00007_lc<c<;o`0004Oo6ATIKOl00007ooooo`7o0000000cooooo`?o00001?oooomEo`00
02_o6ATI7_l0001@oaTI6Foo00001Oooool3o`000000<oooool00ol0003oooooooooo`04oooooeKo
0000U_lI6AUao`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooomHo`0009;o6ATI
Lol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooFOl0002?oaTI6GGo00001ooo
ool1o`000000<oooool00ol0003oooooooooo`04oooooe[o0000S?lI6AUgo`0000Oooooo0Ol00000
03?ooooo00?o0000ooooooooool01?oooomKo`0008[o6ATIN?l00007ooooo`7o0000000cooooo`03
o`000?oooooooooo00CoooooGOl00026oaTI6G[o00001oooool1o`000000<oooool00ol0003ooooo
ooooo`04oooooeoo0000POlI6AUmo`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oo
oomRo`0007co6ATIOol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooIOl0001g
oaTI6H7o00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooofOo0000LolI6AV3o`00
00Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooomXo`0006oo6ATIQ_l00007ooooo`7o
0000000cooooo`03o`000?oooooooooo00CoooooK_l0001VoaTI6HWo00001oooool1o`000000<ooo
ool00ol0003oooooooooo`04ooooog7o0000H?lI6AV<o`0000Oooooo0Ol0000003?ooooo00?o0000
ooooooooool01?oooomco`0005_o6ATISol00007ooooo`7o0000000cooooo`03o`000?oooooooooo
00CoooooMOl0001FoaTI6I;o00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooogKo
0000D?lI6AVGo`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooomlo`0004;o6ATI
Wol00007ooooo`7o0000000cooooo`?o00001?oooon0o`0003[o6ATIXol00005ooooo`?o0000000c
ooooo`03o`000?oooooooooo00CoooooQ_l0000YoaTI6Jko00001oooool1o`000000<oooool00ol0
003oooooooooo`04oooooooo0000G_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Co
ooooool0001No`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?ooooooo`0005ko0000
1oooool1o`000000<oooool00ol0003oooooooooo`04oooooooo0000G_l00007ooooo`7o0000000c
ooooo`03o`000?oooooooooo00Coooooool0001No`0000Oooooo0Ol0000003?ooooo00?o0000oooo
ooooool01?ooooooo`0005ko00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooooo
0000G_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Coooooool0001No`0000Oooooo
0Ol0000003?ooooo00?o0000ooooooooool01?ooooooo`0005ko00001oooool1o`000000<oooool0
0ol0003oooooooooo`04oooooooo0000G_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo
00Coooooool0001No`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?ooooooo`0005ko
00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooooo0000G_l00007ooooo`7o0000
000Yooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`04oooooooo0000G_l0
0007ooooo`7o0000000[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oooooo
o`0005ko00001oooool1o`000000:oooool00ol0003oooooooooo`05ooooo`Co00000oooooooo`00
05ko00001Oooool3o`000000:oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
ooooJOooool1o`000000:oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
JOooool1o`000000:oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooJOoo
ool1o`000000:oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooJOooool1
o`000000:Oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo05Cooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`04ooooo`7o0000000cooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Co
oooo0Ol0000003?oooooool0001]o`000000oooooonPooooo`00oooooonPooooo`00oooooonPoooo
o`00oooooonPooooo`00oooooonPooooo`00l?ooool3o`000003oa0@4?oooooooooo0:Wooooo003E
ooooo`03o`000?oooooooooo00Oooooo00?oMgMgofIVI_ooool02Oooool00ol0003o^[Zjooooo`04
ooooo`03oa0@4?nj^[[ooooo00Cooooo00?oIVIVogMgMoooool0Xoooool00=Gooooo00?o410@omgM
gOooool01_ooool00ooMgMgo410@onk^kP0:ooooo`;o<S8b1Oooool00onHV9So<S8booooo`04oooo
o`03onk^k_l@413ogMgM0:?ooooo003Cooooo`05olc<c?l@413o0000o`000?n7QhL01_ooool01?mE
EEGoV9RHooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00?ogMgM
o`000?nj^[X01Oooool00on7QhOoIVIVooooo`2Rooooo`00doooool01_lQ8B7oQhN7oc8b<_nYZJWo
A4A4ohN7Q`Gooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool0
0oo<c<co0000oa0@4004ooooo`03oeEEEOmgMgOoA4A400Gooooo00?ok^k^o`000?ooool0X_ooool0
0=?ooooo00Ko0000oooooomVIVKoQhN7omgMgOl@4105ooooo`03oc8b<_oooooooooo00;ooooo00Co
gMgMo`000?l@413oc<c<2_ooool01OoMgMgo410@oooooolQ8B7ogMgM00Gooooo00?o0000oooooooo
ool0XOooool00=?ooooo00Ko410@omgMgOmgMgOoMgMgooooool00005ooooo`03oc8b<_oooooooooo
00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2_ooool01OmVIVKoQhN7oooooonHV9SoEEEE00Gooooo00?o
0000ooooooooool0XOooool00=?ooooo00KoZJVYodA4A?nHV9SoA4A4oiRHV?l@4105ooooo`03o`00
0?o^k^kooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2Oooool00oo^k^ko0000onk^kP02ooooo`03
o`000?oMgMgooooo00;ooooo00?ok^k^o`000?ooool0X_ooool00=Cooooo00GoV9RHo`000?l0003o
410@olc<c005ooooo`04oeEEEOmgMgOoooooooooo`;o00000_ooool2o`0000Sooooo00Co410@o`00
0?l0003ooooo0_l000001_l@413oooooooooooooooooMgMgoeEEEJ?ooooo003Eooooo`03okZj^_lb
<S;ooooo00Kooooo00?ogMgMoa0@4?o^k^h06?ooool00oo^k^ko410@omgMg@2Sooooo`00e_ooool0
0ol0003oooooooooo`06ooooo`03ogMgMomVIVKooooo01Oooooo00?oIVIVogMgMoooool0Xoooool0
0?ooooooX?ooool00?ooooooX?ooool00?ooooooX?ooool00?ooooooX?ooool00001\
\>"],
  ImageRangeCache->{{{0, 414.438}, {414.438, 0}} -> {-1.33723, -1.22135, \
0.00717279, 0.00717279}}]
}, Open  ]],

Cell[TextData[{
  "\tSince this problem is analytically tractable, we can compare our \
numerical solution to the analytic solution. The analytic solution is given \
by Eq. ",
  ButtonBox["(6.1.14)",
    ButtonData:>"(6.1.14)",
    ButtonStyle->"Hyperlink"],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] = 5  \[Pi]/4\)]],
  ". In Fig. ",
  ButtonBox["6.7",
    ButtonData:>"Fig. 6.7",
    ButtonStyle->"Hyperlink"],
  " we compare the analytic solution (solid) to the grid solution along the \
",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " axis, for  ",
  Cell[BoxData[
      \(TraditionalForm\`M\_x = \(M\_y = 30\)\)]],
  " (dashed) and ",
  Cell[BoxData[
      \(TraditionalForm\`60\)]],
  " (dotted):"
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0149073 0.588412 [
[.21429 .00241 -9 -9 ]
[.21429 .00241 9 0 ]
[.40476 .00241 -9 -9 ]
[.40476 .00241 9 0 ]
[.59524 .00241 -9 -9 ]
[.59524 .00241 9 0 ]
[.78571 .00241 -9 -9 ]
[.78571 .00241 9 0 ]
[.97619 .00241 -3 -9 ]
[.97619 .00241 3 0 ]
[1.025 .01491 0 -6 ]
[1.025 .01491 10 6 ]
[.01131 .13259 -18 -4.5 ]
[.01131 .13259 0 4.5 ]
[.01131 .25027 -18 -4.5 ]
[.01131 .25027 0 4.5 ]
[.01131 .36795 -18 -4.5 ]
[.01131 .36795 0 4.5 ]
[.01131 .48564 -18 -4.5 ]
[.01131 .48564 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01491 m
.21429 .02116 L
s
[(0.2)] .21429 .00241 0 1 Mshowa
.40476 .01491 m
.40476 .02116 L
s
[(0.4)] .40476 .00241 0 1 Mshowa
.59524 .01491 m
.59524 .02116 L
s
[(0.6)] .59524 .00241 0 1 Mshowa
.78571 .01491 m
.78571 .02116 L
s
[(0.8)] .78571 .00241 0 1 Mshowa
.97619 .01491 m
.97619 .02116 L
s
[(1)] .97619 .00241 0 1 Mshowa
.125 Mabswid
.07143 .01491 m
.07143 .01866 L
s
.11905 .01491 m
.11905 .01866 L
s
.16667 .01491 m
.16667 .01866 L
s
.2619 .01491 m
.2619 .01866 L
s
.30952 .01491 m
.30952 .01866 L
s
.35714 .01491 m
.35714 .01866 L
s
.45238 .01491 m
.45238 .01866 L
s
.5 .01491 m
.5 .01866 L
s
.54762 .01491 m
.54762 .01866 L
s
.64286 .01491 m
.64286 .01866 L
s
.69048 .01491 m
.69048 .01866 L
s
.7381 .01491 m
.7381 .01866 L
s
.83333 .01491 m
.83333 .01866 L
s
.88095 .01491 m
.88095 .01866 L
s
.92857 .01491 m
.92857 .01866 L
s
.25 Mabswid
0 .01491 m
1 .01491 L
s
gsave
1.025 .01491 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .13259 m
.03006 .13259 L
s
[(0.2)] .01131 .13259 1 0 Mshowa
.02381 .25027 m
.03006 .25027 L
s
[(0.4)] .01131 .25027 1 0 Mshowa
.02381 .36795 m
.03006 .36795 L
s
[(0.6)] .01131 .36795 1 0 Mshowa
.02381 .48564 m
.03006 .48564 L
s
[(0.8)] .01131 .48564 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04433 m
.02756 .04433 L
s
.02381 .07375 m
.02756 .07375 L
s
.02381 .10317 m
.02756 .10317 L
s
.02381 .16201 m
.02756 .16201 L
s
.02381 .19143 m
.02756 .19143 L
s
.02381 .22085 m
.02756 .22085 L
s
.02381 .27969 m
.02756 .27969 L
s
.02381 .30911 m
.02756 .30911 L
s
.02381 .33853 m
.02756 .33853 L
s
.02381 .39737 m
.02756 .39737 L
s
.02381 .4268 m
.02756 .4268 L
s
.02381 .45622 m
.02756 .45622 L
s
.02381 .51506 m
.02756 .51506 L
s
.02381 .54448 m
.02756 .54448 L
s
.02381 .5739 m
.02756 .5739 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(L) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02476 .59454 m
.0294 .57582 L
.03373 .56319 L
.04355 .54017 L
.06336 .50391 L
.10545 .44535 L
.14441 .40214 L
.18581 .363 L
.2257 .32995 L
.26408 .30143 L
.3049 .27392 L
.34421 .24971 L
.38201 .22821 L
.42226 .20697 L
.46099 .18794 L
.50217 .16904 L
.54184 .15199 L
.58 .13654 L
.6206 .12103 L
.65969 .10691 L
.70123 .0927 L
.74126 .07973 L
.77977 .06784 L
.82073 .0558 L
.86018 .04474 L
.89812 .03456 L
.9385 .02419 L
.97619 .01491 L
s
1 0 0 r
[ .05 .05 ] 0 setdash
.02381 .60332 m
.06244 .53327 L
.08255 .49094 L
.10458 .45652 L
.14415 .40945 L
.18466 .36884 L
.22365 .33497 L
.2651 .30284 L
.30503 .27494 L
.34344 .2504 L
.38431 .22631 L
.42366 .20482 L
.4615 .18551 L
.50178 .16623 L
.54055 .14877 L
.58178 .13125 L
.62149 .11528 L
.65968 .10066 L
.70033 .08583 L
.73946 .07218 L
.78104 .05832 L
.8211 .04554 L
.85966 .03395 L
.8792 .02837 L
.90066 .02301 L
.92108 .01892 L
.93087 .01738 L
.94015 .01622 L
.94452 .01578 L
.94918 .01539 L
.9516 .01523 L
.95428 .01507 L
.95674 .01494 L
.959 .01486 L
.96108 .01479 L
.96212 .01477 L
.96327 .01475 L
.96442 .01473 L
.96565 .01472 L
.96681 .01472 L
.96787 .01472 L
.96894 .01472 L
.96992 .01473 L
.971 .01475 L
.97215 .01477 L
.97407 .01483 L
.97619 .01491 L
s
0 1 0 r
[ .01 .02 ] 0 setdash
.02381 .60332 m
.04262 .55997 L
.06244 .5124 L
.07286 .49478 L
.08255 .48011 L
.10458 .45011 L
.14357 .40537 L
.18502 .36522 L
.22495 .33144 L
.26336 .30235 L
.30423 .27432 L
.34358 .24965 L
.38141 .22775 L
.4217 .20611 L
.46047 .18671 L
.5017 .16741 L
.54141 .14999 L
.5796 .13418 L
.62025 .11829 L
.65938 .10379 L
.70096 .08918 L
.74102 .07579 L
.77957 .06348 L
.82058 .05094 L
.86007 .03935 L
.89804 .02868 L
.91918 .02306 L
.93846 .01851 L
.94774 .01683 L
.95264 .01612 L
.95784 .01552 L
.96237 .01514 L
.96361 .01506 L
.96495 .01498 L
.9661 .01493 L
.96737 .01488 L
.96853 .01485 L
.96961 .01483 L
.97075 .01482 L
.97197 .01482 L
.97311 .01483 L
.97418 .01485 L
.97515 .01487 L
.97619 .01491 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{303.188, 187.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005j0000jB000`400?l00000o`00003ooooooomk
ooooo`00oooooomkooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000:Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool09_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0:Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0<Oooool4o`000003oa0@4?oooooooooo023ooooo001Dooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B40:Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<oooool00ol0003oooooooooo`0Rooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h0:_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Xooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Wo
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<oooool0
0ol0003oooooooooo`0Rooooo`00E?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h0:Oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
:Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Yoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03?ooooo00?o
0000ooooooooool08_ooool005Cooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Wo
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0:Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00cooooo`03o`00
0?oooooooooo02;ooooo001Dooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Wooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Yooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0[ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03?ooooo00?o0000ooooooooool08_oo
ool005Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
:Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000:Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000cooooo`03o`000?oooooooooo02;ooooo001D
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Wooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Sooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<Oooool00omEEEGoIVIVo`00000Tooooo`008_oo
ool00ol0003oooooooooo`3ooooooeKooooo000Rooooo`03o`000?oooooooooo0?ooooooE_ooool0
02;ooooo00?o0000ooooooooool0oooooom4ooooo`;o00000_ooool2o`0000cooooo000Rooooo`03
o`000?oooooooooo0?ooooooA?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@cooooo000Roooo
o`03o`000?oooooooooo0?ooooooAOooool01?oMgMgo0000oa0@4?o<c<`=ooooo`006_ooooooo`00
033o00001?oo0004o`3o00go00002oooool01?o^k^ko8B4Qoa0@4?o^k^h=ooooo`008_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`08ooooo`Ooo`001_ooool4o`0000;ooooo00?o0000ooooooooool04Oooool01?lQ
8B7oMgMgogMgMolb<S8=ooooo`008_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
02Gooooo0_oo00000ooooooo0?l0o`3o0003o`3o00?ooooo1?l00006ooooo`03o`000?oooooooooo
013ooooo0_l00002ooooo`;o00003?ooool002;ooooo00?o0000ooooooooool0oooooolSooooo`Co
0000;oooool002;ooooo00?o0000ooooooooool0oooooolGooooo`?o0?l01?ooool5o`0003?ooooo
000Rooooo`03o`000?oooooooooo0?oooooo5_ooool01?l0o`3oooooooooooooool4o`0003Sooooo
000Rooooo`03o`000?oooooooooo0?oooooo2_ooool4ool000Sooooo1?l0000looooo`008_ooool0
0ol0003oooooooooo`3oooooo`Oooooo0ooo0003ooooo`Co0?l000?oooooo`000?l000000_l00010
ooooo`008_ooool00ol0003oooooooooo`3oooooo`Cooooo0ooo0007ooooo`Co0000A?ooool002;o
oooo0_l0003oooooo`;ooooo0ooo00001?oooooo0?l0o`3o0?l0o`02ooooo`Co0000B?ooool002;o
oooo00?o0000ooooooooool0o?ooool4ool000;ooooo0_l0o`02ooooo`?o0000C?ooool002;ooooo
00?o0000ooooooooool0ooooool4ooooo`?o0000Coooool002;ooooo00?o0000ooooooooool0nooo
ool2o`3o00?ooooo0ol0001Booooo`008_ooool00ol0003oooooooooo`3iooooo`;o0?l000?ooooo
o`000?l000000_l0001Eooooo`008_ooool00ol0003oooooooooo`3iooooo`?o0000FOooool002;o
oooo00?o0000ooooooooool0k?ooool2ool000Cooooo0_l0o`02ooooo`?o0000G?ooool002;ooooo
00?o0000ooooooooool0jOooool3ool000Cooooo0_l0o`001?oooooo0000o`000?l0001Oooooo`00
8_ooool00ol0003oooooooooo`3Vooooo`?oo`001_ooool4o`0006;ooooo000Rooooo`03o`000?oo
oooooooo0>?ooooo0ooo0003ooooo`;o0?l000Coooooo`000?l0003o0000I_ooool002;ooooo0_l0
003Qooooo`?oo`001?ooool2o`3o00?o0000JOooool002;ooooo00?o0000ooooooooool0g_ooool2
ool000Kooooo0ol0001/ooooo`008_ooool00ol0003oooooooooo`3Pooooo`;o0?l000Coooooo`00
0?l0003o0000Koooool002;ooooo00?o0000ooooooooool0g_ooool2o`3o00?o0000L_ooool002;o
oooo00?o0000ooooooooool0gOooool3o`0007Gooooo000Rooooo`03o`000?oooooooooo0=Kooooo
0_l0o`02ooooo`?o0000N?ooool002;ooooo00?o0000ooooooooool0e?ooool2o`3o0004ooooool0
003o0000o`0007_ooooo000Rooooo`03o`000?oooooooooo0<kooooo0_oo0004ooooo`?o0000O_oo
ool002;ooooo00?o0000ooooooooool0boooool2ool000;o0?l00_ooool3o`00087ooooo000Roooo
o`;o0000b_ooool2ool000;o0?l000Coooooo`000?l0003o0000Q?ooool002;ooooo00?o0000oooo
ooooool0a_ooool3ool000;ooooo0ol00027ooooo`008_ooool00ol0003oooooooooo`33ooooo`03
ool00?l0o`3o0?l000?ooooo0_l0002:ooooo`008_ooool00ol0003oooooooooo`30ooooo`;oo`00
0_l0o`02ooooo`?o0000S?ooool002;ooooo00?o0000ooooooooool0_oooool01?oo003ooooooooo
ooooool3o`0008oooooo000Rooooo`03o`000?oooooooooo0<3ooooo0ol0002Booooo`008_ooool0
0ol0003oooooooooo`2kooooo`;o0?l00ol0002Eooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`2iooooo`;o0?l00_l0002H
ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01_ooool00ol0003oooooooooo`2gooooo`?o0000Voooool000Oooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/_oo
ool2o`3o00?o0000W_ooool000Oooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Kooooo0ol0002_ooooo`03ool00?l0o`3o0?l000;o0000XOooool000Oooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0[?oo
ool3ool000;o0000Y?ooool000Oooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0Z_ooool2ool000?o0000Y_ooool000Oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooo
ooooo`2Xooooo`04ool00?l0o`3o0?l0o`000:Wooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0YOooool2ool0
00;o0?l000?o0000ooooooooool0ZOooool002;ooooo00?o0000ooooooooool0Xoooool2ool000?o
0000[Oooool002;ooooo00?o0000ooooooooool0X_ooool00ooo003o0000o`00002`ooooo`008_oo
ool00ol0003oooooooooo`2Pooooo`;o0?l000?o0000ooooooooool0/?ooool002;ooooo00?o0000
ooooooooool0W_ooool2o`3o0003o`000?oooooooooo0;;ooooo000Rooooo`;o0000WOooool3o`00
0;Kooooo000Rooooo`03o`000?oooooooooo09[ooooo0_l0002iooooo`008_ooool00ol0003ooooo
ooooo`2Fooooo`?o0?l000?o0000ooooooooool0^Oooool002;ooooo00?o0000ooooooooool0UOoo
ool00ol0o`3o0000o`00002mooooo`008_ooool00ol0003oooooooooo`2Booooo`;oo`000_l0002o
ooooo`008_ooool00ol0003oooooooooo`2@ooooo`;oo`000_l00031ooooo`008_ooool00ol0003o
ooooooooo`2=ooooo`;oo`000_l0o`000ol0003oooooooooo`31ooooo`008_ooool00ol0003ooooo
ooooo`2;ooooo`;oo`000_l0o`36ooooo`008_ooool00ol0003oooooooooo`29ooooo`;oo`000_l0
0038ooooo`008_ooool00ol0003oooooooooo`27ooooo`;oo`000_l0003:ooooo`008_ooool2o`00
08Oooooo0_l0o`000ol0003oooooooooo`3:ooooo`008_ooool00ol0003oooooooooo`24ooooo`;o
0?l000?o0000ooooooooool0c?ooool002;ooooo00?o0000ooooooooool0Poooool2o`000=3ooooo
000Rooooo`03o`000?oooooooooo087ooooo0_l0003Booooo`008_ooool00ol0003oooooooooo`1n
ooooo`03o`3o0?l0003o00000=Cooooo000Rooooo`03o`000?oooooooooo07cooooo0_l0o`000ol0
003oooooooooo`3Dooooo`008_ooool00ol0003oooooooooo`1kooooo`03o`3o0?l0003ooooo0=Oo
oooo000Rooooo`03o`000?oooooooooo07Wooooo0_l0003Jooooo`008_ooool00ol0003ooooooooo
o`1eooooo`;oo`000_l0003Looooo`008_ooool2o`0007Cooooo0_oo0002o`3o0=kooooo000Roooo
o`03o`000?oooooooooo07;ooooo00Coo`00o`3o0?l0o`3o0000goooool002;ooooo00?o0000oooo
ooooool0L?ooool2ool000;o0000hOooool002;ooooo00?o0000ooooooooool0K_ooool2ool000;o
0000hoooool002;ooooo00?o0000ooooooooool0K?ooool2o`3o00;o0000iOooool002;ooooo00?o
0000ooooooooool0Joooool00ol0o`3o0000o`00003Wooooo`008_ooool00ol0003oooooooooo`1Y
ooooo`03ool00?l0o`3o00000>Wooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo06Sooooo00?oo`00
o`000?ooool0j_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo06Oooooo0_l0003/ooooo`001oooool01Ol@
413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo06Gooooo00?o0?l0
o`000?ooool0kOooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgo
ooooo`0000Oooooo0ol0001Sooooo`;o0?l0l?ooool000Oooooo00Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0HOooool00ol0003o0?l0
ooooo`3aooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000
1oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo0?;ooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo05kooooo
0_l0003eooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0
1_ooool00ol0003oooooooooo`1Looooo`;o0?l0moooool002;ooooo00?o0000ooooooooool0Fooo
ool00ol0o`3oooooooooo`3gooooo`008_ooool00ol0003oooooooooo`1Iooooo`03o`000?l0o`3o
o`000?Wooooo000Rooooo`03o`000?oooooooooo05Oooooo0_l000000ooo003oooooooooo`3ioooo
o`008_ooool00ol0003oooooooooo`1Fooooo`03o`000?oo003oo`000?cooooo000Rooooo`;o0000
EOooool2o`000003ool00?oooooooooo0?cooooo000Rooooo`03o`000?oooooooooo05?ooooo0_l0
o`000ooo003oooooooooo`3mooooo`008_ooool00ol0003oooooooooo`1Aooooo`03o`000?l0o`3o
o`000?oooooo0_ooool002;ooooo00?o0000ooooooooool0Coooool2o`000003ool00?oooooooooo
0?oooooo0_ooool002;ooooo00?o0000ooooooooool0C_ooool00ol0003oo`00ool0003oooooo`Go
oooo000Rooooo`03o`000?oooooooooo04cooooo0_l000000ooo003oooooooooo`3oooooo`Gooooo
000Rooooo`03o`000?oooooooooo04_ooooo00?o0000o`3o0?oo0000ooooool8ooooo`008_ooool0
0ol0003oooooooooo`19ooooo`;o000000?o0?l0ooooooooool0ooooool8ooooo`008_ooool00ol0
003oooooooooo`18ooooo`03o`000?oooooo0?l00?oooooo2oooool002;ooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`3oooooo`cooooo000Rooooo`;o0000A_ooool2o`000?oooooo
3oooool002;ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`3oooooo`oooooo000R
ooooo`03o`000?oooooooooo04?ooooo00?o0000o`3o0?l0o`00ooooool@ooooo`008_ooool00ol0
003oooooooooo`11ooooo`;o000000?o0?l0ooooooooool0ooooool@ooooo`008_ooool00ol0003o
ooooooooo`10ooooo`03o`000?oooooo0?l00?oooooo4oooool002;ooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`3ooooooaCooooo000Rooooo`03o`000?oooooooooo03gooooo0_l0
0002ool00?oooooo5Oooool002;ooooo00?o0000ooooooooool0??ooool00ol0003oooooool0003o
oooooaOooooo000Rooooo`03o`000?oooooooooo03_ooooo00?o0000ool00?l0o`00oooooolHoooo
o`008_ooool2o`0003_ooooo00?o0000ool00?l0o`00oooooolIooooo`008_ooool00ol0003ooooo
ooooo`0iooooo`03o`000?oo003o0?l00?oooooo6_ooool002;ooooo00?o0000ooooooooool0=ooo
ool2o`000003ool00?oooooooooo0?oooooo6_ooool002;ooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooool0003ooooooagooooo000Rooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
oooo0000oooooolNooooo`008_ooool00ol0003oooooooooo`0dooooo`03o`000?l0o`3o0?l00?oo
oooo7oooool002;ooooo00?o0000ooooooooool0<oooool00ol0003o0?l0ool0003oooooob3ooooo
0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c006ooooo`03o`000?oooooooooo03;ooooo00?o0000o`3o0?oo0000oooooolQooooo`00
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo0?oooooo8_ooool000Oo
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo0?oooooo8oooool000Oooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0002oooooo00?o
0000ooooooooool0oooooolTooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo02kooooo00?o0?l0ooooooooool0
oooooolUooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
2?ooool00ol0003oooooooooo`0]ooooo`03o`000?l0o`3ooooo0?oooooo9_ooool000Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
;?ooool00ol0003o0?l0ooooo`3oooooobOooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo02_ooooo00?o0000o`3o0?oo
ool0oooooolXooooo`008_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0?oooooo
:Oooool002;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3oooooob[ooooo000R
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0ooooool[ooooo`008_ooool00ol0
003oooooooooo`0Wooooo`03o`3o0?ooooooo`000?oooooo;?ooool002;ooooo0_l0000Wooooo`03
o`3o0?ooooooo`000?oooooo;Oooool002;ooooo00?o0000ooooooooool09Oooool00ol0o`3ooooo
ool0003oooooobkooooo000Rooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo0000oooo
ool_ooooo`008_ooool00ol0003oooooooooo`0Tooooo`03o`000?oo003ooooo0?oooooo;oooool0
02;ooooo00?o0000ooooooooool08oooool00ol0003oo`00ooooo`3ooooooc3ooooo000Rooooo`03
o`000?oooooooooo02;ooooo00?o0000oooooooo0000oooooolaooooo`008_ooool00ol0003ooooo
ooooo`0Qooooo`03o`3o0?ooooooo`000?oooooo<_ooool002;ooooo00?o0000ooooooooool08?oo
ool00ol0003o0?l0ool0003ooooooc?ooooo000Rooooo`03o`000?oooooooooo01oooooo00?o0000
o`3o0?oo0000ooooooldooooo`008_ooool00ol0003oooooooooo`0Nooooo`03o`000?l0o`3oo`00
0?oooooo=Oooool002;ooooo0_l0000Nooooo`03o`000?ooooooo`000?oooooo=_ooool002;ooooo
00?o0000ooooooooool07?ooool00ol0003oooooool0003oooooocOooooo000Rooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0oooooolhooooo`008_ooool00ol0003oooooooooo`0J
ooooo`03o`3o0?oooooooooo0?oooooo>Oooool002;ooooo00?o0000ooooooooool06Oooool00ol0
003o0?l0ooooo`3ooooooc[ooooo000Rooooo`03o`000?oooooooooo01Sooooo00?o0000o`3o0?oo
ool0oooooolkooooo`008_ooool00ol0003oooooooooo`0Gooooo`03o`000?l0o`3ooooo0?oooooo
??ooool002;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`3ooooooccooooo000R
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0oooooolmooooo`008_ooool2o`00
01Kooooo00?o0000ooooooooool0oooooolnooooo`008_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo0?oooooo?_ooool002;ooooo00?o0000ooooooooool05?ooool00ol0o`3ooooo
ooooo`3oooooocoooooo000Rooooo`03o`000?oooooooooo01?ooooo00?o0000o`3o0?ooool0oooo
oom0ooooo`008_ooool00ol0003oooooooooo`0Cooooo`03o`3o0?oooooooooo0?oooooo@?ooool0
02;ooooo00?o0000ooooooooool04_ooool00ol0o`3oooooool0003ooooood7ooooo000Rooooo`03
o`000?oooooooooo017ooooo00Co0000ooooooooooooo`00oooooom1ooooo`001oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`0@ooooo`04o`000?ooooooooooool00?oooooo@_ooool000Oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool04?ooool00ol0003oooooool0003ooooood?ooooo0007ooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool03oooool01?l0003ooooooooooooo003ooooood?ooooo0007ooooo`05o`000?oooooooooooooo
ool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0000>ooooo`04o`000?l0o`3o
ooooool00?ooooooA?ooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0
003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`0>ooooo`03o`3o0?ooooooo`000?oooooo
AOooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
41001_ooool00ol0003oooooooooo`0=ooooo`04o`3o0?ooooooooooool00?ooooooAOooool000Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool0
0ol0003oooooooooo`0<ooooo`04o`000?ooooooooooool00?ooooooA_ooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003ooooo
ooooo`0<ooooo`04o`000?ooooooooooool00?ooooooA_ooool002;ooooo00?o0000ooooooooool0
2oooool01?l0003ooooooooooooo003oooooodOooooo000Rooooo`03o`000?oooooooooo00[ooooo
00Go0000ooooooooooooooooool0003oooooodOooooo000Rooooo`03o`000?oooooooooo00[ooooo
00Co0000ooooooooooooo`00oooooom8ooooo`008_ooool00ol0003oooooooooo`09ooooo`;o0?l0
0_ooool00ooo003oooooooooo`3oooooodKooooo000Rooooo`;o00002Oooool01Ol0003o0?l0oooo
ooooooooo`000?ooooooBOooool002;ooooo00?o0000ooooooooool02?ooool00ol0o`3ooooooooo
o`3ooooood_ooooo000Rooooo`03o`000?oooooooooo00Oooooo00?o0000o`3o0?ooool0oooooom<
ooooo`008_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooCOooool002;o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodgooooo000Rooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom>ooooo`008_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?ooooooC_ooool002;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodoooooo000Rooooo`03o`000?oooooooooo00?ooooo00Co0000oooo
oooooooo0?l0oooooom?ooooo`008_ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`3o0?ooooooCoooool002;ooooo0_l00003ooooo`04o`000?ooooooooooo`3o0?ooooooD?ooool0
02;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0o`3ooooooe3ooooo000Roooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooomAooooo`008_ooool01Ol0003o
oooooooooooooooo00000?ooooooE?ooool002;ooooo00Go0000ooooooooooooooooo`00003ooooo
oeCooooo000Rooooo`05o`000?ooooooooooooooool000000oooool00ooo003oooooooooo`3ooooo
odkooooo000Rooooo`04o`000?ooooooooooo`0000Cooooo00?oo`00ooooooooool0oooooom>oooo
o`008_ooool02?l0003oooooooooool0003oooooo`3o0?ooooooo`00oooooomAooooo`008_ooool0
2?l0003oooooooooool0003oooooo`3o0?ooooooo`00oooooomAooooo`008_ooool3o`000004oooo
ool0o`3oooooool00?ooooooD_ooool002;ooooo00Ko0000ooooool0003oooooo`3o0?oo003ooooo
oe?ooooo000Rooooo`03o`000?oooooo000000;ooooo00?oo`00ooooooooool0oooooomAooooo`00
8_ooool2o`0000;ooooo00?oo`00ooooooooool0oooooomBooooo`008_ooool2o`0000;ooooo00?o
o`00ooooooooool0oooooomBooooo`008_ooool2o`000003oooooooo003ooooo0?ooooooE?ooool0
02;ooooo00Co0000ooooooooooooo`00oooooomEooooo`006?ooool4o`000003oa0@4?oooooooooo
00?ooooo00?o0000o`3o0?oo0000oooooomFooooo`006_ooool00ol0003oooooooooo`05ooooo`03
o`000?l0o`3ooooo0?ooooooE_ooool001[ooooo00?o0000ooooooooool01Oooool00ol0o`3oo`00
ooooo`3ooooooeKooooo000Jooooo`03o`000?oooooooooo00Gooooo00?o0?l0o`000?l00000oooo
oomFooooo`006_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooE_ooool0
01[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooeKooooo000Jooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooomFooooo`006?ooool00omEEEGoIVIV
o`000007ooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooNoooool00?ooooooNoooool0
0?ooooooNoooool00?ooooooNoooool00?ooooooNoooool00?ooooooNoooool00?ooooooNoooool0
0?ooooooNoooool00?ooooooNoooool00?ooooooNoooool000oooooo00?o0000ooooooooool01_oo
ool00omgMgOoIVIVooooo`09ooooo`03o`000?nj^[[ooooo00_ooooo00?oIVIVogMgMoooool0oooo
oom6ooooo`003oooool00ol@413ogMgMooooo`05ooooo`03omgMgOl@413ok^k^00[ooooo0_lb<S8<
ooooo`03onk^k_l@413ogMgM0?ooooooA_ooool000gooooo00Goc<c<oa0@4?l0003o0000ohN7Q`05
ooooo`03oeEEEOnHV9Sooooo00;ooooo0_l00002ooooo`;o00000_ooool00on7QhOo0000okZj^P04
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOoIVIVooooo`3oooooodGooooo000=
ooooo`06ob4Q8On7QhOo<S8bojVYZOm4A4CoQhN71?ooool00ol0003oooooooooo`02ooooo`06onk^
k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@4004ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool00oo^k^ko0000ooooo`3oooooodGooooo000=ooooo`06o`000?ooooooIVIV
ohN7QooMgMgo410@1?ooool00olb<S;oooooooooo`03ooooo`04omgMgOl0003o410@olc<c0[ooooo
00Go410@oooooooooooooooooa0@4004ooooo`03o`000?oooooooooo0?ooooooA?ooool000gooooo
00Ko410@omgMgOmgMgOoMgMgooooool00004ooooo`03oc8b<_oooooooooo00?ooooo00Cok^k^ob4Q
8Ol@413ok^k^2_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0oooo
oom4ooooo`003Oooool01_nYZJWoA4A4oiRHV?m4A4CoV9RHoa0@40Cooooo00?o0000onk^k_ooool0
0oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`05o`000?ooooooooooooooool000000oooool00oo^
k^ko0000ooooo`3oooooodGooooo000>ooooo`05oiRHV?l0003o0000oa0@4?o<c<`01?ooool00omE
EEGoMgMgooooo`02ooooo`;o00000_ooool2o`0000Wooooo00Go410@oooooooooooooooooa0@4003
ooooo`03ogMgMomEEEGooooo0?ooooooAOooool000oooooo00?o^[Zjoc8b<_ooool01Oooool00ooM
gMgo410@onk^kP0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool00oo^k^ko410@omgMg@3o
ooooodKooooo000@ooooo`03o`000?oooooooooo00Gooooo00?oMgMgofIVI_ooool04?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?oIVIVogMgMoooool0oooooom6ooooo`00oooooomkoooo
o`00oooooomkooooo`00oooooomkooooo`00\
\>"],
  ImageRangeCache->{{{0, 377.938}, {232.938, 0}} -> {-0.112202, -0.0805045, \
0.00406808, 0.00658444}}],

Cell["Fig. 6.7 ", "Caption",
  CellTags->"Fig. 6.7"],

Cell[TextData[{
  "The  solution is  more accurate than the corresponding Galerkin solution \
(see Fig. ",
  ButtonBox["6.2",
    ButtonData:>"Fig. 6.2",
    ButtonStyle->"Hyperlink"],
  ") near the singularity at ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(y = 0\)\)]],
  ".  However, the Galerkin solution is superior near the circular boundary, \
because of the aforementioned difficulty of fitting a curved edge to a grid. \
"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Relaxation Methods", "Section",
  CellTags->{"i:32", "c:25"}],

Cell[CellGroupData[{

Cell["Jacobi's Method", "Subsubsection",
  CellTags->"i:33"],

Cell[TextData[{
  "Although direct solution of the coupled equations for the potential is not \
difficult using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, it can be much more difficult to program an efficient direct \
solution in other computing environments  where access to sophisticated \
linear algebra packages may be limited. In these situations, relaxation \
methods are often useful. These methods have the advantage that they are \
relatively simple to code, needing no sophisticated external library \
routines.  On the other hand, they are typically not as fast as the direct \
methods. "
}], "Text"],

Cell[TextData[{
  "\t In the following relaxation method, one uses the following idea: \
solutions to Poisson's equation can be thought of as the equilibrium solution \
to the heat equation with a source, Eq. ",
  ButtonBox["(6.2.26)",
    ButtonData:>"(6.2.26)",
    ButtonStyle->"Hyperlink"],
  ".  Starting with any initial condition, the heat equation solution will \
eventually relax to a solution of Poisson's equation. "
}], "Text"],

Cell[TextData[{
  "\t For example, we can take the FTCS algorithm for the heat equation, ",
  ButtonBox["(6.2.28)",
    ButtonData:>"(6.2.28)",
    ButtonStyle->"Hyperlink"],
  ", replace ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`S/\[Chi]\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Rho]\)\)]],
  ", and take the largest possible time step size that is stable according to \
the Courant condition ",
  ButtonBox["(6.2.29)",
    ButtonData:>"(6.2.29)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Phi]\_\(j\ k\)\%\(n + 1\)\), "=", 
          RowBox[{\(\[Phi]\_\(j\ k\)\%n\), "+", 
            RowBox[{\(1\/2\), 
              FractionBox[
                RowBox[{
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["x",
                          FontSlant->"Italic"]}]], "2"], 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["y",
                          FontSlant->"Italic"]}]], "2"]}], 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["x",
                          FontSlant->"Italic"]}]], "2"], "+", 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["y",
                          FontSlant->"Italic"]}]], "2"]}]], 
              RowBox[{"(", 
                RowBox[{\(-\[Rho]\_\(j\ k\)\), "+", 
                  RowBox[{
                    FractionBox["1", 
                      SuperscriptBox[
                        StyleBox[
                          RowBox[{"\[CapitalDelta]", 
                            StyleBox["x",
                              FontSlant->"Italic"]}]], 
                        "2"]], \((\[Phi]\_\(j + 1\ k\)\%n - 
                        2  \[Phi]\_\(j\ k\)\%n + \[Phi]\_\(j - 1\ k\)\%\(\(\ \
\)\(n\)\))\)}], "+", 
                  RowBox[{
                    FractionBox["1", 
                      SuperscriptBox[
                        StyleBox[
                          RowBox[{"\[CapitalDelta]", 
                            StyleBox["y",
                              FontSlant->"Italic"]}]], 
                        "2"]], \((\[Phi]\_\(j\ k + 1\)\%n - 
                        2  \[Phi]\_\(j\ k\)\%n + \[Phi]\_\(j\ k - 1\)\%\(\(\ \
\)\(n\)\)\ )\)}]}], ")"}]}]}]}], TraditionalForm]]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "If one expands out the expression, one finds that the terms involving ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(j\ k\)\%n\)]],
  " cancel, leaving"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Phi]\_\(j\ k\)\%\(n + 1\)\), "=", 
          RowBox[{\(1\/2\), 
            FractionBox[
              RowBox[{
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], "2"], 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["y",
                        FontSlant->"Italic"]}]], "2"]}], 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["x",
                          FontSlant->"Italic"]}]], "2"], "+", 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["y",
                          FontSlant->"Italic"]}]], "2"]}], ")"}]], 
            RowBox[{"(", 
              RowBox[{\(-\[Rho]\_\(j\ k\)\), "+", 
                RowBox[{
                  FractionBox["1", 
                    SuperscriptBox[
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]], 
                      "2"]], \((\[Phi]\_\(j + 1\ k\)\%n + \[Phi]\_\(j - 1\ \
k\)\%\(\(\ \)\(n\)\))\)}], "+", 
                RowBox[{
                  FractionBox["1", 
                    SuperscriptBox[
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["y",
                            FontSlant->"Italic"]}]], 
                      "2"]], \((\[Phi]\_\(j\ k + 1\)\%n + \[Phi]\_\(j\ k - \
1\)\%\(\(\ \)\(n\)\)\ )\)}]}], ")"}]}]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.39)"],

Cell[TextData[{
  "\tEquation ",
  ButtonBox["(6.2.39)",
    ButtonData:>"(6.2.39)",
    ButtonStyle->"Hyperlink"],
  " is called",
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox[ButtonBox["Jacobi's",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Jacobi.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[" method",
    FontSlant->"Italic"],
  ". The equation provides us with a recursion relation for determining the \
solution to ",
  "Poisson's",
  " equation. Starting with any initial choice for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " at time step ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0\)]],
  ", the solution eventually relaxes to a solution of the Poisson equation ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 \[Phi] = \[Rho]\)]],
  ".  We stop the recursion when the difference between ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " at adjacent time steps is less than some tolerance."
}], "Text",
  CellTags->"i:61"],

Cell["\<\
\tThe following simple code implements the Jacobi method in a \
domain of arbitrary shape:\
\>", "Text"],

Cell[BoxData[{
    \(\(\(Clear["\<Global`*\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(M\_x = 20; \ M\_y = 20;\), "\n", 
    \(L\_x = 1.5\ ; \ L\_y = \ 2. ;\), "\n", 
    \(\[CapitalDelta]x = L\_x/M\_x; \ \[CapitalDelta]y = 
      L\_y/M\_y;\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.106"],

Cell["\<\
The homogeneous boundary conditions are specified by the following \
statements: \
\>", "Text"],

Cell[BoxData[{
    \(\[Phi][j_, k_, n_]\  := \ 0\  /; \ j \[LessEqual] \ f[k]\), "\n", 
    \(\[Phi][j_, k_, n_]\  := \ 0\  /; \ j \[GreaterEqual] \ g[k]\), "\n", 
    \(\(\[Phi][j_, 0, n_]\  = \ 0;\)\), "\n", 
    \(\(\[Phi][j_, M\_y, n_]\  = \ 0;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.107"],

Cell[TextData[{
  "The main body of the code is the Jacobi recursion relation, Eq. ",
  ButtonBox["(6.2.39)",
    ButtonData:>"(6.2.39)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\[Phi][j_, k_, 
        n_]\  := \ \(\[Phi][j, k, 
          n]\  = \ \(1\/2\) \(\(\(\[CapitalDelta]x\^2\) \[CapitalDelta]y\^2\)\
\/\((\[CapitalDelta]x\^2 + \[CapitalDelta]y\^2)\)\) \((\(-\[Rho][j, 
                  k]\) + \(1\/\[CapitalDelta]x\^2\) \((\[Phi][j + 1, k, 
                      n - 1] + \[Phi][j - 1, k, 
                      n - 1])\) + \(1\/\[CapitalDelta]y\^2\) \((\[Phi][j, 
                      k + 1, n - 1] + \[Phi][j, k - 1, 
                      n - 1]\ )\))\)\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.108"],

Cell[TextData[{
  "We must start the recursion with an initial guess. Typically, the closer \
the guess to the exact solution, the better the method works. However, we \
will simply choose ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] = 0\)]],
  " inside the domain:"
}], "Text"],

Cell[BoxData[
    \(\(\[Phi][j_, k_, 0]\  = \ 0;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.109"],

Cell[TextData[{
  "In order to determine how well the solution is converging to the correct \
answer, we take the difference between the solutions at the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "th and ",
  Cell[BoxData[
      \(TraditionalForm\`n - 1\)]],
  "st steps:"
}], "Text"],

Cell[BoxData[
    \(error[n_]\  := \ 
      Max[Table[
          Table[Abs[\[Phi][j, k, n] - \[Phi][j, k, n - 1]], {j, f[k] + 1, 
              g[k] - 1}], {k, 1, M\_y - 1}]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.110"],

Cell["\<\
When this difference is sufficiently small, we can say that the \
solution has converged. \
\>", "Text"],

Cell[TextData[{
  "\tLet's now perform a solution of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 \[Phi] = 1\)]],
  " in the irregular domain specified below:"
}], "Text"],

Cell[BoxData[{
    \(\(\(\[Rho][j_, k_]\  = \ 1;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(g[k_]\  := M\_x; \ k \[LessEqual] \ 5;\), "\n", 
    \(\(g[k_]\  := \ M\_x - k + 5 /; 5 < k < 15;\)\), "\n", 
    \(\(g[k_]\  := \ M\_x - 10\  /; \ k \[GreaterEqual] \ 15;\)\), "\n", 
    \(\(f[k_]\ \  = \ Floor[12 \((k/M\_y - 1)\)^2];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.111"],

Cell[TextData[{
  "It requires many steps,  but eventually the error falls to an acceptable \
level, as shown in Cells ",
  ButtonBox["6.112",
    ButtonData:>"Cell 6.112",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["6.113",
    ButtonData:>"Cell 6.113",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(error[200]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.112"],

Cell[BoxData[
    \(4.741557711643307`*^-6\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Graphics`;\)\), "\n", 
    \(\(LogLogListPlot[Table[{n, error[n]}, {n, 1, 200}], 
        AxesLabel \[Rule] {"\<n\>", "\<error[n]\>"}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.113"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.413893 1.22966 0.228198 [
[.02381 -0.0125 -5 -12 ]
[.02381 -0.0125 5 0 ]
[.1484 -0.0125 -5 -12 ]
[.1484 -0.0125 5 0 ]
[.31311 -0.0125 -5 -12 ]
[.31311 -0.0125 5 0 ]
[.4377 -0.0125 -8 -12 ]
[.4377 -0.0125 8 0 ]
[.5623 -0.0125 -8 -12 ]
[.5623 -0.0125 8 0 ]
[.727 -0.0125 -8 -12 ]
[.727 -0.0125 8 0 ]
[.8516 -0.0125 -11 -12 ]
[.8516 -0.0125 11 0 ]
[.97619 -0.0125 -11 -12 ]
[.97619 -0.0125 11 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .08867 -46 -6 ]
[-0.0125 .08867 0 6 ]
[-0.0125 .15736 -46 -6 ]
[-0.0125 .15736 0 6 ]
[-0.0125 .24817 -46 -6 ]
[-0.0125 .24817 0 6 ]
[-0.0125 .31687 -40 -6 ]
[-0.0125 .31687 0 6 ]
[-0.0125 .38556 -40 -6 ]
[-0.0125 .38556 0 6 ]
[-0.0125 .47637 -40 -6 ]
[-0.0125 .47637 0 6 ]
[-0.0125 .54507 -34 -6 ]
[-0.0125 .54507 0 6 ]
[-0.0125 .61376 -34 -6 ]
[-0.0125 .61376 0 6 ]
[0 .64303 -26 0 ]
[0 .64303 26 12 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.1484 0 m
.1484 .00625 L
s
gsave
.1484 -0.0125 -66 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31311 0 m
.31311 .00625 L
s
gsave
.31311 -0.0125 -66 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4377 0 m
.4377 .00625 L
s
gsave
.4377 -0.0125 -69 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5623 0 m
.5623 .00625 L
s
gsave
.5623 -0.0125 -69 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.727 0 m
.727 .00625 L
s
gsave
.727 -0.0125 -69 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8516 0 m
.8516 .00625 L
s
gsave
.8516 -0.0125 -72 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -72 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22129 0 m
.22129 .00375 L
s
.273 0 m
.273 .00375 L
s
.34588 0 m
.34588 .00375 L
s
.37359 0 m
.37359 .00375 L
s
.39759 0 m
.39759 .00375 L
s
.41876 0 m
.41876 .00375 L
s
.63518 0 m
.63518 .00375 L
s
.68689 0 m
.68689 .00375 L
s
.75977 0 m
.75977 .00375 L
s
.78748 0 m
.78748 .00375 L
s
.81149 0 m
.81149 .00375 L
s
.83266 0 m
.83266 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08867 m
.00625 .08867 L
s
gsave
-0.0125 .08867 -107 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00001) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .15736 m
.00625 .15736 L
s
gsave
-0.0125 .15736 -107 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00002) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .24817 m
.00625 .24817 L
s
gsave
-0.0125 .24817 -107 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00005) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .31687 m
.00625 .31687 L
s
gsave
-0.0125 .31687 -101 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0001) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .38556 m
.00625 .38556 L
s
gsave
-0.0125 .38556 -101 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0002) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .47637 m
.00625 .47637 L
s
gsave
-0.0125 .47637 -101 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0005) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .54507 m
.00625 .54507 L
s
gsave
-0.0125 .54507 -95 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.001) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61376 m
.00625 .61376 L
s
gsave
-0.0125 .61376 -95 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.002) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .19755 m
.00375 .19755 L
s
0 .22606 m
.00375 .22606 L
s
0 .26624 m
.00375 .26624 L
s
0 .28152 m
.00375 .28152 L
s
0 .29475 m
.00375 .29475 L
s
0 .30643 m
.00375 .30643 L
s
0 .42575 m
.00375 .42575 L
s
0 .45426 m
.00375 .45426 L
s
0 .49444 m
.00375 .49444 L
s
0 .50972 m
.00375 .50972 L
s
0 .52295 m
.00375 .52295 L
s
0 .53462 m
.00375 .53462 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(error) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(@) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .60332 Mdot
.1484 .60332 Mdot
.22129 .60332 Mdot
.273 .60332 Mdot
.31311 .60332 Mdot
.34588 .60332 Mdot
.37359 .60332 Mdot
.39759 .60175 Mdot
.41876 .60168 Mdot
.4377 .59889 Mdot
.45484 .59871 Mdot
.47048 .59513 Mdot
.48486 .59481 Mdot
.49818 .59072 Mdot
.51059 .59027 Mdot
.52219 .5859 Mdot
.53308 .58529 Mdot
.54336 .58083 Mdot
.55308 .58 Mdot
.5623 .57556 Mdot
.57107 .5747 Mdot
.57943 .57016 Mdot
.58742 .56926 Mdot
.59507 .56466 Mdot
.60241 .56372 Mdot
.60946 .55907 Mdot
.61624 .55809 Mdot
.62278 .55341 Mdot
.62909 .55239 Mdot
.63518 .54768 Mdot
.64107 .54663 Mdot
.64678 .5419 Mdot
.65231 .54082 Mdot
.65768 .53606 Mdot
.66289 .53496 Mdot
.66795 .53019 Mdot
.67288 .52906 Mdot
.67767 .52428 Mdot
.68234 .52313 Mdot
.68689 .51834 Mdot
.69133 .51717 Mdot
.69566 .51238 Mdot
.69989 .51118 Mdot
.70402 .50645 Mdot
.70806 .50516 Mdot
.71201 .50049 Mdot
.71588 .49912 Mdot
.71966 .49451 Mdot
.72337 .49305 Mdot
.727 .4885 Mdot
.73056 .48697 Mdot
.73405 .48247 Mdot
.73748 .48087 Mdot
.74084 .47641 Mdot
.74413 .47475 Mdot
.74737 .47034 Mdot
.75055 .46862 Mdot
.75368 .46425 Mdot
.75675 .46247 Mdot
.75977 .45813 Mdot
.76275 .4563 Mdot
.76567 .45201 Mdot
.76854 .45013 Mdot
.77138 .44586 Mdot
.77416 .44394 Mdot
.77691 .4397 Mdot
.77961 .43776 Mdot
.78227 .43353 Mdot
.7849 .43159 Mdot
.78748 .42734 Mdot
.79003 .4254 Mdot
.79255 .42114 Mdot
.79503 .4192 Mdot
.79747 .41493 Mdot
.79988 .41299 Mdot
.80227 .40871 Mdot
.80462 .40677 Mdot
.80693 .40248 Mdot
.80922 .40054 Mdot
.81149 .39624 Mdot
.81372 .39429 Mdot
.81592 .38999 Mdot
.8181 .38804 Mdot
.82026 .38373 Mdot
.82238 .38178 Mdot
.82449 .37747 Mdot
.82656 .37551 Mdot
.82862 .37119 Mdot
.83065 .36923 Mdot
.83266 .36491 Mdot
.83464 .36295 Mdot
.83661 .35862 Mdot
.83855 .35665 Mdot
.84047 .35233 Mdot
.84238 .35035 Mdot
.84426 .34603 Mdot
.84612 .34405 Mdot
.84796 .33972 Mdot
.84979 .33774 Mdot
.8516 .33341 Mdot
.85338 .33142 Mdot
.85516 .3271 Mdot
.85691 .3251 Mdot
.85865 .32078 Mdot
.86037 .31877 Mdot
.86207 .31445 Mdot
.86376 .31244 Mdot
.86543 .30812 Mdot
.86709 .3061 Mdot
.86873 .30179 Mdot
.87036 .29976 Mdot
.87197 .29545 Mdot
.87356 .29342 Mdot
.87515 .28911 Mdot
.87672 .28707 Mdot
.87827 .28276 Mdot
.87982 .28072 Mdot
.88135 .27642 Mdot
.88286 .27437 Mdot
.88437 .27007 Mdot
.88586 .26801 Mdot
.88734 .26371 Mdot
.88881 .26165 Mdot
.89026 .25736 Mdot
.89171 .25529 Mdot
.89314 .251 Mdot
.89456 .24892 Mdot
.89597 .24464 Mdot
.89737 .24256 Mdot
.89876 .23827 Mdot
.90013 .23619 Mdot
.9015 .23191 Mdot
.90286 .22981 Mdot
.9042 .22554 Mdot
.90554 .22344 Mdot
.90687 .21917 Mdot
.90818 .21706 Mdot
.90949 .2128 Mdot
.91079 .21069 Mdot
.91208 .20643 Mdot
.91336 .20432 Mdot
.91463 .20005 Mdot
.91589 .19795 Mdot
.91714 .19368 Mdot
.91839 .19158 Mdot
.91962 .1873 Mdot
.92085 .18521 Mdot
.92207 .18092 Mdot
.92328 .17884 Mdot
.92448 .17454 Mdot
.92567 .17247 Mdot
.92686 .16816 Mdot
.92804 .16609 Mdot
.92921 .16177 Mdot
.93037 .15972 Mdot
.93153 .15539 Mdot
.93268 .15334 Mdot
.93382 .149 Mdot
.93495 .14697 Mdot
.93608 .14261 Mdot
.9372 .14059 Mdot
.93831 .13623 Mdot
.93942 .13421 Mdot
.94052 .12984 Mdot
.94161 .12783 Mdot
.9427 .12345 Mdot
.94378 .12145 Mdot
.94485 .11706 Mdot
.94592 .11506 Mdot
.94698 .11067 Mdot
.94803 .10868 Mdot
.94908 .10427 Mdot
.95012 .1023 Mdot
.95116 .09788 Mdot
.95219 .09591 Mdot
.95321 .09149 Mdot
.95423 .08952 Mdot
.95524 .08509 Mdot
.95625 .08314 Mdot
.95725 .0787 Mdot
.95825 .07675 Mdot
.95924 .0723 Mdot
.96022 .07036 Mdot
.9612 .06591 Mdot
.96218 .06397 Mdot
.96315 .05951 Mdot
.96411 .05758 Mdot
.96507 .05311 Mdot
.96602 .05119 Mdot
.96697 .04671 Mdot
.96791 .0448 Mdot
.96885 .04031 Mdot
.96979 .03841 Mdot
.97072 .03392 Mdot
.97164 .03202 Mdot
.97256 .02752 Mdot
.97347 .02562 Mdot
.97438 .02112 Mdot
.97529 .01923 Mdot
.97619 .01472 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00@Oooool4o`000003oa0@4?oo
oooooooo01_ooooo1Ol0000Zooooo`05odA4A?l0003o0000oc8b<_oMgMd06_ooool4o`000008oa0@
4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hFooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^027ooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h04oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h04Oooool004?ooooo00?o0000ooooooooool07Oooool01OnHV9So
8B4Qonk^k_ooooooA4A402gooooo00?oMgMgoc8b<_ooool06oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL05_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Tooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9So
MgMg01Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0>ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Aooooo`00@oooool00ol0
003oooooooooo`0Nooooo`03oiRHV?lQ8B7ok^k^02oooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41005oooool00onHV9So8B4Qonk^kP04
ooooo`05oa0@4?ooooooooooooooool@41009Oooool01?l0003oooooooooool@4103ooooo`03oa0@
4?oooooooooo01?ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41004Oooool004?ooooo00?o0000
ooooooooool07oooool00onHV9So8B4Qonk^kP0]ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000001Sooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Ol0003ooooooooooooooooo000002Cooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`00000@ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000004Oooool004?ooooo00?o
0000ooooooooool08?ooool00omgMgOoIVIVooooo`0Yooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
7?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000006Oooool00omgMgOo
IVIVooooo`02ooooo`05o`000?ooooooooooooooool000008Oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00;ooooo00Go0000ooooooooooooooooo`00000Eooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000004Oooool00omgMgOo
IVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
0000017ooooo0013ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400J
ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Oooooo`03o`000?oo
oooooooo00Cooooo00Go410@oooooooooooooooooa0@400Eooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41004_ooool01Ol0
003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo00oooooo0013ooooo`03o`000?oooooooooo01gooooo00Go0000okZj^_ooooooV9RHoa0@
400Zooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01Kooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL08Oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05Oooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00kooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg017ooooo0011ooooo`03oeEEEOmVIVKo0000
01oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Zooooo`Co00006oooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01?ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0>ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomOooooo`04oa0@4?l0003o0000ooooo`;o000000?o
410@ooooooooool00Oooool00?ooooooH?ooool01Ol0003ooooooooooooooooo000000Cooooo003o
ooooof3ooooo00Go0000ooooooooooooooooo`000004ooooo`00??ooooooo`0001Wo00002oooool0
1Ol0003ooooooooooooooooo000000Cooooo000looooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0@ooooo`05o`000?n7QhOoooooojVYZOl000001?oo
ool003cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo00oooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`02ooooo`00??ooool00ol0
003oooooooooo`3oooooob[ooooo000looooo`03o`000?oooooooooo0?oooooo3_ooool2o`0001[o
oooo000looooo`03o`000?oooooooooo0?oooooo3Oooool3o`0001[ooooo000looooo`03o`000?oo
oooooooo0?oooooo3Oooool3o`0001[ooooo000looooo`03o`000?oooooooooo0?oooooo3Oooool2
o`0001_ooooo000looooo`03o`000?oooooooooo0?oooooo3Oooool2o`0001_ooooo000looooo`03
o`000?oooooooooo0?oooooo3?ooool3o`0001_ooooo000looooo`03o`000?oooooooooo0?oooooo
3?ooool2o`0001cooooo000looooo`03o`000?oooooooooo0?oooooo3?ooool2o`0001cooooo000l
ooooo`03o`000?oooooooooo0?oooooo3?ooool2o`0001cooooo000looooo`03o`000?oooooooooo
0?oooooo2oooool3o`0001cooooo000looooo`03o`000?oooooooooo0?oooooo2oooool2o`0001go
oooo000looooo`03o`000?oooooooooo0?oooooo2oooool2o`0001gooooo000looooo`03o`000?oo
oooooooo0?oooooo2_ooool2o`0001kooooo000looooo`03o`000?oooooooooo0?oooooo2_ooool2
o`0001kooooo000looooo`03o`000?oooooooooo0?oooooo2_ooool2o`0001kooooo000looooo`03
o`000?oooooooooo0?oooooo2Oooool3o`0001kooooo000looooo`03o`000?oooooooooo0?oooooo
2Oooool2o`0001oooooo000looooo`03o`000?oooooooooo0?oooooo2Oooool2o`0001oooooo0003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co000000Go410@ooooooooooooooooo`00
003oooooo`_ooooo0_l0000Oooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo2?ooool2o`00023ooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooo
o`Sooooo0_l0000Pooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?o
oooo0ol0003oooooo`Oooooo0ol0000Pooooo`000oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0ooooool7ooooo`;o00008Oooool000?ooooo00Go
410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo1ooo
ool2o`00027ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`3oooooo`Oooooo0_l0000Qooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04oooo
o`03oeEEEOmVIVKo000000Gooooo00?o0000ooooooooool0ooooool6ooooo`?o00008Oooool003co
oooo00?o0000ooooooooool0ooooool6ooooo`;o00008_ooool003cooooo00?o0000ooooooooool0
ooooool6ooooo`;o00008_ooool003cooooo00?o0000ooooooooool0ooooool5ooooo`;o00008ooo
ool003cooooo00?o0000ooooooooool0ooooool5ooooo`;o00008oooool003cooooo00?o0000oooo
ooooool0ooooool5ooooo`;o00008oooool003cooooo00?o0000ooooooooool0ooooool4ooooo`?o
00008oooool003cooooo00?o0000ooooooooool0ooooool4ooooo`;o00009?ooool003cooooo00?o
0000ooooooooool0ooooool4ooooo`;o00009?ooool003cooooo00?o0000ooooooooool0ooooool3
ooooo`?o00009?ooool003cooooo00?o0000ooooooooool0ooooool3ooooo`;o00009Oooool003co
oooo00?o0000ooooooooool0ooooool2ooooo`?o00009Oooool000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo1Ol00004ooooo`03o`000?oooooooooo0?oooooo0_ooool2o`0002Kooooo
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1?ooool00ol0003oooooooooo`3oooooo`;ooooo0_l0000Vooooo`000oooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4004ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool0ooooool1ooooo`?o00009_oo
ool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool00onHV9So8B4Qonk^kP04ooooo`?o0000ooooool1
ooooo`;o00009oooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00omgMgOoIVIVooooo`03oooo
o`03o`000?oooooooooo0?oooooo0Oooool2o`0002Oooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooo`?o00009oooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool0ooooool2o`0002Sooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c004ooooo`03o`000?oooooooooo0?kooooo0ol0000Xooooo`00??ooool00ol0003ooooo
ooooo`3nooooo`?o0000:?ooool003cooooo00?o0000ooooooooool0o_ooool2o`0002Wooooo000l
ooooo`03o`000?oooooooooo0?gooooo0ol0000Yooooo`00??ooool00ol0003oooooooooo`3moooo
o`;o0000:_ooool003cooooo00?o0000ooooooooool0oOooool2o`0002[ooooo000looooo`03o`00
0?oooooooooo0?cooooo0ol0000Zooooo`00??ooool3o`000?cooooo0_l0000[ooooo`00??ooool0
0ol0003oooooooooo`3kooooo`?o0000:oooool003cooooo00?o0000ooooooooool0noooool2o`00
02cooooo000looooo`03o`000?oooooooooo0?_ooooo0_l0000/ooooo`00??ooool00ol0003ooooo
ooooo`3jooooo`?o0000;?ooool003cooooo00?o0000ooooooooool0n_ooool2o`0002gooooo000l
ooooo`03o`000?oooooooooo0?[ooooo0_l0000]ooooo`00??ooool00ol0003oooooooooo`3ioooo
o`?o0000;Oooool003cooooo0ol0003iooooo`;o0000;_ooool003cooooo00?o0000ooooooooool0
n?ooool2o`0002oooooo000looooo`03o`000?oooooooooo0?Sooooo0_l0000_ooooo`000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00?ooooo00?o
0000ooooooooool0moooool3o`0002oooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07
ooooo`03ogMgMolb<S;ooooo00;ooooo00?o0000ooooooooool0moooool2o`00033ooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00Sooooo00Go0000ooooooooooooooooo`00003hooooo`?o0000<?ooool0
00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000001oooool00omgMgOo<S8booooo`02ooooo`?o0000m_ooool2o`00
037ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c003oooo
o`03o`000?oooooooooo0?Kooooo0_l0000aooooo`000oooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4004ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0mOooool2o`0003;ooooo0003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3eooooo`;o0000
<_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool4o`0000Cooooo00?o0000ooooooooool0m?oo
ool3o`0003;ooooo000looooo`?o0000m?ooool2o`0003?ooooo000looooo`03o`000?oooooooooo
0??ooooo0ol0000cooooo`00??ooool00ol0003oooooooooo`3cooooo`;o0000=?ooool003cooooo
00?o0000ooooooooool0l_ooool3o`0003Cooooo000looooo`?o0000l_ooool2o`0003Gooooo000l
ooooo`03o`000?oooooooooo0?;ooooo0_l0000eooooo`00??ooool00ol0003oooooooooo`3aoooo
o`;o0000=_ooool003cooooo00?o0000ooooooooool0l?ooool3o`0003Kooooo000looooo`?o0000
l?ooool2o`0003Oooooo000looooo`03o`000?oooooooooo0>oooooo0ol0000gooooo`00??ooool0
0ol0003oooooooooo`3_ooooo`;o0000>?ooool003cooooo0ol0003^ooooo`?o0000>?ooool000_o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1?ooool4o`000005oa0@4?ooooooooooooooool00000l?ooool2o`0003Wooooo000;ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`3]ooooo`?o0000>Oooool000_ooooo00Go410@
oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo
00?ooooo0ol0003]ooooo`?o0000>Oooool000_ooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
k?ooool3o`0003[ooooo000;ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>cooooo0_l0000k
ooooo`002oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3[ooooo`?o0000>oooool000_ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0j_ooool3o`0003cooooo000;ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00omEEEGoIVIVo`000005oooo
o`03o`000?oooooooooo0>[ooooo0ol0000looooo`00??ooool00ol0003oooooooooo`3Yooooo`?o
0000?Oooool003cooooo00?o0000ooooooooool0jOooool3o`0003gooooo000looooo`03o`000?oo
oooooooo0>Sooooo0ol0000nooooo`00??ooool00ol0003oooooooooo`3Xooooo`;o0000?oooool0
03cooooo00?o0000ooooooooool0ioooool3o`0003oooooo000looooo`03o`000?oooooooooo0>Ko
oooo0ol00010ooooo`00??ooool00ol0003oooooooooo`3Vooooo`?o0000@?ooool003cooooo00?o
0000ooooooooool0iOooool2o`0004;ooooo000looooo`03o`000?oooooooooo0>Cooooo0ol00012
ooooo`00??ooool00ol0003oooooooooo`3Tooooo`;o0000@oooool003cooooo00?o0000oooooooo
ool0hoooool3o`0004?ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo1Ol00004ooooo`03o`000?oooooooooo0>?ooooo0_l0
0014ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01?ooool00ol0003oooooooooo`3Q
ooooo`Co0000A?ooool000_ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4004ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0ol0003Qooooo`?o0000AOooool000_ooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000005ooooo`03oiRHV?lQ
8B7ok^k^00Cooooo00?o0000ooooooooool0h?ooool3o`0004Kooooo000;ooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00omgMgOoIVIVooooo`03oooo
o`03o`000?oooooooooo0>3ooooo0ol00016ooooo`002oooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`3Oooooo`?o0000Aoooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooooooo
o`3Nooooo`?o0000B?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool00ol0003oooooooooo`3N
ooooo`;o0000BOooool003cooooo00?o0000ooooooooool0g?ooool4o`0004Wooooo000looooo`03
o`000?oooooooooo0=cooooo0ol0001:ooooo`00??ooool00ol0003oooooooooo`3Kooooo`?o0000
Boooool003cooooo00?o0000ooooooooool0f_ooool4o`0004_ooooo000looooo`03o`000?oooooo
oooo0=[ooooo0_l0001=ooooo`00??ooool00ol0003oooooooooo`3Iooooo`?o0000COooool003co
oooo0ol0003Hooooo`?o0000C_ooool003cooooo00?o0000ooooooooool0eoooool3o`0004oooooo
000looooo`03o`000?oooooooooo0=Kooooo1?l0001?ooooo`00??ooool00ol0003oooooooooo`3E
ooooo`?o0000DOooool003cooooo00?o0000ooooooooool0eOooool2o`0005;ooooo000looooo`03
o`000?oooooooooo0=Cooooo0ol0001Booooo`00??ooool00ol0003oooooooooo`3Booooo`Co0000
Doooool003cooooo00?o0000ooooooooool0d_ooool3o`0005Cooooo000looooo`?o0000dOooool2
o`0005Kooooo000looooo`03o`000?oooooooooo0=3ooooo0ol0001Fooooo`00??ooool00ol0003o
ooooooooo`3?ooooo`?o0000Eoooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00?ooooo
00?o0000ooooooooool0c_ooool3o`0005Sooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?oMgMgoc8b<_ooool00_ooool0
0ol0003oooooooooo`3=ooooo`?o0000FOooool000_ooooo00Go410@oooooooooooooooooa0@400;
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4008ooooo`05o`000?ooooooooooooooool00000cOooool4o`00
05[ooooo000;ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
1oooool00omgMgOo<S8booooo`02ooooo`?o0000boooool3o`0005_ooooo000;ooooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00?ooooo00?o0000ooooooooool0bOooool3o`0005gooooo000;ooooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0<Sooooo1?l0001Mooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`37ooooo`?o0000Goooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP04ooooo`Co00001?ooool00ol0003oooooooooo`35ooooo`Co0000H?ooool0
03cooooo0ol00035ooooo`?o0000HOooool003cooooo00?o0000ooooooooool0`oooool3o`0006?o
oooo000looooo`03o`000?oooooooooo0<;ooooo1?l0001Sooooo`00??ooool00ol0003ooooooooo
o`31ooooo`?o0000IOooool003cooooo0ol0002oooooo`Co0000I_ooool003cooooo00?o0000oooo
ooooool0_oooool3o`0006Oooooo000looooo`03o`000?oooooooooo0;cooooo0ol0001Zooooo`00
??ooool00ol0003oooooooooo`2kooooo`Co0000J_ooool003cooooo0ol0002jooooo`?o0000K?oo
ool003cooooo00?o0000ooooooooool0]oooool5o`0006gooooo000looooo`03o`000?oooooooooo
0;Oooooo0ol0001_ooooo`004_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l0
00000ol@413oooooooooo`02ooooo`?o0000]?ooool4o`00077ooooo000Booooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;?o
oooo1Ol0001aooooo`004_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0;7ooooo1?l0001dooooo`004_ooool01Ol0003ooooooooooooooooo
000000_ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`04ooooo`?o0000[_ooool5o`0007Kooooo000Booooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[?ooool5o`00
07Sooooo000Booooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0Z_ooool4o`0007_ooooo000Booooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0Yoooool5o`0007gooooo000Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP04ooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0Yoooool4
o`0007kooooo000looooo`03o`000?oooooooooo0:?ooooo1?l00022ooooo`00??ooool00ol0003o
ooooooooo`2Nooooo`;o000000?oooooo`000?l000001?l00022ooooo`00??ooool00ol0003ooooo
ooooo`2Nooooo`;o000000?oooooo`000?l00000Q_ooool003cooooo00?o0000ooooooooool0V_oo
ool4o`0008_ooooo000looooo`03o`000?oooooooooo09Cooooo0_l000001?oooooo0000o`000?oo
ool4o`0008_ooooo000looooo`03o`000?oooooooooo09Cooooo0_l000000ooooooo0000o`00002@
ooooo`00??ooool00ol0003oooooooooo`2>ooooo`;o000000?oooooo`000?l00000U_ooool003co
oooo00?o0000ooooooooool0R?ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`00
0?l00000U_ooool003cooooo00?o0000ooooooooool0P?ooool2o`0000;ooooo0_l00002ooooo`;o
000000?oooooo`000?l00000W?ooool003cooooo00?o0000ooooooooool0Moooool2o`0000?ooooo
0_l00002ooooo`;o00000_ooool2o`000:?ooooo000looooo`03o`000?oooooooooo06cooooo0_l0
0004ooooo`;o00000oooool2o`0000?ooooo0_l0002[ooooo`004_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo1Ol00005ooooo`03o`000?oooooooooo00Cooooo0_l0000Pooooo`;o
00004oooool2o`0000cooooo0_l00009ooooo`;o00001oooool2o`0000Kooooo0_l00005ooooo`;o
00001?ooool2o`000;Gooooo000Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000ooooooooool01?ooool2o`00023ooooo0_l0
000Cooooo`;o00003?ooool2o`0000Wooooo0_l00007ooooo`;o00001_ooool2o`000<;ooooo000B
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4004ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000oooooooo
ool0oooooolZooooo`004_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000001Oooool00onHV9So8B4Qonk^kP05
ooooo`?o0000oooooolZooooo`004_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00omgMgOoIVIV
ooooo`04ooooo`03o`000?oooooooooo0?oooooo:_ooool001;ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00Oooooo00?o0000ooooooooool0ooooool`ooooo`004_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01Ol0003o^[ZjoooooonHV9So410@0?oooooo<_ooool001;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03ooooooc;ooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0018ooooo`;o
00002oooool2o`000?oooooo4_ooool004Sooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`3ooooooa3ooooo000Pooooo`08onk^k_mEEEGo0000o`000?m4A4Co^[Zjooooool@4105o`00
00;ooooo00?o410@o`000?l000000ol00003ooooo`08onk^k_mEEEGo0000o`000?mEEEGok^k^oooo
ool@4105o`0000?ooooo00?o0000ooooooooool00_ooool01?l@413o0000o`000?ooool2o`000004
oa0@4?ooooooooooo`000?oooooo4_ooool0023ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4103
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool01_mEEEGoMgMgoooooooo
ooooMgMgoeEEE@?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`3ooooooa3ooooo000Pooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo0?oooooo4?ooool0023o
oooo1_l00003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`3ooooooa3ooooo000Poooo
o`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0oooool00ol0003o<S8bomgMg@05ooooo`03o`000?lb
<S;ogMgM00Cooooo00KoEEEEogMgMoooooooooooogMgMomEEED3ooooo`03o`000?lb<S;ogMgM00Co
oooo00?o0000ooooooooool00oooool01Ol0003oQhN7oooooonYZJWo000000?ooooo00?o0000oooo
ooooool0ooooool@ooooo`008?ooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo0_l00000
1?nYZJWo8B4Qo`000?lQ8B42ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool01_o^k^koEEEE
o`000?l0003oEEEEonk^kP;ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42ooooo`03o`000?oooooo
oooo00;ooooo00?o410@o`000?mgMgL00_l000001OnHV9Sooooooooooooooooo00000?oooooo4_oo
ool004Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3ooooooa3ooooo0018oooo
o`;o00002oooool2o`000?oooooo4_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.586479, -5.74836, \
0.0108422, 0.0196649}}]
}, Open  ]],

Cell["\<\
We can again construct an interpolation function of the solution, \
taken  from the 200th iteration:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Phi]sol\  = \ 
      Interpolation[
        Flatten[Table[{j\ \[CapitalDelta]x, 
              k\ \[CapitalDelta]y, \[Phi][j, k, 200]}, {j, 0, M\_x}, {k, 0, 
              M\_y}], 1]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.114"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.`, 1.5`}, {0.`, 2.`}}, "<>"]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "A contour plot of the solution is shown in Cell ",
  ButtonBox["6.115",
    ButtonData:>"Cell 6.115",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ContourPlot[\[Phi]sol[x, y], {x, 0, 1.5}, {y, 0, 2}, 
        FrameLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotLabel \[Rule] "\<Potential inside a\ncharge-filled irregular \
box\>", AspectRatio \[Rule] 4/3, PlotPoints \[Rule] 30];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.115"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.641026 0.025641 0.641026 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.14744 -0.0125 -9 -9 ]
[.14744 -0.0125 9 0 ]
[.27564 -0.0125 -9 -9 ]
[.27564 -0.0125 9 0 ]
[.40385 -0.0125 -9 -9 ]
[.40385 -0.0125 9 0 ]
[.53205 -0.0125 -9 -9 ]
[.53205 -0.0125 9 0 ]
[.66026 -0.0125 -3 -9 ]
[.66026 -0.0125 3 0 ]
[.78846 -0.0125 -9 -9 ]
[.78846 -0.0125 9 0 ]
[.91667 -0.0125 -9 -9 ]
[.91667 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .02564 -6 -4.5 ]
[-0.0125 .02564 0 4.5 ]
[-0.0125 .34615 -18 -4.5 ]
[-0.0125 .34615 0 4.5 ]
[-0.0125 .66667 -6 -4.5 ]
[-0.0125 .66667 0 4.5 ]
[-0.0125 .98718 -18 -4.5 ]
[-0.0125 .98718 0 4.5 ]
[-0.0125 1.30769 -6 -4.5 ]
[-0.0125 1.30769 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .66667 -30 -5 ]
[-0.01875 .66667 -18 5 ]
[ 0 1.33333 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.34583 -83 0 ]
[.5 1.34583 83 24.5 ]
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.14744 0 m
.14744 .00625 L
s
[(0.2)] .14744 -0.0125 0 1 Mshowa
.27564 0 m
.27564 .00625 L
s
[(0.4)] .27564 -0.0125 0 1 Mshowa
.40385 0 m
.40385 .00625 L
s
[(0.6)] .40385 -0.0125 0 1 Mshowa
.53205 0 m
.53205 .00625 L
s
[(0.8)] .53205 -0.0125 0 1 Mshowa
.66026 0 m
.66026 .00625 L
s
[(1)] .66026 -0.0125 0 1 Mshowa
.78846 0 m
.78846 .00625 L
s
[(1.2)] .78846 -0.0125 0 1 Mshowa
.91667 0 m
.91667 .00625 L
s
[(1.4)] .91667 -0.0125 0 1 Mshowa
.125 Mabswid
.05128 0 m
.05128 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.17949 0 m
.17949 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.33974 0 m
.33974 .00375 L
s
.37179 0 m
.37179 .00375 L
s
.4359 0 m
.4359 .00375 L
s
.46795 0 m
.46795 .00375 L
s
.5 0 m
.5 .00375 L
s
.5641 0 m
.5641 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.62821 0 m
.62821 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.72436 0 m
.72436 .00375 L
s
.75641 0 m
.75641 .00375 L
s
.82051 0 m
.82051 .00375 L
s
.85256 0 m
.85256 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.94872 0 m
.94872 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02564 m
.00625 .02564 L
s
[(0)] -0.0125 .02564 1 0 Mshowa
0 .34615 m
.00625 .34615 L
s
[(0.5)] -0.0125 .34615 1 0 Mshowa
0 .66667 m
.00625 .66667 L
s
[(1)] -0.0125 .66667 1 0 Mshowa
0 .98718 m
.00625 .98718 L
s
[(1.5)] -0.0125 .98718 1 0 Mshowa
0 1.30769 m
.00625 1.30769 L
s
[(2)] -0.0125 1.30769 1 0 Mshowa
.125 Mabswid
0 .08974 m
.00375 .08974 L
s
0 .15385 m
.00375 .15385 L
s
0 .21795 m
.00375 .21795 L
s
0 .28205 m
.00375 .28205 L
s
0 .41026 m
.00375 .41026 L
s
0 .47436 m
.00375 .47436 L
s
0 .53846 m
.00375 .53846 L
s
0 .60256 m
.00375 .60256 L
s
0 .73077 m
.00375 .73077 L
s
0 .79487 m
.00375 .79487 L
s
0 .85897 m
.00375 .85897 L
s
0 .92308 m
.00375 .92308 L
s
0 1.05128 m
.00375 1.05128 L
s
0 1.11538 m
.00375 1.11538 L
s
0 1.17949 m
.00375 1.17949 L
s
0 1.24359 m
.00375 1.24359 L
s
.25 Mabswid
0 0 m
0 1.33333 L
s
gsave
-0.01875 .66667 -90 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10 translate
90 rotate
-66 -10 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01923 1.32708 m
.01923 1.33333 L
s
.14744 1.32708 m
.14744 1.33333 L
s
.27564 1.32708 m
.27564 1.33333 L
s
.40385 1.32708 m
.40385 1.33333 L
s
.53205 1.32708 m
.53205 1.33333 L
s
.66026 1.32708 m
.66026 1.33333 L
s
.78846 1.32708 m
.78846 1.33333 L
s
.91667 1.32708 m
.91667 1.33333 L
s
.125 Mabswid
.05128 1.32958 m
.05128 1.33333 L
s
.08333 1.32958 m
.08333 1.33333 L
s
.11538 1.32958 m
.11538 1.33333 L
s
.17949 1.32958 m
.17949 1.33333 L
s
.21154 1.32958 m
.21154 1.33333 L
s
.24359 1.32958 m
.24359 1.33333 L
s
.30769 1.32958 m
.30769 1.33333 L
s
.33974 1.32958 m
.33974 1.33333 L
s
.37179 1.32958 m
.37179 1.33333 L
s
.4359 1.32958 m
.4359 1.33333 L
s
.46795 1.32958 m
.46795 1.33333 L
s
.5 1.32958 m
.5 1.33333 L
s
.5641 1.32958 m
.5641 1.33333 L
s
.59615 1.32958 m
.59615 1.33333 L
s
.62821 1.32958 m
.62821 1.33333 L
s
.69231 1.32958 m
.69231 1.33333 L
s
.72436 1.32958 m
.72436 1.33333 L
s
.75641 1.32958 m
.75641 1.33333 L
s
.82051 1.32958 m
.82051 1.33333 L
s
.85256 1.32958 m
.85256 1.33333 L
s
.88462 1.32958 m
.88462 1.33333 L
s
.94872 1.32958 m
.94872 1.33333 L
s
.98077 1.32958 m
.98077 1.33333 L
s
.25 Mabswid
0 1.33333 m
1 1.33333 L
s
.99375 .02564 m
1 .02564 L
s
.99375 .34615 m
1 .34615 L
s
.99375 .66667 m
1 .66667 L
s
.99375 .98718 m
1 .98718 L
s
.99375 1.30769 m
1 1.30769 L
s
.125 Mabswid
.99625 .08974 m
1 .08974 L
s
.99625 .15385 m
1 .15385 L
s
.99625 .21795 m
1 .21795 L
s
.99625 .28205 m
1 .28205 L
s
.99625 .41026 m
1 .41026 L
s
.99625 .47436 m
1 .47436 L
s
.99625 .53846 m
1 .53846 L
s
.99625 .60256 m
1 .60256 L
s
.99625 .73077 m
1 .73077 L
s
.99625 .79487 m
1 .79487 L
s
.99625 .85897 m
1 .85897 L
s
.99625 .92308 m
1 .92308 L
s
.99625 1.05128 m
1 1.05128 L
s
.99625 1.11538 m
1 1.11538 L
s
.99625 1.17949 m
1 1.17949 L
s
.99625 1.24359 m
1 1.24359 L
s
.25 Mabswid
1 0 m
1 1.33333 L
s
gsave
.5 1.34583 -144 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Potential) show
123.000 13.000 moveto
(inside) show
165.000 13.000 moveto
(a) show
63.000 25.500 moveto
(charge) show
99.000 25.500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
105.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(filled) show
147.000 25.500 moveto
(irregular) show
207.000 25.500 moveto
(box) show
225.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
1 g
.01923 1.30769 m
.98077 1.30769 L
.98077 .02564 L
.01923 .02564 L
F
0 g
.5 Mabswid
.9 g
.54973 .03111 m
.58289 .029 L
.61605 .02839 L
.6492 .02815 L
.68236 .02806 L
.71552 .02806 L
.74867 .02812 L
.78183 .02825 L
.81499 .02848 L
.84814 .02885 L
.8813 .0295 L
.91446 .03086 L
.94761 .03502 L
.97444 .06985 L
.97699 .11406 L
.97775 .15827 L
.97809 .20248 L
.97821 .24668 L
.97812 .29089 L
.97747 .3351 L
.95697 .37931 L
.94761 .38954 L
.92439 .42352 L
.91446 .44423 L
.88869 .46773 L
.8813 .47804 L
.86392 .51194 L
.84814 .52924 L
.82872 .55615 L
.81499 .5773 L
.78966 .60035 L
.78183 .61218 L
.76406 .64456 L
.74867 .66053 L
.73013 .68877 L
.71552 .70961 L
.6911 .73298 L
.68236 .7475 L
.66289 .77719 L
.6492 .79115 L
.63116 .8214 L
.61605 .84157 L
.59326 .86561 L
.58289 .88349 L
.56034 .90981 L
.54973 .92129 L
.5317 .95402 L
.51658 .97208 L
.49979 .99823 L
.50024 1.04244 L
.50134 1.08665 L
.50074 1.13086 L
.49984 1.17507 L
.49816 1.21927 L
.49332 1.26348 L
.48342 1.28666 L
.45027 1.30157 L
.41711 1.30351 L
.38395 1.30428 L
.3508 1.30467 L
.31764 1.30487 L
.28448 1.30495 L
.25133 1.30495 L
.21817 1.30487 L
.18501 1.30468 L
.15186 1.30433 L
.1187 1.30369 L
.08554 1.30232 L
.05239 1.29808 L
.02584 1.26348 L
.02318 1.21927 L
.02238 1.17507 L
.02202 1.13086 L
.02187 1.08665 L
.02192 1.04244 L
.02257 .99823 L
.04612 .95402 L
.05239 .94715 L
.072 .90981 L
.07124 .86561 L
.07105 .8214 L
.07441 .77719 L
.08554 .75614 L
.11696 .73298 L
.1187 .73015 L
.14092 .68877 L
.15186 .67742 L
.16585 .64456 L
.16439 .60035 L
.18501 .56213 L
.18961 .55615 L
.21817 .52377 L
.225 .51194 L
.25133 .48314 L
.26058 .46773 L
.26247 .42352 L
.26979 .37931 L
.28448 .36235 L
.31387 .3351 L
.31764 .32846 L
.34952 .29089 L
.3508 .28946 L
.37411 .24668 L
.38395 .23455 L
.41179 .20248 L
.41711 .19351 L
.45027 .15987 L
.4516 .15827 L
.47442 .11406 L
.48342 .10531 L
.51658 .0725 L
.51949 .06985 L
F
0 g
.54973 .03111 m
.58289 .029 L
.61605 .02839 L
.6492 .02815 L
.68236 .02806 L
.71552 .02806 L
.74867 .02812 L
.78183 .02825 L
.81499 .02848 L
.84814 .02885 L
.8813 .0295 L
.91446 .03086 L
.94761 .03502 L
.97444 .06985 L
.97699 .11406 L
.97775 .15827 L
.97809 .20248 L
.97821 .24668 L
.97812 .29089 L
.97747 .3351 L
.95697 .37931 L
.94761 .38954 L
.92439 .42352 L
.91446 .44423 L
.88869 .46773 L
.8813 .47804 L
.86392 .51194 L
.84814 .52924 L
.82872 .55615 L
.81499 .5773 L
.78966 .60035 L
.78183 .61218 L
.76406 .64456 L
.74867 .66053 L
.73013 .68877 L
.71552 .70961 L
.6911 .73298 L
.68236 .7475 L
.66289 .77719 L
.6492 .79115 L
.63116 .8214 L
.61605 .84157 L
.59326 .86561 L
.58289 .88349 L
.56034 .90981 L
.54973 .92129 L
.5317 .95402 L
.51658 .97208 L
.49979 .99823 L
.50024 1.04244 L
Mistroke
.50134 1.08665 L
.50074 1.13086 L
.49984 1.17507 L
.49816 1.21927 L
.49332 1.26348 L
.48342 1.28666 L
.45027 1.30157 L
.41711 1.30351 L
.38395 1.30428 L
.3508 1.30467 L
.31764 1.30487 L
.28448 1.30495 L
.25133 1.30495 L
.21817 1.30487 L
.18501 1.30468 L
.15186 1.30433 L
.1187 1.30369 L
.08554 1.30232 L
.05239 1.29808 L
.02584 1.26348 L
.02318 1.21927 L
.02238 1.17507 L
.02202 1.13086 L
.02187 1.08665 L
.02192 1.04244 L
.02257 .99823 L
.04612 .95402 L
.05239 .94715 L
.072 .90981 L
.07124 .86561 L
.07105 .8214 L
.07441 .77719 L
.08554 .75614 L
.11696 .73298 L
.1187 .73015 L
.14092 .68877 L
.15186 .67742 L
.16585 .64456 L
.16439 .60035 L
.18501 .56213 L
.18961 .55615 L
.21817 .52377 L
.225 .51194 L
.25133 .48314 L
.26058 .46773 L
.26247 .42352 L
.26979 .37931 L
.28448 .36235 L
.31387 .3351 L
.31764 .32846 L
Mistroke
.34952 .29089 L
.3508 .28946 L
.37411 .24668 L
.38395 .23455 L
.41179 .20248 L
.41711 .19351 L
.45027 .15987 L
.4516 .15827 L
.47442 .11406 L
.48342 .10531 L
.51658 .0725 L
.51949 .06985 L
.54973 .03111 L
Mfstroke
.8 g
.54973 .06713 m
.58289 .05373 L
.61605 .04889 L
.6492 .04683 L
.68236 .04599 L
.71552 .04588 L
.74867 .04633 L
.78183 .04734 L
.81499 .04908 L
.84814 .05197 L
.8813 .0571 L
.91446 .06803 L
.91773 .06985 L
.94732 .11406 L
.94761 .11509 L
.95467 .15827 L
.95779 .20248 L
.9589 .24668 L
.95816 .29089 L
.95356 .3351 L
.94761 .3602 L
.92572 .37931 L
.91446 .39425 L
.89686 .42352 L
.8813 .43007 L
.86418 .46773 L
.84814 .48998 L
.82942 .51194 L
.81499 .53401 L
.79975 .55615 L
.78183 .57933 L
.75577 .60035 L
.74867 .62256 L
.72922 .64456 L
.71552 .6692 L
.70144 .68877 L
.68236 .71254 L
.66012 .73298 L
.6492 .75203 L
.62665 .77719 L
.61605 .80206 L
.60154 .8214 L
.58289 .83504 L
.5637 .86561 L
.54973 .8796 L
.53415 .90981 L
.51658 .93555 L
.50167 .95402 L
.48342 .98768 L
.479 .99823 L
.47668 1.04244 L
.47503 1.08665 L
.47232 1.13086 L
.46851 1.17507 L
.46208 1.21927 L
.45027 1.25178 L
.43614 1.26348 L
.41711 1.27158 L
.38395 1.27866 L
.3508 1.2821 L
.31764 1.2839 L
.28448 1.2847 L
.25133 1.28476 L
.21817 1.28412 L
.18501 1.28264 L
.15186 1.2799 L
.1187 1.27478 L
.08554 1.26349 L
.08554 1.26348 L
.05401 1.21927 L
.05239 1.21325 L
.04634 1.17507 L
.04302 1.13086 L
.04164 1.08665 L
.04201 1.04244 L
.04615 .99823 L
.05239 .98566 L
.07259 .95402 L
.08554 .92292 L
.08886 .90981 L
.09028 .86561 L
.09308 .8214 L
.10912 .77719 L
.1187 .76348 L
.13882 .73298 L
.15186 .71565 L
.16883 .68877 L
.18501 .6475 L
.18576 .64456 L
.19243 .60035 L
.21817 .56459 L
.22625 .55615 L
.25133 .51318 L
.25237 .51194 L
.2785 .46773 L
.2843 .42352 L
.28448 .42266 L
.31056 .37931 L
.31764 .36607 L
.34776 .3351 L
.3508 .3186 L
.37296 .29089 L
.38395 .27818 L
.40858 .24668 L
.41711 .23211 L
.44411 .20248 L
.45027 .18803 L
.47465 .15827 L
.48342 .14748 L
.51237 .11406 L
.51658 .10792 L
.54725 .06985 L
F
0 g
.54973 .06713 m
.58289 .05373 L
.61605 .04889 L
.6492 .04683 L
.68236 .04599 L
.71552 .04588 L
.74867 .04633 L
.78183 .04734 L
.81499 .04908 L
.84814 .05197 L
.8813 .0571 L
.91446 .06803 L
.91773 .06985 L
.94732 .11406 L
.94761 .11509 L
.95467 .15827 L
.95779 .20248 L
.9589 .24668 L
.95816 .29089 L
.95356 .3351 L
.94761 .3602 L
.92572 .37931 L
.91446 .39425 L
.89686 .42352 L
.8813 .43007 L
.86418 .46773 L
.84814 .48998 L
.82942 .51194 L
.81499 .53401 L
.79975 .55615 L
.78183 .57933 L
.75577 .60035 L
.74867 .62256 L
.72922 .64456 L
.71552 .6692 L
.70144 .68877 L
.68236 .71254 L
.66012 .73298 L
.6492 .75203 L
.62665 .77719 L
.61605 .80206 L
.60154 .8214 L
.58289 .83504 L
.5637 .86561 L
.54973 .8796 L
.53415 .90981 L
.51658 .93555 L
.50167 .95402 L
.48342 .98768 L
.479 .99823 L
Mistroke
.47668 1.04244 L
.47503 1.08665 L
.47232 1.13086 L
.46851 1.17507 L
.46208 1.21927 L
.45027 1.25178 L
.43614 1.26348 L
.41711 1.27158 L
.38395 1.27866 L
.3508 1.2821 L
.31764 1.2839 L
.28448 1.2847 L
.25133 1.28476 L
.21817 1.28412 L
.18501 1.28264 L
.15186 1.2799 L
.1187 1.27478 L
.08554 1.26349 L
.08554 1.26348 L
.05401 1.21927 L
.05239 1.21325 L
.04634 1.17507 L
.04302 1.13086 L
.04164 1.08665 L
.04201 1.04244 L
.04615 .99823 L
.05239 .98566 L
.07259 .95402 L
.08554 .92292 L
.08886 .90981 L
.09028 .86561 L
.09308 .8214 L
.10912 .77719 L
.1187 .76348 L
.13882 .73298 L
.15186 .71565 L
.16883 .68877 L
.18501 .6475 L
.18576 .64456 L
.19243 .60035 L
.21817 .56459 L
.22625 .55615 L
.25133 .51318 L
.25237 .51194 L
.2785 .46773 L
.2843 .42352 L
.28448 .42266 L
.31056 .37931 L
.31764 .36607 L
.34776 .3351 L
Mistroke
.3508 .3186 L
.37296 .29089 L
.38395 .27818 L
.40858 .24668 L
.41711 .23211 L
.44411 .20248 L
.45027 .18803 L
.47465 .15827 L
.48342 .14748 L
.51237 .11406 L
.51658 .10792 L
.54725 .06985 L
.54973 .06713 L
Mfstroke
.7 g
.6492 .06696 m
.68236 .06525 L
.71552 .06498 L
.74867 .06585 L
.78183 .06791 L
.80231 .06985 L
.81499 .07153 L
.84814 .07784 L
.8813 .09013 L
.90897 .11406 L
.91446 .12221 L
.92775 .15827 L
.93498 .20248 L
.93756 .24668 L
.93643 .29089 L
.92917 .3351 L
.91446 .37127 L
.90394 .37931 L
.8813 .41837 L
.87711 .42352 L
.84814 .46559 L
.84671 .46773 L
.81499 .50954 L
.8132 .51194 L
.78234 .55615 L
.78183 .55692 L
.74883 .60035 L
.74867 .60238 L
.71557 .64456 L
.71552 .6447 L
.68315 .68877 L
.68236 .6899 L
.65009 .73298 L
.6492 .7349 L
.61607 .77719 L
.61605 .77727 L
.58289 .82117 L
.58271 .8214 L
.55086 .86561 L
.54973 .86649 L
.51709 .90981 L
.51658 .9105 L
.48473 .95402 L
.48342 .95679 L
.46497 .99823 L
.46143 1.04244 L
.45854 1.08665 L
.45479 1.13086 L
.45027 1.16451 L
.44769 1.17507 L
.42736 1.21927 L
.41711 1.22994 L
.38395 1.24833 L
.3508 1.25647 L
.31764 1.26055 L
.28448 1.26237 L
.25133 1.26256 L
.21817 1.26123 L
.18501 1.25804 L
.15186 1.25184 L
.1187 1.23907 L
.09522 1.21927 L
.08554 1.20453 L
.07477 1.17507 L
.06681 1.13086 L
.06356 1.08665 L
.0638 1.04244 L
.06949 .99823 L
.08554 .9672 L
.09138 .95402 L
.10324 .90981 L
.1063 .86561 L
.11113 .8214 L
.1187 .79134 L
.13057 .77719 L
.15186 .74002 L
.15635 .73298 L
.18501 .69165 L
.18643 .68877 L
.20108 .64456 L
.21176 .60035 L
.21817 .58848 L
.24426 .55615 L
.25133 .53934 L
.27178 .51194 L
.28448 .48836 L
.29295 .46773 L
.30198 .42352 L
.31764 .39266 L
.32856 .37931 L
.3508 .34329 L
.35699 .3351 L
.38395 .30123 L
.391 .29089 L
.41711 .25773 L
.42587 .24668 L
.45027 .21213 L
.4584 .20248 L
.48342 .17356 L
.49449 .15827 L
.51658 .13466 L
.53486 .11406 L
.54973 .09876 L
.58289 .07952 L
.61605 .07093 L
.62136 .06985 L
F
0 g
.6492 .06696 m
.68236 .06525 L
.71552 .06498 L
.74867 .06585 L
.78183 .06791 L
.80231 .06985 L
.81499 .07153 L
.84814 .07784 L
.8813 .09013 L
.90897 .11406 L
.91446 .12221 L
.92775 .15827 L
.93498 .20248 L
.93756 .24668 L
.93643 .29089 L
.92917 .3351 L
.91446 .37127 L
.90394 .37931 L
.8813 .41837 L
.87711 .42352 L
.84814 .46559 L
.84671 .46773 L
.81499 .50954 L
.8132 .51194 L
.78234 .55615 L
.78183 .55692 L
.74883 .60035 L
.74867 .60238 L
.71557 .64456 L
.71552 .6447 L
.68315 .68877 L
.68236 .6899 L
.65009 .73298 L
.6492 .7349 L
.61607 .77719 L
.61605 .77727 L
.58289 .82117 L
.58271 .8214 L
.55086 .86561 L
.54973 .86649 L
.51709 .90981 L
.51658 .9105 L
.48473 .95402 L
.48342 .95679 L
.46497 .99823 L
.46143 1.04244 L
.45854 1.08665 L
.45479 1.13086 L
.45027 1.16451 L
.44769 1.17507 L
Mistroke
.42736 1.21927 L
.41711 1.22994 L
.38395 1.24833 L
.3508 1.25647 L
.31764 1.26055 L
.28448 1.26237 L
.25133 1.26256 L
.21817 1.26123 L
.18501 1.25804 L
.15186 1.25184 L
.1187 1.23907 L
.09522 1.21927 L
.08554 1.20453 L
.07477 1.17507 L
.06681 1.13086 L
.06356 1.08665 L
.0638 1.04244 L
.06949 .99823 L
.08554 .9672 L
.09138 .95402 L
.10324 .90981 L
.1063 .86561 L
.11113 .8214 L
.1187 .79134 L
.13057 .77719 L
.15186 .74002 L
.15635 .73298 L
.18501 .69165 L
.18643 .68877 L
.20108 .64456 L
.21176 .60035 L
.21817 .58848 L
.24426 .55615 L
.25133 .53934 L
.27178 .51194 L
.28448 .48836 L
.29295 .46773 L
.30198 .42352 L
.31764 .39266 L
.32856 .37931 L
.3508 .34329 L
.35699 .3351 L
.38395 .30123 L
.391 .29089 L
.41711 .25773 L
.42587 .24668 L
.45027 .21213 L
.4584 .20248 L
.48342 .17356 L
.49449 .15827 L
Mistroke
.51658 .13466 L
.53486 .11406 L
.54973 .09876 L
.58289 .07952 L
.61605 .07093 L
.62136 .06985 L
.6492 .06696 L
Mfstroke
.6 g
.58289 .10666 m
.61605 .09491 L
.6492 .08908 L
.68236 .08653 L
.71552 .08621 L
.74867 .08778 L
.78183 .09143 L
.81499 .09807 L
.84814 .11033 L
.85495 .11406 L
.8813 .13593 L
.89494 .15827 L
.90859 .20248 L
.91353 .24668 L
.91253 .29089 L
.90397 .3351 L
.88357 .37931 L
.8813 .38418 L
.85607 .42352 L
.84814 .43604 L
.82762 .46773 L
.81499 .48493 L
.79556 .51194 L
.78183 .53269 L
.76373 .55615 L
.74867 .57775 L
.73276 .60035 L
.71552 .62149 L
.69855 .64456 L
.68236 .667 L
.66512 .68877 L
.6492 .71163 L
.63336 .73298 L
.61605 .75355 L
.59875 .77719 L
.58289 .79801 L
.56463 .8214 L
.54973 .84313 L
.53255 .86561 L
.51658 .88554 L
.49989 .90981 L
.48342 .93183 L
.46948 .95402 L
.45352 .99823 L
.45027 1.02408 L
.44746 1.04244 L
.44056 1.08665 L
.43125 1.13086 L
.41711 1.16931 L
.41419 1.17507 L
.38395 1.20934 L
.36688 1.21927 L
.3508 1.22529 L
.31764 1.23293 L
.28448 1.23626 L
.25133 1.23659 L
.21817 1.23412 L
.18501 1.22802 L
.15908 1.21927 L
.15186 1.21567 L
.1187 1.18769 L
.11079 1.17507 L
.09503 1.13086 L
.08871 1.08665 L
.08797 1.04244 L
.09339 .99823 L
.10874 .95402 L
.11785 .90981 L
.1187 .90229 L
.12298 .86561 L
.1311 .8214 L
.15083 .77719 L
.15186 .77499 L
.17489 .73298 L
.18501 .71842 L
.20152 .68877 L
.21478 .64456 L
.21817 .63039 L
.23062 .60035 L
.25133 .56616 L
.25778 .55615 L
.28448 .516 L
.28695 .51194 L
.30633 .46773 L
.31764 .42559 L
.31854 .42352 L
.34603 .37931 L
.3508 .37092 L
.3766 .3351 L
.38395 .32585 L
.40875 .29089 L
.41711 .28046 L
.44376 .24668 L
.45027 .23757 L
.48013 .20248 L
.48342 .19888 L
.51658 .1594 L
.51765 .15827 L
.54973 .12847 L
.56899 .11406 L
F
0 g
.58289 .10666 m
.61605 .09491 L
.6492 .08908 L
.68236 .08653 L
.71552 .08621 L
.74867 .08778 L
.78183 .09143 L
.81499 .09807 L
.84814 .11033 L
.85495 .11406 L
.8813 .13593 L
.89494 .15827 L
.90859 .20248 L
.91353 .24668 L
.91253 .29089 L
.90397 .3351 L
.88357 .37931 L
.8813 .38418 L
.85607 .42352 L
.84814 .43604 L
.82762 .46773 L
.81499 .48493 L
.79556 .51194 L
.78183 .53269 L
.76373 .55615 L
.74867 .57775 L
.73276 .60035 L
.71552 .62149 L
.69855 .64456 L
.68236 .667 L
.66512 .68877 L
.6492 .71163 L
.63336 .73298 L
.61605 .75355 L
.59875 .77719 L
.58289 .79801 L
.56463 .8214 L
.54973 .84313 L
.53255 .86561 L
.51658 .88554 L
.49989 .90981 L
.48342 .93183 L
.46948 .95402 L
.45352 .99823 L
.45027 1.02408 L
.44746 1.04244 L
.44056 1.08665 L
.43125 1.13086 L
.41711 1.16931 L
.41419 1.17507 L
Mistroke
.38395 1.20934 L
.36688 1.21927 L
.3508 1.22529 L
.31764 1.23293 L
.28448 1.23626 L
.25133 1.23659 L
.21817 1.23412 L
.18501 1.22802 L
.15908 1.21927 L
.15186 1.21567 L
.1187 1.18769 L
.11079 1.17507 L
.09503 1.13086 L
.08871 1.08665 L
.08797 1.04244 L
.09339 .99823 L
.10874 .95402 L
.11785 .90981 L
.1187 .90229 L
.12298 .86561 L
.1311 .8214 L
.15083 .77719 L
.15186 .77499 L
.17489 .73298 L
.18501 .71842 L
.20152 .68877 L
.21478 .64456 L
.21817 .63039 L
.23062 .60035 L
.25133 .56616 L
.25778 .55615 L
.28448 .516 L
.28695 .51194 L
.30633 .46773 L
.31764 .42559 L
.31854 .42352 L
.34603 .37931 L
.3508 .37092 L
.3766 .3351 L
.38395 .32585 L
.40875 .29089 L
.41711 .28046 L
.44376 .24668 L
.45027 .23757 L
.48013 .20248 L
.48342 .19888 L
.51658 .1594 L
.51765 .15827 L
.54973 .12847 L
.56899 .11406 L
Mistroke
.58289 .10666 L
Mfstroke
.5 g
.6492 .11376 m
.68236 .11051 L
.71552 .11042 L
.74867 .1132 L
.7558 .11406 L
.78183 .11921 L
.81499 .13035 L
.84814 .15297 L
.85305 .15827 L
.8774 .20248 L
.8813 .21649 L
.88612 .24668 L
.88609 .29089 L
.8813 .32123 L
.87755 .3351 L
.85932 .37931 L
.84814 .40074 L
.83397 .42352 L
.81499 .45518 L
.80645 .46773 L
.78183 .50426 L
.77652 .51194 L
.74867 .54999 L
.74425 .55615 L
.71552 .59682 L
.71286 .60035 L
.68236 .6417 L
.68024 .64456 L
.6492 .68467 L
.64616 .68877 L
.61605 .72887 L
.61284 .73298 L
.58289 .77276 L
.5795 .77719 L
.54973 .81545 L
.54532 .8214 L
.51658 .85896 L
.51159 .86561 L
.48342 .90605 L
.48087 .90981 L
.45314 .95402 L
.45027 .9585 L
.43632 .99823 L
.42592 1.04244 L
.41711 1.07867 L
.41504 1.08665 L
.39968 1.13086 L
.38395 1.15703 L
.36741 1.17507 L
.3508 1.18622 L
.31764 1.19937 L
.28448 1.20488 L
.25133 1.20534 L
.21817 1.20105 L
.18501 1.19017 L
.16098 1.17507 L
.15186 1.16646 L
.12991 1.13086 L
.1187 1.08917 L
.1183 1.08665 L
.11524 1.04244 L
.1187 .99954 L
.11891 .99823 L
.129 .95402 L
.13782 .90981 L
.14453 .86561 L
.15186 .83128 L
.15459 .8214 L
.1726 .77719 L
.18501 .75109 L
.19492 .73298 L
.21722 .68877 L
.21817 .68591 L
.23306 .64456 L
.25133 .60127 L
.25176 .60035 L
.27659 .55615 L
.28448 .54349 L
.30308 .51194 L
.31764 .47802 L
.32172 .46773 L
.33924 .42352 L
.3508 .40317 L
.36574 .37931 L
.38395 .35304 L
.39713 .3351 L
.41711 .30704 L
.42963 .29089 L
.45027 .26528 L
.46522 .24668 L
.48342 .22595 L
.50419 .20248 L
.51658 .18885 L
.54972 .15827 L
.54973 .15825 L
.58289 .13538 L
.61605 .12124 L
.64688 .11406 L
F
0 g
.6492 .11376 m
.68236 .11051 L
.71552 .11042 L
.74867 .1132 L
.7558 .11406 L
.78183 .11921 L
.81499 .13035 L
.84814 .15297 L
.85305 .15827 L
.8774 .20248 L
.8813 .21649 L
.88612 .24668 L
.88609 .29089 L
.8813 .32123 L
.87755 .3351 L
.85932 .37931 L
.84814 .40074 L
.83397 .42352 L
.81499 .45518 L
.80645 .46773 L
.78183 .50426 L
.77652 .51194 L
.74867 .54999 L
.74425 .55615 L
.71552 .59682 L
.71286 .60035 L
.68236 .6417 L
.68024 .64456 L
.6492 .68467 L
.64616 .68877 L
.61605 .72887 L
.61284 .73298 L
.58289 .77276 L
.5795 .77719 L
.54973 .81545 L
.54532 .8214 L
.51658 .85896 L
.51159 .86561 L
.48342 .90605 L
.48087 .90981 L
.45314 .95402 L
.45027 .9585 L
.43632 .99823 L
.42592 1.04244 L
.41711 1.07867 L
.41504 1.08665 L
.39968 1.13086 L
.38395 1.15703 L
.36741 1.17507 L
.3508 1.18622 L
Mistroke
.31764 1.19937 L
.28448 1.20488 L
.25133 1.20534 L
.21817 1.20105 L
.18501 1.19017 L
.16098 1.17507 L
.15186 1.16646 L
.12991 1.13086 L
.1187 1.08917 L
.1183 1.08665 L
.11524 1.04244 L
.1187 .99954 L
.11891 .99823 L
.129 .95402 L
.13782 .90981 L
.14453 .86561 L
.15186 .83128 L
.15459 .8214 L
.1726 .77719 L
.18501 .75109 L
.19492 .73298 L
.21722 .68877 L
.21817 .68591 L
.23306 .64456 L
.25133 .60127 L
.25176 .60035 L
.27659 .55615 L
.28448 .54349 L
.30308 .51194 L
.31764 .47802 L
.32172 .46773 L
.33924 .42352 L
.3508 .40317 L
.36574 .37931 L
.38395 .35304 L
.39713 .3351 L
.41711 .30704 L
.42963 .29089 L
.45027 .26528 L
.46522 .24668 L
.48342 .22595 L
.50419 .20248 L
.51658 .18885 L
.54972 .15827 L
.54973 .15825 L
.58289 .13538 L
.61605 .12124 L
.64688 .11406 L
.6492 .11376 L
Mfstroke
.4 g
.61605 .15036 m
.6492 .14145 L
.68236 .1377 L
.71552 .13815 L
.74867 .14281 L
.78183 .15306 L
.79304 .15827 L
.81499 .17215 L
.83918 .20248 L
.84814 .22261 L
.85439 .24668 L
.85677 .29089 L
.84929 .3351 L
.84814 .34064 L
.83258 .37931 L
.81499 .41477 L
.80955 .42352 L
.78243 .46773 L
.78183 .46867 L
.75332 .51194 L
.74867 .51855 L
.72231 .55615 L
.71552 .56593 L
.69026 .60035 L
.68236 .61117 L
.65755 .64456 L
.6492 .65531 L
.62397 .68877 L
.61605 .69924 L
.58985 .73298 L
.58289 .74215 L
.55574 .77719 L
.54973 .78478 L
.52176 .8214 L
.51658 .82807 L
.48829 .86561 L
.48342 .87249 L
.45785 .90981 L
.45027 .92092 L
.43206 .95402 L
.41711 .98714 L
.41338 .99823 L
.39959 1.04244 L
.38395 1.08398 L
.38287 1.08665 L
.35488 1.13086 L
.3508 1.13481 L
.31764 1.15682 L
.28448 1.16566 L
.25133 1.16609 L
.21817 1.15839 L
.18501 1.13756 L
.17851 1.13086 L
.15486 1.08665 L
.15186 1.07503 L
.14706 1.04244 L
.14772 .99823 L
.15186 .96946 L
.15437 .95402 L
.16166 .90981 L
.16894 .86561 L
.17998 .8214 L
.18501 .8059 L
.19678 .77719 L
.21746 .73298 L
.21817 .73153 L
.23759 .68877 L
.25133 .65345 L
.2548 .64456 L
.27412 .60035 L
.28448 .57997 L
.29755 .55615 L
.31764 .51927 L
.32126 .51194 L
.34171 .46773 L
.3508 .44684 L
.36185 .42352 L
.38395 .38636 L
.38861 .37931 L
.41711 .33908 L
.42004 .3351 L
.45027 .29613 L
.45449 .29089 L
.48342 .25612 L
.49177 .24668 L
.51658 .22038 L
.53489 .20248 L
.54973 .18972 L
.58289 .16609 L
.59651 .15827 L
F
0 g
.61605 .15036 m
.6492 .14145 L
.68236 .1377 L
.71552 .13815 L
.74867 .14281 L
.78183 .15306 L
.79304 .15827 L
.81499 .17215 L
.83918 .20248 L
.84814 .22261 L
.85439 .24668 L
.85677 .29089 L
.84929 .3351 L
.84814 .34064 L
.83258 .37931 L
.81499 .41477 L
.80955 .42352 L
.78243 .46773 L
.78183 .46867 L
.75332 .51194 L
.74867 .51855 L
.72231 .55615 L
.71552 .56593 L
.69026 .60035 L
.68236 .61117 L
.65755 .64456 L
.6492 .65531 L
.62397 .68877 L
.61605 .69924 L
.58985 .73298 L
.58289 .74215 L
.55574 .77719 L
.54973 .78478 L
.52176 .8214 L
.51658 .82807 L
.48829 .86561 L
.48342 .87249 L
.45785 .90981 L
.45027 .92092 L
.43206 .95402 L
.41711 .98714 L
.41338 .99823 L
.39959 1.04244 L
.38395 1.08398 L
.38287 1.08665 L
.35488 1.13086 L
.3508 1.13481 L
.31764 1.15682 L
.28448 1.16566 L
.25133 1.16609 L
Mistroke
.21817 1.15839 L
.18501 1.13756 L
.17851 1.13086 L
.15486 1.08665 L
.15186 1.07503 L
.14706 1.04244 L
.14772 .99823 L
.15186 .96946 L
.15437 .95402 L
.16166 .90981 L
.16894 .86561 L
.17998 .8214 L
.18501 .8059 L
.19678 .77719 L
.21746 .73298 L
.21817 .73153 L
.23759 .68877 L
.25133 .65345 L
.2548 .64456 L
.27412 .60035 L
.28448 .57997 L
.29755 .55615 L
.31764 .51927 L
.32126 .51194 L
.34171 .46773 L
.3508 .44684 L
.36185 .42352 L
.38395 .38636 L
.38861 .37931 L
.41711 .33908 L
.42004 .3351 L
.45027 .29613 L
.45449 .29089 L
.48342 .25612 L
.49177 .24668 L
.51658 .22038 L
.53489 .20248 L
.54973 .18972 L
.58289 .16609 L
.59651 .15827 L
.61605 .15036 L
Mfstroke
.3 g
.58289 .19949 m
.61605 .18268 L
.6492 .173 L
.68236 .16935 L
.71552 .17117 L
.74867 .17923 L
.78183 .19766 L
.7874 .20248 L
.81499 .24284 L
.81597 .24668 L
.82319 .29089 L
.8181 .3351 L
.81499 .34679 L
.80338 .37931 L
.78194 .42352 L
.78183 .42373 L
.7562 .46773 L
.74867 .48 L
.72766 .51194 L
.71552 .52996 L
.6972 .55615 L
.68236 .57674 L
.66509 .60035 L
.6492 .62186 L
.63205 .64456 L
.61605 .66564 L
.59823 .68877 L
.58289 .70828 L
.56358 .73298 L
.54973 .7505 L
.52871 .77719 L
.51658 .79265 L
.49417 .8214 L
.48342 .8352 L
.46088 .86561 L
.45027 .88028 L
.43064 .90981 L
.41711 .93107 L
.405 .95402 L
.38395 .99675 L
.38338 .99823 L
.36384 1.04244 L
.3508 1.06375 L
.33546 1.08665 L
.31764 1.09932 L
.28448 1.11328 L
.25133 1.1127 L
.21817 1.09557 L
.20879 1.08665 L
.18806 1.04244 L
.18501 1.02424 L
.18306 .99823 L
.18501 .95866 L
.18542 .95402 L
.19053 .90981 L
.19749 .86561 L
.2085 .8214 L
.21817 .79212 L
.22434 .77719 L
.24288 .73298 L
.25133 .71332 L
.26157 .68877 L
.27917 .64456 L
.28448 .63195 L
.29859 .60035 L
.31764 .56278 L
.32112 .55615 L
.34343 .51194 L
.3508 .49676 L
.36454 .46773 L
.38395 .42866 L
.38674 .42352 L
.41464 .37931 L
.41711 .37574 L
.44687 .3351 L
.45027 .33075 L
.48305 .29089 L
.48342 .29046 L
.51658 .25442 L
.52421 .24668 L
.54973 .22361 L
.57802 .20248 L
F
0 g
.58289 .19949 m
.61605 .18268 L
.6492 .173 L
.68236 .16935 L
.71552 .17117 L
.74867 .17923 L
.78183 .19766 L
.7874 .20248 L
.81499 .24284 L
.81597 .24668 L
.82319 .29089 L
.8181 .3351 L
.81499 .34679 L
.80338 .37931 L
.78194 .42352 L
.78183 .42373 L
.7562 .46773 L
.74867 .48 L
.72766 .51194 L
.71552 .52996 L
.6972 .55615 L
.68236 .57674 L
.66509 .60035 L
.6492 .62186 L
.63205 .64456 L
.61605 .66564 L
.59823 .68877 L
.58289 .70828 L
.56358 .73298 L
.54973 .7505 L
.52871 .77719 L
.51658 .79265 L
.49417 .8214 L
.48342 .8352 L
.46088 .86561 L
.45027 .88028 L
.43064 .90981 L
.41711 .93107 L
.405 .95402 L
.38395 .99675 L
.38338 .99823 L
.36384 1.04244 L
.3508 1.06375 L
.33546 1.08665 L
.31764 1.09932 L
.28448 1.11328 L
.25133 1.1127 L
.21817 1.09557 L
.20879 1.08665 L
.18806 1.04244 L
Mistroke
.18501 1.02424 L
.18306 .99823 L
.18501 .95866 L
.18542 .95402 L
.19053 .90981 L
.19749 .86561 L
.2085 .8214 L
.21817 .79212 L
.22434 .77719 L
.24288 .73298 L
.25133 .71332 L
.26157 .68877 L
.27917 .64456 L
.28448 .63195 L
.29859 .60035 L
.31764 .56278 L
.32112 .55615 L
.34343 .51194 L
.3508 .49676 L
.36454 .46773 L
.38395 .42866 L
.38674 .42352 L
.41464 .37931 L
.41711 .37574 L
.44687 .3351 L
.45027 .33075 L
.48305 .29089 L
.48342 .29046 L
.51658 .25442 L
.52421 .24668 L
.54973 .22361 L
.57802 .20248 L
.58289 .19949 L
Mfstroke
.2 g
.58289 .23705 m
.61605 .2198 L
.6492 .21015 L
.68236 .20773 L
.71552 .2128 L
.74867 .22917 L
.76492 .24668 L
.78183 .2872 L
.78246 .29089 L
.78202 .3351 L
.78183 .3363 L
.77031 .37931 L
.75087 .42352 L
.74867 .4281 L
.72648 .46773 L
.71552 .48604 L
.69863 .51194 L
.68236 .53624 L
.66834 .55615 L
.6492 .58281 L
.63623 .60035 L
.61605 .62711 L
.60266 .64456 L
.58289 .66984 L
.56794 .68877 L
.54973 .7114 L
.53235 .73298 L
.51658 .75219 L
.49629 .77719 L
.48342 .79278 L
.4605 .8214 L
.45027 .83405 L
.42625 .86561 L
.41711 .8775 L
.39474 .90981 L
.38395 .92472 L
.36646 .95402 L
.3508 .97503 L
.33381 .99823 L
.31764 1.01577 L
.28448 1.03304 L
.25133 1.02164 L
.23292 .99823 L
.22706 .95402 L
.22835 .90981 L
.23343 .86561 L
.24307 .8214 L
.25133 .79149 L
.2568 .77719 L
.2731 .73298 L
.28448 .70338 L
.29019 .68877 L
.30747 .64456 L
.31764 .62029 L
.32647 .60035 L
.34786 .55615 L
.3508 .55013 L
.36933 .51194 L
.38395 .4821 L
.39114 .46773 L
.41517 .42352 L
.41711 .42032 L
.44439 .37931 L
.45027 .37121 L
.47848 .3351 L
.48342 .32921 L
.51658 .29258 L
.51818 .29089 L
.54973 .26145 L
.56816 .24668 L
F
0 g
.58289 .23705 m
.61605 .2198 L
.6492 .21015 L
.68236 .20773 L
.71552 .2128 L
.74867 .22917 L
.76492 .24668 L
.78183 .2872 L
.78246 .29089 L
.78202 .3351 L
.78183 .3363 L
.77031 .37931 L
.75087 .42352 L
.74867 .4281 L
.72648 .46773 L
.71552 .48604 L
.69863 .51194 L
.68236 .53624 L
.66834 .55615 L
.6492 .58281 L
.63623 .60035 L
.61605 .62711 L
.60266 .64456 L
.58289 .66984 L
.56794 .68877 L
.54973 .7114 L
.53235 .73298 L
.51658 .75219 L
.49629 .77719 L
.48342 .79278 L
.4605 .8214 L
.45027 .83405 L
.42625 .86561 L
.41711 .8775 L
.39474 .90981 L
.38395 .92472 L
.36646 .95402 L
.3508 .97503 L
.33381 .99823 L
.31764 1.01577 L
.28448 1.03304 L
.25133 1.02164 L
.23292 .99823 L
.22706 .95402 L
.22835 .90981 L
.23343 .86561 L
.24307 .8214 L
.25133 .79149 L
.2568 .77719 L
.2731 .73298 L
Mistroke
.28448 .70338 L
.29019 .68877 L
.30747 .64456 L
.31764 .62029 L
.32647 .60035 L
.34786 .55615 L
.3508 .55013 L
.36933 .51194 L
.38395 .4821 L
.39114 .46773 L
.41517 .42352 L
.41711 .42032 L
.44439 .37931 L
.45027 .37121 L
.47848 .3351 L
.48342 .32921 L
.51658 .29258 L
.51818 .29089 L
.54973 .26145 L
.56816 .24668 L
.58289 .23705 L
Mfstroke
.1 g
.58289 .28186 m
.61605 .26498 L
.6492 .25688 L
.68236 .25835 L
.71552 .2755 L
.72571 .29089 L
.73679 .3351 L
.73017 .37931 L
.71552 .41929 L
.71369 .42352 L
.69102 .46773 L
.68236 .48312 L
.66401 .51194 L
.6492 .53435 L
.63379 .55615 L
.61605 .58054 L
.60108 .60035 L
.58289 .62368 L
.5663 .64456 L
.54973 .66461 L
.52965 .68877 L
.51658 .70379 L
.49127 .73298 L
.48342 .74156 L
.45127 .77719 L
.45027 .77824 L
.41711 .81423 L
.41015 .8214 L
.38395 .84874 L
.36586 .86561 L
.3508 .87837 L
.31764 .89404 L
.2959 .86561 L
.28936 .8214 L
.30047 .77719 L
.31326 .73298 L
.31764 .71728 L
.3269 .68877 L
.34278 .64456 L
.3508 .62341 L
.36032 .60035 L
.38037 .55615 L
.38395 .54837 L
.4011 .51194 L
.41711 .4802 L
.42369 .46773 L
.4497 .42352 L
.45027 .42265 L
.48124 .37931 L
.48342 .37654 L
.51658 .33808 L
.51929 .3351 L
.54973 .30622 L
.56856 .29089 L
F
0 g
.58289 .28186 m
.61605 .26498 L
.6492 .25688 L
.68236 .25835 L
.71552 .2755 L
.72571 .29089 L
.73679 .3351 L
.73017 .37931 L
.71552 .41929 L
.71369 .42352 L
.69102 .46773 L
.68236 .48312 L
.66401 .51194 L
.6492 .53435 L
.63379 .55615 L
.61605 .58054 L
.60108 .60035 L
.58289 .62368 L
.5663 .64456 L
.54973 .66461 L
.52965 .68877 L
.51658 .70379 L
.49127 .73298 L
.48342 .74156 L
.45127 .77719 L
.45027 .77824 L
.41711 .81423 L
.41015 .8214 L
.38395 .84874 L
.36586 .86561 L
.3508 .87837 L
.31764 .89404 L
.2959 .86561 L
.28936 .8214 L
.30047 .77719 L
.31326 .73298 L
.31764 .71728 L
.3269 .68877 L
.34278 .64456 L
.3508 .62341 L
.36032 .60035 L
.38037 .55615 L
.38395 .54837 L
.4011 .51194 L
.41711 .4802 L
.42369 .46773 L
.4497 .42352 L
.45027 .42265 L
.48124 .37931 L
.48342 .37654 L
Mistroke
.51658 .33808 L
.51929 .3351 L
.54973 .30622 L
.56856 .29089 L
.58289 .28186 L
Mfstroke
.61605 .33015 m
.6492 .33385 L
.65102 .3351 L
.67346 .37931 L
.66327 .42352 L
.6492 .45564 L
.64379 .46773 L
.61702 .51194 L
.61605 .51348 L
.58603 .55615 L
.58289 .56028 L
.55042 .60035 L
.54973 .60113 L
.51658 .63856 L
.51002 .64456 L
.48342 .67138 L
.46142 .68877 L
.45027 .69756 L
.41711 .71259 L
.39397 .68877 L
.3927 .64456 L
.40888 .60035 L
.41711 .57891 L
.42469 .55615 L
.44533 .51194 L
.45027 .50165 L
.46825 .46773 L
.48342 .44322 L
.49699 .42352 L
.51658 .39941 L
.53491 .37931 L
.54973 .3665 L
.58289 .34195 L
.60023 .3351 L
F
.61605 .33015 m
.6492 .33385 L
.65102 .3351 L
.67346 .37931 L
.66327 .42352 L
.6492 .45564 L
.64379 .46773 L
.61702 .51194 L
.61605 .51348 L
.58603 .55615 L
.58289 .56028 L
.55042 .60035 L
.54973 .60113 L
.51658 .63856 L
.51002 .64456 L
.48342 .67138 L
.46142 .68877 L
.45027 .69756 L
.41711 .71259 L
.39397 .68877 L
.3927 .64456 L
.40888 .60035 L
.41711 .57891 L
.42469 .55615 L
.44533 .51194 L
.45027 .50165 L
.46825 .46773 L
.48342 .44322 L
.49699 .42352 L
.51658 .39941 L
.53491 .37931 L
.54973 .3665 L
.58289 .34195 L
.60023 .3351 L
.61605 .33015 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{315.062, 420.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006900023B000`400?l00000o`00003ooooooon:
ooooo`00oooooon:ooooo`00oooooon:ooooo`00oooooon:ooooo`00oooooon:ooooo`00eoooool2
o`0000;ooooo0_l0002/ooooo`00eoooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgJcooooo003H
ooooo`04omgMgOl0003o410@olc<c:gooooo003Hooooo`04onk^k_lQ8B7o410@onk^kZgooooo003H
ooooo`04ob4Q8OmgMgOoMgMgoc8b<Zgooooo003Gooooo`;o00000_ooool2o`000:cooooo003ooooo
oh[ooooo003ooooooh[ooooo003ooooooh[ooooo003ooooooh[ooooo003ooooooh[ooooo003ooooo
oh[ooooo003ooooooh[ooooo000aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00005oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool05Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`05oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`08?ooool4o`00
0003oa0@4?oooooooooo01gooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`00
01Sooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo
01Cooooo000aooooo`05ogMgMonHV9SooooooiRHV?mgMgL08?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@05oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo01Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q01Oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q02;ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A401[ooooo00?o0000ooooooooool01?ooool2ob4Q8@Oooooo00?o0000ooooooooool0
5Oooool0037ooooo00Go410@oooooooooooooooooa0@400Pooooo`05oa0@4?ooooooooooooooool@
41003?ooool00onHV9So8B4Qonk^kP0Hooooo`05oa0@4?ooooooooooooooool@41002oooool5o`00
01Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000005ooo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Rooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP0Kooooo`03
o`000?oooooooooo00[ooooo1Ol0000Fooooo`00<Oooool01Ol0003ooooooooooooooooo0000023o
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Oooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001Sooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B405oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Rooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool03?ooool00onHV9So8B4Qonk^kP0Jooooo`03o`000?oooooooooo00[ooooo00CoA4A4
omgMgOoooooo00005oooool0037ooooo00Go0000ooooooooooooooooo`00000Pooooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Fooooo`05o`000?ooooooooooooooool0
00002oooool01?oMgMgoEEEEooooool0000Hooooo`05o`000?ooooooooooooooool000002oooool0
1Ol0003oEEEEo`000?l@413oc<c<01Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<
c?l0003o0000o`000?o<c<`08_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00go
oooo00?oMgMgofIVI_ooool06Oooool00ol0003oooooooooo`0:ooooo`04omgMgOmEEEGoooooo`00
01Oooooo000aooooo`05oa0@4?ooooooooooooooool@41008?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool05Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l000006?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
6Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400Roooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00_ooooo00?oMgMgolc<c?l000005oooool0037ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@01Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000001Sooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000008_ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@400Jooooo`03o`000?oo
oooooooo00_ooooo00?ok^k^odA4A?l000005oooool0037ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Pooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<01Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo01Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@41Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT08?ooool00omEEEGoIVIVo`00000Qooooo`03
oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Hooooo`03oeEEEOmVIVKo0000
00kooooo00?oMgMgo`000?ooool05_ooool00?ooooooR_ooool00?ooooooR_ooool00?ooooooR_oo
ool00?ooooooR_ooool00?ooooooR_ooool002koooooool0001Jo`0000;ooooo000^ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool002kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01[ooooo0Ol0
0001ooooo`7ooooo000^ooooo`03o`000?oooooooooo0?ooooooE_ooool1o`00007ooooo0Oooool0
02kooooo00?o0000ooooooooool0oooooomFooooo`7o00000Oooool1ooooo`00;_ooool00ol0003o
ooooooooo`3ooooooeKooooo0Ol00001ooooo`7ooooo000Sooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oooooooooo`3ooooooeKooooo0Ol00001ooooo`7ooooo000Sooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooeKooooo0Ol00001ooooo`7o
oooo000Sooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3ooooooeKo
oooo0Ol00001ooooo`7ooooo000Sooooo`05o`000?ooooooooooooooool000001_ooool3o`000?oo
ooooE?ooool3o`0000;ooooo000Sooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`30ooooog?o00008_ooool1o`00007ooooo0Oooool002?ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03o`000?oooooooooo0;[ooooo1_l0001conKViP_o00005oooool1o`00007o
oooo0Oooool002?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;[o
oooo00?o0000onKVi_oVi^H0POoVi^H6o`00017ooooo0Ol00001ooooo`7ooooo000Sooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`2iooooo`03o`000?oVi^Koi^KV08Oo
i^KV00?o0000ooooooooool03oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0
^?ooool00ol0003oi^KVonKViP29onKViP03o`000?oooooooooo00kooooo0Ol00001ooooo`7ooooo
000^ooooo`03o`000?oooooooooo0;Oooooo00?o0000onKVi_oVi^H0RooVi^H00ol0003ooooooooo
o`0=ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`2gooooo`03o`000?oVi^Ko
i^KV01goi^KV>_l0000eonKViP03o`000?oooooooooo00cooooo0Ol00001ooooo`7ooooo000^oooo
o`03o`000?oooooooooo0;Kooooo00?o0000onKVi_oVi^H04_oVi^H<o`0003[oc<c<2ol0000ZonKV
iP03o`000?oooooooooo00cooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo0;Go
oooo00?o0000onKVi_oVi^H03?oVi^H7o`00057oc<c<2Ol0000RonKViP03o`000?oooooooooo00_o
oooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo0;Cooooo00?o0000onKVi_oVi^H0
2ooVi^H2o`00067oc<c<1Ol0000NonKViP03o`000?oooooooooo00[ooooo0Ol00001ooooo`7ooooo
000^ooooo`03o`000?oooooooooo0;?ooooo00?o0000onKVi_oVi^H02OoVi^H3o`0006Soc<c<1Ol0
000JonKViP03o`000?oooooooooo00Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooo
oooo0;?ooooo00?o0000onKVi_oVi^H01ooVi^H2o`00073oc<c<1?l0000FonKViP03o`000?oooooo
oooo00Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo0;;ooooo00?o0000onKV
i_oVi^H01_oVi^H2o`0002Goc<c<6?l0000iolc<c0?o00005?oVi^H00ol0003oooooooooo`08oooo
o`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`2aooooo`03o`000?oVi^Koi^KV00Ko
i^KV00?o0000olc<c?o<c<`06oo<c<`:o`0001So/k>c5Ol0000Wolc<c0;o00004ooVi^H00ol0003o
ooooooooo`07ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`2`ooooo`03o`00
0?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`04oo<c<`9o`0003Oo/k>c1Ol0000Tolc<c003o`00
0?oVi^Koi^KV017oi^KV00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool002kooooo00?o
0000ooooooooool0[_ooool2o`0000Woi^KV00?o0000olc<c?o<c<`03oo<c<`4o`0004Go/k>c1Ol0
000Oolc<c003o`000?oVi^Koi^KV017oi^KV00?o0000ooooooooool01_ooool1o`00007ooooo0Ooo
ool002kooooo00?o0000ooooooooool0[Oooool00ol0003oi^KVonKViP08onKViP03o`000?o<c<co
c<c<00coc<c<1?l0001>ok>c/`Ko00006_o<c<`00ol0003oi^KVonKViP0@onKViP03o`000?oooooo
oooo00Kooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo0:cooooo00?o0000onKV
i_oVi^H02?oVi^H00ol0003oc<c<olc<c00:olc<c0?o0000F?nc/k<4o`0001Ooc<c<00?o0000onKV
i_oVi^H03ooVi^H00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003o
ooooooooo`2[ooooo`03o`000?oVi^Koi^KV00Soi^KV00?o0000olc<c?o<c<`02_o<c<`00ol0003o
/k>cok>c/`1Mok>c/`?o00005Oo<c<`00ol0003oi^KVonKViP0>onKViP03o`000?oooooooooo00Ko
oooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo0:[ooooo00?o0000onKVi_oVi^H0
2OoVi^H00ol0003oc<c<olc<c008olc<c0;o0000Honc/k<3o`0001;oc<c<00?o0000onKVi_oVi^H0
3_oVi^H00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003ooooooooo
o`2Yooooo`03o`000?oVi^Koi^KV00Woi^KV00?o0000olc<c?o<c<`01oo<c<`2o`00027o/k>c8ol0
000Tok>c/`?o00004?o<c<`00ol0003oi^KVonKViP0=onKViP03o`000?oooooooooo00Kooooo0Ol0
0001ooooo`7ooooo000^ooooo`;o0000ZOooool00ol0003oi^KVonKViP09onKViP03o`000?o<c<co
c<c<00Ooc<c<00?o0000ok>c/onc/k<06?nc/k<9o`0002?oVIVI2?l0000Ook>c/`;o00003oo<c<`0
0ol0003oi^KVonKViP0<onKViP03o`000?oooooooooo00Cooooo0ol00002ooooo`00;_ooool00ol0
003oooooooooo`2Wooooo`03o`000?oVi^Koi^KV00Woi^KV00?o0000olc<c?o<c<`01_o<c<`2o`00
01Ko/k>c1Ol0000doiVIV@Co00007Onc/k<00ol0003oc<c<olc<c00=olc<c003o`000?oVi^Koi^KV
00coi^KV00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool002kooooo00?o0000oooooooo
ool0Y_ooool00ol0003oi^KVonKViP09onKViP03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc
/k<04_nc/k<4o`0003goVIVI0ol0000Kok>c/`03o`000?o<c<coc<c<00coc<c<00?o0000onKVi_oV
i^H03?oVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003ooooo
ooooo`2Uooooo`03o`000?oVi^Koi^KV00[oi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>c
ok>c/`0@ok>c/`?o0000A?nIVIT4o`0001So/k>c00?o0000olc<c?o<c<`03?o<c<`00ol0003oi^KV
onKViP0;onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oo
oooooooo0:Cooooo00?o0000onKVi_oVi^H02_oVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc
/k?o/k>c00ko/k>c0ol0001;oiVIV@?o00005_nc/k<00ol0003oc<c<olc<c00<olc<c003o`000?oV
i^Koi^KV00[oi^KV00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool002kooooo00?o0000
ooooooooool0Xoooool00ol0003oi^KVonKViP0:onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000
ok>c/onc/k<03?nc/k<3o`00057oVIVI0ol0000Dok>c/`03o`000?o<c<coc<c<00_oc<c<00?o0000
onKVi_oVi^H02_oVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0
003oooooooooo`2Rooooo`03o`000?oVi^Koi^KV00[oi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0
003o/k>cok>c/`0:ok>c/`?o0000EonIVIT3o`0001;o/k>c00?o0000olc<c?o<c<`02oo<c<`00ol0
003oi^KVonKViP09onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03
o`000?oooooooooo0:7ooooo00?o0000onKVi_oVi^H02_oVi^H00ol0003oc<c<olc<c005olc<c003
o`000?nc/k?o/k>c00Wo/k>c0_l0000NoiVIVASo00009onIVIT2o`00017o/k>c00?o0000olc<c?o<
c<`02oo<c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7o
oooo000^ooooo`03o`000?oooooooooo0:3ooooo00?o0000onKVi_oVi^H02_oVi^H00ol0003oc<c<
olc<c005olc<c003o`000?nc/k?o/k>c00So/k>c0_l0000GoiVIV@Wo00006?moOgl:o`0001ooVIVI
0_l0000@ok>c/`03o`000?o<c<coc<c<00_oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003ooooo
ooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`2Pooooo`03o`000?oV
i^Koi^KV00[oi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`07ok>c/`03o`000?nI
VIWoVIVI01CoVIVI0ol0000[ogmoO`Go00007?nIVIT00ol0003o/k>cok>c/`0=ok>c/`03o`000?o<
c<coc<c<00_oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003oooooooooo`05ooooo`7o00000Ooo
ool1ooooo`00;_ooool00ol0003oooooooooo`2Oooooo`03o`000?oVi^Koi^KV00[oi^KV00?o0000
olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`06ok>c/`;o00005?nIVIT3o`0003?oOgmo0ol0000J
oiVIV@03o`000?nc/k?o/k>c00go/k>c00?o0000olc<c?o<c<`02_o<c<`00ol0003oi^KVonKViP07
onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo
09oooooo00?o0000onKVi_oVi^H02OoVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c
00Ko/k>c00?o0000oiVIVOnIVIT04OnIVIT3o`0003WoOgmo0ol0000HoiVIV@03o`000?nc/k?o/k>c
00go/k>c00?o0000olc<c?o<c<`02Oo<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo
00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo09kooooo00?o0000onKVi_oV
i^H02OoVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Ko/k>c00?o0000oiVIVOnI
VIT03onIVIT3o`0003ooOgmo0ol0000FoiVIV@03o`000?nc/k?o/k>c00co/k>c00?o0000olc<c?o<
c<`02Oo<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7o
oooo000^ooooo`03o`000?oooooooooo09kooooo00?o0000onKVi_oVi^H02?oVi^H00ol0003oc<c<
olc<c005olc<c003o`000?nc/k?o/k>c00Go/k>c0_l0000@oiVIV@;o0000AOmoOgl3o`0001CoVIVI
00?o0000ok>c/onc/k<03?nc/k<00ol0003oc<c<olc<c009olc<c003o`000?oVi^Koi^KV00Koi^KV
00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0WOoo
ool00ol0003oi^KVonKViP08onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01Onc
/k<00ol0003oVIVIoiVIV@0>oiVIV@;o0000B_moOgl2o`0001?oVIVI00?o0000ok>c/onc/k<02onc
/k<00ol0003oc<c<olc<c009olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool01Ooo
ool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0WOooool00ol0003oi^KVonKViP08
onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@0<
oiVIV@?o0000C_moOgl00ol0003oVIVIoiVIV@0AoiVIV@03o`000?nc/k?o/k>c00[o/k>c00?o0000
olc<c?o<c<`02Oo<c<`00ol0003oi^KVonKViP06onKViP03o`000?oooooooooo00Gooooo0Ol00001
ooooo`7ooooo000^ooooo`03o`000?oooooooooo09cooooo00?o0000onKVi_oVi^H02?oVi^H00ol0
003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT02onIVIT2o`00
01ooOgmo2_l0000YogmoO`;o00004_nIVIT00ol0003o/k>cok>c/`0:ok>c/`03o`000?o<c<coc<c<
00Soc<c<00?o0000onKVi_oVi^H01_oVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1oooo
o`00;_ooool00ol0003oooooooooo`2Kooooo`03o`000?oVi^Koi^KV00Soi^KV00?o0000olc<c?o<
c<`01?o<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomo
Ogl06OmoOgl6o`0000[oIVIV2ol0000PogmoO`03o`000?nIVIWoVIVI00ooVIVI00?o0000ok>c/onc
/k<02_nc/k<00ol0003oc<c<olc<c008olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000oooooooo
ool01Oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0Voooool00ol0003oi^KV
onKViP07onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVI
oiVIV@0:oiVIV@;o00005omoOgl5o`0001_oIVIV1ol0000JogmoO`;o00004?nIVIT00ol0003o/k>c
ok>c/`0:ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000onKVi_oVi^H01_oVi^H00ol0003ooooo
ooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`2Jooooo`03o`000?oV
i^Koi^KV00Ooi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nI
VIWoVIVI00WoVIVI0_l0000EogmoO`Co00009omVIVH3o`0001WoOgmo00?o0000oiVIVOnIVIT03_nI
VIT00ol0003o/k>cok>c/`09ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000onKVi_oVi^H01_oV
i^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`2J
ooooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05
ok>c/`03o`000?nIVIWoVIVI00WoVIVI00?o0000ogmoOomoOgl04_moOgl3o`0002koIVIV0ol0000G
ogmoO`;o00003onIVIT00ol0003o/k>cok>c/`09ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000
onKVi_oVi^H01OoVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0
003oooooooooo`2Iooooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0
003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00SoVIVI0_l0000AogmoO`Co0000=?mVIVH3o`00
01KoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`09ok>c/`03o`000?o<c<coc<c<
00Ooc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1oooo
o`00;_ooool2o`0009[ooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c004olc<c003
o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT02?nIVIT00ol0003oOgmoogmoO`0>ogmoO`?o
0000>omVIVH3o`0001CoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`08ok>c/`03
o`000?o<c<coc<c<00Ooc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`03ooooo`?o
00000_ooool002kooooo00?o0000ooooooooool0V?ooool00ol0003oi^KVonKViP05onKViP03o`00
0?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`00
0?moOgooOgmo00coOgmo0ol00011ofIVIP?o00004_moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`00
0?nc/k?o/k>c00So/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003oi^KVonKViP05onKViP03o`00
0?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo09Sooooo00?o
0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o
0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`0;ogmoO`;o0000AomVIVH00ol0003oOgmoogmo
O`0?ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<02?nc/k<00ol0003oc<c<olc<
c006olc<c003o`000?oVi^Koi^KV00Goi^KV00?o0000ooooooooool01Oooool1o`00007ooooo0Ooo
ool002kooooo00?o0000ooooooooool0Uoooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<co
c<c<00Coc<c<00?o0000ok>c/onc/k<01_nc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgoo
Ogmo00_oOgmo00?o0000ofIVI_mVIVH0B?mVIVH2o`00013oOgmo00?o0000oiVIVOnIVIT02onIVIT0
0ol0003o/k>cok>c/`08ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000onKVi_oVi^H01OoVi^H0
0ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`2Foooo
o`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`06ok>c
/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl02_moOgl2o`0004goIVIV00?o0000ogmo
OomoOgl03OmoOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c00Oo/k>c00?o0000olc<
c?o<c<`01_o<c<`00ol0003oi^KVonKViP05onKViP03o`000?oooooooooo00Gooooo0Ol00001oooo
o`7ooooo000^ooooo`03o`000?oooooooooo09Gooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003o
c<c<olc<c005olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003o
OgmoogmoO`0:ogmoO`03o`000?mVIVKoIVIV01coIVIV3Ol0000UofIVIP03o`000?moOgooOgmo00go
Ogmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`07ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00
;_ooool00ol0003oooooooooo`2Dooooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`0
1?o<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl0
2_moOgl00ol0003oIVIVofIVIP0FofIVIPOo00003Om<C4`7o`0001ooIVIV00?o0000ogmoOomoOgl0
3OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c00So/k>c00?o0000olc<c?o<c<`0
1Oo<c<`00ol0003oi^KVonKViP05onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo
000^ooooo`03o`000?oooooooooo09?ooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<
c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmo
O`09ogmoO`;o00005_mVIVH3o`0001_oC4a<1?l0000KofIVIP03o`000?moOgooOgmo00goOgmo00?o
0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`08ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o
0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool0
0ol0003oooooooooo`2Booooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`01Oo<c<`0
0ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oIVIVofIVIP0CofIVIP?o00008_m<C4`3o`0001WoIVIV00?o0000ogmoOomoOgl03OmoOgl0
0ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c00Oo/k>c00?o0000olc<c?o<c<`01Oo<c<`0
0ol0003oi^KVonKViP05onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000^oooo
o`03o`000?oooooooooo097ooooo00?o0000onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c004olc<
c003o`000?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`08ogmo
O`;o00004omVIVH3o`0002SoC4a<0ol0000GofIVIP03o`000?moOgooOgmo00coOgmo00?o0000oiVI
VOnIVIT02_nIVIT00ol0003o/k>cok>c/`07ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKV
i_oVi^H01OoVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003o
ooooooooo`2@ooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o
/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP0AofIVIP;o0000;_m<C4`2o`0001KoIVIV00?o0000ogmoOomoOgl03?moOgl00ol0003o
VIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c00Oo/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o
i^KVonKViP04onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`00
0?oooooooooo08oooooo00?o0000onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c004olc<c003o`00
0?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`00
0?mVIVKoIVIV013oIVIV0_l0000boda<C0;o00005?mVIVH00ol0003oOgmoogmoO`0<ogmoO`03o`00
0?nIVIWoVIVI00WoVIVI00?o0000ok>c/onc/k<01onc/k<00ol0003oc<c<olc<c006olc<c003o`00
0?oVi^Koi^KV00Coi^KV00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool002kooooo00?o
0000ooooooooool0S_ooool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00Coc<c<00?o
0000ok>c/onc/k<01?nc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00SoOgmo00?o
0000ofIVI_mVIVH03omVIVH2o`0003KoC4a<0_l0000CofIVIP03o`000?moOgooOgmo00coOgmo00?o
0000oiVIVOnIVIT02OnIVIT00ol0003o/k>cok>c/`06ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o
0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool0
0ol0003oooooooooo`2=ooooo`03o`000?oVi^Koi^KV00Soi^KV00?o0000olc<c?o<c<`00oo<c<`0
0ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl02?moOgl0
0ol0003oIVIVofIVIP0>ofIVIP;o0000>_m<C4`2o`0001;oIVIV00?o0000ogmoOomoOgl02omoOgl0
0ol0003oVIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00?o0000olc<c?o<c<`01_o<c<`0
0ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000^oooo
o`03o`000?oooooooooo08cooooo00?o0000onKVi_oVi^H02?oVi^H00ol0003oc<c<olc<c003olc<
c003o`000?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`08ogmo
O`03o`000?mVIVKoIVIV00goIVIV0_l0000noda<C0;o00004?mVIVH00ol0003oOgmoogmoO`0<ogmo
O`03o`000?nIVIWoVIVI00SoVIVI00?o0000ok>c/onc/k<01onc/k<00ol0003oc<c<olc<c005olc<
c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool002ko
oooo00?o0000ooooooooool0S?ooool00ol0003oi^KVonKViP08onKViP03o`000?o<c<coc<c<00;o
c<c<00?o0000ok>c/onc/k<01?nc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00So
Ogmo00?o0000ofIVI_mVIVH03?mVIVH2o`0004;oC4a<00?o0000ofIVI_mVIVH03_mVIVH00ol0003o
OgmoogmoO`0<ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc/k<01onc/k<00ol0003o
c<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool01Oooool1o`00007o
oooo0Oooool002kooooo00?o0000ooooooooool0Roooool00ol0003oi^KVonKViP09onKViP05o`00
0?o<c<coc<c<olc<c?l000001onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00So
Ogmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C013oda<C003o`000?mVIVKoIVIV00ko
IVIV00?o0000ogmoOomoOgl02omoOgl00ol0003oVIVIoiVIV@08oiVIV@03o`000?nc/k?o/k>c00Ko
/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Go
oooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo08[ooooo00?o0000onKVi_oVi^H0
2OoVi^H01Ol0003oc<c<olc<c?o<c<co000000Oo/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l00017oda<C003o`000?mVIVKoIVIV00ko
IVIV00?o0000ogmoOomoOgl02omoOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c00Ko
/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Go
oooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo08[ooooo00?o0000onKVi_oVi^H0
2?oVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT0
1OnIVIT00ol0003oOgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
7Om<C4`:o`00023oC4a<00?o0000ofIVI_mVIVH03_mVIVH00ol0003oOgmoogmoO`0;ogmoO`03o`00
0?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc/k<01_nc/k<00ol0003oc<c<olc<c005olc<c003o`00
0?oVi^Koi^KV00Coi^KV00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool002kooooo00?o
0000ooooooooool0ROooool00ol0003oi^KVonKViP08onKViP03o`000?o<c<coc<c<00;oc<c<00?o
0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00OoOgmo00?o
0000ofIVI_mVIVH02_mVIVH2o`0001WoC4a<1ol0000:oc<c<`Go00007?m<C4`00ol0003oIVIVofIV
IP0>ofIVIP03o`000?moOgooOgmo00[oOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c
/`06ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003ooooooooo
o`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`28ooooo`03o`000?oVi^Ko
i^KV00Soi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWo
VIVI00GoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4co
C4a<01KoC4a<0ol0000Foc<c<`Co00006Om<C4`00ol0003oIVIVofIVIP0=ofIVIP03o`000?moOgoo
Ogmo00_oOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`06ok>c/`03o`000?o<c<co
c<c<00Goc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1
ooooo`00;_ooool00ol0003oooooooooo`27ooooo`03o`000?oVi^Koi^KV00Soi^KV00?o0000olc<
c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmo
OomoOgl01omoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01CoC4a<0ol0000Moc<c
<`;o00005om<C4`00ol0003oIVIVofIVIP0>ofIVIP03o`000?moOgooOgmo00[oOgmo00?o0000oiVI
VOnIVIT01_nIVIT00ol0003o/k>cok>c/`06ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKV
i_oVi^H01?oVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool2o`0008Oo
oooo00?o0000onKVi_oVi^H02?oVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00Co
/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00Wo
IVIV0_l0000Doda<C0?o00008_lc<c<2o`0001KoC4a<00?o0000ofIVI_mVIVH03_mVIVH00ol0003o
OgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003o
c<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool00oooool3o`0000;o
oooo000^ooooo`03o`000?oooooooooo08Gooooo00?o0000onKVi_oVi^H02?oVi^H00ol0003oc<c<
olc<c003olc<c003o`000?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmo
ogmoO`07ogmoO`03o`000?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`04_m<C4`2o`0002Oo<c<c
00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP0=ofIVIP03o`000?moOgooOgmo00WoOgmo
00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00Goc<c<
00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_oo
ool00ol0003oooooooooo`25ooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<c?o<c<`00oo<
c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01omo
Ogl00ol0003oIVIVofIVIP08ofIVIP;o00004om<C4`2o`0002[o<c<c0_l0000Doda<C003o`000?mV
IVKoIVIV00koIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc
/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP04onKViP03o`000?oo
oooooooo00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo08Cooooo00?o0000
onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Co/k>c00?o0000
oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000
oda<C?m<C4`04Om<C4`2o`0002ko<c<c0_l0000Coda<C003o`000?mVIVKoIVIV00goIVIV00?o0000
ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00?o0000
olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP03onKViP03o`000?oooooooooo00Gooooo0Ol00001
ooooo`7ooooo000^ooooo`03o`000?oooooooooo08?ooooo00?o0000onKVi_oVi^H01ooVi^H00ol0
003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0
003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`04?m<C4`2o`00
03;o<c<c00?o0000oda<C?m<C4`04?m<C4`00ol0003oIVIVofIVIP0=ofIVIP03o`000?moOgooOgmo
00WoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`06ok>c/`03o`000?o<c<coc<c<
00Goc<c<00?o0000onKVi_oVi^H00ooVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1oooo
o`00;_ooool00ol0003oooooooooo`22ooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<c?o<
c<`01?o<c<`00ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomo
Ogl01_moOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<00ooC4a<0_l0000eoc<c<`03
o`000?m<C4coC4a<013oC4a<00?o0000ofIVI_mVIVH03OmVIVH00ol0003oOgmoogmoO`08ogmoO`03
o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01_nc/k<00ol0003oc<c<olc<c005olc<c003
o`000?oVi^Koi^KV00?oi^KV00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool002kooooo
00?o0000ooooooooool0POooool00ol0003oi^KVonKViP08onKViP03o`000?o<c<coc<c<00?oc<c<
00?o0000ok>c/onc/k<01?nc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00KoOgmo
00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00>oda<C0;o0000>?lc<c<00ol0003oC4a<
oda<C00@oda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVI
oiVIV@06oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KV
onKViP03onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oo
oooooooo087ooooo00?o0000onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc
/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mV
IVKoIVIV00SoIVIV00?o0000oda<C?m<C4`03Om<C4`2o`0003_o<c<c00?o0000oda<C?m<C4`03om<
C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01onI
VIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H00ooV
i^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`20
ooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03
ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP08
ofIVIP03o`000?m<C4coC4a<00coC4a<0_l0000noc<c<`03o`000?m<C4coC4a<00ooC4a<00?o0000
ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000
ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00?oi^KV00?o0000
ooooooooool01Oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0Ooooool00ol0
003oi^KVonKViP08onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0
003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0
003oC4a<oda<C00<oda<C003o`000?lc<c?o<c<c03oo<c<c00?o0000oda<C?m<C4`03om<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0
003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H00ooVi^H00ol0
003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`1nooooo`03
o`000?oVi^Koi^KV00Soi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`03
o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP08ofIVIP03
o`000?m<C4coC4a<00_oC4a<0_l00013oc<c<`03o`000?m<C4coC4a<00koC4a<00?o0000ofIVI_mV
IVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc
/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00?oi^KV00?o0000oooooooo
ool01Oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0O_ooool00ol0003oi^KV
onKViP08onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVI
oiVIV@05oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<
oda<C00;oda<C003o`000?lc<c?o<c<c04?o<c<c00?o0000oda<C?m<C4`03_m<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>c
ok>c/`05ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H00ooVi^H00ol0003ooooo
ooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`1mooooo`03o`000?oV
i^Koi^KV00Soi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nI
VIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<
C4coC4a<00_oC4a<00?o0000oc<c<olc<c<0AOlc<c<00ol0003oC4a<oda<C00=oda<C003o`000?mV
IVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc
/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP03onKViP03o`000?oo
oooooooo00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo07cooooo00?o0000
onKVi_oVi^H02?oVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000
oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00WoIVIV00?o0000
oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0Koc<c<`Wo00008_lc<c<00ol0003oC4a<oda<C00>
oda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@06
oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP03
onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo
07cooooo00?o0000onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c
00?o/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV
00SoIVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0Hoc<c<`Co00002OlI6AT7o`00
01co<c<c00?o0000oda<C?m<C4`03Om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo
00SoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<
00Goc<c<00?o0000onKVi_oVi^H00ooVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1oooo
o`00;_ooool00ol0003oooooooooo`1kooooo`03o`000?oVi^Koi^KV00Soi^KV00?o0000olc<c?o<
c<`00oo<c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomo
Ogl01_moOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<00WoC4a<0_l0000Hoc<c<`?o
00005?lI6AT2o`0001[o<c<c00?o0000oda<C?m<C4`03Om<C4`00ol0003oIVIVofIVIP0:ofIVIP03
o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`05ok>c/`03
o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H00ooVi^H00ol0003oooooooooo`05ooooo`7o
00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`1kooooo`03o`000?oVi^Koi^KV00Ooi^KV
00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nIVIWoVIVI00GoVIVI
00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<00WoC4a<
00?o0000oc<c<olc<c<05Olc<c<3o`0001Wo6ATI0_l0000Hoc<c<`03o`000?m<C4coC4a<00goC4a<
00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI
00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00?oi^KV
00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0N_oo
ool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc
/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH02?mV
IVH00ol0003oC4a<oda<C009oda<C003o`000?lc<c?o<c<c01Co<c<c0_l0000NoaTI6@03o`000?lc
<c?o<c<c01Ko<c<c00?o0000oda<C?m<C4`03?m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?mo
OgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<
c<coc<c<00Goc<c<00?o0000onKVi_oVi^H00ooVi^H00ol0003oooooooooo`05ooooo`7o00000Ooo
ool1ooooo`00;_ooool00ol0003oooooooooo`1iooooo`03o`000?oVi^Koi^KV00Soi^KV00?o0000
olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000
ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000
oc<c<olc<c<04olc<c<2o`00027o6ATI0_l0000Foc<c<`03o`000?m<C4coC4a<00goC4a<00?o0000
ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000
ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000
ooooooooool01Oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0NOooool00ol0
003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0
003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0
003oC4a<oda<C009oda<C003o`000?lc<c?o<c<c01;o<c<c0_l0000UoaTI6@;o00005Olc<c<00ol0
003oC4a<oda<C00<oda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl01omoOgl00ol0
003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0
003oi^KVonKViP04onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03
o`000?oooooooooo07Sooooo00?o0000onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c002olc<c003
o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`06ogmoO`03
o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`02Om<C4`00ol0003o<c<coc<c<`0Aoc<c<`;o
0000:OlI6AT00ol0003o<c<coc<c<`0Boc<c<`03o`000?m<C4coC4a<00coC4a<00?o0000ofIVI_mV
IVH02_mVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc
/k<01Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000oooooooo
ool01Oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0N?ooool00ol0003oi^KV
onKViP06onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVI
oiVIV@05oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<
oda<C009oda<C003o`000?lc<c?o<c<c013o<c<c0_l0000[oaTI6@03o`000?lc<c?o<c<c01?o<c<c
00?o0000oda<C?m<C4`02om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00OoOgmo
00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00Coc<c<
00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_oo
ool2o`0007Sooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc
/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mV
IVKoIVIV00OoIVIV00?o0000oda<C?m<C4`02Om<C4`00ol0003o<c<coc<c<`0?oc<c<`;o0000;_lI
6AT00ol0003o<c<coc<c<`0Boc<c<`03o`000?m<C4coC4a<00_oC4a<00?o0000ofIVI_mVIVH02_mV
IVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01Onc
/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool00ooo
ool3o`0000;ooooo000^ooooo`03o`000?oooooooooo07Kooooo00?o0000onKVi_oVi^H01_oVi^H0
0ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01OnIVIT0
0ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`02Om<C4`0
0ol0003o<c<coc<c<`0>oc<c<`;o0000<OlI6AT00ol0003o<c<coc<c<`0Aoc<c<`03o`000?m<C4co
C4a<00coC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWo
VIVI00KoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Ko
i^KV00Coi^KV00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool002kooooo00?o0000oooo
ooooool0M_ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c
/onc/k<00onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIV
I_mVIVH01omVIVH00ol0003oC4a<oda<C009oda<C003o`000?lc<c?o<c<c00ko<c<c00?o0000oaTI
6OlI6AT0<OlI6AT00ol0003o<c<coc<c<`0Boc<c<`03o`000?m<C4coC4a<00_oC4a<00?o0000ofIV
I_mVIVH02OmVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c
/onc/k<01Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000oooo
ooooool01Oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0MOooool00ol0003o
i^KVonKViP05onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0003o
VIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003o
C4a<oda<C009oda<C003o`000?lc<c?o<c<c00go<c<c0_l0000eoaTI6@03o`000?lc<c?o<c<c017o
<c<c00?o0000oda<C?m<C4`02om<C4`00ol0003oIVIVofIVIP09ofIVIP03o`000?moOgooOgmo00Oo
Ogmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00Co
c<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00
;_ooool00ol0003oooooooooo`1eooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`0
0oo<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl0
1OmoOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000oc<c<olc<c<0
3?lc<c<00ol0003o6ATIoaTI6@0eoaTI6@03o`000?lc<c?o<c<c017o<c<c00?o0000oda<C?m<C4`0
2om<C4`00ol0003oIVIVofIVIP09ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT0
1_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H0
1?oVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003ooooooooo
o`1dooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c
/`03ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIV
IP07ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000oc<c<olc<c<03?lc<c<00ol0003o6ATIoaTI
6@0foaTI6@03o`000?lc<c?o<c<c017o<c<c00?o0000oda<C?m<C4`02om<C4`00ol0003oIVIVofIV
IP09ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c
/`05ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003ooooooooo
o`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`1cooooo`03o`000?oVi^Ko
i^KV00Goi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nIVIWo
VIVI00GoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4co
C4a<00WoC4a<00?o0000oc<c<olc<c<03?lc<c<00ol0003o6ATIoaTI6@0hoaTI6@03o`000?lc<c?o
<c<c013o<c<c00?o0000oda<C?m<C4`02om<C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?moOgoo
Ogmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<co
c<c<00Goc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1
ooooo`00;_ooool00ol0003oooooooooo`1booooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<
c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmo
OomoOgl01_moOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000oc<c
<olc<c<03?lc<c<00ol0003o6ATIoaTI6@0ioaTI6@03o`000?lc<c?o<c<c013o<c<c00?o0000oda<
C?m<C4`02om<C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVI
VOnIVIT01_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKV
i_oVi^H01?oVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003o
ooooooooo`1aooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o
/k>cok>c/`02ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003o
IVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000oc<c<olc<c<02olc<c<2o`0003co
6ATI00?o0000oc<c<olc<c<04?lc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00Wo
IVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Go
/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Go
oooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo073ooooo00?o0000onKVi_oVi^H0
1_oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT0
1?nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`0
2?m<C4`00ol0003o<c<coc<c<`0;oc<c<`03o`000?lI6AWo6ATI03co6ATI00?o0000oc<c<olc<c<0
4?lc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00WoIVIV00?o0000ogmoOomoOgl0
1omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`0
1Oo<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo
000^ooooo`03o`000?oooooooooo06oooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<
c004olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmo
O`05ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`02?m<C4`00ol0003o<c<coc<c
<`0;oc<c<`03o`000?lI6AWo6ATI03ko6ATI00?o0000oc<c<olc<c<03olc<c<00ol0003oC4a<oda<
C00:oda<C003o`000?mVIVKoIVIV00WoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVI
V@06oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKV
iP04onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooo
oooo06oooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o
/k>c00?o/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKo
IVIV00OoIVIV00?o0000oda<C?m<C4`02?m<C4`00ol0003o<c<coc<c<`0;oc<c<`03o`000?lI6AWo
6ATI03oo6ATI00?o0000oc<c<olc<c<03olc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKo
IVIV00SoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o
/k>c00Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP05onKViP03o`000?oooooo
oooo00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo06kooooo00?o0000onKV
i_oVi^H01OoVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVI
VOnIVIT01?nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<
C?m<C4`02?m<C4`00ol0003o<c<coc<c<`0;oc<c<`03o`000?lI6AWo6ATI043o6ATI00?o0000oc<c
<olc<c<03olc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmo
OomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<
c?o<c<`01Oo<c<`00ol0003oi^KVonKViP05onKViP03o`000?oooooooooo00Gooooo0Ol00001oooo
o`7ooooo000^ooooo`03o`000?oooooooooo06gooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003o
c<c<olc<c004olc<c003o`000?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003o
OgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o
<c<coc<c<`0;oc<c<`03o`000?lI6AWo6ATI04;o6ATI00?o0000oc<c<olc<c<03_lc<c<00ol0003o
C4a<oda<C00:oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003o
VIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o
i^KVonKViP05onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`00
0?oooooooooo06cooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c004olc<c003o`00
0?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`06ogmoO`03o`00
0?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<coc<c<`0;oc<c<`03o`00
0?lI6AWo6ATI04?o6ATI00?o0000oc<c<olc<c<03_lc<c<00ol0003oC4a<oda<C00:oda<C003o`00
0?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`00
0?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP05onKViP03o`00
0?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo06_ooooo00?o
0000onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00?o
0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o
0000oda<C?m<C4`01om<C4`00ol0003o<c<coc<c<`0;oc<c<`03o`000?lI6AWo6ATI04Co6ATI00?o
0000oc<c<olc<c<03_lc<c<00ol0003oC4a<oda<C009oda<C003o`000?mVIVKoIVIV00WoIVIV00?o
0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o
0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP05onKViP03o`000?oooooooooo00Gooooo0Ol0
0001ooooo`7ooooo000^ooooo`03o`000?oooooooooo06[ooooo00?o0000onKVi_oVi^H01ooVi^H0
0ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01?nIVIT0
0ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`01om<C4`0
0ol0003o<c<coc<c<`0;oc<c<`03o`000?lI6AWo6ATI04Go6ATI00?o0000oc<c<olc<c<03_lc<c<0
0ol0003oC4a<oda<C009oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl01omoOgl0
0ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01_o<c<`0
0ol0003oi^KVonKViP05onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000^oooo
o`03o`000?oooooooooo06[ooooo00?o0000onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c002olc<
c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`05ogmo
O`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<coc<c<`0;oc<c
<`03o`000?lI6AWo6ATI01_o6ATI2_l0000RoaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<
C?m<C4`02Om<C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVI
VOnIVIT01_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000onKV
i_oVi^H01OoVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003o
ooooooooo`1Yooooo`03o`000?oVi^Koi^KV00Soi^KV00Go0000olc<c?o<c<coc<c<o`000005ok>c
/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP07ofIV
IP03o`000?m<C4coC4a<00OoC4a<00?o0000oc<c<olc<c<02olc<c<00ol0003o6ATIoaTI6@0HoaTI
6ACo00007?lI6AT00ol0003o<c<coc<c<`0=oc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000ofIV
I_mVIVH02?mVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c
/onc/k<01Onc/k<00ol0003oc<c<olc<c006olc<c003o`000?oVi^Koi^KV00Goi^KV00?o0000oooo
ooooool01Oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0J?ooool00ol0003o
i^KVonKViP09onKViP04o`000?o<c<coc<c<o`0000Ko/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0
003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0
003o<c<coc<c<`0;oc<c<`03o`000?lI6AWo6ATI01Ko6ATI5_l0000LoaTI6@03o`000?lc<c?o<c<c
00go<c<c00?o0000oda<C?m<C4`02Om<C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo
00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<
00Koc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1oooo
o`004oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`1Wooooo`03o`000?oVi^Koi^KV00Woi^KV00Co0000
olc<c?o<c<co00001_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o
0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C007oda<C003o`000?lc<c?o<c<c00co<c<c00?o
0000oaTI6OlI6AT05?lI6ATIo`0001_o6ATI00?o0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<
C009oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVI
V@06oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003oi^KVonKV
iP04onKViP03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo000Cooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`1Vooooo`03o`000?oVi^Koi^KV00Woi^KV00Co0000olc<c?o<c<co00001_nc/k<00ol0003oVIVI
oiVIV@04oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<
oda<C007oda<C003o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT04olI6ATKo`0001_o6ATI
00?o0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV00WoIVIV
00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Go/k>c
00?o0000olc<c?o<c<`01_o<c<`00ol0003oi^KVonKViP05onKViP03o`000?oooooooooo00Kooooo
0Ol00001ooooo`7ooooo000Cooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooo
ooooo`03ooooo`?o0000IOooool00ol0003oi^KVonKViP09onKViP05o`000?o<c<coc<c<olc<c?l0
00001_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mV
IVH01_mVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00_o<c<c00?o0000oaTI6OlI
6AT04olI6ATMo`0001[o6ATI00?o0000oc<c<olc<c<03?lc<c<00ol0003oC4a<oda<C009oda<C003
o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@06oiVIV@03
o`000?nc/k?o/k>c00Ko/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003oi^KVonKViP04onKViP03
o`000?oooooooooo00Gooooo0ol00002ooooo`004oooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1Tooooo`03o`000?oVi^Koi^KV00Wo
i^KV00Go0000olc<c?o<c<coc<c<o`000006ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmo
OomoOgl01OmoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c
<olc<c<02olc<c<00ol0003o6ATIoaTI6@0CoaTI6Ako00006OlI6AT00ol0003o<c<coc<c<`0=oc<c
<`03o`000?m<C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`06ogmo
O`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c007olc<
c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool01oooool1o`00007ooooo0Oooool001?o
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`1Sooooo`03o`000?oVi^Koi^KV00Woi^KV00?o0000olc<c?o<c<`00_o<c<`0
0ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01OmoOgl0
0ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<00OoC4a<00?o0000oc<c<olc<c<02olc<c<0
0ol0003o6ATIoaTI6@0BoaTI6B7o00006?lI6AT00ol0003o<c<coc<c<`0=oc<c<`03o`000?m<C4co
C4a<00SoC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWo
VIVI00KoVIVI00?o0000ok>c/onc/k<01_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?oVi^Ko
i^KV00?oi^KV00?o0000ooooooooool02?ooool1o`00007ooooo0Oooool001?ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0H_ooool0
0ol0003oi^KVonKViP09onKViP03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<00onc/k<0
0ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01_mVIVH0
0ol0003oC4a<oda<C007oda<C003o`000?lc<c?o<c<c00_o<c<c00?o0000oaTI6OlI6AT04_lI6ATR
o`0001So6ATI00?o0000oc<c<olc<c<03?lc<c<00ol0003oC4a<oda<C009oda<C003o`000?mVIVKo
IVIV00SoIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o
/k>c00Go/k>c00?o0000olc<c?o<c<`02?o<c<`00ol0003oi^KVonKViP03onKViP03o`000?oooooo
oooo00Sooooo0Ol00001ooooo`7ooooo000Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo067ooooo00?o0000onKVi_oVi^H02OoVi^H0
0ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnIVIT01?nIVIT0
0ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`02?m<C4`0
0ol0003o<c<coc<c<`0:oc<c<`03o`000?lI6AWo6ATI017o6ATI9Ol0000GoaTI6@03o`000?lc<c?o
<c<c00co<c<c00?o0000oda<C?m<C4`02Om<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgoo
Ogmo00KoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`06ok>c/`03o`000?o<c<co
c<c<00Ooc<c<00?o0000onKVi_oVi^H00ooVi^H00ol0003oooooooooo`09ooooo`7o00000Oooool1
ooooo`004oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooo
oooo063ooooo00?o0000onKVi_oVi^H02OoVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o
/k>c00?o/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKo
IVIV00KoIVIV00?o0000oda<C?m<C4`02?m<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`000?lI6AWo
6ATI017o6ATI9_l0000GoaTI6@03o`000?lc<c?o<c<c00co<c<c00?o0000oda<C?m<C4`02?m<C4`0
0ol0003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01_nIVIT0
0ol0003o/k>cok>c/`06ok>c/`03o`000?o<c<coc<c<00Koc<c<0_l00005onKViP03o`000?oooooo
oooo00Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo05oooooo00?o0000onKV
i_oVi^H02OoVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVI
VOnIVIT01OnIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<
C?m<C4`01om<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`000?lI6AWo6ATI017o6ATI9ol0000GoaTI
6@03o`000?lc<c?o<c<c00co<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP08ofIV
IP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`05ok>c
/`03o`000?o<c<coc<c<00Koc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`09oooo
o`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`1Nooooo`03o`000?oVi^Koi^KV00Wo
i^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00Co
VIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<00So
C4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0@oaTI6B[o00005_lI6AT00ol0003o
<c<coc<c<`0;oc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003o
OgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01_nc/k<00ol0003o
c<c<olc<c005olc<c003o`000?oVi^Koi^KV00Goi^KV00?o0000ooooooooool02_ooool1o`00007o
oooo0Oooool002kooooo00?o0000ooooooooool0GOooool00ol0003oi^KVonKViP0:onKViP03o`00
0?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`00
0?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C008oda<C003o`00
0?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT04?lI6AT[o`0001Go6ATI00?o0000oc<c<olc<c<0
3?lc<c<00ol0003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl0
1_moOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00?o0000olc<c?o<c<`0
0oo<c<`2o`0000Soi^KV00?o0000ooooooooool02_ooool1o`00007ooooo0Oooool002kooooo00?o
0000ooooooooool0G?ooool00ol0003oi^KVonKViP0:onKViP03o`000?o<c<coc<c<00?oc<c<00?o
0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00CoOgmo00?o
0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o
0000oaTI6OlI6AT04?lI6AT]o`0001Co6ATI00?o0000oc<c<olc<c<03?lc<c<00ol0003oC4a<oda<
C008oda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVI
V@06oiVIV@03o`000?nc/k?o/k>c00Go/k>c0_l00005olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o
0000ooooooooool02oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0Foooool0
0ol0003oi^KVonKViP0;onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<0
0ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01_mVIVH0
0ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT04?lI6AT^
o`0001Co6ATI00?o0000oc<c<olc<c<02olc<c<00ol0003oC4a<oda<C009oda<C003o`000?mVIVKo
IVIV00OoIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o
/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooo
oooo00_ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo05[ooooo00?o0000onKV
i_oVi^H02ooVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVI
VOnIVIT01?nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<
C?m<C4`02?m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI013o6ATI<?l0000CoaTI
6@03o`000?lc<c?o<c<c00_o<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP07ofIV
IP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`04ok>c
/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H02?oVi^H00ol0003oooooooooo`0<oooo
o`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`1Jooooo`03o`000?oVi^Koi^KV00_o
i^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00Co
VIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00So
C4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0@oaTI6C3o00004olI6AT00ol0003o
<c<coc<c<`0;oc<c<`03o`000?m<C4coC4a<00SoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003o
OgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003o
c<c<olc<c004olc<c003o`000?oVi^Koi^KV00Soi^KV00?o0000ooooooooool03?ooool1o`00007o
oooo0Oooool002kooooo00?o0000ooooooooool0F_ooool00ol0003oi^KVonKViP0:onKViP03o`00
0?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`00
0?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C008oda<C003o`00
0?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT04?lI6ATao`0001;o6ATI00?o0000oc<c<olc<c<0
2olc<c<00ol0003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl0
1_moOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`0
1?o<c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo00gooooo0Ol00001ooooo`7ooooo
000^ooooo`03o`000?oooooooooo05[ooooo00?o0000onKVi_oVi^H02OoVi^H00ol0003oc<c<olc<
c003olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmo
O`05ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<coc<c
<`09oc<c<`03o`000?lI6AWo6ATI013o6ATI<_l0000BoaTI6@03o`000?lc<c?o<c<c00_o<c<c00?o
0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00KoOgmo00?o
0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o
0000onKVi_oVi^H02?oVi^H00ol0003oooooooooo`0>ooooo`7o00000Oooool1ooooo`00;_ooool0
0ol0003oooooooooo`1Iooooo`03o`000?oVi^Koi^KV00[oi^KV00?o0000olc<c?o<c<`00_o<c<`0
0ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01OmoOgl0
0ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<02Olc<c<0
0ol0003o6ATIoaTI6@0?oaTI6C;o00004olI6AT00ol0003o<c<coc<c<`0:oc<c<`03o`000?m<C4co
C4a<00SoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWo
VIVI00GoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Ko
i^KV00Ooi^KV00?o0000ooooooooool03oooool1o`00007ooooo0Oooool002kooooo00?o0000oooo
ooooool0FOooool00ol0003oi^KVonKViP09onKViP03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c
/onc/k<01?nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIV
I_mVIVH01OmVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI
6OlI6AT03olI6ATco`0001;o6ATI00?o0000oc<c<olc<c<02olc<c<00ol0003oC4a<oda<C008oda<
C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@05oiVI
V@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP08onKV
iP03o`000?oooooooooo00oooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo05Wo
oooo00?o0000onKVi_oVi^H02OoVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co
/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00Ko
IVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00oo
6ATI=?l0000BoaTI6@03o`000?lc<c?o<c<c00_o<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003o
IVIVofIVIP06ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o
/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oVi^H02?oVi^H00ol0003o
ooooooooo`0@ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`1Iooooo`03o`00
0?oVi^Koi^KV00Soi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`03o`00
0?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP05ofIVIP03o`00
0?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0>oaTI6CGo0000
4_lI6AT00ol0003o<c<coc<c<`0:oc<c<`03o`000?m<C4coC4a<00SoC4a<00?o0000ofIVI_mVIVH0
1omVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<0
1?nc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool0
4Oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0FOooool00ol0003oi^KVonKV
iP07onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVI
V@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<
C007oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT03olI6ATeo`00017o6ATI00?o
0000oc<c<olc<c<02olc<c<00ol0003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV00OoIVIV00?o
0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o
0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo017ooooo0Ol0
0001ooooo`7ooooo000^ooooo`03o`000?oooooooooo05Sooooo00?o0000onKVi_oVi^H02?oVi^H0
0ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnIVIT00onIVIT0
0ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`01om<C4`0
0ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00oo6ATI=Ol0000BoaTI6@03o`000?lc<c?o
<c<c00[o<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgoo
Ogmo00OoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<co
c<c<00?oc<c<00?o0000onKVi_oVi^H02?oVi^H00ol0003oooooooooo`0Booooo`7o00000Oooool1
ooooo`00;_ooool00ol0003oooooooooo`1Hooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<
c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmo
OomoOgl01OmoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00OoC4a<00?o0000oc<c
<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0>oaTI6CKo00004_lI6AT00ol0003o<c<coc<c<`0:oc<c
<`03o`000?m<C4coC4a<00SoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`06ogmo
O`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c003olc<
c003o`000?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool04oooool1o`00007ooooo0Oooool002ko
oooo0_l0001Iooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o
/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003o
IVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00OoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o
6ATIoaTI6@0>oaTI6COo00004OlI6AT00ol0003o<c<coc<c<`0:oc<c<`03o`000?m<C4coC4a<00So
C4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00Go
VIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00So
i^KV00?o0000ooooooooool04Oooool3o`0000;ooooo000^ooooo`03o`000?oooooooooo05Sooooo
00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c
00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00KoIVIV
00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00ko6ATI
>?l0000AoaTI6@03o`000?lc<c?o<c<c00[o<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIV
ofIVIP07ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>c
ok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003ooooo
ooooo`0Dooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`1Hooooo`03o`000?oV
i^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nI
VIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<
C4coC4a<00OoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0>oaTI6CSo00004OlI
6AT00ol0003o<c<coc<c<`0:oc<c<`03o`000?m<C4coC4a<00SoC4a<00?o0000ofIVI_mVIVH01_mV
IVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<01Onc
/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool05Ooo
ool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0Eoooool00ol0003oi^KVonKViP06
onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@04
oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C007
oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT03_lI6ATho`00017o6ATI00?o0000
oc<c<olc<c<02_lc<c<00ol0003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000
ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000
olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo01Gooooo0Ol00001
ooooo`7ooooo000^ooooo`03o`000?oooooooooo05Oooooo00?o0000onKVi_oVi^H01OoVi^H00ol0
003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0
003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`01_m<C4`00ol0
003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00ko6ATI>Ol0000AoaTI6@03o`000?lc<c?o<c<c
00[o<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo
00KoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<
00?oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003oooooooooo`0Fooooo`7o00000Oooool1oooo
o`00;_ooool00ol0003oooooooooo`1Gooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<
c<`00oo<c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomo
Ogl01?moOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00OoC4a<00?o0000oc<c<olc
<c<02Olc<c<00ol0003o6ATIoaTI6@0=oaTI6C[o00004?lI6AT00ol0003o<c<coc<c<`0:oc<c<`03
o`000?m<C4coC4a<00SoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`06ogmoO`03
o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c0;o
00002OoVi^H00ol0003oooooooooo`0Gooooo`7o00000Oooool1ooooo`00;_ooool00ol0003ooooo
ooooo`1Gooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>c
ok>c/`02ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIV
ofIVIP05ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATI
oaTI6@0=oaTI6C[o00004?lI6AT00ol0003o<c<coc<c<`09oc<c<`03o`000?m<C4coC4a<00WoC4a<
00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00CoVIVI
00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<o`000002o`0000_oi^KV00?o0000ooooooooool0
5oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0Eoooool00ol0003oi^KVonKV
iP05onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVI
V@04oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<
C007oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT03OlI6ATjo`00013o6ATI00?o
0000oc<c<olc<c<02_lc<c<00ol0003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV00KoIVIV00?o
0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o
0000olc<c?l000003OoVi^H00ol0003oooooooooo`0Hooooo`7o00000Oooool1ooooo`00;_ooool0
0ol0003oooooooooo`1Gooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`00_o<c<`0
0ol0003o/k>cok>c/`02ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01?moOgl0
0ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<00OoC4a<00?o0000oc<c<olc<c<02Olc<c<0
0ol0003o6ATIoaTI6@0=oaTI6C_o00004?lI6AT00ol0003o<c<coc<c<`09oc<c<`03o`000?m<C4co
C4a<00SoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWo
VIVI00GoVIVI00?o0000ok>c/onc/k<01?nc/k<01?l0003oc<c<olc<c?l0000=onKViP03o`000?oo
oooooooo01Sooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo05Oooooo00?o0000
onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000
oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000
oda<C?m<C4`01om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00co6ATI>ol0000@
oaTI6@03o`000?lc<c?o<c<c00[o<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP06
ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`04
ok>c/`04o`000?o<c<coc<c<o`0000goi^KV00?o0000ooooooooool06Oooool1o`00007ooooo0Ooo
ool002kooooo00?o0000ooooooooool0Eoooool00ol0003oi^KVonKViP04onKViP03o`000?o<c<co
c<c<00?oc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgoo
Ogmo00CoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C007oda<C003o`000?lc<c?o
<c<c00Wo<c<c00?o0000oaTI6OlI6AT03?lI6ATlo`00013o6ATI00?o0000oc<c<olc<c<02Olc<c<0
0ol0003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01_moOgl0
0ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c00Co/k>c00Co0000olc<c?o<c<co00003?oV
i^H00ol0003oooooooooo`0Jooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`1G
ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`02
ok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP06
ofIVIP03o`000?m<C4coC4a<00OoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0;
oaTI6Cco00004?lI6AT00ol0003o<c<coc<c<`0:oc<c<`03o`000?m<C4coC4a<00SoC4a<00?o0000
ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000
ok>c/onc/k<01?nc/k<01?l0003oc<c<olc<c?l0000=onKViP03o`000?oooooooooo01[ooooo0Ol0
0001ooooo`7ooooo000^ooooo`03o`000?oooooooooo05Oooooo00?o0000onKVi_oVi^H01?oVi^H0
0ol0003oc<c<olc<c003olc<c005o`000?nc/k?o/k>cok>c/ol000001_nIVIT00ol0003oOgmoogmo
O`04ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<coc<c
<`09oc<c<`03o`000?lI6AWo6ATI00co6ATI??l0000@oaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o
0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00KoOgmo00?o
0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`04ok>c/`05o`000?o<c<coc<c<olc<c?l00000
2ooVi^H2o`0001gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo05Kooooo00?o
0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00;o/k>c00?o
0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o
0000oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00co6ATI?Ol0
000?oaTI6@03o`000?lc<c?o<c<c00[o<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIV
IP06ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c
/`05ok>c/`04o`000?o<c<coc<c<o`0000_oi^KV00?o0000ooooooooool07Oooool1o`00007ooooo
0Oooool002kooooo00?o0000ooooooooool0E_ooool00ol0003oi^KVonKViP05onKViP03o`000?o<
c<coc<c<00;oc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?mo
OgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C007oda<C003o`000?lc
<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT03?lI6ATlo`00013o6ATI00?o0000oc<c<olc<c<02Olc
<c<00ol0003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01_mo
Ogl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00Co/k>c00Go0000olc<c?o<c<coc<c<
o`00000:onKViP03o`000?oooooooooo01kooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oo
oooooooo05Kooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c002olc<c005o`000?nc
/k?o/k>cok>c/ol000001_nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00KoIVIV
00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00co6ATI
?Ol0000@oaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIV
ofIVIP06ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>c
ok>c/`04ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003ooooo
ooooo`0Oooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`1Fooooo`03o`000?oV
i^Koi^KV00Goi^KV00?o0000olc<c?o<c<`00_o<c<`01Ol0003o/k>cok>c/onc/k?o000000GoVIVI
00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<00OoC4a<
00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0;oaTI6Cgo00004?lI6AT00ol0003o<c<c
oc<c<`09oc<c<`03o`000?m<C4coC4a<00SoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmo
ogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<
olc<c002olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool08?ooool1o`00007ooooo
0Oooool002kooooo00?o0000ooooooooool0E_ooool00ol0003oi^KVonKViP04onKViP03o`000?o<
c<coc<c<00?oc<c<00Go0000ok>c/onc/k?o/k>co`000005oiVIV@03o`000?moOgooOgmo00?oOgmo
00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C006oda<C003o`000?lc<c?o<c<c00Wo<c<c
00?o0000oaTI6OlI6AT03?lI6ATmo`00013o6ATI00?o0000oc<c<olc<c<02Olc<c<00ol0003oC4a<
oda<C007oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVI
oiVIV@04oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003oi^KV
onKViP06onKViP03o`000?oooooooooo027ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oo
oooooooo05Kooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc
/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mV
IVKoIVIV00GoIVIV00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI
6AWo6ATI00co6ATI?Ol0000@oaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<C?m<C4`01om<
C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01?nI
VIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H01_oV
i^H00ol0003oooooooooo`0Rooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`1F
ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`00_o<c<`01Ol0003o/k>cok>c/onc
/k?o000000GoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<
C4coC4a<00KoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0<oaTI6Cgo00004?lI
6AT00ol0003o<c<coc<c<`09oc<c<`03o`000?m<C4coC4a<00OoC4a<00?o0000ofIVI_mVIVH01_mV
IVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<01?nc
/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Goi^KV00?o0000ooooooooool08ooo
ool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0E_ooool00ol0003oi^KVonKViP04
onKViP03o`000?o<c<coc<c<00;oc<c<00Go0000ok>c/onc/k?o/k>co`000004oiVIV@03o`000?mo
OgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C006oda<C003o`000?lc
<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT03?lI6ATmo`00013o6ATI00?o0000oc<c<olc<c<02Olc
<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01Omo
Ogl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<
c<`00ol0003oi^KVonKViP05onKViP03o`000?oooooooooo02Cooooo0Ol00001ooooo`7ooooo000^
ooooo`03o`000?oooooooooo05Kooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c002
olc<c005o`000?nc/k?o/k>cok>c/ol000001?nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mV
IVKoIVIV00GoIVIV00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI
6AWo6ATI00co6ATI?Ol0000@oaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<C?m<C4`01om<
C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nI
VIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oVi^H01OoV
i^H00ol0003oooooooooo`0Tooooo`7o00000Oooool1ooooo`00;_ooool2o`0005Kooooo00?o0000
onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c002olc<c005o`000?nc/k?o/k>cok>c/ol000001?nI
VIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`01_m<
C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00co6ATI?Ol0000@oaTI6@03o`000?lc
<c?o<c<c00Wo<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?mo
OgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<
c<coc<c<00?oc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`0Sooooo`?o00000_oo
ool002kooooo00?o0000ooooooooool0E?ooool00ol0003oi^KVonKViP04onKViP03o`000?o<c<co
c<c<00?oc<c<00Go0000ok>c/onc/k?o/k>co`000004oiVIV@03o`000?moOgooOgmo00CoOgmo00?o
0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C006oda<C003o`000?lc<c?o<c<c00So<c<c00?o
0000oaTI6OlI6AT03OlI6ATlo`00013o6ATI00?o0000oc<c<olc<c<02Olc<c<00ol0003oC4a<oda<
C007oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVI
V@04oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKV
iP05onKViP03o`000?oooooooooo02Kooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooo
oooo05Cooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o
/k>c00;o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKo
IVIV00GoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?lI6AWo
6ATI00go6ATI?Ol0000@oaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<C?m<C4`01_m<C4`0
0ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT0
0ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01OoVi^H0
0ol0003oooooooooo`0Vooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`1Coooo
o`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`00oo<c<`01Ol0003o/k>cok>c/onc/k?o
000000CoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4co
C4a<00KoC4a<00?o0000oc<c<olc<c<02?lc<c<00ol0003o6ATIoaTI6@0=oaTI6Cco00004?lI6AT0
0ol0003o<c<coc<c<`09oc<c<`03o`000?m<C4coC4a<00OoC4a<00?o0000ofIVI_mVIVH01_mVIVH0
0ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<0
0ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00Goi^KV00?o0000ooooooooool09oooool1
o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0Doooool00ol0003oi^KVonKViP04onKV
iP03o`000?o<c<coc<c<00?oc<c<00Go0000ok>c/onc/k?o/k>co`000004oiVIV@03o`000?moOgoo
Ogmo00?oOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C007oda<C003o`000?lc<c?o
<c<c00Oo<c<c00?o0000oaTI6OlI6AT03OlI6ATmo`00013o6ATI00?o0000oc<c<olc<c<02?lc<c<0
0ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01OmoOgl0
0ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<c<`0
0ol0003oi^KVonKViP05onKViP03o`000?oooooooooo02Oooooo0Ol00001ooooo`7ooooo000^oooo
o`03o`000?oooooooooo05;ooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c003olc<
c005o`000?nc/k?o/k>cok>c/ol000001OnIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKo
IVIV00GoIVIV00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`08oc<c<`03o`000?lI6AWo
6ATI00go6ATI??l0000@oaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<C?m<C4`01_m<C4`0
0ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT0
0ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01OoVi^H0
0ol0003oooooooooo`0Xooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`1Aoooo
o`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`01Ol0003o/k>cok>c/onc/k?o
000000CoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4co
C4a<00OoC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003o6ATIoaTI6@0=oaTI6Cco00004?lI6AT0
0ol0003o<c<coc<c<`09oc<c<`03o`000?m<C4coC4a<00OoC4a<00?o0000ofIVI_mVIVH01_mVIVH0
0ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<0
0ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool0:?ooool1
o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0D?ooool00ol0003oi^KVonKViP05onKV
iP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@02oiVI
V@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C006oda<
C003o`000?lc<c?o<c<c00So<c<c00?o0000oaTI6OlI6AT03OlI6ATlo`00013o6ATI00?o0000oc<c
<olc<c<02?lc<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmo
OomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<
c?o<c<`01?o<c<`00ol0003oi^KVonKViP06onKViP03o`000?oooooooooo02Wooooo0Ol00001oooo
o`7ooooo000^ooooo`03o`000?oooooooooo04oooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003o
c<c<olc<c003olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003o
OgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o
<c<coc<c<`07oc<c<`03o`000?lI6AWo6ATI00go6ATI??l0000@oaTI6@03o`000?lc<c?o<c<c00Wo
<c<c00?o0000oda<C?m<C4`01_m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00Go
Ogmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?o
c<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003oooooooooo`0Yooooo`7o00000Oooool1ooooo`00
;_ooool00ol0003oooooooooo`1>ooooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`0
0oo<c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl0
0omoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<00KoC4a<00?o0000oc<c<olc<c<0
2?lc<c<00ol0003o6ATIoaTI6@0=oaTI6Cco00003olI6AT00ol0003o<c<coc<c<`09oc<c<`03o`00
0?m<C4coC4a<00OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`00
0?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`00
0?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool0:_ooool1o`00007ooooo0Oooool002kooooo00?o
0000ooooooooool0COooool00ol0003oi^KVonKViP06onKViP03o`000?o<c<coc<c<00?oc<c<00?o
0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00CoOgmo00?o
0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C007oda<C003o`000?lc<c?o<c<c00So<c<c00?o
0000oaTI6OlI6AT03?lI6ATlo`0000oo6ATI00?o0000oc<c<olc<c<02Olc<c<00ol0003oC4a<oda<
C007oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVI
V@04oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKV
iP08onKViP03o`000?oooooooooo02[ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooo
oooo04cooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o
/k>c00;o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKo
IVIV00GoIVIV00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`08oc<c<`03o`000?lI6AWo
6ATI00go6ATI>ol0000@oaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<C?m<C4`01om<C4`0
0ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT00onIVIT0
0ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oVi^H02?oVi^H0
0ol0003oooooooooo`0[ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`1;oooo
o`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c
/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP05ofIV
IP03o`000?m<C4coC4a<00KoC4a<00?o0000oc<c<olc<c<02?lc<c<00ol0003o6ATIoaTI6@0<oaTI
6Cco00003olI6AT00ol0003o<c<coc<c<`09oc<c<`03o`000?m<C4coC4a<00OoC4a<00?o0000ofIV
I_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c
/onc/k<00onc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Woi^KV00?o0000oooo
ooooool0:oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0B_ooool00ol0003o
i^KVonKViP06onKViP;o00001Oo<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00;o
VIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<00Ko
C4a<00?o0000oc<c<olc<c<02?lc<c<00ol0003o6ATIoaTI6@0<oaTI6Cco00003olI6AT00ol0003o
<c<coc<c<`09oc<c<`03o`000?m<C4coC4a<00OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003o
OgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003o
c<c<olc<c002olc<c003o`000?oVi^Koi^KV00Woi^KV00?o0000ooooooooool0;?ooool1o`00007o
oooo0Oooool002kooooo00?o0000ooooooooool0B_ooool00ol0003oi^KVonKViP06onKViP03o`00
0?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`00
0?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C006oda<C003o`00
0?lc<c?o<c<c00So<c<c00?o0000oaTI6OlI6AT03?lI6ATlo`0000oo6ATI00?o0000oc<c<olc<c<0
2Olc<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl0
1_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`0
0_o<c<`00ol0003oi^KVonKViP09onKViP03o`000?oooooooooo02cooooo0Ol00001ooooo`7ooooo
000^ooooo`03o`000?oooooooooo04Wooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<
c004olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmo
O`03ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c
<`08oc<c<`03o`000?lI6AWo6ATI00co6ATI?Ol0000>oaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o
0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00KoOgmo00?o
0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o
0000onKVi_oVi^H02OoVi^H00ol0003oooooooooo`0]ooooo`7o00000Oooool1ooooo`00;_ooool0
0ol0003oooooooooo`19ooooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`00oo<c<`0
0ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00omoOgl0
0ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<00KoC4a<00?o0000oc<c<olc<c<02?lc<c<0
0ol0003o6ATIoaTI6@0<oaTI6Cco00003_lI6AT00ol0003o<c<coc<c<`09oc<c<`03o`000?m<C4co
C4a<00OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWo
VIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Ko
i^KV00Woi^KV00?o0000ooooooooool0;_ooool1o`00007ooooo0Oooool002kooooo00?o0000oooo
ooooool0B?ooool00ol0003oi^KVonKViP06onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c
/onc/k<00onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIV
I_mVIVH01?mVIVH00ol0003oC4a<oda<C006oda<C003o`000?lc<c?o<c<c00So<c<c00?o0000oaTI
6OlI6AT03?lI6ATlo`0000oo6ATI00?o0000oc<c<olc<c<02Olc<c<00ol0003oC4a<oda<C007oda<
C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVI
V@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP08onKV
iP03o`000?oooooooooo02oooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo04So
oooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00?o
/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00Go
IVIV00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`08oc<c<`03o`000?lI6AWo6ATI00co
6ATI>ol0000?oaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003o
IVIVofIVIP05ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o
/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H02?oVi^H00ol0003o
ooooooooo`0`ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`17ooooo`03o`00
0?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`03o`00
0?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP04ofIVIP03o`00
0?m<C4coC4a<00KoC4a<00?o0000oc<c<olc<c<02?lc<c<00ol0003o6ATIoaTI6@0<oaTI6C_o0000
4?lI6AT00ol0003o<c<coc<c<`09oc<c<`03o`000?m<C4coC4a<00KoC4a<00?o0000ofIVI_mVIVH0
1_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<0
0onc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool0
<Oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0A_ooool00ol0003oi^KVonKV
iP07onKViP03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVI
V@03oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<
C005oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT03?lI6ATko`0000oo6ATI00?o
0000oc<c<olc<c<02Olc<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00GoIVIV00?o
0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o
0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo037ooooo0Ol0
0001ooooo`7ooooo000^ooooo`03o`000?oooooooooo04Gooooo00?o0000onKVi_oVi^H01ooVi^H0
0ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01?nIVIT0
0ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`01_m<C4`0
0ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00_o6ATI>ol0000?oaTI6@03o`000?lc<c?o
<c<c00Wo<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgoo
Ogmo00GoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<co
c<c<00?oc<c<00?o0000onKVi_oVi^H02?oVi^H00ol0003oooooooooo`0booooo`7o00000Oooool1
ooooo`00;_ooool2o`0004Gooooo00?o0000onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c002olc<
c003o`000?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`04ogmo
O`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`09oc<c
<`03o`000?lI6AWo6ATI00co6ATI>_l0000@oaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<
C?m<C4`01_m<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVI
VOnIVIT01OnIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKV
i_oVi^H01ooVi^H00ol0003oooooooooo`0aooooo`?o00000_ooool002kooooo00?o0000oooooooo
ool0@oooool00ol0003oi^KVonKViP08onKViP03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc
/k<00onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mV
IVH01OmVIVH00ol0003oC4a<oda<C006oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI
6AT03?lI6ATio`00013o6ATI00?o0000oc<c<olc<c<02Olc<c<00ol0003oC4a<oda<C007oda<C003
o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03
o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP07onKViP03
o`000?oooooooooo03Cooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo04;ooooo
00?o0000onKVi_oVi^H02?oVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00?o/k>c
00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00CoIVIV
00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00co6ATI
>_l0000?oaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIV
ofIVIP05ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>c
ok>c/`03ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003ooooo
ooooo`0eooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`11ooooo`03o`000?oV
i^Koi^KV00Woi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nI
VIWoVIVI00GoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<
C4coC4a<00KoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0<oaTI6CWo00003olI
6AT00ol0003o<c<coc<c<`09oc<c<`03o`000?m<C4coC4a<00OoC4a<00?o0000ofIVI_mVIVH01OmV
IVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<00onc
/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Soi^KV00?o0000ooooooooool0=Ooo
ool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0@?ooool00ol0003oi^KVonKViP09
onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@04
oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C006
oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT03?lI6ATio`00013o6ATI00?o0000
oc<c<olc<c<02Olc<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000
ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000
olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo03Kooooo0Ol00001
ooooo`7ooooo000^ooooo`03o`000?oooooooooo03oooooo00?o0000onKVi_oVi^H02_oVi^H00ol0
003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0
003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`01_m<C4`00ol0
003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00co6ATI>?l0000@oaTI6@03o`000?lc<c?o<c<c
00Wo<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo
00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<
00?oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003oooooooooo`0gooooo`7o00000Oooool1oooo
o`00;_ooool00ol0003oooooooooo`0nooooo`03o`000?oVi^Koi^KV00[oi^KV00?o0000olc<c?o<
c<`00oo<c<`01Ol0003o/k>cok>c/onc/k?o000000KoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0
003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<00KoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0
003o6ATIoaTI6@0<oaTI6CSo00004?lI6AT00ol0003o<c<coc<c<`09oc<c<`03o`000?m<C4coC4a<
00OoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI
00CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV
00Ooi^KV00?o0000ooooooooool0>?ooool1o`00007ooooo0Oooool002kooooo00?o0000oooooooo
ool0?Oooool00ol0003oi^KVonKViP0:onKViP03o`000?o<c<coc<c<00Coc<c<00Go0000ok>c/onc
/k?o/k>co`000006oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0
003oC4a<oda<C006oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT03?lI6ATho`00
013o6ATI00?o0000oc<c<olc<c<02Olc<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV
00GoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c
00?o/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo
03Sooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo03cooooo00?o0000onKVi_oV
i^H02_oVi^H00ol0003oc<c<olc<c004olc<c005o`000?nc/k?o/k>cok>c/ol000001_nIVIT00ol0
003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`01_m<C4`00ol0
003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00co6ATI>?l0000@oaTI6@03o`000?lc<c?o<c<c
00Wo<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo
00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<
00;oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003oooooooooo`0iooooo`7o00000Oooool1oooo
o`00;_ooool00ol0003oooooooooo`0looooo`03o`000?oVi^Koi^KV00Woi^KV00?o0000olc<c?o<
c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomo
Ogl01OmoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<00KoC4a<00?o0000oc<c<olc
<c<02Olc<c<00ol0003o6ATIoaTI6@0<oaTI6CSo00003olI6AT00ol0003o<c<coc<c<`09oc<c<`03
o`000?m<C4coC4a<00OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`04ogmoO`03
o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c002olc<c003
o`000?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool0>_ooool1o`00007ooooo0Oooool002kooooo
00?o0000ooooooooool0>oooool00ol0003oi^KVonKViP0:onKViP03o`000?o<c<coc<c<00?oc<c<
00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00CoOgmo
00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c00Wo<c<c
00?o0000oaTI6OlI6AT03OlI6ATgo`00013o6ATI00?o0000oc<c<olc<c<02?lc<c<00ol0003oC4a<
oda<C007oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVI
oiVIV@04oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003oi^KV
onKViP08onKViP03o`000?oooooooooo03[ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oo
oooooooo03_ooooo00?o0000onKVi_oVi^H02OoVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc
/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mV
IVKoIVIV00GoIVIV00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI
6AWo6ATI00co6ATI=ol0000@oaTI6@03o`000?lc<c?o<c<c00So<c<c00?o0000oda<C?m<C4`02?m<
C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT01?nI
VIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oVi^H01ooV
i^H00ol0003oooooooooo`0kooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0j
ooooo`03o`000?oVi^Koi^KV00Woi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03
ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP06
ofIVIP03o`000?m<C4coC4a<00GoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0=
oaTI6CKo00004?lI6AT00ol0003o<c<coc<c<`09oc<c<`03o`000?m<C4coC4a<00OoC4a<00?o0000
ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000
ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Soi^KV00?o0000
ooooooooool0>oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0>_ooool00ol0
003oi^KVonKViP08onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0
003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0
003oC4a<oda<C006oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT03OlI6ATeo`00
017o6ATI00?o0000oc<c<olc<c<02?lc<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV
00KoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c
00?o/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo
03cooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo03Wooooo00?o0000onKVi_oV
i^H02OoVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnI
VIT00onIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<
C4`01Om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00go6ATI=Ol0000AoaTI6@03
o`000?lc<c?o<c<c00So<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP05ofIVIP03
o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`03ok>c/`03
o`000?o<c<coc<c<00;oc<c<0_l00009onKViP;o0000?oooool1o`00007ooooo0Oooool002kooooo
00?o0000ooooooooool0>?ooool00ol0003oi^KVonKViP09onKViP03o`000?o<c<coc<c<00?oc<c<
00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo
00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C006oda<C003o`000?lc<c?o<c<c00Wo<c<c
00?o0000oaTI6OlI6AT03OlI6ATdo`00017o6ATI00?o0000oc<c<olc<c<02?lc<c<00ol0003oC4a<
oda<C008oda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVI
oiVIV@04oiVIV@03o`000?nc/k?o/k>c00?o/k>c00Go0000olc<c?o<c<coc<c<o`00000:onKViP03
o`000?oooooooooo03oooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo03Sooooo
00?o0000onKVi_oVi^H02?oVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c
00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00KoIVIV
00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00co6ATI
=Ol0000AoaTI6@03o`000?lc<c?o<c<c00So<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIV
ofIVIP05ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>c
ok>c/`03ok>c/`05o`000?o<c<coc<c<olc<c?l000002_oVi^H00ol0003oooooooooo`10ooooo`7o
00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0gooooo`03o`000?oVi^Koi^KV00Soi^KV
00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00CoVIVI
00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<00KoC4a<
00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0=oaTI6CCo00004OlI6AT00ol0003o<c<c
oc<c<`08oc<c<`03o`000?m<C4coC4a<00OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmo
ogmoO`04ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<
olc<c002o`0000Woi^KV0_l00013ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003ooooooooo
o`0gooooo`03o`000?oVi^Koi^KV00Soi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c
/`03ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIV
IP06ofIVIP03o`000?m<C4coC4a<00KoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI
6@0<oaTI6CCo00004OlI6AT00ol0003o<c<coc<c<`08oc<c<`03o`000?m<C4coC4a<00SoC4a<00?o
0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o
0000ok>c/onc/k<00onc/k<01?l0003oc<c<olc<c?l0000:onKViP03o`000?oooooooooo04?ooooo
0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo03Kooooo00?o0000onKVi_oVi^H02?oV
i^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnIVIT00onI
VIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`01_m<
C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00go6ATI<ol0000AoaTI6@03o`000?lc
<c?o<c<c00Wo<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?mo
OgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`02ok>c/`04o`000?o<
c<coc<c<o`0000[oi^KV00?o0000ooooooooool0A?ooool1o`00007ooooo0Oooool002kooooo00?o
0000ooooooooool0=_ooool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00Coc<c<00?o
0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o
0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C006oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o
0000oaTI6OlI6AT03OlI6ATbo`00017o6ATI00?o0000oc<c<olc<c<02Olc<c<00ol0003oC4a<oda<
C007oda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVI
V@04oiVIV@03o`000?nc/k?o/k>c00;o/k>c00Co0000olc<c?o<c<co00002_oVi^H00ol0003ooooo
ooooo`15ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0eooooo`03o`000?oV
i^Koi^KV00Ooi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nI
VIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<
C4coC4a<00KoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0=oaTI6C;o00004OlI
6AT00ol0003o<c<coc<c<`09oc<c<`03o`000?m<C4coC4a<00OoC4a<00?o0000ofIVI_mVIVH01OmV
IVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00_nc
/k<01?l0003oc<c<olc<c?l0000:onKViP03o`000?oooooooooo04Kooooo0Ol00001ooooo`7ooooo
000^ooooo`;o0000=_ooool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00Coc<c<00?o
0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o
0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C006oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o
0000oaTI6OlI6AT03OlI6ATbo`00017o6ATI00?o0000oc<c<olc<c<02Olc<c<00ol0003oC4a<oda<
C007oda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVI
V@04oiVIV@03o`000?nc/k?o/k>c00;o/k>c00Co0000olc<c?o<c<co00002_oVi^H00ol0003ooooo
ooooo`14ooooo`?o00000_ooool002kooooo00?o0000ooooooooool0=Oooool00ol0003oi^KVonKV
iP07onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVI
V@05oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<
C006oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT03_lI6ATbo`00013o6ATI00?o
0000oc<c<olc<c<02Olc<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00GoIVIV00?o
0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o
0000olc<c?l000002_oVi^H00ol0003oooooooooo`17ooooo`7o00000Oooool1ooooo`00;_ooool0
0ol0003oooooooooo`0eooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<c?o<c<`00oo<c<`0
0ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01OmoOgl0
0ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00KoC4a<00?o0000oc<c<olc<c<02Olc<c<0
0ol0003o6ATIoaTI6@0=oaTI6C;o00004?lI6AT00ol0003o<c<coc<c<`09oc<c<`03o`000?m<C4co
C4a<00OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWo
VIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<01?l0003oc<c<olc<c?l0000:onKViP03o`000?oo
oooooooo04Oooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo03Gooooo00?o0000
onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000
oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000
oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00ko6ATI<Ol0000@
oaTI6@03o`000?lc<c?o<c<c00[o<c<c00?o0000oda<C?m<C4`01_m<C4`00ol0003oIVIVofIVIP06
ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`03
ok>c/`05o`000?o<c<coc<c<olc<c?l000002_oVi^H00ol0003oooooooooo`17ooooo`7o00000Ooo
ool1ooooo`00;_ooool00ol0003oooooooooo`0eooooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000
olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000
ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00KoC4a<00?o0000
oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0>oaTI6C3o00004?lI6AT00ol0003o<c<coc<c<`0:
oc<c<`03o`000?m<C4coC4a<00OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`04
ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00_nc/k<01Ol0003oc<c<olc<c?o<
c<co000000[oi^KV00?o0000ooooooooool0B?ooool1o`00007ooooo0Oooool002kooooo00?o0000
ooooooooool0=Oooool00ol0003oi^KVonKViP06onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000
ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000
ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C007oda<C003o`000?lc<c?o<c<c00So<c<c00?o0000
oaTI6OlI6AT03_lI6AT`o`00013o6ATI00?o0000oc<c<olc<c<02_lc<c<00ol0003oC4a<oda<C007
oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@04
oiVIV@03o`000?nc/k?o/k>c00?o/k>c00Go0000olc<c?o<c<coc<c<o`00000:onKViP03o`000?oo
oooooooo04Sooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo03Gooooo00?o0000
onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000
oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000
oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00ko6ATI;ol0000@
oaTI6@03o`000?lc<c?o<c<c00[o<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIVIP06
ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`03
ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003oooooooooo`19
ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0eooooo`03o`000?oVi^Koi^KV
00Koi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nIVIWoVIVI
00CoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<
00KoC4a<00?o0000oc<c<olc<c<02?lc<c<00ol0003o6ATIoaTI6@0?oaTI6Bko00004?lI6AT00ol0
003o<c<coc<c<`0;oc<c<`03o`000?m<C4coC4a<00KoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0
003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0
003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Soi^KV00?o0000ooooooooool0BOooool1o`00
007ooooo0Oooool002kooooo00?o0000ooooooooool0=_ooool00ol0003oi^KVonKViP05onKViP03
o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03
o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C006oda<C003
o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT03_lI6AT_o`00013o6ATI00?o0000oc<c<olc
<c<02_lc<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomo
Ogl01?moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<
c<`00oo<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo04[ooooo0Ol00001ooooo`7o
oooo000^ooooo`03o`000?oooooooooo03Kooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<
olc<c003olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmo
ogmoO`04ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<c
oc<c<`09oc<c<`03o`000?lI6AWo6ATI00ko6ATI;_l0000@oaTI6@03o`000?lc<c?o<c<c00[o<c<c
00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo
00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00;oc<c<
00?o0000onKVi_oVi^H02?oVi^H00ol0003oooooooooo`1:ooooo`7o00000Oooool1ooooo`00;_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`00_o<
c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01?mo
Ogl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00OoC4a<00?o0000oc<c<olc<c<02?lc
<c<00ol0003o6ATIoaTI6@0?oaTI6Bgo00004?lI6AT00ol0003o<c<coc<c<`0;oc<c<`03o`000?m<
C4coC4a<00KoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nI
VIWoVIVI00?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c002olc<c003o`000?oV
i^Koi^KV00Soi^KV00?o0000ooooooooool0Boooool1o`00007ooooo0Oooool002kooooo00?o0000
ooooooooool0=_ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00;oc<c<00?o0000
ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000
ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C006oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000
oaTI6OlI6AT03_lI6AT]o`00017o6ATI00?o0000oc<c<olc<c<02_lc<c<00ol0003oC4a<oda<C006
oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@03
oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003oi^KVonKViP08
onKViP03o`000?oooooooooo04cooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo
03Kooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c
00;o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV
00GoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI
00ko6ATI;?l0000AoaTI6@03o`000?lc<c?o<c<c00[o<c<c00?o0000oda<C?m<C4`01om<C4`00ol0
003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0
003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H02?oVi^H00ol0
003oooooooooo`1<ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0fooooo`03
o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`00oo<c<`01Ol0003o/k>cok>c/onc/k?o0000
00KoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<
00OoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0>oaTI6B_o00004_lI6AT00ol0
003o<c<coc<c<`09oc<c<`03o`000?m<C4coC4a<00OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0
003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0
003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Soi^KV00?o0000ooooooooool0COooool1o`00
007ooooo0Oooool002kooooo00?o0000ooooooooool0=_ooool00ol0003oi^KVonKViP04onKViP03
o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03
o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C006oda<C003
o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT03_lI6ATZo`0001?o6ATI00?o0000oc<c<olc
<c<02Olc<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomo
Ogl01OmoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<
c<`00_o<c<`00ol0003oi^KVonKViP09onKViP03o`000?oooooooooo04gooooo0Ol00001ooooo`7o
oooo000^ooooo`03o`000?oooooooooo03Kooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<
olc<c002olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmo
ogmoO`04ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<c
oc<c<`09oc<c<`03o`000?lI6AWo6ATI00ko6ATI:Ol0000CoaTI6@03o`000?lc<c?o<c<c00Wo<c<c
00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo
00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00;oc<c<
00?o0000onKVi_oVi^H02?oVi^H2o`00053ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oo
oooooooo03Kooooo00?o0000onKVi_oVi^H00ooVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc
/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mV
IVKoIVIV00KoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI
6AWo6ATI00ko6ATI:?l0000DoaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<C?m<C4`01om<
C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT00onI
VIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H01ooV
i^H00ol0003oooooooooo`1@ooooo`7o00000Oooool1ooooo`003Oooool3o`000003oa0@4?oooooo
oooo01_ooooo00?o0000ooooooooool0=Oooool00ol0003oi^KVonKViP04onKViP03o`000?o<c<co
c<c<00;oc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgoo
Ogmo00CoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C007oda<C003o`000?lc<c?o
<c<c00Wo<c<c00?o0000oaTI6OlI6AT03olI6ATWo`0001Co6ATI00?o0000oc<c<olc<c<02Olc<c<0
0ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl01_moOgl0
0ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00_o<c<`0
0ol0003oi^KVonKViP07onKViP03o`000?oooooooooo057ooooo0Ol00001ooooo`7ooooo000?oooo
o`03oa0@4?nj^[[ooooo01cooooo00?o0000ooooooooool0=Oooool00ol0003oi^KVonKViP03onKV
iP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@03oiVI
V@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C007oda<
C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT03olI6ATVo`0001Co6ATI00?o0000oc<c
<olc<c<02Olc<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmo
OomoOgl01_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<
c?o<c<`00_o<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo05;ooooo0Ol00001oooo
o`7ooooo000?ooooo`03oiRHV?lb<S;ooooo01cooooo00?o0000ooooooooool0=?ooool00ol0003o
i^KVonKViP04onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003o
VIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003o
C4a<oda<C007oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT03olI6ATUo`0001Co
6ATI00?o0000oc<c<olc<c<02Olc<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00Ko
IVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00?o
/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP06onKViP03o`000?oooooooooo05?o
oooo0Ol00001ooooo`7ooooo000?ooooo`03omgMgOl0003o^[Zj01;ooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo03Cooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<
olc<c002olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmo
ogmoO`04ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<c
oc<c<`09oc<c<`03o`000?lI6AWo6ATI013o6ATI9?l0000DoaTI6@03o`000?lc<c?o<c<c00Wo<c<c
00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00GoOgmo
00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00;oc<c<
00?o0000onKVi_oVi^H01_oVi^H00ol0003oooooooooo`1Dooooo`7o00000Oooool1ooooo`003ooo
ool00omEEEGoMgMgodA4A00Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<ooo
ool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00_nc
/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01_mV
IVH00ol0003oC4a<oda<C007oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT04?lI
6ATSo`0001Co6ATI00?o0000oc<c<olc<c<02Olc<c<00ol0003oC4a<oda<C008oda<C003o`000?mV
IVKoIVIV00GoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc
/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP06onKViP03o`000?oo
oooooooo05Cooooo0Ol00001ooooo`7ooooo000>ooooo`05omgMgOl@413oooooob4Q8OoMgMd04ooo
ool00ol0003oooooooooo`05ooooo`?o0000<oooool00ol0003oi^KVonKViP04onKViP03o`000?o<
c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?mo
OgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C007oda<C003o`000?lc
<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT04OlI6ATRo`0001Co6ATI00?o0000oc<c<olc<c<02Olc
<c<00ol0003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl01Omo
Ogl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00oo<
c<`00ol0003oi^KVonKViP06onKViP03o`000?oooooooooo05?ooooo0ol00002ooooo`003_ooool0
1OmVIVKoQhN7oooooonHV9SoEEEE01?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0cooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c
/`02ok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIV
IP06ofIVIP03o`000?m<C4coC4a<00OoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI
6@0AoaTI6B7o00005OlI6AT00ol0003o<c<coc<c<`08oc<c<`03o`000?m<C4coC4a<00WoC4a<00?o
0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o
0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Koi^KV00?o
0000ooooooooool0E_ooool1o`00007ooooo0Oooool000gooooo00?ok^k^o`000?o^k^h00_ooool0
0ol0003ogMgMooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<_ooool0
0ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00_nc/k<0
0ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01_mVIVH0
0ol0003oC4a<oda<C007oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT04OlI6ATP
o`0001Go6ATI00?o0000oc<c<olc<c<02Olc<c<00ol0003oC4a<oda<C008oda<C003o`000?mVIVKo
IVIV00GoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o
/k>c00?o/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP06onKViP03o`000?oooooo
oooo05Kooooo0Ol00001ooooo`7ooooo000=ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@
ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03;ooooo00?o0000
onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000
oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000
oda<C?m<C4`01om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI01;o6ATI7_l0000F
oaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP05
ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`03
ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oVi^H01_oVi^H00ol0003oooooooooo`1G
ooooo`7o00000Oooool1ooooo`009_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
037ooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c
00;o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV
00KoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI
01;o6ATI7Ol0000FoaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0
003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0
003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0
003oooooooooo`1Gooooo`7o00000Oooool1ooooo`009?ooool00omEEEGoIVIVo`000007ooooo`03
o`000?oooooooooo033ooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c003olc<c003
o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`04ogmoO`03
o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<coc<c<`09oc<c<`03
o`000?lI6AWo6ATI01?o6ATI7?l0000FoaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<C?m<
C4`02Om<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnI
VIT01OnIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oV
i^H01ooVi^H00ol0003oooooooooo`1Hooooo`7o00000Oooool1ooooo`00;_ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>c
ok>c/`02ok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIV
ofIVIP05ofIVIP03o`000?m<C4coC4a<00OoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATI
oaTI6@0CoaTI6A_o00005_lI6AT00ol0003o<c<coc<c<`0:oc<c<`03o`000?m<C4coC4a<00SoC4a<
00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00GoVIVI
00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Koi^KV
00?o0000ooooooooool0FOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0;_oo
ool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<00_nc
/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01_mV
IVH00ol0003oC4a<oda<C007oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT04olI
6ATJo`0001Ko6ATI00?o0000oc<c<olc<c<02_lc<c<00ol0003oC4a<oda<C008oda<C003o`000?mV
IVKoIVIV00GoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc
/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP07onKViP03o`000?oo
oooooooo05Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo02gooooo00?o0000
onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000
oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000
oda<C?m<C4`01om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI01Co6ATI6Ol0000F
oaTI6@03o`000?lc<c?o<c<c00[o<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP05
ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`03
ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003oooooooooo`1J
ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0]ooooo`03o`000?oVi^Koi^KV
00Ooi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI
00?oVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<
00OoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0EoaTI6AKo00006?lI6AT00ol0
003o<c<coc<c<`0:oc<c<`03o`000?m<C4coC4a<00SoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0
003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0
003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool0F_ooool1o`00
007ooooo0Oooool002kooooo00?o0000ooooooooool0;?ooool00ol0003oi^KVonKViP07onKViP03
o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@03oiVIV@03
o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C007oda<C003
o`000?lc<c?o<c<c00[o<c<c00?o0000oaTI6OlI6AT05_lI6ATDo`0001So6ATI00?o0000oc<c<olc
<c<02_lc<c<00ol0003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomo
Ogl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<
c<`00oo<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo05_ooooo0Ol00001ooooo`7o
oooo000^ooooo`03o`000?oooooooooo02cooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<
olc<c003olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmo
ogmoO`04ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<c
oc<c<`09oc<c<`03o`000?lI6AWo6ATI01So6ATI4_l0000HoaTI6@03o`000?lc<c?o<c<c00[o<c<c
00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00GoOgmo
00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00?oc<c<
00?o0000onKVi_oVi^H01ooVi^H00ol0003oooooooooo`1Looooo`7o00000Oooool1ooooo`00;_oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<c?o<c<`00_o<
c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl01?mo
Ogl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<02Olc
<c<00ol0003o6ATIoaTI6@0IoaTI6@oo00006OlI6AT00ol0003o<c<coc<c<`0:oc<c<`03o`000?m<
C4coC4a<00SoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nI
VIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c003olc<c003o`000?oV
i^Koi^KV00Ooi^KV00?o0000ooooooooool0GOooool1o`00007ooooo0Oooool002kooooo00?o0000
ooooooooool0:oooool00ol0003oi^KVonKViP06onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000
ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000
ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C007oda<C003o`000?lc<c?o<c<c00[o<c<c00?o0000
oaTI6OlI6AT06_lI6AT;o`0001_o6ATI00?o0000oc<c<olc<c<02olc<c<00ol0003oC4a<oda<C007
oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04
oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP07
onKViP03o`000?oooooooooo05gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo
02[ooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c
00?o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV
00GoIVIV00?o0000oda<C?m<C4`02?m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI
01co6ATI2?l0000MoaTI6@03o`000?lc<c?o<c<c00[o<c<c00?o0000oda<C?m<C4`01om<C4`00ol0
003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0
003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0
003oooooooooo`1Nooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0Zooooo`03
o`000?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`03ok>c/`03
o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP05ofIVIP03
o`000?m<C4coC4a<00OoC4a<00?o0000oc<c<olc<c<02_lc<c<00ol0003o6ATIoaTI6@0MoaTI6@Go
00007_lI6AT00ol0003o<c<coc<c<`0:oc<c<`03o`000?m<C4coC4a<00OoC4a<00?o0000ofIVI_mV
IVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc
/k<00onc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000oooooooo
ool0Goooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0:Oooool00ol0003oi^KV
onKViP06onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVI
oiVIV@04oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<
oda<C008oda<C003o`000?lc<c?o<c<c00[o<c<c00?o0000oaTI6OlI6AT07_lI6AT00ol0003o6ATI
oaTI6@0NoaTI6@03o`000?lc<c?o<c<c00[o<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIV
ofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>c
ok>c/`03ok>c/`03o`000?o<c<coc<c<00;oc<c<0_l00009onKViP03o`000?oooooooooo063ooooo
0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo02Wooooo00?o0000onKVi_oVi^H01OoV
i^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT00onI
VIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`02?m<
C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI03oo6ATI00?o0000oc<c<olc<c<02olc
<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01Omo
Ogl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`00_o<
c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo067ooooo0Ol00001ooooo`7ooooo000^
ooooo`03o`000?oooooooooo02Sooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c003
olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`05
ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`02?m<C4`00ol0003o<c<coc<c<`0:
oc<c<`03o`000?lI6AWo6ATI03ko6ATI00?o0000oc<c<olc<c<02olc<c<00ol0003oC4a<oda<C007
oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04
oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003oi^KVonKViP08
onKViP03o`000?oooooooooo06;ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo
02Sooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c
00?o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV
00GoIVIV00?o0000oda<C?m<C4`02?m<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`000?lI6AWo6ATI
03go6ATI00?o0000oc<c<olc<c<02olc<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV
00KoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c
00?o/k>c00Go0000olc<c?o<c<coc<c<o`00000:onKViP03o`000?oooooooooo06?ooooo0Ol00001
ooooo`7ooooo000^ooooo`03o`000?oooooooooo02Oooooo00?o0000onKVi_oVi^H01OoVi^H00ol0
003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0
003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`02?m<C4`00ol0
003o<c<coc<c<`0;oc<c<`03o`000?lI6AWo6ATI03co6ATI00?o0000oc<c<olc<c<02olc<c<00ol0
003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0
003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00?o/k>c00Go0000olc<c?o<c<coc<c<o`00000:
onKViP03o`000?oooooooooo06Cooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo
02Oooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c
00;o/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV
00GoIVIV00?o0000oda<C?m<C4`02?m<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`000?lI6AWo6ATI
03co6ATI00?o0000oc<c<olc<c<02olc<c<00ol0003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV
00KoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c
00;o/k>c00Go0000olc<c?o<c<coc<c<o`00000:onKViP03o`000?oooooooooo06Gooooo0Ol00001
ooooo`7ooooo000^ooooo`;o00009oooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<
00?oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo
00GoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c
00[o<c<c00?o0000oaTI6OlI6AT0>olI6AT00ol0003o<c<coc<c<`0;oc<c<`03o`000?m<C4coC4a<
00SoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI
00CoVIVI00?o0000ok>c/onc/k<00_nc/k<01Ol0003oc<c<olc<c?o<c<co000000[oi^KV00?o0000
ooooooooool0I?ooool3o`0000;ooooo000^ooooo`03o`000?oooooooooo02Cooooo0_l00007onKV
iP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVI
V@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C008oda<
C003o`000?lc<c?o<c<c00_o<c<c00?o0000oaTI6OlI6AT0>_lI6AT00ol0003o<c<coc<c<`0;oc<c
<`03o`000?m<C4coC4a<00SoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmo
O`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00_nc/k<01Ol0003oc<c<olc<c?o<c<co
000000[oi^KV00?o0000ooooooooool0Ioooool1o`00007ooooo0Oooool002kooooo00?o0000oooo
ooooool08oooool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c
/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIV
I_mVIVH01OmVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00_o<c<c00?o0000oaTI
6OlI6AT0>OlI6AT00ol0003o<c<coc<c<`0<oc<c<`03o`000?m<C4coC4a<00SoC4a<00?o0000ofIV
I_mVIVH01OmVIVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c
/onc/k<00_nc/k<01Ol0003oc<c<olc<c?o<c<co000000[oi^KV00?o0000ooooooooool0Ioooool1
o`00007ooooo0Oooool002kooooo00?o0000ooooooooool08_ooool00ol0003oi^KVonKViP07onKV
iP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVI
V@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C008oda<
C003o`000?lc<c?o<c<c00_o<c<c00?o0000oaTI6OlI6AT0>OlI6AT00ol0003o<c<coc<c<`0<oc<c
<`03o`000?m<C4coC4a<00SoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`06ogmo
O`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<01?l0003oc<c<olc<c?l0000:
onKViP03o`000?oooooooooo06Sooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo
023ooooo0_l00009onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01?nc/k<00ol0
003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0
003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00_o<c<c00?o0000oaTI6OlI6AT0>?lI6AT00ol0
003o<c<coc<c<`0<oc<c<`03o`000?m<C4coC4a<00SoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0
003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<01Ol0
003oc<c<olc<c?o<c<co000000Woi^KV00?o0000ooooooooool0JOooool1o`00007ooooo0Oooool0
02kooooo00?o0000ooooooooool07oooool00ol0003oi^KVonKViP09onKViP03o`000?o<c<coc<c<
00?oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo
00GoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c
00_o<c<c00?o0000oaTI6OlI6AT0>?lI6AT00ol0003o<c<coc<c<`0;oc<c<`03o`000?m<C4coC4a<
00SoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI
00CoVIVI00?o0000ok>c/onc/k<00onc/k<01Ol0003oc<c<olc<c?o<c<co000000[oi^KV00?o0000
ooooooooool0JOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool07Oooool2o`00
00_oi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI
00?oVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<
00SoC4a<00?o0000oc<c<olc<c<02olc<c<00ol0003o6ATIoaTI6@0hoaTI6@03o`000?lc<c?o<c<c
00co<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo
00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`03ok>c/`05o`000?o<c<coc<c<
olc<c?l000002_oVi^H00ol0003oooooooooo`1Zooooo`7o00000Oooool1ooooo`00;_ooool00ol0
003oooooooooo`0Looooo`03o`000?oVi^Koi^KV00[oi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0
003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl01_moOgl00ol0
003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<02olc<c<00ol0
003o6ATIoaTI6@0goaTI6@03o`000?lc<c?o<c<c00co<c<c00?o0000oda<C?m<C4`01om<C4`00ol0
003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0
003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H02?oVi^H00ol0
003oooooooooo`1Zooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oVi^Koi^KV00_oi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`03
o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP05ofIVIP03
o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<03?lc<c<00ol0003o6ATIoaTI6@0foaTI6@03
o`000?lc<c?o<c<c00co<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP05ofIVIP03
o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`04ok>c/`05
o`000?o<c<coc<c<olc<c?l000002_oVi^H00ol0003oooooooooo`1[ooooo`7o00000Oooool1oooo
o`00;_ooool00ol0003oooooooooo`0Jooooo`03o`000?oVi^Koi^KV00_oi^KV00?o0000olc<c?o<
c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomo
Ogl01_moOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc
<c<02olc<c<00ol0003o6ATIoaTI6@0foaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<
C4`01om<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnI
VIT01?nIVIT00ol0003o/k>cok>c/`03ok>c/`05o`000?o<c<coc<c<olc<c?l000002_oVi^H00ol0
003oooooooooo`1/ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oVi^Koi^KV00_oi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`03
o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP06ofIVIP03
o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<02olc<c<00ol0003o6ATIoaTI6@0eoaTI6@03
o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIVIP06ofIVIP03
o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`03ok>c/`05
o`000?o<c<coc<c<olc<c?l000002ooVi^H00ol0003oooooooooo`1/ooooo`7o00000Oooool1oooo
o`00;_ooool00ol0003oooooooooo`0Iooooo`03o`000?oVi^Koi^KV00_oi^KV00?o0000olc<c?o<
c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomo
Ogl01omoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc
<c<03?lc<c<00ol0003o6ATIoaTI6@0doaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<
C4`01om<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnI
VIT00onIVIT00ol0003o/k>cok>c/`03ok>c/`05o`000?o<c<coc<c<olc<c?l000002ooVi^H00ol0
003oooooooooo`1]ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oVi^Koi^KV00[oi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`03
o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP06ofIVIP03
o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<02olc<c<00ol0003o6ATIoaTI6@0doaTI6@03
o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIVIP06ofIVIP03
o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`04ok>c/`04
o`000?o<c<coc<c<o`0000_oi^KV00?o0000ooooooooool0K_ooool1o`00007ooooo0Oooool002ko
oooo00?o0000ooooooooool06?ooool00ol0003oi^KVonKViP0:onKViP03o`000?o<c<coc<c<00Co
c<c<00?o0000ok>c/onc/k<01?nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00Ko
Ogmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00co
<c<c00?o0000oaTI6OlI6AT0<olI6AT00ol0003o<c<coc<c<`0=oc<c<`03o`000?m<C4coC4a<00So
C4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00Co
VIVI00?o0000ok>c/onc/k<00onc/k<01?l0003oc<c<olc<c?l0000;onKViP03o`000?oooooooooo
06oooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo01Oooooo00?o0000onKVi_oV
i^H02_oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnI
VIT01?nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<
C4`02?m<C4`00ol0003o<c<coc<c<`0<oc<c<`03o`000?lI6AWo6ATI03;o6ATI00?o0000oc<c<olc
<c<03Olc<c<00ol0003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomo
Ogl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00?o/k>c00Co0000olc<c?o<
c<co00003?oVi^H00ol0003oooooooooo`1_ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oVi^Koi^KV00Woi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o
/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003o
IVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<02olc<c<00ol0003o
6ATIoaTI6@0boaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003o
IVIVofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o
/k>cok>c/`03ok>c/`04o`000?o<c<coc<c<o`0000coi^KV00?o0000ooooooooool0L?ooool1o`00
007ooooo0Oooool002kooooo00?o0000ooooooooool05_ooool00ol0003oi^KVonKViP09onKViP03
o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01?nc/k<00ol0003oVIVIoiVIV@04oiVIV@03
o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C008oda<C003
o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT0<OlI6AT00ol0003o<c<coc<c<`0=oc<c<`03
o`000?m<C4coC4a<00SoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03
o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<01?l0003oc<c<olc<c?l0000<onKV
iP03o`000?oooooooooo077ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo01Ko
oooo00?o0000onKVi_oVi^H02OoVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Co
/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00Ko
IVIV00?o0000oda<C?m<C4`02?m<C4`00ol0003o<c<coc<c<`0<oc<c<`03o`000?lI6AWo6ATI037o
6ATI00?o0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV00Ko
IVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00?o
/k>c00Co0000olc<c?o<c<co00002ooVi^H00ol0003oooooooooo`1booooo`7o00000Oooool1oooo
o`00;_ooool00ol0003oooooooooo`0Fooooo`03o`000?oVi^Koi^KV00Soi^KV00?o0000olc<c?o<
c<`01Oo<c<`00ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomo
Ogl01_moOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc
<c<03Olc<c<00ol0003o6ATIoaTI6@0`oaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<
C4`02?m<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnI
VIT01?nIVIT00ol0003o/k>cok>c/`03ok>c/`04o`000?o<c<coc<c<o`0000_oi^KV00?o0000oooo
ooooool0Loooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool05_ooool00ol0003o
i^KVonKViP08onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003o
VIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003o
C4a<oda<C008oda<C003o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT0<?lI6AT00ol0003o
<c<coc<c<`0=oc<c<`03o`000?m<C4coC4a<00SoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003o
OgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<01Ol0003o
c<c<olc<c?o<c<co000000[oi^KV00?o0000ooooooooool0M?ooool1o`00007ooooo0Oooool002ko
oooo00?o0000ooooooooool05_ooool00ol0003oi^KVonKViP08onKViP03o`000?o<c<coc<c<00?o
c<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00Go
Ogmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00co
<c<c00?o0000oaTI6OlI6AT0;olI6AT00ol0003o<c<coc<c<`0=oc<c<`03o`000?m<C4coC4a<00Wo
C4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00Co
VIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Oo
i^KV00?o0000ooooooooool0MOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0
5_ooool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<0
1_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH0
1_mVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT0
;_lI6AT00ol0003o<c<coc<c<`0=oc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH0
1_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<0
0onc/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool0
M_ooool1o`00007ooooo0Oooool002kooooo0_l0000Gooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o
0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o
0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o
0000oc<c<olc<c<03Olc<c<00ol0003o6ATIoaTI6@0]oaTI6@03o`000?lc<c?o<c<c00go<c<c00?o
0000oda<C?m<C4`02Om<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo00?o
0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o
0000onKVi_oVi^H01ooVi^H00ol0003oooooooooo`1dooooo`?o00000_ooool002kooooo00?o0000
ooooooooool05_ooool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000
ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000
ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00co<c<c00?o0000
oaTI6OlI6AT0;OlI6AT00ol0003o<c<coc<c<`0>oc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000
ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000
ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000
ooooooooool0Moooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool05Oooool00ol0
003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0
003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0
003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT0;?lI6AT00ol0
003o<c<coc<c<`0>oc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0
003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0
003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool0N?ooool1o`00
007ooooo0Oooool002kooooo00?o0000ooooooooool05Oooool00ol0003oi^KVonKViP07onKViP03
o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@05oiVIV@03
o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C008oda<C003
o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT0:olI6AT00ol0003o<c<coc<c<`0>oc<c<`03
o`000?m<C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`05ogmoO`03
o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003
o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool0N?ooool1o`00007ooooo0Oooool002kooooo
00?o0000ooooooooool05Oooool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00?oc<c<
00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo
00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00co<c<c
00?o0000oaTI6OlI6AT0:olI6AT00ol0003o<c<coc<c<`0>oc<c<`03o`000?m<C4coC4a<00WoC4a<
00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00?oVIVI
00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Goi^KV
00?o0000ooooooooool0NOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool05Ooo
ool00ol0003oi^KVonKViP06onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01Onc
/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01omV
IVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT0:_lI
6AT00ol0003o<c<coc<c<`0>oc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH01_mV
IVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<01?nc
/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool0NOoo
ool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool05Oooool00ol0003oi^KVonKViP06
onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@04
oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C008
oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT0:OlI6AT00ol0003o<c<coc<c<`0>
oc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05
ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004
olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool0N_ooool1o`00007ooooo0Oooool0
02kooooo00?o0000ooooooooool05Oooool00ol0003oi^KVonKViP06onKViP03o`000?o<c<coc<c<
00?oc<c<00?o0000ok>c/onc/k<01?nc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo
00GoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c
00go<c<c00?o0000oaTI6OlI6AT0:?lI6AT00ol0003o<c<coc<c<`0>oc<c<`03o`000?m<C4coC4a<
00WoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI
00CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV
00Koi^KV00?o0000ooooooooool0Noooool1o`00007ooooo0Oooool002kooooo00?o0000oooooooo
ool05Oooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc
/k<01Onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mV
IVH01omVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI
6AT0:?lI6AT00ol0003o<c<coc<c<`0>oc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000ofIVI_mV
IVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc
/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000oooooooo
ool0Noooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool05Oooool00ol0003oi^KV
onKViP05onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01?nc/k<00ol0003oVIVI
oiVIV@05oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<
oda<C008oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT09olI6AT00ol0003o<c<c
oc<c<`0>oc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmo
ogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<
olc<c003olc<c0;o00002OoVi^H00ol0003oooooooooo`1looooo`7o00000Oooool1ooooo`00;_oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`00oo<
c<`00ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01_mo
Ogl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<03Olc
<c<00ol0003o6ATIoaTI6@0WoaTI6@03o`000?lc<c?o<c<c00ko<c<c00?o0000oda<C?m<C4`02Om<
C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nI
VIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H02OoV
i^H00ol0003oooooooooo`1looooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0E
ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04
ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP07
ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<03Olc<c<00ol0003o6ATIoaTI6@0V
oaTI6@03o`000?lc<c?o<c<c00ko<c<c00?o0000oda<C?m<C4`02Om<C4`00ol0003oIVIVofIVIP06
ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`03
ok>c/`04o`000?o<c<coc<c<olc<c0;o00002ooVi^H00ol0003oooooooooo`1mooooo`7o00000Ooo
ool1ooooo`00;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000
olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000
ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000
oc<c<olc<c<03Olc<c<00ol0003o6ATIoaTI6@0UoaTI6@03o`000?lc<c?o<c<c00ko<c<c00?o0000
oda<C?m<C4`02Om<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000
oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`03ok>c/`05o`000?o<c<coc<c<olc<c?l000003?oV
i^H00ol0003oooooooooo`1nooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0E
ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03
ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP07
ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<03olc<c<00ol0003o6ATIoaTI6@0S
oaTI6@03o`000?lc<c?o<c<c00oo<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP08
ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`03
ok>c/`04o`000?o<c<coc<c<o`0000coi^KV00?o0000ooooooooool0Ooooool1o`00007ooooo0Ooo
ool002kooooo00?o0000ooooooooool05Oooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<co
c<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgoo
Ogmo00KoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o
<c<c00oo<c<c00?o0000oaTI6OlI6AT08_lI6AT00ol0003o<c<coc<c<`0?oc<c<`03o`000?m<C4co
C4a<00SoC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWo
VIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<01?l0003oc<c<olc<c?l0000=onKViP03o`000?oo
oooooooo07oooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo01Gooooo00?o0000
onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00?o0000
oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000
oda<C?m<C4`02?m<C4`00ol0003o<c<coc<c<`0?oc<c<`03o`000?lI6AWo6ATI027o6ATI00?o0000
oc<c<olc<c<04?lc<c<00ol0003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000
ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c00;o/k>c00Go0000
olc<c?o<c<coc<c<o`00000<onKViP03o`000?oooooooooo083ooooo0Ol00001ooooo`7ooooo000^
ooooo`03o`000?oooooooooo01Gooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c002
olc<c003o`000?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`05
ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`02Om<C4`00ol0003o<c<coc<c<`0?
oc<c<`03o`000?lI6AWo6ATI023o6ATI00?o0000oc<c<olc<c<04?lc<c<00ol0003oC4a<oda<C008
oda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@05
oiVIV@03o`000?nc/k?o/k>c00?o/k>c00Co0000olc<c?o<c<co00003?oVi^H00ol0003ooooooooo
o`21ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oVi^Ko
i^KV00Goi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWo
VIVI00CoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4co
C4a<00WoC4a<00?o0000oc<c<olc<c<03olc<c<00ol0003o6ATIoaTI6@0OoaTI6@03o`000?lc<c?o
<c<c013o<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?moOgoo
Ogmo00CoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`03ok>c/`05o`000?o<c<co
c<c<olc<c?l000003?oVi^H00ol0003oooooooooo`21ooooo`7o00000Oooool1ooooo`00;_ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`00oo<c<`0
0ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01_moOgl0
0ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<04Olc<c<0
0ol0003o6ATIoaTI6@0MoaTI6@03o`000?lc<c?o<c<c013o<c<c00?o0000oda<C?m<C4`02?m<C4`0
0ol0003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT01OnIVIT0
0ol0003o/k>cok>c/`02ok>c/`05o`000?o<c<coc<c<olc<c?l000003?oVi^H00ol0003ooooooooo
o`22ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oVi^Ko
i^KV00Coi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWo
VIVI00GoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4co
C4a<00SoC4a<00?o0000oc<c<olc<c<04Olc<c<00ol0003o6ATIoaTI6@0LoaTI6@03o`000?lc<c?o
<c<c013o<c<c00?o0000oda<C?m<C4`02Om<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgoo
Ogmo00CoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<co
c<c<00;oc<c<00?o0000onKVi_oVi^H02OoVi^H00ol0003oooooooooo`23ooooo`7o00000Oooool1
ooooo`00;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<
c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmo
OomoOgl01OmoOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000oc<c
<olc<c<04Olc<c<00ol0003o6ATIoaTI6@0KoaTI6@03o`000?lc<c?o<c<c013o<c<c00?o0000oda<
C?m<C4`02Om<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVI
VOnIVIT01?nIVIT00ol0003o/k>cok>c/`03ok>c/`05o`000?o<c<coc<c<olc<c?l000002ooVi^H0
0ol0003oooooooooo`24ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c
/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP07ofIV
IP03o`000?m<C4coC4a<00WoC4a<00?o0000oc<c<olc<c<04Olc<c<00ol0003o6ATIoaTI6@0JoaTI
6@03o`000?lc<c?o<c<c017o<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP07ofIV
IP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`03ok>c
/`05o`000?o<c<coc<c<olc<c?l000002ooVi^H00ol0003oooooooooo`25ooooo`7o00000Oooool1
ooooo`00;_ooool2o`0001Kooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c002olc<
c003o`000?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`05ogmo
O`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`02Om<C4`00ol0003o<c<coc<c<`0Aoc<c
<`03o`000?lI6AWo6ATI01Wo6ATI00?o0000oc<c<olc<c<04Olc<c<00ol0003oC4a<oda<C009oda<
C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@05oiVI
V@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003oi^KVonKViP08onKV
iP03o`000?oooooooooo08Cooooo0ol00002ooooo`00;_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`03ok>c/`03
o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP07ofIVIP03
o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<04olc<c<00ol0003o6ATIoaTI6@0GoaTI6@03
o`000?lc<c?o<c<c017o<c<c00?o0000oda<C?m<C4`02Om<C4`00ol0003oIVIVofIVIP07ofIVIP03
o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`03ok>c/`05
o`000?o<c<coc<c<olc<c?l000002_oVi^H00ol0003oooooooooo`27ooooo`7o00000Oooool1oooo
o`00;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<
c<`00_o<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomo
Ogl01OmoOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000oc<c<olc
<c<04olc<c<00ol0003o6ATIoaTI6@0FoaTI6@03o`000?lc<c?o<c<c017o<c<c00?o0000oda<C?m<
C4`02Om<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnI
VIT01?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oV
i^H01ooVi^H00ol0003oooooooooo`28ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>c
ok>c/`03ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIV
ofIVIP07ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000oc<c<olc<c<04olc<c<00ol0003o6ATI
oaTI6@0DoaTI6@;o00004olc<c<00ol0003oC4a<oda<C009oda<C003o`000?mVIVKoIVIV00OoIVIV
00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00?o/k>c
00?o0000olc<c?o<c<`00_o<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo08Wooooo
0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo01Gooooo00?o0000onKVi_oVi^H01?oV
i^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01OnI
VIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`02Om<
C4`00ol0003o<c<coc<c<`0Coc<c<`03o`000?lI6AWo6ATI01?o6ATI00?o0000oc<c<olc<c<04olc
<c<00ol0003oC4a<oda<C009oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01_mo
Ogl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00?o/k>c00Go0000olc<c?o<c<coc<c<
o`00000:onKViP03o`000?oooooooooo08Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oo
oooooooo01Gooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc
/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mV
IVKoIVIV00OoIVIV00?o0000oda<C?m<C4`02Om<C4`00ol0003o<c<coc<c<`0Doc<c<`03o`000?lI
6AWo6ATI013o6ATI0_l0000Eoc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH01_mV
IVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc
/k<01Ol0003oc<c<olc<c?o<c<co000000[oi^KV00?o0000ooooooooool0R_ooool1o`00007ooooo
0Oooool002kooooo00?o0000ooooooooool05Oooool00ol0003oi^KVonKViP04onKViP03o`000?o<
c<coc<c<00;oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?mo
OgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C00:oda<C003o`000?lc
<c?o<c<c01Go<c<c00?o0000oaTI6OlI6AT03_lI6AT00ol0003o<c<coc<c<`0Doc<c<`03o`000?m<
C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nI
VIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<01Ol0003oc<c<olc<c?o<c<co000000[oi^KV
00?o0000ooooooooool0Roooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool05Ooo
ool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<00onc
/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01omV
IVH00ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT02olI
6AT2o`0001Ko<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?mo
OgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`03ok>c/`05o`000?o<
c<coc<c<olc<c?l000002ooVi^H00ol0003oooooooooo`2;ooooo`7o00000Oooool1ooooo`00;_oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`00_o<
c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01Omo
Ogl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000oc<c<olc<c<06?lc
<c<00ol0003o6ATIoaTI6@08oaTI6@;o00006?lc<c<00ol0003oC4a<oda<C009oda<C003o`000?mV
IVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc
/k?o/k>c00?o/k>c00Co0000olc<c?o<c<co00002ooVi^H00ol0003oooooooooo`2<ooooo`7o0000
0Oooool1ooooo`00;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oVi^Koi^KV00Coi^KV00?o
0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o
0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o
0000oc<c<olc<c<06?lc<c<00ol0003o6ATIoaTI6@05oaTI6@?o00006Olc<c<00ol0003oC4a<oda<
C00:oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVI
V@04oiVIV@03o`000?nc/k?o/k>c00?o/k>c00Go0000olc<c?o<c<coc<c<o`00000:onKViP03o`00
0?oooooooooo08gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo01Gooooo00?o
0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00;o/k>c00?o
0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o
0000oda<C?m<C4`02Om<C4`00ol0003o<c<coc<c<`0Ioc<c<`03o`000?lI6AWo6ATI00;o6ATI0_l0
000Koc<c<`03o`000?m<C4coC4a<00[oC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmo
O`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<01Ol0003oc<c<olc<
c?o<c<co000000_oi^KV00?o0000ooooooooool0SOooool1o`00007ooooo0Oooool002kooooo00?o
0000ooooooooool05_ooool00ol0003oi^KVonKViP02onKViP03o`000?o<c<coc<c<00;oc<c<00?o
0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o
0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c01[o<c<c00Co
0000oaTI6Ol0003o00007Olc<c<00ol0003oC4a<oda<C009oda<C003o`000?mVIVKoIVIV00KoIVIV
00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00;o/k>c
00?o0000olc<c?o<c<`00_o<c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo08kooooo
0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo01Kooooo00?o0000onKVi_oVi^H00_oV
i^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01?nI
VIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`02_m<
C4`00ol0003o<c<coc<c<`0Koc<c<`03o`000?lc<c?o<c<c01co<c<c00?o0000oda<C?m<C4`02_m<
C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01?nI
VIT00ol0003o/k>cok>c/`03ok>c/`05o`000?o<c<coc<c<olc<c?l000002_oVi^H00ol0003ooooo
ooooo`2?ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0Fooooo`03o`000?oV
i^Koi^KV00;oi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nI
VIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<
C4coC4a<00[oC4a<00?o0000oc<c<olc<c<0>Olc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mV
IVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc
/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003oi^KVonKViP07onKViP03o`000?oo
oooooooo093ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo01Kooooo00?o0000
onKVi_oVi^H00_oVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000
oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000
oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0ioc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000
ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000
ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000
ooooooooool0TOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool05_ooool00ol0
003oi^KVonKViP02onKViP03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0
003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0
003oC4a<oda<C009oda<C003o`000?lc<c?o<c<c03Wo<c<c00?o0000oda<C?m<C4`02Om<C4`00ol0
003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0
003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0
003oooooooooo`2Aooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oVi^Koi^KV00;oi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`03ok>c/`03
o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP07ofIVIP03
o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<0>Olc<c<00ol0003oC4a<oda<C009oda<C003
o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03
o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003oi^KVonKViP07onKViP03
o`000?oooooooooo09;ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo01Kooooo
00?o0000onKVi_oVi^H00_oVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00;o/k>c
00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00OoIVIV
00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0hoc<c<`03o`000?m<C4coC4a<00WoC4a<
00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI
00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Koi^KV
00?o0000ooooooooool0Toooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool05_oo
ool00ol0003oi^KVonKViP02onKViP03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<00_nc
/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01omV
IVH00ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c03Oo<c<c00?o0000oda<C?m<C4`02Om<
C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nI
VIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oVi^H01_oV
i^H00ol0003oooooooooo`2Dooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oVi^Koi^KV00;oi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`02
ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP07
ofIVIP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<0=olc<c<00ol0003oC4a<oda<C009
oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04
oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP05
onKViP03o`000?oooooooooo09Gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo
01Gooooo00?o0000onKVi_oVi^H00ooVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c
00;o/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV
00OoIVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0foc<c<`03o`000?m<C4coC4a<
00WoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI
00CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV
00Goi^KV00?o0000ooooooooool0U_ooool1o`00007ooooo0Oooool002kooooo00?o0000oooooooo
ool05Oooool00ol0003oi^KVonKViP02onKViP03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc
/k<00_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mV
IVH01omVIVH00ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c03Go<c<c00?o0000oda<C?m<
C4`02Om<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnI
VIT01?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oV
i^H01OoVi^H00ol0003oooooooooo`2Gooooo`7o00000Oooool1ooooo`00;_ooool2o`0001Gooooo
00?o0000onKVi_oVi^H00ooVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00;o/k>c
00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00OoIVIV
00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0doc<c<`03o`000?m<C4coC4a<00WoC4a<
00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00?oVIVI
00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00Coi^KV
00?o0000ooooooooool0U_ooool3o`0000;ooooo000^ooooo`03o`000?oooooooooo01Cooooo00?o
0000onKVi_oVi^H00ooVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00;o/k>c00?o
0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o
0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0coc<c<`03o`000?m<C4coC4a<00[oC4a<00?o
0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o
0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Goi^KV00?o
0000ooooooooool0V?ooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool04oooool0
0ol0003oi^KVonKViP03onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00_nc/k<0
0ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH02?mVIVH0
0ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c03?o<c<c00?o0000oda<C?m<C4`02Om<C4`0
0ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT00_nIVIT0
0ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oVi^H01OoVi^H0
0ol0003oooooooooo`2Iooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`03ok>c
/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP08ofIV
IP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<0<_lc<c<00ol0003oC4a<oda<C009oda<
C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@02oiVI
V@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP05onKV
iP03o`000?oooooooooo09Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo01;o
oooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00;o
/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00Oo
IVIV00?o0000oda<C?m<C4`02om<C4`00ol0003o<c<coc<c<`0aoc<c<`03o`000?m<C4coC4a<00[o
C4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00?o
VIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00Go
i^KV00?o0000ooooooooool0V_ooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0
4Oooool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<0
0_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH0
1omVIVH00ol0003oC4a<oda<C00;oda<C003o`000?lc<c?o<c<c037o<c<c00?o0000oda<C?m<C4`0
2Om<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT0
0_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oVi^H0
1_oVi^H00ol0003oooooooooo`2Jooooo`7o00000Oooool1ooooo`00;_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c
/`03ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIV
IP07ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<0<?lc<c<00ol0003oC4a<oda<
C00:oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVI
V@02oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKV
iP06onKViP03o`000?oooooooooo09_ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooo
oooo013ooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o
/k>c00?o/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKo
IVIV00OoIVIV00?o0000oda<C?m<C4`02om<C4`00ol0003o<c<coc<c<`0`oc<c<`03o`000?m<C4co
C4a<00WoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWo
VIVI00;oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Ko
i^KV00Koi^KV00?o0000ooooooooool0W?ooool1o`00007ooooo0Oooool002kooooo00?o0000oooo
ooooool04?ooool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c
/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIV
I_mVIVH02?mVIVH00ol0003oC4a<oda<C00;oda<C003o`000?lc<c?o<c<c02oo<c<c00?o0000oda<
C?m<C4`02_m<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVI
VOnIVIT00_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKV
i_oVi^H01ooVi^H00ol0003oooooooooo`2Looooo`7o00000Oooool1ooooo`00;_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o
/k>cok>c/`02ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003o
IVIVofIVIP08ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<0;_lc<c<00ol0003o
C4a<oda<C00:oda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003o
VIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o
i^KVonKViP07onKViP03o`000?oooooooooo09gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`00
0?oooooooooo00kooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c002olc<c003o`00
0?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`00
0?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`02om<C4`00ol0003o<c<coc<c<`0^oc<c<`03o`00
0?m<C4coC4a<00[oC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`00
0?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c002olc<c003o`00
0?oVi^Koi^KV00Soi^KV00?o0000ooooooooool0WOooool1o`00007ooooo0Oooool002kooooo00?o
0000ooooooooool03Oooool00ol0003oi^KVonKViP06onKViP03o`000?o<c<coc<c<00?oc<c<00?o
0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00KoOgmo00?o
0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00;oda<C003o`000?lc<c?o<c<c02go<c<c00?o
0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo00?o
0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o
0000onKVi_oVi^H02?oVi^H00ol0003oooooooooo`2Nooooo`7o00000Oooool1ooooo`00;_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`00oo<c<`0
0ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01_moOgl0
0ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<0;Olc<c<0
0ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01OmoOgl0
0ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`00oo<c<`0
0ol0003oi^KVonKViP08onKViP03o`000?oooooooooo09kooooo0Ol00001ooooo`7ooooo000^oooo
o`03o`000?oooooooooo00cooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c003olc<
c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`06ogmo
O`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`03?m<C4`00ol0003o<c<coc<c<`0/oc<c
<`03o`000?m<C4coC4a<00[oC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmo
O`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c002olc<
c003o`000?oVi^Koi^KV00Soi^KV00?o0000ooooooooool0Woooool1o`00007ooooo0Oooool002ko
oooo00?o0000ooooooooool03?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Co
c<c<00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00Ko
Ogmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00<oda<C003o`000?lc<c?o<c<c02_o
<c<c00?o0000oda<C?m<C4`02om<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00Go
Ogmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00?o
c<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003oooooooooo`2Pooooo`7o00000Oooool1ooooo`00
;_ooool00ol0003oooooooooo`0;ooooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`0
1?o<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl0
1_moOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<00coC4a<00?o0000oc<c<olc<c<0
:_lc<c<00ol0003oC4a<oda<C00;oda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl0
1?moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`0
0_o<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo0:7ooooo0Ol00001ooooo`7ooooo
000^ooooo`03o`000?oooooooooo00_ooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<
c004olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmo
O`06ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`03Om<C4`00ol0003o<c<coc<c
<`0Xoc<c<`03o`000?m<C4coC4a<00coC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmo
O`05ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<
c003olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool0X_ooool1o`00007ooooo0Ooo
ool002kooooo00?o0000ooooooooool02_ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<co
c<c<00Goc<c<00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgoo
Ogmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00=oda<C003o`000?lc<c?o
<c<c02Oo<c<c00?o0000oda<C?m<C4`03?m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgoo
Ogmo00GoOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<co
c<c<00;oc<c<00?o0000onKVi_oVi^H01_oVi^H00ol0003oooooooooo`2Sooooo`7o00000Oooool1
ooooo`00;_ooool00ol0003oooooooooo`0:ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<
c?o<c<`01?o<c<`00ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmo
OomoOgl01_moOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<00goC4a<00?o0000oc<c
<olc<c<09_lc<c<00ol0003oC4a<oda<C00=oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmo
OomoOgl01OmoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<
c?o<c<`00_o<c<`00ol0003oi^KVonKViP06onKViP03o`000?oooooooooo0:?ooooo0Ol00001oooo
o`7ooooo000^ooooo`03o`000?oooooooooo00Wooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003o
c<c<olc<c005olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003o
OgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`03Om<C4`00ol0003o
<c<coc<c<`0Voc<c<`03o`000?m<C4coC4a<00coC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003o
OgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003o
c<c<olc<c002olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool0Y?ooool1o`00007o
oooo0Oooool001Cooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP06onKViP03
o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01?nc/k<00ol0003oVIVIoiVIV@05oiVIV@03
o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00=oda<C003
o`000?lc<c?o<c<c02Go<c<c00?o0000oda<C?m<C4`03Om<C4`00ol0003oIVIVofIVIP06ofIVIP03
o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`02ok>c/`03
o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`2Uooooo`7o
00000Oooool1ooooo`005_ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<
olc<c005olc<c003o`000?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmo
ogmoO`07ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`03Om<C4`00ol0003o<c<c
oc<c<`0Toc<c<`03o`000?m<C4coC4a<00koC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmo
ogmoO`05ogmoO`03o`000?nIVIWoVIVI00?oVIVI00Go0000ok>c/onc/k?o/k>co`000004olc<c003
o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool0YOooool1o`00007ooooo0Oooool001Kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Co/k>c
00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00WoIVIV
00?o0000oda<C?m<C4`03Om<C4`00ol0003o<c<coc<c<`0Toc<c<`03o`000?m<C4coC4a<00goC4a<
00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00;oVIVI
00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Goi^KV
00?o0000ooooooooool0Y_ooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool03_oo
ool00omgMgOo<S8booooo`04ooooo`?o00001oooool00ol0003oi^KVonKViP05onKViP03o`000?o<
c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01?nc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?mo
OgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02OmVIVH00ol0003oC4a<oda<C00>oda<C003o`000?lc
<c?o<c<c02;o<c<c00?o0000oda<C?m<C4`03_m<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?mo
OgooOgmo00GoOgmo00?o0000oiVIVOnIVIT00onIVIT01Ol0003o/k>cok>c/onc/k?o000000Coc<c<
00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`2Uooooo`?o00000_ooool001Kooooo00?o
0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<0
1Onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH0
2OmVIVH00ol0003oC4a<oda<C00>oda<C003o`000?lc<c?o<c<c02;o<c<c00?o0000oda<C?m<C4`0
3Om<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT0
0onIVIT01Ol0003o/k>cok>c/onc/k?o000000Coc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003o
ooooooooo`2Wooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oi^KVonKViP05onKViP03o`00
0?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01?nc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`00
0?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH02OmVIVH00ol0003oC4a<oda<C00>oda<C003o`00
0?lc<c?o<c<c027o<c<c00?o0000oda<C?m<C4`03_m<C4`00ol0003oIVIVofIVIP06ofIVIP03o`00
0?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`02ok>c/`05o`00
0?o<c<coc<c<olc<c?l000001ooVi^H00ol0003oooooooooo`2Xooooo`7o00000Oooool1ooooo`00
5_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1Oooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<0
1Onc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH0
2OmVIVH00ol0003oC4a<oda<C00>oda<C003o`000?lc<c?o<c<c023o<c<c00?o0000oda<C?m<C4`0
3_m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT0
0onIVIT01Ol0003o/k>cok>c/onc/k?o000000Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003o
ooooooooo`2Yooooo`7o00000Oooool1ooooo`005?ooool00omEEEGoIVIVo`00000=ooooo`Co0000
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`0
1Oo<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl0
1omoOgl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<00koC4a<00?o0000oc<c<olc<c<0
7olc<c<00ol0003oC4a<oda<C00?oda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl0
1OmoOgl00ol0003oVIVIoiVIV@03oiVIV@05o`000?nc/k?o/k>cok>c/ol000001?o<c<`00ol0003o
i^KVonKViP04onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`00
0?oooooooooo00Gooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c005olc<c003o`00
0?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`07ogmoO`03o`00
0?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`03om<C4`00ol0003o<c<coc<c<`0Moc<c<`03o`00
0?m<C4coC4a<00ooC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`00
0?nIVIWoVIVI00?oVIVI00Go0000ok>c/onc/k?o/k>co`000004olc<c003o`000?oVi^Koi^KV00Co
i^KV00?o0000ooooooooool0ZOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0
1Oooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<0
1Onc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH0
2OmVIVH00ol0003oC4a<oda<C00@oda<C003o`000?lc<c?o<c<c01_o<c<c00?o0000oda<C?m<C4`0
4?m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT0
1?nIVIT01Ol0003o/k>cok>c/onc/k?o000000Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003o
ooooooooo`2Yooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`05ok>c/`03o`00
0?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP09ofIVIP03o`00
0?m<C4coC4a<017oC4a<00?o0000oc<c<olc<c<06Olc<c<00ol0003oC4a<oda<C00@oda<C003o`00
0?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@05o`00
0?nc/k?o/k>cok>c/ol000001?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo0:Wo
oooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo00Gooooo00?o0000onKVi_oVi^H0
1?oVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT0
1onIVIT00ol0003oOgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`0
4Om<C4`00ol0003o<c<coc<c<`0Hoc<c<`03o`000?m<C4coC4a<017oC4a<00?o0000ofIVI_mVIVH0
2?mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<0
0_nc/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool0
ZOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool01Oooool00ol0003oi^KVonKV
iP04onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVI
V@06oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02OmVIVH00ol0003oC4a<oda<
C00Boda<C003o`000?lc<c?o<c<c01Go<c<c0_l0000Doda<C003o`000?mVIVKoIVIV00OoIVIV00?o
0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o
0000olc<c?o<c<`00_o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo0:Wooooo0Ol0
0001ooooo`7ooooo000^ooooo`03o`000?oooooooooo00Gooooo00?o0000onKVi_oVi^H01?oVi^H0
0ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01_nIVIT0
0ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`04om<C4`0
0ol0003o<c<coc<c<`0Boc<c<`;o00005Om<C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?moOgoo
Ogmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<co
c<c<00;oc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`2Yooooo`7o00000Oooool1
ooooo`00;_ooool00ol0003oooooooooo`05ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<
c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<01CoC4a<0ol0000?oc<c
<`;o00005om<C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVI
VOnIVIT01?nIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKV
i_oVi^H01?oVi^H00ol0003oooooooooo`2Yooooo`7o00000Oooool1ooooo`00;_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o
/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003o
IVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01OoC4a<0ol0000;oc<c<`03o`000?m<C4coC4a<01Ko
C4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00Co
VIVI00Go0000ok>c/onc/k?o/k>co`000004olc<c003o`000?oVi^Koi^KV00Goi^KV00?o0000oooo
ooooool0ZOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool01?ooool00ol0003o
i^KVonKViP05onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003o
VIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003o
C4a<oda<C00Joda<C0?o00001_lc<c<2o`0001WoC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003o
OgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00CoVIVI00Go0000ok>c/onc/k?o/k>co`000004olc<
c003o`000?oVi^Koi^KV00Goi^KV00?o0000ooooooooool0ZOooool1o`00007ooooo0Oooool002ko
oooo00?o0000ooooooooool01?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Go
c<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00Oo
Ogmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Moda<C0?o000000?o<c<co`000?l0
00006_m<C4`00ol0003oIVIVofIVIP09ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnI
VIT01OnIVIT01Ol0003o/k>cok>c/onc/k?o000000Coc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0
003oooooooooo`2Yooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`04ooooo`03
o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`05ok>c/`03
o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP0;ofIVIP03
o`000?m<C4coC4a<01ooC4a<00?o0000oda<C?m<C4`06_m<C4`00ol0003oIVIVofIVIP08ofIVIP03
o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01OnIVIT01Ol0003o/k>cok>c/onc/k?o0000
00Coc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`2Yooooo`7o00000Oooool1oooo
o`00;_ooool00ol0003oooooooooo`04ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<
c<`01Oo<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomo
Ogl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<03coC4a<00?o0000ofIVI_mV
IVH02?mVIVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc
/k<00_nc/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Goi^KV00?o0000oooooooo
ool0ZOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool01?ooool00ol0003oi^KV
onKViP04onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVI
oiVIV@06oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<
oda<C00koda<C003o`000?mVIVKoIVIV00WoIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVI
oiVIV@04oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003oi^KV
onKViP05onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oo
oooooooo00Cooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc
/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mV
IVKoIVIV00coIVIV00?o0000oda<C?m<C4`0>_m<C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?mo
OgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<
c<coc<c<00;oc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`2Yooooo`7o00000Ooo
ool1ooooo`00;_ooool00ol0003oooooooooo`04ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000
olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000
ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<03WoC4a<00?o0000
ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000
ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Goi^KV00?o0000
ooooooooool0ZOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool01?ooool00ol0
003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0
003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0
003oC4a<oda<C00ioda<C003o`000?mVIVKoIVIV00WoIVIV00?o0000ogmoOomoOgl01_moOgl00ol0
003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0
003oi^KVonKViP05onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo000^ooooo`03
o`000?oooooooooo00Cooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c005olc<c003
o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`08ogmoO`03
o`000?mVIVKoIVIV00goIVIV00?o0000oda<C?m<C4`0=om<C4`00ol0003oIVIVofIVIP09ofIVIP03
o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`02ok>c/`03
o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`2Yooooo`7o
00000Oooool1ooooo`00;_ooool2o`0000Gooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<
olc<c005olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmo
ogmoO`08ogmoO`03o`000?mVIVKoIVIV00goIVIV00?o0000oda<C?m<C4`0=_m<C4`00ol0003oIVIV
ofIVIP0:ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>c
ok>c/`03ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003ooooo
ooooo`2Wooooo`?o00000_ooool002kooooo00?o0000ooooooooool01?ooool00ol0003oi^KVonKV
iP04onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVI
V@06oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH03OmVIVH00ol0003oC4a<oda<
C00doda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVI
V@05oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003oi^KVonKV
iP05onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooo
oooo00Cooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o
/k>c00Go/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKo
IVIV00goIVIV00?o0000oda<C?m<C4`0=?m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgoo
Ogmo00OoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<co
c<c<00;oc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`2Yooooo`7o00000Oooool1
ooooo`00;_ooool00ol0003oooooooooo`04ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<
c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<03;oC4a<00?o0000ofIV
I_mVIVH02omVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c
/onc/k<00onc/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Goi^KV00?o0000oooo
ooooool0ZOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool01?ooool00ol0003o
i^KVonKViP04onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003o
VIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003o
C4a<oda<C00aoda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003o
VIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o
i^KVonKViP05onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`00
0?oooooooooo00Cooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c005olc<c003o`00
0?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`00
0?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`0<?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`03ok>c/`03o`00
0?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H01_oVi^H00ol0003oooooooooo`2Yooooo`7o0000
0Oooool1ooooo`00;_ooool00ol0003oooooooooo`04ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o
0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o
0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<02ooC4a<00?o
0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o
0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Koi^KV00?o
0000ooooooooool0ZOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool01?ooool0
0ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01Onc/k<0
0ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH03_mVIVH0
0ol0003oC4a<oda<C00^oda<C003o`000?mVIVKoIVIV00goIVIV00?o0000ogmoOomoOgl01omoOgl0
0ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00_o<c<`0
0ol0003oi^KVonKViP06onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo000^oooo
o`03o`000?oooooooooo00Cooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c005olc<
c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`09ogmo
O`03o`000?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`0;Om<C4`00ol0003oIVIVofIVIP0<ofIV
IP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`03ok>c
/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H01_oVi^H00ol0003oooooooooo`2Yoooo
o`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`04ooooo`03o`000?oVi^Koi^KV00Co
i^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00So
VIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<02co
C4a<00?o0000ofIVI_mVIVH03OmVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00Ko
VIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Ko
i^KV00?o0000ooooooooool0ZOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0
1?ooool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<0
1Onc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH0
4?mVIVH00ol0003oC4a<oda<C00[oda<C003o`000?mVIVKoIVIV00goIVIV00?o0000ogmoOomoOgl0
1omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`0
0_o<c<`00ol0003oi^KVonKViP06onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo
000^ooooo`03o`000?oooooooooo00Cooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<
c005olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT02?nIVIT00ol0003oOgmoogmo
O`09ogmoO`03o`000?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`0:_m<C4`00ol0003oIVIVofIV
IP0=ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c
/`04ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H01_oVi^H00ol0003ooooooooo
o`2Yooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`04ooooo`03o`000?oVi^Ko
i^KV00Coi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWo
VIVI00SoVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0@ofIVIP03o`000?m<C4co
C4a<02OoC4a<0_l0000@ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01OnIVIT0
0ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H01_oVi^H0
0ol0003oooooooooo`2Yooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`04oooo
o`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`05ok>c
/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0AofIV
IP03o`000?m<C4coC4a<02GoC4a<00?o0000ofIVI_mVIVH04?mVIVH00ol0003oOgmoogmoO`08ogmo
O`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c002olc<
c003o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool0ZOooool1o`00007ooooo0Oooool002ko
oooo00?o0000ooooooooool01?ooool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Go
c<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00[o
Ogmo00?o0000ofIVI_mVIVH04OmVIVH00ol0003oC4a<oda<C00Roda<C0;o00004_mVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003o
c<c<olc<c002olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool0ZOooool1o`00007o
oooo0Oooool002kooooo00?o0000ooooooooool01?ooool00ol0003oi^KVonKViP04onKViP03o`00
0?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01_nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`00
0?moOgooOgmo00[oOgmo00?o0000ofIVI_mVIVH04_mVIVH2o`00027oC4a<00?o0000ofIVI_mVIVH0
4OmVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<0
1Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool0
ZOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool01?ooool00ol0003oi^KVonKV
iP04onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01_nc/k<00ol0003oVIVIoiVI
V@08oiVIV@03o`000?moOgooOgmo00[oOgmo00?o0000ofIVI_mVIVH04omVIVH2o`0001goC4a<0_l0
000DofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c
/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H01_oVi^H00ol0003ooooooooo
o`2Yooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`04ooooo`03o`000?oVi^Ko
i^KV00Coi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`06ok>c/`03o`000?nIVIWo
VIVI00SoVIVI00?o0000ogmoOomoOgl02_moOgl00ol0003oIVIVofIVIP0EofIVIP;o00006Om<C4`2
o`0001GoIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o
/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP06onKViP03o`000?oooooo
oooo0:Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo00Cooooo00?o0000onKV
i_oVi^H01?oVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Ko/k>c00?o0000oiVI
VOnIVIT02?nIVIT00ol0003oOgmoogmoO`0;ogmoO`03o`000?mVIVKoIVIV01KoIVIV00?o0000oda<
C?m<C4`04om<C4`3o`0001KoIVIV00?o0000ogmoOomoOgl02_moOgl00ol0003oVIVIoiVIV@06oiVI
V@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP06onKV
iP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo00Co
oooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Ko
/k>c00?o0000oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmoO`0:ogmoO`03o`000?mVIVKoIVIV01Oo
IVIV0_l0000Aoda<C0;o00006OmVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00Oo
VIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Ko
i^KV00?o0000ooooooooool0ZOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0
1?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<0
1_nc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00_oOgmo00?o0000ofIVI_mVIVH0
6?mVIVH2o`0000goC4a<0_l0000JofIVIP03o`000?moOgooOgmo00[oOgmo00?o0000oiVIVOnIVIT0
1_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H0
1ooVi^H00ol0003oooooooooo`2Yooooo`7o00000Oooool1ooooo`00;_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c
/`06ok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl03?moOgl00ol0003oIVIVofIV
IP0IofIVIPgo00006omVIVH00ol0003oOgmoogmoO`0;ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o
0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o
0000ooooooooool0ZOooool1o`00007ooooo0Oooool002kooooo0_l00005ooooo`03o`000?oVi^Ko
i^KV00Goi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`06ok>c/`03o`000?nIVIWo
VIVI00SoVIVI00?o0000ogmoOomoOgl03?moOgl00ol0003oIVIVofIVIP11ofIVIP03o`000?moOgoo
Ogmo00[oOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<co
c<c<00;oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003oooooooooo`2Wooooo`?o00000_ooool0
02kooooo00?o0000ooooooooool01?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<
00Goc<c<00?o0000ok>c/onc/k<01_nc/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?moOgooOgmo
00coOgmo00?o0000ofIVI_mVIVH0?omVIVH00ol0003oOgmoogmoO`0;ogmoO`03o`000?nIVIWoVIVI
00OoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV
00Ooi^KV00?o0000ooooooooool0ZOooool1o`00007ooooo0Oooool002kooooo00?o0000oooooooo
ool01?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc
/k<01_nc/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?moOgooOgmo00coOgmo00?o0000ofIVI_mV
IVH0?_mVIVH00ol0003oOgmoogmoO`0;ogmoO`03o`000?nIVIWoVIVI00SoVIVI00?o0000ok>c/onc
/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000oooooooo
ool0ZOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool01?ooool00ol0003oi^KV
onKViP05onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVI
oiVIV@08oiVIV@03o`000?moOgooOgmo00goOgmo00?o0000ofIVI_mVIVH0?OmVIVH00ol0003oOgmo
ogmoO`0;ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<
olc<c003olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool0ZOooool1o`00007ooooo
0Oooool002kooooo00?o0000ooooooooool01?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<
c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?mo
OgooOgmo00coOgmo00?o0000ofIVI_mVIVH0??mVIVH00ol0003oOgmoogmoO`0<ogmoO`03o`000?nI
VIWoVIVI00OoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c003olc<c003o`000?oV
i^Koi^KV00Ooi^KV00?o0000ooooooooool0ZOooool1o`00007ooooo0Oooool002kooooo00?o0000
ooooooooool01?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000
ok>c/onc/k<01onc/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?moOgooOgmo00goOgmo00?o0000
ofIVI_mVIVH0>OmVIVH2o`0000koOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0003o/k>cok>c/`05
ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003oooooooooo`2Y
ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`04ooooo`03o`000?oVi^Koi^KV
00Goi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`07ok>c/`03o`000?nIVIWoVIVI
00WoVIVI00?o0000ogmoOomoOgl03_moOgl00ol0003oIVIVofIVIP0fofIVIP;o00004?moOgl00ol0
003oVIVIoiVIV@08oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0
003oi^KVonKViP07onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo000^ooooo`03
o`000?oooooooooo00Cooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c005olc<c003
o`000?nc/k?o/k>c00So/k>c00?o0000oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmoO`0>ogmoO`;o
0000=OmVIVH00ol0003oOgmoogmoO`0?ogmoO`03o`000?nIVIWoVIVI00SoVIVI00?o0000ok>c/onc
/k<01_nc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000oooooooo
ool0ZOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool01?ooool00ol0003oi^KV
onKViP05onKViP03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVI
oiVIV@09oiVIV@03o`000?moOgooOgmo013oOgmo0_l0000bofIVIP03o`000?moOgooOgmo013oOgmo
00?o0000oiVIVOnIVIT02?nIVIT00ol0003o/k>cok>c/`06ok>c/`03o`000?o<c<coc<c<00?oc<c<
00?o0000onKVi_oVi^H01ooVi^H00ol0003oooooooooo`2Yooooo`7o00000Oooool1ooooo`00;_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01_o<
c<`00ol0003o/k>cok>c/`07ok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl04Omo
Ogl00ol0003oIVIVofIVIP0]ofIVIP;o00004_moOgl00ol0003oVIVIoiVIV@09oiVIV@03o`000?nc
/k?o/k>c00Ko/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP07onKViP03o`000?oo
oooooooo0:Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo00Cooooo00?o0000
onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00So/k>c00?o0000
oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`0AogmoO`;o0000;?mVIVH00ol0003oOgmoogmoO`0A
ogmoO`03o`000?nIVIWoVIVI00WoVIVI00?o0000ok>c/onc/k<01onc/k<00ol0003oc<c<olc<c003
olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool0ZOooool1o`00007ooooo0Oooool0
02kooooo00?o0000ooooooooool01?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<
00Koc<c<00?o0000ok>c/onc/k<02?nc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo
01?oOgmo0_l0000XofIVIP;o00005?moOgl00ol0003oVIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c
00Oo/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo
0:Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo00Cooooo00?o0000onKVi_oV
i^H01OoVi^H00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00So/k>c00?o0000oiVIVOnI
VIT02onIVIT00ol0003oOgmoogmoO`0DogmoO`03o`000?mVIVKoIVIV02CoIVIV00?o0000ogmoOomo
Ogl04omoOgl00ol0003oVIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c00Oo/k>c00?o0000olc<c?o<
c<`01?o<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7o
oooo000^ooooo`03o`000?oooooooooo00Gooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<
olc<c006olc<c003o`000?nc/k?o/k>c00So/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmo
ogmoO`0EogmoO`;o00008omVIVH00ol0003oOgmoogmoO`0DogmoO`03o`000?nIVIWoVIVI00WoVIVI
00?o0000ok>c/onc/k<01onc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Soi^KV
00?o0000ooooooooool0ZOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool01Ooo
ool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<02?nc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo01KoOgmo0ol0000MofIVIP?o00005_mo
Ogl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c00Oo/k>c00?o0000olc<c?o<c<`00oo<
c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo000^
ooooo`03o`000?oooooooooo00Gooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c006
olc<c003o`000?nc/k?o/k>c00So/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`0H
ogmoO`Co00005OmVIVH4o`0001SoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`08
ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oVi^H02?oVi^H00ol0003oooooooooo`2Y
ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`05ooooo`03o`000?oVi^Koi^KV
00Goi^KV00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`09ok>c/`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ogmoOomoOgl07?moOgl3o`0000ooIVIV0ol0000KogmoO`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ok>c/onc/k<02?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV
00Soi^KV00?o0000ooooooooool0ZOooool1o`00007ooooo0Oooool002kooooo00?o0000oooooooo
ool01Oooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc
/k<02Onc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo01koOgmo3ol0000MogmoO`03
o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<02?nc/k<00ol0003oc<c<olc<c003olc<c003
o`000?oVi^Koi^KV00Soi^KV00?o0000ooooooooool0ZOooool1o`00007ooooo0Oooool002kooooo
00?o0000ooooooooool01Oooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Ooc<c<
00?o0000ok>c/onc/k<02?nc/k<00ol0003oVIVIoiVIV@0=oiVIV@03o`000?moOgooOgmo04SoOgmo
00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`09ok>c/`03o`000?o<c<coc<c<00?oc<c<
00?o0000onKVi_oVi^H02?oVi^H00ol0003oooooooooo`2Yooooo`7o00000Oooool1ooooo`00;_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01oo<
c<`00ol0003o/k>cok>c/`09ok>c/`03o`000?nIVIWoVIVI00goVIVI00?o0000ogmoOomoOgl0A_mo
Ogl00ol0003oVIVIoiVIV@0=oiVIV@03o`000?nc/k?o/k>c00So/k>c00?o0000olc<c?o<c<`01?o<
c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo000^
ooooo`03o`000?oooooooooo00Gooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c007
olc<c003o`000?nc/k?o/k>c00Wo/k>c00?o0000oiVIVOnIVIT03_nIVIT2o`0004CoOgmo0_l0000?
oiVIV@03o`000?nc/k?o/k>c00Wo/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP08
onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo
00Gooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o/k>c
00Wo/k>c00?o0000oiVIVOnIVIT04?nIVIT00ol0003oOgmoogmoO`10ogmoO`03o`000?nIVIWoVIVI
00ooVIVI00?o0000ok>c/onc/k<02Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV
00Soi^KV00?o0000ooooooooool0ZOooool1o`00007ooooo0Oooool002kooooo0_l00006ooooo`03
o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>cok>c/`0:ok>c/`03
o`000?nIVIWoVIVI013oVIVI0_l0000nogmoO`;o00004OnIVIT00ol0003o/k>cok>c/`09ok>c/`03
o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H02?oVi^H00ol0003oooooooooo`2Wooooo`?o
00000_ooool002kooooo00?o0000ooooooooool01Oooool00ol0003oi^KVonKViP05onKViP03o`00
0?o<c<coc<c<00Soc<c<00?o0000ok>c/onc/k<02_nc/k<00ol0003oVIVIoiVIV@0AoiVIV@;o0000
>omoOgl00ol0003oVIVIoiVIV@0@oiVIV@03o`000?nc/k?o/k>c00[o/k>c00?o0000olc<c?o<c<`0
1Oo<c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo
000^ooooo`03o`000?oooooooooo00Gooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<
c007olc<c003o`000?nc/k?o/k>c00_o/k>c0_l0000CoiVIV@03o`000?moOgooOgmo03KoOgmo0_l0
000BoiVIV@03o`000?nc/k?o/k>c00[o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003oi^KVonKV
iP08onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooo
oooo00Gooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o
/k>c00go/k>c00?o0000oiVIVOnIVIT04OnIVIT3o`0003;oOgmo0ol0000CoiVIV@03o`000?nc/k?o
/k>c00_o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP09onKViP03o`000?oooooo
oooo0:Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo00Gooooo00?o0000onKV
i_oVi^H01_oVi^H00ol0003oc<c<olc<c008olc<c003o`000?nc/k?o/k>c00go/k>c00?o0000oiVI
VOnIVIT04onIVIT3o`0002coOgmo0ol0000EoiVIV@03o`000?nc/k?o/k>c00_o/k>c00?o0000olc<
c?o<c<`01_o<c<`00ol0003oi^KVonKViP09onKViP03o`000?oooooooooo0:Wooooo0Ol00001oooo
o`7ooooo000^ooooo`03o`000?oooooooooo00Gooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003o
c<c<olc<c008olc<c003o`000?nc/k?o/k>c00ko/k>c00?o0000oiVIVOnIVIT05OnIVIT3o`0002Ko
Ogmo0ol0000HoiVIV@03o`000?nc/k?o/k>c00_o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o
i^KVonKViP09onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`00
0?oooooooooo00Gooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c008olc<c003o`00
0?nc/k?o/k>c00oo/k>c00?o0000oiVIVOnIVIT05onIVIT3o`0001ooOgmo1?l0000JoiVIV@03o`00
0?nc/k?o/k>c00_o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003oi^KVonKViP08onKViP03o`00
0?oooooooooo0:[ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo00Gooooo00?o
0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c009olc<c003o`000?nc/k?o/k>c00oo/k>c00?o
0000oiVIVOnIVIT06OnIVIT4o`0001KoOgmo1Ol0000MoiVIV@03o`000?nc/k?o/k>c00co/k>c00?o
0000olc<c?o<c<`01oo<c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo0:[ooooo0Ol0
0001ooooo`7ooooo000^ooooo`03o`000?oooooooooo00Gooooo00?o0000onKVi_oVi^H01_oVi^H0
0ol0003oc<c<olc<c009olc<c003o`000?nc/k?o/k>c013o/k>c00?o0000oiVIVOnIVIT07?nIVIT5
o`0000SoOgmo2Ol0000QoiVIV@03o`000?nc/k?o/k>c00go/k>c00?o0000olc<c?o<c<`01oo<c<`0
0ol0003oi^KVonKViP08onKViP03o`000?oooooooooo0:[ooooo0Ol00001ooooo`7ooooo000^oooo
o`03o`000?oooooooooo00Gooooo00?o0000onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c008olc<
c003o`000?nc/k?o/k>c017o/k>c00?o0000oiVIVOnIVIT08?nIVIT8o`0002WoVIVI00?o0000ok>c
/onc/k<03Onc/k<00ol0003oc<c<olc<c008olc<c003o`000?oVi^Koi^KV00Soi^KV00?o0000oooo
ooooool0Z_ooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool01Oooool00ol0003o
i^KVonKViP07onKViP03o`000?o<c<coc<c<00Woc<c<00?o0000ok>c/onc/k<04Onc/k<00ol0003o
VIVIoiVIV@1>oiVIV@;o00004?nc/k<00ol0003oc<c<olc<c007olc<c003o`000?oVi^Koi^KV00Wo
i^KV00?o0000ooooooooool0Z_ooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0
1Oooool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00[oc<c<00?o0000ok>c/onc/k<0
4Onc/k<00ol0003oVIVIoiVIV@1;oiVIV@;o00004Onc/k<00ol0003oc<c<olc<c008olc<c003o`00
0?oVi^Koi^KV00Woi^KV00?o0000ooooooooool0Z_ooool1o`00007ooooo0Oooool002kooooo00?o
0000ooooooooool01Oooool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00_oc<c<00?o
0000ok>c/onc/k<04Onc/k<3o`0004SoVIVI0_l0000Cok>c/`03o`000?o<c<coc<c<00Soc<c<00?o
0000onKVi_oVi^H02OoVi^H00ol0003oooooooooo`2Zooooo`7o00000Oooool1ooooo`00;_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<c?o<c<`03?o<c<`2
o`0001Co/k>c0_l00014oiVIV@;o00005?nc/k<00ol0003oc<c<olc<c009olc<c003o`000?oVi^Ko
i^KV00Woi^KV00?o0000ooooooooool0Z_ooool1o`00007ooooo0Oooool002kooooo00?o0000oooo
ooooool01Oooool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00koc<c<00?o0000ok>c
/onc/k<04onc/k<3o`0003koVIVI0ol0000Eok>c/`03o`000?o<c<coc<c<00[oc<c<00?o0000onKV
i_oVi^H02OoVi^H00ol0003oooooooooo`2Zooooo`7o00000Oooool1ooooo`00;_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oVi^Koi^KV00Soi^KV00?o0000olc<c?o<c<`03_o<c<`00ol0003o
/k>cok>c/`0Eok>c/`?o0000=onIVIT4o`0001Oo/k>c00?o0000olc<c?o<c<`02_o<c<`00ol0003o
i^KVonKViP0:onKViP03o`000?oooooooooo0:[ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`00
0?oooooooooo00Gooooo00?o0000onKVi_oVi^H02OoVi^H00ol0003oc<c<olc<c00>olc<c003o`00
0?nc/k?o/k>c01Oo/k>c1?l0000_oiVIV@Co00006_nc/k<00ol0003oc<c<olc<c00;olc<c003o`00
0?oVi^Koi^KV00[oi^KV00?o0000ooooooooool0Z_ooool1o`00007ooooo0Oooool002kooooo00?o
0000ooooooooool01Oooool00ol0003oi^KVonKViP09onKViP03o`000?o<c<coc<c<00ooc<c<00?o
0000ok>c/onc/k<06_nc/k<6o`0002KoVIVI0ol0000Lok>c/`;o00003_o<c<`00ol0003oi^KVonKV
iP0:onKViP03o`000?oooooooooo0:[ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooo
oooo00Gooooo00?o0000onKVi_oVi^H02_oVi^H00ol0003oc<c<olc<c00?olc<c003o`000?nc/k?o
/k>c01oo/k>c2Ol0000FoiVIV@Oo00007Onc/k<2o`0000ooc<c<00?o0000onKVi_oVi^H02ooVi^H0
0ol0003oooooooooo`2Zooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`05oooo
o`03o`000?oVi^Koi^KV00_oi^KV00?o0000olc<c?o<c<`03oo<c<`00ol0003o/k>cok>c/`0Wok>c
/aKo00008_nc/k<2o`00017oc<c<00?o0000onKVi_oVi^H02ooVi^H00ol0003oooooooooo`2Zoooo
o`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`05ooooo`03o`000?oVi^Koi^KV00_o
i^KV00?o0000olc<c?o<c<`04?o<c<`2o`0005ko/k>c00?o0000olc<c?o<c<`04Oo<c<`00ol0003o
i^KVonKViP0;onKViP03o`000?oooooooooo0:[ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`00
0?oooooooooo00Gooooo00?o0000onKVi_oVi^H03?oVi^H00ol0003oc<c<olc<c00Aolc<c0;o0000
F_nc/k<2o`0001?oc<c<00?o0000onKVi_oVi^H03?oVi^H00ol0003oooooooooo`2Zooooo`7o0000
0Oooool1ooooo`00;_ooool2o`0000Oooooo00?o0000onKVi_oVi^H03?oVi^H00ol0003oc<c<olc<
c00Bolc<c0?o0000EOnc/k<2o`0001Goc<c<00?o0000onKVi_oVi^H02ooVi^H00ol0003ooooooooo
o`2Yooooo`?o00000_ooool002kooooo00?o0000ooooooooool01_ooool00ol0003oi^KVonKViP0=
onKViP03o`000?o<c<coc<c<01Coc<c<0_l0001@ok>c/`?o00005oo<c<`00ol0003oi^KVonKViP0;
onKViP03o`000?oooooooooo0:_ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo
00Kooooo00?o0000onKVi_oVi^H03OoVi^H00ol0003oc<c<olc<c00Folc<c0;o0000B_nc/k<4o`00
01Woc<c<00?o0000onKVi_oVi^H03?oVi^H00ol0003oooooooooo`2[ooooo`7o00000Oooool1oooo
o`00;_ooool00ol0003oooooooooo`06ooooo`03o`000?oVi^Koi^KV00koi^KV00?o0000olc<c?o<
c<`05oo<c<`4o`0004;o/k>c1?l0000Lolc<c0;o00003_oVi^H00ol0003oooooooooo`2[ooooo`7o
00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`06ooooo`03o`000?oVi^Koi^KV00ooi^KV
00?o0000olc<c?o<c<`06_o<c<`5o`0003So/k>c1Ol0000Oolc<c003o`000?oVi^Koi^KV00koi^KV
00?o0000ooooooooool0Zoooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool01_oo
ool00ol0003oi^KVonKViP0?onKViP03o`000?o<c<coc<c<01ooc<c<2Ol0000Zok>c/`Go00008oo<
c<`00ol0003oi^KVonKViP0?onKViP03o`000?oooooooooo0:_ooooo0Ol00001ooooo`7ooooo000^
ooooo`03o`000?oooooooooo00Kooooo00?o0000onKVi_oVi^H04?oVi^H2o`0002Soc<c<:_l0000W
olc<c003o`000?oVi^Koi^KV013oi^KV00?o0000ooooooooool0Zoooool1o`00007ooooo0Oooool0
02kooooo00?o0000ooooooooool01_ooool00ol0003oi^KVonKViP0AonKViP?o0000M?o<c<`3o`00
01?oi^KV00?o0000ooooooooool0Zoooool1o`00007ooooo0Oooool002kooooo00?o0000oooooooo
ool01_ooool00ol0003oi^KVonKViP0DonKViPCo0000KOo<c<`3o`0001Koi^KV00?o0000oooooooo
ool0Zoooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool01oooool00ol0003oi^KV
onKViP0GonKViPCo0000IOo<c<`4o`0001Soi^KV00?o0000ooooooooool0[?ooool1o`00007ooooo
0Oooool002kooooo00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP0JonKViPGo0000G?o<
c<`4o`0001coi^KV00?o0000ooooooooool0[?ooool1o`00007ooooo0Oooool002kooooo00?o0000
ooooooooool02Oooool00ol0003oi^KVonKViP0NonKViPGo0000E?o<c<`3o`0001ooi^KV00?o0000
ooooooooool0[Oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool02_ooool00ol0
003oi^KVonKViP0RonKViPWo0000@oo<c<`8o`0002;oi^KV00?o0000ooooooooool0[Oooool1o`00
007ooooo0Oooool002kooooo00?o0000ooooooooool02oooool00ol0003oi^KVonKViP0ZonKViP_o
0000;Oo<c<`;o`0002Woi^KV00?o0000ooooooooool0[_ooool1o`00007ooooo0Oooool002kooooo
00?o0000ooooooooool02oooool00ol0003oi^KVonKViP0eonKViRgo0000=?oVi^H00ol0003ooooo
ooooo`2^ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0<ooooo`03o`000?oV
i^Koi^KV09?oi^KV0_l0002aooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oVi^Koi^KV093oi^KV0_l0002cooooo`7o00000Oooool1ooooo`00;_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oVi^Koi^KV08coi^KV0ol0002eooooo`7o00000Oooool1oooo
o`00;_ooool00ol0003oooooooooo`0?ooooo`Co0000R?oVi^H2o`000;Sooooo0Ol00001ooooo`7o
oooo000Sooooo`Go00001_ooool00ol0003oooooooooo`0Cooooo`Go0000POoVi^H2o`000;[ooooo
0Ol00001ooooo`7ooooo000Sooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooo
ooooo`0HoooooaGo0000F_oVi^HBo`000;cooooo0Ol00001ooooo`7ooooo000Tooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?o0000ooooooooool0;OoooomJo`000<kooooo0Ol00001ooooo`7ooooo000U
ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooooeCooooo0ol00002ooooo`009_ooool00omg
MgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?ooooooE_ooool1o`00007ooooo0Oooool002Oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooooeKooooo0Ol00001ooooo`7o
oooo000Sooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3ooooooeKo
oooo0Ol00001ooooo`7ooooo000Sooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003o
ooooooooo`3ooooooeKooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo0?oooooo
E_ooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo01[ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool002kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00;_ooooooo`0005[o
00000_ooool00?ooooooR_ooool00?ooooooR_ooool00?ooooooR_ooool00?ooooooR_ooool00?oo
ooooR_ooool009Oooooo00Go8B4Qo`000?l0003oA4A4omgMg@1Tooooo`05ob4Q8Ol0003o0000odA4
A?oMgMd0Q?ooool009[ooooo00?oMgMgoc8b<_ooool0I_ooool00omgMgOo<S8booooo`23ooooo`00
Voooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo08;ooooo001gooooo`05ofIVI_l0
003o0000odA4A?o<c<`00_ooool01?l@413o0000o`000?ooool2o`000003oa0@4?ooooooV9RH00;o
000000GoMgMgoa0@4?l0003ooooooa0@4005o`0000?ooooo00Kok^k^oeEEEOl0003o410@olc<c?l0
0002ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj1_ooool00ol@413o0000o`000002o`000004
oa0@4?ooooooooooooooo`Go00000_ooool5o`0000?ooooo1Ol00003ooooo`06onk^k_mEEEGo0000
o`000?m4A4Co^[Zj0_ooool01oo^k^koEEEEo`000?l0003oV9RHo`000?l@41001oooool5o`000003
ooooool@413o000000Co00000_ooool00ol@413o0000o`000003o`0000?ooooo00Kok^k^oeEEEOl0
003o0000odA4A?nj^[X2ooooo`06onk^k_mEEEGo0000oa0@4?o<c<co00000oooool01onHV9So0000
o`000?mgMgOo0000oa0@4?ooool01Ol00003ooooo`08oiRHV?l0003o0000ogMgMol@413o0000oooo
ool@4105o`0000Kooooo00?o410@o`000?n7QhL00_l000001OmVIVKok^k^ooooooo^k^koEEEE00;o
000000CoEEEEonk^k_oooooooooo0_l00002ooooo`;o0000BOooool007Kooooo00KoIVIVogMgMooo
ooooooooohN7Qol@4103ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003oc<c<onk^
k_n7QhOo000000Cooooo00?o0000ooooooooool01?ooool01_mEEEGoMgMgooooooo^k^koEEEEo`00
00;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4108ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Ko
EEEEogMgMoooooook^k^ogMgMol@4102ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00002_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
1_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00003oooo
o`05o`000?nYZJWoooooohN7Qol000001?ooool00ol0003oooooooooo`03ooooo`05o`000?o<c<co
k^k^ohN7Qol000001?ooool00ol0003oooooooooo`08ooooo`09o`000?mEEEGok^k^oooooomgMgOo
IVIVoooooomEEEGoMgMg00;ooooo00[oMgMgoeEEEOooooooooooonk^k_lQ8B7oQhN7okZj^_l0003o
gMgMBOooool007Kooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Go410@ohN7Qoooooook^k^o`000004ooooo`03o`000?oooooooooo00Cooooo00Ko0000oooo
ooooooooooooonk^k_l00002ooooo`03o`000?oooooooooo00;ooooo1_l00003ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool01_l0003oooooooooooooooook^k^o`0000[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01Oooool01_l0003oooooooooooooooook^k^o`0000?ooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00Go410@ohN7Qoooooook^k^
o`000004ooooo`03o`000?oooooooooo00Sooooo00?o0000onk^k_ooool00_ooool00ol0003ooooo
o`000004ooooo`08o`000?oooooooooooooooooMgMgo0000oa0@4?o<c<a:ooooo`00M_ooool00ol0
003oooooooooo`06ooooo`05o`000?ooooooooooooooool000000_ooool00onj^[[o410@o`000002
o`0000Cooooo00?o0000ooooooooool01?ooool01_l0003oooooooooooooooook^k^o`0000;ooooo
1_l00008ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo1_l00002ooooo`06o`000?ooooooooooooooooo^
k^ko00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool6o`0000;ooooo00Ko0000ooooooooooooooooonk^k_l00003ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03okZj^_l@413o000000;o0000
1?ooool00ol0003oooooooooo`08ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooool00000
1?ooool02?l0003oooooooooooooooook^k^ob4Q8Ol@413ok^k^B_ooool007Kooooo00KoIVIVogMg
MoooooooooooohN7Qol00003ooooo`05o`000?mgMgOoooooojVYZOl000001Oooool00oo<c<co0000
ooooo`03ooooo`03o`000?lb<S;ogMgM00Cooooo00KoEEEEogMgMoooooook^k^oeEEEOl00002oooo
o`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b2?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`06oeEEEOn7
QhOok^k^oooooon7QhOo<S8b0_ooool01_mVIVKoMgMgooooooo^k^koEEEEo`0000[ooooo00?o0000
ooooooooool00oooool00ol0003o<S8bomgMg@05ooooo`03o`000?lb<S;ogMgM00Cooooo00KoEEEE
ohN7Qoo^k^koooooohN7Qolb<S82ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00000oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01_ooool00oo<c<co0000ooooo`03
ooooo`03o`000?lb<S;ogMgM00Sooooo00Wo0000oeEEEOo^k^koooooogMgMomEEEGooooooeEEEOmg
MgL00_ooool00omgMgOoEEEEooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<T[ooooo001fooooo`06
onk^k_mVIVKo0000o`000?m4A4Co00000oooool01Ol0003oMgMgo`000?l0003oV9RH00?ooooo00Co
<S8bo`000?l0003oV9RH0oooool2o`000004ojVYZOlQ8B7o0000ob4Q8@;ooooo00[ok^k^oeEEEOl0
003o8B4QojVYZOl0003o410@ooooooo^k^koEEEE0_l000000om4A4Cok^k^ooooo`05ooooo`03oa0@
4?l0003o000000?o00000oooool00ol@413o0000o`000006ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo00Kok^k^oeEE
EOl0003o410@olc<c?l00008ooooo`03oa0@4?l0003o000000Cooooo0_l000001?nYZJWo8B4Qo`00
0?lQ8B42ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool01_o^k^koEEEEo`000?l0003oA4A4
onk^kP;ooooo00[ok^k^oeEEEOl0003o8B4QojVYZOl0003o410@ooooool@413o00000_ooool2o`00
00Cooooo00?o0000ooooooooool01?ooool01?lb<S;o0000o`000?nHV9P3ooooo`;o000000CoZJVY
ob4Q8Ol0003o8B4Q1_ooool02Ol0003oc<c<oa0@4?l0003oEEEEonk^k_ooooook^k^oeEEE@02o`00
0004oeEEEOo^k^koooooooooo`;o00000_ooool2o`0004Wooooo001oooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
05_ooooo001oooooo`03o`000?oooooooooo02[ooooo00?o410@okZj^_ooool01_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`1Kooooo`00O_ooool00ol@413o0000ooooo`0[ooooo`04okZj^_l@413o0000oa0@40Go
oooo00?o410@ooooooooool00_ooool00ol@413o0000o`000005ooooo`03oa0@4?l0003o0000017o
oooo0_l0000:ooooo`03oa0@4?oooooooooo02[ooooo00?o410@o`000?l000006?ooool00ol@413o
0000ooooo`1Looooo`00oooooon:ooooo`00oooooon:ooooo`00oooooon:ooooo`00oooooon:oooo
o`00oooooon:ooooo`00oooooon:ooooo`00M_ooool3o`000003oa0@4?oooooooooo00;ooooo00Ko
k^k^oeEEEOl0003o0000oeEEEOo^k^h3ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool01_o^
k^koEEEEo`000?l0003oA4A4okZj^P;ooooo00Co410@o`000?l0003ooooo0_l000001?l@413ooooo
oooooonHV9P2o`000003odA4A?nj^[[ooooo00;ooooo1Ol00002ooooo`06oiRHV?l0003o0000ogMg
Mol@413o00000_ooool5o`0000Oooooo1Ol00002ooooo`04oa0@4?l0003o0000ooooo`;o000000Co
410@ooooool@413o<S8b0_l000000ol@413oZJVYooooo`02ooooo`Go00000_ooool02_o^k^koEEEE
o`000?l0003oV9RHo`000?l@413oooooonk^k_mEEED2o`000003odA4A?nj^[[ooooo00Gooooo00Ko
V9RHo`000?l0003oMgMgoa0@4?l0002>ooooo`00Moooool00ol0003oooooooooo`04ooooo`06oeEE
EOmgMgOooooooooooomgMgOoEEEE0oooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo00KoEEEE
ogMgMoooooook^k^ogMgMol@4103ooooo`05o`000?ooooooooooooooool000000oooool01Ol@413o
^[Zjonk^k_mgMgOo410@00Gooooo00?o0000ooooooooool00_ooool01Ol0003oc<c<onk^k_n7QhOo
000000Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000000_ooool01_l0003oZJVYoooooooooooo^[Zjo`0000Gooooo00?o0000oooooooo
ool00_ooool01_mEEEGoMgMgooooooo^k^koEEEEo`0000;ooooo00KoEEEEogMgMoooooook^k^ogMg
Mol@4106ooooo`05o`000?o<c<cok^k^ohN7Qol00000Soooool007Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`06ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00;ooooo00Go410@ohN7Qoooooook^k^o`000005ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
^[ZjohN7QomVIVKoIVIVoa0@4005ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo
ooooonk^k_l00002ooooo`03o`000?oooooooooo00Wooooo00Go410@ohN7Qoooooook^k^o`00002?
ooooo`00Moooool3o`000005ob4Q8Oo<c<coooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000000Kooooo1_l00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o^[Zjoa0@4?l000000_l00005ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;o
oooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h5ooooo`03o`000?oooooooooo00;ooooo00Ko0000
ooooooooooooooooonk^k_l00002ooooo`Ko00001_ooool00onj^[[o410@o`000002o`0008oooooo
001gooooo`05o`000?ooooooooooohN7Qol@41000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEE
E@?ooooo00?o0000ooooooooool01?ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00Go
0000ohN7QoooooooZJVYo`000003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1Oooool00oo<c<co0000ooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0oooool01Ol0003oQhN7oooooonYZJWo000000;ooooo00Ko0000okZj^_ooooook^k^ogMgMol00005
ooooo`03o`000?oooooooooo00;ooooo00KoIVIVogMgMoooooook^k^oeEEEOl00002ooooo`06oeEE
EOn7QhOok^k^oooooon7QhOo<S8b2Oooool00oo<c<co0000ooooo`2>ooooo`00Moooool01Ol0003o
oooooooooooooooo000000;ooooo00Sok^k^oeEEEOl0003o0000oeEEEOo^k^kooooooa0@40Go0000
0oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo00?o410@o`000?mgMgL00_l000000onH
V9Sooooooa0@4005o`0000Cooooo00?o410@o`000?l000001Oooool01?lb<S;o0000o`000?nHV9P5
ooooo`03o`000?oooooooooo00Oooooo00?o410@o`000?l000001?ooool00ol@413o0000ogMgM`02
o`000005oiRHV?ooooooooooojVYZOlQ8B400_l000000olb<S;o0000ooooo`02ooooo`03oa0@4?l0
003o000000Cooooo00Kok^k^oeEEEOl0003o410@olc<c?l00002ooooo`06onk^k_mEEEGo0000o`00
0?m4A4Cok^k^1oooool01?lb<S;o0000o`000?nHV9R?ooooo`00Moooool01Ol0003ooooooooooon7
QhOo410@00_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0X?ooool007Kooooo1?l000000olQ8B7oc<c<ooooo`0:
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0:3ooooo002Yooooo`03oa0@4?oooooooooo00[ooooo00?o410@o`00
0?l000002oooool00ol@413oooooooooo`0Eooooo`03oa0@4?oooooooooo00Kooooo0_l0002Roooo
o`00oooooon:ooooo`00oooooon:ooooo`00\
\>"],
  ImageRangeCache->{{{0, 392.812}, {524.062, 0}} -> {-0.240152, -0.178572, \
0.0056696, 0.0056696}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Simultaneous Overrelaxation", "Subsubsection",
  CellTags->"i:34"],

Cell[TextData[{
  "The convergence of the Jacobi method is quite slow, rendering it \
impractical in most applications.  Furthermore, the larger the system, the \
slower the convergence. This is simply because we are solving a heat equation \
problem, and we know that for a system of size ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " the solution to the heat equation decays  toward equilibrium at a rate ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\)]],
  " of order ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]/L\^2\)]],
  " [the order of magnitude of the lowest eigenvalue: see Eq. ",
  ButtonBox["(3.1.60)",
    ButtonData:>{"Chapter3.nb", "(3.1.60)"},
    ButtonStyle->"Hyperlink"],
  "]. Multiplying this rate  by our time step size ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", and using the Courant condition ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], " ", "~", " ", 
          FormBox[
            RowBox[{
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"], "/", "\[Chi]"}],
            "TraditionalForm"]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " is the grid spacing, we obtain"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"1", "/", 
          RowBox[{"(", 
            RowBox[{"\[Nu]", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}], " ", ")"}]}], "=", " ", 
        RowBox[{"number", " ", "of", " ", "time", " ", 
          RowBox[{"steps", " ", "~", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"L", "/", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]]}], ")"}], "2"]}]}]}], 
      TraditionalForm]]]], "UNNEQ"],

Cell["\<\
The number of time steps required to get a converged solution \
scales like the square of the number of grid points across the system. \
\>", \
"Text"],

Cell[TextData[{
  "\tIn order to improve on this poor scaling, various recipes have been put \
forward. One of the most successful is the method of ",
  StyleBox["simultaneous overrelaxation",
    FontSlant->"Italic"],
  ". In this algorithm, the Jacobi method is modified in two ways, shown in \
red in Eq. ",
  ButtonBox["(6.2.40)",
    ButtonData:>"(6.2.40)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Phi]\_\(j\ k\)\%\(n + 1\)\), "=", 
          RowBox[{
            StyleBox[\(\((1 - \[Omega])\) \[Phi]\_\(j\ k\)\%n\),
              FontColor->RGBColor[1, 0, 0]], "+", 
            RowBox[{
              FractionBox[
                StyleBox["\[Omega]",
                  FontColor->RGBColor[1, 0, 0]], "2"], 
              RowBox[{
                FractionBox[
                  RowBox[{
                    SuperscriptBox[
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]], "2"], 
                    SuperscriptBox[
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["y",
                            FontSlant->"Italic"]}]], "2"]}], 
                  RowBox[{
                    SuperscriptBox[
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]], "2"], "+", 
                    SuperscriptBox[
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["y",
                            FontSlant->"Italic"]}]], "2"]}]], "[", 
                RowBox[{\(-\[Rho]\_\(j\ k\)\), "+", 
                  RowBox[{
                    FractionBox["1", 
                      SuperscriptBox[
                        StyleBox[
                          RowBox[{"\[CapitalDelta]", 
                            StyleBox["x",
                              FontSlant->"Italic"]}]], "2"]], 
                    RowBox[{"(", 
                      RowBox[{\(\[Phi]\_\(j + 1\ k\)\%n\), "+", 
                        SubsuperscriptBox["\[Phi]", \(j - 1\ k\), 
                          RowBox[{" ", 
                            StyleBox[\(n + 1\),
                              FontColor->RGBColor[1, 0, 0]]}]]}], ")"}]}], 
                  "+", 
                  RowBox[{
                    FractionBox["1", 
                      SuperscriptBox[
                        StyleBox[
                          RowBox[{"\[CapitalDelta]", 
                            StyleBox["y",
                              FontSlant->"Italic"]}]], "2"]], 
                    RowBox[{"(", 
                      RowBox[{\(\[Phi]\_\(j\ k + 1\)\%n\), "+", 
                        SubsuperscriptBox["\[Phi]", \(j\ k - 1\), 
                          RowBox[{" ", 
                            StyleBox[\(n + 1\),
                              FontColor->RGBColor[1, 0, 0]]}]]}], " ", 
                      ")"}]}]}], "]"}]}]}]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.40)"],

Cell[TextData[{
  "First, we use improved values for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " on the right-hand side as soon as they become available, in order to help \
improve the guess we are making for the next step.  This looks like an \
implicit method with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(j\ k\)\%\(n + 1\)\)]],
  " appearing on both sides, but it is not: assuming that we are stepping \
through the equations  from smaller to larger values of ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox["j",
              "TraditionalForm"], "and", 
            FormBox["k",
              "TraditionalForm"]}]}], TraditionalForm]]],
  ",  by the time we evaluate ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(j\ k\)\%\(n + 1\)\)]],
  " we have already evaluated ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(j - 1\ k\)\%\(n + 1\)\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(j\ k - 1\)\%\(n + 1\)\)]],
  ", so we can use these values on the ",
  "right-hand",
  " side. (Stepping through the grid is performed when we evaluate the error \
in the solution,  creating a table of the error at each grid point, just as \
in the Jacobi method. The steps in the table are performed from smaller to \
larger values of ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ")."
}], "Text"],

Cell[TextData[{
  "\tAlso, we have added terms involving a ",
  StyleBox["relaxation parameter ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  ". It has been proven that this parameter must take on a value in the range \
",
  Cell[BoxData[
      \(TraditionalForm\`1 < \[Omega] < 2\)]],
  " for the method to work.  This parameter is added in order to take \
advantage of the fact that the Jacobi method converges exponentially toward \
equilibrium  (it is a solution to the heat equation), and tries to overshoot \
the exponential decay and go directly to the final result in one step.  \
However, the rate of convergence of the SOR method depends sensitively on the \
choice of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  ", and there is no way to know the correct choice beforehand (without doing \
considerable extra work). This is the main weakness of the method. Typically, \
one must simply make a guess for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  ".  However, even if the guess is not close to the optimum value, the SOR \
method usually works better than the Jacobi method, and is just as easy to \
program. We provide a module below, and use it to solve the same problem as \
we did previously :"
}], "Text"],

Cell[BoxData[{
    RowBox[{\(Clear["\<Global`*\>"];\), "\n"}], "\[IndentingNewLine]", 
    RowBox[{\(SOR[\[Omega]_, Nstep_]\), " ", ":=", " ", 
      RowBox[{"Module", "[", 
        RowBox[{\({\[Phi]}\), ",", "\[IndentingNewLine]", 
          
          StyleBox[\( (*\ 
              choose\ grid\ parameters\ and\ shape\ of\ region*) \),
            FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
          
          RowBox[{\(M\_x = 20\), ";", "\[IndentingNewLine]", \(M\_y = 20\), 
            ";", "\[IndentingNewLine]", \(L\_x = 1.5\), ";", 
            "\[IndentingNewLine]", \(L\_y = \ 2. \), ";", 
            "\[IndentingNewLine]", \(\[CapitalDelta]x = L\_x/M\_x\), ";", 
            "\[IndentingNewLine]", \(\[CapitalDelta]y = L\_y/M\_y\), ";", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", \(g[k_]\  := M\_x\),
             ";", " ", \(k \[LessEqual] \ 5\), ";", 
            "\[IndentingNewLine]", \(g[k_]\  := \ 
              M\_x - k + 5 /; 5 < k < 15\), ";", 
            "\[IndentingNewLine]", \(g[k_]\  := \ 
              M\_x - 10\  /; \ k \[GreaterEqual] \ 15\), ";", 
            "\[IndentingNewLine]", \(f[k_]\ \  = \ 
              Floor[12 \((k/M\_y - 1)\)^2]\), ";", "\[IndentingNewLine]", 
            StyleBox[\( (*\ boundary\ conditions\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[Phi][j_, k_, n_]\  := \ 
              0\  /; \ j \[LessEqual] \ f[k]\), ";", 
            "\[IndentingNewLine]", \(\[Phi][j_, k_, n_]\  := \ 
              0\  /; \ j \[GreaterEqual] \ g[k]\), ";", 
            "\[IndentingNewLine]", \(\[Phi][j_, 0, n_]\  = \ 0\), ";", 
            "\[IndentingNewLine]", \(\[Phi][j_, M\_y, n_]\  = \ 0\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ charge\ density\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[Rho][j_, k_] = \ 1\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ SOR\ recursion\ relation\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[Phi][j_, k_, 
                n_]\  := \ \(\[Phi][j, k, 
                  n]\  = \((1 - \[Omega])\) \[Phi][j, k, 
                      n - 1]\  + \ \[Omega]\ \(1\/2\) \
\(\(\(\[CapitalDelta]x\^2\) \[CapitalDelta]y\^2\)\/\((\[CapitalDelta]x\^2 + \
\[CapitalDelta]y\^2)\)\) \((\(-\[Rho][j, 
                            k]\) + \(1\/\[CapitalDelta]x\^2\) \((\[Phi][
                                j + 1, k, n - 1] + \[Phi][j - 1, k, 
                                n])\) + \(1\/\[CapitalDelta]y\^2\) \((\[Phi][
                                j, k + 1, n - 1] + \[Phi][j, k - 1, 
                                n]\ )\))\)\)\), ";", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                initial\ choice\ for\ \[Phi]\ to\ start\ the\ iteration\ *) \
\),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[Phi][j_, k_, 0]\  = \ 0\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ define\ error\ at\ the\ nth\ step\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(error[n_]\  := \ 
              Max[Table[
                  Table[Abs[\[Phi][j, k, n] - \[Phi][j, k, n - 1]], {j, 
                      f[k] + 1, g[k] - 1}], {k, 1, M\_y - 1}]]\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*evaluate\ error\ at\ step\ NStep*) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(Print["\<error at step NStep = \>", 
              error[Nstep]]\), ";", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                create\ interpolation\ function\ of\ solution\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[Phi]sol\  = \ 
              Interpolation[
                Flatten[
                  Table[{j\ \[CapitalDelta]x, 
                      k\ \[CapitalDelta]y, \[Phi][j, k, Nstep]}, {j, 0, 
                      M\_x}, {k, 0, M\_y}], 1]]\)}]}], "]"}]}]}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.116"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SOR[1.6, 30]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.117"],

Cell[BoxData[
    InterpretationBox[\("error at step NStep = \
"\[InvisibleSpace]4.1582873067103066`*^-7\),
      SequenceForm[ "error at step NStep = ", 4.1582873067103066*^-07],
      Editable->False]], "Print"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.`, 1.5`}, {0.`, 2.`}}, "<>"]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "With the guess \[Omega]=1.6, the result has already converged within 30 \
steps, as compared to the 200 steps needed in the Jacobi method. The error is \
plotted in Cell ",
  ButtonBox["6.118",
    ButtonData:>"Cell 6.118",
    ButtonStyle->"Hyperlink"],
  ", showing faster convergence than the Jacobi method."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(<< Graphics`;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(LogLogListPlot[Table[{n, error[n]}, {n, 1, 30}], 
        AxesLabel \[Rule] {"\<n\>", "\<error[n]\>"}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.118"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.644755 0.846729 0.130387 [
[.02381 -0.0125 -5 -12 ]
[.02381 -0.0125 5 0 ]
[.2179 -0.0125 -5 -12 ]
[.2179 -0.0125 5 0 ]
[.47447 -0.0125 -5 -12 ]
[.47447 -0.0125 5 0 ]
[.66856 -0.0125 -8 -12 ]
[.66856 -0.0125 8 0 ]
[.86265 -0.0125 -8 -12 ]
[.86265 -0.0125 8 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .0644 -47.0625 -6.40625 ]
[-0.0125 .0644 0 6.40625 ]
[-0.0125 .19479 -46 -6 ]
[-0.0125 .19479 0 6 ]
[-0.0125 .32518 -40 -6 ]
[-0.0125 .32518 0 6 ]
[-0.0125 .45557 -34 -6 ]
[-0.0125 .45557 0 6 ]
[-0.0125 .58595 -28 -6 ]
[-0.0125 .58595 0 6 ]
[0 .64303 -26 0 ]
[0 .64303 26 12 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.2179 0 m
.2179 .00625 L
s
gsave
.2179 -0.0125 -66 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.47447 0 m
.47447 .00625 L
s
gsave
.47447 -0.0125 -66 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.66856 0 m
.66856 .00625 L
s
gsave
.66856 -0.0125 -69 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86265 0 m
.86265 .00625 L
s
gsave
.86265 -0.0125 -69 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.33144 0 m
.33144 .00375 L
s
.41199 0 m
.41199 .00375 L
s
.52553 0 m
.52553 .00375 L
s
.56869 0 m
.56869 .00375 L
s
.60608 0 m
.60608 .00375 L
s
.63906 0 m
.63906 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0644 m
.00625 .0644 L
s
gsave
-0.0125 .0644 -108.062 -10.4062 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.8125 translate 1 -1 scale
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.812 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.812 9.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
105.000 9.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .19479 m
.00625 .19479 L
s
gsave
-0.0125 .19479 -107 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00001) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .32518 m
.00625 .32518 L
s
gsave
-0.0125 .32518 -101 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0001) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .45557 m
.00625 .45557 L
s
gsave
-0.0125 .45557 -95 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.001) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .58595 m
.00625 .58595 L
s
gsave
-0.0125 .58595 -89 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .10365 m
.00375 .10365 L
s
0 .12661 m
.00375 .12661 L
s
0 .1429 m
.00375 .1429 L
s
0 .15554 m
.00375 .15554 L
s
0 .16587 m
.00375 .16587 L
s
0 .17459 m
.00375 .17459 L
s
0 .18216 m
.00375 .18216 L
s
0 .18883 m
.00375 .18883 L
s
0 .23404 m
.00375 .23404 L
s
0 .257 m
.00375 .257 L
s
0 .27329 m
.00375 .27329 L
s
0 .28593 m
.00375 .28593 L
s
0 .29625 m
.00375 .29625 L
s
0 .30498 m
.00375 .30498 L
s
0 .31254 m
.00375 .31254 L
s
0 .31921 m
.00375 .31921 L
s
0 .36443 m
.00375 .36443 L
s
0 .38739 m
.00375 .38739 L
s
0 .40368 m
.00375 .40368 L
s
0 .41632 m
.00375 .41632 L
s
0 .42664 m
.00375 .42664 L
s
0 .43537 m
.00375 .43537 L
s
0 .44293 m
.00375 .44293 L
s
0 .4496 m
.00375 .4496 L
s
0 .49482 m
.00375 .49482 L
s
0 .51778 m
.00375 .51778 L
s
0 .53407 m
.00375 .53407 L
s
0 .5467 m
.00375 .5467 L
s
0 .55703 m
.00375 .55703 L
s
0 .56576 m
.00375 .56576 L
s
0 .57332 m
.00375 .57332 L
s
0 .57999 m
.00375 .57999 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(error) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(@) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .60332 Mdot
.2179 .60011 Mdot
.33144 .59603 Mdot
.41199 .591 Mdot
.47447 .58505 Mdot
.52553 .57787 Mdot
.56869 .56965 Mdot
.60608 .55983 Mdot
.63906 .5482 Mdot
.66856 .53415 Mdot
.69525 .51612 Mdot
.71962 .49177 Mdot
.74203 .45054 Mdot
.76278 .43002 Mdot
.7821 .40959 Mdot
.80017 .38977 Mdot
.81715 .36763 Mdot
.83315 .34376 Mdot
.84829 .31598 Mdot
.86265 .28737 Mdot
.87632 .25676 Mdot
.88934 .22582 Mdot
.90179 .20237 Mdot
.91371 .18123 Mdot
.92514 .15746 Mdot
.93612 .13133 Mdot
.94669 .10363 Mdot
.95687 .07027 Mdot
.9667 .04513 Mdot
.97619 .01472 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00@oooool4
o`000003oa0@4?oooooooooo02gooooo1Ol00014ooooo`05odA4A?l0003o0000oc8b<_oMgMd0;Ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hXooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Gooooo0015ooooo`03o`000?oooooooooo02oooooo00GoV9RHob4Q
8Oo^k^koooooodA4A017ooooo`03ogMgMolb<S;ooooo02kooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0=Oooool004Gooooo00?o0000ooooooooool0<?ooool00onHV9So8B4Q
onk^kP19ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@02Wooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
03Gooooo0015ooooo`03o`000?oooooooooo037ooooo00?oV9RHob4Q8Oo^k^h0Aoooool00omgMgOo
<S8booooo`0^ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zoooo
o`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000eooooo`00AOooool00ol0
003oooooooooo`0booooo`03ogMgMomVIVKooooo04?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00_
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[ooooo`03ogMgMomV
IVKooooo00;ooooo00Go0000ooooooooooooooooo`00000eooooo`00AOooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@4100;?ooool01Ol0003ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool0<oooool004Gooooo00?o0000ooooooooool0;oooool01Ol0003o^[Zj
oooooonHV9So410@04Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0:?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0eooooo`00@oooool00omEEEGoIVIVo`00000aooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`0A?ooool4o`0002kooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h0=Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooGoooool0
1?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo007ooooo003oooooof3ooooo00Go0000
ooooooooooooooooo`000004ooooo`00?_ooooooo`0001Oo00002oooool01Ol0003ooooooooooooo
oooo000000Cooooo000nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`00
0004ooooo`00?_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool0A?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool0;oooool01Ol0003oQhN7oooooonYZJWo000000Cooooo000nooooo`03o`000?oooooo
oooo0?oooooo7_ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo00;ooooo000noooo
o`03o`000?oooooooooo0?oooooo3?ooool2o`0001[ooooo000nooooo`03o`000?oooooooooo0?oo
oooo3?ooool2o`0001[ooooo000nooooo`03o`000?oooooooooo0?oooooo:?ooool003kooooo00?o
0000ooooooooool0oooooolXooooo`00?_ooool00ol0003oooooooooo`3oooooobSooooo000noooo
o`03o`000?oooooooooo0?oooooo:?ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00
?_ooool00ol0003oooooooooo`3oooooobSooooo000nooooo`03o`000?oooooooooo0?oooooo2Ooo
ool2o`0001gooooo000nooooo`03o`000?oooooooooo0?oooooo2Oooool2o`0001gooooo000Coooo
o`;ok^k^0oooool2onk^kRCooooo00?o0000ooooooooool0oooooolXooooo`001?ooool4o`000003
oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?ooooo00?o0000oooooooo
ool0oooooolXooooo`001_ooool00ol0003oooooooooo`04ooooo`;o8B4Q1Oooool01Oo^k^koEEEE
omgMgOmEEEGok^k^00Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
01?ooooo00?o0000ooooooooool0oooooolXooooo`001_ooool00ol0003oooooooooo`0<ooooo`03
omgMgOl0003ogMgM00Wooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
01?ooooo00?o0000ooooooooool0oooooolXooooo`001_ooool00ol0003oooooooooo`0;ooooo`05
onk^k_mEEEGogMgMoeEEEOo^k^h02?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000004oooool3o`000?oooooo:?ooool000Kooooo00?o0000ooooooooool02_ooool01oo^
k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000004oooool00ol0003oooooooooo`3oooooo`Oooooo0_l0000Oooooo`001_oo
ool00ol0003oooooooooo`0:ooooo`;ok^k^0oooool2onk^kPOooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00Oooooo0_l0000:ooooo`03o`000?oooooooooo0?oooooo
1oooool2o`0001oooooo0006ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooooooo`3oooooobSooooo0004ooooo`03oeEEEOmVIVKo000001Sooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo1Ol00002ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolXooooo`00<Oooool3o`0000[ooooo00?o0000ooooooooool0
oooooolXooooo`00<_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0?oooooo:?oo
ool003?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3oooooobSooooo000noooo
o`03o`000?oooooooooo0?oooooo:?ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00
?_ooool00ol0003oooooooooo`3oooooobSooooo000nooooo`;o0000ooooool5ooooo`;o00008_oo
ool003kooooo00?o0000ooooooooool0ooooool4ooooo`;o00008_ooool003kooooo00?o0000oooo
ooooool0oooooolXooooo`00?_ooool00ol0003oooooooooo`3oooooobSooooo000nooooo`03o`00
0?oooooooooo0?oooooo:?ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00?_ooool0
0ol0003oooooooooo`3oooooobSooooo000nooooo`;o0000ooooool2ooooo`;o00009Oooool003ko
oooo00?o0000ooooooooool0ooooool1ooooo`;o00009Oooool003kooooo00?o0000ooooooooool0
oooooolXooooo`00?_ooool00ol0003oooooooooo`3oooooobSooooo000nooooo`;o0000oooooolY
ooooo`00?_ooool00ol0003oooooooooo`3oooooobSooooo000nooooo`03o`000?oooooooooo0?oo
oooo:?ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00?_ooool2o`000?kooooo0_l0
000Xooooo`00?_ooool00ol0003oooooooooo`3mooooo`;o0000:?ooool003kooooo0_l0003ooooo
obWooooo000nooooo`03o`000?oooooooooo0?oooooo:?ooool003kooooo00?o0000ooooooooool0
oooooolXooooo`00?_ooool2o`000?oooooo:Oooool003kooooo00?o0000ooooooooool0n_ooool2
o`0002_ooooo000nooooo`;o0000noooool2o`0002_ooooo0004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooobSo
oooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Cooooo
0_l0003oooooobWooooo0004ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool01?oo
ool3o`000?oooooo:?ooool000Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?oooooo:?ooool000Cooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo0_l0000_ooooo`001?ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0m_ooool2o`0002oo
oooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3oooooobSooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?oEEEEofIVI_l000001_oo
ool00ol0003oooooooooo`3oooooobSooooo000nooooo`03o`000?oooooooooo0?oooooo:?ooool0
03kooooo00?o0000ooooooooool0oooooolXooooo`00?_ooool00ol0003oooooooooo`3oooooobSo
oooo000nooooo`03o`000?oooooooooo0??ooooo0_l0000booooo`00?_ooool00ol0003ooooooooo
o`3cooooo`;o0000<_ooool003kooooo0_l0003oooooobWooooo000nooooo`03o`000?oooooooooo
0?oooooo:?ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00?_ooool00ol0003ooooo
ooooo`3oooooobSooooo000nooooo`03o`000?oooooooooo0?oooooo:?ooool003kooooo00?o0000
ooooooooool0oooooolXooooo`00?_ooool00ol0003oooooooooo`3_ooooo`;o0000=_ooool003ko
oooo0_l0003`ooooo`;o0000=_ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00?_oo
ool00ol0003oooooooooo`3oooooobSooooo000nooooo`03o`000?oooooooooo0?oooooo:?ooool0
03kooooo0_l0003oooooobWooooo000nooooo`03o`000?oooooooooo0?oooooo:?ooool003kooooo
00?o0000ooooooooool0oooooolXooooo`00?_ooool00ol0003oooooooooo`3oooooobSooooo000n
ooooo`;o0000k?ooool2o`0003[ooooo000nooooo`03o`000?oooooooooo0>_ooooo0_l0000joooo
o`00?_ooool00ol0003oooooooooo`3oooooobSooooo000nooooo`;o0000oooooolYooooo`00?_oo
ool00ol0003oooooooooo`3oooooobSooooo000nooooo`;o0000oooooolYooooo`00?_ooool00ol0
003oooooooooo`3oooooobSooooo000nooooo`;o0000oooooolYooooo`003?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co000000?o
410@ooooooooool00_ooool00ol0003oooooooooo`3Wooooo`;o0000?_ooool000cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0
003oooooooooo`04ooooo`;o0000j?ooool2o`0003kooooo000<ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0?oooooo:?ooool000cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo00Cooooo0ol0003oooooobSooooo000<oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0?oooooo:?ooool000cooooo00Go410@oooooooooooo
oooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolXooooo`003?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooo
obSooooo000<ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo0>?ooooo0_l00012ooooo`00?_oo
ool00ol0003oooooooooo`3Sooooo`;o0000@_ooool003kooooo00?o0000ooooooooool0oooooolX
ooooo`00?_ooool00ol0003oooooooooo`3oooooobSooooo000nooooo`03o`000?oooooooooo0?oo
oooo:?ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00?_ooool2o`000?oooooo:Ooo
ool003kooooo00?o0000ooooooooool0goooool2o`0004Kooooo000nooooo`03o`000?oooooooooo
0=oooooo0_l00016ooooo`00?_ooool00ol0003oooooooooo`3oooooobSooooo000nooooo`03o`00
0?oooooooooo0?oooooo:?ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00?_ooool0
0ol0003oooooooooo`3oooooobSooooo000nooooo`;o0000foooool2o`0004_ooooo000nooooo`03
o`000?oooooooooo0=[ooooo0_l0001;ooooo`00?_ooool00ol0003oooooooooo`3oooooobSooooo
000nooooo`03o`000?oooooooooo0?oooooo:?ooool003kooooo0_l0003oooooobWooooo000noooo
o`03o`000?oooooooooo0?oooooo:?ooool003kooooo00?o0000ooooooooool0eOooool2o`00053o
oooo000nooooo`03o`000?oooooooooo0=Gooooo0_l0001@ooooo`00?_ooool2o`000?oooooo:Ooo
ool003kooooo00?o0000ooooooooool0oooooolXooooo`00?_ooool00ol0003oooooooooo`3ooooo
obSooooo000nooooo`;o0000dOooool2o`0005Gooooo000nooooo`03o`000?oooooooooo0=3ooooo
0_l0001Eooooo`00?_ooool2o`000?oooooo:Oooool003kooooo00?o0000ooooooooool0oooooolX
ooooo`00?_ooool2o`000?oooooo:Oooool001?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP04ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooobSooooo000C
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`05ooooo`;o
0000boooool2o`0005_ooooo000Cooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0b_ooool2o`0005_ooooo000Cooooo`05o`000?oooooooooo
ooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00Gooooo0ol0003oooooobSooooo000Cooooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolXoooo
o`004oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo:?ooool001?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooobSooooo000Cooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04
ooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0oooooolXooooo`00?_ooool00ol0
003oooooooooo`3oooooobSooooo000nooooo`03o`000?oooooooooo0?oooooo:?ooool003kooooo
00?o0000ooooooooool0oooooolXooooo`00?_ooool00ol0003oooooooooo`3oooooobSooooo000n
ooooo`03o`000?oooooooooo0<Cooooo0_l0001Qooooo`00?_ooool00ol0003oooooooooo`34oooo
o`;o0000HOooool003kooooo0_l0003oooooobWooooo000nooooo`03o`000?oooooooooo0?oooooo
:?ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00?_ooool00ol0003oooooooooo`3o
ooooobSooooo000nooooo`03o`000?oooooooooo0?oooooo:?ooool003kooooo00?o0000oooooooo
ool0_Oooool2o`0006Sooooo000nooooo`;o0000__ooool2o`0006Sooooo000nooooo`03o`000?oo
oooooooo0?oooooo:?ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00?_ooool00ol0
003oooooooooo`3oooooobSooooo000nooooo`;o0000]oooool2o`0006oooooo000nooooo`03o`00
0?oooooooooo0;Kooooo0_l0001_ooooo`00?_ooool00ol0003oooooooooo`3oooooobSooooo000n
ooooo`03o`000?oooooooooo0?oooooo:?ooool003kooooo0_l0002^ooooo`;o0000N?ooool003ko
oooo00?o0000ooooooooool0[Oooool2o`0007Sooooo000nooooo`03o`000?oooooooooo0?oooooo
:?ooool003kooooo0_l0002Uooooo`;o0000POooool003kooooo00?o0000ooooooooool0Y?ooool2
o`00087ooooo000nooooo`;o0000oooooolYooooo`00?_ooool00ol0003oooooooooo`2Jooooo`;o
0000Roooool003kooooo0_l0002Kooooo`;o0000Roooool001_ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo08kooooo0_l0002Gooooo`006oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0
003oooooooooo`05ooooo`;o0000Soooool2o`0009Oooooo000Kooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`20ooooo`;o0000YOooool001_ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`?o0000P?oo
ool2o`000:Gooooo000Kooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1^ooooo`;o0000
]oooool001_ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Sooooo0_l0000Dooooo`;o
0000]oooool001_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Wooooo0_l0000Moooo
o`;o0000cOooool001_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01?ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo00?ooooo0_l0000d
ooooo`;o0000k?ooool003kooooo00?o0000ooooooooool00oooool2o`000?oooooo8oooool003ko
oooo00?o0000ooooooooool0oooooolXooooo`00?_ooool00ol0003oooooooooo`3oooooobSooooo
000nooooo`03o`000?oooooooooo0?oooooo:?ooool003kooooo00?o0000ooooooooool0oooooolX
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00BOooool2o`0000_ooooo0_l0
003ooooooa7ooooo0019ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0ooooool?
ooooo`008Oooool02?o^k^koEEEEo`000?l0003oA4A4okZj^_oooooo410@1Ol00002ooooo`03oa0@
4?l0003o000000?o00000oooool02?o^k^koEEEEo`000?l0003oEEEEonk^k_oooooo410@1Ol00003
ooooo`03o`000?oooooooooo00;ooooo00Co410@o`000?l0003ooooo0_l000001?l@413ooooooooo
ool0003ooooooa7ooooo000Qooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00KoEEEEogMgMoooooooooooogMgMomEEED3
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool0ooooool?ooooo`008Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`3oooooo`oooooo000Qooooo`Ko00000ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool0ooooool?ooooo`008Oooool01_mEEEGoQhN7
onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oMgMd01Oooool00ol0003o<S8bomgMg@04oooo
o`06oeEEEOmgMgOooooooooooomgMgOoEEEE0oooool00ol0003o<S8bomgMg@04ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ohN7QoooooooZJVYo`000003ooooo`03o`000?oooooooooo0?oooooo
3oooool0027ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`;o000000CoZJVYob4Q8Ol0
003o8B4Q0_ooool2o`000004ojVYZOlQ8B7o0000ob4Q8@;ooooo00Kok^k^oeEEEOl0003o0000oeEE
EOo^k^h2ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool00ol0003oooooooooo`02ooooo`03
oa0@4?l0003oMgMg00;o000000GoV9RHooooooooooooooooo`00003ooooooa7ooooo0019ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0ooooool?ooooo`00BOooool2o`0000_ooooo
0_l0003ooooooa7ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.385391, -7.13773, \
0.00699214, 0.0345757}}]
}, Open  ]],

Cell[TextData[{
  "A description of the theory behind SOR, and further references, can be \
found in ",
  ButtonBox["Press et al. (1992)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ".  The reader is invited to vary the parameter \[Omega], the shape of the \
region and the boundary conditions in order to examine the convergence \
properties of the method."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FFT Method", "Section",
  CellTags->{"i:36", "c:26"}],

Cell[TextData[{
  "Solution of Poisson's equation within a rectangle (or a 3D box) can be \
efficiently performed using the analytic trigonometric Fourier series methods \
discussed in Chapter ",
  ButtonBox["4",
    ButtonData:>{"Chapter4.nb", None},
    ButtonStyle->"Hyperlink"],
  ". However, for high-accuracy results, the number of terms kept in the \
series in each dimension must be large, and the total number of terms in the \
series is the square (in 2D) or cube (in 3D) of this large number. Evaluation \
of the enormous list of Fourier coefficients can be most rapidly accomplished \
using the FFT methods discussed in Chapter ",
  ButtonBox["2",
    ButtonData:>{"Chapter2.nb", None},
    ButtonStyle->"Hyperlink"],
  ".  However, use of the FFT requires that we discretize the potential on a \
grid. "
}], "Text"],

Cell[TextData[{
  "\tAs an example, consider the Poisson equation ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 \[Phi] = \[Rho]\)]],
  " with periodic boundary conditions in a rectangular box with dimensions ",
  Cell[BoxData[
      \(TraditionalForm\`L\_x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`L\_y\)]],
  ". The density and potential are discretized on  the usual rectangular \
grid, "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(x\_j\), "=", " ", 
          RowBox[{"j", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0, 1, 2,  ... , M\_x\ , \)]],
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{\(y\_k\), "=", 
          RowBox[{"k", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["y",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`k = 0, 1, 2,  ... , M\_y\)]],
  ","
}], "UNNEQ"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[
              RowBox[{
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "=", \(L\_x/M\_x\)}],
              "TraditionalForm"], "and", 
            RowBox[{
              FormBox[
                RowBox[{
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["y",
                        FontSlant->"Italic"]}]], "=", \(L\_y/M\_y\)}],
                "TraditionalForm"], "."}]}]}], TraditionalForm]]],
  " Then the density and potential at the grid point ",
  Cell[BoxData[
      \(TraditionalForm\`\((j, k)\)\)]],
  " can be written in terms of a double discrete inverse Fourier transform in \
",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  ", using Eq. ",
  ButtonBox["(2.3.63)",
    ButtonData:>{"Chapter2.nb", "(2.3.63)"},
    ButtonStyle->"Hyperlink"],
  " (changed to use Fourier conventions for spatial transforms):"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Rho]\_\(j\ k\) = \[Sum]\+\(m = 0\)\%\(M\_x - 1\)\ \(\
\[Sum]\+\(n = 0\)\%\(M\_y - 1\)\ \(\[Rho]\&~\_\(m\ n\)\) \
\(\[ExponentialE]\^\(\(\ \ \)\(2\ \[Pi]\ \[ImaginaryI]\ m\ \ j/
                    M\_x\)\)\) \[ExponentialE]\^\(\(\ \)\(2\ \[Pi]\ \
\[ImaginaryI]\ n\ \ k/M\_y\)\)\)\)]]], "NE2",
  CellTags->"(6.2.41)"],

Cell["and", "Text"],

Cell[TextData[{
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(j\ k\) = \[Sum]\+\(m = 0\)\%\(M\_x - 1\)\ \
\(\[Sum]\+\(n = 0\)\%\(M\_y - 1\)\ \(\[Phi]\&~\_\(m\ n\)\) \
\(\[ExponentialE]\^\(2\ \[Pi]\ \[ImaginaryI]\ m\ \ j/
                      M\_x\)\) \[ExponentialE]\^\(\(\ \)\(2\ \[Pi]\
\ \ \[ImaginaryI]\ n\ \ k/M\_y\)\)\)\)], "NE2"], "NE2"],
  StyleBox[".", "NE2"]
}], "NE2",
  CellTags->"(6.2.42)"],

Cell[TextData[{
  "If we substitute these expressions into the discretized Poisson equation \
",
  ButtonBox["(6.2.34)",
    ButtonData:>"(6.2.34)",
    ButtonStyle->"Hyperlink"],
  ", and use orthogonality of the separate Fourier modes, we find that the \
Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\&~\_\(m\ n\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\&~\_\(m\ n\)\)]],
  " are related according to "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[Phi]\&~\_\(m\ n\)\), "(", 
            RowBox[{
              
              FractionBox[\(\[ExponentialE]\^\(\(\ \)\(2\ \[Pi]\ \
\[ImaginaryI]\ m\ /M\_x\)\) - 
                  2\  + \ \[ExponentialE]\^\(\(-2\)\ \[Pi]\ \[ImaginaryI]\ m\ \
/M\_x\)\), 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], "2"]], "+", 
              
              FractionBox[\(\[ExponentialE]\^\(2\ \[Pi]\ \[ImaginaryI]\ n\ /M\
\_y\) - 2\  + \ \[ExponentialE]\^\(\(-2\)\ \[Pi]\[ImaginaryI]\ n\ /M\_y\)\), 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["y",
                        FontSlant->"Italic"]}]], "2"]]}], ")"}], 
          "=", \(\[Rho]\&~\_\(m\ n\)\)}], TraditionalForm]]],
  ","
}], "UNNEQ"],

Cell["or in other words,", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Phi]\&~\_\(m\ n\)\  = \(-\(\[Rho]\&~\_\(m\ n\)\/\(\(\
\(\[Kappa]\^2\)(m, n)\)\(\ \)\)\)\)\)]]], "NE2",
  CellTags->"(6.2.43)"],

Cell["where", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(\[Kappa]\^2\)(m, n)\), " ", "=", " ", 
          RowBox[{
            RowBox[{
              FractionBox["4", 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], 
                  "2"]], \(\(sin\^2\)(\[Pi]\ m/M\_x)\)}], " ", "+", 
            RowBox[{
              FractionBox["4", 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["y",
                        FontSlant->"Italic"]}]], 
                  "2"]], \(\(sin\^2\)(\[Pi]\ n/M\_y)\)}]}]}], 
        TraditionalForm]]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "We can then use this expression in Eq. ",
  ButtonBox["(6.2.42)",
    ButtonData:>"(6.2.42)",
    ButtonStyle->"Hyperlink"],
  " to evaluate the potential at each grid point. Thus, our strategy will be \
to: "
}], "Text"],

Cell[TextData[{
  "(a) Compute the Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\&~\_\(m\ n\)\)]],
  " by a FFT."
}], "Text"],

Cell[TextData[{
  "(b) Determine the Fourier coefficients of the potential via Eq. ",
  ButtonBox["(6.2.43)",
    ButtonData:>"(6.2.43)",
    ButtonStyle->"Hyperlink"],
  ""
}], "Text"],

Cell[TextData[{
  "(c) Perform an inverse FFT to obtain ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(j\ k\)\)]],
  ". We can then interpolate, if we wish, to determine ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y)\)]],
  " at any point ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " in the rectangle."
}], "Text"],

Cell[TextData[{
  "\tBecause of the centered-difference method used, the error in this method \
scales roughly as ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(k\^2\), 
          SuperscriptBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], "2"]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " is the dominant wavenumber in the density and potential. One can see this \
directly in Eq. ",
  ButtonBox["(6.2.43)",
    ButtonData:>"(6.2.43)",
    ButtonStyle->"Hyperlink"],
  ". For low wavenumbers, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\^2\  \[TildeTilde] k\^2\)]],
  " and Eq. ",
  ButtonBox["(6.2.43)",
    ButtonData:>"(6.2.43)",
    ButtonStyle->"Hyperlink"],
  " correctly yields the Fourier transformed Poisson equation,  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\&~ = \(-\[Rho]\&~\)/k\^2\)]],
  ". However, if the density is dominated by wavenumbers on the order of the \
grid spacing, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\^2\)]],
  " is not close to ",
  Cell[BoxData[
      \(TraditionalForm\`k\^2\)]],
  "and the FFT method fails."
}], "Text"],

Cell[TextData[{
  "\tBefore we proceed, we note that Eq. ",
  ButtonBox["(6.2.43)",
    ButtonData:>"(6.2.43)",
    ButtonStyle->"Hyperlink"],
  " blows up for ",
  Cell[BoxData[
      \(TraditionalForm\`n = \(m = 0\)\)]],
  ". This is because, for periodic boundary conditions, constant charge \
density (the ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", Cell[TextData[{
            Cell[BoxData[
                \(TraditionalForm\`m = \(n = 0\)\)]],
            " "
          }]]}], TraditionalForm]]],
  "term) creates an infinite potential :  the uniform charge density \
stretches to infinity in both ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " directions in the periodically replicated boxes, creating an infinite \
potential. Therefore, when using periodic boundary conditions, we require \
that this term in the charge density vanish, so that the net charge density \
in the box  is  zero. "
}], "Text"],

Cell[TextData[{
  "\tFirst, we set the parameters of the grid, taking a rather fine grid in \
",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " to illustrate the speed of the method:"
}], "Text"],

Cell[BoxData[{
    \(\(Clear["\<Global`*\>"];\)\), "\n", 
    \(\(M\_x = \(M\_y = 50\);\)\), "\n", 
    \(\(\(L\_x = \(L\_y = 1\);\)\(\n\)
    \)\), "\n", 
    \(\[CapitalDelta]x = L\_x/M\_x; \[CapitalDelta]y = L\_y/M\_y;\)}], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 6.119"],

Cell[TextData[{
  "This corresponds to a discrete Fourier series with ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(2500\)\(\ \)\)\)]],
  " terms, which would be quite time-consuming to evaluate using a standard \
Fourier series expansion. For fine grids, the FFT method is also more \
efficient than the direct or relaxation methods discusssed previously."
}], "Text"],

Cell["\t  Next, we choose a charge density:", "Text"],

Cell[BoxData[
    \(\(\[Rho][x_, y_]\  = \ 
        x\ Sin[Pi\ x]\ Sin[Pi\ y] - 2\ /Pi^2\ ;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.120"],

Cell["\<\
As required by our periodic boundary conditions, this charge \
density has a zero average, as can be seen by evaluating the integral over \
the box:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Integrate[\ \[Rho][x, y], {x, 0, L\_x}, {y, 0, L\_y}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.121"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The charge density is plotted in Cell ",
  ButtonBox["6.122",
    ButtonData:>"Cell 6.122",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot3D[\[Rho][x, y], {x, 0, 1}, {y, 0, 1}, 
        PlotLabel \[Rule] "\<\[Rho][x,y]\>", 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.122"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
4.2768e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -20 0 ]
[.5 .82364 20 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.29165 .07573 -9.31117 -12 ]
[.29165 .07573 .68883 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.91861 .21225 0 -8.04169 ]
[.91861 .21225 10 3.95831 ]
[.02396 .26606 -24 -2.74312 ]
[.02396 .26606 0 6.25688 ]
[.01223 .33957 -6 -2.80532 ]
[.01223 .33957 0 6.19468 ]
[-7e-05 .41668 -18 -2.87087 ]
[-7e-05 .41668 0 6.12913 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
gsave
.91861 .21225 -61 -12.0417 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03619 .26128 m
.0423 .2589 L
s
[(-0.2)] .02396 .26606 1 -0.39042 Mshowa
.02451 .33495 m
.03065 .33263 L
s
[(0)] .01223 .33957 1 -0.3766 Mshowa
.01227 .41221 m
.01844 .40998 L
s
[(0.2)] -7e-05 .41668 1 -0.36203 Mshowa
.125 Mabswid
.03332 .27938 m
.03699 .27795 L
s
.03042 .29768 m
.03409 .29627 L
s
.02748 .3162 m
.03116 .3148 L
s
.02151 .35391 m
.0252 .35254 L
s
.01846 .37311 m
.02216 .37175 L
s
.01539 .39254 m
.01908 .39119 L
s
.00911 .43212 m
.01282 .43079 L
s
.00592 .45228 m
.00963 .45097 L
s
.00268 .47269 m
.0064 .47139 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.651 .738 .913 r
.38313 .58323 .40512 .60371 .44189 .59268 .42017 .5731 Metetra
.624 .742 .931 r
.42017 .5731 .44189 .59268 .47916 .5815 .45772 .56506 Metetra
.585 .767 .966 r
.45772 .56506 .47916 .5815 .51695 .57017 .49585 .55881 Metetra
.509 .803 .999 r
.49585 .55881 .51695 .57017 .55526 .55867 .53465 .55383 Metetra
.343 .795 .95 r
.53465 .55383 .55526 .55867 .59412 .54701 .57418 .54941 Metetra
.57418 .54941 .59412 .54701 .63352 .53519 .61445 .54472 Metetra
.131 0 0 r
.61445 .54472 .63352 .53519 .67349 .5232 .65544 .53887 Metetra
.227 0 0 r
.65544 .53887 .67349 .5232 .71403 .51104 .6971 .53096 Metetra
.249 0 0 r
.6971 .53096 .71403 .51104 .75515 .4987 .73931 .52017 Metetra
.217 0 0 r
.73931 .52017 .75515 .4987 .79688 .48619 .78193 .50584 Metetra
.12 0 0 r
.78193 .50584 .79688 .48619 .83921 .47349 .82482 .48755 Metetra
.82482 .48755 .83921 .47349 .88217 .4606 .86781 .46517 Metetra
.513 .902 .752 r
.86781 .46517 .88217 .4606 .92578 .44752 .91077 .43888 Metetra
.788 .949 .926 r
.91077 .43888 .92578 .44752 .97003 .43424 .95362 .4092 Metetra
.639 .735 .918 r
.36056 .56222 .38313 .58323 .42017 .5731 .39788 .55293 Metetra
.581 .728 .944 r
.39788 .55293 .42017 .5731 .45772 .56506 .43566 .54791 Metetra
.495 .731 .978 r
.43566 .54791 .45772 .56506 .49585 .55881 .47408 .54658 Metetra
.349 .724 .986 r
.47408 .54658 .49585 .55881 .53465 .55383 .51329 .54794 Metetra
.115 .644 .871 r
.51329 .54794 .53465 .55383 .57418 .54941 .55339 .55064 Metetra
.125 0 0 r
.55339 .55064 .57418 .54941 .61445 .54472 .59445 .55304 Metetra
.252 0 0 r
.59445 .55304 .61445 .54472 .65544 .53887 .63641 .55334 Metetra
.281 0 0 r
.63641 .55334 .65544 .53887 .6971 .53096 .67914 .54972 Metetra
.245 0 0 r
.67914 .54972 .6971 .53096 .73931 .52017 .72244 .54049 Metetra
.149 0 0 r
.72244 .54049 .73931 .52017 .78193 .50584 .766 .52431 Metetra
.766 .52431 .78193 .50584 .82482 .48755 .8095 .50037 Metetra
.8095 .50037 .82482 .48755 .86781 .46517 .85263 .46846 Metetra
.754 .991 .787 r
.85263 .46846 .86781 .46517 .91077 .43888 .8951 .4291 Metetra
.887 .938 .843 r
.8951 .4291 .91077 .43888 .95362 .4092 .93675 .38345 Metetra
.628 .732 .922 r
.33741 .54067 .36056 .56222 .39788 .55293 .375 .5321 Metetra
.535 .71 .952 r
.375 .5321 .39788 .55293 .43566 .54791 .41298 .52981 Metetra
.397 .683 .976 r
.41298 .52981 .43566 .54791 .47408 .54658 .45162 .53295 Metetra
.187 .621 .944 r
.45162 .53295 .47408 .54658 .51329 .54794 .49114 .54014 Metetra
0 .497 .788 r
.49114 .54014 .51329 .54794 .55339 .55064 .53173 .54943 Metetra
.253 0 0 r
.53173 .54943 .55339 .55064 .59445 .55304 .57346 .55846 Metetra
.32 0 0 r
.57346 .55846 .59445 .55304 .63641 .55334 .61628 .56455 Metetra
.296 0 0 r
.61628 .56455 .63641 .55334 .67914 .54972 .66003 .56498 Metetra
.2 0 0 r
.66003 .56498 .67914 .54972 .72244 .54049 .70437 .55721 Metetra
.018 0 0 r
.70437 .55721 .72244 .54049 .766 .52431 .74888 .53924 Metetra
.74888 .53924 .766 .52431 .8095 .50037 .79306 .50987 Metetra
.648 .935 .675 r
.79306 .50987 .8095 .50037 .85263 .46846 .83645 .46892 Metetra
.883 .992 .782 r
.83645 .46892 .85263 .46846 .8951 .4291 .87864 .4173 Metetra
.93 .908 .778 r
.87864 .4173 .8951 .4291 .93675 .38345 .91939 .35695 Metetra
.618 .729 .926 r
.31365 .51855 .33741 .54067 .375 .5321 .3515 .51054 Metetra
.493 .692 .957 r
.3515 .51054 .375 .5321 .41298 .52981 .38966 .5105 Metetra
.306 .63 .962 r
.38966 .5105 .41298 .52981 .45162 .53295 .42847 .51741 Metetra
.06 .523 .894 r
.42847 .51741 .45162 .53295 .49114 .54014 .46823 .52956 Metetra
0 .389 .736 r
.46823 .52956 .49114 .54014 .53173 .54943 .50919 .54451 Metetra
.313 0 0 r
.50919 .54451 .53173 .54943 .57346 .55846 .55147 .55927 Metetra
.338 0 0 r
.55147 .55927 .57346 .55846 .61628 .56455 .59503 .57041 Metetra
.264 0 0 r
.59503 .57041 .61628 .56455 .66003 .56498 .63967 .57438 Metetra
.087 0 0 r
.63967 .57438 .66003 .56498 .70437 .55721 .68498 .56786 Metetra
.68498 .56786 .70437 .55721 .74888 .53924 .73041 .54823 Metetra
.572 .916 .707 r
.73041 .54823 .74888 .53924 .79306 .50987 .77534 .51399 Metetra
.834 .997 .773 r
.77534 .51399 .79306 .50987 .83645 .46892 .81913 .46502 Metetra
.935 .955 .764 r
.81913 .46502 .83645 .46892 .87864 .4173 .86129 .40269 Metetra
.947 .877 .734 r
.86129 .40269 .87864 .4173 .91939 .35695 .90152 .32967 Metetra
.61 .726 .928 r
.28926 .49583 .31365 .51855 .3515 .51054 .32736 .48817 Metetra
.458 .675 .958 r
.32736 .48817 .3515 .51054 .38966 .5105 .36569 .48978 Metetra
.239 .583 .945 r
.36569 .48978 .38966 .5105 .42847 .51741 .40464 .49953 Metetra
0 .452 .859 r
.40464 .49953 .42847 .51741 .46823 .52956 .44457 .51544 Metetra
0 .332 .727 r
.44457 .51544 .46823 .52956 .50919 .54451 .4858 .53474 Metetra
.309 0 0 r
.4858 .53474 .50919 .54451 .55147 .55927 .5285 .55393 Metetra
.292 0 0 r
.5285 .55393 .55147 .55927 .59503 .57041 .57266 .56899 Metetra
.155 0 0 r
.57266 .56899 .59503 .57041 .63967 .57438 .61805 .57568 Metetra
.126 .675 .75 r
.61805 .57568 .63967 .57438 .68498 .56786 .66422 .57006 Metetra
.498 .907 .856 r
.66422 .57006 .68498 .56786 .73041 .54823 .71053 .54902 Metetra
.781 .997 .859 r
.71053 .54902 .73041 .54823 .77534 .51399 .75623 .51079 Metetra
.908 .969 .803 r
.75623 .51079 .77534 .51399 .81913 .46502 .80058 .45536 Metetra
.948 .909 .747 r
.80058 .45536 .81913 .46502 .86129 .40269 .843 .38451 Metetra
.95 .851 .708 r
.843 .38451 .86129 .40269 .90152 .32967 .88312 .30158 Metetra
.605 .725 .93 r
.2642 .4725 .28926 .49583 .32736 .48817 .30258 .46493 Metetra
.436 .663 .957 r
.30258 .46493 .32736 .48817 .36569 .48978 .34108 .46748 Metetra
.204 .553 .932 r
.34108 .46748 .36569 .48978 .40464 .49953 .38015 .47893 Metetra
0 .418 .847 r
.38015 .47893 .40464 .49953 .44457 .51544 .42022 .49716 Metetra
0 .32 .754 r
.42022 .49716 .44457 .51544 .4858 .53474 .46164 .51917 Metetra
0 .303 .714 r
.46164 .51917 .4858 .53474 .5285 .55393 .50464 .54113 Metetra
0 .384 .752 r
.50464 .54113 .5285 .55393 .57266 .56899 .54924 .55863 Metetra
.043 .569 .864 r
.54924 .55863 .57266 .56899 .61805 .57568 .59522 .56699 Metetra
.374 .797 .973 r
.59522 .56699 .61805 .57568 .66422 .57006 .6421 .56182 Metetra
.678 .93 .97 r
.6421 .56182 .66422 .57006 .71053 .54902 .6892 .53967 Metetra
.845 .941 .885 r
.6892 .53967 .71053 .54902 .75623 .51079 .73569 .49864 Metetra
.915 .906 .799 r
.73569 .49864 .75623 .51079 .80058 .45536 .78075 .43877 Metetra
.941 .865 .736 r
.78075 .43877 .80058 .45536 .843 .38451 .8237 .36217 Metetra
.947 .828 .694 r
.8237 .36217 .843 .38451 .88312 .30158 .86416 .27265 Metetra
.603 .724 .93 r
.23846 .44853 .2642 .4725 .30258 .46493 .27712 .44078 Metetra
.431 .658 .955 r
.27712 .44078 .30258 .46493 .34108 .46748 .31582 .44347 Metetra
.206 .543 .928 r
.31582 .44347 .34108 .46748 .38015 .47893 .35503 .45535 Metetra
.003 .419 .858 r
.35503 .45535 .38015 .47893 .42022 .49716 .39522 .47427 Metetra
0 .346 .802 r
.39522 .47427 .42022 .49716 .46164 .51917 .43678 .49711 Metetra
0 .356 .805 r
.43678 .49711 .46164 .51917 .50464 .54113 .47999 .51994 Metetra
.014 .454 .87 r
.47999 .51994 .50464 .54113 .54924 .55863 .52489 .53817 Metetra
.246 .615 .956 r
.52489 .53817 .54924 .55863 .59522 .56699 .57129 .54693 Metetra
.515 .762 .986 r
.57129 .54693 .59522 .56699 .6421 .56182 .61874 .54167 Metetra
.718 .835 .937 r
.61874 .54167 .6421 .56182 .6892 .53967 .66652 .5188 Metetra
.834 .849 .857 r
.66652 .5188 .6892 .53967 .73569 .49864 .71377 .47635 Metetra
.893 .839 .785 r
.71377 .47635 .73569 .49864 .78075 .43877 .75964 .41441 Metetra
.923 .824 .73 r
.75964 .41441 .78075 .43877 .8237 .36217 .8034 .33523 Metetra
.938 .809 .69 r
.8034 .33523 .8237 .36217 .86416 .27265 .84462 .24283 Metetra
.605 .725 .93 r
.212 .42389 .23846 .44853 .27712 .44078 .25096 .41566 Metetra
.441 .66 .954 r
.25096 .41566 .27712 .44078 .31582 .44347 .28991 .41766 Metetra
.242 .553 .931 r
.28991 .41766 .31582 .44347 .35503 .45535 .32931 .42866 Metetra
.081 .448 .881 r
.32931 .42866 .35503 .45535 .39522 .47427 .36965 .44653 Metetra
.013 .395 .85 r
.36965 .44653 .39522 .47427 .43678 .49711 .41135 .46823 Metetra
.054 .414 .863 r
.41135 .46823 .43678 .49711 .47999 .51994 .45469 .48988 Metetra
.19 .494 .903 r
.45469 .48988 .47999 .51994 .52489 .53817 .49978 .507 Metetra
.381 .598 .932 r
.49978 .507 .52489 .53817 .57129 .54693 .54646 .51483 Metetra
.567 .685 .92 r
.54646 .51483 .57129 .54693 .61874 .54167 .59429 .50891 Metetra
.707 .739 .876 r
.59429 .50891 .61874 .54167 .66652 .5188 .64261 .48572 Metetra
.801 .767 .822 r
.64261 .48572 .66652 .5188 .71377 .47635 .69057 .44334 Metetra
.861 .78 .771 r
.69057 .44334 .71377 .47635 .75964 .41441 .73732 .38187 Metetra
.9 .787 .728 r
.73732 .38187 .75964 .41441 .8034 .33523 .78211 .30346 Metetra
.925 .792 .694 r
.78211 .30346 .8034 .33523 .84462 .24283 .82447 .21208 Metetra
.61 .726 .928 r
.18479 .39856 .212 .42389 .25096 .41566 .22409 .38956 Metetra
.466 .668 .951 r
.22409 .38956 .25096 .41566 .28991 .41766 .26335 .39004 Metetra
.305 .578 .937 r
.26335 .39004 .28991 .41766 .32931 .42866 .30302 .39884 Metetra
.188 .493 .903 r
.30302 .39884 .32931 .42866 .36965 .44653 .34358 .41395 Metetra
.156 .452 .882 r
.34358 .41395 .36965 .44653 .41135 .46823 .38544 .43254 Metetra
.21 .463 .881 r
.38544 .43254 .41135 .46823 .45469 .48988 .42891 .45102 Metetra
.324 .511 .886 r
.42891 .45102 .45469 .48988 .49978 .507 .47411 .46522 Metetra
.459 .57 .879 r
.47411 .46522 .49978 .507 .54646 .51483 .52092 .47079 Metetra
.585 .624 .857 r
.52092 .47079 .54646 .51483 .59429 .50891 .56898 .46363 Metetra
.686 .667 .826 r
.56898 .46363 .59429 .50891 .64261 .48572 .61769 .44053 Metetra
.764 .701 .792 r
.61769 .44053 .64261 .48572 .69057 .44334 .66626 .3997 Metetra
.824 .728 .759 r
.66626 .3997 .69057 .44334 .73732 .38187 .71389 .34117 Metetra
.871 .753 .73 r
.71389 .34117 .73732 .38187 .78211 .30346 .75986 .26687 Metetra
.907 .776 .704 r
.75986 .26687 .78211 .30346 .82447 .21208 .80369 .18035 Metetra
.618 .729 .926 r
.1568 .3725 .18479 .39856 .22409 .38956 .19648 .36245 Metetra
.502 .681 .946 r
.19648 .36245 .22409 .38956 .26335 .39004 .23613 .36063 Metetra
.383 .609 .939 r
.23613 .36063 .26335 .39004 .30302 .39884 .27618 .366 Metetra
.306 .542 .914 r
.27618 .366 .30302 .39884 .34358 .41395 .31707 .37678 Metetra
.294 .504 .89 r
.31707 .37678 .34358 .41395 .38544 .43254 .35917 .39046 Metetra
.341 .501 .872 r
.35917 .39046 .38544 .43254 .42891 .45102 .40279 .40391 Metetra
.42 .519 .853 r
.40279 .40391 .42891 .45102 .47411 .46522 .44806 .41356 Metetra
.509 .549 .833 r
.44806 .41356 .47411 .46522 .52092 .47079 .49492 .41568 Metetra
.592 .582 .811 r
.49492 .41568 .52092 .47079 .56898 .46363 .54307 .40678 Metetra
.666 .616 .789 r
.54307 .40678 .56898 .46363 .61769 .44053 .592 .38412 Metetra
.73 .649 .769 r
.592 .38412 .61769 .44053 .66626 .3997 .64105 .34616 Metetra
.786 .684 .751 r
.64105 .34616 .66626 .3997 .71389 .34117 .68951 .29283 Metetra
.837 .72 .735 r
.68951 .29283 .71389 .34117 .75986 .26687 .73673 .22568 Metetra
.883 .759 .721 r
.73673 .22568 .75986 .26687 .80369 .18035 .78223 .14761 Metetra
.628 .732 .922 r
.128 .34568 .1568 .3725 .19648 .36245 .16809 .33434 Metetra
.544 .696 .939 r
.16809 .33434 .19648 .36245 .23613 .36063 .20824 .32953 Metetra
.465 .641 .933 r
.20824 .32953 .23613 .36063 .27618 .366 .2488 .3304 Metetra
.418 .586 .911 r
.2488 .3304 .27618 .366 .31707 .37678 .29015 .33546 Metetra
.414 .548 .881 r
.29015 .33546 .31707 .37678 .35917 .39046 .33261 .34269 Metetra
.443 .529 .851 r
.33261 .34269 .35917 .39046 .40279 .40391 .37646 .3496 Metetra
.49 .528 .823 r
.37646 .3496 .40279 .40391 .44806 .41356 .42181 .35336 Metetra
.543 .537 .798 r
.42181 .35336 .44806 .41356 .49492 .41568 .46865 .35106 Metetra
.597 .555 .778 r
.46865 .35106 .49492 .41568 .54307 .40678 .51677 .34001 Metetra
.649 .579 .763 r
.51677 .34001 .54307 .40678 .592 .38412 .56577 .31809 Metetra
.698 .608 .752 r
.56577 .31809 .592 .38412 .64105 .34616 .61516 .28405 Metetra
.748 .644 .746 r
.61516 .28405 .64105 .34616 .68951 .29283 .66434 .23777 Metetra
.797 .687 .743 r
.66434 .23777 .68951 .29283 .73673 .22568 .71279 .18031 Metetra
.849 .74 .743 r
.71279 .18031 .73673 .22568 .78223 .14761 .76008 .1138 Metetra
.639 .735 .918 r
.09834 .31807 .128 .34568 .16809 .33434 .13889 .30523 Metetra
.587 .71 .928 r
.13889 .30523 .16809 .33434 .20824 .32953 .17965 .29687 Metetra
.541 .669 .92 r
.17965 .29687 .20824 .32953 .2488 .3304 .22087 .29236 Metetra
.514 .622 .896 r
.22087 .29236 .2488 .3304 .29015 .33546 .26284 .29064 Metetra
.51 .582 .863 r
.26284 .29064 .29015 .33546 .33261 .34269 .30581 .29026 Metetra
.522 .553 .829 r
.30581 .29026 .33261 .34269 .37646 .3496 .34999 .28949 Metetra
.544 .537 .798 r
.34999 .28949 .37646 .3496 .42181 .35336 .39548 .2864 Metetra
.571 .533 .774 r
.39548 .2864 .42181 .35336 .46865 .35106 .44229 .27901 Metetra
.601 .539 .756 r
.44229 .27901 .46865 .35106 .51677 .34001 .49029 .26554 Metetra
.634 .553 .746 r
.49029 .26554 .51677 .34001 .56577 .31809 .53924 .24454 Metetra
.669 .576 .742 r
.53924 .24454 .56577 .31809 .61516 .28405 .58879 .21517 Metetra
.707 .608 .744 r
.58879 .21517 .61516 .28405 .66434 .23777 .63854 .17724 Metetra
.751 .654 .753 r
.63854 .17724 .66434 .23777 .71279 .18031 .68812 .13137 Metetra
.802 .716 .77 r
.68812 .13137 .71279 .18031 .76008 .1138 .73719 .07886 Metetra
.651 .738 .913 r
.0678 .28963 .09834 .31807 .13889 .30523 .10886 .27514 Metetra
.627 .722 .915 r
.10886 .27514 .13889 .30523 .17965 .29687 .15032 .26282 Metetra
.606 .69 .902 r
.15032 .26282 .17965 .29687 .22087 .29236 .19236 .25233 Metetra
.592 .65 .876 r
.19236 .25233 .22087 .29236 .26284 .29064 .23513 .24309 Metetra
.585 .609 .842 r
.23513 .24309 .26284 .29064 .30581 .29026 .27877 .23437 Metetra
.584 .574 .808 r
.27877 .23437 .30581 .29026 .34999 .28949 .32341 .22525 Metetra
.588 .55 .779 r
.32341 .22525 .34999 .28949 .39548 .2864 .36913 .21477 Metetra
.596 .535 .757 r
.36913 .21477 .39548 .2864 .44229 .27901 .41593 .20195 Metetra
.607 .53 .742 r
.41593 .20195 .44229 .27901 .49029 .26554 .46378 .1859 Metetra
.622 .535 .735 r
.46378 .1859 .49029 .26554 .53924 .24454 .51256 .16593 Metetra
.641 .549 .736 r
.51256 .16593 .53924 .24454 .58879 .21517 .56212 .14158 Metetra
.665 .576 .745 r
.56212 .14158 .58879 .21517 .63854 .17724 .61226 .11272 Metetra
.696 .618 .765 r
.61226 .11272 .63854 .17724 .68812 .13137 .66278 .07959 Metetra
.737 .684 .8 r
.66278 .07959 .68812 .13137 .73719 .07886 .71353 .04274 Metetra
.664 .741 .908 r
.03634 .26033 .0678 .28963 .10886 .27514 .07793 .24409 Metetra
.663 .732 .901 r
.07793 .24409 .10886 .27514 .15032 .26282 .12022 .22757 Metetra
.659 .707 .882 r
.12022 .22757 .15032 .26282 .19236 .25233 .16322 .21077 Metetra
.653 .67 .854 r
.16322 .21077 .19236 .25233 .23513 .24309 .20695 .19369 Metetra
.644 .631 .822 r
.20695 .19369 .23513 .24309 .27877 .23437 .25144 .17632 Metetra
.634 .595 .792 r
.25144 .17632 .27877 .23437 .32341 .22525 .29669 .15864 Metetra
.625 .565 .766 r
.29669 .15864 .32341 .22525 .36913 .21477 .34274 .14065 Metetra
.618 .543 .747 r
.34274 .14065 .36913 .21477 .41593 .20195 .3896 .12235 Metetra
.613 .529 .735 r
.3896 .12235 .41593 .20195 .46378 .1859 .43729 .10372 Metetra
.612 .524 .731 r
.43729 .10372 .46378 .1859 .51256 .16593 .48583 .08476 Metetra
.613 .529 .735 r
.48583 .08476 .51256 .16593 .56212 .14158 .53526 .06546 Metetra
.619 .545 .749 r
.53526 .06546 .56212 .14158 .61226 .11272 .58558 .0458 Metetra
.629 .578 .778 r
.58558 .0458 .61226 .11272 .66278 .07959 .63684 .02578 Metetra
.646 .638 .828 r
.63684 .02578 .66278 .07959 .71353 .04274 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00l_ooool4o`000003oa0@4?oooooooooo06oooooo003dooooo`03o`00
0?oooooooooo077ooooo003dooooo`03o`000?oooooooooo077ooooo003dooooo`03o`000?oooooo
oooo077ooooo003dooooo`03o`000?oooooooooo077ooooo003dooooo`03o`000?oooooooooo077o
oooo003dooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Uooooo`00
l_ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0IOooool00?kooooo
00Go410@oooooooooooooooooa0@401Uooooo`00o_ooool01Ol0003ooooooooooooooooo000006Go
oooo003nooooo`05o`000?ooooooooooooooool00000IOooool00?kooooo00Go410@oooooooooooo
oooooa0@401Uooooo`00n?ooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Uooooo`00
mOooool3o`000003ooooool0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Uooooo`00
loooool2o`0000?ooooo0ol0001]ooooo`00l?ooool3o`0000;ooooo0ol000001?nUXm?o0000oooo
ool0001/ooooo`00k_ooool2o`0000;ooooo0ol00004ojFSd`?o0000K?ooool00>_ooooo1?l00000
0ooooooo0000o`000007ojFSd`04o`000?nUXm?o0000o`0006_ooooo002eooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o0000
0_ooool3o`0000WoYJ?C00Go0000ojFSdol0003oooooo`00001Zooooo`00]Oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B407?ooool2o`00
00;ooooo0ol0000<ojFSd`03o`000?nUXm?oYJ?C00;o0000J_ooool00;Gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0000;ooooo0_l0000?
ojFSd`04o`000?nUXm?oYJ?CojFSd`;o0000JOooool00;Gooooo00Go0000ooooooooooooooooo`00
000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S805oooool2o`0000;ooooo0ol000000onQTlOo0000
ojFSd`0?ojFSd`03o`000?nUXm?oYJ?C00?o0000J?ooool00;Gooooo00Go0000oooooooooooooooo
o`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`05?ooool3o`0000;ooooo0_l00005oj6Ca`03
o`000?nUXm?oYJ?C00goYJ?C00Co0000ojFSdonUXm?oYJ?C0_l0001Xooooo`00]Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400Booooo`;o00000_ooool3
o`0000OoXI?700?o0000ojFSdonUXm<03OnUXm<00ol0003oYJ?CojFSd`02ojFSd`;o0000Ioooool0
0;Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000003ooo
ool3o`0000;ooooo0_l0000;oj6Ca`03o`000?nUXm?oYJ?C00coYJ?C00?o0000ojFSdonUXm<00_nU
Xm<00ol0003oooooo`00001Vooooo`00]Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@0=ooooo`;o00000oooool2o`0000goXI?700?o0000ojFSdonUXm<0
3?nUXm<00ol0003oYJ?CojFSd`03ojFSd`;o0000I_ooool007?ooooo0_l00002ooooo`;o0000Fooo
ool4o`000004ooooool0003o0000o`0000ooXI?700?o0000ojFSdonUXm<03?nUXm<00ol0003oYJ?C
ojFSd`03ojFSd`?o0000IOooool007?ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMeIooooo`;o
00000oooool2o`0001?oXI?700?o0000ojFSdonUXm<02onUXm<00ol0003oYJ?CojFSd`02ojFSd`04
o`000?nl[lco0000o`0006Gooooo001dooooo`04omgMgOl0003o410@olc<c5Oooooo0ol00002oooo
o`?o000000?oWX^oo`000?nQTlL04_nQTlL00ol0003oYJ?CojFSd`0;ojFSd`05o`000?nUXm?oYJ?C
ojFSdol000000onl[l`2o`0006Cooooo001dooooo`04onk^k_lQ8B7o410@onk^kUCooooo0ol00003
ooooo`;o00001OnNRkl00ol0003oXI?7oj6Ca`0Aoj6Ca`03o`000?nUXm?oYJ?C00[oYJ?C00Co0000
ojFSdol0003o00001Onl[l`2o`0006?ooooo001dooooo`04ob4Q8OmgMgOoMgMgoc8b<U;ooooo0ol0
0002ooooo`?o00001onNRkl00ol0003oXI?7oj6Ca`0Aoj6Ca`03o`000?nUXm?oYJ?C00[oYJ?C0_l0
0008okb_c003o`000?oooooooooo067ooooo001cooooo`;o00000_ooool2o`0004kooooo0ol00002
ooooo`?o00002onNRkl00ol0003oXI?7oj6Ca`0Aoj6Ca`03o`000?nUXm?oYJ?C00WoYJ?C00?o0000
okb_c?nl[l`01onl[l`2o`0006;ooooo0035ooooo`;o00000oooool4o`0000coWX^o00?o0000oj6C
aonQTlL04OnQTlL00ol0003oYJ?CojFSd`07ojFSd`?o00002_nl[l`2o`00067ooooo0032ooooo`?o
00000oooool2o`00013oWX^o00?o0000oj6CaonQTlL04_nQTlL00ol0003oYJ?CojFSd`05ojFSd`04
o`000?nl[lco_:o<o`0000_o_:o<00?o0000ooooooooool0Goooool00<3ooooo0_l00003ooooo`?o
000000?oW8Nlo`000?nNRkl04?nNRkl00ol0003oXI?7oj6Ca`0Aoj6Ca`03o`000?nUXm?oYJ?C00Co
YJ?C00Go0000okb_c?nl[lco_:o<o`00000;okb_c0;o0000H?ooool008Wooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<01oooooo0ol00000
0ooooooo0000o`000002o`0000GoW8Nl00?o0000oij;_onNRkl03_nNRkl00ol0003oXI?7oj6Ca`0A
oj6Ca`03o`000?nUXm?oYJ?C00;oYJ?C0_l00004okb_c003o`000?nl[lco_:o<00[o_:o<0_l0001O
ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOo
oooooiRHV?lQ8B407Oooool2o`0000?ooooo0_l00008oib7_003o`000?nNRkooWX^o00ooWX^o00?o
0000oj6CaonQTlL04OnQTlL01?l0003oYJ?CojFSdol00007okb_c003o`000?nl[lco_:o<00[o_:o<
00?o0000ooooooooool0GOooool008Wooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`00
0?ooooooooooooooool000006_ooool3o`0000;ooooo0ol0000:oib7_003o`000?nNRkooWX^o00oo
WX^o00?o0000oj6CaonQTlL04OnQTlL00ol0003oYJ?Co`000008okb_c003o`000?nl[lco_:o<00_o
_:o<00?o0000ooooooooool0G?ooool008Wooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?nHV9SooooooiRHV?lQ8B406?ooool2o`0000;ooooo0ol0000>oib7_003o`000?nNRkooWX^o
00ooWX^o00?o0000oj6CaonQTlL04?nQTlL2o`0000Wo_:o<00?o0000okb_c?nl[l`02onl[l`2o`00
00Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00043ooooo0029oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<01Gooooo1?l0
00000ooooooo0000o`00000Aoib7_003o`000?nNRkooWX^o00ooWX^o00?o0000oj6CaonQTlL03onQ
TlL00ol0003o/Yk3o`000009okb_c003o`000?nl[lco_:o<00[o_:o<00?o0000olfgaOl000002?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@0@?ooool008Wooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo01Go
oooo0_l00002ooooo`?o000000?oW8Jko`000?nLQk`04?nLQk`00ol0003oWX^ooij;_`0?oij;_`03
o`000?nQTlOoXI?700goXI?70_l00003ok:N``03o`000?nl[lco_:o<00Ko_:o<00?o0000okb_c?nl
[l`02Onl[l`01Ol0003ocKO5olfgaOo=]lGo000000Oooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^047ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
0ooMgMgo410@oiRHV00Booooo`?o000000Coooooo`000?l0003o00001?nLQ[/00ol0003oW8Nloib7
_00@oib7_003o`000?nNRkooWX^o00ooWX^o00?o0000oj6CaonQTlL02_nQTlL2o`0000Go/Yk300?o
0000okb_c?nl[l`01_nl[l`00ol0003o_:o<okb_c008okb_c003o`000?o=]lGocKO500;ocKO50_l0
0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP10ooooo`00ROoo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@3Oooool3o`0000;o
oooo0_l00008oib6^`03o`000?nLQkcoW8Nl00ooW8Nl00?o0000oij;_onNRkl03onNRkl00ol0003o
XI?7oj6Ca`09oj6Ca`03o`000?nbW/?o/Yk300Ko/Yk300?o0000okb_c?nl[l`01Onl[l`00ol0003o
_:o<okb_c007okb_c003o`000?o=]lGocKO500CocKO500?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0?oooool00:Wooooo0ol000001?oooooo
0000o`000?l0000:oib6^`03o`000?nLQkcoW8Nl00ooW8Nl00?o0000oij;_onNRkl04?nNRkl00ol0
003oXI?7oj6Ca`06oj6Ca`;o00002OnbW/<00ol0003o_:o<okb_c005okb_c003o`000?nl[lco_:o<
00Ko_:o<00?o0000olfgaOo=]lD01_o=]lD00ol0003oooooooooo`03ooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`0nooooo`00Y_ooool3o`000004ooooool0003o0000
o`0000goW8Jk00?o0000oib7_?nLQk`04?nLQk`00ol0003oWX^ooij;_`0?oij;_`03o`000?nQTlOo
XI?700GoXI?700?o0000ok:N`onbW/<02_nbW/<00ol0003o_:o<okb_c004okb_c003o`000?nl[lco
_:o<00Go_:o<00?o0000olfgaOo=]lD01oo=]lD2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100@?ooool00:Cooooo0_l00002ooooo`;o00004OnL
Q[/00ol0003oW8Nloib7_00?oib7_003o`000?nNRkooWX^o013oWX^o00?o0000oj6CaonQTlL00_nQ
TlL2o`0000go/Yk300?o0000okb_c?nl[l`01?nl[l`00ol0003o_:o<okb_c004okb_c003o`000?o=
]lGocKO500WocKO500?o0000ooooooooool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c010ooooo`00XOooool3o`000006ooooool0003o0000o`000?nL
Qkco00004OnLQ[/00ol0003oW8Nloib7_00?oib7_003o`000?nNRkooWX^o013oWX^o00?o0000oj6C
aonQTlL00_l0000@ok:N``03o`000?nl[lco_:o<00?o_:o<00?o0000okb_c?nl[l`00onl[l`00ol0
003ocKO5olfga@0:olfga@;o0000F?ooool009oooooo0_l00002ooooo`;o00001OnLQk`00ol0003o
W8Jkoib6^`0>oib6^`03o`000?nLQkcoW8Nl013oW8Nl00?o0000oij;_onNRkl03onNRkl00ol0003o
XI?7o`00000Bok:N``03o`000?nl[lco_:o<00?o_:o<00?o0000okb_c?nl[l`00_nl[l`00ol0003o
cKO5olfga@0<olfga@;o0000Eoooool009cooooo0ol000001?oooooo0000o`000?l00007oib7_003
o`000?nLQ[_oW8Jk00ooW8Jk00?o0000oib7_?nLQk`03onLQk`00ol0003oWX^ooij;_`0?oij;_`;o
00005?nbW/<00ol0003o_:o<okb_c002okb_c005o`000?nl[lco_:o<okb_c?l000004?o=]lD00ol0
003oooooooooo`1Eooooo`00V_ooool2o`0000;ooooo0_l00002oib7_003o`000?nLQkcoW8Nl00Go
W8Nl00?o0000oib6^onLQ[/03onLQ[/00ol0003oW8Nloib7_00?oib7_003o`000?nNRkooWX^o00go
WX^o0_l000000onZTkko0000ok:N``0Cok:N``03o`000?nl[lco_:o<00;o_:o<00Co0000okb_c?nl
[lco00004Oo=]lD2o`0005Kooooo002Gooooo`?o000000Coooooo`000?l0003o00003OnLQk`00ol0
003oW8Jkoib6^`0>oib6^`03o`000?nLQkcoW8Nl013oW8Nl00?o0000oij;_onNRkl02onNRkl00ol0
003oZY>nojZC_P02ojZC_P03o`000?nbW/?o/Yk301;o/Yk300Oo0000okb_c?nl[lco_:o<o`000?nl
[lco0000017ocKO500Co0000omVm__l0003o0000EOooool005oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo01oooooo0_l00002ooooo`;o0000
4?nLQk`00ol0003oW8Jkoib6^`0?oib6^`03o`000?nLQkcoW8Nl00ooW8Nl00?o0000oij;_onNRkl0
2OnNRkl2o`0000GoZY>n00?o0000ok:N`onbW/<04_nbW/<01?l0003o_:o<okb_c?nl[l`2o`00017o
cKO500Go0000omVm__oI_KkofKfno`00001Eooooo`00Goooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo01gooooo0ol000001_oooooo0000o`000?l0003o
WX^oo`00013oW8Nl00?o0000oib6^onLQ[/03onLQ[/00ol0003oW8Nloib7_00?oib7_003o`000?nN
RkooWX^o00OoWX^o0_l00007ojZC_P03o`000?nbW/?o/Yk301?o/Yk300?o0000okb_c?nl[l`00_l0
000@olfga@03o`000?oI_KkofKfn00;ofKfn0_l0001Dooooo`00Goooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol0000Kooooo`?o00000_ooool2o`0000GoWX^o00?o0000oib7_?nLQk`03_nL
Qk`00ol0003oW8Jkoib6^`0>oib6^`03o`000?nLQkcoW8Nl013oW8Nl00?o0000oij;_onNRkl01?nN
Rkl2o`0000[oZY>n00?o0000ok:N`onbW/<04_nbW/<01Ol0003o_:o<o`000?o=]lGo0000013ocKO5
00?o0000omVm__oI_Kh00ooI_Kh2o`0005?ooooo001Oooooo`05o`000?ooooooooooooooool00000
2oooool01?m4A4CogMgMooooool0000Jooooo`;o00000_ooool3o`0000OoWX^o00?o0000oib7_?nL
Qk`03_nLQk`00ol0003oW8Jkoib6^`0>oib6^`03o`000?nLQkcoW8Nl013oW8Nl00?o0000oij;_onN
Rkl00_nNRkl2o`0000coZY>n00?o0000ok:N`onbW/<04_nbW/<2o`0000;ocKO500?o0000olfgaOo=
]lD03Oo=]lD00ol0003ofKfnomVm_P05omVm_P03o`000?oooooooooo057ooooo001Oooooo`05o`00
0?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000Gooooo`?o00000_ooool2o`00
00[oWX^o00?o0000oib7_?nLQk`03_nLQk`00ol0003oW8Jkoib6^`0?oib6^`03o`000?nLQkcoW8Nl
00ooW8Nl00Go0000oij;_onNRkooWX^oo`00000>ojZC_P03o`000?nbW/?o/Yk3017o/Yk300?o0000
ol2W`?l000000_o=]lD00ol0003ocKO5olfga@0<olfga@03o`000?oI_KkofKfn00KofKfn0_l0001B
ooooo`00Goooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000005Oooool2
o`0000;ooooo0ol0000=oij;_`03o`000?nLQkcoW8Nl00koW8Nl00?o0000oib6^onLQ[/03_nLQ[/0
0ol0003oW8Nloib7_00@oib7_0?o00004?nZTkh00ol0003o/Yk3ok:N``0?ok:N``07o`000?o0Yl3o
`:O0ol2W`?l0003ocKO5o`00000>olfga@03o`000?oI_KkofKfn00OofKfn00?o0000ooooooooool0
D?ooool005oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000001;ooooo
0ol00002ooooo`;o00004?nNRkl00ol0003oW8Nloib7_00>oib7_003o`000?nLQ[_oW8Jk00koW8Jk
00?o0000oib7_?nLQk`03onLQk`2o`0001;oZY>n00?o0000ok:N`onbW/<03_nbW/<00ol0003o`:O0
ol2W`002ol2W`003o`000?o=]lGo000000gocKO500?o0000omVm__oI_Kh02?oI_Kh2o`00057ooooo
001Oooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0?ooooo`;o0000
0_ooool3o`000003oin@a?l0003oWX^o00ooWX^o00?o0000oib7_?nLQk`03_nLQk`00ol0003oW8Jk
oib6^`0?oib6^`03o`000?nLQkcoW8Nl00coW8Nl0_l000000onTS;co0000ojZC_P0BojZC_P03o`00
0?nbW/?o/Yk300co/Yk300?o0000ol2W`?o0Yl001?o0Yl02o`0000cocKO500?o0000omVm__oI_Kh0
2_oI_Kh2o`00053ooooo0020ooooo`?o00000_ooool2o`0000GoWi3400?o0000oij;_onNRkl03_nN
Rkl00ol0003oW8Nloib7_00>oib7_003o`000?nLQ[_oW8Jk00koW8Jk00?o0000oib7_?nLQk`02_nL
Qk`2o`0000CoY8bl00?o0000ojZC__nZTkh04?nZTkh00ol0003o/Yk3ok:N``0;ok:N``03o`000?o0
Yl3o`:O000Go`:O00_l0000;olfga@03o`000?oI_KkofKfn00cofKfn00?o0000ooooooooool0C_oo
ool007kooooo0_l00002ooooo`?o00001onOT<@00ol0003oWX^ooij;_`0>oij;_`03o`000?nLQkco
W8Nl00koW8Nl00?o0000oib6^onLQ[/03_nLQ[/00ol0003oW8Nloib7_008oib7_0;o00001_nTS;`0
0ol0003oZY>nojZC_P0@ojZC_P03o`000?nbW/?o/Yk300[o/Yk300?o0000ol2W`?o0Yl001oo0Yl00
0ol0003ocKO5olfga@09olfga@03o`000?oI_KkofKfn00cofKfn0_l0001?ooooo`00Noooool3o`00
00;ooooo0ol00009oin@a003o`000?nNRkooWX^o00koWX^o00?o0000oib7_?nLQk`03_nLQk`00ol0
003oW8Jkoib6^`0?oib6^`03o`000?nLQkcoW8Nl00GoW8Nl0_l00008ojB<_003o`000?nZTkkoZY>n
017oZY>n00?o0000ok:N`onbW/<02?nbW/<00ol0003o`:O0ol2W`008ol2W`003o`000?o=]lGocKO5
00SocKO500?o0000omVm__oI_Kh03?oI_Kh01?l0003oh/:ho`000?l0001>ooooo`00NOooool2o`00
00?ooooo0_l0000=oin@a003o`000?nNRkooWX^o00koWX^o00?o0000oib7_?nLQk`03_nLQk`00ol0
003oW8Jkoib6^`0>oib6^`03o`000?nLQkcoW8Nl00?oW8Nl0_l0000;ojB<_003o`000?nZTkkoZY>n
013oZY>n00?o0000ok:N`onbW/<01onbW/<00ol0003o`:O0ol2W`009ol2W`0;o00002?o=]lD00ol0
003ofKfnomVm_P0<omVm_P05o`000?oR`[Soh/:hon;2^?l00000C_ooool007Kooooo0ol00003oooo
o`;o00003onOT<@00ol0003oWX^ooij;_`0>oij;_`03o`000?nLQkcoW8Nl00koW8Nl00?o0000oib6
^onLQ[/03_nLQ[/01?l0003oW8Nloib7_?nLQk`2o`0000goY8bl00?o0000ojZC__nZTkh04OnZTkh0
0ol0003o/Yk3ok:N``05ok:N``03o`000?o0Yl3o`:O000[o`:O000?o0000ol2W`?l000001oo=]lD0
0ol0003ofKfnomVm_P0<omVm_P04o`000?oR`[Soh/:hon;2^0;o0000COooool007?ooooo0ol00002
ooooo`Co000000?oXYS:o`000?nOT<@03onOT<@00ol0003oWX^ooij;_`0>oij;_`03o`000?nLQkco
W8Nl00goW8Nl00?o0000oib6^onLQ[/03onLQ[/3o`0000ooY8bl00?o0000ojZC__nZTkh04OnZTkh0
0ol0003o/Yk3ok:N``04ok:N``03o`000?o0Yl3o`:O000_o`:O000?o0000ol2W`?l000001_o=]lD0
0ol0003ofKfnomVm_P0<omVm_P03o`000?oR`[Soh/:h00?oh/:h0_l0001<ooooo`00LOooool2o`00
00?ooooo1?l00004oj:HbP03o`000?nOT<CoWi3400goWi3400?o0000oij;_onNRkl03_nNRkl00ol0
003oW8Nloib7_00>oib7_003o`000?nLQ[_oW8Jk00goW8Jk0_l0000BojB<_003o`000?nZTkkoZY>n
013oZY>n00?o0000ok:N`onbW/<00onbW/<00ol0003o`:O0ol2W`00<ol2W`004o`000?o0Yl3o`:O0
o`0000CocKO500?o0000omVm__oI_Kh03OoI_Kh00ol0003oh/:hon;2^004on;2^003o`000?oooooo
oooo04[ooooo001^ooooo`?o00000_ooool3o`0000SoXYS:00?o0000oin@a?nOT<@03OnOT<@00ol0
003oWX^ooij;_`0>oij;_`03o`000?nLQkcoW8Nl00koW8Nl00?o0000oib6^onLQ[/02_nLQ[/3o`00
0003oin8_?l0003oY8bl017oY8bl00?o0000ojZC__nZTkh04OnZTkh01Ol0003o/Yk3ok:N`onbW/?o
000000oo`:O000Co0000ol2W`?o0Yl3o00000oo=]lD00ol0003ofKfnomVm_P0=omVm_P03o`000?oR
`[Soh/:h00Koh/:h00?o0000ooooooooool0BOooool003Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`00027ooooo0_l00002ooooo`?o00002onRV<X00ol0003oWi34oin@
a00>oin@a003o`000?nNRkooWX^o00koWX^o00?o0000oib7_?nLQk`03OnLQk`00ol0003oW8Jkoib6
^`08oib6^`;o00001OnOR;`00ol0003oY8blojB<_00@ojB<_003o`000?nZTkkoZY>n013oZY>n00Co
0000ok:N`onbW/?o00004?o0Yl001Ol0003o`:O0ol2W`?o0Yl3o000000;ocKO500?o0000omVm__oI
_Kh03?oI_Kh00ol0003oh/:hon;2^007on;2^0;o0000B_ooool003Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A401kooooo0ol00002oooo
o`;o00003onRV<X00ol0003oWi34oin@a00=oin@a003o`000?nNRkooWX^o00koWX^o00?o0000oib7
_?nLQk`03_nLQk`00ol0003oW8Jkoib6^`04oib6^`?o00001onOR;`00ol0003oY8blojB<_00@ojB<
_003o`000?nZTkkoZY>n013oZY>n00?o0000ok:N`ol000004_o0Yl001_l0003o`:O0ol2W`?l0003o
cKO5o`0000oofKfn00?o0000on;2^?oR`[P02?oR`[P00ol0003oooooooooo`06ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`0[ooooo`00=_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h07Oooool2o`0000;ooooo
0ol000000onTXM;o0000oj:HbP0>oj:HbP03o`000?nOT<CoWi3400koWi3400?o0000oij;_onNRkl0
3OnNRkl00ol0003oW8Nloib7_00>oib7_003o`000?nLQ[_oW8Jk00;oW8Jk0_l0000:oin8_003o`00
0?nTS;coY8bl013oY8bl00?o0000ojZC__nZTkh04?nZTkh2o`0001?o`:O000Go0000ol2W`?o0Yl3o
`:O0o`00000?omVm_P03o`000?oR`[Soh/:h00[oh/:h00?o0000ooooooooool01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02cooooo000fooooo`05
o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Iooooo`?o00000_ooool2o`00
00GoY:7B00?o0000oj:Hb_nRV<X03?nRV<X00ol0003oWi34oin@a00>oin@a003o`000?nNRkooWX^o
00koWX^o00?o0000oib7_?nLQk`03OnLQk`00ol0003oW8Jko`000002o`0000goWhRl00?o0000ojB<
_?nTS;`04?nTS;`00ol0003oZY>nojZC_P0>ojZC_P03o`000?ndVkko000001?o`:O000Go0000ol2W
`?o0Yl3o`:O0o`00000?omVm_P03o`000?oR`[Soh/:h00[oh/:h0_l00006ooooo`05oa0@4?oooooo
ooooooooool@41002oooool5o`0002gooooo000fooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`0Fooooo`;o00000_ooool3o`0000OoY:7B00?o0000oj:Hb_nRV<X03OnR
V<X00ol0003oWi34oin@a00=oin@a003o`000?nNRkooWX^o00koWX^o00?o0000oib7_?nLQk`03OnL
Qk`2o`00013oWhRl00?o0000ojB<_?nTS;`04?nTS;`00ol0003oZY>nojZC_P0=ojZC_P05o`000?nd
Vkko]9^nokBK__l000004_o0Yl001_l0003o`:O0ol2W`?l0003oc:nno`0000gofKfn00?o0000on;2
^?oR`[P02_oR`[P00ol0003oj<Jdo`000006ooooo`05o`000?ooooooooooooooool000002oooool0
1?m4A4CogMgMooooool0000;ooooo`?o000000?o410@ooooooooool07Oooool003Kooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01;ooooo0ol00002ooooo`;o00002_nT
XM800ol0003oXYS:oj:HbP0=oj:HbP03o`000?nOT<CoWi3400koWi3400?o0000oij;_onNRkl03OnN
Rkl00ol0003oW8Nloib7_00:oib7_0?o000000?oVhNmo`000?nOR;`03onOR;`00ol0003oY8blojB<
_00@ojB<_003o`000?nZTkkoZY>n00coZY>n00?o0000okBK__ndVkh00_ndVkh00ol0003o`:O0ol2W
`00@ol2W`003o`000?o0Yl3o000000;oc:nn00?o0000omVm__oI_Kh02_oI_Kh00ol0003oh/:hon;2
^00;on;2^004o`000?oXa[Co0000o`0000Gooooo00Go0000ooooooooooooooooo`00000;ooooo`04
omgMgOmEEEGoooooo`0000gooooo00?o410@okZj^_ooool07_ooool003Kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41004_ooool2o`0000;ooooo0ol0000=
ojBQdP03o`000?nRV<[oXYS:00goXYS:00?o0000oin@a?nOT<@03OnOT<@00ol0003oWX^ooij;_`0>
oij;_`03o`000?nLQkcoW8Nl00KoW8Nl0ol00004oi^7_@03o`000?nOR;coWhRl00ooWhRl00?o0000
ojB<_?nTS;`04?nTS;`00ol0003oZY>nojZC_P09ojZC_P;o00001OndVkh00ol0003o`:O0ol2W`00@
ol2W`0;o00001?o<[kh00ol0003ofKfnomVm_P09omVm_P03o`000?oR`[Soh/:h00[oh/:h00Co0000
onS6]?oXa[Coj<Jd0_l00004ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000=ooooo`03oiRHV?lb<S;ooooo01kooooo000fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00oooooo0ol00002ooooo`;o00004?nTXM800ol0003o
XYS:oj:HbP0=oj:HbP03o`000?nOT<CoWi3400goWi3400?o0000oij;_onNRkl03_nNRkl00ol0003o
W8Nloib7_003oib7_0?o00002?nKQkd00ol0003oWhRloin8_00>oin8_003o`000?nTS;coY8bl013o
Y8bl00?o0000ojZC__nZTkh02?nZTkh00ol0003o]9^nokBK_P06okBK_P03o`000?o0Yl3o`:O000oo
`:O000?o0000olb___o<[kh00oo<[kh00ol0003ofKfnomVm_P08omVm_P03o`000?oR`[Soh/:h00_o
h/:h00Co0000onS6]?oXa[Coj<Jd0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0oo^k^koA4A4o`00000=ooooo`03omgMgOl0003o^[Zj01kooooo001Hooooo`?o000000Koooooo`00
0?l0003o0000ojN[f_l0000AojBQdP03o`000?nRV<[oXYS:00coXYS:00?o0000oin@a?nOT<@03_nO
T<@00ol0003oWX^ooij;_`0=oij;_`03o`000?nLQkcoW8Nl00?o00002onKQkd00ol0003oWhRloin8
_00>oin8_003o`000?nTS;coY8bl017oY8bl00?o0000ojZC__nZTkh01_nZTkh00ol0003o]9^nokBK
_P07okBK_P03o`000?o0Yl3o`:O000ko`:O00_l00006olb__P03o`000?oI_KkofKfn00OofKfn00?o
0000on;2^?oR`[P02_oR`[P00ol0003oj<JdonS6]003onS6]0;o00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool03?ooool00omEEEGoMgMgodA4A00Nooooo`00EOoo
ool3o`000004ooooool0003o0000o`0000GoYj_J00?o0000ojBQd_nTXM803_nTXM800ol0003oXYS:
oj:HbP0=oj:HbP03o`000?nOT<CoWi3400goWi3400?o0000oij;_onNRkl03?nNRkl4o`0000koVhNm
00?o0000oin8_?nOR;`03onOR;`00ol0003oY8blojB<_00@ojB<_003o`000?nZTkkoZY>n00GoZY>n
00?o0000okBK__ndVkh02OndVkh00ol0003o`:O0ol2W`00=ol2W`0;o00001_o<[kh00ol0003ofKfn
omVm_P06omVm_P03o`000?oR`[Soh/:h00_oh/:h00?o0000onS6]?oXa[@01?oXa[@2o`0002;ooooo
00GogMgMoa0@4?oooooo8B4QomgMg@0Mooooo`00D_ooool3o`0000;ooooo0_l00009ojN[fP03o`00
0?nTXM;oY:7B00koY:7B00?o0000oj:Hb_nRV<X03?nRV<X00ol0003oWi34oin@a00>oin@a003o`00
0?nNRkooWX^o00OoWX^o1?l00002oiR8`@03o`000?nKQkgoVhNm00koVhNm00?o0000oin8_?nOR;`0
3_nOR;`00ol0003oY8blojB<_00@ojB<_003o`000?nZTkkoZY>n00?oZY>n0_l0000<okBK_P03o`00
0?o0Yl3o`:O000co`:O000?o0000olb___l000001oo<[kh00ol0003ofKfnomVm_P04omVm_P03o`00
0?oR`[Soh/:h00_oh/:h00?o0000onS6]?oXa[@01OoXa[@2o`0002;ooooo00GoIVIVohN7Qooooooo
V9RHoeEEE@0Mooooo`00D?ooool2o`0000;ooooo0ol0000;ojN[fP03o`000?nTXM;oY:7B00koY:7B
00?o0000oj:Hb_nRV<X03OnRV<X00ol0003oWi34oin@a00=oin@a003o`000?nNRkooWX^o00CoWX^o
0ol00006oiR8`@03o`000?nKQkgoVhNm00koVhNm00?o0000oin8_?nOR;`03onOR;`00ol0003oY8bl
ojB<_00@ojB<_005o`000?nZTkkoZY>nojZC__l000003ondVkh00ol0003o`:O0ol2W`00:ol2W`004
o`000?o<[kkoc:nno`0000Ooc:nn00?o0000omVm__oI_Kh01?oI_Kh00ol0003oh/:hon;2^00;on;2
^003o`000?oXa[Coj<Jd00Koj<Jd0_l0000Pooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgM
gOooool06oooool004gooooo1?l000000ooooooo0000o`00000?ojN[fP03o`000?nTXM;oY:7B00go
Y:7B00?o0000oj:Hb_nRV<X03OnRV<X00ol0003oWi34oin@a00=oin@a003o`000?nNRkooWX^o00Co
00002_nHR<400ol0003oVhNmoi^7_@0=oi^7_@03o`000?nOR;coWhRl00ooWhRl00?o0000ojB<_?nT
S;`04?nTS;`01?l0003oZY>nojZC__l0000@okBK_P03o`000?o0Yl3o`:O000Wo`:O000Go0000olb_
__o<[kkoc:nno`000007olb__P03o`000?oI_KkofKfn00?ofKfn00?o0000on;2^?oR`[P02ooR`[P0
0ol0003oj<JdonS6]007onS6]003o`000?oooooo000001oooooo00Co410@o`000?l0003ooooo0_l0
00000ol@413oooooooooo`0Jooooo`00Boooool2o`0000;ooooo0ol000000onX]>7o0000ojN[fP0>
ojN[fP03o`000?nTXM;oY:7B00koY:7B00?o0000oj:Hb_nRV<X03?nRV<X00ol0003oWi34oin@a00<
oin@a0Co00003_nHR<400ol0003oVhNmoi^7_@0>oi^7_@03o`000?nOR;coWhRl00koWhRl00?o0000
ojB<_?nTS;`04?nTS;`00ol0003oZY>no`00000AokBK_P03o`000?o0Yl3o`:O000So`:O000?o0000
olb___o<[kh00_o<[kh00ol0003oc:nnolb__P06olb__P03o`000?oI_KkofKfn00;ofKfn00?o0000
on;2^?oR`[P02ooR`[P00ol0003oj<JdonS6]008onS6]0;o0000@_ooool004Sooooo0ol000001?oo
oooo0000o`000?l00005ojRdh@03o`000?nWZm[oYj_J00goYj_J00?o0000ojBQd_nTXM803OnTXM80
0ol0003oXYS:oj:HbP0=oj:HbP03o`000?nOT<CoWi3400OoWi341?l00002oiJ<a`03o`000?nHR<7o
V8S100goV8S100?o0000oi^7_OnKQkd03_nKQkd00ol0003oWhRloin8_00?oin8_003o`000?nTS;co
Y8bl00ooY8bl0_l0000CokBK_P03o`000?o0Yl3o`:O000Ko`:O000?o0000olb___o<[kh00oo<[kh0
0ol0003oc:nnolb__P06olb__P05o`000?oI_KkofKfnomVm__l000003OoR`[P00ol0003oj<JdonS6
]009onS6]0?o0000@Oooool0027ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Pooooo`;o000000Co
ooooo`000?l0003o00002OnX]>400ol0003oYj_JojN[fP0=ojN[fP03o`000?nTXM;oY:7B00goY:7B
00?o0000oj:Hb_nRV<X03?nRV<X00ol0003oWi34oin@a004oin@a0?o00001onFS<L00ol0003oV8S1
oiR8`@0=oiR8`@03o`000?nKQkgoVhNm00goVhNm00?o0000oin8_?nOR;`03onOR;`00ol0003oY8bl
ojB<_00=ojB<_0;o000000?oZi>mo`000?ndVkh04_ndVkh00ol0003o`:O0ol2W`005ol2W`003o`00
0?o<[kkoc:nn00Coc:nn00?o0000olb___o<[kh01oo<[kh00ol0003ofKfno`00000>on;2^003o`00
0?oXa[Coj<Jd00Soj<Jd00Co0000onc:/Ol0003o0000@Oooool0027ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Mooooo`Ko00003?nX]>400ol0003oYj_JojN[fP0=ojN[fP03o`000?nTXM;oY:7B00go
Y:7B00?o0000oj:Hb_nRV<X03?nRV<X00ol0003oWi34oin@a004o`0000[oUXc700?o0000oiR8`OnH
R<403OnHR<400ol0003oVhNmoi^7_@0>oi^7_@03o`000?nOR;coWhRl00koWhRl00?o0000ojB<_?nT
S;`03?nTS;`00ol0003oZi>moj^C_@02oj^C_@03o`000?ndVkko]9^n017o]9^n00?o0000ol2W`?o0
Yl001?o0Yl000ol0003oc:nnolb__P05olb__P03o`000?o<[kkoc:nn00Koc:nn00?o0000omVm__l0
00003OoR`[P00ol0003oj<JdonS6]009onS6]003o`000?o/b[7ok<Za00;o0000@?ooool0027ooooo
00Go410@oooooooooooooooooa0@400Kooooo`;o000000?oooooo`000?l000004?nX]>400ol0003o
Yj_JojN[fP0=ojN[fP03o`000?nTXM;oY:7B00goY:7B00?o0000oj:Hb_nRV<X02_nRV<X4o`0000ko
UXc700?o0000oiR8`OnHR<403OnHR<400ol0003oVhNmoi^7_@0>oi^7_@03o`000?nOR;coWhRl00oo
WhRl00?o0000ojB<_?nTS;`02OnTS;`2o`0000GoZi>m00?o0000okBK__ndVkh04OndVkh00ol0003o
`:O0ol2W`003ol2W`003o`000?o<[kkoc:nn00Koc:nn00?o0000olb___o<[kh01oo<[kh00ol0003o
h/:hon;2^00<on;2^003o`000?oXa[Coj<Jd00Soj<Jd00?o0000onc:/Oo/b[400_o/b[42o`0003oo
oooo000Qooooo`05o`000?ooooooooooooooool000006?ooool3o`000005ooooool0003o0000ojVk
i_l000004OnX]>400ol0003oYj_JojN[fP0<ojN[fP03o`000?nTXM;oY:7B00goY:7B00?o0000oj:H
b_nRV<X01OnRV<X5o`0000;oUI;>00?o0000oiJ<aonFS<L03_nFS<L00ol0003oV8S1oiR8`@0=oiR8
`@03o`000?nKQkgoVhNm00goVhNm00?o0000oin8_?nOR;`03onOR;`00ol0003oY8blojB<_007ojB<
_0;o00001on[Tkd00ol0003o]9^nokBK_P0BokBK_P05o`000?o0Yl3o`:O0ol2W`?l000002Oo<[kh0
0ol0003oc:nnolb__P07olb__P03o`000?oR`[Soh/:h00_oh/:h00?o0000onS6]?oXa[@02OoXa[@0
0ol0003ok<Zaonc:/@03onc:/@03o`000?oooooooooo03gooooo000Qooooo`05o`000?oooooooooo
ooooool000005_ooool2o`0000;ooooo0_l00004ojVkiP03o`000?nX]>7oZ;CQ00ooZ;CQ00?o0000
ojN[f_nWZmX03?nWZmX00ol0003oY:7BojBQdP0<ojBQdP03o`000?nRV<[oXYS:00Go00002?nET/h0
0ol0003oUXc7oiJ<a`0=oiJ<a`03o`000?nHR<7oV8S100goV8S100?o0000oi^7_OnKQkd03OnKQkd0
0ol0003oWhRloin8_00?oin8_003o`000?nTS;coY8bl00GoY8bl0_l0000:oj^C_@03o`000?ndVkko
]9^n017o]9^n00Co0000ol2W`?o0Yl3o00002_o<[kh00ol0003oc:nnolb__P06olb__P03o`000?oF
^;co000000coh/:h00?o0000onS6]?oXa[@02OoXa[@00ol0003ok<Zaonc:/@03onc:/@;o0000?_oo
ool0027ooooo00Go410@oooooooooooooooooa0@400Cooooo`?o000000Coooooo`000?l0003o0000
1onY^nH00ol0003oZ;CQojRdh@0>ojRdh@03o`000?nWZm[oYj_J00goYj_J00?o0000ojBQd_nTXM80
2OnTXM85o`0000goUI;>00?o0000oiJ<aonFS<L03OnFS<L00ol0003oV8S1oiR8`@0=oiR8`@03o`00
0?nKQkgoVhNm00koVhNm00?o0000oin8_?nOR;`03onOR;`00ol0003oY8blojB<_002ojB<_0;o0000
3?n[Tkd00ol0003o]9^nokBK_P0AokBK_P03o`000?o0Yl3o000000_oc:nn00?o0000olb___o<[kh0
1Oo<[kh01Ol0003oe[RlomJh_?oF^;co000000[oh/:h00?o0000onS6]?oXa[@02OoXa[@00ol0003o
k<Zaonc:/@05onc:/@;o0000?Oooool0027ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`?o
00000_ooool2o`0000_oZK_V00?o0000ojRdhOnX]>403_nX]>400ol0003oYj_JojN[fP0<ojN[fP03
o`000?nTXM;oY:7B00;oY:7B1ol00003oiFKe`03o`000?nET/koUI;>00goUI;>00?o0000oiJ<aonF
S<L03OnFS<L00ol0003oV8S1oiR8`@0=oiR8`@03o`000?nKQkgoVhNm00goVhNm00?o0000oin8_?nO
R;`03onOR;`01Ol0003oY8blojB<_?nTS;co000000koZi>m00?o0000okBK__ndVkh04OndVkh2o`00
00coc:nn00?o0000olb___o<[kh01?o<[kh00ol0003oe[RlomJh_002omJh_003o`000?oR`[Soh/:h
00Soh/:h00?o0000onS6]?oXa[@02OoXa[@00ol0003ok<Zaonc:/@06onc:/@03o`000?oooooooooo
03_ooooo000Qooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool2o`0000?ooooo0_l0000=ojVk
iP03o`000?nX]>7oZ;CQ00ooZ;CQ00?o0000ojN[f_nWZmX02_nWZmX6o`0000_oUI_G00?o0000oiFB
c_nET/h03?nET/h00ol0003oUXc7oiJ<a`0=oiJ<a`03o`000?nHR<7oV8S100goV8S100?o0000oi^7
_OnKQkd03OnKQkd00ol0003oWhRloin8_00?oin8_004o`000?nTS;co0000o`00013oZi>m00?o0000
okBK__ndVkh03ondVkh00ol0003o_jBno`00000<olb__P03o`000?o<[kkoc:nn00Coc:nn00?o0000
omJh_?oF^;`00ooF^;`00ol0003oh/:hon;2^006on;2^003o`000?oXa[Coj<Jd00Woj<Jd00?o0000
onc:/Oo/b[402?o/b[400ol0003oooooooooo`0jooooo`00<Oooool5o`000003ooooool0003o0000
013oZK_V00?o0000ojRdhOnX]>403_nX]>400ol0003oYj_JojN[fP05ojN[fPGo00000_nGY^000ol0
003oUI_GoiFKe`0<oiFKe`03o`000?nET/koUI;>00coUI;>00?o0000oiJ<aonFS<L03OnFS<L00ol0
003oV8S1oiR8`@0=oiR8`@03o`000?nKQkgoVhNm00koVhNm00?o0000oin8_?nOR;`03_nOR;`2o`00
01;oZi>m00?o0000okBK__ndVkh03_ndVkh01Ol0003o_jBnoknT__noY;ko000000[oc:nn0_l00005
olb__P03o`000?oF^;coe[Rl00Coe[Rl00?o0000on;2^?oR`[P01_oR`[P00ol0003oj<JdonS6]009
onS6]003o`000?o/b[7ok<Za00Sok<Za0_l0000kooooo`00;oooool2o`0000?ooooo0ol000000onY
_NSo0000ojVkiP0@ojVkiP03o`000?nX]>7oZ;CQ00koZ;CQ00?o0000ojN[f_nWZmX01?l00008oiNV
h003o`000?nEVmOoUI_G00coUI_G00?o0000oiFBc_nET/h03?nET/h00ol0003oUXc7oiJ<a`0=oiJ<
a`03o`000?nHR<7oV8S100goV8S100?o0000oi^7_OnKQkd03OnKQkd00ol0003oWhRloin8_00<oin8
_0;o000000?oXXfno`000?n[Tkd04_n[Tkd00ol0003o]9^nokBK_P0<okBK_P03o`000?noY;ko_jBn
00;o_jBn00?o0000olb___o<[kh01Oo<[kh3o`000003olb___l0003oc:nn00?oc:nn00?o0000omJh
_?oF^;`01_oF^;`00ol0003oh/:hon;2^004on;2^003o`000?oXa[Coj<Jd00Woj<Jd00?o0000onc:
/Oo/b[402?o/b[400ol0003ol<n`o`00000kooooo`00;?ooool3o`0000;ooooo0ol00005ojVmj003
o`000?nY^nKoZK_V00ooZK_V00?o0000ojRdhOnX]>403?nX]>44o`0000goUjKP00?o0000oiFKeonE
VmL02onEVmL00ol0003oUI;>oiFBcP0<oiFBcP03o`000?nFS<OoUXc700goUXc700?o0000oiR8`OnH
R<403OnHR<400ol0003oVhNmoi^7_@0=oi^7_@03o`000?nOR;coWhRl00WoWhRl0ol00004oj:=_P03
o`000?n[TkgoZi>m013oZi>m00?o0000okBK__ndVkh02ondVkh00ol0003o_jBnoknT_P04oknT_P04
o`000?o<[kkoc:nnolb__P?o00001Oo<[kh01Ol0003oc:nnolb___o<[kko000000Woe[Rl00?o0000
on;2^?oR`[P00ooR`[P00ol0003oj<JdonS6]009onS6]003o`000?o/b[7ok<Za00Sok<Za00Co0000
oo3?/?o`ck3o0000>_ooool002_ooooo0_l000001?oooooo0000o`000?l00009ojVmj003o`000?nY
^nKoZK_V00koZK_V00?o0000ojRdhOnX]>402OnX]>43o`0000;oVk3V00?o0000oiNVh?nGY^003?nG
Y^000ol0003oUI_GoiFKe`0<oiFKe`03o`000?nET/koUI;>00coUI;>00?o0000oiJ<aonFS<L03?nF
S<L00ol0003oV8S1oiR8`@0=oiR8`@03o`000?nKQkgoVhNm00koVhNm00?o0000oin8_?nOR;`01_nO
R;`2o`0000OoXXfn00?o0000oj^C_On[Tkd04?n[Tkd00ol0003o]9^nokBK_P0:okBK_P03o`000?no
Y;ko_jBn00Go_jBn1?l00009olb__P03o`000?o<[kko000000[oe[Rl00?o0000on;2^?oR`[P00_oR
`[P00ol0003oj<JdonS6]009onS6]003o`000?o/b[7ok<Za00Sok<Za00Co0000oo3?/?o`ck3ol<n`
0_l0000iooooo`00:oooool3o`0000goZKgX00?o0000ojVki_nY^nH03_nY^nH00ol0003oZ;CQojRd
h@04ojRdh@Co00001_nK/>H00ol0003oUjKPoiNVh00<oiNVh003o`000?nEVmOoUI_G00_oUI_G00?o
0000oiFBc_nET/h03?nET/h00ol0003oUXc7oiJ<a`0=oiJ<a`03o`000?nHR<7oV8S100goV8S100?o
0000oi^7_OnKQkd03OnKQkd00ol0003oWhRloin8_004oin8_0;o00002OnRSKh00ol0003oZi>moj^C
_@0Aoj^C_@03o`000?ndVkko]9^n00So]9^n00?o0000oknT__noY;h01?noY;h4o`0000coc:nn00?o
0000omJh_?oF^;`02_oF^;`01Ol0003oh/:hon;2^?oR`[So000000_oj<Jd00?o0000onc:/Oo/b[40
2?o/b[400ol0003ol<n`oo3?/002oo3?/0;o0000>?ooool002[ooooo0ol0000?ojVmj003o`000?nY
^nKoZK_V00koZK_V00?o0000ojRdhOnX]>400ol0000;oi^`iP03o`000?nGY^3oUjKP00_oUjKP00?o
0000oiFKeonEVmL03?nEVmL00ol0003oUI;>oiFBcP0<oiFBcP03o`000?nFS<OoUXc700coUXc700?o
0000oiR8`OnHR<403OnHR<400ol0003oVhNmoi^7_@0=oi^7_@04o`000?nOR;coWhRloin8_0?o0000
3?nRSKh00ol0003oZi>moj^C_@0@oj^C_@03o`000?ndVkko]9^n00Oo]9^n00?o0000oknT__noY;h0
0_noY;h3o`0000?o_jBn00?o0000olb___o<[kh02Oo<[kh2o`0000coe[Rl00Co0000on;2^?oR`[So
00002ooXa[@00ol0003ok<Zaonc:/@09onc:/@03o`000?o`ck3ol<n`00;ol<n`0_l00008ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c00K
ooooo`00:oooool2o`00013oZKgX00?o0000ojVki_nY^nH03?nY^nH4o`0000koVk3V00?o0000oiNV
h?nGY^003?nGY^000ol0003oUI_GoiFKe`0<oiFKe`03o`000?nET/koUI;>00_oUI;>00?o0000oiJ<
aonFS<L03?nFS<L00ol0003oV8S1oiR8`@0=oiR8`@03o`000?nKQkgoVhNm00koVhNm0ol0000?oj:=
_P03o`000?n[TkgoZi>m017oZi>m00?o0000okBK__ndVkh01OndVkh00ol0003o_jBnoknT_P03o`00
00Oo_jBn00?o0000olb___o<[kh02?o<[kh00ol0003oe[Rlo`00000<omJh_003o`000?oR`[So0000
00_oj<Jd00?o0000onc:/Oo/b[402?o/b[400ol0003ol<n`oo3?/004oo3?/0;o00001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B406ooo
ool000oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00Co
0000oooooooooooo00004?nY_NP00ol0003oZK_VojVkiP08ojVkiP?o00000onP^>X00ol0003oVk3V
oi^`iP0=oi^`iP03o`000?nGY^3oUjKP00coUjKP00?o0000oiFKeonEVmL02onEVmL00ol0003oUI;>
oiFBcP0<oiFBcP03o`000?nFS<OoUXc700coUXc700?o0000oiR8`OnHR<403OnHR<400ol0003oVhNm
oi^7_@0;oi^7_@?o00004OnRSKh00ol0003oZi>moj^C_@0Aoj^C_@03o`000?ndVkko]9^n00Co]9^n
00Co0000oknT__l0003o00002_noY;h00ol0003oc:nnolb__P07olb__P05o`000?oF^;coe[RlomJh
_?l000003?oF^;`00ol0003oj<JdonS6]00:onS6]003o`000?o/b[7ok<Za00Sok<Za00?o0000oo3?
/?o`ck001Oo`ck000ol0003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol0003ooooooooooooooooo000001_ooooo000?ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`05o`000?ooooooooooooooool0
00004?nY_NP00ol0003oZK_VojVkiP04ojVkiP?o00001onP^>X00ol0003oVk3Voi^`iP0=oi^`iP03
o`000?nGY^3oUjKP00_oUjKP00?o0000oiFKeonEVmL03?nEVmL00ol0003oUI;>oiFBcP0;oiFBcP03
o`000?nFS<OoUXc700coUXc700?o0000oiR8`OnHR<403OnHR<400ol0003oVhNmoi^7_@07oi^7_@Co
00000_nIRL400ol0003oXXfnoj:=_P0@oj:=_P03o`000?n[TkgoZi>m013oZi>m00?o0000okBK__nd
Vkh00ondVkh3o`0000co_jBn00?o0000olb___o<[kh01_o<[kh00ol0003oe[RlomJh_002omJh_003
o`000?oF^;coe[Rl00[oe[Rl00?o0000onS6]?oXa[@02OoXa[@00ol0003ok<Zaonc:/@08onc:/@03
o`000?o`ck3ol<n`00Kol<n`0_l00006ooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003oV9RHoooooonHV9So8B4Q01_ooooo0007ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`02ooooo`03o`000?nY_NSo
ZKgX00koZKgX00?o0000ojVki_nY^nH00ol0000;oj2hjP03o`000?nK/>KoVk3V00goVk3V00?o0000
oiNVh?nGY^002onGY^000ol0003oUI_GoiFKe`0;oiFKe`03o`000?nET/koUI;>00coUI;>00?o0000
oiJ<aonFS<L02onFS<L00ol0003oV8S1oiR8`@0=oiR8`@03o`000?nKQkgoVhNm00CoVhNm0ol00007
oiV9`@03o`000?nRSKkoXXfn00ooXXfn00?o0000oj^C_On[Tkd04On[Tkd00ol0003o]9^no`000002
o`00013o_jBn00?o0000olb___o<[kh01Oo<[kh00ol0003oe[RlomJh_003omJh_003o`000?oF^;co
e[Rl00Soe[Rl00?o0000omk0^_l000002_oXa[@00ol0003ok<Zaonc:/@08onc:/@03o`000?o`ck3o
l<n`00Ool<n`0_l00005ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`00
0?l@413oc<c<01_ooooo000?ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP06ooooo`;o00001?ooool00ol0003oZKgXojVmj00<ojVmj0Co00003onP^>X00ol0003oVk3V
oi^`iP0<oi^`iP03o`000?nGY^3oUjKP00_oUjKP00?o0000oiFKeonEVmL03?nEVmL00ol0003oUI;>
oiFBcP0;oiFBcP03o`000?nFS<OoUXc700coUXc700?o0000oiR8`OnHR<403OnHR<400ol0003oVhNm
o`000003o`0000[oVHW100?o0000oj:=__nRSKh03onRSKh00ol0003oZi>moj^C_@0@oj^C_@?o0000
00?o]9^no`000?noY;h04?noY;h00ol0003oc:nnolb__P04olb__P03o`000?oF^;coe[Rl00Goe[Rl
00?o0000omJh_?oF^;`01_oF^;`01?l0003og/2jomk0^_l00009onS6]003o`000?o/b[7ok<Za00So
k<Za00?o0000oo3?/?o`ck002?o`ck02o`0000Gooooo00Go410@oooooooooooooooooa0@400;oooo
o`03oeEEEOn7QhOooooo01gooooo000?ooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOoIVIVooooo`04ooooo`;o00001_ooool00ol0003oZKgXojVmj008ojVmj0?o00001?nV_>T00ol0
003oX;SZoj2hjP0=oj2hjP03o`000?nK/>KoVk3V00coVk3V00?o0000oiNVh?nGY^002onGY^000ol0
003oUI_GoiFKe`0;oiFKe`03o`000?nET/koUI;>00_oUI;>00?o0000oiJ<aonFS<L03?nFS<L00ol0
003oV8S1oiR8`@09oiR8`@Ko00003_nIRL400ol0003oXXfnoj:=_P0@oj:=_P03o`000?n[TkgoZi>m
00coZi>m0ol000001?n[Tkgo0000okBK__l0000CoknT_P03o`000?o<[kkoc:nn00;oc:nn00?o0000
omJh_?oF^;`01ooF^;`00ol0003oe[RlomJh_005omJh_005o`000?oN`;[og/2jomk0^_l000002?oX
a[@00ol0003ok<Zaonc:/@08onc:/@03o`000?o`ck3ol<n`00Ool<n`00Co0000oo;C/Ol0003o0000
1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P07Oooool000oooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oZKgXojVmj004ojVmj0?o00002?nV_>T00ol0003oX;SZoj2hjP0=oj2hjP03
o`000?nK/>KoVk3V00coVk3V00?o0000oiNVh?nGY^002onGY^000ol0003oUI_GoiFKe`0;oiFKe`03
o`000?nET/koUI;>00_oUI;>00?o0000oiJ<aonFS<L02onFS<L00ol0003oV8S1oiR8`@02oiR8`@Oo
00001?nBR<H00ol0003oVHW1oiV9`@0>oiV9`@03o`000?nRSKkoXXfn00ooXXfn00?o0000oj^C_On[
Tkd02On[Tkd3o`0000CoZi>m0_l0000DoknT_P05o`000?o<[kkoc:nnolb___l000002_oF^;`00ol0
003oe[RlomJh_004omJh_003o`000?oN`;[og/2j00?og/2j00?o0000onS6]?oXa[@01?oXa[@00ol0
003ok<Zaonc:/@09onc:/@03o`000?o`ck3ol<n`00Ool<n`00?o0000oo;C/Oobdk400_l00003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410Kooooo`003oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ojVmj?nY_NP00ol0000<ojJlj@03o`000?nP^>[oX;SZ00goX;SZ
00?o0000oi^`i_nK/>H02onK/>H00ol0003oUjKPoiNVh00;oiNVh003o`000?nEVmOoUI_G00_oUI_G
00?o0000oiFBc_nET/h02onET/h00ol0003oUXc7oiJ<a`05oiJ<a`_o00003?nBR<H00ol0003oVHW1
oiV9`@0=oiV9`@03o`000?nRSKkoXXfn00ooXXfn00?o0000oj^C_On[Tkd01_n[Tkd3o`0000KoZi>m
00?o0000ok:K`?l000005OnoY;h01?l0003oc:nnolb___l0000;omJh_003o`000?oF^;coe[Rl00;o
e[Rl00?o0000omk0^_oN`;X01?oN`;X00ol0003oj<JdonS6]004onS6]003o`000?o/b[7ok<Za00So
k<Za00?o0000oo3?/?o`ck001oo`ck001?l0003ol]>aoo;C/Oobdk42o`0003?ooooo000?ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000
ooooooooool02?ooool2o`00013oY[cY00?o0000oj2hj_nP^>X03OnP^>X00ol0003oVk3Voi^`iP0;
oi^`iP03o`000?nGY^3oUjKP00GoUjKP:Ol00007oh^9c003o`000?nBR<KoTXS600goTXS600?o0000
oiV9`OnIRL403_nIRL400ol0003oXXfnoj:=_P0?oj:=_P03o`000?n[TkgoZi>m00?oZi>m0_l00007
oj^C_@;o00000onbVl000ol0003o_jBnoknT_P0BoknT_P03o`000?o<[kko000000goe[Rl00Go0000
omJh_?oF^;coe[Rlo`000007omk0^P03o`000?oXa[Coj<Jd00;oj<Jd00?o0000onc:/Oo/b[402Oo/
b[400ol0003ol<n`oo3?/007oo3?/003o`000?obdk7ol]>a00;ol]>a0_l0000booooo`00:Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?nV_>WoY[cY00koY[cY00?o0000oj2hj_nP^>X03OnP^>X0
0ol0003oVk3Voi^`iP05oi^`iPgo00001_n3WnD00ol0003oPYCLoh:Dg00;oh:Dg003o`000?n5SMCo
QHgD00_oQHgD00?o0000oh^9c?n;RL`03?n;RL`00ol0003oTXS6oi:8aP0<oi:8aP03o`000?nIRL7o
VHW100koVHW100?o0000oj:=__nRSKh03onRSKh00ol0003oZi>moj^C_@03o`0000SoZi>m00?o0000
ok:K`?nbVl000onbVl000ol0003o_jBnoknT_P0CoknT_P03o`000?oF^;coe[Rl00coe[Rl00Co0000
omJh_?oF^;co00002?oN`;X00ol0003oj<JdonS6]002onS6]003o`000?o/b[7ok<Za00Sok<Za00?o
0000oo3?/?o`ck001oo`ck000ol0003ol]>aoo;C/@04oo;C/@;o0000<Oooool002Wooooo0_l0000<
ooooo`03o`000?nV_>WoY[cY00koY[cY00?o0000oj2hj_nP^>X02onP^>X9o`0000KoRZ_[00?o0000
oh>OiOn3WnD02on3WnD00ol0003oPYCLoh:Dg00;oh:Dg003o`000?n5SMCoQHgD00_oQHgD00?o0000
oh^9c?n;RL`02on;RL`00ol0003oTXS6oi:8aP0=oi:8aP03o`000?nIRL7oVHW100goVHW100?o0000
oj:=__nRSKh03onRSKh3o`0000WoZi>m0_l00006ok:K`003o`000?noY;ko_jBn01?o_jBn00?o0000
omJh_?oF^;`03OoF^;`2o`0000[og/2j00Go0000onS6]?oXa[Coj<Jdo`00000:onc:/@03o`000?o`
ck3ol<n`00Ool<n`00?o0000oo;C/Oobdk401?obdk42o`00037ooooo000Xooooo`;o00003_ooool0
0ol0003oY[cYojJlj@0>ojJlj@03o`000?nP^>[oX;SZ00GoX;SZ1Ol00002oiJek@03o`000?n:Zn_o
RZ_[00_oRZ_[00?o0000oh>OiOn3WnD02on3WnD00ol0003oPYCLoh:Dg00:oh:Dg003o`000?n5SMCo
QHgD00_oQHgD00?o0000oh^9c?n;RL`03?n;RL`00ol0003oTXS6oi:8aP0<oi:8aP03o`000?nIRL7o
VHW100koVHW100?o0000oj:=__nRSKh02onRSKh3o`000003oj:=__l0003oZi>m00SoZi>m00?o0000
ok:K`?nbVl001onbVl000ol0003o_jBnoknT_P0AoknT_P03o`000?o9[l3o000000ooe[Rl00?o0000
omk0^_oN`;X02OoN`;X00ol0003oj<Jdo`00000:onc:/@03o`000?o`ck3ol<n`00Sol<n`00?o0000
oo;C/Oobdk401Oobdk42o`00033ooooo000Yooooo`03o`000?oooooooooo00gooooo00?o0000ojJl
jOnV_>T03_nV_>T00ol0003oX;SZoj2hjP04o`0000SoU[G]00?o0000ohZ[jon:Zn/02on:Zn/00ol0
003oPioUoh>Oi@0:oh>Oi@03o`000?n2U=coPYCL00_oPYCL00?o0000ohF=e?n5SM@02_n5SM@00ol0
003oRhW<oh^9c00<oh^9c003o`000?nBR<KoTXS600coTXS600?o0000oiV9`OnIRL403_nIRL400ol0
003oXXfnoj:=_P08oj:=_P?o00001?nRSKh00ol0003oZi>moj^C_@06oj^C_@03o`000?nbVl3o/Y_0
00So/Y_000?o0000oknT__noY;h04?noY;h01?l0003obJo0olV_`?l0000>omJh_003o`000?oN`;[o
000000[og/2j00?o0000onS6]?l000002_o/b[400ol0003ol<n`oo3?/007oo3?/003o`000?obdk7o
l]>a00Ool]>a00?o0000ooooooooool0;_ooool002Wooooo00?o0000ooooooooool03_ooool00ol0
003oY[cYojJlj@0<ojJlj@Co00003OnF]Nd00ol0003oRZ_[ohZ[j`0;ohZ[j`03o`000?n3WnGoPioU
00[oPioU00?o0000oh:Dg?n2U=`02_n2U=`00ol0003oQHgDohF=e00;ohF=e003o`000?n;RLcoRhW<
00_oRhW<00?o0000oi:8a_nBR<H03OnBR<H00ol0003oVHW1oiV9`@0>oiV9`@03o`000?nRSKkoXXfn
00CoXXfn0ol00007oj:=_P03o`000?n[TkgoZi>m00CoZi>m0_l0000<ok:K`003o`000?noY;ko_jBn
00ko_jBn00?o0000olV_`?o9[l000_o9[l000ol0003oe[RlomJh_00:omJh_004o`000?oN`;[og/2j
o`0000_og/2j00?o0000onc:/Oo/b[402Oo/b[400ol0003ol<n`oo3?/007oo3?/003o`000?obdk7o
l]>a00Ool]>a0_l0000_ooooo`00:?ooool00ol0003oooooooooo`0@ooooo`03o`000?nV_>WoY[cY
00SoY[cY0ol00003oj>lj`03o`000?nF]NgoU[G]00coU[G]00?o0000ohZ[jon:Zn/02_n:Zn/00ol0
003oPioUoh>Oi@0:oh>Oi@03o`000?n2U=coPYCL00_oPYCL00?o0000ohF=e?n5SM@02_n5SM@00ol0
003oRhW<oh^9c00<oh^9c003o`000?nBR<KoTXS600coTXS600?o0000oiV9`OnIRL403_nIRL401?l0
003oXXfnoj:=__nRSKh3o`0000_oXXfn00?o0000oj^C_On[Tkd00_n[Tkd00ol0003o/Y_0ok:K`00<
ok:K`003o`000?noY;ko_jBn00go_jBn00?o0000olV_`?o9[l000oo9[l000ol0003oe[RlomJh_00:
omJh_005o`000?oN`;[og/2jomk0^_l000002_oN`;X00ol0003ok<Zaonc:/@08onc:/@03o`000?o`
ck3ol<n`00Ool<n`00?o0000oo;C/Oobdk401oobdk401?l0003olmVeo`000?l0000^ooooo`00:?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?nV_>WoY[cY00CoY[cY0ol00007oj>lj`03o`000?nF
]NgoU[G]00coU[G]00?o0000ohZ[jon:Zn/02_n:Zn/00ol0003oPioUoh>Oi@0:oh>Oi@03o`000?n2
U=coPYCL00[oPYCL00?o0000ohF=e?n5SM@02on5SM@00ol0003oRhW<oh^9c00;oh^9c003o`000?nB
R<KoTXS600coTXS600?o0000oiV9`OnIRL403_nIRL401?l0003oXXfno`000?l0000>oj:=_P03o`00
0?n[TkgoZi>m00;o00003onbVl000ol0003o_jBnoknT_P0<oknT_P03o`000?o9[l3obJo000GobJo0
00?o0000omJh_?oF^;`02?oF^;`00ol0003og/2jomk0^P03omk0^P03o`000?oN`;[og/2j00Kog/2j
00?o0000onK9^_l000002Oo/b[400ol0003ol<n`oo3?/007oo3?/003o`000?obdk7ol]>a00Ool]>a
00Co0000oo?I]OocfKGo0000;_ooool002Sooooo0_l0000Cooooo`03o`000?nV_>WoY[cY00?o0000
2onS_>/00ol0003oU[G]oiJek@0<oiJek@03o`000?n:Zn_oRZ_[00[oRZ_[00?o0000oh>OiOn3WnD0
2_n3WnD00ol0003oPYCLoh:Dg00:oh:Dg003o`000?n5SMCoQHgD00[oQHgD00?o0000oh^9c?n;RL`0
3?n;RL`00ol0003oTXS6oi:8aP0<oi:8aP03o`000?nIRL7oVHW100coVHW10ol0000@oj:=_P03o`00
0?n[Tkgo000001;o/Y_000?o0000oknT__noY;h02_noY;h00ol0003obJo0olV_`006olV_`003o`00
0?oF^;coe[Rl00Soe[Rl00?o0000omk0^_oN`;X01?oN`;X00ol0003og/2jomk0^P05omk0^P04o`00
0?oVbK[oi/Vjo`0000Ook<Za00?o0000oo3?/?o`ck001oo`ck000ol0003ol]>aoo;C/@07oo;C/@04
o`000?ocfKGolmVeoo?I]@;o0000;Oooool002Sooooo00?o0000ooooooooool04oooool2o`0000oo
Xkc[00?o0000oiJekOnF]Nd02onF]Nd00ol0003oRZ_[ohZ[j`0;ohZ[j`03o`000?n3WnGoPioU00Wo
PioU00?o0000oh:Dg?n2U=`02_n2U=`00ol0003oQHgDohF=e00;ohF=e003o`000?n;RLcoRhW<00_o
RhW<00?o0000oi:8a_nBR<H03?nBR<H00ol0003oVHW1oiV9`@09oiV9`@?o00000_nIRL400ol0003o
XXfnoj:=_P0>oj:=_P;o00004onbVl000ol0003o_jBnoknT_P09oknT_P03o`000?o9[l3obJo000So
bJo000?o0000omJh_?oF^;`01_oF^;`00ol0003og/2jomk0^P05omk0^P03o`000?oN`;[og/2j00Co
g/2j00Go0000onK9^_oVbK[oi/Vjo`000007onc:/@03o`000?o`ck3ol<n`00Ool<n`00?o0000oo;C
/Oobdk401oobdk400ol0003olmVeoo?I]@02oo?I]@;o0000;?ooool002Sooooo00?o0000oooooooo
ool05?ooool00ol0003oXkc[oj>lj`0>oj>lj`03o`000?nF]NgoU[G]00_oU[G]00?o0000ohZ[jon:
Zn/02_n:Zn/00ol0003oPioUoh>Oi@0:oh>Oi@03o`000?n2U=coPYCL00WoPYCL00?o0000ohF=e?n5
SM@02on5SM@00ol0003oRhW<oh^9c00<oh^9c003o`000?nBR<KoTXS600_oTXS600?o0000oiV9`OnI
RL401_nIRL43o`0000GoVHW100?o0000oj:=__nRSKh03?nRSKh2o`000003ojJD`ol0003o/Y_001?o
/Y_000?o0000oknT__noY;h01onoY;h00ol0003obJo0olV_`00:olV_`003o`000?oF^;coe[Rl00Co
e[Rl00?o0000omk0^_oN`;X01ooN`;X00ol0003og/2jomk0^P02omk0^P03o`000?oVbK[oi/Vj00?o
i/Vj00?o0000onc:/Oo/b[400oo/b[400ol0003ol<n`oo3?/007oo3?/003o`000?obdk7ol]>a00Oo
l]>a00?o0000oo?I]OocfKD01?ocfKD00ol0003oooooooooo`0Zooooo`00:?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?nS_>_oXkc[00koXkc[00?o0000oiJekOnF]Nd02onF]Nd00ol0003oRZ_[
ohZ[j`0:ohZ[j`03o`000?n3WnGoPioU00WoPioU00?o0000oh:Dg?n2U=`02_n2U=`00ol0003oQHgD
ohF=e00:ohF=e003o`000?n;RLcoRhW<00coRhW<00?o0000oi:8a_nBR<H03?nBR<H00ol0003oVHW1
oiV9`@02oiV9`@?o00002OnIRL400ol0003oXXfnoj:=_P09oj:=_P;o00001?nVU<<00ol0003o/Y_0
ok:K`00Aok:K`003o`000?noY;ko_jBn00Oo_jBn00?o0000olV_`?o9[l002_o9[l000ol0003oe[Rl
omJh_004omJh_003o`000?oN`;[og/2j00Sog/2j00Go0000omk0^_oN`;[og/2jo`000006onK9^P03
o`000?o/b[7ok<Za00;ok<Za00?o0000oo3?/?o`ck001oo`ck000ol0003ol]>aoo;C/@07oo;C/@03
o`000?ocfKGolmVe00ColmVe0_l0000[ooooo`009oooool00ol0003oooooooooo`0Gooooo`03o`00
0?nS_>_oXkc[00koXkc[00?o0000oiJekOnF]Nd02onF]Nd00ol0003oRZ_[ohZ[j`0:ohZ[j`03o`00
0?n3WnGoPioU00WoPioU00?o0000oh:Dg?n2U=`02On2U=`00ol0003oQHgDohF=e00;ohF=e003o`00
0?n;RLcoRhW<00_oRhW<00?o0000oi:8a_nBR<H03?nBR<H00ol0003oVHW1o`000002o`0000coVHW1
00?o0000oj:=__nRSKh01_nRSKh3o`0000KoYYC300?o0000ok:K`?nbVl004OnbVl000ol0003o_jBn
oknT_P06oknT_P03o`000?o9[l3obJo000cobJo000?o0000omJh_?oF^;`00_oF^;`00ol0003og/2j
omk0^P09omk0^P04o`000?oN`;[og/2jo`0000Soi/Vj00Go0000onc:/Oo/b[7ok<Zao`000008oo3?
/003o`000?obdk7ol]>a00Ool]>a00?o0000oo?I]OocfKD01_ocfKD2o`0002[ooooo000Wooooo`03
o`000?oooooooooo01Sooooo00?o0000oj>ljonS_>/03_nS_>/00ol0003oU[G]oiJek@05oiJekAOo
00002?n3WnD00ol0003oPYCLoh:Dg009oh:Dg003o`000?n5SMCoQHgD00[oQHgD00?o0000oh^9c?n;
RL`03?n;RL`00ol0003oTXS6oi:8aP0:oi:8aP?o00004?nIRL400ol0003oXXfnoj:=_P03oj:=_P;o
00002_nVU<<00ol0003o/Y_0ok:K`00Aok:K`003o`000?noY;ko_jBn00Co_jBn00?o0000olV_`?o9
[l003Oo9[l001Ol0003oe[RlomJh_?oF^;co000000gog/2j00?o0000omk0^_l000002?oVbKX01?l0
003ok<Zaonc:/Ol00009oo3?/003o`000?obdk7ol]>a00Ool]>a00?o0000oo?I]OocfKD01oocfKD0
0ol0003oooooooooo`0Xooooo`009oooool3o`0001Wooooo00?o0000oj>ljonS_>/03?nS_>/9o`00
00KoRk;`00?o0000ogNTk_mgY>h02_mgY>h01?l0003oJiKYof^FjOm[U^T7o`000003oh>OiOl0003o
PYCL00[oPYCL00?o0000ohF=e?n5SM@02on5SM@00ol0003oRhW<oh^9c00;oh^9c003o`000?nBR<Ko
TXS600SoTXS60_l00002oi:8aP03o`000?nIRL7oVHW100koVHW100Co0000oj:=__nRSKkoXXfn0_l0
000<ojJD``03o`000?nbVl3o/Y_0017o/Y_000?o0000oknT__noY;h00onoY;h00ol0003obJo0olV_
`00?olV_`004o`000?oF^;coe[Rlo`0000kog/2j00?o0000onK9^_oVbKX02?oVbKX00ol0003ok<Za
o`000008oo3?/003o`000?obdk7ol]>a00Ool]>a00?o0000oo?I]OocfKD02?ocfKD2o`0002Wooooo
000Wooooo`03o`000?oooooooooo01[ooooo00?o0000oj>ljonS_>/02?nS_>/3o`0000?oX;_/00?o
0000oh^bl?n;/_002_n;/_000ol0003oMjC^ogNTkP0:ogNTkP03o`000?m[U^WoJiKY00OoJiKY1_l0
0008oh:Dg003o`000?n5SMCoQHgD00[oQHgD00?o0000oh^9c?n;RL`03?n;RL`00ol0003oTXS6oi:8
aP04oi:8aP?o00001?nBR<H00ol0003oVHW1oiV9`@0>oiV9`@04o`000?nRSKko0000o`0000koYYC3
00?o0000ok:K`?nbVl004_nbVl001Ol0003o_jBnoknT__noY;ko000001;obJo000?o0000omJh_?l0
00003_oN`;X00ol0003oi/Vjo`00000:onK9^P03o`000?o`ck3ol<n`00Ool<n`00?o0000oo;C/Oob
dk401oobdk400ol0003olmVeoo?I]@07oo?I]@04o`000?obh;_o0000o`0002Sooooo000Looooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Kooooo`03o`000?nS_>_oXkc[
00CoXkc[0ol00007oj2kk003o`000?n;/_3oRk;`00[oRk;`00?o0000ogNTk_mgY>h02_mgY>h00ol0
003oJiKYof^Fj@08of^Fj@04o`000?mYS>7oJHcQofV<h@Oo000000?oPYCLo`000?n5SM@03?n5SM@0
0ol0003oRhW<oh^9c00;oh^9c004o`000?nBR<KoTXS6oi:8aP?o00001onBR<H00ol0003oVHW1oiV9
`@0=oiV9`@?o00004OnVU<<00ol0003o/Y_0ok:K`00Aok:K`004o`000?noY;ko_jBno`0001CobJo0
00?o0000omk0^_oN`;X03OoN`;X00ol0003oi/Vjo`00000:onK9^P03o`000?o`ck3ol<n`00Kol<n`
00?o0000oo;C/Oobdk401oobdk400ol0003olmVeoo?I]@08oo?I]@04o`000?obh;_ol^2ko`0000So
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00_ooooo000Looooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0L
ooooo`03o`000?nS_>_oXkc[00?o00002onP^n`00ol0003oRk;`oh^bl00:oh^bl003o`000?mgY>ko
MjC^00[oMjC^00?o0000of^FjOm[U^T02?m[U^T00ol0003oJHcQofV<h@07ofV<h@Oo00002?n5SM@0
0ol0003oRhW<oh^9c00<oh^9c0?o00002onBR<H00ol0003oVHW1oiV9`@08oiV9`@Co00000_nHS/L0
0ol0003oYYC3ojJD``0?ojJD``03o`000?nbVl3o/Y_0017o/Y_000?o0000oknT__l000005Oo9[l00
0ol0003og/2jomk0^P0<omk0^P05o`000?oVbK[oi/VjonK9^_l000002?oVbKX00ol0003ok=:jo`00
0007oo3?/003o`000?obdk7ol]>a00Ool]>a00?o0000oo?I]OocfKD01oocfKD01?l0003ol^2koo;P
^oobh;/2o`0000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7o
V9RHoooooonHV9So8B4Q00_ooooo000Looooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0
003oooooooooo`0Nooooo`;o00003onP^n`00ol0003oRk;`oh^bl00:oh^bl003o`000?mgY>koMjC^
00WoMjC^00?o0000of^FjOm[U^T02Om[U^T00ol0003oJHcQofV<h@08ofV<h@03o`000?maQmWoLHOI
00;oLHOI1ol000000on5SMCo0000oh^9c00:oh^9c0Co00003OnBR<H00ol0003oVHW1oiV9`@04oiV9
`@Co00001onHS/L00ol0003oYYC3ojJD``0?ojJD``03o`000?nbVl3o/Y_0013o/Y_00_l0000EolV_
`003o`000?oB^/;o000000gog/2j00?o0000onK9^_oVbKX00_oVbKX00ol0003oi/VjonK9^P05onK9
^P04o`000?o/d[[ok=:jo`0000Kol<n`00?o0000oo;C/Oobdk401_obdk400ol0003olmVeoo?I]@07
oo?I]@03o`000?obh;_ol^2k00?ol^2k0_l00006ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol0003ooooooooooooooooo000000_ooooo000Looooo`05o`000?ooooooooooooooool00000
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?nP^ncoX;_/00goX;_/00?o0000oh^bl?n;/_00
2_n;/_000ol0003oMjC^ogNTkP09ogNTkP03o`000?m[U^WoJiKY00SoJiKY00?o0000ofV<hOmYS>40
2OmYS>400ol0003oLHOIog67f@08og67f@go00000on;RL`00ol0003oTXS6oi:8aP0;oi:8aP03o`00
0?nIRL7oVHW100Co00002onHS/L00ol0003oYYC3ojJD``0?ojJD``03o`000?nbVl3o/Y_000oo/Y_0
00?o0000okZVa?l000005?o9[l001Ol0003od[[2om:j`_oB^/;o000000_og/2j00?o0000onK9^_oV
bKX01?oVbKX00ol0003oi/VjonK9^P03onK9^P03o`000?o/d[[ok=:j00;ok=:j00?o0000oo3?/?o`
ck000_o`ck000ol0003ol]>aoo;C/@07oo;C/@03o`000?ocfKGolmVe00OolmVe00?o0000oo;P^oob
h;/00oobh;/2o`0000Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9Sooooo
oiRHV?lb<S802oooool001cooooo00Go0000ooooooooooooooooo`000005ooooo`;o00008_ooool0
0ol0003oX;_/oj2kk00=oj2kk003o`000?n;/_3oRk;`00[oRk;`00?o0000ogNTk_mgY>h02OmgY>h0
0ol0003oJiKYof^Fj@08of^Fj@03o`000?mYS>7oJHcQ00WoJHcQ00?o0000og67fOmaQmT02OmaQmT0
0ol0003oOHOBogf7dP02ogf7dP?o000000?oOHOBo`000?l000005?l0000?oiR>a`03o`000?nVU<?o
YYC3013oYYC300?o0000ok:K`?nbVl003OnbVl001Ol0003o^ZK4okZVa?njY/Co000001;obJo000?o
0000om:j`_oB^/800_oB^/800ol0003og/2jomk0^P09omk0^P03o`000?oVbK[oi/Vj00Coi/Vj00?o
0000onK9^_oVbKX00_oVbKX00ol0003ok=:joncB^P03oncB^P03o`000?o`ck3ol<n`00;ol<n`00?o
0000oo;C/Oobdk401_obdk400ol0003olmVeoo?I]@07oo?I]@03o`000?obh;_ol^2k00Gol^2k0_l0
0005ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00_o
oooo000Looooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`0Rooooo`03
o`000?nP^ncoX;_/00goX;_/00?o0000oh^bl?n;/_002_n;/_000ol0003oMjC^ogNTkP08ogNTkP03
o`000?m[U^WoJiKY00SoJiKY00?o0000ofV<hOmYS>402OmYS>400ol0003oLHOIog67f@0:og67f@04
o`000?mmQm;o0000o`0000[oOHOB00?o0000oh^9c?n;RL`02on;RL`00ol0003oV8k7oiR>a`0?oiR>
a`03o`000?nVU<?oYYC300ooYYC300?o0000ok:K`?nbVl003?nbVl000ol0003o^ZK4okZVa002okZV
a003o`000?o9[l3obJo000oobJo000?o0000om:j`_oB^/801?oB^/800ol0003og/2jomk0^P07omk0
^P03o`000?oVbK[oi/Vj00Koi/Vj00Go0000onK9^_oVbK[oi/Vjo`000006oncB^P04o`000?o`ck3o
l<n`o`0000Wol]>a00?o0000oo?I]OocfKD01oocfKD00ol0003ol^2koo;P^`06oo;P^`;o00001?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400;ooooo`00
7?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool08oooool2o`0000ko
X;_/00?o0000oh^bl?n;/_002_n;/_000ol0003oMjC^ogNTkP08ogNTkP03o`000?m[U^WoJiKY00So
JiKY00?o0000ofV<hOmYS>402OmYS>400ol0003oLHOIog67f@08og67f@?o00003OmmQm800ol0003o
RhW<oh^9c00;oh^9c003o`000?nHS/OoV8k700koV8k700?o0000ojJD`onVU<<03onVU<<00ol0003o
/Y_0ok:K`00:ok:K`0;o00001_njY/@00ol0003obJo0olV_`00>olV_`003o`000?oB^/;od[[200Co
d[[200?o0000omk0^_oN`;X01_oN`;X00ol0003oi/VjonK9^P08onK9^P03o`000?oVbK[o000000So
k=:j00?o0000oo3?/?l000002?obdk400ol0003olmVeoo?I]@07oo?I]@03o`000?obh;_ol^2k00Oo
l^2k0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o
000000_ooooo000Looooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0U
ooooo`03o`000?nP^ncoX;_/00[oX;_/5_l00004ogNTkP03o`000?m[U^WoJiKY00SoJiKY00?o0000
ofV<hOmYS>402?mYS>400ol0003oLHOIog67f@05og67f@?o00000_maQmT00ol0003oOHOBogf7dP0;
ogf7dP03o`000?n;RLcoRhW<00_oRhW<00?o0000oiR>aonHS/L03_nHS/L00ol0003oYYC3ojJD``0@
ojJD``03o`000?nbVl3o/Y_000So/Y_000?o0000okZVa?njY/@01_njY/@00ol0003obJo0olV_`00=
olV_`003o`000?oB^/;od[[200Kod[[200?o0000omk0^_oN`;X01OoN`;X00ol0003oi/VjonK9^P08
onK9^P03o`000?oVbK[o000000Wok=:j00?o0000oo;C/Oobdk401oobdk400ol0003olmVeoo?I]@07
oo?I]@03o`000?obh;_ol^2k00Kol^2k00Co0000onkXaol0003o00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0;ooooo`009Oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?nP^ncoX;_/00GoX;_/1?l00003oijjk@03o`000?n0[_;oP:kb00WoP:kb
00?o0000of:Kl?mRVo001?mRVo08o`0000OoJiKY00?o0000ofV<hOmYS>402OmYS>401?l0003oLHOI
og67fOmaQmT3o`0000GoLHOI00?o0000ogf7d_mmQm802ommQm800ol0003oRhW<oh^9c00<oh^9c003
o`000?nHS/OoV8k700koV8k700?o0000ojJD`onVU<<03onVU<<00ol0003o/Y_0ok:K`007ok:K`003
o`000?njY/Co^ZK400So^ZK400?o0000olV_`?o9[l002oo9[l000ol0003od[[2om:j`P08om:j`P03
o`000?oN`;[og/2j00?og/2j00?o0000onK9^_oVbKX02_oVbKX00ol0003ok=:joncB^P08oncB^P03
o`000?obdk7ol]>a00Kol]>a00?o0000oo?I]OocfKD01oocfKD00ol0003ol^2koo;P^`06oo;P^`04
o`000?o^j<Ook^S7onkXa`;o00008_ooool002Gooooo00?o0000ooooooooool0:?ooool00ol0003o
X;_/oj2kk004o`0000SoW[[]00?o0000oh2^l_n0[_802On0[_800ol0003oHY_`of:Kl008of:Kl003
o`000?m>R^WoCX[Y00?o00001Om[U^T00ol0003oJHcQofV<h@09ofV<h@?o00002OmaQmT00ol0003o
OHOBogf7dP0;ogf7dP03o`000?n;RLcoRhW<00_oRhW<00?o0000oiR>aonHS/L03_nHS/L00ol0003o
YYC3ojJD``0@ojJD``03o`000?nbVl3o/Y_000Go/Y_000?o0000okZVa?njY/@02OnjY/@00ol0003o
bJo0olV_`00:olV_`003o`000?oB^/;od[[200Wod[[200?o0000omk0^_oN`;X00ooN`;X00ol0003o
i/VjonK9^P0:onK9^P;o00002?o/d[X00ol0003ol=flo`000007oo;C/@03o`000?ocfKGolmVe00Ko
lmVe00?o0000oo;P^oobh;/01oobh;/01?l0003ok^S7onkXaoo^j<L2o`0002;ooooo000Uooooo`;o
0000:_ooool2o`0000goW[[]00?o0000oh2^l_n0[_802On0[_800ol0003oHY_`of:Kl008of:Kl003
o`000?m>R^WoCX[Y00;oCX[Y0ol00002of^Fj@03o`000?mYS>7oJHcQ00KoJHcQ1?l0000;og67f@03
o`000?mmQm;oOHOB00_oOHOB00?o0000oh^9c?n;RL`02on;RL`00ol0003oV8k7oiR>a`0?oiR>a`03
o`000?nVU<?oYYC300ooYYC300?o0000ok:K`?nbVl000onbVl02o`0000go^ZK400?o0000olV_`?o9
[l002?o9[l000ol0003od[[2om:j`P0;om:j`P05o`000?oN`;[og/2jomk0^_l000003?oVbKX01?l0
003ok=:joncB^_l00007oncB^P04o`000?o`gKcol=flo`0000Gol]>a00?o0000oo?I]OocfKD01ooc
fKD00ol0003ol^2koo;P^`06oo;P^`03o`000?o^j<Ook^S700?ok^S70_l0000Qooooo`009Oooool0
0ol0003oooooooooo`0Yooooo`03o`000?nN^^goW[[]00goW[[]00?o0000oh2^l_n0[_802On0[_80
0ol0003oHY_`of:Kl008of:Kl003o`000?m>R^WoCX[Y00CoCX[Y1?l00004ofV<h@?o00001?mYS>40
0ol0003oLHOIog67f@09og67f@03o`000?mmQm;oOHOB00_oOHOB00?o0000oh^9c?n;RL`02on;RL`0
0ol0003oV8k7oiR>a`0>oiR>a`03o`000?nVU<?oYYC3013oYYC300Go0000ok:K`?nbVl3o/Y_0o`00
000?okZVa003o`000?o9[l3obJo000SobJo000?o0000om:j`_oB^/802ooB^/801?l0003og/2jomk0
^_l0000=onK9^P04o`000?o/d[[ok=:jo`0000Kok=:j00?o0000oo3M_?o`gK`00_o`gK`00ol0003o
l]>aoo;C/@02oo;C/@03o`000?ocfKGolmVe00KolmVe00?o0000oo;P^oobh;/01_obh;/00ol0003o
k^S7onkXa`05onkXa`;o00008?ooool002Gooooo00?o0000ooooooooool0:_ooool00ol0003oW[[]
oijjk@0=oijjk@03o`000?n0[_;oP:kb00WoP:kb00?o0000of:Kl?mRVo002?mRVo000ol0003oCX[Y
odj:j@06odj:j@Go00001omYS>400ol0003oLHOIog67f@0:og67f@03o`000?mmQm;oOHOB00[oOHOB
00?o0000oh^9c?n;RL`02on;RL`00ol0003oV8k7oiR>a`0>oiR>a`03o`000?nVU<?oYYC3013oYYC3
00Co0000ok:K`?nbVl3o00004?njY/@00ol0003obJo0olV_`007olV_`003o`000?oB^/;od[[200go
d[[200?o0000omk0^_l000003?oVbKX00ol0003ok=:joncB^P02oncB^P03o`000?o/d[[ok=:j00;o
k=:j00?o0000oo3M_?o`gK`01?o`gK`01?l0003ol]>aoo;C/Ol00009oo?I]@03o`000?obh;_ol^2k
00Kol^2k00?o0000onkXaoo^j<L01Oo^j<L2o`00023ooooo000Uooooo`03o`000?oooooooooo02_o
oooo00?o0000oijjkOnN^^d03OnN^^d00ol0003oP:kboh2^lP09oh2^lP03o`000?mRVo3oHY_`00So
HY_`00?o0000odj:jOm>R^T01Om>R^T2o`0000;oBh7S0ol00006ofV<h@03o`000?maQmWoLHOI00Wo
LHOI00?o0000ogf7d_mmQm802ommQm800ol0003oRhW<oh^9c00;oh^9c003o`000?nHS/OoV8k700ko
V8k700?o0000ojJD`onVU<<03onVU<<00ol0003o/Y_0o`00000BokZVa003o`000?o9[l3obJo000Go
bJo000?o0000om:j`_oB^/803ooB^/800ol0003oi/VjonK9^P0:onK9^P03o`000?o/d[[ok=:j00Co
k=:j00Go0000oncB^_o/d[[ok=:jo`000007oo3M_003o`000?obdk7o000000SolmVe00?o0000oo;P
^oobh;/01_obh;/00ol0003ok^S7onkXa`07onkXa`;o00007oooool002Gooooo00?o0000oooooooo
ool0;?ooool00ol0003oW[[]oijjk@0=oijjk@03o`000?n0[_;oP:kb00WoP:kb00?o0000of:Kl?mR
Vo002?mRVo001?l0003oCX[Yodj:jOm>R^T3o`0000;oCX[Y00?o0000od^1hom;PN<00_m;PN<4o`00
00?oJHcQ00?o0000og67fOmaQmT02OmaQmT00ol0003oOHOBogf7dP0:ogf7dP03o`000?n;RLcoRhW<
00_oRhW<00?o0000oiR>aonHS/L03_nHS/L00ol0003oYYC3ojJD``0?ojJD``;o00004onjY/@00ol0
003obJo0olV_`004olV_`003o`000?oB^/;od[[2013od[[200?o0000onK9^_oVbKX02_oVbKX00ol0
003ok=:joncB^P04oncB^P04o`000?o/d[[ok=:jo`0000Wol=fl00?o0000oo?I]OocfKD01oocfKD0
0ol0003ol^2koo;P^`05oo;P^`03o`000?o^j<Ook^S700Wok^S70_l0000Nooooo`009?ooool00ol0
003oooooooooo`0^ooooo`03o`000?nN^^goW[[]00goW[[]00?o0000oh2^l_n0[_802On0[_800ol0
003oHY_`of:Kl007of:Kl0Co00001_m>R^T00ol0003oBh7Sod^1h`05od^1h`Co00002omaQmT00ol0
003oOHOBogf7dP0:ogf7dP03o`000?n;RLcoRhW<00coRhW<00?o0000oiR>aonHS/L03_nHS/L00ol0
003oYYC3ojJD``0<ojJD``;o000000?oZYg9o`000?njY/@04onjY/@00ol0003obJo0olV_`003olV_
`003o`000?oB^/;od[[200ood[[200?o0000omc7aOl000002_oVbKX00ol0003ok=:joncB^P06oncB
^P03o`000?o/d[[o000000Wol=fl0_l00007oo?I]@03o`000?obh;_ol^2k00Kol^2k00?o0000onkX
aoo^j<L02Oo^j<L2o`0001kooooo000Tooooo`;o0000<?ooool00ol0003oW[[]oijjk@0;oijjkA7o
00001?mRVo04o`0000WoCX[Y00?o0000od^1hom;PN<01om;PN<4o`0000WoLHOI00?o0000ogf7d_mm
Qm802_mmQm800ol0003oRhW<oh^9c00;oh^9c003o`000?nHS/OoV8k700koV8k700?o0000ojJD`onV
U<<02OnVU<<3o`0000CoZYg900?o0000okZVa?njY/@04OnjY/@00ol0003obJo0olV_`002olV_`003
o`000?oB^/;od[[200ood[[200Go0000omc7aOoLalGog<O5o`000009onK9^P03o`000?o/d[[ok=:j
00Ook=:j00?o0000oo3M_?o`gK`01oo`gK`01?l0003ol^Rooo;X_ol00006oo?I]@03o`000?obh;_o
l^2k00Gol^2k00?o0000onkXaoo^j<L02Oo^j<L01?l0003oho3Go`000?l0000Mooooo`009?ooool0
0ol0003oooooooooo`0`ooooo`03o`000?nN^^goW[[]00GoW[[]1Ol00003oibik@03o`000?mgZo?o
Mj_c00WoMj_c00?o0000odjCkol000001?l00003of:Kl003o`000?m>R^WoCX[Y00KoCX[Y00?o0000
od^1hom;PN<02?m;PN<00ol0003oEh3OoeN0g`03o`0000KoLHOI00?o0000ogf7d_mmQm802_mmQm80
0ol0003oRhW<oh^9c00<oh^9c003o`000?nHS/OoV8k700goV8k700?o0000ojJD`onVU<<01onVU<<2
o`0000OoZYg900?o0000okZVa?njY/@04_njY/@01?l0003obJo0olV_`?l0000Aom:j`P03o`000?oL
alGog<O500;og<O500?o0000onK9^_oVbKX01_oVbKX00ol0003ok=:joncB^P07oncB^P03o`000?o`
gKco000000Sol=fl00Go0000oo;X_oobj;ool^Roo`000004oo?I]@03o`000?obh;_ol^2k00Kol^2k
00?o0000onkXaoo^j<L02?o^j<L01?l0003oho3Gon?`eooSl=L2o`0001cooooo000Tooooo`03o`00
0?oooooooooo037ooooo00?o0000oijjkOnN^^d01?l00009oibik@03o`000?mgZo?oMj_c00SoMj_c
0ol00004odjCk`Go00002?m>R^T00ol0003oBh7Sod^1h`08od^1h`03o`000?mGP=ooEh3O00;oEh3O
1?l00003og67f@03o`000?mmQm;oOHOB00[oOHOB00?o0000oh^9c?n;RL`02on;RL`00ol0003oV8k7
oiR>a`0>oiR>a`03o`000?nVU<?oYYC300CoYYC30_l0000:ojZMb@03o`000?njY/Co^ZK4017o^ZK4
00?o0000olV_`?l000004_oB^/800ol0003og<O5omc7a@03omc7a@03o`000?oVbK[oi/Vj00Goi/Vj
00?o0000oncB^_o/d[X01oo/d[X00ol0003ol=flo`000007oo3M_003o`000?obj;ool^Ro00?ol^Ro
00Co0000oo?I]OocfKGo00002?obh;/00ol0003ok^S7onkXa`08onkXa`03o`000?oSl=Ooho3G00;o
ho3G0_l0000Looooo`009?ooool00ol0003oooooooooo`0booooo`;o00003_nL^Nd00ol0003oMj_c
ogN[l`04ogN[l`?o00000_mgZo<00ol0003oCY?_odjCk`06odjCk`?o00001om>R^T00ol0003oBh7S
od^1h`08od^1h`03o`000?mGP=ooEh3O00GoEh3O1?l0000<ogf7dP03o`000?n;RLcoRhW<00coRhW<
00?o0000oiR>aonHS/L03OnHS/L01?l0003oYYC3ojJD`onVU<<3o`0000coZYg900?o0000okZVa?nj
Y/@04OnjY/@2o`0001;od[[200?o0000omc7aOoLalD01OoLalD00ol0003oi/VjonK9^P03onK9^P03
o`000?o/d[[ok=:j00Ook=:j00Go0000oo3M_?o`gKcol=flo`000005oo3M_003o`000?obj;ool^Ro
00Gol^Ro00?o0000oo?I]Ol000001oobh;/00ol0003ok^S7onkXa`08onkXa`03o`000?oSl=Ooho3G
00Coho3G0_l0000Kooooo`009?ooool00ol0003oooooooooo`0dooooo`03o`000?nL^NgoW;W]00co
W;W]00Co0000ogN[lomgZo?oMj_c0_l00006ogN[l`03o`000?m>TnooCY?_00KoCY?_00?o0000oc1n
iol000000_l00005odj:j@03o`000?m;PN?oBh7S00OoBh7S00?o0000oeN0gomGP=l02?mGP=l4o`00
00[oOHOB00?o0000oh^9c?n;RL`02on;RL`00ol0003oV8k7oiR>a`0=oiR>a`04o`000?nVU<?o0000
o`0000ooZYg900?o0000okZVa?njY/@04?njY/@00ol0003o`k?:o`00000Aom:j`P03o`000?oLalGo
g<O500Kog<O500?o0000onK9^_oVbKX00ooVbKX00ol0003ok=:joncB^P07oncB^P03o`000?o`gKco
l=fl00;ol=fl00?o0000oo3M_?o`gK`00_o`gK`00ol0003ol^Rooo;X_`06oo;X_`03o`000?obh;_o
l^2k00Kol^2k00?o0000onkXaoo^j<L01oo^j<L00ol0003oho3Gon?`e`05on?`e`;o00006oooool0
02?ooooo00?o0000ooooooooool0=_ooool00ol0003oW;W]oibik@0<oibik@?o00002OmgZo<00ol0
003oCY?_odjCk`06odjCk`04o`000?l`O^Oo<7kWoc1ni`?o00000_m>R^T00ol0003oBh7Sod^1h`08
od^1h`03o`000?mGP=ooEh3O00SoEh3O00?o0000of^4f_m[Q=X01Ol00005ogf7dP03o`000?n;RLco
RhW<00_oRhW<00?o0000oiR>aonHS/L03?nHS/L3o`0001;oZYg900?o0000okZVa?njY/@03_njY/@0
1Ol0003o`k?:ol>cb_o3/l[o000000ood[[200?o0000omc7aOoLalD02?oLalD01Ol0003oi/VjonK9
^_oVbK[o000000Wok=:j00?o0000oo3M_?o`gK`01?o`gK`01?l0003ol=floo3M_?l00009oo;X_`;o
00001_obh;/00ol0003ok^S7onkXa`07onkXa`03o`000?oSl=Ooho3G00Ooho3G0_l0000Jooooo`00
8oooool3o`0003Oooooo00?o0000oibikOnL^Nd02?nL^Nd3o`000003oibikOl0003oMj_c00[oMj_c
00?o0000odjCkom>Tnl01_m>Tnl00ol0003o<7kWoc1ni`03oc1ni`;o000000?oCX[Yo`000?m;PN<0
2?m;PN<00ol0003oEh3OoeN0g`09oeN0g`03o`000?m[Q=[oJhCJ00CoJhCJ1_l0000>oh^9c003o`00
0?nHS/OoV8k700KoV8k71Ol00002oiNDc`03o`000?nZWLWoZYg9013oZYg900?o0000okZVa?njY/@0
3OnjY/@00ol0003o`k?:ol>cbP02ol>cbP03o`000?oB^/;od[[200god[[200?o0000omc7aOoLalD0
2?oLalD01?l0003oi/VjonK9^_l0000:oncB^P03o`000?o`gKcol=fl00Col=fl00Co0000oo3M_?o`
gKco00002?obj;l01?l0003okoC3onod`ol00004oo;P^`03o`000?o^j<Ook^S700Ook^S700?o0000
on?`eooSl=L02?oSl=L3o`0001Wooooo000Sooooo`03o`000?oooooooooo03Sooooo00?o0000oibi
kOnL^Nd01?nL^Nd3o`0000GoW;W]00?o0000ogN[lomgZo<02OmgZo<00ol0003oCY?_odjCk`06odjC
k`03o`000?l`O^Oo<7kW00Co<7kW0ol00009od^1h`03o`000?mGP=ooEh3O00SoEh3O00?o0000of^4
f_m[Q=X02Om[Q=X:o`0000GoRhW<00Co0000oiR>aonHS/OoV8k71Ol00008oiNDc`03o`000?nZWLWo
ZYg9013oZYg900?o0000okZVa?njY/@02onjY/@00ol0003o`k?:ol>cbP04ol>cbP03o`000?oB^/;o
d[[200_od[[200?o0000omc7aOoLalD02_oLalD00ol0003oi/Vjo`000009oncB^P03o`000?o`gKco
l=fl00Kol=fl0_l00008oo;X_`03o`000?o_m<?okoC300;okoC300Go0000oo;P^oobh;_ol^2ko`00
0008onkXa`03o`000?oSl=Ooho3G00Soho3G00?o0000olWbkOl000000_l00008ooooo`Co000000?o
410@ooooooooool02Oooool000Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0000Kooooo00?o0000ooooooooool0>Oooool00ol0003oW;W]oibik@03o`0000OoW;W]2_l0
0004ogN[l`03o`000?m>TnooCY?_00KoCY?_00?o0000oc1niol`O^L01_l`O^L2o`0000SoBh7S00?o
0000oeN0gomGP=l02?mGP=l00ol0003oJhCJof^4fP09of^4fP03o`000?n2S=GoPXcE00KoPXcE2Ol0
000=oiNDc`03o`000?nZWLWoZYg9013oZYg900?o0000okZVa?njY/@02_njY/@00ol0003o`k?:ol>c
bP06ol>cbP03o`000?oB^/;od[[200Wod[[200?o0000omc7aOoLalD03?oLalD00ol0003ok=:joncB
^P07oncB^P03o`000?o`gKcol=fl00Sol=fl00?o0000oo;X_oobj;l01_obj;l00ol0003okoC3onod
``03onod``03o`000?obh;_o000000Sok^S700?o0000on?`eooSl=L01ooSl=L2o`0000?obO;]0_l0
000:ooooo`03o`000?oooooooooo00_ooooo0008ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo03Wooooo
0ol00006oibik@Co00001?nJ^Nh00ol0003oL:Sdog2Xm003og2Xm0So00001_m>Tnl00ol0003o<7kW
oc1ni`05oc1ni`03o`000?lWLn7o000000;o00001Om;PN<00ol0003oEh3OoeN0g`08oeN0g`03o`00
0?m[Q=[oJhCJ00[oJhCJ00?o0000oh:<eOn2S=D02on2S=D00ol0003oUiC?oiNDc`0>oiNDc`03o`00
0?nZWLWoZYg9013oZYg900?o0000okZVa?njY/@01onjY/@2o`0000Wo`k?:00?o0000om:j`_oB^/80
2?oB^/800ol0003og<O5omc7a@0=omc7a@03o`000?o/d[[ok=:j00Ook=:j00?o0000oo3M_?o`gK`0
1oo`gK`2o`0000Ool^Ro00?o0000onod`oo_m<<01Oo_m<<2o`0000Ook^S700?o0000on?`eooSl=L0
1ooSl=L00ol0003obO;]olWbk@04olWbk@;o00002Oooool00ol0003oooooooooo`0;ooooo`002?oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooo
ooooo`0fooooo`?o00000_ooool00ol0003oW;W]oibik@04o`0000WoV[W^00?o0000og2Xm?m`Z?@0
2?m`Z?@00ol0003o?Hg^o`000003o`0000?oCY?_00?o0000oc1niol`O^L01Ol`O^L01?l0003o9g?Q
obMchOlWLn43o`0000?oBh7S00?o0000oeN0gomGP=l02?mGP=l00ol0003oJhCJof^4fP09of^4fP03
o`000?n2S=GoPXcE00coPXcE00?o0000oiNDconGU<l03OnGU<l00ol0003oZYg9ojZMb@0@ojZMb@03
o`000?njY/Co^ZK400Ko^ZK400?o0000ol>cb_o3/lX02_o3/lX00ol0003od[[2om:j`P07om:j`P03
o`000?oLalGog<O500cog<O500?o0000onCFb?l000001oo/d[X00ol0003ol=floo3M_007oo3M_004
o`000?obj;ool^Roo`0000Gol^Ro00?o0000onod`oo_m<<01_o_m<<01?l0003oh_g8o`000?l00004
onkXa`03o`000?oSl=Ooho3G00Koho3G0_l00007olWbk@;o00002Oooool00ol0003oooooooooo`0;
ooooo`002?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool0
0ol0003oooooooooo`0eooooo`;o00001_ooool2o`0000koV[W^00?o0000og2Xm?m`Z?@02?m`Z?@0
0ol0003o?Hg^ocf=kP02ocf=kPGo00001ol`O^L00ol0003o9g?QobMch@03obMch@;o000000?oBh7S
o`000?mGP=l02OmGP=l00ol0003oJhCJof^4fP0:of^4fP03o`000?n2S=GoPXcE00_oPXcE00?o0000
oiNDconGU<l03OnGU<l00ol0003oZYg9ojZMb@0AojZMb@03o`000?njY/Co^ZK400Co^ZK400?o0000
ol>cb_o3/lX02oo3/lX00ol0003od[[2om:j`P06om:j`P03o`000?oLalGog<O500cog<O500Go0000
onCFb?oTe/Soi=K8o`000006oncB^P03o`000?o`gKcol=fl00Ool=fl00Go0000oo;X_oobj;ool^Ro
o`000004oo;X_`03o`000?o_m<?okoC300GokoC300?o0000on;mb?oRoLP00_oRoLP2o`000003onkX
aol0003oho3G00Ooho3G00?o0000olWbkOo9l^d02?o9l^d2o`0000Sooooo00?o0000ooooooooool0
2oooool000Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0<_ooool3o`0000Wooooo00?o0000oiZik_nJ^Nh03OnJ^Nh00ol0003oL:Sd
og2Xm008og2Xm003o`000?lmSNko?Hg^00Go?Hg^0ol00006oc1ni`03o`000?lWLn7o9g?Q00Co9g?Q
0ol0000:oeN0g`03o`000?m[Q=[oJhCJ00WoJhCJ00?o0000oh:<eOn2S=D03?n2S=D00ol0003oUiC?
oiNDc`0=oiNDc`03o`000?nZWLWoZYg9013oZYg900?o0000okZVa?njY/@00onjY/@00ol0003o`k?:
ol>cbP0=ol>cbP03o`000?oB^/;od[[200Cod[[200?o0000omc7aOoLalD03?oLalD00ol0003oi=K8
onCFb003onCFb003o`000?o/d[[ok=:j00;ok=:j00?o0000oo3M_?o`gK`01oo`gK`00ol0003ol^Ro
oo;X_`03oo;X_`04o`000?obj;ool^Roo`0000OokoC300?o0000on;mb?oRoLP01?oRoLP3o`0000Oo
ho3G00?o0000olWbkOo9l^d02Oo9l^d3o`0000Oooooo00?o0000ooooooooool02oooool000Sooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00?ooooo0_l0000`ooooo`?o
00003Oooool00ol0003oV[W^oiZikP0=oiZikP03o`000?m`Z?CoL:Sd00SoL:Sd00?o0000ocf=k_lm
SNh01OlmSNh01?l0003o57;Qo`000?l00005oc1ni`03o`000?lWLn7o9g?Q00Ko9g?Q0_l00009oeN0
g`03o`000?m[Q=[oJhCJ00WoJhCJ00?o0000oh:<eOn2S=D02on2S=D00ol0003oUiC?oiNDc`0=oiND
c`03o`000?nZWLWoZYg9013oZYg900?o0000okZVa?njY/@00_njY/@00ol0003o`k?:ol>cbP0>ol>c
bP03o`000?oB^/;od[[200?od[[200?o0000omc7aOoLalD03?oLalD00ol0003oi=K8onCFb005onCF
b004o`000?o/d[[ok=:jo`0000[ol=fl00?o0000oo;X_oobj;l00oobj;l00ol0003ol^Roo`000007
onod``03o`000?oRoLSoh_g800Coh_g800Co0000ol7mbOo1oLWo`Og90_l00003on?`e`;o00003Oo9
l^d2o`0000Oooooo00?o0000ooooooooool02oooool000Sooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`0/ooooo`?o0000
4Oooool00ol0003oV[W^oiZikP0=oiZikP03o`000?m`Z?CoL:Sd00SoL:Sd00?o0000ocf=k_lmSNh0
1OlmSNh00ol0003o57;QoaAbh@02o`0000?o<7kW00?o0000obMchOlWLn401_lWLn400ol0003o=GKQ
o`000002o`0000KoEh3O00?o0000of^4f_m[Q=X02Om[Q=X00ol0003oPXcEoh:<e@0;oh:<e@03o`00
0?nGU<ooUiC?00koUiC?00?o0000ojZMbOnZWLT04?nZWLT01?l0003o^ZK4okZVa?l0000Bol>cbP03
o`000?oB^/;od[[200;od[[200?o0000omc7aOoLalD03?oLalD00ol0003oi=K8onCFb006onCFb003
o`000?o/d[[o000000Wol=fl00?o0000oo;X_oobj;l01Oobj;l2o`0000KokoC300?o0000on;mb?oR
oLP01?oRoLP00ol0003o`Og9ol7mb@04ol7mb@03o`000?oSl=Oo000000kobO;]0ol00005ooooo`03
oeEEEOmVIVKo000000gooooo0008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0:Oooool3o`0001Gooooo00?o0000oiZi
k_nJ^Nh03OnJ^Nh00ol0003oL:Sdog2Xm008og2Xm003o`000?lmSNko?Hg^00Go?Hg^00Co0000oaAb
hOlDL^7o57;Q0ol000000ol`O^Oo0000obMch@07obMch@04o`000?leM^7o=GKQocEfh@;o00001OmG
P=l00ol0003oJhCJof^4fP09of^4fP03o`000?n2S=GoPXcE00_oPXcE00?o0000oiNDconGU<l03OnG
U<l00ol0003oZYg9ojZMb@0@ojZMb@03o`000?njY/Co000001Co`k?:00Co0000om:j`_oB^/;o0000
3_oLalD00ol0003oi=K8onCFb008onCFb0;o00002Oo`gK`00ol0003ol^Rooo;X_`05oo;X_`;o0000
1_o_m<<00ol0003oh_g8on;mb003on;mb003o`000?o1oLWo`Og900Go`Og90ol0000;olWbk@?o0000
0_ooool00ol0003oooooooooo`0Cooooo`008_ooool00ol0003oooooooooo`0Vooooo`?o00006Ooo
ool00ol0003oV[W^oiZikP0;oiZikPWo00001?m`Z?@00ol0003o?Hg^ocf=kP05ocf=kP03o`000?lD
L^7o57;Q00?o57;Q0ol00008obMch@03o`000?leM^7o=GKQ00;o=GKQ0_l00003oeN0g`03o`000?m[
Q=[oJhCJ00WoJhCJ00?o0000oh:<eOn2S=D02on2S=D00ol0003oUiC?oiNDc`0>oiNDc`03o`000?nZ
WLWoZYg900ooZYg90_l0000Eol>cbP03o`000?oB^/;o000000kog<O500?o0000onCFb?oTe/P02OoT
e/P00ol0003oj^O<o`000007oo3M_003o`000?obj;ool^Ro00Kol^Ro0_l00005onod``03o`000?oR
oLSoh_g800?oh_g800?o0000ol7mbOo1oLT01Oo1oLT01Ol0003oPnK0oh?V`?n3i/3o000000KobO;]
1?l00005ooooo`03o`000?oooooooooo01?ooooo000Qooooo`03o`000?oooooooooo02Cooooo0ol0
000Mooooo`03o`000?nJ^NkoV[W^00GoV[W^1Ol00003oiZikP03o`000?m^Z?CoKZSd00?oKZSd2?l0
0005ocf=kP03o`000?lDL^7o57;Q00Co57;Q0_l00007obMch@03o`000?leM^7o=GKQ00Co=GKQ0ol0
00000omGP=oo0000of^4fP09of^4fP03o`000?n2S=GoPXcE00coPXcE00?o0000oiNDconGU<l03OnG
U<l00ol0003oZYg9ojZMb@0=ojZMb@;o000000?o[j[Co`000?o3/lX05?o3/lX2o`0000kog<O500?o
0000onCFb?oTe/P02OoTe/P01Ol0003oj^O<on[Wc?oZilco000000Kol=fl00?o0000oo;X_oobj;l0
1Oobj;l01?l0003okoC3onod`ol00003onod``03o`000?oRoLSoh_g800?oh_g800?o0000ol7mbOo1
oLT01?o1oLT2o`0000GoPnK000?o0000olWbkOo9l^d00ol0000:ooooo`03o`000?oooooooooo01;o
oooo000Qooooo`03o`000?oooooooooo02;ooooo0_l0000Qooooo`03o`000?nJ^NkoV[W^00Co0000
2OnJ^Nh00ol0003oKZSdofjXm008ofjXm003o`000?ldRngo000000;o00000olmSNh00ol0003o57;Q
oaAbh@05oaAbh@;o00001_lWLn400ol0003o=GKQocEfh@06ocEfh@;o00002om[Q=X00ol0003oPXcE
oh:<e@0;oh:<e@03o`000?nGU<ooUiC?00koUiC?00?o0000ojZMbOnZWLT02OnZWLT3o`0000Co[j[C
00?o0000ol>cb_o3/lX04Oo3/lX00ol0003ocLCBo`00000=omc7a@03o`000?oTe/Soi=K800Woi=K8
00?o0000on[Wc?oZil`00ooZil`00ol0003ol=floo3M_002oo3M_003o`000?obj;ool^Ro00Gol^Ro
00?o0000onod`oo_m<<00_o_m<<00ol0003okoC3o`000005on;mb003o`000?o1oLWo`Og900Co`Og9
00?o0000oh?V`?n3i/001?n3i/04o`0000gooooo00?o0000ooooooooool04_ooool0027ooooo0_l0
000Pooooo`?o00009?ooool2o`0000koV[W^00?o0000ofjXm?m^Z?@02?m^Z?@01?l0003o=8_]ocB;
kOldRnd3o`000003ocf=k_l0003o57;Q00Go57;Q00Co0000o`=UfOl0003o00001OlWLn400ol0003o
=GKQocEfh@07ocEfh@;o00002Om[Q=X00ol0003oPXcEoh:<e@0<oh:<e@03o`000?nGU<ooUiC?00go
UiC?00?o0000ojZMbOnZWLT01onZWLT2o`0000Oo[j[C00?o0000ol>cb_o3/lX04?o3/lX01Ol0003o
cLCBolg4d_o=a=;o000000cog<O500?o0000onCFb?oTe/P02?oTe/P00ol0003oj^O<on[Wc005on[W
c004o`000?o`gKcol=flo`0000Sol^Ro00?o0000onod`oo_m<<00oo_m<<00ol0003oh_g8on;mb003
on;mb003o`000?o1oLWo`Og900?o`Og90_l00004oh?V`0?o00004Oooool00ol0003oooooooooo`0B
ooooo`008Oooool00ol0003oooooooooo`0Looooo`?o0000:Oooool00ol0003oV[W^oiZikP0<oiZi
kP03o`000?m^Z?CoKZSd00SoKZSd00?o0000ocB;kOldRnd00oldRnd3o`0000Ko57;Q00?o0000o`=U
fOl3IMT00_l00003obMch@03o`000?leM^7o=GKQ00Oo=GKQ00?o0000oe:2h_l000000_l00007of^4
fP03o`000?n2S=GoPXcE00_oPXcE00?o0000oiNDconGU<l03OnGU<l00ol0003oZYg9ojZMb@05ojZM
b@;o00002_n_Z]<00ol0003o`k?:ol>cbP0>ol>cbP03o`000?o=a=;ocLCB00?ocLCB00?o0000omc7
aOoLalD02?oLalD00ol0003oi=K8onCFb009onCFb003o`000?oZilcoj^O<00Koj^O<00?o0000oo3M
_?l000001oobj;l00ol0003okoC3onod``03onod``;o00001?oRoLP00ol0003o`Og9ol7mb@02ol7m
b@;o00000on3i/03o`0001Cooooo00?o0000ooooooooool04_ooool0027ooooo00?o0000oooooooo
ool06Oooool3o`0002gooooo00?o0000oiZik_nJ^Nh03?nJ^Nh00ol0003oKZSdofjXm008ofjXm003
o`000?ldRngo=8_]00Go=8_]0_l00005oaAbh@04o`000?l3IMWo0fGIo`=Uf@;o00000_lWLn400ol0
003o=GKQocEfh@07ocEfh@04o`000?mBP^;oDX;Roe:2hP?o00001?m[Q=X00ol0003oPXcEoh:<e@0<
oh:<e@03o`000?nGU<ooUiC?00goUiC?00Co0000ojZMbOnZWLWoZYg90ol0000=ojnZd`03o`000?o3
/l[o`k?:00co`k?:00?o0000olg4d_o=a=801?o=a=800ol0003og<O5omc7a@07omc7a@03o`000?oT
e/Soi=K800Woi=K800?o0000on[Wc?oZil`02?oZil`2o`0000Kol^Ro00?o0000onod`oo_m<<01?o_
m<<00ol0003oh_g8o`000002on;mb003o`000?o1oLWo`Og900;o`Og900?o0000oh?V`?n3i/000ol0
000Gooooo`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo01Kooooo0ol0000a
ooooo`;o00003OnJ^Nh00ol0003oKZSdofjXm008ofjXm003o`000?ldRngo=8_]00Ko=8_]0_l00004
oaAbh@03o`000?l3IMWo0fGI00;o0fGI00Co0000obMchOlWLn7o00002OleM^400ol0003oDX;Roe:2
hP03oe:2hP?o00000_m[Q=X00ol0003oPXcEoh:<e@0;oh:<e@03o`000?nGU<ooUiC?00goUiC?00Co
0000ojZMbOl0003o00004?n_Z]<00ol0003o`k?:ol>cbP0;ol>cbP03o`000?o=a=;ocLCB00KocLCB
00?o0000omc7aOoLalD01OoLalD00ol0003oi=K8onCFb009onCFb003o`000?oZilcoj^O<00Woj^O<
00Co0000onShcOl0003o00001?obj;l00ol0003okoC3onod``03onod``04o`000?oRoLSoh_g8on;m
b0;o00000oo1oLT5o`0001[ooooo00?o0000ooooooooool04_ooool0027ooooo00?o0000oooooooo
ool04oooool3o`0003Kooooo00?o0000oiZik_nJ^Nh02onJ^Nh00ol0003oKZSdofjXm008ofjXm003
o`000?ldRngo=8_]00Ko=8_]0ol00003oaAbh@03o`000?l3IMWo0fGI00;o0fGI0ol00009ocEfh@03
o`000?mBP^;oDX;R00KoDX;R0ol0000=oh:<e@03o`000?nGU<ooUiC?00coUiC?0ol0000CojnZd`03
o`000?o3/l[o`k?:00So`k?:0_l0000:olg4dP03o`000?oLalGog<O500Cog<O500?o0000onCFb?oT
e/P02?oTe/P00ol0003oj^O<on[Wc009on[Wc003o`000?oXn<goj?S=00;oj?S=0_l000000oobj;oo
0000onod``04onod``03o`000?oRoLSoh_g800;oh_g80_l00002ol7mb@?o00007Oooool00ol0003o
ooooooooo`0Booooo`008?ooool00ol0003oooooooooo`0Aooooo`?o0000>_ooool00ol0003oV[W^
oiZikP08oiZikP[o00001?m^Z?@00ol0003o=8_]ocB;k@06ocB;k@03o`000?l0Jm_o000000;o0000
00?o57;Qo`000?l3IMT01?l3IMT2o`0000Wo=GKQ00?o0000oe:2h_mBP^802?mBP^85o`0000WoPXcE
00?o0000oiNDconGU<l01_nGU<l5o`0000;oUIoK00?o0000ojnZdon_Z]<04On_Z]<00ol0003o`k?:
ol>cbP07ol>cbP03o`000?o=a=;ocLCB00_ocLCB00?o0000omc7aOoLalD00_oLalD00ol0003oi=K8
onCFb009onCFb003o`000?oZilcoj^O<00Soj^O<00?o0000onShcOoXn<d01OoXn<d4o`0000;okoC3
00?o0000on;mb?oRoLP00_oRoLP00ol0003o`Og9o`000002o`00027ooooo00?o0000ooooooooool0
4Oooool0023ooooo00?o0000ooooooooool03oooool2o`0003kooooo00Co0000oiZik_nJ^NkoV[W^
1_l00005oiZikP03o`000?m_ZOCoKjWd00;oKjWd2?l00006ocB;k@04o`000?l0Jm_o06_Ko`1[f`?o
00001_l3IMT2o`0000Oo=GKQ00?o0000oe:2h_mBP^802?mBP^800ol0003oMI7QogFAh@02ogFAh@Oo
00000_n2S=D01?l0003oUiC?oiNDconGU<l5o`0000SoUIoK00?o0000ojnZdon_Z]<04On_Z]<00ol0
003o`k?:ol>cbP05ol>cbP03o`000?o=a=;ocLCB00cocLCB00Go0000omc7aOoLalGog<O5o`00000;
onCFb003o`000?oZilcoj^O<00Soj^O<00?o0000onShcOoXn<d01_oXn<d01?l0003oeOo5omGoaOoE
olD;o`0002;ooooo00?o0000ooooooooool04Oooool0023ooooo0_l0000=ooooo`?o0000@Oooool3
o`0000coV[W^00?o0000ofnYm?m_ZO@02?m_ZO@5o`0000?o=8_]00?o0000o`1[fol0Jm/00_l0Jm/2
o`0000Go0fGI00Co0000o`eYg?l0003o00001_leM^400ol0003oDX;Roe:2hP08oe:2hP03o`000?me
TN7oMI7Q00SoMI7Q1_l0000=oiFOf`03o`000?n_Z]?o[j[C017o[j[C00?o0000ol>cb_o3/lX01?o3
/lX00ol0003ocLCBolg4dP0>olg4dP03o`000?oLalGo000000_oi=K800?o0000on[Wc?oZil`02?oZ
il`00ol0003oj?S=onShc@06onShc@05o`000?oEolGoeOo5omGoaOl000001?nUkj`4o`0000?ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Aooooo`008?ooool00ol0003ooooooooo
o`09ooooo`?o0000AOooool00ol0003oV[W^oiZikP0<oiZikP03o`000?m_ZOCoKjWd00SoKjWd00Co
0000ocB=k_ldSNko=8g^1Ol00005o`1[f`;o00001?l3IMT00ol0003o3FWLo`eYg002o`0000Go=GKQ
00?o0000oe:2h_mBP^802?mBP^800ol0003oMI7QogFAh@0:ogFAh@03o`000?nEWm_oUIoK00koUIoK
00?o0000ojnZdon_Z]<04On_Z]<00ol0003o`k?:ol>cbP02ol>cbP03o`000?o=a=;ocLCB00oocLCB
0_l0000<onCFb003o`000?oZilcoj^O<00Ooj^O<00?o0000onShcOoXn<d01_oXn<d01Ol0003oeOo5
omGoaOoEolGo000000CoYNn/0ol00005ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool04Oooool0023ooooo00?o0000ooooooooool01_ooool3o`0004Wooooo00?o0000oiZik_nJ^Nh0
3?nJ^Nh00ol0003oKjWdofnYm008ofnYm003o`000?ldSNko=8g^00Co=8g^0ol00005o`1[f`;o0000
0ol3IMT01?l0003o3FWLo`eYg?l=JM`2o`0000?o=GKQ00?o0000oe:2h_mBP^802?mBP^800ol0003o
MI7QogFAh@0;ogFAh@03o`000?nEWm_oUIoK00goUIoK00?o0000ojnZdon_Z]<04_n_Z]<01?l0003o
`k?:ol>cb_l0000Aolg4dP04o`000?oEfM_oeMWKo`0000[oi=K800?o0000on[Wc?oZil`02?oZil`0
0ol0003oj?S=onShc@05onShc@05o`000?oEolGoeOo5omGoaOl000000onUkj`3o`0000Sooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Aooooo`008?ooool00ol0003oooooooooo`03
ooooo`?o0000COooool00ol0003oV[W^oiZikP0<oiZikP03o`000?m_ZOCoKjWd00SoKjWd00?o0000
ocB=k_ldSNh01_ldSNh2o`0000Co06_K0ol00002o`=Uf@03o`000?l=JMco3FWL00;o3FWL0_l00002
ocEfh@03o`000?mBP^;oDX;R00SoDX;R00?o0000ogFAhOmeTN402_meTN400ol0003oUIoKoiFOf`0>
oiFOf`03o`000?n_Z]?o[j[C017o[j[C00?o0000ol>cb_l000004Oo=a=800ol0003oeMWKomGIf`02
omGIf`03o`000?oTe/Soi=K800Koi=K800?o0000on[Wc?oZil`02?oZil`00ol0003oj?S=onShc@05
onShc@05o`000?oEolGoeOo5omGoaOl000000onUkj`2o`0000_ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Aooooo`007oooool01?l0003oooooooooooooool3o`00057ooooo00?o
0000oiZik_nJ^Nh03?nJ^Nh00ol0003oKjWdofnYm008ofnYm003o`000?ldSNko=8g^00Ko=8g^0ol0
0003o`1[f`06o`000?l0F<go0000o`000?l3IMWo00001Ol=JM`3o`0000[oDX;R00?o0000ogFAhOme
TN402omeTN400ol0003oUIoKoiFOf`0=oiFOf`03o`000?n_Z]?o[j[C017o[j[C0_l0000Aolg4dP03
o`000?oEfM_oeMWK00CoeMWK00?o0000onCFb?oTe/P01?oTe/P00ol0003oj^O<on[Wc008on[Wc003
o`000?oXn<goj?S=00Goj?S=00Go0000omGoaOoEolGoeOo5o`000003ojG_[003o`000?oooooooooo
00cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Aooooo`007oooool4o`0005Go
oooo00?o0000oiZik_nJ^Nh02_nJ^Nh9o`0000CoKjWd00?o0000ocB=k_ldSNh01_ldSNh00ol0003o
06_Ho`000002o`000007o`1[fol0003o05S=o`1HcOl0003o0fGIo`000006o`eYg0;o00002_mBP^80
0ol0003oMI7QogFAh@0;ogFAh@03o`000?nEWm_oUIoK00goUIoK00?o0000ojnZdon_Z]<03_n_Z]<2
o`000003okBmh?l0003ocLCB00oocLCB00?o0000omGIfooEfM/01_oEfM/00ol0003oi=K8onCFb003
onCFb003o`000?oZilcoj^O<00Ooj^O<00?o0000onShcOoXn<d01OoXn<d01Ol0003oeOo5omGoaOoE
olGo000000?oYNn/00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo013ooooo000Oooooo`;o0000F?ooool00ol0003oV[W^oiZikP05oiZikPCo00000onL^Nd0
0ol0003oMJceogF/m@03ogF/m@So00001_ldSNh01?l0003o06_Ho`1[f?l0JmP3o`0000;o05S=0ol0
0007o`eYg0;o00002OmBP^800ol0003oMI7QogFAh@0:ogFAh@03o`000?nEWm_oUIoK00koUIoK00?o
0000ojnZdon_Z]<02on_Z]<2o`0000Co];gP00?o0000olg4d_o=a=803?o=a=800ol0003oeMWKomGI
f`08omGIf`05o`000?oTe/Soi=K8onCFb?l000002OoZil`00ol0003oj?S=onShc@05onShc@05o`00
0?oEolGoeOo5omGoaOl000000_nUkj`2o`00017ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0@ooooo`008Oooool00ol0003oooooooooo`1Fooooo`03o`000?nJ^NkoV[W^00Co0000
2?nL^Nd00ol0003oMJceogF/m@09ogF/m@Go00000oldSNh00ol0003o06_Ho`1[f002o`1[f0;o0000
0ol0F<d2o`0000Ko3FWL00?o0000oc1niol000000_l00006oe:2hP03o`000?meTN7oMI7Q00_oMI7Q
00?o0000oiFOfonEWm/03OnEWm/00ol0003o[j[CojnZd`09ojnZd`;o00001ond_N000ol0003ocLCB
olg4dP0:olg4dP03o`000?oEfM_oeMWK00[oeMWK00?o0000onCFb?l000002_oZil`00ol0003oj?S=
onShc@04onShc@05o`000?oEolGoeOo5omGoaOl000000_nUkj`00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool0
E_ooool2o`0000goW;W]00?o0000ogF/mOme[?D02Ome[?D01?l0003o?IGaocfElOlmUO45o`0000Go
06_H0_l00003o`1Hc@;o00001Ol=JM`01?l0003o<7kWoc1niol`O^L3o`0000CoDX;R00?o0000ogFA
hOmeTN402_meTN400ol0003oUIoKoiFOf`0>oiFOf`03o`000?n_Z]?o[j[C00Ko[j[C0_l00009okBm
h003o`000?o=a=;ocLCB00WocLCB00?o0000omGIfooEfM/02ooEfM/3o`0000Woj^O<00?o0000onSh
cOoXn<d01?oXn<d01Ol0003oeOo5omGoaOoEolGo000000;oYNn/00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo013ooooo000Sooooo`03o`000?oooooooooo
05Kooooo00?o0000oibikOnL^Nd03?nL^Nd00ol0003oMJceogF/m@09ogF/m@03o`000?lmUO7o?IGa
00Co?IGa0ol00005o`1[f0;o00000ol0F<d2o`0000Co3FWL00?o0000oc1niol`O^L00ol`O^L3o`00
0003oe:2h_l0003oMI7Q00coMI7Q00?o0000oiFOfonEWm/03OnEWm/00ol0003o[j[CojnZd`04ojnZ
d`;o00003?nd_N000ol0003ocLCBolg4dP07olg4dP03o`000?oEfM_oeMWK00_oeMWK00Co0000omS`
h_oHl>;of?3R0_l00006on[Wc003o`000?oXn<goj?S=00Coj?S=00Ko0000omGoaOoEolGoeOo5o`00
0?nUkj`2o`0001Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0@ooooo`009?oo
ool2o`0005Oooooo00?o0000oibikOnL^Nd03?nL^Nd00ol0003oMJceogF/m@09ogF/m@03o`000?lm
UO7o?IGa00Ko?IGa0ol00003o`1[f0?o00000_l0F<d3o`0000?o3FWL00?o0000oc1niol`O^L01Ol`
O^L3o`0000coMI7Q00?o0000oiFOfonEWm/03_nEWm/01?l0003o[j[CojnZdon_Z]<2o`0000oo];gP
00?o0000olg4d_o=a=801Oo=a=800ol0003oeMWKomGIf`0;omGIf`03o`000?oHl>;of?3R00Cof?3R
00?o0000on[Wc?oZil`00_oZil`00ol0003oj?S=onShc@04onShc@04o`000?oEolGoeOo5omGoa@?o
00006_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo013ooooo000Vooooo`03o`00
0?oooooooooo05Gooooo00?o0000oibikOnL^Nd03?nL^Nd00ol0003oMJceogF/m@09ogF/m@03o`00
0?lmUO7o?IGa00Ko?IGa1Ol000000ol0JmSo0000o`000002o`000003o`1HcOl0003o05_>00;o0000
0_l=JM`00ol0003o<7kWoc1ni`07oc1ni`Co00002OmeTN400ol0003oUIoKoiFOf`0=oiFOf`04o`00
0?n_Z]?o0000o`00017o];gP00?o0000olg4d_o=a=801?o=a=800ol0003oeMWKomGIf`0;omGIf`03
o`000?oHl>;of?3R00Kof?3R0_l000000ooZilco0000onShc@05onShc@04o`000?oEolGoeOo5omGo
a@;o00007Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo013ooooo000Wooooo`03
o`000?oooooooooo05Gooooo00?o0000oibikOnL^Nd02_nL^NdBo`0000Ko?IGa0_l000002Ol0Lm_o
0000o`000?l0JmSo0000o`1A`Ol0003o05S=o`000002o`1KcP;o000000?o3FWLo`000?l`O^L01ol`
O^L01?l0003oHIW^of6Ik_mQVNh5o`0000GoMI7Q00?o0000oiFOfonEWm/02OnEWm/5o`0001Co];gP
00?o0000olg4d_o=a=800_o=a=800ol0003oeMWKomGIf`0;omGIf`03o`000?oHl>;of?3R00Sof?3R
1Ol00003onShc@03o`000?oEolGo000000?o00007_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00oooooo000Xooooo`03o`000?oooooooooo05Gooooo00?o0000oibikOnL^Nd01OnL
^Nd4o`0000CoW[[]00?o0000ogjam?mn/O@02Omn/O@00ol0003oCZ7fo`000006o`000004ocfElOl0
003o07?Ko`1cf`?o000000Co0571o`000?l0003o00000ol0Flh3o`0000So<7kW00?o0000of6Ik_mQ
VNh01OmQVNh6o`0000CoUIoK1ol00004oi6_j`03o`000?nd_N3o];gP01;o];gP00Go0000olg4d_o=
a=;ocLCBo`00000=omGIf`03o`000?oHl>;of?3R00Sof?3R00?o0000olOofoo7om/00oo7om/7o`00
027ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0?ooooo`00:Oooool2o`0005Ko
oooo00?o0000oibikOnL^Nd01?l00009oijjk@03o`000?mn/OCoO[7d00WoO[7d00?o0000odjQm_m>
XOH01Om>XOH5o`0000;o07?K0_l000000ol0DL7o0000o`000004o`1KcP;o00002?l`O^L00ol0003o
HIW^of6IkP09of6IkPGo00003?nA[n/00ol0003o];gPokBmh00BokBmh003o`000?o=a=;o000000co
eMWK0_l0000:omS`hP03o`000?o7om_oaooK00CoaooK00?o0000oi;Z]?nBj[@00_l0000Tooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool03oooool002_ooooo00?o0000ooooooooool0
E?ooool2o`0000koW[[]00?o0000ogjam?mn/O@02Omn/O@2o`0000WoCZ7f1?l000001?l0Lm_o0000
o`000?l0DL42o`0000Co05_>0_l00007oc1ni`03o`000?mQVNkoHIW^00WoHIW^00?o0000oi6_jonA
[n/03_nA[n/00ol0003o];gPokBmh00AokBmh0?o00002ooEfM/00ol0003of?3RomS`hP09omS`hP03
o`000?o7om_oaooK00CoaooK00Co0000oi;Z]?nBj[Co00009oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00oooooo000/ooooo`03o`000?oooooooooo05Gooooo00?o0000oijjkOnN
^^d03?nN^^d00ol0003oO[7dogjam00:ogjam003o`000?m>XOKoCZ7f00OoCZ7f0_l000000ol?QNCo
0000o`000003o`000003o`1A`Ol0003o000000Co05_>0ol00005oc1ni`03o`000?mQVNkoHIW^00Wo
HIW^00?o0000oi6_jonA[n/03_nA[n/00ol0003o];gPokBmh00>okBmh0;o00000ongeNl00ol0003o
eMWKomGIf`07omGIf`03o`000?oHl>;of?3R00Sof?3R0_l00005olOof`;o000000?oT^Zdo`000?l0
0000:?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00oooooo000]ooooo`03o`00
0?oooooooooo05Gooooo00?o0000oijjkOnN^^d03?nN^^d00ol0003oO[7dogjam00:ogjam003o`00
0?m>XOKoCZ7f00SoCZ7f00Co0000o`n5i?l?QNCo3hGT1ol00003o`1KcP04o`000?l3M=ko0000o`00
00?o<7kW00?o0000of6Ik_mQVNh02_mQVNh00ol0003oTJo[oi6_j`0>oi6_j`03o`000?nd_N3o];gP
00_o];gP0_l00006okOEk`03o`000?oEfM_oeMWK00GoeMWK00?o0000omS`h_oHl>802?oHl>800ol0
003oaooKolOof`04olOof`04o`000?nBj[Co0000o`0002_ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0?ooooo`00;_ooool00ol0003oooooooooo`1Eooooo`03o`000?nN^^goW[[]
00coW[[]00?o0000ogjam?mn/O@01?mn/O@=o`0000CoCZ7f00?o0000o`n5i?l?QN@00ol?QN@6o`00
00;o05_>00?o0000o`=dg_l3M=h00_l00002oc1ni`03o`000?mQVNkoHIW^00[oHIW^00?o0000oi6_
jonA[n/03OnA[n/00ol0003o];gPokBmh008okBmh0?o00002OngeNl00ol0003oeMWKomGIf`03omGI
f`03o`000?oHl>;of?3R00Sof?3R00?o0000olOofoo7om/00oo7om/2o`000003oi;Z]?l0003ooooo
02gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0?ooooo`00;oooool2o`0005Ko
oooo00?o0000oijjkOnN^^d02_nN^^d8o`0000SoR;Gc00?o0000ofF^nOmU[_T00_mU[_T8o`0000Co
3hGT1_l000000ol0Flko0000o`=dgP02o`=dgPCo00003?mQVNh00ol0003oTJo[oi6_j`0=oi6_j`03
o`000?nd_N3o];gP00Go];gP0_l0000=okOEk`05o`000?oEfM_oeMWKomGIfol000002_oHl>800ol0
003oaooKolOof`03olOof`04o`000?nBj[Co0000o`0002oooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0>ooooo`00<Oooool00ol0003oooooooooo`1Dooooo`03o`000?nN^^goW[[]
00GoW[[]1?l00003oj2kk003o`000?n8]O?oR;Gc00_oR;Gc00?o0000ofF^nOmU[_T02?mU[_T6o`00
0003o`n5i?l0003o000000Go00001Ol3M=h2o`0000_oHIW^00?o0000oi6_jonA[n/03_nA[n/00ol0
003o];gPokBmh002okBmh0;o00004?ngeNl00ol0003oeMWKo`000009omS`hP;o00001Oo7om/00ol0
003oT^Zdo`00000booooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03_ooool003;o
oooo00?o0000ooooooooool0E?ooool00ol0003oW[[]oijjk@04o`0000SoX;_/00?o0000ohRelon8
]O<02on8]O<00ol0003oIJkiofF^n@08ofF^n@;o00000ol_W_49o`0000Ko0gCN1?l00008of6IkP03
o`000?nA[n_oTJo[00koTJo[00Co0000okBmh?l0003o00004_ngeNl3o`0000Sof?3R00?o0000olOo
foo7om/00oo7om/4o`0003Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0>oooo
o`00<oooool00ol0003oooooooooo`1Dooooo`;o00003OnP^n`00ol0003oR;GcohRel`0;ohRel`03
o`000?mU[_WoIJki00WoIJki00?o0000obnNlOl_W_401?l_W_47o`0000Ko0gCN00?o0000ocjMm?l0
00001?l00004of6IkP03o`000?nA[n_oTJo[00[oTJo[1_l0000AokOEk`;o00000on]k_P3o`0000Co
f?3R00?o0000olOofoo7om/00oo7om/3o`0003Oooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0>ooooo`00=?ooool2o`0005Gooooo00?o0000oj2kk?nP^n`03?nP^n`00ol0003oR;Gc
ohRel`0;ohRel`03o`000?mU[_WoIJki00WoIJki00?o0000obnNlOl_W_401ol_W_46o`0000Co0gCN
00?o0000ocjMm?lnWO@00olnWO@6o`0000CoTJo[1ol00006oh?3o003o`000?ngeNoo]mG_00co]mG_
0_l00008ojg^n0;o000000?of?3Ro`000?o7om/01?o7om/2o`0003Wooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0>ooooo`00=_ooool00ol0003oooooooooo`1Cooooo`03o`000?nP
^ncoX;_/00coX;_/00?o0000ohRelon8]O<02?n8]O<Qo`0000;o0gCN0_l00008ocjMm0Go00003_n3
`o`00ol0003o]mG_okOEk`08okOEk`?o00002on]k_P8o`0003cooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0>ooooo`00=oooool00ol0003oooooooooo`1Cooooo`03o`000?nP^nco
X;_/00coX;_/00Co0000ohRelon8]O?oR;Gc1_l00005oiBjl@03o`000?mn^o[oO[_j00WoO[_j0_l0
000;oeVio0;o000000Ko06;0o`000?l0003o0000o`=dg_l0000:ocjMm003o`000?n3`ocoPl?l00ko
Pl?l00?o0000okOEkongeNl01OngeNl2o`0000co[Nkh0_l00003ogoXf`?o0000?oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00kooooo000hooooo`03o`000?oooooooooo05?ooooo
00?o0000oj2kk?nP^n`02_nP^n`5o`0000coU;[a0_l0000;ogjknP03o`000?mI^OcoFKWl00WoFKWl
0ol00002o`1R`0?o00002_lnWO@00ol0003oPl?loh?3o00>oh?3o003o`000?ngeNoo]mG_00;o]mG_
0_l0000<ojg^n0;o00000omoj=/2o`0004?ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0>ooooo`00>Oooool2o`0005Cooooo00?o0000oj2kk?nP^n`01OnP^n`4o`0000CoXkc[00?o
0000oiBjlOnD^_403?nD^_400ol0003oO[_jogjknP09ogjknP;o00000omI^O`6o`0000?oP/go0ol0
0002o`1R`0Co00001olnWO@2o`0000ooPl?l00Co0000okOEkol0003o00002on]k_P3o`0000?oOnSK
0_l00015ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03Oooool003_ooooo00?o
0000ooooooooool0D_ooool00ol0003oX;_/oj2kk004o`0000WoXkc[00?o0000oiBjlOnD^_403?nD
^_400ol0003oO[_jogjknP04ogjknPWo00003?n2cOl3o`000003o`1R`?l0003o000000Go00001?ln
WO@00ol0003oPl?loh?3o00:oh?3o0Go00002_n]k_P2o`0000?oOnSK0ol00018ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool03Oooool003cooooo00?o0000ooooooooool0D_ooool2
o`0000koXkc[00?o0000oiBjlOnD^_402_nD^_48o`0000SoULCg0ol00007oh;=o`?o00000oooool4
o`0000Co2i7M1_l00004oh?3o0Oo00001OmOc?T3o`0000Go[Nkh0_l00003ogoXf`;o0000C?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo000mooooo`03o`000?oooooooooo
05?ooooo00?o0000oj>ljonS_>/03?nS_>/00ol0003oU;[aoiBjl@05oiBjl@Co00001?nO_Nh00ol0
003oULCgoiG4m`0<oiG4m`;o00000_n2cOl3o`0000Wooooo0ol00007o`^Ag@Go00003omOc?T2o`00
0004ojg^n?l0003o0000ogoXf`Co0000C_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00gooooo000nooooo`;o0000E?ooool00ol0003oXkc[oj>lj`0<oj>lj`03o`000?nD^_7oU;[a
00Co00002OnO_Nh00ol0003oULCgoiG4m`0<oiG4m`?o00003oooool5o`0000Go2i7M0ol0000=oeo<
n@Oo0000Doooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo0010ooooo`03
o`000?oooooooooo05;ooooo00?o0000oj>ljonS_>/02_nS_>/4o`0000koWkg^00?o0000oiG4monE
a?L02?nEa?L3o`0001Oooooo1ol000000ol;TMgo0000o`000004oeo<n@Oo0000Foooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00gooooo0011ooooo`03o`000?oooooooooo05;ooooo
00?o0000oj>ljonS_>/01OnS_>/4o`0000CoY[cY00?o0000oinmk_nO_Nh03?nO_Nh00ol0003oULCg
oiG4m`04oiG4m`?o00008Oooool7o`0006?ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0=ooooo`00@_ooool00ol0003oooooooooo`1Booooo`03o`000?nS_>_oXkc[00Co00002OnV
_>T00ol0003oWkg^oinmkP0<oinmkP03o`000?nEa?OoULCg00?o0000S_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo0013ooooo`03o`000?oooooooooo05;ooooo0_l0000>
ojJlj@03o`000?nO_NkoWkg^00[oWkg^1?l0002Booooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool004Cooooo0_l0001Cooooo`03o`000?nV_>WoY[cY00goY[cY00?o0000oinm
k_nO_Nh01OnO_Nh4o`0009Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<oooo
o`00A_ooool00ol0003oooooooooo`1Aooooo`03o`000?nV_>WoY[cY00goY[cY00?o0000oinmk_nO
_Nh01?l0002Kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool004Oooooo
00?o0000ooooooooool0DOooool00ol0003oY[cYojJlj@0<ojJlj@?o0000X?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00cooooo0018ooooo`03o`000?oooooooooo057ooooo00?o
0000ojJljOnV_>T02?nV_>T3o`000:Cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0<ooooo`00BOooool2o`0005;ooooo00?o0000ojJljOnV_>T01?nV_>T3o`000:Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0<ooooo`00Boooool00ol0003oooooooooo`1@oooo
o`03o`000?nV_>WoY[cY00?o0000Zoooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00_ooooo001<ooooo`03o`000?oooooooooo053ooooo0_l0002_ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02oooool004gooooo00?o0000ooooooooool0Coooool00ol0003ooooo
ooooo`2_ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool004kooooo0_l0
001?ooooo`03o`000?oooooooooo0;3ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0;ooooo`00D?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo0;3ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`00DOooool00ol0003oooooooooo`1;oooo
o`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;oooo
o`00D_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0;ooooo`00Doooool2o`0004[ooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo001Eooooo`03o`000?oo
oooooooo04Oooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00[ooooo001Fooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0]?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo001Gooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool0]Oooool01Ol0003ooooooooooooooooo000000cooooo001Hoooo
o`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0]Oooool01Ol0003ooooooooooooooooo
000000cooooo001Iooooo`;o0000A?ooool00ol0003oooooooooo`2fooooo`04o`000?oooooooooo
o`0000cooooo001Kooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0]oooool00ol0
003oooooo`00000<ooooo`00G?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo0;Oo
oooo00Co0000oooooooooooo00002oooool005gooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`2hooooo`03o`000?oooooo000000_ooooo001Nooooo`;o0000?oooool00ol0003ooooo
ooooo`2iooooo`;o00002oooool0063ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2iooooo`?o00002oooool0067ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`2e
ooooo`Co00003_ooool006;ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`2aoooo
o`Co00004_ooool006?ooooo0_l0000iooooo`03o`000?oooooooooo0:kooooo0ol0000Fooooo`00
IOooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo0:[ooooo1?l0000Iooooo`00I_oo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo0:Kooooo1?l0000Mooooo`00Ioooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo0:;ooooo1?l0000Qooooo`00J?ooool2o`00
03Cooooo00?o0000ooooooooool0W_ooool4o`0002Gooooo001Zooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool0Voooool3o`0002Wooooo001[ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0Uoooool4o`0002cooooo001/ooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0Toooool4o`00033ooooo001]ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0Soooool4o`0003Cooooo001^ooooo`;o0000;_ooool00ol0003oooooooooo`2;oooo
o`Co0000>?ooool0073ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`27ooooo`Co
0000??ooool0077ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`24ooooo`?o0000
@?ooool007;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`20ooooo`Co0000@ooo
ool007?ooooo0_l0000Yooooo`03o`000?oooooooooo07cooooo1?l00017ooooo`00MOooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo07Sooooo1?l0001;ooooo`00M_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo07Cooooo1?l0001?ooooo`00Moooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo077ooooo0ol0001Cooooo`00N?ooool2o`0002Cooooo00?o
0000ooooooooool0KOooool4o`0005Kooooo001jooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0JOooool4o`0005[ooooo001kooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0IOooool4o`0005kooooo001looooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool0HOooool4o`0006;ooooo001mooooo`;o00007oooool00ol0003oooooooooo`1Mooooo`Co0000
I_ooool007oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Jooooo`?o0000J_oo
ool0083ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Fooooo`Co0000KOooool0
087ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Booooo`Co0000LOooool008;o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1>ooooo`Co0000MOooool008?ooooo
0_l0000Iooooo`03o`000?oooooooooo04[ooooo1?l0001iooooo`00QOooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04Kooooo1?l0001mooooo`00Q_ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo04?ooooo0ol00021ooooo`00Qoooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo03oooooo1?l00024ooooo`00R?ooool2o`0001Cooooo00?o0000oooooooo
ool0>oooool4o`0008Sooooo002:ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
>?ooool4o`0008cooooo002;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=?oo
ool4o`00093ooooo002<ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0<Oooool3
o`0009Cooooo002=ooooo`;o00003_ooool00ol0003oooooooooo`0]ooooo`Co0000Uoooool008oo
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Yooooo`Co0000Voooool0093ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Uooooo`Co0000Woooool0097ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`Co0000Xoooool009;ooooo0_l00009
ooooo`03o`000?oooooooooo01gooooo1?l0002Wooooo`00U?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01[ooooo0ol0002[ooooo`00UOooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Kooooo1?l0002^ooooo`00U_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01;ooooo1?l0002booooo`00Uoooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00kooooo1?l0002fooooo`00V?ooool2o`0000?ooooo00?o0000ooooooooool02_ooool4
o`000;[ooooo002Jooooo`04o`000?ooooooooooo`0000Wooooo0ol0002nooooo`00Voooool00ol0
003oooooo`000005ooooo`Co0000`Oooool009cooooo0_l000000ooooooo0000o`000002o`000<Go
oooo002Mooooo`;o0000bOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00<Gooooo0ol000000ol@413oooooooooo`2Mooooo`00Yoooool00ol0003ogMgMoooo
o`08ooooo`;o00002oooool00ol0003o^[Zjooooo`05ooooo`03oa0@4?nj^[[ooooo00Cooooo0_l0
002Hooooo`00Yoooool00olb<S;o^[Zjooooo`08ooooo`03o`000?oooooooooo00[ooooo0_lb<S86
ooooo`03oiRHV?lb<S;ooooo00Gooooo00?o0000ooooooooool0U_ooool00:Oooooo00KoMgMgohN7
Qom4A4Co0000oa0@4?n7QhL5ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00000_oo
ool00on7QhOo0000okZj^P05ooooo`03omgMgOl0003o^[Zj00Gooooo00?o0000ooooooooool0U_oo
ool00:Oooooo00OoZJVYo`000?nj^[[oooooomgMgOlQ8B7oQhN700Cooooo00?o0000ooooooooool0
0_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41001Oooool00omE
EEGoMgMgodA4A005ooooo`03o`000?oooooooooo09Kooooo002Wooooo`03omgMgOl@413ooooo00;o
oooo00?ogMgMoa0@4?ooool00oooool00ol0003oooooooooo`03ooooo`04omgMgOl0003o410@olc<
c0[ooooo00GogMgMoa0@4?oooooo8B4QomgMg@04ooooo`03o`000?oooooooooo09Kooooo002Xoooo
o`03oa0@4?oMgMgooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`04onk^k_lQ8B7o410@onk^kP[ooooo00GoIVIVohN7QoooooooV9RHoeEEE@04ooooo`03o`000?oo
oooooooo09Kooooo002Xooooo`06ohN7QolQ8B7ogMgMoooooomgMgOo<S8b1?ooool00ol0003ooooo
ooooo`03ooooo`04ob4Q8OmgMgOoMgMgoc8b<PWooooo00?ok^k^o`000?o^k^h00_ooool00ol0003o
gMgMooooo`02ooooo`03o`000?oooooooooo09Kooooo002Yooooo`05ogMgMol0003o0000oc8b<_o<
c<`01?ooool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000Sooooo00Co410@o`000?l0
003ooooo0_l000001Ol@413ooooooooooooooooo000009Sooooo002booooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0U_ooool00;;ooooo0_l0000Jooooo`;o0000V?ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0939778, 0.020481, \
0.0037547, 0.0037547}}]
}, Open  ]],

Cell[TextData[{
  "\tWe now create a matrix with elements ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(j\ k\)\)]],
  ", and convert the matrix to approximate numbers in order to assure that no \
exact arithmetic is attempted in what follows:"
}], "Text"],

Cell[BoxData[
    \(\(\[Rho]matrix = 
        Table[\[Rho][j\ \[CapitalDelta]x, k\ \[CapitalDelta]y], {j, 0, 
              M\_x - 1}, {k, 0, M\_y - 1}]\  // N;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.123"],

Cell[TextData[{
  "We next determine the Fourier coefficient matrix, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\&~\_\(m\ n\)\)]],
  ",",
  " using an FFT:"
}], "Text"],

Cell[BoxData[
    \(\(\[Rho]ft = Fourier[\[Rho]matrix];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.124"],

Cell[TextData[{
  "The (1,1) element of this matrix corresponds to the ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0, n = 0\)]],
  " term, and should be zero:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Rho]ft[\([1, 1]\)]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.125"],

Cell[BoxData[
    \(\(-0.006666008589945491`\) + 0.`\ \[ImaginaryI]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This element is not quite zero because of the discretization of the charge \
density: the discrete Fourier transform is not exactly the same as the \
integral of the charge over the rectangular domain, although it is close for \
large ",
  Cell[BoxData[
      \(TraditionalForm\`M\_x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`M\_y\)]],
  ". Therefore, we simply set this term equal to zero directly:"
}], "Text"],

Cell[BoxData[
    \(\(\[Rho]ft[\([1, 1]\)] = 0;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.126"],

Cell[TextData[{
  "Now we define the factor by which we are to divide ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\&~\_\(m\ n\)\)]],
  " [see Eq. ",
  ButtonBox["(6.2.43)",
    ButtonData:>"(6.2.43)",
    ButtonStyle->"Hyperlink"],
  " ]:"
}], "Text"],

Cell[BoxData[{
    \(\(factor[m_, 
          n_]\  := \(-\ \((\(4\/\[CapitalDelta]x\^2\) 
                Sin[\[Pi]\ m/M\_x]^2 + \(4\/\[CapitalDelta]y\^2\) 
                Sin[\[Pi]\ n/M\_y]^2\ )\)\);\)\), "\n", 
    \(\(factor[0, 0] = 1;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.127"],

Cell[TextData[{
  "This factor is defined so that we may safely divide by it without getting \
an error when ",
  Cell[BoxData[
      \(TraditionalForm\`m = \(n = 0\)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(\[Phi]\&~ = 
        Table[\[Rho]ft[\([m + 1, n + 1]\)]/factor[m, n], {m, 0, 
            M\_x - 1}, {n, 0, M\_y - 1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.128"],

Cell[TextData[{
  "Finally, we obtain the potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(j\ k\)\)]],
  " at the grid points ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ j \[LessEqual] \ M\_x - 1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ \ k\  \[LessEqual] \ M\_y - 1\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(\[Phi]matrix\  = \ InverseFourier[\[Phi]\&~];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.129"],

Cell["\<\
\t It is enlightening to compare the time required to complete \
these operations with that required by the direct solution method, or the \
relaxation methods for the same fine grid.  The reader is invited to evaluate \
these methods, which should provide convincing proof of the efficacy of the \
FFT method for this rectangular geometry.  \
\>", "Text"],

Cell[TextData[{
  "\tWe can create an interpolation of the matrix ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]matrix\)],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " by first adding to the data the corresponding ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(,\)\(y\)\(\ \)\)\)]],
  "positions for each grid point, and then interpolating the resulting data \
list:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Phi]\  = \ 
        Table[{j\ \[CapitalDelta]x, \ 
            k\ \[CapitalDelta]y, \ \[Phi]matrix[\([j + 1, k + 1]\)]}, {j, 0, 
            M\_x - 1}, {k, 0, M\_y - 1}];\)\), "\n", 
    \(\[Phi]sol\  = \ Interpolation[Flatten[\[Phi], 1]]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.130"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.`, 0.98`}, {0.`, 0.98`}}, "<>"]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "This function is defined only in the square from 0 to 0.98, rather than \
from 0 to 1, because of the discretization.  If we wished, we could use the \
periodicity of the system to extend the result to the entire ",
  Cell[BoxData[
      \(TraditionalForm\`x - y\)]],
  " plane."
}], "Text"],

Cell[TextData[{
  "The solution is plotted in Cell ",
  ButtonBox["6.131",
    ButtonData:>"Cell 6.131",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot3D[\[Phi]sol[x, y], {x, 0,  .98}, {y, 0,  .98}, 
        PlotLabel \[Rule] "\<\[Phi](x,y)\>", 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.131"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.1978e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -20 0 ]
[.5 .82364 20 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14845 .1986 -17.8706 -9 ]
[.14845 .1986 .12936 0 ]
[.27533 .14869 -17.1047 -9 ]
[.27533 .14869 .89525 0 ]
[.40865 .09626 -16.3389 -9 ]
[.40865 .09626 1.66114 0 ]
[.54892 .04112 -15.573 -9 ]
[.54892 .04112 2.42702 0 ]
[.29165 .07573 -9.31117 -12 ]
[.29165 .07573 .68883 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76874 .09901 0 -6.15994 ]
[.76874 .09901 18 2.84006 ]
[.83048 .19354 0 -6.06902 ]
[.83048 .19354 18 2.93098 ]
[.88694 .28 0 -5.98753 ]
[.88694 .28 18 3.01247 ]
[.93877 .35938 0 -5.91409 ]
[.93877 .35938 18 3.08591 ]
[.91861 .21225 0 -8.04169 ]
[.91861 .21225 10 3.95831 ]
[.01531 .32029 -36 -2.78898 ]
[.01531 .32029 0 6.21102 ]
[.00397 .39137 -6 -2.84932 ]
[.00397 .39137 0 6.15068 ]
[-0.0079 .46575 -30 -2.91276 ]
[-0.0079 .46575 0 6.08724 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(L) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.15767 .20795 m
.16227 .21262 L
s
[(0.2)] .14845 .1986 .98563 1 Mshowa
.28411 .15844 m
.2885 .16331 L
s
[(0.4)] .27533 .14869 .90053 1 Mshowa
.41694 .10643 m
.42109 .11151 L
s
[(0.6)] .40865 .09626 .81543 1 Mshowa
.55666 .05172 m
.56052 .05702 L
s
[(0.8)] .54892 .04112 .73033 1 Mshowa
.125 Mabswid
.06675 .24355 m
.0696 .24627 L
s
.0967 .23182 m
.09952 .23457 L
s
.127 .21996 m
.12979 .22273 L
s
.1887 .1958 m
.19144 .19863 L
s
.22012 .1835 m
.22282 .18636 L
s
.25192 .17104 m
.25459 .17394 L
s
.3167 .14568 m
.3193 .14863 L
s
.3497 .13276 m
.35226 .13575 L
s
.38311 .11967 m
.38563 .12269 L
s
.4512 .09301 m
.45365 .09609 L
s
.4859 .07942 m
.48831 .08254 L
s
.52105 .06566 m
.52342 .06881 L
s
.59272 .0376 m
.595 .04081 L
s
.62926 .02329 m
.63149 .02653 L
s
.66629 .00879 m
.66847 .01207 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75643 .10355 m
.75028 .10582 L
s
[(0.2)] .76874 .09901 -1 .36888 Mshowa
.81809 .19786 m
.81189 .20002 L
s
[(0.4)] .83048 .19354 -1 .34867 Mshowa
.87448 .28412 m
.86825 .28618 L
s
[(0.6)] .88694 .28 -1 .33056 Mshowa
.92625 .36331 m
.91999 .36528 L
s
[(0.8)] .93877 .35938 -1 .31424 Mshowa
.125 Mabswid
.70627 .02683 m
.7026 .02824 L
s
.72339 .05301 m
.71971 .05441 L
s
.74011 .07858 m
.73642 .07996 L
s
.77238 .12795 m
.76868 .12929 L
s
.78796 .15178 m
.78426 .15311 L
s
.8032 .17508 m
.79948 .1764 L
s
.83265 .22014 m
.82893 .22142 L
s
.8469 .24193 m
.84317 .2432 L
s
.86084 .26326 m
.85711 .26451 L
s
.88783 .30455 m
.88409 .30577 L
s
.90091 .32455 m
.89716 .32575 L
s
.91371 .34413 m
.90996 .34532 L
s
.93854 .38211 m
.93478 .38328 L
s
.95058 .40053 m
.94681 .40168 L
s
.96238 .41858 m
.95861 .41972 L
s
gsave
.91861 .21225 -61 -12.0417 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02757 .31563 m
.03371 .31329 L
s
[(-0.005)] .01531 .32029 1 -0.38023 Mshowa
.01629 .38685 m
.02245 .38459 L
s
[(0)] .00397 .39137 1 -0.36682 Mshowa
.00448 .46139 m
.01066 .4592 L
s
[(0.005)] -0.0079 .46575 1 -0.35272 Mshowa
.125 Mabswid
.02536 .32962 m
.02904 .32823 L
s
.02312 .34373 m
.02681 .34235 L
s
.02086 .35798 m
.02455 .3566 L
s
.01859 .37235 m
.02228 .37098 L
s
.01397 .40149 m
.01767 .40014 L
s
.01163 .41626 m
.01533 .41492 L
s
.00927 .43116 m
.01297 .42983 L
s
.00688 .4462 m
.01059 .44488 L
s
.02977 .30176 m
.03345 .30035 L
s
.03195 .28801 m
.03562 .2866 L
s
.03411 .27439 m
.03778 .27296 L
s
.03625 .26088 m
.03992 .25945 L
s
.00205 .47671 m
.00576 .47541 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.554 .684 .926 r
.3752 .77366 .39834 .7978 .43696 .79532 .41405 .77169 Metetra
.654 .725 .901 r
.41405 .77169 .43696 .79532 .47643 .78485 .45384 .7606 Metetra
.716 .738 .869 r
.45384 .7606 .47643 .78485 .51649 .76687 .49429 .74121 Metetra
.748 .737 .842 r
.49429 .74121 .51649 .76687 .55692 .74311 .53512 .71551 Metetra
.76 .73 .825 r
.53512 .71551 .55692 .74311 .59759 .71607 .57618 .68629 Metetra
.757 .718 .816 r
.57618 .68629 .59759 .71607 .63848 .68858 .61742 .65664 Metetra
.74 .704 .817 r
.61742 .65664 .63848 .68858 .67972 .66343 .65897 .62959 Metetra
.711 .685 .823 r
.65897 .62959 .67972 .66343 .72151 .64296 .70104 .60771 Metetra
.669 .663 .835 r
.70104 .60771 .72151 .64296 .76417 .62881 .74397 .5928 Metetra
.616 .637 .848 r
.74397 .5928 .76417 .62881 .80801 .62167 .7881 .58565 Metetra
.557 .61 .861 r
.7881 .58565 .80801 .62167 .85329 .62108 .83373 .58587 Metetra
.503 .589 .873 r
.83373 .58587 .85329 .62108 .9001 .62534 .88101 .5917 Metetra
.473 .585 .886 r
.88101 .5917 .9001 .62534 .94833 .63149 .92983 .59993 Metetra
.485 .609 .9 r
.92983 .59993 .94833 .63149 .99755 .63554 .97974 .60602 Metetra
.553 .643 .893 r
.35174 .74396 .3752 .77366 .41405 .77169 .39073 .74308 Metetra
.657 .692 .871 r
.39073 .74308 .41405 .77169 .45384 .7606 .43081 .73121 Metetra
.719 .708 .839 r
.43081 .73121 .45384 .7606 .49429 .74121 .47162 .70967 Metetra
.748 .705 .812 r
.47162 .70967 .49429 .74121 .53512 .71551 .51283 .68093 Metetra
.756 .694 .793 r
.51283 .68093 .53512 .71551 .57618 .68629 .55422 .64824 Metetra
.75 .679 .782 r
.55422 .64824 .57618 .68629 .61742 .65664 .59573 .61518 Metetra
.731 .659 .779 r
.59573 .61518 .61742 .65664 .65897 .62959 .63746 .58518 Metetra
.701 .637 .781 r
.63746 .58518 .65897 .62959 .70104 .60771 .67967 .56117 Metetra
.661 .611 .788 r
.67967 .56117 .70104 .60771 .74397 .5928 .72271 .5452 Metetra
.611 .584 .798 r
.72271 .5452 .74397 .5928 .7881 .58565 .76701 .53828 Metetra
.556 .557 .81 r
.76701 .53828 .7881 .58565 .83373 .58587 .8129 .54007 Metetra
.503 .537 .824 r
.8129 .54007 .83373 .58587 .88101 .5917 .86062 .5487 Metetra
.47 .533 .84 r
.86062 .5487 .88101 .5917 .92983 .59993 .91006 .56054 Metetra
.478 .56 .86 r
.91006 .56054 .92983 .59993 .97974 .60602 .96073 .5701 Metetra
.541 .619 .88 r
.32792 .71103 .35174 .74396 .39073 .74308 .36698 .71142 Metetra
.659 .677 .856 r
.36698 .71142 .39073 .74308 .43081 .73121 .40734 .69877 Metetra
.724 .695 .823 r
.40734 .69877 .43081 .73121 .47162 .70967 .44852 .67487 Metetra
.753 .694 .795 r
.44852 .67487 .47162 .70967 .51283 .68093 .49011 .64273 Metetra
.761 .683 .776 r
.49011 .64273 .51283 .68093 .55422 .64824 .53185 .60618 Metetra
.754 .667 .766 r
.53185 .60618 .55422 .64824 .59573 .61518 .57361 .56933 Metetra
.734 .647 .763 r
.57361 .56933 .59573 .61518 .63746 .58518 .61552 .53608 Metetra
.703 .624 .766 r
.61552 .53608 .63746 .58518 .67967 .56117 .65782 .50973 Metetra
.66 .596 .773 r
.65782 .50973 .67967 .56117 .72271 .5452 .70094 .49265 Metetra
.606 .566 .783 r
.70094 .49265 .72271 .5452 .76701 .53828 .74533 .48603 Metetra
.544 .535 .795 r
.74533 .48603 .76701 .53828 .8129 .54007 .79143 .4896 Metetra
.484 .509 .808 r
.79143 .4896 .8129 .54007 .86062 .5487 .83952 .50134 Metetra
.444 .501 .823 r
.83952 .50134 .86062 .5487 .91006 .56054 .88954 .51716 Metetra
.452 .528 .845 r
.88954 .51716 .91006 .56054 .96073 .5701 .94092 .5305 Metetra
.523 .611 .882 r
.30362 .67732 .32792 .71103 .36698 .71142 .34274 .6789 Metetra
.662 .677 .854 r
.34274 .6789 .36698 .71142 .40734 .69877 .38337 .66552 Metetra
.732 .697 .817 r
.38337 .66552 .40734 .69877 .44852 .67487 .42494 .6394 Metetra
.763 .697 .788 r
.42494 .6394 .44852 .67487 .49011 .64273 .46697 .60407 Metetra
.772 .687 .77 r
.46697 .60407 .49011 .64273 .53185 .60618 .5091 .5639 Metetra
.765 .673 .761 r
.5091 .5639 .53185 .60618 .57361 .56933 .55119 .52349 Metetra
.745 .654 .76 r
.55119 .52349 .57361 .56933 .61552 .53608 .59331 .4872 Metetra
.711 .63 .765 r
.59331 .4872 .61552 .53608 .65782 .50973 .63576 .45868 Metetra
.664 .601 .775 r
.63576 .45868 .65782 .50973 .70094 .49265 .67897 .44055 Metetra
.601 .567 .788 r
.67897 .44055 .70094 .49265 .74533 .48603 .72346 .43417 Metetra
.528 .529 .8 r
.72346 .43417 .74533 .48603 .79143 .4896 .76974 .43933 Metetra
.454 .495 .812 r
.76974 .43933 .79143 .4896 .83952 .50134 .81814 .45387 Metetra
.404 .481 .825 r
.81814 .45387 .83952 .50134 .88954 .51716 .86865 .47325 Metetra
.415 .507 .845 r
.86865 .47325 .88954 .51716 .94092 .5305 .92067 .49 Metetra
.499 .615 .898 r
.27866 .64507 .30362 .67732 .34274 .6789 .31786 .64752 Metetra
.665 .689 .863 r
.31786 .64752 .34274 .6789 .38337 .66552 .35878 .63349 Metetra
.743 .71 .821 r
.35878 .63349 .38337 .66552 .42494 .6394 .4008 .60554 Metetra
.777 .711 .79 r
.4008 .60554 .42494 .6394 .46697 .60407 .44332 .56758 Metetra
.787 .704 .772 r
.44332 .56758 .46697 .60407 .5091 .5639 .48592 .52443 Metetra
.781 .691 .765 r
.48592 .52443 .5091 .5639 .55119 .52349 .52842 .48112 Metetra
.761 .675 .767 r
.52842 .48112 .55119 .52349 .59331 .4872 .57088 .44234 Metetra
.726 .653 .777 r
.57088 .44234 .59331 .4872 .63576 .45868 .61356 .41201 Metetra
.672 .624 .792 r
.61356 .41201 .63576 .45868 .67897 .44055 .65694 .39297 Metetra
.598 .585 .809 r
.65694 .39297 .67897 .44055 .72346 .43417 .70159 .3867 Metetra
.506 .537 .823 r
.70159 .3867 .72346 .43417 .76974 .43933 .74805 .39301 Metetra
.411 .491 .831 r
.74805 .39301 .76974 .43933 .81814 .45387 .79674 .40965 Metetra
.349 .467 .839 r
.79674 .40965 .81814 .45387 .86865 .47325 .84768 .43173 Metetra
.366 .496 .857 r
.84768 .43173 .86865 .47325 .92067 .49 .90025 .45103 Metetra
.468 .632 .925 r
.25285 .61598 .27866 .64507 .31786 .64752 .29217 .61887 Metetra
.669 .714 .882 r
.29217 .61887 .31786 .64752 .35878 .63349 .33343 .60431 Metetra
.755 .734 .833 r
.33343 .60431 .35878 .63349 .4008 .60554 .37593 .57502 Metetra
.792 .735 .799 r
.37593 .57502 .4008 .60554 .44332 .56758 .41902 .53523 Metetra
.805 .73 .781 r
.41902 .53523 .44332 .56758 .48592 .52443 .46219 .49002 Metetra
.801 .721 .777 r
.46219 .49002 .48592 .52443 .52842 .48112 .50522 .44469 Metetra
.782 .71 .783 r
.50522 .44469 .52842 .48112 .57088 .44234 .54812 .40417 Metetra
.746 .692 .8 r
.54812 .40417 .57088 .44234 .61356 .41201 .59118 .37254 Metetra
.686 .665 .824 r
.59118 .37254 .61356 .41201 .65694 .39297 .63486 .35276 Metetra
.594 .621 .848 r
.63486 .35276 .65694 .39297 .70159 .3867 .67976 .34639 Metetra
.474 .56 .863 r
.67976 .34639 .70159 .3867 .74805 .39301 .72647 .35328 Metetra
.35 .495 .864 r
.72647 .35328 .74805 .39301 .79674 .40965 .77544 .37109 Metetra
.274 .459 .861 r
.77544 .37109 .79674 .40965 .84768 .43173 .82676 .3947 Metetra
.302 .491 .877 r
.82676 .3947 .84768 .43173 .90025 .45103 .87981 .41547 Metetra
.427 .658 .956 r
.22597 .59113 .25285 .61598 .29217 .61887 .26549 .59395 Metetra
.671 .748 .908 r
.26549 .59395 .29217 .61887 .33343 .60431 .30714 .57896 Metetra
.767 .765 .851 r
.30714 .57896 .33343 .60431 .37593 .57502 .35018 .54895 Metetra
.808 .766 .814 r
.35018 .54895 .37593 .57502 .41902 .53523 .39388 .50823 Metetra
.823 .764 .797 r
.39388 .50823 .41902 .53523 .46219 .49002 .43772 .462 Metetra
.823 .762 .795 r
.43772 .462 .46219 .49002 .50522 .44469 .48139 .41567 Metetra
.807 .758 .807 r
.48139 .41567 .50522 .44469 .54812 .40417 .52489 .37425 Metetra
.77 .749 .834 r
.52489 .37425 .54812 .40417 .59118 .37254 .56847 .34188 Metetra
.701 .728 .871 r
.56847 .34188 .59118 .37254 .63486 .35276 .6126 .32156 Metetra
.585 .681 .907 r
.6126 .32156 .63486 .35276 .67976 .34639 .65787 .31488 Metetra
.422 .6 .919 r
.65787 .31488 .67976 .34639 .72647 .35328 .70492 .32168 Metetra
.259 .506 .9 r
.70492 .32168 .72647 .35328 .77544 .37109 .75421 .33961 Metetra
.172 .453 .881 r
.75421 .33961 .77544 .37109 .82676 .3947 .80589 .36347 Metetra
.223 .492 .898 r
.80589 .36347 .82676 .3947 .87981 .41547 .85939 .38444 Metetra
.379 .687 .979 r
.19783 .57086 .22597 .59113 .26549 .59395 .23765 .5731 Metetra
.67 .788 .937 r
.23765 .5731 .26549 .59395 .30714 .57896 .27975 .5578 Metetra
.776 .801 .873 r
.27975 .5578 .30714 .57896 .35018 .54895 .32336 .52768 Metetra
.821 .803 .834 r
.32336 .52768 .35018 .54895 .39388 .50823 .36773 .48698 Metetra
.84 .805 .817 r
.36773 .48698 .39388 .50823 .43772 .462 .41229 .44083 Metetra
.843 .81 .818 r
.41229 .44083 .43772 .462 .48139 .41567 .45671 .39456 Metetra
.83 .817 .838 r
.45671 .39456 .48139 .41567 .52489 .37425 .50094 .35311 Metetra
.792 .822 .876 r
.50094 .35311 .52489 .37425 .56847 .34188 .5452 .32058 Metetra
.71 .812 .928 r
.5452 .32058 .56847 .34188 .6126 .32156 .58994 .29992 Metetra
.556 .76 .973 r
.58994 .29992 .6126 .32156 .65787 .31488 .63574 .29269 Metetra
.334 .645 .967 r
.63574 .29269 .65787 .31488 .70492 .32168 .68323 .29872 Metetra
.13 .511 .911 r
.68323 .29872 .70492 .32168 .75421 .33961 .73293 .31568 Metetra
.048 .444 .875 r
.73293 .31568 .75421 .33961 .80589 .36347 .78498 .33844 Metetra
.133 .496 .906 r
.78498 .33844 .80589 .36347 .85939 .38444 .83891 .35833 Metetra
.334 .711 .983 r
.16829 .55479 .19783 .57086 .23765 .5731 .20851 .55593 Metetra
.662 .825 .961 r
.20851 .55593 .23765 .5731 .27975 .5578 .25111 .54042 Metetra
.779 .837 .897 r
.25111 .54042 .27975 .5578 .32336 .52768 .29531 .5108 Metetra
.828 .84 .857 r
.29531 .5108 .32336 .52768 .36773 .48698 .34038 .47105 Metetra
.85 .848 .84 r
.34038 .47105 .36773 .48698 .41229 .44083 .38572 .42603 Metetra
.856 .862 .844 r
.38572 .42603 .41229 .44083 .45671 .39456 .43097 .38084 Metetra
.843 .881 .868 r
.43097 .38084 .45671 .39456 .50094 .35311 .47604 .3402 Metetra
.798 .899 .914 r
.47604 .3402 .50094 .35311 .5452 .32058 .52112 .30806 Metetra
.691 .896 .971 r
.52112 .30806 .5452 .32058 .58994 .29992 .56662 .28726 Metetra
.482 .823 .998 r
.56662 .28726 .58994 .29992 .63574 .29269 .6131 .27925 Metetra
.202 .659 .944 r
.6131 .27925 .63574 .29269 .68323 .29872 .66118 .28385 Metetra
0 .495 .857 r
.66118 .28385 .68323 .29872 .73293 .31568 .71136 .29879 Metetra
0 .432 .83 r
.71136 .29879 .73293 .31568 .78498 .33844 .76384 .31914 Metetra
.056 .504 .892 r
.76384 .31914 .78498 .33844 .83891 .35833 .8182 .33667 Metetra
.314 .732 .976 r
.1373 .54175 .16829 .55479 .20851 .55593 .17803 .54135 Metetra
.65 .85 .977 r
.17803 .54135 .20851 .55593 .25111 .54042 .22116 .52574 Metetra
.772 .865 .918 r
.22116 .52574 .25111 .54042 .29531 .5108 .26596 .49714 Metetra
.825 .871 .879 r
.26596 .49714 .29531 .5108 .34038 .47105 .31172 .45914 Metetra
.85 .885 .864 r
.31172 .45914 .34038 .47105 .38572 .42603 .35784 .41617 Metetra
.855 .906 .868 r
.35784 .41617 .38572 .42603 .43097 .38084 .40396 .37295 Metetra
.837 .933 .892 r
.40396 .37295 .43097 .38084 .47604 .3402 .44995 .33387 Metetra
.774 .955 .931 r
.44995 .33387 .47604 .3402 .52112 .30806 .49596 .30261 Metetra
.627 .936 .963 r
.49596 .30261 .52112 .30806 .56662 .28726 .54236 .28182 Metetra
.369 .821 .937 r
.54236 .28182 .56662 .28726 .6131 .27925 .58967 .27284 Metetra
.084 .628 .842 r
.58967 .27284 .6131 .27925 .66118 .28385 .63846 .27542 Metetra
0 .475 .765 r
.63846 .27542 .66118 .28385 .71136 .29879 .68923 .28739 Metetra
0 .434 .774 r
.68923 .28739 .71136 .29879 .76384 .31914 .74218 .30415 Metetra
.025 .526 .873 r
.74218 .30415 .76384 .31914 .8182 .33667 .79701 .31818 Metetra
.337 .757 .977 r
.10492 .52986 .1373 .54175 .17803 .54135 .14625 .5276 Metetra
.639 .86 .983 r
.14625 .5276 .17803 .54135 .22116 .52574 .18991 .51199 Metetra
.758 .877 .933 r
.18991 .51199 .22116 .52574 .26596 .49714 .23528 .48479 Metetra
.812 .889 .899 r
.23528 .48479 .26596 .49714 .31172 .45914 .2817 .44909 Metetra
.838 .907 .885 r
.2817 .44909 .31172 .45914 .35784 .41617 .32859 .40882 Metetra
.841 .933 .889 r
.32859 .40882 .35784 .41617 .40396 .37295 .37559 .36819 Metetra
.813 .96 .907 r
.37559 .36819 .40396 .37295 .44995 .33387 .42253 .3312 Metetra
.73 .972 .929 r
.42253 .3312 .44995 .33387 .49596 .30261 .46954 .30118 Metetra
.557 .928 .925 r
.46954 .30118 .49596 .30261 .54236 .28182 .51692 .28054 Metetra
.298 .792 .862 r
.51692 .28054 .54236 .28182 .58967 .27284 .56515 .27043 Metetra
.05 .615 .771 r
.56515 .27043 .58967 .27284 .63846 .27542 .61476 .27055 Metetra
0 .494 .725 r
.61476 .27055 .63846 .27542 .68923 .28739 .66621 .27884 Metetra
0 .478 .765 r
.66621 .27884 .68923 .28739 .74218 .30415 .71972 .29113 Metetra
.062 .575 .881 r
.71972 .29113 .74218 .30415 .79701 .31818 .77506 .3008 Metetra
.4 .781 .991 r
.07138 .51663 .10492 .52986 .14625 .5276 .11332 .51243 Metetra
.636 .852 .982 r
.11332 .51243 .14625 .5276 .18991 .51199 .15752 .49686 Metetra
.741 .871 .94 r
.15752 .49686 .18991 .51199 .23528 .48479 .20342 .47118 Metetra
.794 .886 .912 r
.20342 .47118 .23528 .48479 .2817 .44909 .25044 .43794 Metetra
.818 .907 .901 r
.25044 .43794 .2817 .44909 .32859 .40882 .29805 .40053 Metetra
.82 .933 .906 r
.29805 .40053 .32859 .40882 .37559 .36819 .34587 .36267 Metetra
.79 .959 .921 r
.34587 .36267 .37559 .36819 .42253 .3312 .39375 .32792 Metetra
.708 .966 .937 r
.39375 .32792 .42253 .3312 .46954 .30118 .44175 .29925 Metetra
.55 .924 .929 r
.44175 .29925 .46954 .30118 .51692 .28054 .49015 .27879 Metetra
.328 .811 .877 r
.49015 .27879 .51692 .28054 .56515 .27043 .53935 .2675 Metetra
.123 .67 .811 r
.53935 .2675 .56515 .27043 .61476 .27055 .58984 .265 Metetra
.01 .577 .788 r
.58984 .265 .61476 .27055 .66621 .27884 .64203 .26935 Metetra
.023 .571 .835 r
.64203 .26935 .66621 .27884 .71972 .29113 .69615 .27679 Metetra
.171 .649 .928 r
.69615 .27679 .71972 .29113 .77506 .3008 .75203 .28175 Metetra
.473 .784 .998 r
.03702 .49924 .07138 .51663 .11332 .51243 .07955 .49337 Metetra
.64 .826 .972 r
.07955 .49337 .11332 .51243 .15752 .49686 .12423 .4778 Metetra
.727 .844 .936 r
.12423 .4778 .15752 .49686 .20342 .47118 .17062 .45333 Metetra
.774 .859 .913 r
.17062 .45333 .20342 .47118 .25044 .43794 .21821 .42205 Metetra
.798 .878 .905 r
.21821 .42205 .25044 .43794 .29805 .40053 .26649 .38692 Metetra
.802 .9 .911 r
.26649 .38692 .29805 .40053 .34587 .36267 .31508 .35127 Metetra
.781 .923 .931 r
.31508 .35127 .34587 .36267 .39375 .32792 .36382 .31829 Metetra
.724 .936 .957 r
.36382 .31829 .39375 .32792 .44175 .29925 .41274 .29066 Metetra
.615 .919 .976 r
.41274 .29066 .44175 .29925 .49015 .27879 .46207 .27026 Metetra
.458 .857 .97 r
.46207 .27026 .49015 .27879 .53935 .2675 .51218 .25788 Metetra
.299 .765 .943 r
.51218 .25788 .53935 .2675 .58984 .265 .56352 .25307 Metetra
.204 .691 .927 r
.56352 .25307 .58984 .265 .64203 .26935 .61646 .25393 Metetra
.211 .673 .944 r
.61646 .25393 .64203 .26935 .69615 .27679 .67122 .25709 Metetra
.317 .708 .98 r
.67122 .25709 .69615 .27679 .75203 .28175 .72768 .25782 Metetra
.524 .753 .98 r
.00232 .47502 .03702 .49924 .07955 .49337 .04527 .46819 Metetra
.645 .785 .949 r
.04527 .46819 .07955 .49337 .12423 .4778 .09039 .45238 Metetra
.718 .801 .917 r
.09039 .45238 .12423 .4778 .17062 .45333 .1373 .42812 Metetra
.759 .811 .894 r
.1373 .42812 .17062 .45333 .21821 .42205 .18549 .39734 Metetra
.78 .821 .884 r
.18549 .39734 .21821 .42205 .26649 .38692 .23443 .36284 Metetra
.784 .83 .888 r
.23443 .36284 .26649 .38692 .31508 .35127 .28375 .32776 Metetra
.77 .838 .904 r
.28375 .32776 .31508 .35127 .36382 .31829 .33324 .29517 Metetra
.735 .842 .93 r
.33324 .29517 .36382 .31829 .41274 .29066 .38292 .26764 Metetra
.672 .834 .961 r
.38292 .26764 .41274 .29066 .46207 .27026 .433 .24692 Metetra
.58 .805 .985 r
.433 .24692 .46207 .27026 .51218 .25788 .48383 .23373 Metetra
.477 .757 .992 r
.48383 .23373 .51218 .25788 .56352 .25307 .53584 .22757 Metetra
.398 .708 .985 r
.53584 .22757 .56352 .25307 .61646 .25393 .58941 .22656 Metetra
.379 .685 .979 r
.58941 .22656 .61646 .25393 .67122 .25709 .64477 .22744 Metetra
.429 .698 .977 r
.64477 .22744 .67122 .25709 .72768 .25782 .70185 .22585 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.15767 .20795 m
.16227 .21262 L
s
[(0.2)] .14845 .1986 .98563 1 Mshowa
.28411 .15844 m
.2885 .16331 L
s
[(0.4)] .27533 .14869 .90053 1 Mshowa
.41694 .10643 m
.42109 .11151 L
s
[(0.6)] .40865 .09626 .81543 1 Mshowa
.55666 .05172 m
.56052 .05702 L
s
[(0.8)] .54892 .04112 .73033 1 Mshowa
.125 Mabswid
.06675 .24355 m
.0696 .24627 L
s
.0967 .23182 m
.09952 .23457 L
s
.127 .21996 m
.12979 .22273 L
s
.1887 .1958 m
.19144 .19863 L
s
.22012 .1835 m
.22282 .18636 L
s
.25192 .17104 m
.25459 .17394 L
s
.3167 .14568 m
.3193 .14863 L
s
.3497 .13276 m
.35226 .13575 L
s
.38311 .11967 m
.38563 .12269 L
s
.4512 .09301 m
.45365 .09609 L
s
.4859 .07942 m
.48831 .08254 L
s
.52105 .06566 m
.52342 .06881 L
s
.59272 .0376 m
.595 .04081 L
s
.62926 .02329 m
.63149 .02653 L
s
.66629 .00879 m
.66847 .01207 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00ooooool7ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0GOooool00?oooooo1oooool01Omg
MgOoV9RHoooooonHV9SoMgMg05gooooo003oooooo`Oooooo00Go410@oooooooooooooooooa0@401M
ooooo`00ooooool7ooooo`05o`000?ooooooooooooooool00000GOooool00?oooooo1oooool01Ol0
003ooooooooooooooooo000005gooooo003oooooo`Oooooo00Go410@oooooooooooooooooa0@401M
ooooo`00ooooool1ooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg05gooooo003moooo
o`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^05gooooo003koooo
o`;o00001?ooool2o`0006Gooooo003hooooo`?o00001_ooool00ol0003oooooo`00001Tooooo`00
`Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`08?ooool2o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooo`00001Toooo
o`00`Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B407Oooool3o`0000_ooooo00Co0000oooooooooooo0000Hoooool00<7ooooo00Go410@
oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006_ooool3o`0000kooooo
00Go0000ooooooooooooooooo`00001Rooooo`00`Oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Hooooo`;o00004Oooool01Ol0003ooooooooooooooooo
000006;ooooo0031ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0
003oc<c<01Gooooo1?l0000Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Gooo
ool00<7ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
4oooool2o`0000Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`03o`00063ooooo
0031ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000013o
oooo0ol0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0G_ooool00<7ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT03_ooool2o`00
01cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Mooooo`00hOooool3o`0001ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Looooo`00goooool2o`0000;ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05cooooo
001looooo`;o00000_ooool2o`0005[ooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Foooool007cooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMeHooooo`;o0000
9_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo001mooooo`04omgMgOl0
003o410@olc<c5Kooooo0ol0000Xooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
F_ooool007gooooo00Cok^k^ob4Q8Ol@413ok^k^Doooool5o`0002Wooooo00?o0000ooooooooool0
1_ooool2o`0005_ooooo001mooooo`04ob4Q8OmgMgOoMgMgoc8b<U7ooooo0_l00005ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`00O?oo
ool2o`0000;ooooo0_l0001=ooooo`?o0000<?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo05Sooooo003=ooooo`;o0000<oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo05Oooooo003:ooooo`?o0000=Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
05Oooooo002Dooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b
<_l0003o410@olc<c00Oooooo`;o00000oooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0E_ooool009Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q01cooooo0ol0000jooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0EOooool009Cooooo00Go410@oooooooooooooooooa0@
400;ooooo`05o`000?ooooooooooooooool000006_ooool2o`0003kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`1Eooooo`00U?ooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000oiRHV?ooooooV9RHob4Q8@0Gooooo`?o0000@?ooool00ol0003oooooooooo`0:ooooo`;o
0000E_ooool009Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`05Oooool2o`0000;ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo05?ooooo002Dooooo`05oa0@4?ooooooooooooooool@41002oooool00omE
EEGoQhN7ooooo`0Dooooo`?o0000AOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0003Sooooo002Doooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00Booooo`;o0000B?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A403Sooooo002Dooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410=ooooo`?o0000B_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^03Wooooo002cooooo`Co0000C?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
03Sooooo002aooooo`;o00001?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0=oooool00:kooooo0ol0001Booooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0=_ooool00:co
oooo0_l0001Eooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400hooooo`00ZOooool4o`00
05Kooooo00?o0000ooooooooool03oooool00ol0003oooooo`000003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<03Sooooo002Wooooo`;o00001?ooool0
0ol0003oooooooooo`1Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0COooool0
0:Cooooo0ol0001Looooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0COooool00:;o
oooo0_l0001Oooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0C?ooool006Wooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo01oo
oooo0ol0001Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Boooool006Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Nooooo`;o
00000_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0Boooool006Wooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00007?ooool3o`0006Oo
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1:ooooo`00JOooool01Ol0003ooooo
oooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00006_ooool3o`0006[ooooo00?o0000oooo
ooooool04oooool3o`0004_ooooo001Yooooo`05o`000?ooooooooooooooool000002oooool01?oM
gMgoEEEEooooool0000Hooooo`;o0000KOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo04Wooooo001Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000E
ooooo`?o00000_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0B?ooool006Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co
000001?ooooo0_l0001booooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0B?ooool0
06Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00oooooo0ol0001d
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Aoooool008_ooooo0_l0001goooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0A_ooool008Sooooo0ol000000ooooooo
0000ooooo`1fooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0A_ooool008Kooooo
0_l0001looooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0AOooool008?ooooo0ol0
001nooooo`03o`000?oooooooooo01Sooooo00?o0000ooooool00000A_ooool0087ooooo0_l00021
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0A?ooool007kooooo0ol000000ooo
oooo0000ooooo`20ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@oooool007_o
oooo0ol00005ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`12ooooo`00NOooool2o`0008Wooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`12ooooo`00@?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
8Oooool3o`0008_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`11ooooo`00@?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@07oooool2o`0000;ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo043ooooo0010ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP0Mooooo`?o0000TOooool00ol0003oooooooooo`0Looooo`;o0000@_ooool0043ooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0002Dooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool01_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool08_ooool0043ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo01Kooooo0ol0002Fooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47
ooooo`03o`000?oooooooooo02?ooooo0010ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`0Cooooo`;o00000_ooool00ol0003oooooooooo`2Dooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
0008ooooo`?o000000?o410@ooooooooool05_ooool0043ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41004_ooool3o`0009_ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4Co
gMgMooooool0000;ooooo`03oa0@4?nj^[[ooooo01Oooooo0010ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<013ooooo0_l0002Nooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
gMgMoeEEEOoooooo00002oooool00onHV9So<S8booooo`0Gooooo`00H_ooool3o`000:3ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`03ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00omgMgOoc<c<o`00000;ooooo`03omgMgOl0003o^[Zj01Oooooo001Pooooo`;o00000_oo
ool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo023ooooo0ol00004ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000;ooooo`03oeEEEOmgMgOoA4A401Oooooo
001Mooooo`?o0000YOooool00ol0003oooooooooo`0Sooooo`09o`000?ooooooooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool02Oooool01OoMgMgo410@oooooolQ8B7o
gMgM01Kooooo001Jooooo`?o0000Z?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
01oooooo00GoIVIVohN7QoooooooV9RHoeEEE@0Fooooo`00F?ooool3o`000:[ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Mooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgM
gOooool05?ooool005Gooooo0ol00003ooooo`03o`000?oooooooooo0:Oooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Looooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooo
ooooool04oooool005?ooooo0_l0002`ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0>?ooool002Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Rooooo`?o0000/_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo03Oooooo000Yooooo`05ogMgMonHV9SooooooiRHV?mg
MgL08?ooool3o`000;Cooooo00?o0000ooooooooool09Oooool3o`0003Sooooo000Yooooo`05oa0@
4?ooooooooooooooool@41007Oooool3o`0000?ooooo00?o0000ooooooooool0Z?ooool;o`0002So
oooo00?o0000ooooooooool0=_ooool002Wooooo00Go0000ooooooooooooooooo`00000Kooooo`;o
0000P_ooool_o`0000WoKK;j0_l0000Yooooo`03o`000?oooooooooo03Gooooo000Yooooo`05o`00
0?ooooooooooooooool000006?ooool3o`0007_ooooo2Ol00006og[1o@03o`000?mU]OcoIKGl00go
IKGl00?o0000of6_n_mQ[oX03_mQ[oX00ol0003oKK;joffbnP0?offbnP03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0=Oooool002Wooooo00Go410@oooooooooooooooooa0@400Fooooo`;o
000000?oooooo`000?ooool0MOooool6o`00013oN/7m00?o0000ofFeo?mU]O`03OmU]O`00ol0003o
HJojof6_nP0>of6_nP03o`000?m]/_[oKK;j00koKK;j0_l0000Yooooo`03o`000?oooooooooo03Co
oooo000Yooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool3o`0007Kooooo1?l00004oiC>o003
o`000?mj`OgoN/7m013oN/7m00?o0000ofFeo?mU]O`03OmU]O`00ol0003oHJojof6_nP0>of6_nP03
o`000?m]/_[oKK;j00goKK;j00?o0000offbn_l00000:Oooool00ol0003oooooooooo`0cooooo`00
:Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^013ooooo0ol0001eooooo`Co00002OnDc_`00ol0003o
N/7mog[1o@0@og[1o@03o`000?mU]OcoIKGl00goIKGl00?o0000of6_n_mQ[oX03_mQ[oX00ol0003o
KK;joffbnP0<offbnP03o`000?m]/_[o000002Wooooo00?o0000ooooooooool0<oooool003cooooo
0_l0001dooooo`Co00003_nDc_`00ol0003oN/7mog[1o@0@og[1o@03o`000?mU]OcoIKGl00goIKGl
00?o0000of6_n_mQ[oX03_mQ[oX00ol0003oKK;joffbnP0;offbnP04o`000?m]/_[oKK;jo`0002So
oooo0_l0000dooooo`00>Oooool3o`0000;ooooo00?o0000ooooooooool0K_ooool3o`0001?oU<kl
00?o0000og[1oOmj`Od04?mj`Od00ol0003oIKGlofFeo00=ofFeo003o`000?mQ[o[oHJoj00koHJoj
00?o0000offbn_m]/_X02Om]/_X2o`0000?oKK;j00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0aooooo`00=oooool2o`0007Cooooo0_l00003ojcEmP03o`000?nDc_coU<kl017oU<kl00?o
0000og[1oOmj`Od04?mj`Od00ol0003oIKGlofFeo00=ofFeo003o`000?mQ[o[oHJoj00koHJoj00?o
0000offbn_m]/_X01Om]/_X3o`000003offbn_l0003oKK;j00;oKK;j00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0aooooo`00=?ooool3o`0007Cooooo0_l00006ojcEmP03o`000?nDc_co
U<kl017oU<kl00?o0000og[1oOmj`Od03?mj`OdNo`0000OoHJoj00Co0000offbn_m]/_[oKK;j0ol0
0005offbnP05o`000?m]/_[oKK;joffbn_l00000:Oooool00ol0003oooooooooo`0`ooooo`00<ooo
ool2o`0007?ooooo0ol00009ojcEmP03o`000?nDc_coU<kl017oU<kl00?o0000og[1oOmj`Od00_mj
`Od9o`0000KoC<?a0_l0000>ocB`k@03o`000?lf[?7o=Zca00Go=Zca4_l00002offbnP05o`000?m]
/_[oKK;joffbn_l00000:Oooool00ol0003oooooooooo`0_ooooo`00<oooool3o`00073ooooo0_l0
000=ojcEmP;o00004?nDc_`6o`00017oC<?a0_l0000=ocB`k@;o00002_lf[?43o`000003ocJ/lOl0
003oDKGj00OoDKGj2Ol0000Wooooo`03o`000?oooooooooo02oooooo000cooooo`04o`000?oooooo
ooooo`0006gooooo0_l0000AojcEmP03o`000?nDc_coU<kl00WoU<kl1?l00005ogGKn0?o00004Om<
`o42o`0000go=;3]0_l00005ocJ/l@?o00001Olf[?400ol0003oDKGjoe6enP08oe6enP03o`000?mA
]O[oDKGj00?oDKGj00?o0000ooooooooool09Oooool00ol0003oooooooooo`0^ooooo`00<oooool0
1Ol0003ooooooooooooooooo000006[ooooo0_l0000DojcEmP03o`000?nDc_coU<kl00GoU<kl0ol0
000<ogGKn0?o00002?m<`o4Ao`0000Ko=;3]00?o0000ocJ/lOl000000_l00009ocJ/l@03o`000?mA
]O[oDKGj00SoDKGj00?o0000oe6en_mA]OX00omA]OX00ol0003oooooooooo`0Sooooo`03o`000?oo
oooo000000Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<01;ooooo000booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
IOooool3o`0001Ko[=Gf00?o0000oiC>o?nDc_`01?l0000?ogGKn0_o00002olOZll4o`0000;o0Y?9
2ol0000:ocJ/l@03o`000?mA]O[oDKGj00SoDKGj00?o0000oe6en_mA]OX00omA]OX00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q01;ooooo000booooo`?o00001?ooool00ol0003o
ooooooooo`1Rooooo`;o00000onlenh00ol0003o[=GfojcEmP0CojcEmPCo00003OmefoP5o`0000So
DloP6Ol00004o`:Cb@So00001Olf[?400ol0003oDKGjoe6enP07oe6enP03o`000?mA]O[oDKGj00Co
DKGj00?o0000ooooooooool09?ooool00ol0003oooooooooo`05ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000001;ooooo000booooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0Goooool2o`0000Ko_=O^00?o0000ojcEm_n/eOH03on/eOH3o`00
00CoWN_i1?l00004ogGKn0Go00002OmCcn05o`0000?oC<[L1Ol00005oekBk`?o00000olEX=L?o`00
00;o1I;E1Ol000000olf[?7o0000oe6enP08oe6enP03o`000?mA]O[oDKGj00CoDKGj00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002oooool0
1Ol0003oV9RHoooooonHV9So8B4Q01;ooooo000booooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0G?ooool2o`0000Wo_=O^0_l0000<ojcEmP?o00002onMjoT7o`0000KoDloP1Ol00003
odc:g0Go00003?mNd^l7o`0000Go5J3G2_l00004o`FBe@go00001_mA]OX00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mE
EEGo0000oa0@4?o<c<`04_ooool003;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Iooooo`;o00003Onlenh00ol0003o[=GfojcEmP07ojcEmP;o00003?nMjoT2o`0000OoS>c]3_l0
000<oekBk`Ko00000omkd_l00ol0003o<jSaoc>Xl@07o`000003oaFPeol0003o000000Wo00001?l5
T]D2o`0000Ko:jK]2_l0000Tooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`03oeEEEOn7QhOooooo01Cooooo000booooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0E_ooool2o`00013o_=O^00?o0000ojcEm_n/eOH00on/eOH3o`0000coWN_i0_l0
0008ohc/k@?o00001_n>kN`2o`0000CoX>of1?l00003oekBk`So00001omkd_l2o`0000Oo<jSa1_l0
00000ol0NL?o0000o`000008o`000003o`FBeOl0003o000000Go:jK]00?o0000ob^VkOl[Y^d01_l[
Y^d00ol0003oooooooooo`0Qooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00?ogMgMoa0@4?nHV9P05?ooool003;ooooo0_l0000:ooooo`03o`000?oooooooooo05?ooooo0_l0
000CokcGkP03o`000?n/eOKo000000;o00003?nMjoT3o`0000SoS>c]0_l00007ohk]k0;o00002_nP
koH3o`0000;oNm;o0ol0000<og_Bo`03o`000?lcZ?7o<jSa00Wo<jSa1?l00002o`1i``Co00000_l0
N/<5o`0000Co:jK]00?o0000ob^VkOl[Y^d01_l[Y^d00ol0003oooooooooo`0Oooooo`03o`000?oo
oooo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@41;o
oooo000aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0D?ooool2o`0001Go_=O^
1?l0000;oig[n@;o00002?n<k>d3o`0000KoS^g/0ol00009oj3_mP?o00000_n`iOP3o`00013oNm;o
00?o0000oc>XlOlcZ?402_lcZ?400ol0003o07kKo`000002o`0000;o07W31?l00003o`1j``Go0000
00?o:jK]o`000?l[Y^d01ol[Y^d00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Sooooo
000aooooo`03o`000?oooooooooo00cooooo0_l0001>ooooo`?o00005?nlenh2o`0000Co^Nod0ol0
0006oig[n@;o00002?n<k>d2o`0000OoS^g/0_l0000:oj3_mP;o00000_n`iOP3o`0000?o/>Gh00?o
0000og_Boomkd_l02omkd_l<o`0000Co<jSa0_l00002o`1nf`?o000000?o07W3o`000?l0KlH01?l0
0002o`1j``So00001Ol[Y^d00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Oooooo000a
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0B_ooool01Ol0003oaMKWolGFioo5
e^Oo000001;o_=O^00?o0000okW_m?niko@01oniko@3o`000003oig[nOl0003o000000OoS>c]0ol0
0007ohk]k0;o00002OnPkoH3o`000004ok3Un?l0003o0000o`0000Oo/>Gh0_l00004og_Bo`Oo0000
1?n>`_T00ol0003oEJGgoeFUm`05oeFUm`So00000ol0O]/4o`0000?o06o60ol000001?l0N/?o0000
o`nChOl00003o`nCh@Go000000?o:jK]o`000?ooool08Oooool00ol0003oooooooooo`0Wooooo`00
<Oooool2o`00013ooooo00?o0000ooooooooool0Aoooool2o`0000GoaMKW00?o0000okcGk_nlenh0
3Onlenh2o`0000co^Nod3ol00004ohk]k0;o00002OnPkoH2o`0000;o/>Gh0_l0000;ok3Un0Go0000
3?n>`_T00ol0003oEJGgoeFUm`0:oeFUm`03o`000?lQP^Wo000000;o00000ol0O]/3o`0000Co06o6
1Ol00007o`nCh@Co00008Oooool00ol0003oooooooooo`0Vooooo`00<Oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo04Gooooo00?o0000olGFioo5e^L01_o5e^L00ol0003o_=O^okcG
kP0:okcGkP;o00003?niko@2o`0000So]OO_00?o0000ok[hkOnjn>d01?njn>d8o`0000CoX>of0ol0
00001?n`iOSo0000o`000?l0000:ok3Un0?o00000_necnd00ol0003oS/;iohk2n@0=ohk2n@03o`00
0?mEYOOoEJGg00[oEJGg00Co0000ob62jOlQP^Wo8H;Y0ol00003o`1nf`?o00001?l0KlH4o`0000Wo
3i?Q00?o0000ooooooooool07_ooool2o`0002Oooooo000aooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0@_ooool2o`0000[oaMKW0_l00009okcGkP03o`000?nikoCo^Nod00_o^Nod
00?o0000okGgkonemnl01_nemnl2o`0000So^_S]00?o0000olKdk_o6m>h01?o6m>h8o`0000_o/>Gh
0_l00006okG?k@03o`000?n>`_WoS/;i00goS/;i00?o0000oeFUmomEYOL02_mEYOL00ol0003o8H;Y
ob62j@03ob62j@;o00000_l0O]/5o`0000?o06o61Ol00007o`nCh@03o`000?oooooooooo01gooooo
0_l0000Wooooo`00<Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo043ooooo00?o
0000olGFioo5e^L03?o5e^L00ol0003o_=O^okcGkP04okcGkP;o00003?niko@2o`0000So]OO_00?o
0000ok[hkOnjn>d01_njn>d2o`0000Soa_C^1_l0000:ok3Un0;o00002Onecnd00ol0003oS/;iohk2
n@0=ohk2n@03o`000?mEYOOoEJGg00[oEJGg00?o0000ob62jOlQP^T01?lQP^T3o`000004o`1nfol0
003o06kDo`1^e0?o000000Go06o6o`000?l0003o0000o`J6g`04o`0000Co3i?Q00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Tooooo`00<?ooool3o`0001Cooooo00?o0000ooooooooool0
?_ooool00ol0003oaMKWolGFi`0>olGFi`04o`000?nlenko_=O^okcGkP;o00003?niko@2o`0000So
]OO_0_l00008ok[hk@03o`000?o6m>koa_C^00Koa_C^0ol00005olcVj@;o00001On`iOP3o`0000co
]Lo]00?o0000ohk2nOn>`_T03On>`_T00ol0003oEJGgoeFUm`0:oeFUm`03o`000?lQP^Wo8H;Y00Ko
8H;Y0ol00004o`1^e0?o000000?o06o6o`000?l6Q]l00ol6Q]l3o`0000;o3i?Q00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Tooooo`00<?ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo03_ooooo0_l0000BolGFi`03o`000?nlenko000000go^Nod00?o0000okGgkonemnl0
1onemnl00ol0003o^_S]ok[hk@07ok[hk@03o`000?o6m>koa_C^00Coa_C^1?l00009olcVj@;o0000
00?o/>Gho`000?l000004?necnd00ol0003oS/;iohk2n@0:ohk2n@So00002?mEYOL00ol0003o8H;Y
ob62j@08ob62j@;o00001Ol0K]@3o`0000Ko1XKO1?l0000Oooooo`03o`000?oooooooooo02?ooooo
0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0iooooo`03o`000?o5e^Oo
aMKW01;oaMKW1?l0000:okW_m0;o00002?nemnl2o`0000So^_S]0_l00004olKdkP?o000000?oa_C^
o`000?l000002oo<i^T2o`0001?o]Lo]00?o0000ohk2nOn>`_T00_n>`_T7o`0000?oUJkX00?o0000
ofbIjom/VN/00_m/VN/7o`0000;oEJGg00?o0000ob62jOlQP^T02?lQP^T3o`0000?o06kD00?o0000
o`1^e?l0K]@00ol00006o`J6g`?o00007_ooool00ol0003oooooooooo`0Rooooo`001_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo03Kooooo0_l0000DolGFi`03o`000?o7k>koanc^00;oanc^
0ol00005okW_m0;o00002Onemnl00ol0003o^_S]ok[hk@07ok[hk@04o`000?o6m>koa_C^olKdkP?o
00000oo6m>h00ol0003oc>KYolcVj@0:olcVj@04o`000?o:d^3ob];Po`0001;o]Lo]1Ol0000;oiF^
j003o`000?m/VN_oK9W[00SoK9W[1_l00008ob62j@03o`000?l<LMoo000000;o000000Ko06kDo`00
0?l0K]Co06kDo`000?l>PN@3o`0000Ko1XKO00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Rooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0dooooo`03o`000?o5e^OoaMKW01;o
aMKW0_l00008olO/kP?o000000?o^Nodo`000?nemnl02?nemnl2o`0000So^_S]0_l000001?o6m>ko
0000o`000?l00005olKdkP03o`000?o<i^Woc>KY00[oc>KY00?o0000ol[Bh?o:d^000_o:d^000ol0
003o]Lo]okG?k@0<okG?k@?o000000?o/k[No`000?nE[^P03_nE[^P00ol0003oK9W[ofbIj`0:ofbI
j`03o`000?m2PNKo@X7V00?o00001_lQP^T01?l0003o377Oo`aagol<LMl3o`0000;o06kD00Co0000
o`j1i?l>PNCo3X7T1?l00003o`J6g`;o00006oooool2o`0002?ooooo0006ooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000007ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0000Jooooo`03o`000?oooooooooo037o
oooo0ol0000BolGFi`;o00003?o7k>h7o`0000Co]OO_00?o0000ok[hkOnjn>d01onjn>d01?l0003o
a_C^o`000?l00006olKdkP;o00003?o<i^T00ol0003ob];Pol[Bh004ol[Bh003o`000?necngo]Lo]
00Wo]Lo]0_l00005ok>jgP03o`000?nE[^SoUJkX00coUJkX00?o0000ofbIjom/VN/02om/VN/00ol0
003o@X7Vod:1iP02od:1iP?o00001?lQP^T00ol0003o377Oo`aag`02o`aag`;o00000_l0K]@00ol0
003o3X7To`j1i004o`j1i0?o00000_l6Q]l00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
023ooooo0006ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1?ooool00ol0003oooooooooo`0Jooooo`;o0000<?ooool01Ol0003ob=CSolSDhoo8e>?o0000013o
aMKW00?o0000olO/k_o7k>h02oo7k>h00ol0003ob_G[ol[ej`05ol[ej`Wo00001?njn>d3o`0000Oo
a_C^00?o0000olcVjOo<i^T02_o<i^T2o`0000Sob];P00?o0000okG?kOnecnd01_necnd2o`0000So
/k[N00?o0000oiF^j?nE[^P03?nE[^P00ol0003oK9W[ofbIj`0;ofbIj`03o`000?m2PNKo@X7V00Co
@X7V0ol00002ob62j@03o`000?l<LMoo377O00;o377O1Ol00008o`j1i0Co00006oooool00ol0003o
ooooooooo`0Pooooo`001_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0;?ooool00ol0003ob=CSolSDh`03
olSDh`;o00003?o5e^L2o`0000goanc^00?o0000ol[ejoo:mN/01oo:mN/00ol0003od?GXom3ej005
om3ej0Ko00001oo6m>h00ol0003oc>KYolcVj@0:olcVj@03o`000?o:d^3ob];P00Wob];P00?o0000
okG?kOnecnd00_necnd3o`0000[o/k[N00?o0000oiF^j?nE[^P03OnE[^P00ol0003oK9W[ofbIj`0:
ofbIj`03o`000?m2PNKo@X7V00Oo@X7V1?l00004o`aag`03o`000?l<LMoo377O00;o00002_l>PN@2
o`0001_ooooo00?o0000ooooooooool07oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Wooooo
0_l00008olSDh`03o`000?o5e^OoaMKW00SoaMKW00?o0000olO/k_o7k>h02oo7k>h2o`0000Wob_G[
00?o0000om3ej?o@mNP01?o@mNP4o`0000Coe^kT1?l00002olKdkP03o`000?o<i^Woc>KY00[oc>KY
00?o0000ol[Bh?o:d^002oo:d^001?l0003o]Lo]o`000?l0000>ok>jgP03o`000?nE[^SoUJkX00go
UJkX00?o0000ofbIjom/VN/02_m/VN/00ol0003o@X7Vod:1iP09od:1iP?o00000ol<LMl01?l0003o
377Oo`aagol<LMl2o`0000Wo3X7T00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Noooo
o`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool4o`0000Cooooo0_l0000Pooooo`03o`000?oo
oooooooo02Oooooo00?o0000olSDhoo8e><02Oo8e><00ol0003oaMKWolGFi`05olGFi`;o00003Oo7
k>h00ol0003ob_G[ol[ej`07ol[ej`;o00001?o@mNP3o`0000;od?GX00?o0000omK^i?oFk^@01ooF
k^@3o`0000[oc>KY0_l0000>ol[Bh0;o00004Onc^]h00ol0003oUJkXoiF^j00<oiF^j003o`000?m/
VN_oK9W[00_oK9W[00?o0000od:1i_m2PNH02Om2PNH01_l0003o;7?Qo`000?l0003o377Oo`0000?o
377O00?o0000ob9niol000000_l00007o`j1i003o`000?oooooooooo01Wooooo00?o0000oooooooo
ool07_ooool002oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Tooooo`;o0000
3Oo8e><2o`0000?oaMKW0_l0000=olO/kP;o00002Oo:mN/01?l0003od?GXom3ej?o@mNP3o`0000Co
d?GX00?o0000omK^i?oFk^@01ooFk^@01?l0003oen7NomOQg_oGhMh2o`0000Ooc>KY00?o0000ol[B
h?o:d^003Oo:d^000ol0003oaKoEo`00000Bok>jgP03o`000?nE[^SoUJkX00coUJkX00?o0000ofbI
jom/VN/02om/VN/00ol0003o@X7Vod:1iP09od:1iP03o`000?l/Ln7o;7?Q00?o00000ol<LMl01?l0
003o8WkWob9niolRO^L3o`0000Go3X7T00?o0000ooooooooool06?ooool2o`0000Sooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00;ooooo
000_ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08_ooool00ol0003ob=CSolSD
h`0?olSDh`03o`000?o5e^Oo000000koanc^00?o0000ol[ejoo:mN/01oo:mN/2o`000004om3ej?l0
003o0000o`0000God?GX0_l00009omK^i003o`000?oGhMkoen7N00Coen7N0_l00004olcVj@03o`00
0?o:d^3ob];P00cob];P0_l00003olFoe@03o`000?nc^]ko/k[N00oo/k[N00?o0000oiF^j?nE[^P0
2_nE[^P8o`0000SoK9W[00?o0000od:1i_m2PNH02_m2PNH01?l0003o;7?QobachOl/Ln42o`0000?o
377O00?o0000ob9niolRO^L00olRO^L3o`0000?o3X7T00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRH
V?ooooooV9RHob4Q8@02ooooo`00;oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
023ooooo00?o0000olSDhoo8e><04?o8e><3o`0000goanc^00?o0000ol[ejoo:mN/01oo:mN/4o`00
00Ood?GX00?o0000omK^i?oFk^@02?oFk^@00ol0003oen7NomOQgP07omOQgP;o000000?oc>KYo`00
0?o:d^003Oo:d^000ol0003oaKoEolFoe@04olFoe@03o`000?nc^]ko/k[N00oo/k[N00?o0000oiF^
j?nE[^P00_nE[^P7o`0000?oV9kI00?o0000ogV?g?miSm`00_miSm`7o`0000;oK9W[00?o0000od:1
i_m2PNH02Om2PNH00ol0003o;7?Qobach@03obach@;o00000_l<LMl00ol0003o8WkWob9ni`05ob9n
i`?o000000?o3X7To`000?ooool06Oooool00ol0003oooooooooo`05ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000000;ooooo000^ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool07Oooool2o`0001;ob=CS00Co0000olgVjOo=i^WocNKY0ol0
0008olO/kP;o00002Oo:mN/2o`0000Wod?GX00?o0000omK^i?oFk^@02?oFk^@00ol0003oen7NomOQ
gP09omOQgP?o00003Oo:d^000ol0003oaKoEolFoe@05olFoe@03o`000?nc^]ko/k[N00oo/k[N1Ol0
000;oiRNf@03o`000?miSmcoNHoL00SoNHoL1_l00009od:1iP03o`000?l/Ln7o;7?Q00;o;7?Q00Ko
0000obachOl0003o0000o`aagol00009ob9ni`?o00006_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00;ooooo000^oooo
o`;o00009_ooool00ol0003oooooooooo`0Kooooo`03o`000?o8e>?ob=CS017ob=CS00?o0000olgV
jOo=i^T01Oo=i^T2o`0000Goanc^00?o0000ol[ejoo:mN/01_o:mN/3o`0000[od?GX00?o0000omK^
i?oFk^@02?oFk^@00ol0003oen7NomOQgP09omOQgP05o`000?oDdMKoe=7FomCAe_l000002_o:d^02
o`0000WoaKoE00?o0000ok>jg_nc^]h02onc^]h3o`000003ojnZd_l0003oV9kI00goV9kI00?o0000
ogV?g?miSm`02omiSm`00ol0003oFGkMoeUng@03o`0000Ko@X7V00?o0000obachOl/Ln400ol/Ln40
0ol0003o;7?Qobach@03o`0000_o8WkW00?o0000ooooooooool06?ooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00;ooooo
000^ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool06Oooool00ol0003ob=CSolSD
h`0@olSDh`;o00002_o=i^T3o`000003olO/k_l0003ob_G[00Gob_G[1?l0000:om3ej0;o00002OoF
k^@2o`0000_oen7N00?o0000omCAe_oDdMH00ooDdMH00ol0003ob];Pol[Bh006ol[Bh003o`000?o5
_mGoaKoE00[oaKoE00?o0000ok>jg_nc^]h02?nc^]h2o`0000Go[j[B00?o0000oiRNfOnHW]T03?nH
W]T00ol0003oNHoLogV?g00;ogV?g003o`000?mIO]goFGkM00;oFGkM0ol00004od:1iP03o`000?l/
Ln7o;7?Q00?o;7?Q00Co0000obachOl/Ln7o;7?Q0_l0000:ob9ni`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool00oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oo
oooo^[Zjoa0@4002ooooo`00;_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Ko
oooo0ol0000AolSDh`03o`000?o=i^WocNKY00cocNKY2Ol00002ol[ej`03o`000?o@mNSod?GX00So
d?GX00?o0000omK^i?oFk^@02?oFk^@00ol0003oen7NomOQgP0:omOQgP03o`000?oDdMKoe=7F00Go
e=7F00?o0000ol[Bh?o:d^000oo:d^02o`0000koaKoE00?o0000ok>jg_nc^]h01Onc^]h2o`0000Oo
[j[B00?o0000oiRNfOnHW]T03OnHW]T00ol0003oNHoLogV?g00:ogV?g003o`000?mIO]goFGkM00Go
FGkM0ol00002od:1iP03o`000?l/Ln7o;7?Q00?o;7?Q00?o0000obachOl/Ln400_l/Ln42o`0000Wo
8WkW00?o0000ooooooooool05oooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooookZj^_l000000_ooool002kooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0Dooooo`05o`000?o7d^;oam;RolOBh_l000003_o8e><2o`0000kocNKY00Co0000
om7^iooAk^OodNkW0ol000000ooAk^Oo0000o`000004o`0000Sod?GX00?o0000omK^i?oFk^@02?oF
k^@00ol0003oen7NomOQgP0:omOQgP03o`000?oDdMKoe=7F00Ooe=7F00Go0000ol[Bh?o:d^3ob];P
o`00000@olFoe@03o`000?nc^]ko/k[N00;o/k[N0ol0000:ojnZdP03o`000?nHW]WoV9kI00coV9kI
00?o0000ogV?g?miSm`02omiSm`00ol0003oFGkMoeUng@07oeUng@?o00001Ol/Ln400ol0003o;7?Q
obach@02obach@03o`000?liONGo000000;o00001olRO^L00ol0003oooooooooo`0Eooooo`04o`00
0?ooooooooooo`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000
oa0@4?nYZJT00_ooool002kooooo0_l0000Zooooo`;o00004_ooool2o`0000Goam;R0_l0000;olSD
h`03o`000?o=i^WocNKY00gocNKY00?o0000om7^iol000000_l00005om7^i`03o`000?oGk^?oenkS
00;oenkS1Ol00002om3ej003o`000?oFk^Coe^kT00Soe^kT00?o0000omOQg_oGhMh02_oGhMh00ol0
003oe=7FomCAeP09omCAeP03o`000?o:d^3o000001;oaKoE00Co0000ok>jg_l0003o00003_n_Z]80
0ol0003oV9kIoiRNf@0<oiRNf@03o`000?miSmcoNHoL00_oNHoL00?o0000oeUngOmIO]d02OmIO]d2
o`0000Co;7?Q00?o0000obachOl/Ln400_l/Ln401?l0003o>GgUocUmiOliOND2o`0000Ko8WkW00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Hooooo`00;_ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo00kooooo00?o0000olOBh_o7d^801oo7d^800ol0003ob=CSolSDh`07
olSDh`03o`000?o=i^WocNKY00gocNKY0ol00007om7^i`03o`000?oGk^?oenkS00SoenkS1?l00008
omK^i003o`000?oGhMkoen7N00[oen7N00?o0000omCAe_oDdMH02ooDdMH00ol0003oaKoEolFoe@0A
olFoe@;o00004?n_Z]800ol0003oV9kIoiRNf@0<oiRNf@03o`000?miSmcoNHoL00_oNHoL00?o0000
oeUngOmIO]d02OmIO]d01?l0003oAWGLo`000?l00003obach@03o`000?l/Ln7o;7?Q00;o;7?Q00?o
0000ocUmiOliOND00_liOND3o`0000Co8WkW00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Gooooo`00;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo0_l0000;
olOBhP03o`000?o8e>?ob=CS00Cob=CS0_l0000=olgVj@?o00002OoAk^L00ol0003oenkSomO^h`09
omO^h`04o`000?oJimkof^ONom[WgPGo00000_oFk^@00ol0003oen7NomOQgP0:omOQgP03o`000?oD
dMKoe=7F00_oe=7F0_l0000BolFoe@03o`000?nn/Lco0000017o[j[B00?o0000oiRNfOnHW]T03?nH
W]T00ol0003oNHoLogV?g00;ogV?g003o`000?mIO]goFGkM00WoFGkM00?o0000odIeg?m6MM`00_l0
00000ol/Ln7o0000obach@03obach@03o`000?liONGo>GgU00Go>GgU0_l00002ob9ni`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool05_ooool002gooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`09ooooo`03o`000?o7d^;oam;R00coam;R0_l00003olSDh`03o`000?o=i^Wo
cNKY00[ocNKY1?l0000:om7^i`03o`000?oGk^?oenkS00WoenkS00?o0000om[Wg_oJimh01ooJimh3
o`0000_oen7N00?o0000omCAe_oDdMH02ooDdMH01?l0003oc/;>olk2c_l0000@olFoe@05o`000?nn
/Lco_[7<okjac?l000004?n_Z]800ol0003oV9kIoiRNf@0=oiRNf@03o`000?miSmcoNHoL00[oNHoL
00?o0000oeUngOmIO]d02OmIO]d00ol0003oAWGLodIeg002odIeg0?o00001?l/Ln400ol0003o>GgU
ocUmi@06ocUmi@;o000000?o8WkWo`000?ooool06?ooool00ol0003oooooooooo`0Fooooo`00;Ooo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Oooooo00?o0000olOBh_o7d^803oo7
d^800ol0003ob=CSo`00000;olgVj@;o00000_o=i^T00ol0003odNkWom7^i`08om7^i`03o`000?oG
k^?oenkS00WoenkS00?o0000om[Wg_oJimh02?oJimh01?l0003ofmcHom_Lf?l00009omOQgP03o`00
0?oDdMKoe=7F00_oe=7F00?o0000olk2c_o>`/h00_o>`/h00ol0003oaKoEolFoe@0;olFoe@;o0000
1?nn/L`00ol0003o[j[BojnZdP0?ojnZdP03o`000?nHW]WoV9kI00coV9kI00?o0000ogV?g?miSm`0
2omiSm`00ol0003oFGkMoeUng@09oeUng@03o`000?m6MMcoAWGL00?oAWGL0ol00003obach@03o`00
0?liONGo>GgU00Oo>GgU0ol0000Hooooo`;o00005oooool002gooooo0ol0000`ooooo`03o`000?oo
oooooooo00Cooooo0_l0000BolOBhP?o00002?o=i^T3o`0000?ocNKY00?o0000om7^iooAk^L01ooA
k^L2o`0000_oenkS00?o0000om[Wg_oJimh02?oJimh00ol0003ofmcHom_Lf002om_Lf0;o00001_oG
hMh00ol0003oe=7FomCAeP0;omCAeP03o`000?o>`/koc/;>00Coc/;>00?o0000olFoeOo5_mD02Oo5
_mD00ol0003o_[7<okjac005okjac003o`000?n_Z];o[j[B00oo[j[B00?o0000oiRNfOnHW]T02OnH
W]T8o`0000WoNHoL00?o0000oeUngOmIO]d02?mIO]d00ol0003oAWGLodIeg005odIeg0?o00000_l/
Ln400ol0003o>GgUocUmi@09ocUmi@03o`000?oooooooooo01Oooooo00?o0000ooooooooool05?oo
ool002gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`02ooooo`03o`000?o7d^;o
am;R017oam;R00Co0000olcPioo<h>Ooc>3W0_l00003olgVj@?o00001?o=i^T2o`0000WodNkW00?o
0000omO^hooGk^<02_oGk^<00ol0003of^ONom[WgP08om[WgP03o`000?oKg=SofmcH00GofmcH0_l0
0003omOQgP03o`000?oDdMKoe=7F00_oe=7F00?o0000olk2c_o>`/h01_o>`/h00ol0003oaKoEolFo
e@07olFoe@03o`000?nn/Lco_[7<00Oo_[7<00?o0000ojnZd_n_Z]803_n_Z]800ol0003oV9kIoiRN
f@02oiRNf@Oo00000onIULl00ol0003oPHWBoh69dP02oh69dPOo00000_miSm`00ol0003oFGkMoeUn
g@09oeUng@03o`000?m6MMcoAWGL00CoAWGL00?o0000odIeg?m6MM`00ol0000;ocUmi@03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool05?ooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooooooo03;ooooo00Co0000ooooool0003o00004oo7d^800ol0003oc>3W
olcPi`04olcPi`?o00001_o=i^T00ol0003odNkWom7^i`08om7^i`03o`000?oGk^?oenkS00[oenkS
00?o0000om[Wg_oJimh02?oJimh00ol0003ofmcHom_Lf008om_Lf003o`000?oGhMko000000goe=7F
00?o0000olk2c_o>`/h01oo>`/h00ol0003oaKoEolFoe@06olFoe@03o`000?nn/Lco_[7<00So_[7<
00?o0000ojnZd_n_Z]803_n_Z]85o`0000_oVIG?00?o0000oh69d_n1RM802?n1RM85o`0000[oFGkM
00?o0000odIeg?m6MM`01?m6MM`01?l0003oAWGLodIeg?m6MM`2o`0000_o>GgU00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Cooooo`008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo00?o0000ooooooooool0<oooool00ol0003oam;RolOBhP0AolOBhP;o00001?o<h>L3o`0000;o
c>3W0_l00004olgVj@03o`000?oAk^OodNkW00SodNkW00?o0000omO^hooGk^<02_oGk^<00ol0003o
f^ONom[WgP08om[WgP03o`000?oKg=SofmcH00[ofmcH0_l0000<omCAeP03o`000?o>`/koc/;>00Wo
c/;>00?o0000olFoeOo5_mD00oo5_mD2o`0000co_[7<00?o0000ojnZd_n_Z]802_n_Z]83o`000003
ojbOb_l0003oVIG?00goVIG?00?o0000oh69d_n1RM802on1RM800ol0003oJGgDo`000002o`0000Oo
FGkM00?o0000odIeg?m6MM`01Om6MM`00ol0003oAWGLodIeg002odIeg0;o00002_liOND00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo01?ooooo000Rooooo`05oa0@4?ooooooooooooooool@
41001Oooool00ol0003oooooooooo`0booooo`?o00004_o7d^801?l0003oc>3WolcPioo<h>L3o`00
00Ooc>3W0_l000000oo=i^Wo0000om7^i`09om7^i`03o`000?oGk^?oenkS00[oenkS00?o0000om[W
g_oJimh02?oJimh00ol0003ofmcHom_Lf00:om_Lf004o`000?oGcm7oeloAo`0000[oe=7F00?o0000
olk2c_o>`/h02oo>`/h01Ol0003oaKoEolFoeOo5_mGo000000ko_[7<00?o0000ojnZd_n_Z]802?n_
Z]82o`0000Go[9o:00?o0000oiVEconIULl03?nIULl00ol0003oPHWBoh69dP0;oh69dP04o`000?mY
OMCoJGgDofUme0;o00001_mIO]d00ol0003oAWGLodIeg005odIeg006o`000?m6MMcoAWGLodIeg?l0
003oCGgP0ol00007ocUmi@03o`000?oooooooooo01Oooooo00?o0000ooooooooool04_ooool002;o
oooo00Go0000ooooooooooooooooo`000005ooooo`;o0000<Oooool2o`0000?o`/oT00?o0000olOB
h_o7d^803Oo7d^82o`000004olcPiol0003o0000o`0000_oc>3W1?l00008om7^i`03o`000?oGk^?o
enkS00[oenkS00?o0000om[Wg_oJimh02?oJimh00ol0003ofmcHom_Lf00:om_Lf003o`000?oGcm7o
eloA00;oeloA00?o0000omCAe_oDdMH01_oDdMH00ol0003oc/;>olk2cP0=olk2cP03o`000?o5_mGo
0000013o_[7<00?o0000ojnZd_n_Z]801On_Z]82o`0000Oo[9o:00?o0000oiVEconIULl03?nIULl0
0ol0003oPHWBoh69dP0;oh69dP03o`000?mYOMCoJGgD00?oJGgD0ol00003oeUng@03o`000?m6MMco
AWGL00GoAWGL00?o0000odIeg?m6MM`00_m6MM`01?l0003oCGgPodemh?m=ON03o`0000Go>GgU00?o
0000ooooooooool05_ooool2o`0001?ooooo000Rooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`0_ooooo`03o`000?o2cnCo`/oT00Co`/oT0_l0000<olOBhPCo00003Oo<
h>L00ol0003odNSVom7XiP02om7XiPGo00000_oAk^L00ol0003oenkSomO^h`0:omO^h`03o`000?oJ
imkof^ON00Sof^ON00?o0000om_Lf?oKg=P02_oKg=P00ol0003oeloAomO?d@04omO?d@;o00001OoD
dMH00ol0003oc/;>olk2cP0>olk2cP;o00004_nn/L`01?l0003o[j[BojnZd_n_Z]83o`0000[o[9o:
00?o0000oiVEconIULl03?nIULl00ol0003oPHWBoh69dP0;oh69dP03o`000?mYOMCoJGgD00GoJGgD
0_l00002oeUng@03o`000?m6MMcoAWGL00GoAWGL00Go0000odIeg?m6MMcoAWGLo`000006odemh0;o
00001?liOND00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo017ooooo000Rooooo`05oa0@
4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`0]ooooo`;o00002Oo2cn@2o`0000Wo
am;R0_l0000?olcPi`03o`000?oAj>KodNSV00SodNSV1?l0000:omO^h`03o`000?oJimkof^ON00So
f^ON00?o0000om_Lf?oKg=P02_oKg=P00ol0003oeloAomO?d@07omO?d@05o`000?oDdMKoe=7FomCA
e_l000004?o>`/h00ol0003ob;G8o`00000Bokjac004o`000?n_Z];o0000o`0000go[9o:00?o0000
oiVEconIULl03?nIULl00ol0003oPHWBoh69dP0;oh69dP03o`000?mYOMCoJGgD00OoJGgD0ol00008
odIeg005o`000?m6MMcoAWGLodIeg?l000001om=ON03o`000003ocUmiOl0003ooooo01Sooooo00?o
0000ooooooooool04?ooool002;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oo
oooooooo02_ooooo0_l0000=ol;?i003o`000?o7d^;oam;R00?oam;R0ol0000?olcPi`;o00002_oA
j>H00ol0003oe^SRomKXhP02omKXhP?o00001_oGk^<00ol0003of^ONom[WgP08om[WgP03o`000?oK
g=SofmcH00[ofmcH00?o0000omO?dOoGcm402OoGcm400ol0003oe=7Fo`00000@olk2cP05o`000?o8
]LSob;G8olReb?l000004Onn/L`2o`00013o[9o:00?o0000oiVEconIULl03?nIULl00ol0003oPHWB
oh69dP0;oh69dP03o`000?mYOMCoJGgD00WoJGgD0_l00006odIeg005o`000?m6MMcoAWGLodIeg?l0
00002_m=ON03o`0001Wooooo00?o0000ooooooooool03oooool002;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o0000:oooool00ol0003o`/oTol;?i00>ol;?i0Ko00004?o<h>L00ol0003o
dNSVom7XiP09om7XiP03o`000?oFj>;oe^SR00Koe^SR0ol00002omO^h`03o`000?oJimkof^ON00So
f^ON00?o0000om_Lf?oKg=P02_oKg=P00ol0003oeloAomO?d@0;omO?d@03o`000?o>`/koc/;>00ko
c/;>00?o0000olReb?o8]LP00_o8]LP00ol0003o_[7<okjac00>okjac003o`000?niYlKo0000013o
[9o:00?o0000oiVEconIULl03?nIULl00ol0003oPHWBoh69dP0;oh69dP03o`000?mYOMCoJGgD00Wo
JGgD00?o0000oeUge_l000000_l00004odIeg005o`000?m6MMcoAWGLodIeg?l000003?m=ON000ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00oooooo000[ooooo`03o`000?oooooooooo02Wo
oooo0_l0000@ol;?i0Co000000?oam;Ro`000?o<h>L03_o<h>L2o`0000_odNSV00?o0000omKXh_oF
j>802_oFj>83o`0000Wof^ON00?o0000om_Lf?oKg=P02_oKg=P00ol0003oeloAomO?d@0<omO?d@03
o`000?o>`/koc/;>00goc/;>00?o0000olReb?o8]LP01?o8]LP00ol0003o_[7<okjac00<okjac005
o`000?niYlKo^JO6okVWa_l000004?n/WlX00ol0003oVIG?oiVEc`0;oiVEc`03o`000?n1RM;oPHWB
00coPHWB00?o0000ofUme?mYOM@02OmYOM@01?l0003oFGOFoeUge_mIMmH3o`0000;oAWGL00Go0000
odIeg?m6MMcoAWGLo`00000;odemh003o`000?oooooooooo01Oooooo00?o0000ooooooooool03_oo
ool002_ooooo00?o0000ooooooooool09oooool2o`0000oo`/oT0ol00003ol;?i0?o00003_o<h>L0
0ol0003odNSVom7XiP0:om7XiP03o`000?oFj>;oe^SR00[oe^SR00Co0000omWRgOoIh]gofN;M0ol0
0005om[WgP03o`000?oKg=SofmcH00[ofmcH00?o0000omO?dOoGcm403?oGcm400ol0003od/?;o`00
000=olk2cP03o`000?o8]LSob;G800Kob;G800?o0000okjac?nn/L`02Onn/L`2o`0000Co^JO600?o
0000ojbOb_n/WlX03_n/WlX00ol0003oVIG?oiVEc`0<oiVEc`03o`000?n1RM;oPHWB00_oPHWB00?o
0000ofUme?mYOM@02OmYOM@00ol0003oFGOFoeUgeP04oeUgeP;o000000GoAWGLo`000?m6MMcoAWGL
o`00000<odemh003o`000?oooooooooo01Gooooo00?o0000ooooool000003oooool002_ooooo00?o
0000ooooooooool09_ooool00ol0003o`/oTol;?i00<ol;?i0?o00001Oo2cn@01?l0003oa]_YolKK
jOo6fnT2o`0000_oc>3W00?o0000om7Xi_oAj>H02_oAj>H00ol0003oe^SRomKXhP0:omKXhP03o`00
0?oIh]gofN;M00GofN;M0ol000000ooJimko0000om_Lf00;om_Lf003o`000?oGcm7oeloA00coeloA
00Go0000om;3booB`l_od/?;o`00000;olk2cP03o`000?o8]LSob;G800Oob;G800?o0000okjac?nn
/L`02?nn/L`00ol0003o^JO6okVWaP05okVWaP03o`000?n/Wl[o[9o:00go[9o:00?o0000oiVEconI
ULl03?nIULl00ol0003oPHWBoh69dP0;oh69dP03o`000?mYOMCoJGgD00[oJGgD00?o0000oeUge_mI
MmH01OmIMmH3o`0000;oAWGL00?o0000odemh?m=ON002Om=ON000ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00gooooo000[ooooo`03o`000?oooooooooo02Cooooo0ol0000;ol;?i0?o0000
1_o2cn@2o`0000Koa]_Y0_l00007olcPi`;o00003?oAj>H00ol0003oe^SRomKXhP0:omKXhP03o`00
0?oIh]gofN;M00WofN;M0_l0000;om_Lf003o`000?oGcm7oeloA00coeloA00?o0000om;3booB`l/0
0_oB`l/00ol0003oc/;>olk2cP08olk2cP03o`000?o8]LSob;G800Wob;G800?o0000okjac?nn/L`0
1_nn/L`00ol0003o^JO6okVWaP06okVWaP03o`000?n/Wl[o[9o:00ko[9o:00?o0000oiVEconIULl0
3?nIULl00ol0003oPHWBoh69dP0;oh69dP03o`000?mYOMCoJGgD00WoJGgD00?o0000oeUge_mIMmH0
1omIMmH4o`0000coCGgP00?o0000ooooooooool05oooool00ol0003oooooooooo`0<ooooo`00:ooo
ool2o`0002?ooooo0_l00003okO=jP03o`000?o2cnCo`/oT00Go`/oT0ol00008ol;?i003o`000?o6
fnWoa]_Y00Soa]_Y0_l00004olcPi`03o`000?oAj>KodNSV00_odNSV00?o0000omKXh_oFj>802_oF
j>800ol0003ofN;MomWRg@09omWRg@03o`000?oIfMOofMWG00;o00002?oKg=P00ol0003oeloAomO?
d@0<omO?d@03o`000?oB`l_od/?;00Cod/?;00?o0000olk2c_o>`/h01_o>`/h00ol0003ob;G8olRe
b00:olReb003o`000?nn/Lco_[7<00Go_[7<00?o0000okVWa_niYlH02?niYlH00ol0003o[9o:ojbO
bP0=ojbObP03o`000?nIULooVIG?00coVIG?00?o0000oh69d_n1RM802on1RM800ol0003oJGgDofUm
e00:ofUme003o`000?mIMmKoFGOF00OoFGOF00?o0000oeUge_mIMmH00_l0000;odemh003o`000?oo
oooooooo01Gooooo0ol0000=ooooo`00:oooool00ol0003oooooooooo`0Pooooo`;o00001_ngcNX0
1?l0003o`/oTol;?i?o2cn@3o`0000Wo`/oT0_l0000=olKKj@;o000000?oc>3Wo`000?oAj>H03?oA
j>H00ol0003oe^SRomKXhP0:omKXhP03o`000?oIh]gofN;M00WofN;M00?o0000omWIeooIfML00ooI
fML3o`0000CofmcH00?o0000omO?dOoGcm403?oGcm400ol0003od/?;om;3b`06om;3b`03o`000?o>
`/koc/;>00Coc/;>00?o0000olReb?o8]LP03?o8]LP00ol0003o_[7<okjac002okjac0;o00002oni
YlH00ol0003o[9o:ojbObP0>ojbObP03o`000?nIULooVIG?00WoVIG?2?l00009oh69dP03o`000?mY
OMCoJGgD00[oJGgD00?o0000oeUge_mIMmH01omIMmH01?l0003oFGOFo`000?mMO]/3o`0000SoCGgP
00?o0000ooooooooool04_ooool3o`0000;ooooo00?o0000ooooooooool02oooool002_ooooo00?o
0000ooooooooool07_ooool2o`0000Wo]lgZ0ol0000;ol;?i003o`000?o6fnWoa]_Y00koa]_Y0ol0
000<om7XiP03o`000?oFj>;oe^SR00Woe^SR0_l0000;omWRg@03o`000?oIfMOofMWG00OofMWG0_l0
00000ooKg=So0000omO?d@0=omO?d@03o`000?oB`l_od/?;00Sod/?;00?o0000olk2c_o>`/h00_o>
`/h00ol0003ob;G8olReb00>olReb004o`000?nn/Lco_[7<o`0000ko^JO600?o0000ojbOb_n/WlX0
3On/WlX00ol0003oVIG?oiVEc`02oiVEc`Oo00000onITLT00ol0003oQhO<ohN7c002ohN7c0Oo0000
0_n1RM800ol0003oJGgDofUme00:ofUme003o`000?mIMmKoFGOF00OoFGOF00Co0000oeUge_mIMmKo
00000omMO]/2o`0000OoCGgP00?o0000ooooooooool03_ooool3o`0000Gooooo00?o0000oooooooo
ool02oooool002[ooooo00?o0000ooooooooool07_ooool00ol0003o]lgZokO=jP07okO=jP?o0000
00?o]lgZo`000?o2cn@02?o2cn@2o`00013oa]_Y00Co0000ol_RjOo;h^Wobn;Y0ol00008om7XiP03
o`000?oFj>;oe^SR00Woe^SR00?o0000omWRgOoIh]d02_oIh]d00ol0003ofMWGomWIe`0:omWIe`;o
00003OoGcm400ol0003od/?;om;3b`09om;3b`05o`000?o>`/koc/;>olk2c_l000004Oo8]LP00ol0
003o_[7<o`00000?okVWaP03o`000?n/Wl[o[9o:00go[9o:1Ol0000;oiVAb@03o`000?n7QlcoQhO<
00SoQhO<1_l0000:ofUme003o`000?mIMmKoFGOF00OoFGOF00?o0000oeUge_l000001OmMO]/3o`00
00CoCGgP00?o0000ooooooooool02_ooool4o`0000Sooooo00?o0000ooooooooool02oooool002[o
oooo00?o0000ooooooooool07?ooool2o`0000Oo]lgZ0ol00005okO=jP;o00001_o2cn@00ol0003o
a]_YolKKj@0?olKKj@03o`000?o;h^Wobn;Y00Gobn;Y0_l00005om7XiP03o`000?oFj>;oe^SR00Wo
e^SR00?o0000omWRgOoIh]d02_oIh]d00ol0003ofMWGomWIe`0;omWIe`03o`000?oGc]7o000000_o
eloA00?o0000om;3booB`l/02ooB`l/00ol0003oc/;>o`00000BolReb0;o00004?niYlH00ol0003o
[9o:ojbObP0:ojbObP?o000000?oZIW6o`000?nITLT03OnITLT00ol0003oQhO<ohN7c00;ohN7c003
o`000?mdO/ooM7k?00Co00001_mYOM@00ol0003oFGOFoeUgeP08oeUgeP03o`000?mIMmKo000000Oo
GGkK0_l00003odemh003o`000?oooooooooo00Kooooo0ol0000<ooooo`03o`000?oooooooooo00_o
oooo000Zooooo`;o00006oooool2o`0000Ko]lgZ0ol0000:okO=jP04o`000?o2cnCo`/oTol;?i0;o
00004?o6fnT2o`0000[obn;Y0ol000000ooAj>Ko0000omKXhP0:omKXhP03o`000?oIh]gofN;M00[o
fN;M00?o0000omWIeooIfML02ooIfML01Ol0003oelkAomO>dOoGc]7o000000WoeloA00?o0000om;3
booB`l/03OoB`l/00ol0003ob;G8olReb00@olReb003o`000?o2[<Co0000017o^JO600?o0000ojbO
b_n/WlX01on/WlX2o`0000GoZIW600?o0000oiVAbOnITLT02onITLT00ol0003oQhO<ohN7c00<ohN7
c003o`000?mdO/ooM7k?00?oM7k?0ol00004ofUme003o`000?mIMmKoFGOF00OoFGOF00?o0000oeUg
e_l000002OmMO]/2o`0000;oCGgP00?o0000ooooooooool00_ooool3o`00013ooooo00?o0000oooo
ooooool02_ooool002[ooooo00?o0000ooooooooool06?ooool2o`0000Go]lgZ0ol0000>okO=jP03
o`000?o2cnCo0000017oa]_Y00?o0000ol_RjOo;h^T03?o;h^T4o`0000Woe^SR00?o0000omWRgOoI
h]d02_oIh]d00ol0003ofMWGomWIe`0;omWIe`03o`000?oGc]7oelkA00?oelkA00?o0000omO?dOoG
cm401OoGcm400ol0003od/?;om;3b`0>om;3b`03o`000?o8]LSob;G800oob;G800Go0000ol:/a?o2
[<Co`Zc4o`00000@okVWaP03o`000?n/Wl[o[9o:00Go[9o:0_l00007ojVIaP03o`000?nITLWoVI79
00coVI7900?o0000ohN7c?n7Ql`02on7Ql`00ol0003oM7k?ogAnc`06ogAnc`Go00002_mIMmH00ol0
003oFGOFo`00000:oeenf`Oo00004oooool00ol0003oooooooooo`0:ooooo`00:_ooool00ol0003o
ooooooooo`0Fooooo`?o00000ongcNX3o`00017o]lgZ0ol0000?olKKj@;o00003_o;h^T00ol0003o
cn?VoloSiP02oloSiP?o00001OoFj>800ol0003ofN;MomWRg@0:omWRg@03o`000?oIfMOofMWG00_o
fMWG00?o0000omO>dOoGc]401OoGc]400ol0003oeloAomO?d@03omO?d@03o`000?oB`l_od/?;00ko
d/?;00?o0000olfha_l000003oo8]LP00ol0003o`Zc4ol:/a002ol:/a003o`000?niYlKo^JO600oo
^JO600Co0000ojbOb_n/Wl[o[9o:0ol00009ojVIaP03o`000?nITLWoVI7900coVI7900?o0000ohN7
c?n7Ql`02on7Ql`00ol0003oM7k?ogAnc`0:ogAnc`?o00002OmIMmH2o`0000goGGkK00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0:ooooo`00:_ooool00ol0003oooooooooo`0Cooooo`?o
00000onUb?83o`0001;o]lgZ0_l00003ok[Hk`;o00003?o6fnT00ol0003obn;Yol_Rj@0=ol_Rj@03
o`000?o?hnKocn?V00Kocn?V0ol000000ooFj>;o0000omWRg@0;omWRg@03o`000?oIfMOofMWG00_o
fMWG00?o0000omO>dOoGc]401ooGc]401Ol0003oeloAomO?dOoGcm7o0000013od/?;00Go0000olfh
a_o=^<KocKS6o`00000=olReb003o`000?o2[<Co`Zc400Co`Zc400?o0000okVWa_niYlH03_niYlH0
1?l0003o[9o:o`000?l0000=ojVIaP03o`000?nITLWoVI7900coVI7900?o0000ohN7c?n7Ql`02on7
Ql`00ol0003oM7k?ogAnc`0:ogAnc`04o`000?mWNm?o0000o`0000SoFGOF0_l0000<oeenf`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool02_ooool002[ooooo0_l0000Aooooo`?o00000onU
b?83o`000003ojG8l_l0003o]lgZ013o]lgZ0_l00007ok[Hk`03o`000?o6fnWoa]_Y00Soa]_Y00?o
0000ol_RjOo;h^T03?o;h^T2o`0000_ocn?V0ol0000;omWRg@03o`000?oIfMOofMWG00_ofMWG00?o
0000omO>dOoGc]402OoGc]400ol0003oeloAo`00000@om;3b`03o`000?o=^<KocKS600;ocKS600?o
0000olReb?o8]LP02_o8]LP00ol0003o`Zc4ol:/a005ol:/a003o`000?niYlKo^JO600ko^JO60_l0
000?ojVIaP03o`000?nITLWoVI7900coVI7900?o0000ohN7c?n7Ql`02on7Ql`00ol0003oM7k?ogAn
c`0;ogAnc`03o`000?mWNm?oIg_C00?o00001OmIMmH2o`0000goGGkK00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0:ooooo`00:Oooool00ol0003oooooooooo`0>ooooo`?o00001?nUb?82
o`0000GoYLSb0_l0000=okO=jP;o00002_njf>l2o`0000Koa]_Y0_l0000>ol_Rj@03o`000?o?hnKo
cn?V00[ocn?V00Co0000om?NhOoCg^7odmkQ0_l00008omWRg@03o`000?oIfMOofMWG00_ofMWG00?o
0000omO>dOoGc]402ooGc]400ol0003od/?;om;3b`0>om;3b`03o`000?o=^<KocKS600CocKS600?o
0000olReb?o8]LP01oo8]LP2o`0000Wo`Zc400?o0000okVWa_niYlH03?niYlH00ol0003o]Z73o`00
000@ojVIaP03o`000?nITLWoVI7900coVI7900?o0000ohN7c?n7Ql`02_n7Ql`00ol0003oM7k?ogAn
c`0;ogAnc`03o`000?mWNm?oIg_C00?oIg_C0_l00004oeUgeP;o00003?mMO]/00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00[ooooo00000ol0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0;ooooo`?o00001?nUb?83o`0000Wo
YLSb00?o0000okO=j_ngcNX02OngcNX00ol0003o^]S_ok[Hk`0<ok[Hk`;o00000oo6fnT00ol0003o
bn;Yol_Rj@0<ol_Rj@;o00003?o?hnH00ol0003odmkQom?Nh@04om?Nh@?o00001?oIh]d00ol0003o
fMWGomWIe`0;omWIe`03o`000?oGc]7oelkA00coelkA00?o0000om;3booB`l/03OoB`l/00ol0003o
cKS6olfhaP06olfhaP03o`000?o8]LSob;G800Gob;G800?o0000ol:/a?o2[<@02Oo2[<@00ol0003o
^JO6okVWaP0:okVWaP;o00000onfXL<00ol0003oZIW6ojVIaP0=ojVIaP03o`000?nITLWoVI7900co
VI7900?o0000ohN7c?n7Ql`02on7Ql`00ol0003oM7k?ogAnc`0;ogAnc`03o`000?mWNm?oIg_C00Co
Ig_C0_l00003oeUgeP03o`000?mMO]_oGGkK00_oGGkK00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0:ooooo`0000?ooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo00Oooooo1Ol00003ojG8lP?o00003OnUb?82o`0000Oo]lgZ0_l0000Aok[H
k`03o`000?o6fnWo000000kobn;Y00?o0000oloSi_o?hnH02oo?hnH00ol0003odmkQom?Nh@08om?N
h@;o000000?ofN;Mo`000?oIfML03?oIfML00ol0003oelkAomO>d@0<omO>d@03o`000?oB`lco0000
00god/?;00?o0000olfha_o=^<H01oo=^<H00ol0003ob;G8olReb004olReb003o`000?o2[<Co`Zc4
00_o`Zc400?o0000okVWa_niYlH02?niYlH00ol0003o]Z73okJQ``03okJQ``03o`000?nYVLKoZIW6
00koZIW600?o0000oiVAbOnITLT02onITLT00ol0003oQhO<ohN7c00;ohN7c003o`000?mdO/ooM7k?
00_oM7k?00?o0000ofMkdomWNm<01_mWNm<5o`0000coGGkK00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0:ooooo`000_ooool00ol@413oooooooooo`09ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`07o`0000GoQ/3j0ol0000BojG8lP03o`000?ngcN[o]lgZ00;o]lgZ0_l0000C
ok[Hk`?o00003Oo;h^T00ol0003ocn?VoloSiP0;oloSiP03o`000?oCg^7odmkQ00[odmkQ0ol0000<
omWIe`03o`000?oGc]7oelkA00coelkA00Go0000om;3c?oB`lcod/?<o`00000;om;3b`03o`000?o=
^<KocKS600WocKS600?o0000olReb?o8]LP00_o8]LP00ol0003o`Zc4ol:/a00<ol:/a003o`000?ni
YlKo^JO600Ko^JO60_l00007okJQ``03o`000?nYVLKoZIW600goZIW600?o0000oiVAbOnITLT03?nI
TLT00ol0003oQhO<ohN7c00;ohN7c003o`000?mdO/ooM7k?00_oM7k?00?o0000ofMkdomWNm<02?mW
Nm<2o`0000goGGkK00?o0000ooooooooool04_ooool00ol0003oooooooooo`09ooooo`000_ooool0
0ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Oooooo00?oMgMgoc8b<_ooool00oooool4o`0000WoQ/3j0ol000000on6`?[o0000
ojG8lP0CojG8lP04o`000?ngcN[o0000o`0001?o^]S_0_l00003okgNl0?o00002?o;h^T2o`0000go
cn?V00?o0000om?NhOoCg^402_oCg^401?l0003odmOKom?GfooCem/2o`0000WofMWG00?o0000omO>
dOoGc]403?oGc]400ol0003od/?<om;3c003om;3c003o`000?oB`l_od/?;00Ood/?;00?o0000olfh
a_o=^<H02_o=^<H01Ol0003ob;G8olReb?o8]LSo0000013o`Zc400?o0000okVWa_niYlH01?niYlH0
0ol0003o]Z73okJQ``07okJQ``03o`000?nYVLKoZIW600goZIW600?o0000oiVAbOnITLT03?nITLT0
0ol0003oQhO<ohN7c00;ohN7c003o`000?mdO/ooM7k?00_oM7k?00?o0000ofMkdomWNm<02_mWNm<3
o`0000[oGGkK00?o0000ooooooooool04_ooool00ol0003oooooooooo`09ooooo`000_ooool00ol0
003oooooooooo`09ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`?o00001on6`?X3o`0000GoQ/3j
0_l0000BojG8lP?o00004_njf>l2o`0000So_Mk`0_l00005ol_Rj@03o`000?o?hnKocn?V00_ocn?V
0_l0000<om?Nh@03o`000?oCem_odmOK00CodmOK0_l00006omWIe`03o`000?oGc]7oelkA00coelkA
00?o0000om;3c?oB`l`01OoB`l`00ol0003od/?;om;3b`05om;3b`03o`000?o=^<KocKS600cocKS6
00?o0000olReb?l000004Oo2[<@00ol0003o^JO6okVWaP03okVWaP03o`000?nfXL?o]Z7300So]Z73
00?o0000ojVIa_nYVLH03_nYVLH00ol0003oVI79oiVAb@0<oiVAb@03o`000?n7QlcoQhO<00[oQhO<
00?o0000ogAncomdO/l03?mdO/l00ol0003oIg_CofMkd`09ofMkd`;o000000CoJX7Ho`000?l0003o
00002?mMO]/00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo0002ooooo`03oa0@
4?oooooooooo00Wooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000?oQ/3j0ol0000:ohK0
nP03o`000?nUb?;oYLSb00coYLSb0ol00003oj?Cn0;o00003_njf>l2o`0000co_Mk`0ol000000oo;
h^Wo0000oloSiP0<oloSiP03o`000?oCg^7odmkQ00_odmkQ00?o0000om?GfooCem/01ooCem/00ol0
003ofMWGomWIe`02omWIe`03o`000?oGc]7oelkA00coelkA00?o0000om;3c?oB`l`01ooB`l`00ol0
003od/?;om;3b`03om;3b`03o`000?o=^<KocKS600kocKS600?o0000ol:/a?o2[<@04Oo2[<@00ol0
003o^JO6okVWaP02o`0000co]Z7300?o0000ojVIa_nYVLH03OnYVLH00ol0003oVI79oiVAb@0<oiVA
b@03o`000?n7QlcoQhO<00_oQhO<00?o0000ogAncomdO/l02omdO/l00ol0003oIg_CofMkd`0:ofMk
d`03o`000?mZPMSoJX7H00;oJX7H0ol00005oeenf`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool02Oooool00003oooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`06ooooo`04o`000?oooooo
ooooooooo`?o00003_n6`?X2o`0000WoYLSb0ol00008oj?Cn003o`000?njf>oo^]S_00[o^]S_00?o
0000okgNl?nmg_003_nmg_03o`0000cocn?V00?o0000om?NhOoCg^402ooCg^400ol0003odmOKom?G
f`09om?Gf`;o000000?ofMWGo`000?oGc]403OoGc]400ol0003od/?<om;3c009om;3c005o`000?oB
`l_od/?;om;3bol000004Oo=^<H00ol0003o`Zc4ol:/a00Aol:/a003o`000?niYlKo000000ko]Z73
00?o0000ojVIa_nYVLH03_nYVLH00ol0003oVI79oiVAb@0;oiVAb@03o`000?n7QlcoQhO<00_oQhO<
00?o0000ogAncomdO/l02omdO/l00ol0003oIg_CofMkd`0:ofMkd`;o00001_mZPMP3o`0000?oGGkK
00?o0000ooooooooool04?ooool00ol0003oooooooooo`09ooooo`0000?o0000oc8b<_o^k^h02ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co
00001Oooool4o`0000;ooooo00?o0000ohK0n_n6`?X03_n6`?X00ol0003oYLSbojG8lP03ojG8lP?o
00003?nSdoP2o`0000So^]S_0_l0000@okgNl004o`000?o2h>ko`^3^ol;PkP?o00002?o?hnH00ol0
003odmkQom?Nh@0;om?Nh@03o`000?oCem_odmOK00_odmOK0ol0000=omO>d@03o`000?oB`lcod/?<
00_od/?<00?o0000om;3bol000004Oo=^<H00ol0003oak33o`00000Bol:/a0;o00004?nfXL<00ol0
003oZIW6ojVIaP0=ojVIaP03o`000?nITLWoVI7900WoVI792ol00005ohN7c003o`000?mdO/ooM7k?
00coM7k?00?o0000ofMkdomWNm<02_mWNm<2o`0000SoJX7H1?l0000Booooo`03o`000?oooooooooo
00Wooooo000Xooooo`;o00001Oooool2o`0000ooQ/3j00?o0000ojG8l_l000000_l0000Aoj?Cn0;o
00001?njf>l2o`00013o_Mk`0_l00007ol;PkP;o00001Oo?hnH00ol0003odmkQom?Nh@0:om?Nh@;o
00003OoCem/01Ol0003od/gEom;=eOoBcMGo000000_oelkA00?o0000om;3c?oB`l`03OoB`l`00ol0
003ocKS6olfhaP0?olfhaP05o`000?o7/<?oak33olN``ol000004?o2[<@00ol0003o_ZO2o`00000@
okJQ``03o`000?nYVLKoZIW600goZIW600?o0000oiVAbOnITLT00_nITLT7o`0000?oVi3800?o0000
oh^8bon;R</01On;R</:o`0000[oM7k?00?o0000ofMkdomWNm<02_mWNm<00ol0003oJX7Ho`00000:
ofZ1f0;o00004Oooool00ol0003oooooooooo`09ooooo`00:_ooool00ol0003oooooooooo`04oooo
o`03o`000?n6`?[oQ/3j00[oQ/3j1Ol0000Eoj?Cn004o`000?njf>oo0000o`00017o_Mk`00?o0000
ol;Pk_o2h>h02Oo2h>h3o`000003oloSi_l0003odmkQ00_odmkQ00?o0000om?GfooCem/03?oCem/0
0ol0003od/gEom;=e@03om;=e@03o`000?oGc]7oelkA00OoelkA00?o0000om;3c?oB`l`03OoB`l`2
o`00013ocKS600?o0000olN``oo7/<<00_o7/<<00ol0003o`Zc4ol:/a00=ol:/a005o`000?nnYl;o
_ZO2okjW`_l000004?nfXL<00ol0003oZIW6ojVIaP0<ojVIaPGo00002onKT<P00ol0003oRhS;oh^8
b`0:oh^8b`04o`000?mkP/koNh;>og^2cPGo00001_mdO/l00ol0003oIg_CofMkd`0:ofMkd`;o0000
2omZPMP00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo000[ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ohK0n_n6`?X00_n6`?X7o`0000GoNLSo0_l0000Coj?Cn0?o00004?nm
g_02o`0000ko`^3^0ol0000;om?Nh@03o`000?oCem_odmOK00codmOK00?o0000om;=eOoBcMD01OoB
cMD00ol0003oelkAomO>d@05omO>d@03o`000?oB`lcod/?<00god/?<00Co0000oljjaoo>^/Oo0000
3_o=^<H00ol0003oak33olN```04olN```03o`000?o2[<Co`Zc400_o`Zc400?o0000okjW`_nnYl80
0_nnYl800ol0003o]Z73okJQ``0>okJQ``03o`000?nYVLKoZIW600WoZIW60ol000000onXV<Go0000
oi^@b00=oi^@b003o`000?n;R<_oRhS;00_oRhS;00?o0000og^2c_mkP/h01OmkP/h5o`000003ogAn
col0003oIg_C00_oIg_C00?o0000ofZ1f?l000002omZPMP00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Sooooo000/ooooo`03o`000?oooooooooo00Cooooo1?l0000>ogW8o`03o`000?nS
doSoXm?h00goXm?h0ol00003oj;Jn`;o00003?nmg_02o`0000ko`^3^0_l00003olGMj`;o00002?oC
g^400ol0003odmOKom?Gf`0<om?Gf`03o`000?oBcMGod/gE00Ood/gE00?o0000omO>dOoGc]400ooG
c]400ol0003od/?<om;3c00=om;3c003o`000?o>^/Ooc[[700;oc[[700?o0000olfha_o=^<H02_o=
^<H00ol0003oak33olN```05olN```03o`000?o2[<Co`Zc400[o`Zc400?o0000okjW`_nnYl801?nn
Yl800ol0003o]Z73okJQ``0=okJQ``03o`000?nYVLKoZIW600KoZIW60ol00005ojRHa@03o`000?nK
T<SoVi3800coVi3800?o0000oh^8bon;R</02_n;R</00ol0003oNh;>og^2cP0:og^2cPGo00002OmW
Nm<01?l0003oJX7HofZ1f?l0000:ofZ1f003o`000?oooooooooo00oooooo00?o0000ooooooooool0
2?ooool002gooooo0_l00006ooooo`;o00003omib?l2o`0000[oXm?h0ol00008oj;Jn`?o00002?nm
g_000ol0003o`^3^ol;PkP0=ol;PkP03o`000?o5gN_oaMg[00GoaMg[0ol00004om?Nh@03o`000?oC
em_odmOK00codmOK00?o0000om;=eOoBcMD02OoBcMD01Ol0003oelkAomO>dOoGc]7o000000ood/?<
00?o0000oljjaoo>^/L00oo>^/L00ol0003ocKS6olfhaP09olfhaP03o`000?o7/<?oak3300Ooak33
00?o0000ol:/a?o2[<@01oo2[<@2o`0000Oo_ZO200?o0000okJQ`onfXL<03_nfXL<00ol0003oZIW6
ojVIaP02ojVIaP?o00002?nXV<D00ol0003oVi38oi^@b00<oi^@b003o`000?n;R<_oRhS;00_oRhS;
00?o0000og^2c_mkP/h02omkP/h00ol0003oLH3Bog60dP03o`0000OoIg_C00?o0000ofZ1f?l00000
2omZPMP00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo000_ooooo`03o`000?oo
oooooooo00Gooooo0ol0000>ogW8o`;o00001OnSdoP3o`0000koX][k0_l00004okgNl0;o00003_o2
h>h2o`0000_oaMg[0_l000000ooCg^7o0000om?Gf`0=om?Gf`03o`000?oBcMGod/gE00_od/gE00?o
0000omO>dOl000003ooB`l`00ol0003oc[[7oljja`05oljja`03o`000?o=^<KocKS600OocKS600?o
0000olN``oo7/<<02Oo7/<<00ol0003o`Zc4ol:/a005ol:/a003o`000?nnYl;o_ZO200So_ZO200?o
0000okJQ`onfXL<03OnfXL<00ol0003oZIW6o`000002o`0000coZ9S500?o0000oi^@b?nKT<P02onK
T<P00ol0003oRhS;oh^8b`0;oh^8b`03o`000?mkP/koNh;>00coNh;>00?o0000og60d_maP=800_ma
P=83o`0000CoIg_C00Co0000ofZ1f?mZPMSo00002_mZPMP00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00Sooooo000`ooooo`03o`000?oooooooooo00Oooooo0_l0000>ogW8o`03o`000?nS
doSo000000;o00004onRf_/2o`000003okgNl?l0003o`^3^00go`^3^0_l0000>olGMj`?o00003OoC
em/00ol0003od/gEom;=e@0<om;=e@;o00003ooB`l`00ol0003oc[[7oljja`07oljja`03o`000?o=
^<KocKS600GocKS600?o0000olN``oo7/<<02_o7/<<00ol0003o`Zc4ol:/a004ol:/a003o`000?nn
Yl;o_ZO200Wo_ZO200?o0000okJQ`onfXL<03OnfXL<2o`0000ooZ9S500?o0000oi^@b?nKT<P03?nK
T<P00ol0003oRhS;oh^8b`0:oh^8b`03o`000?mkP/koNh;>00coNh;>00?o0000og60d_maP=801Oma
P=83o`0000;oIg_C00Co0000ofZ1f?mZPMSo00002_mZPMP00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Sooooo000aooooo`03o`000?oooooooooo00Sooooo0_l00007ogW8o`So00005_nR
f_/3o`0000go`^3^00?o0000olGMjoo5gN/03Oo5gN/01Ol0003oamKUolOFiOo7e^Go000000_odmOK
00?o0000om;=eOoBcMD03?oBcMD01?l0003oc/C@olk4d?l0000=om;3c003o`000?o>^/Ooc[[700So
c[[700?o0000olfha_o=^<H01?o=^<H00ol0003oak33olN```0<olN```03o`000?o2[<Co`Zc400;o
`Zc400?o0000okjW`_nnYl802onnYl800ol0003o]Z73okJQ``0;okJQ``03o`000?ncWlCo000000oo
Z9S500?o0000oi^@b?nKT<P03?nKT<P00ol0003oRhS;oh^8b`0;oh^8b`03o`000?mkP/koNh;>00_o
Nh;>00?o0000og60d_maP=802?maP=83o`0000?oJX7H00?o0000ofZ1f?mZPMP02?mZPMP00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo000booooo`;o00002_ooool7o`0000SoI/Om
0_l0000Aoj;Jn`?o00000onSg?/2o`0000Wo`^3^0_l0000>olGMj`;o00001Oo7e^D2o`0000SodmOK
00?o0000om;=eOoBcMD03?oBcMD00ol0003oc/C@olk4d002olk4d003o`000?oB`lcod/?<00Wod/?<
00?o0000oljjaoo>^/L02_o>^/L00ol0003ocKS6olfhaP02olfhaP03o`000?o7/<?oak3300goak33
00Go0000ol:/a?o2[<Co`Zc4o`00000>okjW`P03o`000?nfXL?o]Z7300Wo]Z730_l00003ok>Oa003
o`000?nXV<GoZ9S500goZ9S500?o0000oi^@b?nKT<P03?nKT<P00ol0003oRhS;oh^8b`0:oh^8b`03
o`000?mkP/koNh;>00coNh;>00?o0000og60d_maP=802_maP=84o`0000[oJX7H00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`08ooooo`00=?ooool00ol0003oooooooooo`09ooooo`?o0000
3?mVaod3o`0000_oX][k0ol00008oj?Ln`?o00001?o2h>h2o`0000ooaMg[00?o0000olOFiOo7e^D0
1oo7e^D00ol0003odmOKom?Gf`04om?Gf`03o`000?oBcMGod/gE00cod/gE00?o0000olk4d?o>a=00
1?o>a=000ol0003od/?<om;3c007om;3c003o`000?o>^/Ooc[[700_oc[[700Go0000olfha_o=^<Ko
cKS6o`00000AolN```03o`000?o2[<Co000000oo_ZO200?o0000okJQ`onfXL<01onfXL<2o`0000Go
/io400?o0000ojRHaOnXV<D03OnXV<D00ol0003oVi38oi^@b00<oi^@b003o`000?n;R<_oRhS;00_o
RhS;00?o0000og^2c_mkP/h02omkP/h00ol0003oLH3Bog60dP0:og60dP03o`000?mcQmSoLhOH00?o
00002OmZPMP00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo000eooooo`03o`00
0?oooooooooo00_ooooo0ol0000<ofK7o@;o00001_nRf_/3o`0000koXmck0_l000000oo2h>ko0000
olGMj`0?olGMj`03o`000?o7e^GoamKU00WoamKU0_l00003om?Gf`03o`000?oBcMGod/gE00cod/gE
00?o0000olk4d?o>a=001_o>a=000ol0003od/?<om;3c005om;3c003o`000?o>^/Ooc[[700goc[[7
00?o0000olfha_l000004_o7/<<2o`00017o_ZO200?o0000okJQ`onfXL<01OnfXL<00ol0003o/io4
ok>Oa006ok>Oa003o`000?nXV<GoZ9S500goZ9S500?o0000oi^@b?nKT<P03?nKT<P00ol0003oRhS;
oh^8b`0:oh^8b`03o`000?mkP/koNh;>00coNh;>00?o0000og60d_maP=802_maP=801?l0003oLhOH
og>7f?mcQmP5o`0000GoJX7H00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`00
=_ooool00ol0003oooooooooo`0=ooooo`?o00002omVaod2o`000004oj;Jnol0003o0000o`0001;o
Xmck0ol0000>olGMj`;o00003_o7e^D00ol0003odmOKo`00000>om;=e@03o`000?o>a=3oc/C@00So
c/C@00?o0000om;3c?oB`l`00ooB`l`00ol0003oc[[7oljja`0?oljja`03o`000?o7/<?oak33013o
ak3300?o0000ol>/`_l000004OnnYl800ol0003o]Z73okJQ``03okJQ``;o00002OncWl@00ol0003o
Z9S5ojRHa@0=ojRHa@03o`000?nKT<SoVi3800coVi3800?o0000oh^8bon;R</02on;R</00ol0003o
Nh;>og^2cP0;og^2cP03o`000?maP=;oLH3B00[oLH3B00?o0000og>7f?mcQmP00_mcQmP01?l0003o
LhOHog>7f?mcQmP3o`0000?oJX7H00?o0000ooooooooool02oooool00ol0003oooooooooo`07oooo
o`00=oooool00ol0003oooooooooo`0?ooooo`oo00004OnSg?/3o`0000?oY]Wj0_l0000;olGMj`03
o`000?o7e^GoamKU00koamKU0ol0000<om;=e@;o00003?o>a=001Ol0003od/?<om;3c?oB`lco0000
017oc[[70_l0000AolN```05o`000?o3[<;o`jc2ol>/`_l000004OnnYl800ol0003o]Z73okJQ``02
o`0000_o/io400?o0000ojRHaOnXV<D03_nXV<D00ol0003oVi38oi^@b00;oi^@b003o`000?n;R<_o
RhS;00_oRhS;00?o0000og^2c_mkP/h02omkP/h00ol0003oLH3Bog60dP0;og60dP05o`000?mcQmSo
LhOHog>7f?l000001_mcQmP4o`0000gooooo00?o0000ooooooooool01oooool003Sooooo0_l0000A
ooooo`?o00002_mF`OX3o`0000_oXmck0ol00008ojKInP;o00001oo5gN/2o`00013oamKU00Go0000
olK=goo6cMooa/gOo`00000:om;=e@03o`000?o>a=3oc/C@00goc/C@00?o0000om;3c?l000004Oo>
^/L01?l0003obKC5olVdaOl0000?olN```03o`000?o3[<;o`jc200;o`jc200?o0000okjW`_nnYl80
3onnYl800ol0003o]Z73o`00000>ok>Oa003o`000?nXV<GoZ9S500goZ9S500?o0000oi^@b?nKT<P0
3?nKT<P00ol0003oRhS;oh^8b`0:oh^8b`03o`000?mkP/koNh;>00coNh;>00?o0000og60d_maP=80
2_maP=800ol0003oLhOHog>7f002og>7f003o`000?mcQmSoLhOH00KoLhOH0_l0000<ooooo`03o`00
0?oooooooooo00Oooooo000jooooo`03o`000?oooooooooo017ooooo0_l0000;oeK1nP;o00001onS
g?/2o`0000goY]Wj0_l00004olGMj`03o`000?o7e^GoamKU00koamKU0_l00005olK=g`03o`000?oB
cMGod/gE00Kod/gE00?o0000olk4d?o>a=003_o>a=02o`00017oc[[700Go0000olVdaOo9]<GobKC5
o`00000>olN```03o`000?o3[<;o`jc200Co`jc200?o0000okjW`_nnYl803_nnYl82o`0000oo/io4
00?o0000ojRHaOnXV<D03OnXV<D00ol0003oVi38oi^@b00<oi^@b003o`000?n;R<_oRhS;00_oRhS;
00?o0000og^2c_mkP/h02omkP/h00ol0003oLH3Bog60dP0;og60dP03o`000?mcQmSoLhOH00;oLhOH
00?o0000og>7f?mcQmP01_mcQmP00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo
000kooooo`03o`000?oooooooooo01;ooooo0ol0000:oeK1nP?o000000CoXmcko`000?l0003o0000
4OnVfOX2o`000003olGMjol0003oamKU00ooamKU00?o0000olK=goo6cMl01_o6cMl2o`0000God/gE
00?o0000olk4d?o>a=003_o>a=000ol0003ob[c<o`00000@oljja`03o`000?o9]<GobKC500?obKC5
00?o0000olN``oo7/<<02_o7/<<00ol0003o`jc2ol>/`P05ol>/`P03o`000?nnYl;o_ZO200go_ZO2
00?o0000ok^U`ol000004?ncWl@00ol0003oZ9S5ojRHa@0=ojRHa@03o`000?nKT<SoVi3800WoVi38
2ol00005oh^8b`03o`000?mkP/koNh;>00coNh;>00?o0000og60d_maP=802_maP=800ol0003oLhOH
og>7f002og>7f003o`000?mcQmSoLhOH00OoLhOH00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`07ooooo`00??ooool00ol0003oooooooooo`0Dooooo`oo00005?nVfOX3o`0000koamKU0_l0
000;olK=g`05o`000?oBcMGod/gEom;=eOl000004?o>a=001Ol0003ob[c<olZlc?o:_<co000000ko
c[[700?o0000olVdaOo9]<D01Oo9]<D00ol0003oak33olN```08olN```03o`000?o3[<;o`jc200Oo
`jc200?o0000okjW`_nnYl802onnYl801Ol0003o^jG3ok^U`onkYL?o000000oo/io400?o0000ojRH
aOnXV<D03OnXV<D00ol0003oVi38oi^@b002oi^@b0Oo00000onLUL`00ol0003oSXk?ohj>c`05ohj>
c`_o00002OmkP/h00ol0003oLH3Bog60dP0;og60dP03o`000?mcQmSoLhOH00;oLhOH00?o0000og>7
f?mcQmP01_mcQmP00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo000mooooo`;o
00005_ooool3o`0000[oD;_i0_l0000?ojKInP?o00000onYdoH2o`0000[oamKU0_l0000>olK=g`03
o`000?oBcMGo0000013oc/C@00?o0000olZlc?o:_<`00oo:_<`00ol0003oc[[7oljja`0:oljja`03
o`000?o9]<GobKC500KobKC500?o0000olN``oo7/<<01oo7/<<00ol0003o`jc2ol>/`P08ol>/`P03
o`000?nnYl;o_ZO200[o_ZO200?o0000ok^U`onkYL<00_nkYL<00ol0003o/io4ok>Oa00>ok>Oa003
o`000?nXV<GoZ9S500coZ9S51Ol0000;oibEc003o`000?n>S/ooSXk?00[oSXk?00?o0000oh29d_n0
RM800_n0RM87o`0000;oNh;>00?o0000og60d_maP=802omaP=800ol0003oLhOHog>7f003og>7f003
o`000?mcQmSoLhOH00KoLhOH00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`00
?oooool00ol0003oooooooooo`0Fooooo`;o00002_m@^oT2o`0000[oY]Wj0ol00008ojWCmP;o0000
1oo7e^D00ol0003oa/gOolK=g`0>olK=g`;o00004?o>a=000ol0003ob[c<olZlc005olZlc003o`00
0?o>^/Ooc[[700Soc[[700?o0000olVdaOo9]<D02?o9]<D00ol0003oak33olN```05olN```03o`00
0?o3[<;o`jc200[o`jc200?o0000okjW`_nnYl802?nnYl800ol0003o^jG3ok^U``04ok^U``03o`00
0?ncWlCo/io400go/io400?o0000ojRHaOnXV<D02OnXV<D3o`000003ojVLbOl0003oW9G<00goW9G<
00?o0000ohj>con>S/l02on>S/l00ol0003oP8WBoh29dP08oh29dPKo00002omaP=800ol0003oLhOH
og>7f003og>7f003o`000?mcQmSoLhOH00GoLhOH00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`06ooooo`00@?ooool00ol0003oooooooooo`0Gooooo`?o00002Om@^oT00ol0003oY]WjojKI
nP04ojKInP?o00003OnYdoH00ol0003oamKUolOFi@02olOFi@;o00004?o6cMl00ol0003oa<?Io`00
000?olk4d003o`000?o:_<cob[c<00Oob[c<00?o0000oljjaoo>^/L01_o>^/L00ol0003obKC5olVd
a@09olVda@03o`000?o7/<?oak3300Coak3300?o0000ol>/`_o3[<802oo3[<800ol0003o_ZO2okjW
`P06okjW`P;o00001onkYL<00ol0003o/io4ok>Oa00=ok>Oa003o`000?nXV<GoZ9S500KoZ9S50ol0
0005ojVLb@03o`000?nLULcoW9G<00_oW9G<00?o0000ohj>con>S/l02on>S/l00ol0003oP8WBoh29
dP0;oh29dP03o`000?mhR=OoN8SG00Co00001omaP=800ol0003oLhOHog>7f003og>7f003o`000?mc
QmSoLhOH00KoLhOH00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`00@Oooool0
0ol0003oooooooooo`0Iooooo`Oo00000om@^oT2o`000004ojKIn_l0003o0000o`00017oZM?f0_l0
00000oo7e^Go0000olK=g`0@olK=g`05o`000?o4`mWoa<?IolC3fOl000003Oo>a=000ol0003ob[c<
olZlc008olZlc003o`000?o>^/Ooc[[700Goc[[700?o0000olVdaOo9]<D02oo9]<D00ol0003oak33
olN```02olN```03o`000?o3[<;o`jc200co`jc200?o0000okjW`_nnYl801OnnYl800ol0003o^jG3
ok^U``07ok^U``03o`000?ncWlCo/io400ko/io400?o0000ojRHaOnXV<D00_nXV<D3o`0000SoZIc9
00?o0000oibEc?nLUL`03?nLUL`00ol0003oSXk?ohj>c`0;ohj>c`03o`000?n0RM;oP8WB00_oP8WB
00?o0000ogR8eomhR=L00omhR=L4o`0000CoLH3B00?o0000og>7f?mcQmP00omcQmP00ol0003oLhOH
og>7f005og>7f003o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool004;ooooo0_l0
000Kooooo`;o00000omE]_/7o`0001CoZM?f0ol0000?olK=g`;o00001Oo4`mT00ol0003oc/C@olk4
d009olk4d003o`000?o:_<cob[c<00[ob[c<00?o0000oljjaoo>^/L00oo>^/L00ol0003obKC5olVd
a@0=olVda@04o`000?o7/<?oak33o`00013o`jc200?o0000okjW`_nnYl800onnYl800ol0003o^jG3
ok^U``09ok^U``03o`000?ncWlCo/io400go/io400?o0000ojRHaOl000000_l0000<ojVLb@03o`00
0?nLULcoW9G<00_oW9G<00?o0000ohj>con>S/l02on>S/l00ol0003oP8WBoh29dP0;oh29dP03o`00
0?mhR=OoN8SG00OoN8SG1Ol00006og>7f003o`000?mcQmSoLhOH00GoLhOH00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`00A?ooool00ol0003oooooooooo`0Jooooo`;o00002?mE
]_/2o`0000ooZM?f0ol00003oj_9k`03o`000?o6cMooa/gO00_oa/gO00?o0000olC3fOo4`mT01_o4
`mT00ol0003oc/C@olk4d007olk4d003o`000?o:_<cob[c<00cob[c<00Go0000oljjaoo>^/Ooc[[7
o`00000@olVda@03o`000?o7/<?o0000017o`jc200?o0000okjW`_nnYl800_nnYl800ol0003o^jG3
ok^U``0:ok^U``03o`000?ncWlCo/io400go/io40_l0000?ojVLb@03o`000?nLULcoW9G<00coW9G<
00?o0000ohj>con>S/l02on>S/l00ol0003oP8WBoh29dP0;oh29dP03o`000?mhR=OoN8SG00[oN8SG
1Ol00003og>7f003o`000?mcQmSoLhOH00CoLhOH00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`00AOooool00ol0003oooooooooo`0Kooooo`03o`000?mE]__oEKKk00OoEKKk0_l0
000:ojWCmP?o00001on[bNl00ol0003oa/gOolK=g`09olK=g`03o`000?o4`mWoa<?I00Soa<?I00?o
0000olk4d?o>a=001Oo>a=000ol0003ob[c<olZlc00>olZlc003o`000?o>^/Oo000001;obKC500?o
0000ol>/`_o3[<804Oo3[<801?l0003o_ZO2okjW`_l0000>ok^U``03o`000?ncWlCo/io400_o/io4
00?o0000ok>Saol000004?nYW<T00ol0003oW9G<oibEc00;oibEc003o`000?n>S/ooSXk?00_oSXk?
00?o0000oh29d_n0RM802on0RM800ol0003oN8SGogR8e`0;ogR8e`04o`000?mjSmcoNXoLogZ?g0Go
00001_mcQmP00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo0016ooooo`03o`00
0?oooooooooo01_ooooo0_l00009oeFfn`;o00001_nYdoH2o`0000_oZlW_0_l00008olK=g`03o`00
0?o4`mWoa<?I00[oa<?I00?o0000olk4d?o>a=000oo>a=000ol0003ob[c<olZlc00?olZlc0;o0000
4_o9]<D2o`0001?o`jc200?o0000okjW`_l000003onkYL<00ol0003o/io4ok>Oa009ok>Oa0;o0000
0oncXlL00ol0003oZIc9ojVLb@0=ojVLb@03o`000?nLULcoW9G<00_oW9G<00?o0000ohj>con>S/l0
3?n>S/l00ol0003oP8WBoh29dP0;oh29dP03o`000?mhR=OoN8SG00_oN8SG00?o0000ogZ?g?mjSm`0
1?mjSm`6o`000003og>7f?l0003ooooo00Oooooo00?o0000ooooooooool01_ooool004Oooooo0_l0
000Mooooo`So00000omE]_/2o`000004ojWCm_l0003o0000o`0000ooZlW_00?o0000olK=goo6cMl0
0oo6cMl2o`0000koa<?I00Go0000olk4d?o>a=3oc/C@o`00000AolZlc003o`000?o6]/[o0000017o
bKC500Co0000olF_aOo5[lGo00004_o3[<82o`00017o^jG300?o0000ok>Oa?ncWl@01_ncWl@2o`00
00Go/j?700?o0000ojVLbOnYW<T03_nYW<T00ol0003oW9G<oibEc00;oibEc003o`000?n>S/ooSXk?
00_oSXk?00?o0000oh29d_n0RM802on0RM800ol0003oN8SGogR8e`0;ogR8e`03o`000?mjSmcoNXoL
00GoNXoL00?o0000ogZ?g?mjSm`00_mjSm`3o`0000Sooooo00?o0000ooooooooool01Oooool004Wo
oooo00?o0000ooooooooool07?ooool00ol0003oHJojof6_nP03of6_nPOo00004_n[bNl01Ol0003o
a/gOolK=goo6cMoo0000017oa<?I00?o0000olk4d?l000004Oo:_<`01Ol0003oa[K:olJfb_o6]/[o
000000oobKC500Go0000olF_aOo5[lGoaJo5o`00000Aol>/`P03o`000?o1Z/Co0000017o^jG300?o
0000ok>Oa?ncWl@01OncWl@00ol0003o/j?7ok>Sa`06ok>Sa`03o`000?nYW<WoZIc900goZIc900?o
0000oibEc?nLUL`02onLUL`00ol0003oSXk?ohj>c`0<ohj>c`03o`000?n0RM;oP8WB00_oP8WB00?o
0000ogR8eomhR=L02omhR=L00ol0003oNXoLogZ?g004ogZ?g003o`000?mjSmcoNXoL00CoNXoL00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`00B_ooool00ol0003oooooooooo`0L
ooooo`03o`000?mQ[o[oHJoj00WoHJoj00?o0000oj_9kon[bNl04?n[bNl00ol0003oa/gOo`00000B
olC3f@;o00004Oo:_<`00ol0003oa[K:olJfbP02olJfbP03o`000?o9]<GobKC500cobKC500?o0000
olF_aOo5[lD00oo5[lD00ol0003o`jc2ol>/`P0=ol>/`P05o`000?o1Z/Co`J[4ol6Za?l000004?nk
YL<00ol0003o/io4ok>Oa003ok>Oa0;o00002OncXlL00ol0003oZIc9ojVLb@0=ojVLb@03o`000?nL
ULcoW9G<00coW9G<00?o0000ohj>con>S/l02on>S/l00ol0003oP8WBoh29dP0;oh29dP03o`000?mh
R=OoN8SG00_oN8SG00?o0000ogZ?g?mjSm`01OmjSm`00ol0003oNXoLogZ?g004ogZ?g003o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool004_ooooo00?o0000ooooooooool07?ooool2
o`0000[oHJoj00?o0000oj_9kon[bNl03on[bNl2o`0001;oa<?I00?o0000ol6keOl000004?o:_<`0
0ol0003oa[K:olJfbP04olJfbP03o`000?o9]<GobKC500[obKC500?o0000olF_aOo5[lD01Oo5[lD0
0ol0003o`jc2ol>/`P0;ol>/`P03o`000?o1Z/Co`J[400;o`J[400?o0000ok^U`onkYL<03onkYL<0
0ol0003o/io4ok>Oa002o`0000co/j?700?o0000ojVLbOnYW<T03OnYW<T00ol0003oW9G<oibEc00;
oibEc003o`000?n>S/ooSXk?00coSXk?00?o0000oh29d_n0RM802on0RM800ol0003oN8SGogR8e`0;
ogR8e`03o`000?mjSmcoNXoL00GoNXoL00?o0000ogZ?g?mjSm`00omjSm`00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo001<ooooo`;o00007_ooool00ol0003oHJojof6_nP08of6_
nP03o`000?n[bNooZlW_00_oZlW_0ol00002oj^oj003o`000?o4`mWoa<?I00goa<?I0_l00003ol6k
e@03o`000?o:_<cob[c<00cob[c<00?o0000olJfb_o6]/X01_o6]/X00ol0003obKC5olVda@08olVd
a@03o`000?o5[lGoaJo500KoaJo500?o0000ol>/`_o3[<802_o3[<800ol0003o`J[4ol6Za004ol6Z
a003o`000?nkYL?o^jG300ko^jG300?o0000ok>Oa?l000003_ncXlL00ol0003oZIc9ojVLb@0=ojVL
b@03o`000?nLULcoW9G<00_oW9G<00?o0000ohj>con>S/l03?n>S/l00ol0003oP8WBoh29dP0;oh29
dP03o`000?mhR=OoN8SG00_oN8SG00?o0000ogZ?g?mjSm`01_mjSm`00ol0003oNXoLogZ?g003ogZ?
g003o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool004kooooo00?o0000oooooooo
ool07?ooool00ol0003oHJojof6_nP08of6_nP03o`000?n[bNooZlW_00OoZlW_0ol00006oj^oj003
o`000?o4`mWoa<?I00_oa<?I00?o0000ol6keOo1^mD01?o1^mD00ol0003ob[c<olZlc009olZlc0;o
00002Oo6]/X00ol0003obKC5olVda@07olVda@03o`000?o5[lGoaJo500SoaJo500?o0000ol>/`_o3
[<802?o3[<800ol0003o`J[4ol6Za005ol6Za003o`000?nkYL?o^jG300ko^jG30_l0000@ok>Sa`03
o`000?nYW<WoZIc900goZIc900?o0000oibEc?nLUL`02?nLUL`Go`0000WoP8WB00?o0000ogR8eomh
R=L02_mhR=L00ol0003oNXoLogZ?g006ogZ?g003o`000?mjSmcoNXoL00?oNXoL00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`00Coooool00ol0003oooooooooo`0Looooo`03o`00
0?mQ[o[oHJoj00SoHJoj00?o0000oj_9kon[bNl00on[bNl3o`0000[oZkoX00?o0000olC3fOo4`mT0
2?o4`mT2o`0000So`K_E00?o0000olZlc?o:_<`01oo:_<`00ol0003oa[K:olJfbP0:olJfbP03o`00
0?o9]<GobKC500GobKC500?o0000olF_aOo5[lD02Oo5[lD00ol0003o`jc2ol>/`P07ol>/`P03o`00
0?o1Z/Co`J[400Oo`J[400?o0000ok^U`onkYL<03?nkYL<00ol0003o^jS7o`00000@ok>Sa`03o`00
0?nYW<WoZIc900goZIc900Co0000oibEc?nLULcoW9G<1ol00003oifSf@03o`000?n>W=coSYcL00co
SYcL00?o0000oh2Fgon0U]l00_n0U]l7o`0000;oP8WB00?o0000ogR8eomhR=L02omhR=L00ol0003o
NXoLogZ?g006ogZ?g003o`000?mjSmcoNXoL00?oNXoL00?o0000ooooooooool00oooool00ol0003o
ooooooooo`05ooooo`00D?ooool00ol0003oooooooooo`0Looooo`Oo00001?mQ[oX00ol0003oZlW_
o`000002o`0000koZkoX00?o0000olC3fOo4`mT01_o4`mT00ol0003o`K_Eol6ke@09ol6ke@03o`00
0?o:_<cob[c<00Gob[c<00?o0000olJfb_o6]/X02oo6]/X00ol0003obKC5olVda@04olVda@03o`00
0?o5[lGoaJo500_oaJo500?o0000ol>/`_o3[<801Oo3[<800ol0003o`J[4ol6Za008ol6Za003o`00
0?nkYL?o^jG300[o^jG30_l00003ok^Xa`03o`000?ncXlOo/j?700go/j?700?o0000ojVLbOnYW<T0
3OnYW<T4o`0000_oWJ?I00?o0000ohjLg?n>W=`03?n>W=`00ol0003oP9KOoh2Fg`08oh2Fg`Oo0000
2OmhR=L00ol0003oNXoLogZ?g007ogZ?g003o`000?mjSmcoNXoL00?oNXoL00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`00DOooool00ol0003oooooooooo`0Looooo`03o`000?m]
Z?CoKJSd00?oKJSd1ol0000Aoj^oj003o`000?o4`mWoa<?I00Coa<?I00?o0000ol6keOo1^mD02oo1
^mD00ol0003ob[c<olZlc003olZlc003o`000?o6]/[oa[K:00goa[K:00?o0000olVdaOo9]<D00_o9
]<D00ol0003oaJo5olF_a@0<olF_a@03o`000?o3[<;o`jc200Co`jc200?o0000ol6Za?o1Z/@02_o1
Z/@00ol0003o^jG3ok^U``08ok^U``03o`000?nkZ<Oo^jS700?o^jS700?o0000ok>SaoncXlL03_nc
XlL00ol0003oZIc9ojVLb@09ojVLb@?o000000?oZjWEo`000?nMXmT03OnMXmT00ol0003oSYcLohjL
g00;ohjLg003o`000?n0U]ooP9KO00_oP9KO00Co0000ogVEh_miUN;oNIGR1Ol00005ogR8e`03o`00
0?mjSmcoNXoL00OoNXoL00?o0000ogZ?g?mjSm`00_mjSm`00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo001Booooo`;o00007Oooool00ol0003oKJSdoffXm009offXm003o`000?n[
_nSoZkoX00ooZkoX00Co0000olC3fOo4`mWoa<?I0_l0000?ol6ke@05o`000?o:_<cob[c<olZlc?l0
00004Oo6]/X01?l0003obKC5olVdaOl0000@olF_a@03o`000?o3[<;o`jc200;o`jc200?o0000ol6Z
a?o1Z/@02oo1Z/@00ol0003o^jG3ok^U``06ok^U``;o00001onkZ<L00ol0003o/j?7ok>Sa`0=ok>S
a`03o`000?nYW<WoZIc900KoZIc90ol00005oj^Ye@03o`000?nMXmWoWJ?I00_oWJ?I00?o0000ohjL
g?n>W=`03?n>W=`00ol0003oP9KOoh2Fg`0;oh2Fg`03o`000?miUN;oNIGR00GoNIGR1_l00009ogZ?
g003o`000?mjSmcoNXoL00?oNXoL00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`00E?ooool00ol0003oooooooooo`0Kooooo`03o`000?m]Z?CoKJSd00WoKJSd00?o0000oj^oj?n[
_nP03on[_nP00ol0003oa<?Io`00000Bol6ke@03o`000?o:_<co000001;oa[K:00?o0000olVdaOl0
00004_o5[lD01?l0003o`jc2ol>/`_l0000?ol6Za003o`000?nkYL?o^jG300Co^jG300?o0000ok^X
aonkZ<L01onkZ<L00ol0003o/j?7ok>Sa`0>ok>Sa`03o`000?nYW<WoZIc900;oZIc90ol00008oj^Y
e@03o`000?nMXmWoWJ?I00coWJ?I00?o0000ohjLg?n>W=`02on>W=`00ol0003oP9KOoh2Fg`0;oh2F
g`03o`000?miUN;oNIGR00[oNIGR2_l000000omjSmco0000ogZ?g003ogZ?g003o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool005Gooooo00?o0000ooooooooool06oooool00ol0003o
KJSdoffXm009offXm003o`000?n[_nSoZkoX00koZkoX0_l0000Col6ke@;o00004oo6]/X2o`0001?o
aJo500?o0000ol>/`_l000004?o1Z/@00ol0003o^jG3ok^U``03ok^U``03o`000?nkZ<Oo^jS700Wo
^jS700?o0000ok>SaoncXlL03OncXlL00ol0003oZIc9o`000002o`0000coZjWE00?o0000oifSfOnM
XmT03?nMXmT00ol0003oSYcLohjLg00;ohjLg003o`000?n0U]ooP9KO00_oP9KO00?o0000ogVEh_mi
UN802_miUN800ol0003oO9_VogbKiP06ogbKiPSo00000oooool00ol0003oooooooooo`04ooooo`00
E_ooool00ol0003oooooooooo`0Kooooo`03o`000?m]Z?CoKJSd00WoKJSd00?o0000oj^oj?n[_nP0
2_n[_nP3o`000003oj^fhOl0003o`K_E017o`K_E00?o0000okjed_l000004_o6]/X00ol0003o`k;9
o`00000ColF_a@;o00004_o1Z/@00ol0003o^jG3ok^U``02o`0000co^jS700?o0000ok>SaoncXlL0
3OncXlL2o`0000ooZjWE00?o0000oifSfOnMXmT03?nMXmT00ol0003oSYcLohjLg00<ohjLg003o`00
0?n0U]ooP9KO00[oP9KO00?o0000ogVEh_miUN802omiUN800ol0003oO9_VogbKiP07ogbKiP03o`00
0?mlVnKoO9_V00;oO9_V00Go0000ooooooooooooooooo`000006ooooo`00Eoooool2o`0001cooooo
00?o0000offXm?m]Z?@02Om]Z?@00ol0003oZkoXoj^oj006oj^oj0?o00001On[]^400ol0003o`K_E
ol6ke@0=ol6ke@;o00000onn]M800ol0003oa[K:olJfbP0>olJfbP05o`000?o3//Wo`k;9ol>bbOl0
00004Oo5[lD00ol0003o`Zk6o`00000Bol6Za003o`000?nkYL?o000000oo^jS700?o0000ok>Saonc
XlL02_ncXlL2o`000003okJ_d_l0003oZjWE00ooZjWE00?o0000oifSfOnMXmT03?nMXmT00ol0003o
SYcLohjLg00;ohjLg003o`000?n0U]ooP9KO00_oP9KO00?o0000ogVEh_miUN802omiUN800ol0003o
O9_VogbKiP07ogbKiP03o`000?mlVnKoO9_V00;oO9_V00Co0000oooooooooooo00001_ooool005Wo
oooo00?o0000ooooooooool06_ooool00ol0003oKJSdoffXm009offXm003o`000?n[_nSoZkoX00?o
ZkoX0_l00009oj^fh@03o`000?o1^mGo`K_E00_o`K_E00?o0000okjed_nn]M801?nn]M800ol0003o
a[K:olJfbP0<olJfbP03o`000?o3//Wo`k;900;o`k;900?o0000olF_aOo5[lD03_o5[lD01Ol0003o
`Zk6ol:^a_o2[/Ko0000017o`J[40_l0000@ok^Xa`03o`000?ncXlOo/j?700So/j?70_l00004okJ_
dP03o`000?n[ZMGoZjWE00goZjWE00?o0000oifSfOnMXmT03?nMXmT00ol0003oSYcLohjLg00<ohjL
g003o`000?n0U]ooP9KO00_oP9KO00?o0000ogVEh_miUN802_miUN800ol0003oO9_VogbKiP08ogbK
iP03o`000?mlVnKoO9_V00;oO9_V00?o0000ooooool000001_ooool005[ooooo00?o0000oooooooo
ool06_ooool8o`0000CoKJSd00?o0000oj^oj?l000000_l0000<oj^fh@03o`000?o1^mGo`K_E00So
`K_E0_l00008okjedP03o`000?o6]/[oa[K:00[oa[K:00?o0000ol>bbOo3//T01?o3//T00ol0003o
aJo5olF_a@0<olF_a@03o`000?o2[/Ko`Zk600;o`Zk600?o0000ol6Za?o1Z/@03_o1Z/@00ol0003o
_jg8o`00000Aok^Xa`03o`000?ncXlOo/j?700Go/j?70_l00006okJ_dP03o`000?n[ZMGoZjWE00ko
ZjWE00?o0000oifSfOnMXmT03?nMXmT00ol0003oSYcLohjLg00;ohjLg003o`000?n0U]ooP9KO00_o
P9KO00?o0000ogVEh_miUN802omiUN800ol0003oO9_VogbKiP08ogbKiP05o`000?mlVnKoO9_VogbK
i_l000000_ooool00ol0003oooooooooo`03ooooo`00Foooool00ol0003oooooooooo`0Jooooo`03
o`000?mgXNcoMj7/00CoMj7/1_l0000@oj^fh@03o`000?o1^mGo`K_E00Ko`K_E00?o0000okjed_nn
]M802?nn]M800ol0003oa[K:olJfbP08olJfbP;o00002?o3//T00ol0003oaJo5olF_a@09olF_a@;o
00001_o2[/H00ol0003o`J[4ol6Za00<ol6Za005o`000?no[LSo_jg8okn]b?l000004?nkZ<L00ol0
003o/j?7ok>Sa`04ok>Sa`03o`000?nf[m;o]ZoB00Oo]ZoB00?o0000oj^YeOn[ZMD03On[ZMD00ol0
003oWJ?IoifSf@0;oifSfAGo00002On0U]l00ol0003oNIGRogVEhP0:ogVEhP03o`000?mlVnKoO9_V
00SoO9_V00?o0000ogbKi_mlVnH00_mlVnH00ol0003oooooo`000005ooooo`00G?ooool2o`0001_o
oooo00?o0000ogNQk?mgXN`02?mgXN`00ol0003oZkKQoj^fh@0?oj^fh@03o`000?o1^mGo`K_E00Co
`K_E00?o0000okjed_nn]M802_nn]M800ol0003oa[K:olJfbP06olJfbP03o`000?o3//Wo`k;900So
`k;900?o0000olF_aOo5[lD02?o5[lD00ol0003o`Zk6ol:^aP06ol:^aP03o`000?o1Z/Co`J[400_o
`J[400?o0000okn]b?no[LP00_no[LP00ol0003o^jS7ok^Xa`0?ok^Xa`04o`000?ncXlOo/j?7ok>S
a`;o00002_nf[m800ol0003oZjWEoj^Ye@0>oj^Ye@03o`000?nMXmWoWJ?I00GoWJ?I1Ol0000Eoooo
o`Oo00000_n0U]l00ol0003oNIGRogVEhP0;ogVEhP03o`000?mlVnKoO9_V00SoO9_V00Oo0000ogbK
i_mlVnKoO9_Vo`000?oooooo000000Gooooo001Nooooo`03o`000?oooooooooo01Wooooo00?o0000
ogNQk?mgXN`02?mgXN`00ol0003oZkKQoj^fh@0?oj^fh@04o`000?o1^mGo`K_Eol6ke@;o00003_nn
]M800ol0003oa[K:olJfbP04olJfbP03o`000?o3//Wo`k;900[o`k;900?o0000olF_aOo5[lD01_o5
[lD00ol0003o`Zk6ol:^aP08ol:^aP03o`000?o1Z/Co`J[400Wo`J[400?o0000okn]b?no[LP01?no
[LP00ol0003o^jS7ok^Xa`0>ok^Xa`04o`000?ncXlOo0000o`0000go]ZoB00?o0000oj^YeOn[ZMD0
3On[ZMD00ol0003oWJ?IoifSf@05o`00027ooooo2?l00009ogVEhP03o`000?mlVnKoO9_V00SoO9_V
00Co0000ogbKi_mlVnKoO9_V0_l00005ooooo`00Goooool00ol0003oooooooooo`0Iooooo`03o`00
0?mgXNcoMj7/00SoMj7/00?o0000oj^fhOn[]^403on[]^400ol0003o`K_Eo`00000@okjedP03o`00
0?o6]/[oa[K:00?oa[K:00?o0000ol>bbOo3//T02oo3//T00ol0003oaJo5olF_a@04olF_a@;o0000
3?o2[/H00ol0003o`J[4ol6Za006ol6Za0;o00001ono[LP00ol0003o^jS7ok^Xa`0>ok^Xa`;o0000
4?nf[m800ol0003oZjWEoj^Ye@0;oj^Ye@Co0000;_ooool7o`0000;oNIGR00?o0000ogbKi_mlVnH0
2OmlVnH01Ol0003oO9_VogbKi_mlVnKo000000Gooooo001Pooooo`03o`000?oooooooooo01Wooooo
00?o0000ogNQk?mgXN`02?mgXN`00ol0003oZkKQoj^fh@0>oj^fh@;o00004_nn]M801Ol0003oa[K:
olJfb_o6]/[o000000oo`k;900?o0000olF_aOo5[lD00_o5[lD00ol0003o`Zk6ol:^aP0<ol:^aP03
o`000?o1Z/Co`J[400Go`J[400?o0000okn]b?no[LP02?no[LP00ol0003o^jS7ok^Xa`0<ok^Xa`03
o`000?nm]=7o0000013o]ZoB00?o0000oj^YeOn[ZMD02?n[ZMD3o`0003Wooooo3?l00002ogbKiP05
o`000?mlVnKoO9_VogbKi_l000001Oooool0067ooooo0_l0000Jooooo`03o`000?mgXNcoMj7/00So
Mj7/00?o0000oj^fhOn[]^402_n[]^43o`000003ojZ`g?l0003o_[GB01;o_[GB00?o0000olJfb_l0
00004Oo3//T01?l0003oaJo5olF_aOl0000@ol:^aP03o`000?o1Z/Co`J[400?o`J[400?o0000okn]
b?no[LP02_no[LP00ol0003o^jS7ok^Xa`09ok^Xa`;o00000onm]=400ol0003o]ZoBokJ_dP0>okJ_
dP03o`000?n[ZMGoZjWE00?oZjWE1?l00018ooooo`So00001?ooool006?ooooo00?o0000oooooooo
ool06?ooool00ol0003oMj7/ogNQk008ogNQk003o`000?n[]^7oZkKQ00KoZkKQ0ol00005ojZ`g003
o`000?nn]M;o_[GB013o_[GB0_l0000Bol>bb@03o`000?o5[lGo0000017o`Zk600?o0000ol6Za?o1
Z/@00_o1Z/@00ol0003o_jg8okn]b00;okn]b003o`000?nkZ<Oo^jS700Oo^jS70_l00005okfdd@03
o`000?nf[m;o]ZoB00ko]ZoB00?o0000oj^YeOn[ZMD00ol0001@ooooo`03o`000?oooooo000000Go
oooo001Tooooo`03o`000?oooooooooo01Sooooo00?o0000ogNQk?mgXN`02?mgXN`00ol0003oZkKQ
oj^fh@03oj^fh@;o00002OnZ/=`00ol0003o_[GBokjedP0>okjedP03o`000?nk/]7o000001;o`k;9
0_l0000Col:^aP04o`000?o1Z/Co`J[4o`0000oo_jg800?o0000ok^XaonkZ<L01OnkZ<L00ol0003o
_KCAokfdd@06okfdd@03o`000?nf[m;o]ZoB00go]ZoB0ol0001Cooooo`04o`000?ooooooooooo`00
00Cooooo001Uooooo`03o`000?oooooooooo01Sooooo1ol00004ogNQk003o`000?n[]^7o000000;o
00003?nZ/=`00ol0003o_[GBokjedP0;okjedP;o00000onk/]400ol0003o`k;9ol>bb@0>ol>bb@03
o`000?o0/L_o000001?o`Zk600?o0000ol6Za?l000004?no[LP00ol0003o^jS7ok^Xa`03ok^Xa`;o
00002Onm]=400ol0003o]ZoBokJ_dP0;okJ_dP;o0000Eoooool00ol0003oooooo`000004ooooo`00
I_ooool2o`0001Sooooo00?o0000ognMiOmoWND01?moWND6o`00013oZ[3L00?o0000okjed_nn]M80
2?nn]M82o`0000Ko^k;A00?o0000ol>bbOo3//T03?o3//T01Ol0003o`;7;ol2aboo0/L_o000001;o
`Zk60_l0000Bokn]b003o`000?nkZ<Oo^jS700;o00003?nm]=400ol0003o]ZoBokJ_dP08okJ_dP;o
0000F_ooool2o`0000Cooooo001Xooooo`03o`000?oooooooooo01Kooooo00?o0000ognMiOmoWND0
2?moWND00ol0003oZ[3LojZ`g00>ojZ`g003o`000?nn]M;o_[GB00Oo_[GB00?o0000ok^bdOnk/]40
1_nk/]400ol0003o`k;9ol>bb@0:ol>bb@;o00001Oo0/L/00ol0003o`Zk6ol:^aP0>ol:^aP03o`00
0?o1/L_o000001;o_jg800?o0000ok^Xaol000003onm]=400ol0003o]ZoBokJ_dP05okJ_dP;o0000
Foooool3o`0000Cooooo001Yooooo`03o`000?oooooooooo01Kooooo00?o0000ognMiOmoWND02?mo
WND00ol0003oZ[3LojZ`g00>ojZ`g003o`000?nn]M;o_[GB00Co_[GB0_l0000:ok^bd@03o`000?o3
//Wo`k;900So`k;900?o0000ol2aboo0/L/01Oo0/L/00ol0003o`Zk6ol:^aP0=ol:^aP05o`000?o1
/L_o`K7;ol6abol000004Ono[LP2o`00013o_KCA00?o0000okJ_d_nf[m801?nf[m800ol0003ooooo
ooooo`1Gooooo`Co00001oooool006[ooooo00?o0000ooooooooool05_ooool00ol0003oOigUognM
i@08ognMi@03o`000?nZ/=coZ[3L00koZ[3L00Co0000okjed_nn]M;o_[GB0_l0000=ok^bd@03o`00
0?o3//Wo`k;900Ko`k;900?o0000ol2aboo0/L/01oo0/L/00ol0003o`Zk6ol:^aP0:ol:^aP;o0000
1?o1/L/00ol0003o_jg8okn]b00>okn]b003o`000?o1]m3o0000017o_KCA00Co0000okJ_d_nf[m;o
]ZoB0_l0001Fooooo`Co00002oooool006_ooooo00?o0000ooooooooool05_ooool00ol0003oOigU
ognMi@08ognMi@03o`000?nZ/=coZ[3L00koZ[3L00?o0000okjed_l000003onk/]400ol0003o`k;9
ol>bb@05ol>bb@03o`000?o0/L_o`;7;00Wo`;7;00?o0000ol:^a_o2[/H02?o2[/H00ol0003o`K7;
ol6ab`05ol6ab`03o`000?no[LSo_jg800co_jg800Go0000ol6gd?o1]m3o`KO@o`00000@okfdd@04
o`000?nf[m;o0000o`0005Gooooo0ol0000?ooooo`00K?ooool2o`0001Kooooo00?o0000ognMiOmo
WND02OmoWND00ol0003oZ[3LojZ`g00=ojZ`g0;o00004Onk/]400ol0003o`k;9ol>bb@02ol>bb@;o
00003?o0/L/00ol0003o`Zk6ol:^aP07ol:^aP03o`000?o1/L_o`K7;00Oo`K7;00?o0000okn]b?no
[LP02Ono[LP2o`0000Co`KO@00?o0000okfddOnm]=403_nm]=42o`0005?ooooo1?l0000Booooo`00
K_ooool00ol0003oooooooooo`0Dooooo`03o`000?moWNGoOigU00SoOigU00?o0000ojZ`g?nZ/=`0
2_nZ/=`3o`000003ojV]f_l0003o^k;A013o^k;A00Go0000ol>bbOo3//Wo`k;9o`00000?ol2ab`03
o`000?o2[/Ko`Zk600Go`Zk600?o0000ol6aboo1/L/02?o1/L/00ol0003o_jg8okn]b008okn]b003
o`000?o1]m3o`KO@00Go`KO@00?o0000okfddOnm]=403?nm]=400ol0003oooooooooo`1?ooooo`Co
00005_ooool006oooooo00?o0000ooooooooool05?ooool00ol0003oOigUognMi@08ognMi@03o`00
0?nZ/=coZ[3L00KoZ[3L0ol00005ojV]fP03o`000?nk/]7o^k;A00oo^k;A00?o0000ol>bbOl00000
4Oo0/L/00ol0003o`Zk6ol:^aP02ol:^aP;o00003?o1/L/00ol0003o_jg8okn]b006okn]b003o`00
0?o1]m3o`KO@00Ko`KO@00?o0000okfddOnm]=402_nm]=42o`0004kooooo1?l0000Jooooo`00L?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?moWNGoOigU00SoOigU00?o0000ojZ`g?nZ/=`00onZ
/=`2o`0000WoZJgJ00?o0000ok^bdOnk/]403_nk/]42o`0001;o`;7;00Go0000ol:^a_o2[/Ko`Zk6
o`00000>ol6ab`03o`000?no[LSo_jg800Go_jg800?o0000ol6gd?o1]m002?o1]m000ol0003o_KCA
okfdd@07okfdd@;o0000C?ooool4o`0001kooooo001aooooo`;o00005Oooool7o`0000CoOigU00?o
0000ojZ`g?l000000_l0000;ojV]fP03o`000?nk/]7o^k;A00go^k;A00?o0000okVad_l000004oo0
/L/00ol0003o`Zk6o`00000@ol6ab`03o`000?no[LSo_jg800;o_jg80_l0000<ol6gd003o`000?nm
]=7o_KCA00Go_KCA00?o0000ooooooooool0BOooool3o`0002;ooooo001cooooo`03o`000?oooooo
oooo01;ooooo00?o0000ohFLhOn5W>401?n5W>46o`0000ooZJgJ00?o0000ok^bdOnk/]402_nk/]42
o`0000?o^K7B00?o0000ol2aboo0/L/04?o0/L/2o`0001;o`K7;00Co0000okn]b?no[LSo00003_o1
]m000ol0003o_KCAokfdd@03okfdd@;o0000B?ooool4o`0002Gooooo001dooooo`03o`000?oooooo
oooo01;ooooo00?o0000ohFLhOn5W>402?n5W>400ol0003oZJgJojV]fP0>ojV]fP03o`000?nk/]7o
^k;A00Oo^k;A0_l00006okVadP03o`000?o0/L_o`;7;00ko`;7;00?o0000okndcol000004_o1/L/0
0ol0003o_jg8o`00000@ol6gd003o`000?nm]=7o_KCA00;o0000A_ooool4o`0002Wooooo001eoooo
o`03o`000?oooooooooo01;ooooo00?o0000ohFLhOn5W>402?n5W>400ol0003oZJgJojV]fP0=ojV]
fP03o`000?nk/]7o^k;A00Ko^k;A00?o0000okVad_ni/M801oni/M800ol0003o`;7;ol2ab`0;ol2a
b`;o00000ono]<l00ol0003o`K7;ol6ab`0?ol6ab`;o00004Oo1]m000ol0003o_KCAo`000014oooo
o`Co0000;Oooool007Kooooo0_l0000Booooo`03o`000?n5W>7oQIcQ00WoQIcQ00?o0000ojV]f_nY
[MX03OnY[MX00ol0003o^k;Aok^bd@03ok^bd@;o00002_ni/M800ol0003o`;7;ol2ab`0:ol2ab`03
o`000?no]<oo_kC?00Co_kC?00?o0000ol6aboo1/L/03Oo1/L/00ol0003o`[[Co`00000Aol6gd0;o
0000@Oooool4o`00037ooooo001hooooo`03o`000?oooooooooo013ooooo00?o0000ohFLhOn5W>40
2On5W>400ol0003oZJgJojV]fP0<ojV]fP04o`000?nk/]7o^k;Aok^bd@;o00003Oni/M800ol0003o
`;7;ol2ab`07ol2ab`;o00001ono]<l00ol0003o`K7;ol6ab`0;ol6ab`;o00000oo2^]<00ol0003o
`KO@ol6gd00=ol6gd003o`000?oooooooooo03kooooo0ol0000eooooo`00NOooool00ol0003ooooo
ooooo`0@ooooo`03o`000?n5W>7oQIcQ00WoQIcQ00?o0000ojV]f_nY[MX03?nY[MX00ol0003o^k;A
o`00000@okVadP03o`000?o0/L_o`;7;00Go`;7;00?o0000okndcono]<l02?no]<l00ol0003o`K7;
ol6ab`09ol6ab`03o`000?o2^]?o`[[C00Co`[[C00?o0000ol6gd?o1]m002_o1]m02o`0003gooooo
1?l0000hooooo`00N_ooool00ol0003oooooooooo`0?ooooo`03o`000?n5W>7oQIcQ00WoQIcQ00?o
0000ojV]f_nY[MX03?nY[MX2o`00017o^K7B00?o0000ol2aboo0/L/01?o0/L/00ol0003o_kC?oknd
c`0:okndc`03o`000?o1/L_o`K7;00Ko`K7;0_l00007ol:jd`03o`000?o1]m3o`KO@00So`KO@0_l0
000kooooo`Co0000??ooool007_ooooo0_l0000@ooooo`03o`000?n5W>7oQIcQ00WoQIcQ00?o0000
ojV]f_nY[MX02?nY[MX3o`000003ojR]fol0003o^K7B017o^K7B00Co0000ol2aboo0/L_o`;7;0_l0
000=okndc`03o`000?o1/L_o`K7;00Go`K7;00?o0000ol:jdoo2^]<02?o2^]<00ol0003o`KO@ol6g
d006ol6gd003o`000?oooooooooo03Oooooo1?l00010ooooo`00OOooool00ol0003oooooooooo`0=
ooooo`03o`000?n5W>7oQIcQ00[oQIcQ00?o0000ojV]f_nY[MX01?nY[MX3o`0000GoZ:gK00?o0000
okVad_ni/M804?ni/M800ol0003o`;7;o`00000@okndc`03o`000?o1/L_o`K7;00?o`K7;00?o0000
ol:jdoo2^]<02_o2^]<00ol0003o`KO@ol6gd003ol6gd0;o0000=_ooool4o`0004Cooooo001noooo
o`03o`000?oooooooooo00gooooo00?o0000ohFLhOn5W>402_n5W>400ol0003oZJgJojV]fP03o`00
00WoZ:gK00?o0000okVad_ni/M803oni/M82o`00017o_kC?00Co0000ol6aboo1/L_o`K7;0_l0000=
ol:jd`04o`000?o1]m3o`KO@ol6gd0;o0000=Oooool3o`0004Sooooo001oooooo`03o`000?oooooo
oooo00gooooo3ol0000=ojR]f`03o`000?ni/M;o^K7B00co^K7B0_l000000onh]MKo0000okndc`0A
okndc`03o`000?o1/L_o0000013o`[[C00?o0000ol6gd?l00000<oooool4o`0004_ooooo0020oooo
o`03o`000?oooooooooo00cooooo00?o0000ohZNhOn:W^402_n:W^400ol0003oZ:gKojR]f`0=ojR]
f`03o`000?ni/M;o^K7B00Wo^K7B0_l00004okReeP03o`000?no]<oo_kC?00oo_kC?0_l0000Aol:j
d`;o0000<?ooool4o`0004oooooo0021ooooo`;o00003Oooool00ol0003oRYkQohZNh@0:ohZNh@03
o`000?nX[M_oZ:gK00coZ:gK00?o0000okVad_ni/M801oni/M82o`0000Oo^;GF00?o0000okndcono
]<l03Ono]<l00ol0003o_kcGo`00000@ol:jd`03o`000?oooooooooo02cooooo1?l0001Cooooo`00
Poooool00ol0003oooooooooo`0;ooooo`03o`000?n:W^7oRYkQ00[oRYkQ00?o0000ojR]fonX[M/0
3?nX[M/00ol0003o^K7BokVadP05okVadP03o`000?nh]MKo^;GF00Oo^;GF00?o0000okndcono]<l0
2ono]<l2o`0000?o_kcG00?o0000ol:jdoo2^]<02oo2^]<2o`0002_ooooo1?l0001Gooooo`00Q?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?n:W^7oRYkQ00WoRYkQ00?o0000ojR]fonX[M/03OnX
[M/00ol0003o^K7BokVadP02okVadP;o00002onh]MH00ol0003o_kC?okndc`08okndc`;o00001_no
_=L00ol0003o`[[Col:jd`09ol:jd`03o`000?oooooooooo02Sooooo0ol0001Kooooo`00QOooool0
0ol0003oooooooooo`0;ooooo`03o`000?n:W^7oRYkQ00WoRYkQ00?o0000ojR]fonX[M/03OnX[M/0
1?l0003o^K7Bo`000?l0000>okReeP03o`000?no]<oo_kC?00Ko_kC?00?o0000oknleono_=L01_no
_=L00ol0003o`[[Col:jd`07ol:jd`;o00009oooool4o`0005kooooo0026ooooo`;o00002oooool0
0ol0003oRYkQohZNh@0:ohZNh@03o`000?nX[M_oZ:gK00_oZ:gK0ol0000AokReeP03o`000?no]<oo
_kC?00?o_kC?0_l0000:oknle`03o`000?o2^]?o`[[C00Go`[[C00?o0000ooooooooool08oooool4
o`0006;ooooo0028ooooo`03o`000?oooooooooo00Wooooo00?o0000ohZNhOn:W^402_n:W^400ol0
003oZ:gKojR]f`07ojR]f`?o00000_nX/Mh00ol0003o^;GFokReeP0?okReeP04o`000?no]<oo_kC?
okndc`;o00003Ono_=L00ol0003o`[[Col:jd`03ol:jd`03o`000?oooooooooo023ooooo1?l0001V
ooooo`00ROooool00ol0003oooooooooo`09ooooo`03o`000?n:W^7oRYkQ00WoRYkQ00?o0000ojR]
fonX[M/01?nX[M/3o`0000KoZ;7N00?o0000okRee_nh]MH03onh]MH00ol0003o_kC?o`00000?oknl
e`04o`000?o2^]?o`[[Col:jd`;o00007oooool4o`0006[ooooo002:ooooo`03o`000?oooooooooo
00Wooooo00?o0000ohZNhOn:W^402On:W^400ol0003oZ:gKojR]f`03o`0000[oZ;7N00?o0000okRe
e_nh]MH03_nh]MH2o`00017o_kcG00?o0000ol:jdol000007_ooool3o`0006kooooo002;ooooo`;o
00002_ooool>o`0000koZ;7N00?o0000okRee_nh]MH02onh]MH2o`000003okNlg_l0003o_kcG013o
_kcG0_l0000Kooooo`Co0000LOooool008gooooo00?o0000ooooooooool01oooool00ol0003oSJCT
ohfTi009ohfTi003o`000?nX/MkoZ;7N00koZ;7N00?o0000okRee_nh]MH02?nh]MH2o`0000Co]kcN
00?o0000oknleono_=L03?no_=L2o`0001Wooooo1?l0001eooooo`00S_ooool00ol0003ooooooooo
o`07ooooo`03o`000?n=Y>CoSJCT00WoSJCT00?o0000ojRag_nX/Mh03OnX/Mh00ol0003o^;GFokRe
eP05okReeP?o00001ong_=h00ol0003o_kcGoknle`0:oknle`03o`000?oooooooooo01Gooooo1?l0
001iooooo`00Soooool00ol0003oooooooooo`07ooooo`03o`000?n=Y>CoSJCT00WoSJCT00?o0000
ojRag_nX/Mh03OnX/Mh00ol0003o^;GFokReeP02okReeP;o00002ong_=h00ol0003o_kcGoknle`07
oknle`;o00005?ooool4o`0007gooooo002@ooooo`;o00002?ooool00ol0003oSJCTohfTi009ohfT
i003o`000?nX/MkoZ;7N00goZ;7N00Co0000okRee_l0003o00003_ng_=h00ol0003o_kcGoknle`04
oknle`;o00004oooool3o`00087ooooo002Booooo`03o`000?oooooooooo00Kooooo00?o0000ohfT
i?n=Y>@02On=Y>@00ol0003oZ;7NojRagP0;ojRagP?o00004Ong_=h00ol0003o_kcGoknle`02oknl
e`03o`000?oooooooooo00oooooo1?l00024ooooo`00Toooool00ol0003oooooooooo`05ooooo`03
o`000?n=Y>CoSJCT00WoSJCT00?o0000ojRag_nX/Mh02?nX/Mh3o`0000;oYkWV00?o0000okNlg_ng
_=h04?ng_=h01?l0003o_kcGo`000?l0000>ooooo`Co0000R?ooool009Cooooo00?o0000oooooooo
ool01Oooool00ol0003oSJCTohfTi009ohfTi003o`000?nX/MkoZ;7N00CoZ;7N0ol00006ojNiiP03
o`000?ng_=ko]kcN00oo]kcN0_l0000<ooooo`Co0000S?ooool009Gooooo0_l00006ooooo`03o`00
0?n=Y>CoSJCT00WoSJCT00?o0000ojRag_nX/Mh00ol0000:ojNiiP03o`000?ng_=ko]kcN00co]kcN
0_l0000:ooooo`Co0000T?ooool009Oooooo00?o0000ooooooooool01?ooool>o`0000koYkWV00?o
0000okNlg_ng_=h02Ong_=h2o`0000Wooooo0ol0002Dooooo`00V?ooool00ol0003oooooooooo`03
ooooo`03o`000?n=[ngoSJo]00_oSJo]00?o0000ojNii_nW^NH03?nW^NH00ol0003o]kcNokNlgP05
okNlgP?o00001oooool4o`0009Oooooo002Iooooo`03o`000?oooooooooo00?ooooo00?o0000ohf_
kOn=[nd02on=[nd00ol0003oYkWVojNiiP0<ojNiiP03o`000?ng_=ko]kcN00;o]kcN0_l00006oooo
o`Co0000Voooool009[ooooo00?o0000ooooooooool00oooool00ol0003oSJo]ohf_k@0;ohf_k@03
o`000?nW^NKoYkWV00coYkWV00Co0000okNlg_l0003o00001?ooool4o`0009oooooo002Kooooo`;o
00001?ooool00ol0003oSJo]ohf_k@0;ohf_k@03o`000?nW^NKoYkWV00[oYkWV0ol00002ooooo`Co
0000Xoooool009gooooo00?o0000ooooooooool00_ooool00ol0003oSJo]ohf_k@0;ohf_k@03o`00
0?nW^NKoYkWV00GoYkWV1?l00002ooooo`?o0000Yoooool009kooooo00?o0000ooooooooool00_oo
ool00ol0003oSJo]ohf_k@0;ohf_k@03o`000?nW^NKoYkWV00Co00000_ooool4o`000:[ooooo002O
ooooo`03o`000?oooooooooo00;ooooo00?o0000ohf_kOn=[nd01On=[nd8o`0000;ooooo1?l0002^
ooooo`00X?ooool2o`0000?ooooo1ol00006ooooo`Co0000/_ooool00:;ooooo00Co0000oooooooo
oooo00002?ooool4o`000;Kooooo002Sooooo`03o`000?oooooo000000Gooooo0ol0002jooooo`00
Y?ooool2o`000003ooooool0003o000000;o0000_Oooool00:Gooooo0_l00031ooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00cOooool3
o`000003oa0@4?oooooooooo09Gooooo002booooo`03o`000?oooooooooo00Kooooo00?oMgMgofIV
I_ooool02Oooool00ol0003o^[Zjooooo`05ooooo`03oa0@4?nj^[[ooooo00?ooooo00?oIVIVogMg
Moooool0T?ooool00;;ooooo00?o410@omgMgOooool01Oooool00ooMgMgo410@onk^kP0:ooooo`;o
<S8b1_ooool00onHV9So<S8booooo`03ooooo`03onk^k_l@413ogMgM093ooooo002`ooooo`05olc<
c?l@413o0000o`000?n7QhL01Oooool00omEEEGoV9RHooooo`02ooooo`;o00000_ooool2o`0000;o
oooo00?oQhN7o`000?nj^[X01Oooool00ooMgMgo0000okZj^P04ooooo`03ohN7QomVIVKooooo08oo
oooo002`ooooo`06ob4Q8On7QhOo<S8bojVYZOm4A4CoQhN71?ooool00ol0003oooooooooo`02oooo
o`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@4005ooooo`03oeEEEOmg
MgOoA4A400Cooooo00?ok^k^o`000?ooool0Soooool00;3ooooo00Ko0000oooooomVIVKoQhN7omgM
gOl@4104ooooo`03oc8b<_oooooooooo00?ooooo00CogMgMo`000?l@413oc<c<2_ooool01OoMgMgo
410@oooooolQ8B7ogMgM00Cooooo00?o0000ooooooooool0S_ooool00;3ooooo00Ko410@omgMgOmg
MgOoMgMgooooool00004ooooo`03oc8b<_oooooooooo00?ooooo00Cok^k^ob4Q8Ol@413ok^k^2_oo
ool01OmVIVKoQhN7oooooonHV9SoEEEE00Cooooo00?o0000ooooooooool0S_ooool00;3ooooo00Ko
ZJVYodA4A?nHV9SoA4A4oiRHV?l@4104ooooo`03o`000?o^k^kooooo00?ooooo00Co8B4QogMgMomg
MgOo<S8b2Oooool00oo^k^ko0000onk^kP02ooooo`06o`000?oMgMgoooooooooooo^k^ko0000T?oo
ool00;7ooooo00GoV9RHo`000?l0003o410@olc<c004ooooo`03oeEEEOmgMgOooooo00;ooooo0_l0
0002ooooo`;o00002?ooool01?l@413o0000o`000?ooool2o`000005oa0@4?ooooooooooogMgMomE
EED0T?ooool00;;ooooo00?o^[Zjoc8b<_ooool01Oooool00ooMgMgo410@onk^kP0Hooooo`03onk^
k_l@413ogMgM093ooooo002cooooo`03o`000?oooooooooo00Gooooo00?oMgMgofIVI_ooool05ooo
ool00omVIVKoMgMgooooo`2@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.121221, 0.0265831, \
0.00377224, 0.00377224}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 6.2", "Subsubtitle",
  CellTags->"c:27"],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " Consider the following heat equation problem on ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(0 \[LessEqual] \ x \[LessEqual] \ 1\)\(:\)\)\)]]
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[PartialD]\(T(x, t)\)\), \(\[PartialD]t\),
            MultilineFunction->None], "=", 
          RowBox[{
            RowBox[{\(\[Chi](x)\), 
              
              FractionBox[\(\[PartialD]\^2\( T(x, t)\)\), \(\[PartialD]x\^2\),
                
                MultilineFunction->None]}], "+", \(2\ x\)}]}], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`T(0, t) = \(T(1, t) = 0\)\)]],
  ",",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, 0) = 0\)]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi](x)\  = \ 1\ \ for\ 0 < x < 1/2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi](x) = 2\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`1/2\  < x < 1\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Using the FTCS method, and taking  ",
  Cell[BoxData[
      \(TraditionalForm\`M = 10\)]],
  " (i.e., 11 grid points including the end points), what is the largest time \
step size one can use? "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Solve the equation with the largest possible time step size.  Make an \
animation showing only every fifth time step for ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ t \[LessEqual] \ 1/2\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  "  Using the Lax method with the largest possible time step size, solve the \
following heat equation problem on ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(0 \[LessEqual] \ x \[LessEqual] \ 
          1\)\(:\)\)\)]],
  " "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[PartialD]\(T(x, t)\)\), \(\[PartialD]t\),
            MultilineFunction->None], "=", 
          RowBox[{
            FractionBox["\[PartialD]", \(\[PartialD]x\),
              MultilineFunction->None], \(\[Chi](x)\), 
            FractionBox[\(\[PartialD]\(T(x, t)\)\), \(\[PartialD]x\),
              MultilineFunction->None]}]}], TraditionalForm]]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`T(0, t) = sin(6  \[Pi]\ t), \ T(1, t) = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, 0) = 0\)]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi](x)\  = \ x\ \ for\ 0 < x < 1/2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi](x) = 2  x - 1/2\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`1/2\  < x < 1\)]],
  ".Make an animation showing only every fifth time step for ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ t \[LessEqual] \ 1/2\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " Consider the following first-order PDE:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(\[PartialD]\(y(x, t)\)\), \(\[PartialD]t\),
              MultilineFunction->None], "+", 
            RowBox[{"c", 
              FractionBox[\(\[PartialD]\(y(x, t)\)\), \(\[PartialD]x\),
                MultilineFunction->None]}]}], "=", "0"}], TraditionalForm]]],
  "."
}], "Text"],

Cell["\<\
Using von Neumann  stability analysis, show that the CTCS method \
applied to that equation is stable provided that the following Courant \
condition is satisfied:\
\>", "Text",
  CellTags->"i:66"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"c", " ", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], "/", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}]}], " ", "\[LessEqual]", "  ", 
          "1"}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.44)"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " For the time-dependent Schr\[ODoubleDot]dinger equation in 1D [Eq. ",
  ButtonBox["(3.1.81)",
    ButtonData:>{"Chapter3.nb", "(3.1.81)"},
    ButtonStyle->"Hyperlink"],
  "], and for a particle of mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " in a constant potential ",
  Cell[BoxData[
      \(TraditionalForm\`V(x) = V\_o\)]],
  ", show that the CTCS method is stable only if ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], " ", "[", 
            RowBox[{"|", \(V\_o\), "|", 
              RowBox[{\(\(/\)\(\[HBar]\)\), " ", "+", " ", 
                RowBox[{"4", " ", 
                  RowBox[{"\[HBar]", "/", 
                    RowBox[{"(", 
                      RowBox[{"m", " ", 
                        SuperscriptBox[
                          StyleBox[
                            RowBox[{"\[CapitalDelta]", 
                              StyleBox["x",
                                FontSlant->"Italic"]}]], "2"]}], 
                      ")"}]}]}]}]}], "]"}], " ", "<", "2"}], 
        TraditionalForm]]],
  ". This sets a rather stringent condition on ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", rendering CTCS  of only academic interest for quantum problems."
}], "Text"],

Cell[TextData[{
  StyleBox["(5)(a)",
    FontWeight->"Bold"],
  " Use the CTCS method to finite-difference the wave equation in ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " dimensions (on a uniform Cartesian grid). Perform a von Neumann  \
stability analysis to show that this method is stable provided that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"c", " ", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], "/", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}]}], " ", "\[LessEqual]", 
          "  ", \(1/\(\(\@D\)\(.\)\)\)}], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " For the 1-D wave equation,  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[PartialD]\^2 y\), \(\[PartialD]t\^2\),
            MultilineFunction->None], "=", 
          RowBox[{\(c\^2\), " ", \((x)\), 
            FractionBox[\(\[PartialD]\^2\( y(x, t)\)\), \(\[PartialD]x\^2\),
              MultilineFunction->None]}]}], TraditionalForm]]],
  "on ",
  Cell[BoxData[
      \(TraditionalForm\`\(-4\) < x < 4\)]],
  ",  where ",
  Cell[BoxData[
      \(TraditionalForm\`c(x)\  = \ 1\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`x < 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`c(x)\  = \(\(1/2\)\(\ \)\)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`x \[GreaterEqual] \ 0\)]],
  ", use the CTCS method to solve the following problem for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 20\)]],
  ". Take ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", " ", "0.25"}], TraditionalForm]]],
  ",  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "=", "0.2"}], TraditionalForm]]],
  ":"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`y(x, 
          0) = \[ExponentialE]\^\(\(-2\) \((x - 2)\)\^2\)\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(\[PartialD]\(y(x, t)\)\), \(\[PartialD]t\),
              
              MultilineFunction->
                None], \( \[VerticalSeparator] \_\(t = 0\)\)}], 
          "=", \(\(-2\) \((x - 
                2)\)\ \[ExponentialE]\^\(\(-2\) \((x - 2)\)\^2\)\)}], 
        TraditionalForm]]],
  ",",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`y(\(-4\), t)\  = \(y(4, t)\  = \ 0\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Make an animation of the result showing every fifth time step. Note: The \
CTCS scheme will require you to specify  ",
  Cell[BoxData[
      \(TraditionalForm\`y\_k\%1\)]],
  " directly from the two initial conditions. To determine ",
  Cell[BoxData[
      \(TraditionalForm\`y\_k\%1\)]],
  "use the equation for uniform acceleration, "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(y\_k\%1\), "=", 
          RowBox[{\(y\_k\%0\), "+", 
            RowBox[{\(v\_\(0\ k\)\), 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}], "  ", "+", " ", 
            RowBox[{\(a\_\(\(k\)\(\ \)\)\), 
              RowBox[{
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]], "2"], "/", "2"}]}]}]}], 
        TraditionalForm]]],
  ", "
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\(o\ k\)\)]],
  " is the initial velocity of the ",
  Cell[BoxData[
      FormBox[
        RowBox[{Cell["k"], "th"}], TraditionalForm]]],
  " point and ",
  Cell[BoxData[
      \(TraditionalForm\`a\_k\)]],
  " is the initial acceleration, determined by"
}], "Text"],

Cell[TextData[{
  "  \t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(a\_\(\(k\)\(\ \)\)\), "=", " ", 
          RowBox[{
            RowBox[{\(c\^2\), " ", 
              
              FractionBox[\(\[PartialD]\^2\( y(x, 0)\)\), \(\[PartialD]x\^2\),
                
                MultilineFunction->None]}], \( | \_\(x = x\_k\)\)}]}], 
        TraditionalForm]]],
  " . "
}], "Text"],

Cell[TextData[{
  StyleBox["(6)(a)",
    FontWeight->"Bold"],
  " Prove Eq. ",
  ButtonBox["(6.2.15)",
    ButtonData:>"(6.2.15)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Prove Eq. ",
  ButtonBox["(6.2.17)",
    ButtonData:>"(6.2.17)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(7)",
    FontWeight->"Bold"],
  " Repeat Exercise (1) using the Crank-Nicolson method. Now take as a time \
step size ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], " ", "=", " ", "0.02"}], 
        TraditionalForm]]],
  " and show every frame of the animation for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 1/2\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(8)(a)",
    FontWeight->"Bold"],
  " For the 1-D Schr\[ODoubleDot]dinger equation and for a particle of mass \
",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " in a uniform potential ",
  Cell[BoxData[
      \(TraditionalForm\`V(x) = V\_o\)]],
  ", show that the Crank-Nicolson method is stable for any time step size. "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Use the Crank-Nicolson method to solve the Schr\[ODoubleDot]dinger \
equation for a particle of mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ", described by a wave function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, t)\)]],
  ", moving in a potential ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\  = \ 8\ x\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`\(-4\) < x < 4\)]],
  ", over the time range ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 3\)]],
  ". Animate ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(|\)\(\[Psi]\)\(|\))\)\^2\)]],
  " over this time interval. Take ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] = 0\)]],
  " on the boundaries, and assume an initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, 
          0) = \[ExponentialE]\^\(5\ \[ImaginaryI]\ x\  - 2\ \((x + 2)\)\^2\)\
\)]],
  ". Also, take ",
  Cell[BoxData[
      \(TraditionalForm\`m = \(\[HBar] = 1\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(9) ",
    FontWeight->"Bold"],
  "Consider the following heat equation problem on ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ r \[LessEqual] \ 1\)]],
  " in ",
  StyleBox["cylindrical",
    FontSlant->"Italic"],
  " geometry:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[PartialD]T\), \(\[PartialD]t\),
            MultilineFunction->None], "=", 
          RowBox[{
            FractionBox[\(\[PartialD]\^2 T\), \(\[PartialD]r\^2\),
              MultilineFunction->None], "+", 
            RowBox[{\(1\/r\), 
              FractionBox[\(\[PartialD]T\), \(\[PartialD]r\),
                MultilineFunction->None]}], "+", 
            RowBox[{\(1\/r\^2\), 
              FractionBox[\(\[PartialD]\^2 T\), \(\[PartialD]\[Theta]\^2\),
                MultilineFunction->None]}], "+", 
            " ", \(\(r\^2\) cos\ m\ \[Theta]\)}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(T(1, \[Theta], \ t)\), "=", 
            RowBox[{
              RowBox[{"-", 
                
                FractionBox[\(\[PartialD]\(T(r, \[Theta], \ 
                      t)\)\), \(\[PartialD]r\),
                  MultilineFunction->None]}], 
              SubscriptBox[
                StyleBox["\[VerticalSeparator]",
                  FontSize->14], \(r = 1\)]}]}], ","}], TraditionalForm]]],
  "   ",
  Cell[BoxData[
      \(TraditionalForm\`T(r, \[Theta], 0) = 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " The solution will depend on ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`cos\ m\ \[Theta]\)]],
  ", so only a radial grid is necessary. While this simplifies the numerics, \
we now require a boundary condition at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  ". Recall from Sec. ",
  ButtonBox["6.1",
    ButtonData:>"c:2",
    ButtonStyle->"Hyperlink"],
  " that the proper boundary condition is"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{\(lim\_\(r \[Rule] 0\)\), 
              FractionBox[\(\[PartialD]T\), \(\[PartialD]r\),
                MultilineFunction->None]}], "-", \(\(m\^2\/r\) T\)}], " ", 
          "=", " ", "0"}], TraditionalForm]]]
}], "Text",
  CellTags->"i:38"],

Cell[TextData[{
  "[see Eq. ",
  ButtonBox["(6.1.37)",
    ButtonData:>"(6.1.37)",
    ButtonStyle->"Hyperlink"],
  "].   For ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0\)]],
  " this implies ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[PartialD]T\), \(\[PartialD]r\),
            MultilineFunction->None], "=", "0"}], TraditionalForm]]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  ", but for ",
  Cell[BoxData[
      \(TraditionalForm\`m \[NotEqual] \ 0\)]],
  " it implies ",
  Cell[BoxData[
      \(TraditionalForm\`T = 0\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  ". In both cases the grid must avoid ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  ". The best choice is ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(r(j)\), " ", "=", " ", 
          RowBox[{\((j - 1/2)\), " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["r",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0, 1,  ... \)]],
  "., using a centered-difference for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]T/\[PartialD]r\)\( | \_\(r = 
              0\)\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\((\ if\ m = 0)\)\)]],
  ",  or the average value at grid points ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0\)]],
  " and 1 for ",
  Cell[BoxData[
      \(TraditionalForm\`T\_\(|\_\(r = 0\)\)\)]],
  "(if ",
  Cell[BoxData[
      \(TraditionalForm\`m \[NotEqual] \ 0\)]],
  "). Use the differencing techniques discussed in connection with Eqs. ",
  ButtonBox["(6.2.23)",
    ButtonData:>"(6.2.23)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(6.2.25)",
    ButtonData:>"(6.2.25)",
    ButtonStyle->"Hyperlink"],
  " to  satisfy the mixed boundary condition at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 1\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Use the  Crank-Nicolson method to solve this problem for the case ",
  Cell[BoxData[
      \(TraditionalForm\`m = 1\)]],
  ". Take the time step size  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], 
            StyleBox[" ",
              FontSlant->"Italic"], "=", " ", "0.02"}], ","}], 
        TraditionalForm]]],
  " and take ",
  Cell[BoxData[
      \(TraditionalForm\`M = 10\)]],
  " (i.e. 11 grid points in ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  "). Make an animation of the solution as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] = 0\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ t \[LessEqual] \ 1/2\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(10)",
    FontWeight->"Bold"],
  " A sandbar causes the water depth in the ocean to vary as ",
  Cell[BoxData[
      \(TraditionalForm\`h(x)\  = \ 1 - \[ExponentialE]\^\(-x\^2\)/2\)]],
  ". Water waves impinge on the sand bar at normal incidence, satisfying the \
1-D shallow water wave equation ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[PartialD]\^2\( z(x, t)\)\), \(\[PartialD]t\^2\),
            MultilineFunction->None], "=", 
          RowBox[{
            FractionBox["\[PartialD]", \(\[PartialD]x\),
              MultilineFunction->None], 
            RowBox[{"(", 
              RowBox[{\(c\^2\), " ", \((x)\), 
                FractionBox[\(\[PartialD]\(z(x, t)\)\), \(\[PartialD]x\),
                  MultilineFunction->None]}], ")"}]}]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\^2\)(x)\  = \ g\ \(h(x)\)\)]],
  ". Solve using CTCS for ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, t)\)]],
  "on a grid with ",
  Cell[BoxData[
      \(TraditionalForm\`M = 50\)]],
  " points, with ",
  StyleBox["periodic",
    FontSlant->"Italic"],
  " boundary conditions on ",
  Cell[BoxData[
      \(TraditionalForm\`\(-5\) < x < 5\)]],
  ", and with initial conditions that ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, 
          0)\  = \ \[ExponentialE]\^\(\(-2\) \((x - 2)\)\^2\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(z\& . \)(x, 
          0) = \(-4\) \((x - 
              2)\)\ \[ExponentialE]\^\(\(-2\) \((x - 2)\)\^2\)\)]],
  " . [Hint: Periodic boundary conditions imply that ",
  Cell[BoxData[
      \(TraditionalForm\`z(\(-5\), t) = z(5, t)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(z\^\[Prime]\)(\(-5\), t) = \(z\^\[Prime]\)(5, 
          t)\)]],
  ". ] Animate the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 6\)]],
  ", taking ",
  Cell[BoxData[
      \(TraditionalForm\`g\  = 1\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " as large as possible."
}], "Text"],

Cell[TextData[{
  StyleBox["(11) ",
    FontWeight->"Bold"],
  "A square pool with ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < a\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`0 < y < a\)]],
  ",  has a sloped bottom, becoming deeper  as ",
  Cell[BoxData[
      \(TraditionalForm\`x\ or\ y\)]],
  " increases: ",
  Cell[BoxData[
      \(TraditionalForm\`h(x, y)\  = \ \(h\_o\)(1 + x/a + y/a)\)]],
  ". Assuming potential flow, the horizontal fluid displacement satisfies ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[Eta]",
            FontWeight->"Bold"], " ", "=", 
          " ", \(\[Del]\(\[Phi](x, y, t)\)\)}], TraditionalForm]]],
  "and the wave height is given by ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, y, 
          t) = \(-\[Del]\)\[CenterDot]\([\(h(x, y)\) \[Del]\[Phi]]\)\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " satisfying the following wave equation:"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FractionBox[\(\[PartialD]\^2\( \[Phi](x, y, 
                t)\)\), \(\[PartialD]t\^2\),
            MultilineFunction->None], "=", 
          RowBox[{
            RowBox[{
              FractionBox["\[PartialD]", \(\[PartialD]x\),
                MultilineFunction->None], 
              RowBox[{"(", 
                RowBox[{\(\(c\^2\)(x, y)\), 
                  
                  FractionBox[\(\[PartialD]\(\[Phi](x, , y, 
                        t)\)\), \(\[PartialD]x\),
                    MultilineFunction->None]}], ")"}]}], "+", 
            RowBox[{
              FractionBox["\[PartialD]", \(\[PartialD]y\),
                MultilineFunction->None], 
              RowBox[{"(", 
                RowBox[{\(\(c\^2\)(x, y)\), 
                  
                  FractionBox[\(\[PartialD]\(\[Phi](x, , y, 
                        t)\)\), \(\[PartialD]y\),
                    MultilineFunction->None]}], ")"}]}]}]}], 
        TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(6.2.45)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`c\^2 = g\ h\)]],
  ". Initially, the fluid is stationary, but an inlet at the center of the ",
  "left-hand",
  " side, of length ",
  Cell[BoxData[
      \(TraditionalForm\`a/2\)]],
  " begins to add and remove water according to  ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(\[Eta]\_x\)(0, y)\  = \ x\_o\ \(sin(\[Omega]\_o\ t)\)\), 
          ",", " ", 
          RowBox[{\(a/4\), "<", "y", "<", 
            RowBox[{"3", " ", \(a/4\), " ", Cell[""]}]}]}], 
        TraditionalForm]]],
  ". Around the rest of the pool, the normal component of ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Eta]",
          FontWeight->"Bold"], TraditionalForm]]],
  " is zero."
}], "Text"],

Cell[TextData[{
  "Using CTCS, solve ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y, t)\)]],
  " on a 15-by-15 grid for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < \)]],
  "4 s, assuming that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"a", "=", 
            RowBox[{"5", " ", 
              StyleBox["m",
                FontSlant->"Plain"]}]}], ",", \(h\_o = 10\ cm\), ",", " ", 
          RowBox[{\(\[Omega]\_o\), "=", 
            RowBox[{"3", Cell[""]}]}], ",", " ", 
          RowBox[{\(x\_o\), "=", 
            RowBox[{"2", " ", "cm", Cell[""]}]}]}], TraditionalForm]]],
  ". Make an animation of the resulting wave height ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, y, t)\)]],
  " over this time period. "
}], "Text"],

Cell[TextData[{
  StyleBox["(12)",
    FontWeight->"Bold"],
  " An electrolytic cell consists of a glass tank of width ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " and height ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ", and length ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " in the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-direction (into the page).  The tank is filled with fluid that has \
electrical conductivity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\)]],
  " . The tank has electrodes of length ",
  Cell[BoxData[
      \(TraditionalForm\`L = a/2\)]],
  ", located as shown in Fig. ",
  ButtonBox["6.8",
    ButtonData:>"Fig. 6.8",
    ButtonStyle->"Hyperlink"],
  ",  and attached on the left and right sides; the rest of the surface is \
electrically insulated.  The right electrode  is grounded and the left \
electrode is at a potential ",
  Cell[BoxData[
      \(TraditionalForm\`V\_o\)]],
  ".  Using the direct method, solve for the potential in the fluid, and use \
this result to find the total current ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(I\)\(\ \)\)\)]],
  " running between the two electrodes . (See Example 2 in Sec. ",
  ButtonBox["3.2.2",
    ButtonData:>{"Chapter3.nb", "c:30"},
    ButtonStyle->"Hyperlink"],
  " for help on setting up the equations for this problem.) Do this problem \
for ",
  Cell[BoxData[
      \(TraditionalForm\`b = n\ a/5\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2,  ... , 10\)]],
  ", and plot the result  for ",
  Cell[BoxData[
      \(TraditionalForm\`I\)]],
  " vs. ",
  Cell[BoxData[
      \(TraditionalForm\`b/a\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`I\)]],
  " suitably normalized in terms of the given parameters.  [Hint: This is \
really a two-dimensional problem; current density and potential depend only \
on ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  ". Part of the boundary has a von Neumann  boundary condition, and part has \
a Dirichlet condition. For second-order accuracy, use a grid for which the \
boundary falls halfway between the grid points. For the von Neumann  portion \
of the boundary, use the centered-difference method discussed in relation to \
Eq. ",
  ButtonBox["(6.2.20)",
    ButtonData:>"(6.2.20)",
    ButtonStyle->"Hyperlink"],
  ", and for the Dirichlet part of the boundary, use the averaging technique \
discussed in relation to Eq. ",
  ButtonBox["(6.2.22)",
    ButtonData:>"(6.2.22)",
    ButtonStyle->"Hyperlink"],
  ".]"
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:@0001F2000`400?l00000o`00003ooooooooo
oooooi;ooooo003oooooooooooooT_ooool00?oooooooooooonBooooo`00oooooooooooooi;ooooo
003oooooooooooooT_ooool00?oooooooooooonBooooo`00oooooooooooooi;ooooo003ooooooooo
ooooT_ooool00?oooooooooooonBooooo`004?oooomZ0?ooo`030820P000000000000?l00000c000
000g0?oooa7ooooo000@ooooofX0oooo00<0P820000000000000o`00003<000003L0oooo4Oooool0
013oooooJP3oool00`20P80000000000003o00000<`00000=`3ooolAooooo`004?oooomZ0?ooo`04
0820P0000000000000000?l0ooooaP3oool5000003L0oooo4Oooool0013oooooJP3oool01020P800
000000000000003o0?ooolH0oooo1@00000g0?oooa7ooooo000@ooooob@0oooo00<000000?ooo`3o
ool0@03oool<00000?l0oooo`@3oool5000003L0oooo4Oooool0013ooooo903oool00`000000oooo
0?ooo`100?ooo``00000o`3oooo10?ooo`D00000=`3ooolAooooo`004?oooolS0?ooo`030820P000
0000P8200440oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`000011
0?ooo``00000o`3oooo10?ooo`D00000=`3ooolAooooo`004?oooolS0?ooo`<00000@@3oool<0000
0?l0oooo`@3oool5000003L0oooo4Oooool0013ooooo8P3oool500000400oooo3000003o0?oool40
oooo1@00000g0?oooa7ooooo000@ooooob80oooo1@0000100?ooo``00000o`3oooo10?ooo`D00000
=`3ooolAooooo`004?oooolR0?ooo`D00000@03oool<00000?l0oooo`@3oool5000003L0oooo4Ooo
ool0013ooooo8@3oool7000003l0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@oooo
ob40oooo1`00000o0?ooo``00000o`3oooo10?ooo`D00000=`3ooolAooooo`004?oooolQ0?ooo`L0
0000?`3oool<00000?l0oooo`@3oool5000003L0oooo4Oooool0013ooooo803oool9000003h0oooo
3000003o0?oool40oooo1@00000g0?oooa7ooooo000@ooooob00oooo2@00000n0?ooo``00000o`3o
ooo10?ooo`D00000=`3ooolAooooo`004?oooolP0?ooo`T00000?P3oool<00000?l0oooo`@3oool5
000003L0oooo4Oooool0013ooooo7`3oool;000003d0oooo3000003o0?oool40oooo1@00000g0?oo
oa7ooooo000@oooooal0oooo2`00000m0?ooo``00000o`3oooo10?ooo`D00000=`3ooolAooooo`00
4?oooolN0?ooo``0000000<0P8200?ooo`3oool0>P3oool<00000?l0oooo`@3oool5000003L0oooo
4Oooool0013ooooo7P3oool=000003`0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@
oooooad0oooo3P00000l0?ooo``00000o`3oooo10?ooo`D00000=`3ooolAooooo`004?oooolM0?oo
o`l00000>`3oool<00000?l0oooo`@3oool5000003L0oooo4Oooool0013ooooo7@3oool?000003/0
oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@oooooa`0oooo4@00000j0?ooo``00000
o`3oooo10?ooo`D00000=`3ooolAooooo`004?oooolL0?oooa400000>P3oool<00000?l0oooo`@3o
ool5000003L0oooo4Oooool0013ooooo6`3ooolB000003X0oooo3000003o0?oool40oooo1@00000g
0?oooa7ooooo000@oooooa/0oooo4`00000i0?ooo``00000o`3oooo10?ooo`D00000=`3ooolAoooo
o`004?oooolK0?oooa<00000>@3oool<00000?l0oooo`@3oool5000003L0oooo4Oooool0013ooooo
6`3ooolC000003T0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@oooooaX0oooo5@00
000h0?ooo``00000o`3oooo10?ooo`D00000=`3ooolAooooo`004?oooolJ0?oooaD00000>03oool<
00000?l0oooo`@3oool5000003L0oooo4Oooool0013ooooo6P3ooolE000003P0oooo3000003o0?oo
ol40oooo1@00000g0?oooa7ooooo000@oooooaT0oooo5`00000g0?ooo``00000o`3oooo10?ooo`D0
0000=`3ooolAooooo`004?oooolI0?oooaL00000=`3oool<00000?l0oooo`@3oool5000003L0oooo
4Oooool0013ooooo603ooolI000003H0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@
oooooaP0oooo6@00000f0?ooo``00000o`3oooo10?ooo`D00000=`3ooolAooooo`004?oooolG0?oo
oaX00000=P3oool<00000?l0oooo`@3oool5000003L0oooo4Oooool0013ooooo5`3ooolJ00000003
0820P03oool0oooo03<0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@oooooaL0oooo
6P0000000`20P800oooo0?ooo`0c0?ooo``00000o`3oooo10?ooo`D00000=`3ooolAooooo`004?oo
oolF0?oooa/0000000<0P8200?ooo`3oool0<`3oool<00000?l0oooo`@3oool5000003L0oooo4Ooo
ool0013ooooo5P3ooolL000003D0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@oooo
oaH0oooo7000000e0?ooo``00000o`3oooo10?ooo`D00000=`3ooolAooooo`004?oooolF0?oooa`0
0000=@3oool<00000?l0oooo`@3oool5000003L0oooo4Oooool0013ooooo5@3oool00`20P8000000
0000000K000003@0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@oooooaD0oooo00<0
P8200000000000006`00000d0?ooo``00000o`3oooo10?ooo`D00000=`3ooolAooooo`004?oooolH
0?oooaT00000=P3oool<00000?l0oooo`@3oool5000003L0oooo4Oooool0013ooooo6`3oool60820
P0T000001020P80i0?ooo``00000o`3oooo10?ooo`D00000=`3ooolAooooo`004?oooolS0?ooo`<0
0000@@3oool<00000?l0oooo`@3oool5000003L0oooo4Oooool0013ooooo8`3oool3000001H0oooo
6@00000B0?ooo``00000o`3oooo10?ooo`D00000=`3ooolAooooo`004?oooolS0?ooo`<00000603o
oolH00000140oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`00000I
0?ooo`030820P0000000000000800000303oool600000140oooo3000003o0?oool40oooo1@00000g
0?oooa7ooooo000@ooooob<0oooo0`00000I0?ooo`040820P0000000000000000100oooo0`00000A
0?ooo``00000o`3oooo10?ooo`D00000=`3ooolAooooo`004?oooolS0?ooo`<000006@3oool01020
P800000000000000000A0?ooo`<00000403oool<00000?l0oooo`@3oool5000003L0oooo4Oooool0
013ooooo8`3oool3000001T0oooo00@0P82000000000000000004P3oool200000100oooo3000003o
0?oool40oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`00000I0?ooo`040820P00000000000
000001<0oooo00<000000?ooo`3oool03P3oool<00000?l0oooo`@3oool5000003L0oooo4Oooool0
013ooooo8`3oool3000001T0oooo00@0P82000000000000000004`3oool2000000l0oooo3000003o
0?oool40oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`00000I0?ooo`040820P00000000000
000002@0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`00000I0?oo
o`040820P00000000000000002@0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@oooo
ob<0oooo0`00000I0?ooo`040820P00000000000000002@0oooo3000003o0?oool40oooo1@00000g
0?oooa7ooooo000@ooooob<0oooo0`00000I0?ooo`040820P00000000000000002@0oooo3000003o
0?oool40oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`00000I0?ooo`040820P00000000000
000002@0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`00000I0?oo
o`040820P00000000000000002@0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@oooo
ob<0oooo0`00000I0?ooo`040820P00000000000000002@0oooo3000003o0?oool40oooo1@00000g
0?oooa7ooooo000@ooooob<0oooo0`00000I0?ooo`040820P00000000000000002@0oooo3000003o
0?oool40oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`00000I0?ooo`040820P00000000000
000002@0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`00000I0?oo
o`040820P00000000000000002@0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@oooo
ob<0oooo0`00000I0?ooo`040820P00000000000000002@0oooo3000003o0?oool40oooo1@00000g
0?oooa7ooooo000@ooooob<0oooo0`00000I0?ooo`040820P00000000000000002@0oooo3000003o
0?oool40oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`00000I0?ooo`040820P00000000000
000002@0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`00000I0?oo
o`040820P00000000000000002@0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@oooo
ob<0oooo0`00000I0?ooo`040820P00000000000000002@0oooo3000003o0?oool40oooo1@00000g
0?oooa7ooooo000@ooooob<0oooo0`00000I0?ooo`040820P00000000000000002@0oooo3000003o
0?oool40oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`00000I0?ooo`040820P00000000000
000002@0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`00000I0?oo
o`040820P00000000000000002@0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@oooo
ob<0oooo0`00000I0?ooo`040820P00000000000000002@0oooo3000003o0?oool40oooo1@00000g
0?oooa7ooooo000@ooooob<0oooo0`00000I0?ooo`040820P00000000000000002@0oooo3000000/
0?ooo`80P820o`3ooonC0?ooo`D00000=`3ooolAooooo`004?oooolS0?ooo`<000006@3oool50000
02<0oooo3000000[0?ooo`@00000o`3ooonB0?ooo`D00000=`3ooolAooooo`004?oooolS0?ooo`<0
0000603oool700000280oooo3000000Z0?ooo`D0000000<0P8200?ooo`3oool0o`3ooon?0?ooo`D0
0000=`3ooolAooooo`004?oooolS0?ooo`<000005P3oool;00000200oooo3000000[0?ooo`D00000
o`3ooonA0?ooo`D00000=`3ooolAooooo`004?oooolS0?ooo`<00000@@3oool<000002`0oooo1P00
003o0?ooohl0oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`0000110?ooo``00000;@3oool6
00000?l0ooooSP3oool5000003L0oooo4Oooool0013ooooo8`3oool300000440oooo3000000^0?oo
o`H00000o`3ooon=0?ooo`D00000=`3ooolAooooo`004?oooolS0?ooo`<00000@@3oool<000002l0
oooo00<0P8200000000000000`00003o0?oooh`0oooo1@00000g0?oooa7ooooo000@ooooob<0oooo
0`0000110?ooo``00000<03oool600000?l0ooooR`3oool5000003L0oooo4Oooool0013ooooo8`3o
ool300000440oooo3000000a0?ooo`H00000o`3ooon:0?ooo`D00000=`3ooolAooooo`004?oooolS
0?ooo`<00000@@3oool<00000380oooo1P00003o0?ooohT0oooo1@00000g0?oooa7ooooo000@oooo
ob<0oooo0`0000110?ooo``00000<`3oool600000?l0ooooR03oool5000003L0oooo4Oooool0013o
oooo8`3oool300000440oooo3000000d0?ooo`H00000o`3ooon70?ooo`D00000=`3ooolAooooo`00
4?oooolS0?ooo`<00000@@3oool<000003D0oooo1P00003o0?ooohH0oooo1@00000g0?oooa7ooooo
000@ooooob<0oooo0`0000110?ooo``00000=P3oool00`20P800000000000004000000030<30`03o
ool0oooo0?l0ooooP@3oool5000003L0oooo4Oooool0013ooooo8`3oool300000440oooo3000000h
0?ooo`H00000o`3ooon30?ooo`D00000=`3ooolAooooo`004?oooolS0?ooo`<00000@@3oool<0000
03X0oooo1@00003o0?oooh80oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`0000110?ooo``0
0000>`3oool500000?l0ooooP@3oool5000003L0oooo4Oooool0013ooooo8`3oool300000440oooo
3000000l0?ooo`D00000o`3ooon00?ooo`D00000=`3ooolAooooo`004?oooolS0?ooo`<00000@@3o
ool<000003d0oooo1@00003o0?ooogl0oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`000011
0?ooo``00000?@3oool00`20P80000000000000300000?l0ooooOP3oool5000003L0oooo4Oooool0
013ooooo8`3oool300000440oooo3000000n0?ooo`H00000o`3ooomm0?ooo`D00000=`3ooolAoooo
o`004?oooolS0?ooo`<00000@@3oool<000003l0oooo1`00003o0?ooog/0oooo1@00000g0?oooa7o
oooo000@ooooob<0oooo0`0000110?ooo``00000@03oool700000?l0ooooNP3oool5000003L0oooo
4Oooool0013ooooo8`3oool300000440oooo300000110?ooo`L00000o`3ooomi0?ooo`D00000=`3o
oolAooooo`004?oooolS0?ooo`<00000@@3oool<000004<0oooo1P00003o0?ooogP0oooo1@00000g
0?oooa7ooooo000@ooooob<0oooo0`0000110?ooo``00000A03oool600000?l0ooooM`3oool50000
03L0oooo4Oooool0013ooooo8`3oool300000440oooo300000150?ooo`H00000o`3ooomf0?ooo`D0
0000=`3ooolAooooo`004?oooolS0?ooo`<00000@@3oool<000004H0oooo00<0P820000000000000
0`0000000`10@400oooo0?ooo`3o0?ooog80oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`00
00110?ooo``00000B03oool600000?l0ooooL`3oool5000003L0oooo4Oooool0013ooooo8`3oool3
00000440oooo3000001:0?ooo`D00000o`3ooomb0?ooo`D00000=`3ooolAooooo`004?oooolS0?oo
o`<00000@@3oool<000004/0oooo1@00003o0?ooog40oooo1@00000g0?oooa7ooooo000@ooooob<0
oooo0`0000110?ooo``00000C03oool500000?l0ooooL03oool5000003L0oooo4Oooool0013ooooo
8`3oool300000440oooo3000001<0?ooo`030820P0000000000000@00000o`3ooom^0?ooo`D00000
=`3ooolAooooo`004?oooolS0?ooo`<00000@@3oool<000004d0oooo1`00003o0?ooofd0oooo1@00
000g0?oooa7ooooo000@ooooob<0oooo0`0000110?ooo``00000CP3oool700000?l0ooooK03oool5
000003L0oooo4Oooool0013ooooo8`3oool300000440oooo3000001@0?ooo`H00000o`3ooom[0?oo
o`D00000=`3ooolAooooo`004?oooolS0?ooo`<00000@@3oool<00000540oooo1@00003o0?ooof/0
oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`0000110?ooo``00000DP3oool600000?l0oooo
J@3oool5000003L0oooo4Oooool0013ooooo8`3oool300000440oooo3000001C0?ooo`H00000o`3o
oomX0?ooo`D00000=`3ooolAooooo`004?ooool40?ooo`@000001`3oool300000140oooo0`000011
0?ooo``00000E03oool6000000030820P03oool0oooo0?l0ooooI03oool5000003L0oooo4Oooool0
013ooooo0`3oool7000000@0oooo1P00000?0?ooo`<00000@@3oool<000005H0oooo1@00003o0?oo
ofH0oooo1@00000g0?oooa7ooooo000@ooooo`030?ooo`20P800000000@000000`20P8000`000000
P8200820P004000000<0P82000<000000?ooo`3oool0303oool300000440oooo3000001G0?ooo`03
0820P00000000000008000000P20P83o0?ooof<0oooo1@00000g0?oooa7ooooo000@ooooo`030?oo
o`000000000000<000001P3oool500000180oooo0`0000110?ooo``00000F@3oool600000?l0oooo
HP3oool5000003L0oooo4Oooool0013ooooo00<0oooo0000000000000P0000080?ooo`@000004P3o
ool300000440oooo3000001J0?ooo`030820P0000000000000<00000o`3ooomQ0?ooo`D00000=`3o
oolAooooo`004?ooool00`3oool0000000000002000000P0oooo1000000B0?ooo`<00000@@3oool<
000005/0oooo1`00003o0?oooel0oooo1@00000g0?oooa7ooooo000@ooooo`030?ooo`0000000000
00800000203oool400000180oooo0`0000110?ooo``00000G03oool700000?l0ooooGP3oool50000
03L0oooo4Oooool0013ooooo0P3oool3000000P0oooo1000000B0?ooo`<00000@@3oool<000005h0
oooo1`00003o0?oooe`0oooo1@00000g0?oooa7ooooo000@ooooo`<0oooo0`0000070?ooo`@00000
4P3oool300000440oooo3000001O0?ooo`L00000o`3ooomK0?ooo`D00000=`3ooolAooooo`004?oo
ool40?ooo`<000001P3oool400000180oooo0`0000110?ooo``00000H03oool700000?l0ooooFP3o
ool5000003L0oooo4Oooool0013ooooo1@3oool2000000030820P03oool0oooo00<0oooo1000000B
0?ooo`<00000@@3oool<00000680oooo1P0000000`20P800oooo0?ooo`3o0?oooeH0oooo1@00000g
0?oooa7ooooo000@ooooo`L0oooo00<0P8200000003oool00`3oool400000180oooo0`0000110?oo
o``00000H`3oool600000?l0ooooF03oool5000003L0oooo4Oooool0013ooooo2@3oool300000003
0?ooo`0000000000008000004P3oool300000440oooo3000001T0?ooo`H00000o`3ooomG0?ooo`D0
0000=`3ooolAooooo`004?ooool<0?ooo`D000004P3oool300000440oooo3000001U0?ooo`L00000
o`3ooomE0?ooo`D00000=`3ooolAooooo`004?ooool=0?ooo`@000004P3oool300000440oooo3000
001W0?ooo`H00000o`3ooomD0?ooo`D00000=`3ooolAooooo`004?ooool30?ooo`800000203oool4
00000180oooo0`0000110?ooo``00000J03oool700000?l0ooooDP3oool5000003L0oooo4Oooool0
013ooooo0P3oool4000000L0oooo1000000B0?ooo`<00000@@3oool<000006P0oooo00<0P8200000
000000001@00003o0?oooe40oooo1@00000g0?oooa7ooooo000@ooooo`80oooo100000070?ooo`<0
000000<0P8200?ooo`3oool0403oool300000440oooo0`20P8001010@40000000000000000050820
P6X0oooo00<0P820000000000000100000020820P?l0ooooCP3oool5000003L0oooo4Oooool0013o
oooo0`3oool3000000H0oooo1000000C0?ooo`<00000A03oool01020P800000000000000001b0?oo
o`L00000o`3ooom=0?ooo`D00000=`3ooolAooooo`004?ooool40?ooo`<00000103oool4000001@0
oooo0`0000140?ooo`040820P00000000000000007<0oooo1`00001Q0?ooo`/00000g`3oool50000
03L0oooo4Oooool0013ooooo1`3oool6000001H0oooo0`0000140?ooo`040820P000000000000000
07@0oooo1`0000000`20P800oooo0?ooo`1O0?ooo`L00000h@3oool5000003L0oooo4Oooool0013o
oooo8`3oool3000004@0oooo00@0P8200000000000000000MP3oool600000680oooo00@0P8200000
000000000000h`3oool5000003L0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P8200000
000000000000M`3oool700000600oooo00@0P8200000000000000000h`3oool5000003L0oooo4Ooo
ool0013ooooo8`3oool3000004@0oooo00@0P8200000000000000000N@3oool6000005l0oooo00@0
P8200000000000000000h`3oool5000003L0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0
P8200000000000000000NP3oool6000005h0oooo00@0P8200000000000000000g`3oool00`20P800
00000000000:000003<0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P820000000000000
0000N`3oool7000005`0oooo00@0P8200000000000000000g`3oool00`20P80000000000000:0000
03<0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P8200000000000000000O03oool70000
05/0oooo00@0P8200000000000000000g`3oool00`20P80000000000000:000003<0oooo4Oooool0
013ooooo8`3oool3000004@0oooo00@0P8200000000000000000O@3oool8000005T0oooo00@0P820
0000000000000000g`3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo8`3oool3
000004@0oooo00@0P8200000000000000000O`3oool7000005P0oooo00@0P8200000000000000000
g`3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0
P8200000000000000000P03oool8000005H0oooo00@0P8200000000000000000g`3oool00`20P800
00000000000:000003<0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P820000000000000
0000PP3oool7000005D0oooo00@0P8200000000000000000g`3oool00`20P80000000000000:0000
03<0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P8200000000000000000P`3oool20820
P0D000000P20P81B0?ooo`040820P0000000000000000=l0oooo00<0P8200000000000002P00000c
0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P00000000000000008H0oooo1`00001A
0?ooo`040820P0000000000000000=l0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@
ooooob<0oooo0`0000140?ooo`040820P00000000000000008P0oooo1`00001?0?ooo`040820P000
0000000000000=l0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`00
00140?ooo`040820P00000000000000008T0oooo2000001=0?ooo`040820P0000000000000000=l0
oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820
P00000000000000008X0oooo2000001<0?ooo`040820P0000000000000000=l0oooo00<0P8200000
000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P000000000000000
08`0oooo2000001:0?ooo`040820P0000000000000000=l0oooo00<0P8200000000000002P00000c
0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P00000000000000008d0oooo20000019
0?ooo`040820P0000000000000000=l0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@
ooooob<0oooo0`0000140?ooo`040820P00000000000000008l0oooo200000170?ooo`040820P000
0000000000000=l0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`00
00140?ooo`040820P0000000000000000900oooo200000160?ooo`040820P0000000000000000=l0
oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820
P0000000000000000980oooo200000140?ooo`040820P0000000000000000=l0oooo00<0P8200000
000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P000000000000000
09<0oooo2@0000120?ooo`040820P0000000000000000=l0oooo00<0P8200000000000002P00000c
0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P00000000000000009D0oooo20000011
0?ooo`040820P0000000000000000=l0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@
ooooob<0oooo0`0000140?ooo`040820P00000000000000009L0oooo2000000o0?ooo`040820P000
0000000000000=l0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`00
00140?ooo`040820P00000000000000009P0oooo2@00000m0?ooo`040820P0000000000000000=l0
oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820
P00000000000000009X0oooo00<0P8200000000000001P0000020820P3T0oooo00@0P82000000000
00000000g`3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo8`3oool3000004@0
oooo00@0P8200000000000000000W@3oool9000000030820P03oool0oooo03D0oooo00@0P8200000
000000000000g`3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo8`3oool30000
04@0oooo00@0P8200000000000000000W`3oool8000003L0oooo00@0P8200000000000000000g`3o
ool00`20P80000000000000:000003<0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P820
0000000000000000X@3oool8000003@0oooo1`00003M0?ooo`030820P0000000000000X00000<`3o
oolAooooo`004?oooolS0?ooo`<00000A03oool01020P800000000000000002S0?ooo`P00000<03o
ool;00000=/0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`000014
0?ooo`040820P0000000000000000:D0oooo2000003o0?oooaD0oooo00<0P8200000000000002P00
000c0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P0000000000000000:H0oooo2@00
003o0?oooa<0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`000014
0?ooo`040820P0000000000000000:L0oooo2P00003o0?oooa40oooo00<0P8200000000000002P00
000c0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P0000000000000000:T0oooo2P00
003o0?ooo`l0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`000014
0?ooo`040820P0000000000000000:/0oooo2@0000000`20P800oooo0?ooo`3o0?ooo`/0oooo00<0
P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P0000000
000000000:h0oooo2000003o0?ooo``0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@
ooooob<0oooo0`0000140?ooo`040820P0000000000000000;00oooo2000003o0?ooo`X0oooo00<0
P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P0000000
000000000;80oooo2000003o0?ooo`P0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@
ooooob<0oooo0`0000140?ooo`040820P0000000000000000;@0oooo00<0P8200000000000001@00
003o0?ooo`H0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`000014
0?ooo`040820P0000000000000000;H0oooo0P20P80600000080P820o`3oool20?ooo`030820P000
0000000000X00000<`3ooolAooooo`004?oooolS0?ooo`<00000A03oool01020P800000000000000
002j0?ooo`P0000000<0P8200?ooo`3oool0o03oool00`20P80000000000000:000003<0oooo4Ooo
ool0013ooooo8`3oool3000004@0oooo00@0P8200000000000000000_@3oool700000?d0oooo00<0
P8200000000000002P00000D0?oooaT000001P3ooolAooooo`004?oooolS0?ooo`<00000A03oool0
1020P800000000000000002o0?ooo`P00000nP3oool00`20P80000000000000:000001H0oooo6000
00050?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P0000000000000000<40oooo2000
003h0?ooo`030820P0000000000000X00000603oool5000000`0oooo1@0000050?oooa7ooooo000@
ooooob<0oooo0`0000140?ooo`040820P0000000000000000<<0oooo2@00003e0?ooo`030820P000
0000000000X00000603oool4000000l0oooo00<0P8200000000000001@3ooolAooooo`004?oooolS
0?ooo`<00000A03oool01020P80000000000000000350?ooo`T00000l`3oool00`20P80000000000
000:000001P0oooo1000000@0?ooo`<00000103ooolAooooo`004?oooolS0?ooo`<00000A03oool0
1020P80000000000000000370?ooo`T0000000<0P8200?ooo`3oool0kP3oool00`20P80000000000
000:000001P0oooo1000000A0?ooo`800000103ooolAooooo`004?oooolS0?ooo`<00000A03oool0
1020P800000000000000003:0?ooo`P00000k`3oool00`20P80000000000000:000001P0oooo1000
000B0?ooo`030000003oool0oooo0080oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P820
0000000000000000c03oool900000>`0oooo00<0P8200000000000002P00000H0?ooo`@000004P3o
ool2000000<0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P8200000000000000000cP3o
ool:00000>T0oooo00<0P8200000000000002P00000H0?ooo`@000005`3ooolAooooo`004?oooolS
0?ooo`<00000A03oool01020P800000000000000003@0?ooo`/00000iP3oool00`20P80000000000
000:000001P0oooo1000000G0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P0000000
000000000=80oooo3000003S0?ooo`030820P0000000000000X00000603oool4000001L0oooo4Ooo
ool0013ooooo8`3oool3000004@0oooo00@0P8200000000000000000e03oool<00000>40oooo00<0
P8200000000000002P00000H0?ooo`@000005`3ooolAooooo`004?oooolS0?ooo`<00000A03oool0
1020P800000000000000003G0?ooo`<0P8202@0000030820P=/0oooo00<0P8200000000000002P00
000H0?ooo`@000005`3ooolAooooo`004?oooolS0?ooo`<00000A03oool01020P800000000000000
003M0?ooo``00000f03oool00`20P80000000000000:000001P0oooo1000000G0?oooa7ooooo000@
ooooob<0oooo0`0000140?ooo`040820P0000000000000000=l0oooo3@00003E0?ooo`030820P000
0000000000X00000603oool4000001L0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P820
0000000000000000hP3oool=00000=80oooo00<0P8200000000000002P00000H0?ooo`@000005`3o
oolAooooo`004?oooolS0?ooo`<00000A03oool01020P800000000000000003U0?ooo`h00000cP3o
ool00`20P80000000000000:000001P0oooo1000000G0?oooa7ooooo000@ooooob<0oooo0`000014
0?ooo`040820P0000000000000000>P0oooo3`00003:0?ooo`030820P0000000000000X00000603o
ool4000001L0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P8200000000000000000j`3o
ool@00000<H0oooo00<0P8200000000000002P00000H0?ooo`@000005`3ooolAooooo`004?oooolS
0?ooo`<00000A03oool01020P800000000000000003^0?oooa000000``3oool00`20P80000000000
000:000001P0oooo1000000G0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P0000000
000000000?80oooo4000002o0?ooo`030820P0000000000000X00000603oool4000001L0oooo4Ooo
ool0013ooooo8`3oool3000004@0oooo00@0P8200000000000000000mP3oool@00000;/0oooo00<0
P8200000000000002P00000H0?ooo`@000005`3ooolAooooo`004?oooolS0?ooo`<00000A03oool0
1020P800000000000000003j0?oooa000000]`3oool00`20P80000000000000:000001P0oooo1000
000G0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P0000000000000000?d0oooo4@00
002c0?ooo`030820P0000000000000X00000603oool4000001L0oooo4Oooool0013ooooo8`3oool3
000004@0oooo00@0P8200000000000000000o`3oool20?oooa400000L03oool3000003`0oooo00<0
P8200000000000002P00000H0?ooo`@000005`3ooolAooooo`004?oooolS0?ooo`<00000A03oool0
1020P800000000000000003o0?ooo`H0oooo4P00001Z0?ooo`H00000>P3oool00`20P80000000000
000:000001P0oooo1000000G0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P0000000
000000000?l0oooo2P3oool00`20P80000000000000>000006L0oooo2@00000g0?ooo`030820P000
0000000000X00000603oool4000001L0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P820
0000000000000000o`3oool>0?ooo`@0P820400000060820P5T0oooo00<0P8200000000000002P00
00020820P380oooo00<0P8200000000000002P00000H0?ooo`@000005`3ooolAooooo`004?oooolS
0?ooo`<00000A03oool01020P800000000000000003o0?oooaL0oooo5`00001C0?oooa800000;`3o
ool00`20P80000000000000:000001L0oooo1P00000F0?oooa7ooooo000@ooooob<0oooo0`000014
0?ooo`040820P0000000000000000?l0oooo6P3ooolJ000000030820P03oool0oooo04X0oooo5000
000]0?ooo`030820P0000000000000X000005P3oool7000000030820P03oool0oooo01<0oooo4Ooo
ool0013ooooo8`3oool3000004@0oooo00@0P8200000000000000000o`3ooolQ0?oooa`00000A03o
oolF000000030820P03oool0oooo02P0oooo00<0P8200000000000002P00000D0?ooo`/00000503o
oolAooooo`004?oooolS0?ooo`<00000A03oool01020P800000000000000003o0?ooobL0oooo7`00
000k0?oooaP00000:@3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo8`3oool3
000004@0oooo00@0P8200000000000000000o`3oool]0?ooob800000<@3ooolL000002H0oooo00<0
P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P0000000
000000000?l0oooo=03ooolT000002P0oooo8000000R0?ooo`030820P0000000000000X00000<`3o
oolAooooo`004?oooolS0?ooo`<00000A03oool01020P800000000000000003o0?ooocX0oooo9`00
000O0?ooob@000007P3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo8`3oool3
000004@0oooo00@0P8200000000000000000o`3ooom20?ooobT000005@3ooolU000000030820P03o
ool0oooo01X0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`000014
0?ooo`040820P0000000000000000?l0ooooB03ooomO000001/0oooo00<0P8200000000000002P00
000c0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P0000000000000000?l0ooooC`3o
oomJ000001T0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`000014
0?ooo`040820P0000000000000000?l0ooooG@3ooom@000001D0oooo00<0P8200000000000002P00
000c0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P0000000000000000?l0ooooJ`3o
oom4000001<0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`000014
0?ooo`040820P0000000000000000?l0ooooP03oool/000001H0oooo00<0P8200000000000002P00
000c0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P0000000000000000?l0ooooP03o
oolV000000<0P8206@3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo8`3oool3
000004@0oooo00@0P8200000000000000000o`3ooon00?ooob@000007P3oool00`20P80000000000
000:000003<0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P8200000000000000000o`3o
oon00?ooob4000008@3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo8`3oool3
000004@0oooo00@0P8200000000000000000o`3ooon00?oooah00000903oool00`20P80000000000
000:000003<0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P8200000000000000000o`3o
oon00?oooa/000009`3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo8`3oool3
000004@0oooo00@0P8200000000000000000o`3ooon10?oooaP00000:@3oool00`20P80000000000
000:000003<0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P8200000000000000000o`3o
oon10?oooaH00000:`3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo8`3oool3
000004@0oooo00@0P8200000000000000000o`3ooon10?oooa<00000;P3oool00`20P80000000000
000:000003<0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P8200000000000000000o`3o
oon10?oooa000000<@3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo8`3oool3
000004@0oooo00@0P8200000000000000000o`3ooon20?ooo``00000=03oool00`20P80000000000
000:000003<0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P8200000000000000000o`3o
oon20?ooo`T00000=`3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo7P3oool<
00000400oooo00@0P8200000000000000000o`3ooon30?ooo`H00000>@3oool00`20P80000000000
000:000003<0oooo4Oooool0013ooooo6`3ooolC000003`0oooo00@0P8200000000000000000o`3o
oon30?ooo`<00000?03oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo603ooolJ
000003P0oooo00@0P8200000000000000000o`3oooo20?ooo`030820P0000000000000X00000<`3o
oolAooooo`004?oooolE0?ooo`030820P0000000000001/00000=`3oool01020P800000000000000
003o0?oool80oooo00<0P8200000000000002P00000c0?oooa7ooooo000@oooooaH0oooo7000000h
0?ooo`040820P0000000000000000?l0oooo`P3oool00`20P80000000000000:000003<0oooo4Ooo
ool0013ooooo5P3ooolL000003P0oooo00@0P8200000000000000000o`3oooo20?ooo`030820P000
0000000000X00000<`3ooolAooooo`004?oooolF0?oooa`00000>03oool01020P800000000000000
003o0?oool80oooo00<0P8200000000000002P00000c0?oooa7ooooo000@oooooaH0oooo6`000000
0`20P800oooo0?ooo`0f0?ooo`040820P0000000000000000?l0oooo`P3oool00`20P80000000000
000:000003<0oooo4Oooool0013ooooo5`3ooolJ000000030820P03oool0oooo03H0oooo00@0P820
0000000000000000o`3oooo20?ooo`030820P0000000000000X00000<`3ooolAooooo`004?oooolG
0?oooaX0000000<0P8200?ooo`3oool0=P3oool01020P800000000000000003o0?oool80oooo00<0
P8200000000000002P00000c0?oooa7ooooo000@oooooaP0oooo6@00000i0?ooo`040820P0000000
000000000?l0oooo`P3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo603ooolI
000003T0oooo00@0P8200000000000000000o`3oooo20?ooo`030820P0000000000000X00000<`3o
oolAooooo`004?oooolI0?oooaP00000>@3oool01020P800000000000000003o0?oool80oooo00<0
P8200000000000002P00000c0?oooa7ooooo000@oooooaT0oooo5`00000j0?ooo`040820P0000000
000000000?l0oooo`P3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo6@3ooolG
000003X0oooo00@0P8200000000000000000o`3oooo20?ooo`030820P0000000000000X00000<`3o
oolAooooo`004?oooolJ0?oooaD00000>`3oool01020P800000000000000003o0?oool80oooo00<0
P8200000000000002P00000c0?oooa7ooooo000@oooooaX0oooo5@00000k0?ooo`040820P0000000
000000000?l0oooo`P3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo6P3ooolD
000000030820P03oool0oooo03T0oooo00@0P8200000000000000000o`3oooo20?ooo`030820P000
0000000000X00000<`3ooolAooooo`004?oooolK0?oooa<00000?03oool01020P800000000000000
003o0?oool80oooo00<0P8200000000000002P00000c0?oooa7ooooo000@oooooa/0oooo4`00000l
0?ooo`040820P0000000000000000?l0oooo`P3oool00`20P80000000000000:000003<0oooo4Ooo
ool0013ooooo6`3ooolB000003d0oooo00@0P8200000000000000000o`3oooo20?ooo`030820P000
0000000000X00000<`3ooolAooooo`004?oooolK0?oooa800000?@3oool01020P800000000000000
003o0?oool80oooo00<0P8200000000000002P00000c0?oooa7ooooo000@oooooa`0oooo4@00000m
0?ooo`040820P0000000000000000?l0oooo`P3oool00`20P80000000000000:000003<0oooo4Ooo
ool0013ooooo703oool@000003h0oooo00@0P8200000000000000000o`3oooo20?ooo`030820P000
0000000000X00000<`3ooolAooooo`004?oooolM0?ooo`l00000?P3oool01020P800000000000000
003o0?oool80oooo00<0P8200000000000002P00000c0?oooa7ooooo000@oooooad0oooo3`00000n
0?ooo`040820P0000000000000000?l0oooo`P3oool00`20P80000000000000:000003<0oooo4Ooo
ool0013ooooo7@3oool>000003l0oooo00@0P8200000000000000000o`3oooo20?ooo`030820P000
0000000000X00000<`3ooolAooooo`004?oooolN0?ooo`d00000?`3oool01020P800000000000000
003o0?oool80oooo00<0P8200000000000002P00000c0?oooa7ooooo000@oooooah0oooo3@00000o
0?ooo`040820P0000000000000000?l0oooo`P3oool00`20P80000000000000:000003<0oooo4Ooo
ool0013ooooo7P3oool<00000400oooo00@0P8200000000000000000o`3oooo20?ooo`030820P000
0000000000X00000<`3ooolAooooo`004?oooolO0?ooo`/00000@03oool01020P800000000000000
003o0?oool80oooo00<0P8200000000000002P00000c0?oooa7ooooo000@oooooal0oooo2`000010
0?ooo`040820P0000000000000000?l0oooo`P3oool00`20P80000000000000:000003<0oooo4Ooo
ool0013ooooo803oool900000440oooo00@0P8200000000000000000o`3oooo20?ooo`030820P000
0000000000X00000<`3ooolAooooo`004?oooolQ0?ooo`P00000@@3oool01020P800000000000000
003o0?oool80oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob40oooo1`000012
0?ooo`040820P0000000000000000?l0oooo`P3oool00`20P80000000000000:000003<0oooo4Ooo
ool0013ooooo8@3oool700000480oooo00@0P8200000000000000000o`3oooo20?ooo`030820P000
0000000000X00000<`3ooolAooooo`004?oooolR0?ooo`D00000@`3oool01020P800000000000000
003o0?oool80oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob80oooo1@000013
0?ooo`040820P0000000000000000?l0oooo`P3oool00`20P80000000000000:000003<0oooo4Ooo
ool0013ooooo8P3oool5000004<0oooo00@0P8200000000000000000o`3oooo20?ooo`030820P000
0000000000X00000<`3ooolAooooo`004?oooolS0?ooo`<00000A03oool01020P800000000000000
003o0?oool80oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`000014
0?ooo`040820P0000000000000000?l0oooo`P3oool00`20P80000000000000:000003<0oooo4Ooo
ool0013ooooo8`3oool3000004@0oooo00<0P820000000000000o`00003@000003<0oooo4Oooool0
013ooooo8`3oool00`20P80000000?ooo`140?ooo`030820P000000000000?l00000d000000c0?oo
oa7ooooo000@ooooob<0oooo00<0P8200000003oool0A03oool00`20P80000000000003o00000<`0
0000=`3ooolAooooo`004?oooolT0?ooo`030000003oool0oooo04<0oooo00<0P820000000000000
o`00003<000003L0oooo4Oooool0013oooooo`3ooooo0?ooog40oooo4Oooool0013oooooo`3ooooo
0?ooog40oooo4Oooool0013oooooo`3ooooo0?ooog40oooo4Oooool0013oooooo`3ooooo0?ooog40
oooo4Oooool0013oooooo`3ooooo0?ooog40oooo4Oooool0013oooooo`3ooooo0?ooog40oooo4Ooo
ool0013oooooo`3ooooo0?ooog40oooo4Oooool0013oooooo`3ooooo0?ooog40oooo4Oooool0013o
ooooo`3ooooo0?ooog40oooo4Oooool0013oooooo`3ooooo0?ooog40oooo4Oooool0013oooooo`3o
oooo0?ooog40oooo4Oooool0013oooooo`3ooooo0?ooog40oooo4Oooool0013oooooo`3ooooo0?oo
og40oooo4Oooool0013oooooo`3ooooo0?ooog40oooo4Oooool0013oooooo`3ooooo0?ooog40oooo
4Oooool0013oooooo`3ooomA0?ooo`P0P820o`3ooolH0?oooa7ooooo000@ooooool0ooooC`3oool<
00000?l0oooo5P3ooolAooooo`004?oooooo0?ooodd0oooo00<0P8200000000000000`0000060?oo
o`80000000<0P8200?ooo`3oool0o`3ooolC0?oooa7ooooo000@ooooool0ooooC@3oool01020P800
00000000000000090?ooo`<00000o`3ooolD0?oooa7ooooo000@ooooool0ooooC@3oool01020P800
000000000000000:0?ooo`800000o`3ooolD0?oooa7ooooo000@ooooool0ooooC@3oool01020P800
000000000000000:0?ooo`030820P000000000000?l0oooo4`3ooolAooooo`004?oooooo0?ooodd0
oooo00@0P82000000000000000002P3oool01020P800000000000000003o0?oooa80oooo4Oooool0
013oooooo`3ooom=0?ooo`040820P00000000000000000/0oooo0`00003o0?oooa80oooo4Oooool0
013oooooo`3ooom=0?ooo`040820P00000000000000000/0oooo0`00003o0?oooa80oooo4Oooool0
013oooooo`3ooom=0?ooo`040820P00000000000000000/0oooo1000003o0?oooa40oooo4Oooool0
013oooooo`3ooom=0?ooo`040820P00000000000000000/0oooo1000003o0?oooa40oooo4Oooool0
013oooooo`3ooom=0?ooo`040820P00000000000000000/0oooo1000003o0?oooa40oooo4Oooool0
013oooooo`3ooom=0?ooo`040820P00000000000000000/0oooo1000003o0?oooa40oooo4Oooool0
013oooooo`3ooom=0?ooo`040820P00000000000000000/0oooo1000003o0?oooa40oooo4Oooool0
013oooooo`3ooom=0?ooo`040820P00000000000000000X0oooo00<0P8200000000000000P00003o
0?oooa40oooo4Oooool0013oooooo`3ooom=0?ooo`040820P00000000000000000X0oooo00@0P820
0000000000000000o`3ooolB0?oooa7ooooo000@ooooool0ooooC@3oool01020P800000000000000
000:0?ooo`@00000o`3ooolB0?oooa7ooooo000@ooooool0ooooC@3oool00`20P800000000000002
000000P0oooo1@00003o0?oooa80oooo4Oooool0013oooooo`3ooom=0?ooo`030820P00000000000
00@000001@3oool500000?l0oooo4`3ooolAooooo`004?oooooo0?ooodd0oooo00D0P82000000000
000000000?ooo`0;00000?l0oooo503ooolAooooo`004?oooooo0?ooodd0oooo00@0P82000000000
000000000P3oool900000?l0oooo5@3ooolAooooo`004?oooooo0?ooodd0oooo00@0P82000000000
00000000103oool600000?l0oooo5P3ooolAooooo`004?oooooo0?ooodd0oooo00@0P82000000000
00000000o`3ooolP0?oooa7ooooo000@ooooool0ooooC@3oool01020P800000000000000003o0?oo
ob00oooo4Oooool0013oooooo`3ooom=0?ooo`040820P0000000000000000?l0oooo803ooolAoooo
o`004?oooooo0?ooodd0oooo00@0P8200000000000000000o`3ooolP0?oooa7ooooo000@ooooool0
ooooC@3oool01020P800000000000000003o0?ooob00oooo4Oooool0013oooooo`3ooom=0?ooo`04
0820P0000000000000000?l0oooo803ooolAooooo`004?oooooo0?ooodd0oooo00@0P82000000000
00000000o`3ooolP0?oooa7ooooo000@ooooool0ooooB`3oool600000?l0oooo803ooolAooooo`00
4?oooooo0?ooodd0oooo1000003o0?ooob00oooo4Oooool0013oooooo`3ooom?0?ooo`800000o`3o
oolP0?oooa7ooooo000@ooooool0ooooo`3oooma0?oooa7ooooo000@ooooool0ooooo`3oooma0?oo
oa7ooooo000@ooooool0ooooo`3oooma0?oooa7ooooo000@ooooool0ooooo`3oooma0?oooa7ooooo
003oooooooooooooT_ooool00?oooooooooooonBooooo`00oooooooooooooi;ooooo003ooooooooo
ooooT_ooool00?oooooooooooonBooooo`00oooooooooooooi;ooooo003oooooooooooooT_ooool0
0?oooooooooooonBooooo`00\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{192.25, 100.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 6.8 Exercise (12).", "Caption",
  CellTags->"Fig. 6.8"],

Cell[TextData[{
  StyleBox["(13)",
    FontWeight->"Bold"],
  " An enclosure in the shape of an isosceles triangle with base of length ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and with height ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " is filled with a uniform charge density ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Rho]/\[Epsilon]\_o\), "=", 
          RowBox[{"2", " ", 
            StyleBox["V",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ". The surface of the triangle is grounded. Find the best grid to fit this \
problem, taking ",
  Cell[BoxData[
      \(TraditionalForm\`M\_x = \(M\_y = \ 20\)\)]],
  ", and solve it using the direct method, for the case ",
  Cell[BoxData[
      \(TraditionalForm\`b = \(\@5\) meter\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a = 1.5\ meter\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["(14) ",
    FontWeight->"Bold"],
  "A room is heated with a corner radiator, held at temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\_o = 70\ \[Degree]C\)]],
  ". As seen in Fig. ",
  ButtonBox["6.9",
    ButtonData:>"Fig. 6.9",
    ButtonStyle->"Hyperlink"],
  ", the bottom and left wall  of the room are insulated, but the right and \
top walls are at constant temperature of 15\[Degree]C. Treating the air in \
the room as a thermally-conductive material, and for the dimensions of the \
room shown in the figure, find the temperature distribution ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, y)\)]],
  " in the room using the direct method. What is the total heat flux entering \
the room through the radiator in watss per square meter, assuming that, for \
air,  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Kappa]", "=", 
          RowBox[{"0.1", " ", 
            RowBox[{
              StyleBox["W",
                FontSlant->"Plain"], "/", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontSlant->"Plain"], "  ", "\[Degree]K"}], ")"}]}]}]}], 
        TraditionalForm]]],
  "? "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009U0001DB000`400?l00000o`00003ooooooooo
ooooofOooooo003oooooooooooooIoooool00?oooooooooooomWooooo`00ooooooooooooofOooooo
003oooooooooooooIoooool00?oooooooooooomWooooo`00ooooooooooooofOooooo003ooooooooo
ooooIoooool00?oooooooooooomWooooo`003_oooooo0?ooool0ooooB@3oool@ooooo`003_oooooo
0?ooool0ooooB@3oool@ooooo`003_oooooo0?ooool0ooooB@3oool@ooooo`003_oooooo0?ooool0
ooooB@3oool@ooooo`003_oooooo0?ooool0ooooB@3oool@ooooo`003_oooooo0?ooool0ooooB@3o
ool@ooooo`003_oooooo0?ooool0ooooB@3oool@ooooo`003_oooooo0?ooool0ooooB@3oool@oooo
o`003_oooooo0?ooool0ooooB@3oool@ooooo`003_oooooo0?oooa@0oooo1000000@0?ooo`L00000
0P3oool700000080oooo1`00003o0?ooo`P0oooo4?ooool000koooooo`3ooolA0?ooo`040820P000
0000P8200<30`0<0oooo00<0P82000000020P8003P3oool01@30`<000000000000000000`<3000@0
oooo00D0`<3000000000000000000820P0040?ooo`050<30`0000000000000000020P800o`3oool9
0?oooa3ooooo000>ooooool0oooo403oool2000000L0oooo0P0000000`20P800oooo0?ooo`0<0?oo
o`<000001P3oool3000000H0oooo0`00003o0?ooo`X0oooo4?ooool000koooooo`3oool?0?ooo`03
0410@0000000P82000P0oooo0P00000>0?ooo`<000001P3oool3000000H0oooo0`00003o0?ooo`X0
oooo4?ooool000koooooo`3oool?0?ooo`8000002P3oool2000000d0oooo0`0000060?ooo`<00000
1P3oool300000?l0oooo2P3oool@ooooo`003_oooooo0?ooo`h0oooo0`00000:0?ooo`80000000<0
`<300?ooo`3oool02P3oool3000000H0oooo0`0000060?ooo`<00000o`3oool:0?oooa3ooooo000>
ooooool0oooo3P3oool2000000/0oooo0P0000000`20P800oooo0?ooo`0:0?ooo`<000001P3oool3
000000H0oooo0`00003o0?ooo`X0oooo4?ooool000koooooo`3oool=0?ooo`030820P00000000000
00/0oooo0P0000000`20P800oooo0?ooo`0:0?ooo`<000001P3oool3000000H0oooo0`00003o0?oo
o`X0oooo4?ooool000koooooo`3oool=0?ooo`030820P0000000000000/0oooo0P0000000`20P800
oooo0?ooo`0:0?ooo`<000001P3oool3000000H0oooo0`00003o0?ooo`X0oooo4?ooool000kooooo
o`3oool=0?ooo`030820P0000000000000X0oooo0`0000000`20P800oooo0?ooo`0:0?ooo`<00000
1P3oool3000000H0oooo0`00003o0?ooo`X0oooo4?ooool000koooooo`3oool=0?ooo`030820P000
0000000000T0oooo00D0P82000000000000000000<30`00<0?ooo`<000001P3oool3000000H0oooo
0`00003o0?ooo`X0oooo4?ooool000koooooo`3oool=0?ooo`040820P00000000000000000P0oooo
1000000=0?ooo`<000001P3oool3000000H0oooo0`00003o0?ooo`X0oooo4?ooool000koooooo`3o
ool=0?ooo`050<30`0000000000000000010@4001@3oool01@20P800@410000000000000@41000h0
oooo0`0000000`30`<00oooo0?ooo`020?ooo`030<30`000000000000080P82000D0`<300?ooo`3o
ool0oooo0<30`00300000?l0oooo2P3oool@ooooo`003_oooooo0?ooo`h0oooo0`0000000`20P800
00000000000600000100oooo0`0000000`20P80000000?ooo`020?ooo`<000000P3oool010000000
oooo0?ooo`3oool3000000030820P03oool0oooo0?l0oooo203oool@ooooo`003_oooooo0?ooo`h0
oooo0`0000030?ooo`@0000000<0P8200?ooo`3oool03@3oool5000000030?ooo`000000000000D0
00000P3oool00`20P800000000000004000000030820P03oool0oooo0?l0oooo203oool@ooooo`00
3_oooooo0?ooo`l0oooo0P0000000`10@400oooo0?ooo`0E0?ooo`040<30`020P800@41000000080
oooo00<0P8200410@00000000P0000001P30`<00oooo0?ooo`3oool0P8200410@0<0000000<0P820
0?ooo`3oool0o`3oool90?oooa3ooooo000>ooooool0oooo3`3oool00`20P80000000000003o0?oo
ocL0oooo4?ooool000koooooo`3oool@0?ooo`040820P000000000000820P?l0oooo=@3oool@oooo
o`003_oooooo0?oooa40oooo00@0P820000000000000P820o`3ooold0?oooa3ooooo000>ooooool0
oooo4P3oool01020P800000000000020P83o0?oooc<0oooo4?ooool000koooooo`3ooolD0?ooo`80
000000<0P8200?ooo`3oool0o`3oool`0?oooa3ooooo000>ooooool0oooo5@3oool3000000030820
P03oool0oooo0?l0oooo;P3oool@ooooo`003_oooooo0?oooaL0oooo0P20P80200000080P820o`3o
ool/0?oooa3ooooo000>ooooool0ooooo`3ooom90?oooa3ooooo000>ooooool0ooooo`3ooom90?oo
oa3ooooo000>ooooool0ooooo`3ooom90?oooa3ooooo000>ooooool0ooooo`3ooom90?oooa3ooooo
000>ooooool0ooooo`3ooom90?oooa3ooooo000>ooooool0ooooo`3ooom90?oooa3ooooo000>oooo
ool0ooooo`3ooom90?oooa3ooooo000>ooooool0ooooo`3ooom90?oooa3ooooo000>ooooodT0oooo
o`00002d000004/0oooo4?ooool000koooooAP3ooooo00000;L00000B`3oool@ooooo`003_oooom6
0?ooo`P00000o`20P82/0820P0030410@0000000000004/0oooo4?ooool000koooooAP3oool80000
0?l0oooo[03oool00`20P80000000000001;0?oooa3ooooo000>ooooodH0oooo2000003o0?oooj`0
oooo00<0P820000000000000B`3oool@ooooo`003_oooom60?ooo`P00000o`3ooon/0?ooo`030820
P0000000000004/0oooo4?ooool000koooooAP3oool800000?l0oooo[03oool00`20P80000000000
001;0?oooa3ooooo000>ooooodH0oooo2000003o0?oooj`0oooo00<0P820000000000000B`3oool@
ooooo`003_oooom60?ooo`P00000o`3ooon/0?ooo`030820P0000000000004/0oooo4?ooool000ko
ooooAP3oool800000?l0oooo[03oool00`20P80000000000001;0?oooa3ooooo000>ooooodH0oooo
2000003o0?oooj`0oooo00<0P820000000000000B`3oool@ooooo`003_oooom60?ooo`P00000o`3o
oon/0?ooo`030820P0000000000004/0oooo4?ooool000koooooAP3oool800000?l0oooo[03oool0
0`20P80000000000001;0?oooa3ooooo000>ooooodH0oooo2000003o0?oooj`0oooo00<0P8200000
00000000B`3oool@ooooo`003_oooom60?ooo`P00000o`3ooon/0?ooo`030820P0000000000004/0
oooo4?ooool000koooooAP3oool800000?l0oooo[03oool00`20P80000000000001;0?oooa3ooooo
000>ooooodH0oooo2000003o0?oooj`0oooo00<0P820000000000000B`3oool@ooooo`003_oooom6
0?ooo`P00000o`3ooon/0?ooo`030820P0000000000004/0oooo4?ooool000kooooo1P3oool00`20
P80000000410@00=0?ooo`030<30`020P800@41000<0P82000<000000820P03oool0503oool20820
P0H000000P20P8090?ooo`P000005P3oool30820P0@000000`20P80<0?ooo`80P820100000001@20
P800oooo0?ooo`30`<00P82000@0000000D0P8200<30`03oool0`<300820P004000000030820P030
`<00oooo0?l0ooooI@3oool00`20P80000000000001;0?oooa3ooooo000>ooooo`L0oooo0P00000=
0?ooo`8000001@3oool00`20P80000000?ooo`0A0?ooo`030820P00000000000008000001@3oool0
0`20P8000000000000080?ooo`P000006@3oool00`20P80000000000000B0?ooo`030820P0000000
000000H0oooo00<0P8200000000000001P3oool01020P800000000000020P83o0?ooofP0oooo00<0
P820000000000000B`3oool@ooooo`003_ooool70?ooo`800000303oool2000000L0oooo00<00000
0820P03oool0403oool3000000030820P03oool0oooo00H0oooo0P0000070?ooo`P000006@3oool0
0`20P80000000000000B0?ooo`030820P0000000000000H0oooo00<0P8200000000000001P3oool0
1020P800000000000020P83o0?ooofP0oooo00<0P820000000000000B`3oool@ooooo`003_ooool8
0?ooo`8000002P3oool2000000030820P03oool0oooo00D0oooo00<0P8200000003oool03P3oool0
1@30`<000000000000000000P82000X0oooo00<0P82000000020P8001@3oool8000001T0oooo00<0
P8200000000000004P3oool00`20P8000000000000060?ooo`030820P0000000000000H0oooo00@0
P820000000000000P820o`3ooomX0?ooo`030820P0000000000004/0oooo4?ooool000kooooo203o
ool2000000030820P03oool0oooo00H0oooo00<0P8200000000000002@3oool2000000h0oooo0`00
000=0?ooo`030820P03oool0oooo00@0oooo2000000I0?ooo`030820P000000000000180oooo00<0
P8200000000000001P3oool00`20P8000000000000060?ooo`040820P000000000000820P?l0oooo
J03oool00`20P80000000000001;0?oooa3ooooo000>ooooo`P0oooo00<0P82000000020P800203o
ool00`10@4000000000000090?ooo`80000000<0`<300?ooo`3oool02P3oool3000000030820P03o
ool0oooo0180oooo2000000I0?ooo`030820P000000000000180oooo00<0P8200000000000001P3o
ool00`20P8000000000000060?ooo`040820P000000000000820P?l0ooooJ03oool00`20P8000000
0000001;0?oooa3ooooo000>ooooo`T0oooo0P0000080?ooo`8000002P3oool00`20P80000000820
P00;0?ooo`040820P00000000000000001D0oooo2000000I0?ooo`030820P000000000000180oooo
00<0P8200000000000001P3oool00`20P8000000000000060?ooo`040820P000000000000820P?l0
ooooJ03oool00`20P80000000000001;0?oooa3ooooo000>ooooo`T0oooo0P0000070?ooo`030820
P0000000000000X0oooo00<0P82000000020P8002`3oool01020P800000000000000000E0?ooo`P0
00006@3oool00`20P80000000000000B0?ooo`030820P0000000000000H0oooo00<0P82000000000
00001P3oool01020P800000000000020P83o0?ooofP0oooo00<0P820000000000000B`3oool@oooo
o`003_ooool:0?ooo`8000001P3oool3000000X0oooo00<0P8200000000000002`3oool3000001H0
oooo2000000I0?ooo`030820P000000000000180oooo00<0P8200000000000001P3oool00`20P800
0000000000060?ooo`040820P000000000000820P?l0ooooJ03oool00`20P80000000000001;0?oo
oa3ooooo000>ooooo`X0oooo0P0000000`30`<00oooo0?ooo`030?ooo`<000002P3oool00`20P800
00000000000;0?ooo`<000005P3oool8000001T0oooo00<0P8200000000000004P3oool00`20P800
0000000000060?ooo`030820P0000000000000H0oooo00@0P820000000000000P820o`3ooomX0?oo
o`030820P0000000000004/0oooo4?ooool000kooooo2P3oool00`20P80000000820P0050?ooo`<0
00002P3oool00`20P80000000000000;0?ooo`<000005P3oool8000001T0oooo00<0P82000000000
00004P3oool00`20P8000000000000060?ooo`030820P0000000000000H0oooo00@0P82000000000
0000P820o`3ooomX0?ooo`030820P0000000000004/0oooo4?ooool000kooooo2P3oool00`20P800
00000820P0050?ooo`<000002P3oool00`20P80000000000000;0?ooo`<000005P3oool8000001T0
oooo00<0P8200000000000004P3oool00`20P8000000000000060?ooo`030820P0000000000000H0
oooo00@0P820000000000000P820o`3ooomX0?ooo`030820P0000000000004/0oooo4?ooool000ko
oooo2P3oool00`30`<000000000000050?ooo`<000002P3oool00`20P80000000000000;0?ooo`<0
00005P3oool8000001T0oooo00<0P8200000000000004P3oool01020P800000000000020P8050?oo
o`030410@0000000@4100080P820103oool01010@400000000000020P83o0?ooofP0oooo00<0P820
000000000000B`3oool@ooooo`003_ooool;0?ooo`8000001@3oool3000000X0oooo00<0P8200000
000000002`3oool3000001H0oooo2000000I0?ooo`030820P000000000000180oooo00D0P8200000
00000000oooo000000030?ooo`<0000000@0P8200?ooo`000000P8200P3oool400000?l0ooooJ@3o
ool00`20P80000000000001;0?oooa3ooooo000>ooooo``0oooo0P0000040?ooo`<000002P3oool0
0`20P80000000000000;0?ooo`040410@000000000000820P1D0oooo2000000I0?ooo`030820P000
000000000100oooo0P20P803000000030?ooo`30`<00000000D0000000@0`<300?ooo`3oool0@410
1@0000000`20P800oooo0?ooo`3o0?ooofL0oooo00<0P820000000000000B`3oool@ooooo`003_oo
ool<0?ooo`8000001@3oool2000000X0oooo00<0P82000000020P8002`3oool01020P80000000000
0000000>0?ooo`030820P03oool0oooo00@0oooo2000000I0?ooo`030820P0000000000001@0oooo
00<000000?ooo`3oool00P3oool3000000H0oooo0`00003o0?ooof/0oooo00<0P820000000000000
B`3oool@ooooo`003_ooool<0?ooo`030820P0000000000000@0oooo0`0000090?ooo`80000000<0
P8200?ooo`3oool02@3oool01@30`<000000000000000000`<3000d0oooo00<0P8200?ooo`3oool0
103oool8000001T0oooo00<0P820000000000000o`3ooon@0?ooo`030820P0000000000004/0oooo
4?ooool000kooooo00<000000?ooo`3oool02@3oool01020P800000000000020P8030?ooo`030820
P0000000000000T0oooo0P00000=0?ooo`<0000000<0P8200?ooo`3oool02`3oool00`000000oooo
0?ooo`040?ooo`P000006@3oool00`20P80000000000003o0?oooi00oooo00<0P820000000000000
B`3oool@ooooo`003_ooool00`000000P8200?ooo`0:0?ooo`80000000D0P8200?ooo`3oool0oooo
0820P002000000T0oooo0P00000>0?ooo`<00000303oool2000000H0oooo2000000I0?ooo`030820
P000000000000?l0ooooT03oool00`20P80000000000001;0?oooa3ooooo000>ooooo`030?ooo`00
0000P82000X0oooo00<0P82000000010@400103oool2000000030820P03oool0oooo00D0oooo0P00
000?0?ooo`050<30`0000000000000000020P8002@3oool00`30`<000000000000060?ooo`P00000
5P3oool01020P800oooo0?ooo`20P80200000?l0ooooT03oool00`20P80000000000001;0?oooa3o
oooo000>ooooo`030?ooo`20P800000000d000001@3oool2000000H0oooo00<0P82000000020P800
4@3oool3000000030820P03oool0oooo00D0oooo100000060?ooo`P000005`3oool500000?l0oooo
T03oool00`20P80000000000001;0?oooa3ooooo000>ooooo`030?ooo`30`<00000000d0000000<0
P8200?ooo`3oool00`3oool00`10@40000000<30`0030?ooo`030820P0000000P8200180oooo00<0
`<300820P00000000P0000050820P080000000<0@4100820P00000001P3oool8000001P0oooo00@0
P8200410@00000000000o`3ooon@0?ooo`030820P0000000000004/0oooo4?ooool000kooooo0P3o
ool?000000L0oooo1@00000H0?ooo`H00000103oool00`20P800oooo0?ooo`040?ooo`P000006`3o
ool00`20P800oooo0?ooo`3o0?ooohh0oooo00<0P820000000000000B`3oool@ooooo`003_oooom6
0?ooo`P00000o`3ooon/0?ooo`030820P0000000000004/0oooo4?ooool000koooooAP3oool80000
0?l0oooo[03oool00`20P80000000000001;0?oooa3ooooo000>ooooodH0oooo2000003o0?oooj`0
oooo00<0P820000000000000B`3oool@ooooo`003_oooom60?ooo`P00000o`3ooon/0?ooo`030820
P0000000000004/0oooo4?ooool000koooooAP3oool800000?l0oooo[03oool00`20P80000000000
001;0?oooa3ooooo000>ooooodH0oooo2000003o0?oooj`0oooo00<0P820000000000000B`3oool@
ooooo`003_oooom60?ooo`P00000o`3ooon/0?ooo`030820P0000000000004/0oooo4?ooool000ko
ooooAP3oool800000?l0oooo[03oool00`20P80000000000001;0?oooa3ooooo000>ooooodH0oooo
2000003o0?oooj`0oooo00<0P820000000000000B`3oool@ooooo`003_oooom60?ooo`P00000o`3o
oon/0?ooo`030820P0000000000004/0oooo4?ooool000koooooAP3oool800000?l0oooo[03oool0
0`20P80000000000001;0?oooa3ooooo000>ooooodH0oooo2000003o0?oooj`0oooo00<0P8200000
00000000B`3oool@ooooo`003_oooom60?ooo`P00000o`3ooon/0?ooo`030820P0000000000004/0
oooo4?ooool000koooooAP3oool800000?l0oooo[03oool00`20P80000000000001;0?oooa3ooooo
000>ooooodH0oooo2000003o0?oooj`0oooo00<0P820000000000000B`3oool@ooooo`003_oooom6
0?ooo`P00000o`3ooon/0?ooo`030820P0000000000004/0oooo4?ooool000koooooAP3oool80000
0?l0oooo[03oool00`20P80000000000001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800
oooo0?ooo`3o0?oooj`0oooo00<0P820000000000000B`3oool@ooooo`003_oooom90?ooo`800000
00<0P8200?ooo`3oool0o`3ooon/0?ooo`030820P0000000000004/0oooo4?ooool000koooooB@3o
ool2000000030820P03oool0oooo0?l0oooo[03oool00`20P80000000000001;0?oooa3ooooo000>
ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?oooj`0oooo00<0P820000000000000503oool6
000001<0oooo1`0000020?ooo`L000000P3oool7000000D0oooo4?ooool000koooooB@3oool20000
00030820P03oool0oooo0?l0oooo[03oool00`20P80000000000000B0?ooo`050820P00000000000
00000010@4001020P8000`10@400P8200<30`00@0?ooo`050820P0000000000000000030`<00103o
ool01@30`<000000000000000000`<3000@0oooo00D0`<3000000000000000000820P0060?oooa3o
oooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?oooj`0oooo00<0P820000000000000
4P3oool00`20P8000000000000070?ooo`8000004@3oool3000000H0oooo0`0000060?ooo`<00000
1`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820P000
0000000001d0oooo00<0@41000000020P8003`3oool3000000H0oooo0`0000060?ooo`<000001`3o
ool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820P0000000
000001h0oooo0P0000000`20P800oooo0?ooo`0<0?ooo`<000001P3oool3000000H0oooo0`000007
0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?oooj`0oooo00<0P8200000
000000007P3oool2000000030820P03oool0oooo00`0oooo0`0000060?ooo`<000001P3oool30000
00L0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0?l0oooo[03oool00`20P800
00000000000N0?ooo`<000003P3oool3000000H0oooo0`0000060?ooo`<000001`3oool@ooooo`00
3_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820P0000000000001h0oooo
0`00000>0?ooo`<000001P3oool3000000H0oooo0`0000070?oooa3ooooo000>ooooodT0oooo0P00
00000`20P800oooo0?ooo`3o0?oooj`0oooo00<0P8200000000000007@3oool01020P80000000000
0000000>0?ooo`<000001P3oool3000000H0oooo0`0000070?oooa3ooooo000>ooooodT0oooo0P00
00000`20P800oooo0?ooo`3o0?oooj`0oooo00<0P8200000000000007@3oool3000000030820P03o
ool0oooo00`0oooo0`0000060?ooo`<000001P3oool3000000L0oooo4?ooool000koooooB@3oool2
000000030820P03oool0oooo0?l0oooo[03oool00`20P80000000000000J0?ooo`80P82010000000
0`30`<00oooo0?ooo`0<0?ooo`<000001P3oool3000000H0oooo0`0000070?oooa3ooooo000>oooo
odT0oooo0P0000000`20P800oooo0?ooo`3o0?oooj`0oooo00<0P8200000000000005P3oool90000
0100oooo0`0000060?ooo`<000001P3oool3000000L0oooo4?ooool000koooooB@3oool200000003
0820P03oool0oooo0?l0oooo[03oool00`20P80000000000000H0?ooo`060820P010@40000000000
0020P800`<304@3oool3000000030<30`03oool0oooo0080oooo00<0`<300000000000000P20P804
0?ooo`040<30`00000000000000000L0oooo4?ooool000koooooB@3oool2000000030820P03oool0
oooo0?l0oooo[03oool00`20P80000000000000K0?ooo`8000004P3oool3000000030820P0000000
oooo0080oooo0`0000000`3oool0P820000000030?ooo`<00000203oool@ooooo`003_oooom90?oo
o`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820P0000000000001/0oooo00<0P8200000
000000003`3oool5000000030?ooo`000000000000D000000P3oool7000000P0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0?l0oooo[03oool00`20P80000000000000L0?ooo`03
0820P0000000P82000l0oooo0P20P8001@10@40000000?ooo`3oool0P82000@0000000H0`<300?oo
o`3oool0oooo0820P010@403000000030<30`03oool0oooo00H0oooo4?ooool000koooooB@3oool2
000000030820P03oool0oooo0?l0oooo[03oool00`20P80000000000000M0?ooo`<00000:`3oool@
ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820P00000000000
0180oooo00<0`<300?ooo`3oool0203oool3000002/0oooo4?ooool000koooooB@3oool200000003
0820P03oool0oooo0?l0oooo[03oool00`20P80000000000000C0?ooo`030000003oool0oooo00L0
oooo0`00000[0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?oooj`0oooo
00<0P8200000000000004`3oool00`20P800@4100?ooo`050?ooo`050<30`0000000000000000020
P800:`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820
P0000000000001@0oooo0P0000001020P800oooo0?ooo`3oool5000002`0oooo4?ooool000kooooo
B@3oool2000000030820P03oool0oooo0?l0oooo[03oool00`20P80000000000000E0?ooo`T00000
;@3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820P000
0000000001H0oooo00<0P8200000000000000`0000000`20P800`<300?ooo`0/0?oooa3ooooo000>
ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?oooj`0oooo00<0P820000000000000B`3oool@
ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820P00000000000
04/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0?l0oooo[03oool00`20P800
00000000001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?oooj`0oooo
00<0P820000000000000B`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3o
oon/0?ooo`030820P0000000000004/0oooo4?ooool000koooooB@3oool2000000030820P03oool0
oooo0?l0oooo[03oool00`20P80000000000001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20
P800oooo0?ooo`3o0?oooj`0oooo00<0P820000000000000B`3oool@ooooo`003_oooom90?ooo`80
000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820P0000000000004/0oooo4?ooool000kooooo
B@3oool2000000030820P03oool0oooo0?l0oooo[03oool00`20P80000000000001;0?oooa3ooooo
000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?oooj`0oooo00<0P820000000000000B`3o
ool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820P0000000
000004/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0?l0oooo[03oool00`20
P80000000000001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?oooj`0
oooo00<0P820000000000000B`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0
o`3ooon/0?ooo`030820P0000000000004/0oooo4?ooool000koooooB@3oool2000000030820P03o
ool0oooo0?l0oooo[03oool00`20P80000000000001;0?oooa3ooooo000>ooooodT0oooo0P000000
0`20P800oooo0?ooo`3o0?oooj`0oooo00<0P820000000000000B`3oool@ooooo`003_oooom90?oo
o`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820P0000000000004/0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0?l0oooo[03oool00`20P80000000000001;0?oooa3o
oooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?oooj`0oooo00<0P820000000000000
B`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820P000
0000000004/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0?l0oooo[03oool0
0`20P80000000000001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?oo
oj`0oooo00<0P820000000000000B`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3o
ool0o`3ooon/0?ooo`030820P0000000000004/0oooo4?ooool000koooooB@3oool2000000030820
P03oool0oooo0?l0oooo[03oool00`20P80000000000001;0?oooa3ooooo000>ooooodT0oooo0P00
00000`20P800oooo0?ooo`3o0?oooj`0oooo00<0P820000000000000B`3oool@ooooo`003_oooom9
0?ooo`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820P0000000000004/0oooo4?ooool0
00koooooB@3oool2000000030820P03oool0oooo0?l0oooo[03oool00`20P80000000000001;0?oo
oa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?oooj`0oooo00<0P82000000000
0000B`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820
P0000000000004/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0?l0oooo[03o
ool00`20P80000000000001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o
0?oooc`0oooo1P00000C0?ooo`L000000P3oool700000080oooo1`00000n0?ooo`030820P0000000
000004/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0?l0oooo>P3oool00`20
P800000000000002000000@0P82000<0@4100820P030`<00403oool01@30`<000000000000000000
`<3000@0oooo00D0`<3000000000000000000820P0040?ooo`050<30`0000000000000000020P800
?`3oool00`20P80000000000001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?oo
o`3o0?ooocX0oooo00<0P8200000000000001`3oool200000140oooo0`0000060?ooo`<000001P3o
ool300000400oooo00<0P820000000000000B`3oool@ooooo`003_oooom90?ooo`80000000<0P820
0?ooo`3oool0o`3ooom50?ooo`030410@0000000P82000l0oooo0`0000060?ooo`<000001P3oool3
00000400oooo00<0P820000000000000B`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?oo
o`3oool0o`3ooom60?ooo`80000000<0P8200?ooo`3oool0303oool3000000H0oooo0`0000060?oo
o`<00000@03oool00`20P80000000000001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800
oooo0?ooo`3o0?ooodH0oooo0P0000000`20P800oooo0?ooo`0<0?ooo`<000001P3oool3000000H0
oooo0`0000100?ooo`030820P0000000000004/0oooo4?ooool000koooooB@3oool2000000030820
P03oool0oooo0?l0ooooAP3oool3000000h0oooo0`0000060?ooo`<000001P3oool300000400oooo
00<0P820000000000000B`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3o
oom60?ooo`<000003P3oool3000000H0oooo0`0000060?ooo`<00000@03oool00`20P80000000000
001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?ooodD0oooo00@0P820
00000000000000003P3oool3000000H0oooo0`0000060?ooo`<00000@03oool00`20P80000000000
001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?ooodD0oooo0`000000
0`20P800oooo0?ooo`0<0?ooo`<000001P3oool3000000H0oooo0`0000100?ooo`030820P0000000
000004/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0?l0oooo@P3oool20820
P0@0000000<0`<300?ooo`3oool0303oool3000000H0oooo0`0000060?ooo`<00000@03oool00`20
P80000000000001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?oooch0
oooo2@00000@0?ooo`<000001P3oool3000000H0oooo0`0000100?ooo`030820P0000000000004/0
oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0?l0oooo@03oool01P20P800@410
000000000000P8200<30`140oooo0`0000000`30`<00oooo0?ooo`020?ooo`030<30`00000000000
0080P82000D0`<300?ooo`3oool0oooo0<30`00300000400oooo00<0P820000000000000B`3oool@
ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3ooom30?ooo`8000004P3oool30000
00030820P0000000oooo0080oooo0`0000020?ooo`040000003oool0oooo0?ooo`<0000000<0P820
0?ooo`3oool0?P3oool00`20P80000000000001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20
P800oooo0?ooo`3o0?oood<0oooo00<0P8200000000000003`3oool5000000030?ooo`0000000000
00D000000P3oool00`20P800000000000004000000030820P03oool0oooo03h0oooo00<0P8200000
00000000B`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3ooom40?ooo`03
0820P0000000P82000l0oooo00@0`<300820P010@40000000P3oool00`20P800@410000000020000
00060<30`03oool0oooo0?ooo`20P800@4100`0000000`20P800oooo0?ooo`0o0?ooo`030820P000
0000000004/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0?l0ooooA@3oool3
000006@0oooo00<0P820000000000000B`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?oo
o`3oool0o`3ooolj0?ooo`030<30`03oool0oooo00P0oooo0`00001T0?ooo`030820P00000000000
04/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0?l0oooo>`3oool00`000000
oooo0?ooo`070?ooo`<00000I03oool00`20P80000000000001;0?oooa3ooooo000>ooooodT0oooo
0P0000000`20P800oooo0?ooo`3o0?oooc/0oooo00<0P8200410@03oool01@3oool01@30`<000000
000000000000P82006@0oooo00<0P820000000000000B`3oool@ooooo`003_oooom90?ooo`800000
00<0P8200?ooo`3oool0o`3oooll0?ooo`<000000`3oool5000006D0oooo00<0P820000000000000
B`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3ooolm0?ooo`T00000IP3o
ool00`20P80000000000001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o
0?oooch0oooo00<0P8200410@00000000`0000000`20P800`<300?ooo`1U0?ooo`030820P0000000
000004/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0?l0oooo[03oool00`20
P80000000000001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?oooj`0
oooo00<0P820000000000000B`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0
o`3ooon/0?ooo`030820P0000000000004/0oooo4?ooool000koooooB@3oool2000000030820P03o
ool0oooo0?l0oooo[03oool00`20P80000000000001;0?oooa3ooooo000>ooooodT0oooo0P000000
0`20P800oooo0?ooo`3o0?oooj`0oooo00<0P820000000000000B`3oool@ooooo`003_oooom90?oo
o`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820P0000000000004/0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0?l0oooo[03oool00`20P80000000000001;0?oooa3o
oooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooom@00000B`3oool@ooooo`003_oo
oom90?ooo`80000000<0P8200?ooo`3oool0fP3ooooD000004/0oooo4?ooool000koooooB@3oool2
000000030820P03oool0oooo0=X0ooooe000001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20
P800oooo0?ooo`3J0?ooo`80000000<0@4100820P020P800c`20P81;0?oooa3ooooo000>ooooodT0
oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3o
oooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0
o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0
P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J
0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20
P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0
oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3o
oooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0
o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0
P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J
0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20
P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0
oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3o
oooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0
o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0
P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J
0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20
P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0
oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3o
oooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0
o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0
P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J
0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20
P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0
oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3o
oooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0
o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0
P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J
0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20
P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0
oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3o
oooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0
o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0
P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J
0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20
P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0
oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3o
oooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0
o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0
P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J
0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20
P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0
oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3o
oooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0
o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0
P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J
0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20
P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0
oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3o
oooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0
o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0
P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J
0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20
P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0
oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3o
oooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0
o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0
P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J
0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20
P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0
oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3o
oooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0
o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0
P8200?ooo`3oool00P3oool00`30`<00P8200000000500000080P8204@3oool00`20P80000000000
0002000000060410@020P800oooo0?ooo`20P800@4100`0000001P10@400P8200?ooo`3oool0P820
0410@0@0000000<0P8200?ooo`3oool0hP3oool@ooooo`003_oooom90?ooo`80000000<0P8200?oo
o`3oool0fP3oool2000000030820P03oool0oooo0080oooo00D0P82000000000000000000820P004
0?ooo`030820P0000000P8200140oooo0`0000060?ooo`<000001P3oool300000>H0oooo4?ooool0
00koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`020?oo
o`030<30`020P800P82000L0oooo00<0P82000000020P800403oool3000000H0oooo0`0000060?oo
o`<00000iP3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0fP3oool200000003
0820P03oool0oooo00d0oooo00<0P8200000000000003`3oool3000000H0oooo0`0000060?ooo`<0
0000iP3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0fP3oool2000000030820
P03oool0oooo00h0oooo0P0000000`20P800oooo0?ooo`0<0?ooo`<000001P3oool3000000H0oooo
0`00003V0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0
P8200?ooo`3oool03P3oool2000000030410@03oool0oooo00`0oooo0`0000060?ooo`<000001P3o
ool300000>H0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P000000
0`20P800oooo0?ooo`0>0?ooo`<000003P3oool3000000H0oooo0`0000060?ooo`<00000iP3oool@
ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0fP3oool2000000030820P03oool0oooo
00d0oooo00@0`<3000000000000000003P3oool3000000H0oooo0`0000060?ooo`<00000iP3oool@
ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0fP3oool2000000030820P03oool0oooo
00d0oooo00@0P82000000000000000003P3oool3000000H0oooo0`0000060?ooo`<00000iP3oool@
ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0fP3oool2000000030820P03oool0oooo
00`0oooo00D0P82000000000000000000820P00>0?ooo`<000001P3oool3000000H0oooo0`00003V
0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?oo
o`3oool02P3oool6000000l0oooo0`0000060?ooo`<000001P3oool300000>H0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`060?ooo`T0
0000403oool3000000H0oooo0`0000060?ooo`<00000iP3oool@ooooo`003_oooom90?ooo`800000
00<0P8200?ooo`3oool0fP3oool2000000030820P03oool0oooo00P0oooo00H0P8200410@0000000
00000820P030`<0A0?ooo`<0000000<0`<300?ooo`3oool00P3oool00`30`<000000000000020820
P0@0oooo00@0`<300000000000000000iP3oool@ooooo`003_oooom90?ooo`80000000<0P8200?oo
o`3oool0fP3oool2000000030820P03oool0oooo00/0oooo0P00000B0?ooo`<0000000<0P8200000
003oool00P3oool3000000030?ooo`20P800000000<0oooo0`00003W0?oooa3ooooo000>ooooodT0
oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool02`3oool00`30`<00
00000000000?0?ooo`030820P000000000000080000000<0oooo0820P0000000100000001010@400
oooo0?ooo`20P805000000030410@03oool0oooo0>D0oooo4?ooool000koooooB@3oool200000003
0820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`0=0?ooo`8000004@3oool00`20P800
00000?ooo`020?ooo`@000001@3oool01020P800000000000000003X0?oooa3ooooo000>ooooodT0
oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool03@3oool300000?l0
oooo2`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0fP3oool2000000030820
P03oool0oooo0080oooo00<0P8200?ooo`3oool0203oool300000?l0oooo2`3oool@ooooo`003_oo
oom90?ooo`80000000<0P8200?ooo`3oool0fP3oool2000000030820P03oool0oooo00<0oooo00<0
00000<30`03oool01P3oool01020P800000000000000003o0?ooo`/0oooo4?ooool000koooooB@3o
ool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00@0P8200000000000000000o`3oool<0?oooa3ooooo000>ooooodT0oooo0P00
00000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0103oool2000000040820P03o
ool0oooo0?ooo`D00000o`3oool<0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?oo
o`3J0?ooo`80000000<0P8200?ooo`3oool01@3oool00`20P800000000000005000000030410@03o
ool0oooo0?l0oooo2`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0fP3oool2
000000030820P03oool0oooo00L0oooo1@00003o0?ooo`l0oooo4?ooool000koooooB@3oool20000
00030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0
oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo
0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P00
00000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0
oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool20000
00030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0
oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo
0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P00
00000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0
oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool20000
00030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0
oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo
0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P00
00000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0
oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool20000
00030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0
oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo
0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P00
00000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0
oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool20000
00030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0
oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo
0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P00
00000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0
oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool20000
00030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0
oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo
0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P00
00000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0
oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool20000
00030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0
oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo
0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P00
00000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0
oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool20000
00030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0
oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo
0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P00
00000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0
oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool20000
00030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0
oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo
0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P00
00000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0
oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool20000
00030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0
oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo
0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P00
00000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0
oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool20000
00030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0
oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo
0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P00
00000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3ooooQ000000030820P03oool0
oooo0?l0oooo6`3oool@ooooo`003_oooom90?ooon40000000<0P8200?ooo`3oool0o`3ooolK0?oo
oa3ooooo000>ooooodT0ooooh@0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool00?oooooo
oooooomWooooo`00ooooooooooooofOooooo003oooooooooooooIoooool00?oooooooooooomWoooo
o`00ooooooooooooofOooooo003oooooooooooooIoooool00?oooooooooooomWooooo`00oooooooo
ooooofOooooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{204.375, 112.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 6.9 Exercise (14).", "Caption",
  CellTags->"Fig. 6.9"],

Cell[TextData[{
  StyleBox["(15)",
    FontWeight->"Bold"],
  " A  grounded square box, with an interior defined by  ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`0 < y < 1\)]],
  ", is cut into two sections by a conducting plate at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 1/2\)]],
  ". The plate is held at potential ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(V\_o\), "=", 
          RowBox[{"1", " ", 
            StyleBox["V",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ". The plate has a gap at the center, leaving an opening at ",
  Cell[BoxData[
      \(TraditionalForm\`1/4\  < \ y < \ 3/4\)]],
  ". Find the potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y)\)]],
  " in the box using a 20 by 20 grid. Solve this problem using simultaneous \
overrelaxation and add conditions to the recursion equation for the interior \
points that avoids the points that fall on the central plate.  The solution \
for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Phi](x, y)\)\(\ \)\)\)]],
  " is shown in Fig. ",
  ButtonBox["6.10",
    ButtonData:>"Fig. 6.10",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01569 .31789 -24 -2.78694 ]
[.01569 .31789 0 6.21306 ]
[.00698 .37252 -18 -2.83329 ]
[.00698 .37252 0 6.16671 ]
[-0.00205 .42908 -24 -2.88145 ]
[-0.00205 .42908 0 6.11855 ]
[-0.0114 .48769 -6 -2.93153 ]
[-0.0114 .48769 0 6.06847 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02796 .31322 m
.03409 .31089 L
s
[(0.25)] .01569 .31789 1 -0.38068 Mshowa
.01928 .36796 m
.02543 .36568 L
s
[(0.5)] .00698 .37252 1 -0.37038 Mshowa
.0103 .42464 m
.01647 .42242 L
s
[(0.75)] -0.00205 .42908 1 -0.35968 Mshowa
.00099 .48337 m
.00719 .48121 L
s
[(1)] -0.0114 .48769 1 -0.34855 Mshowa
.125 Mabswid
.03468 .27077 m
.03835 .26934 L
s
.03302 .28127 m
.03669 .27985 L
s
.03134 .29185 m
.03502 .29044 L
s
.02965 .3025 m
.03333 .30109 L
s
.02624 .32402 m
.02993 .32263 L
s
.02452 .33489 m
.02821 .3335 L
s
.02279 .34584 m
.02647 .34446 L
s
.02104 .35686 m
.02473 .35548 L
s
.01751 .37914 m
.0212 .37778 L
s
.01573 .39039 m
.01942 .38904 L
s
.01393 .40173 m
.01763 .40038 L
s
.01212 .41314 m
.01582 .4118 L
s
.00846 .43622 m
.01217 .43489 L
s
.00662 .44788 m
.01033 .44656 L
s
.00475 .45962 m
.00847 .45831 L
s
.00288 .47145 m
.00659 .47015 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.649 .738 .914 r
.39889 .59791 .40512 .60371 .41558 .60058 .40936 .59516 Mtetra
.647 .751 .925 r
.40936 .59516 .41558 .60058 .42607 .59743 .41987 .59239 Mtetra
.645 .765 .936 r
.41987 .59239 .42607 .59743 .4366 .59427 .43042 .58962 Mtetra
.64 .78 .948 r
.43042 .58962 .4366 .59427 .44718 .59109 .44102 .58686 Mtetra
.634 .795 .96 r
.44102 .58686 .44718 .59109 .4578 .58791 .45166 .58411 Mtetra
.626 .812 .971 r
.45166 .58411 .4578 .58791 .46846 .58471 .46234 .58137 Mtetra
.613 .828 .983 r
.46234 .58137 .46846 .58471 .47916 .5815 .47307 .57866 Mtetra
.595 .845 .992 r
.47307 .57866 .47916 .5815 .4899 .57828 .48384 .57598 Mtetra
.567 .86 .997 r
.48384 .57598 .4899 .57828 .50069 .57504 .49466 .57334 Mtetra
.524 .868 .991 r
.49466 .57334 .50069 .57504 .51152 .57179 .50553 .57077 Mtetra
.459 .862 .965 r
.50553 .57077 .51152 .57179 .52239 .56853 .51644 .56828 Mtetra
.36 .827 .902 r
.51644 .56828 .52239 .56853 .5333 .56526 .5274 .5659 Mtetra
.223 .744 .782 r
.5274 .5659 .5333 .56526 .54426 .56197 .53842 .56364 Mtetra
0 0 0 r
.53842 .56364 .54426 .56197 .55526 .55867 .54948 .56158 Mtetra
.127 0 0 r
.54948 .56158 .55526 .55867 .56631 .55536 .5606 .55976 Mtetra
.276 0 0 r
.5606 .55976 .56631 .55536 .5774 .55203 .57178 .55826 Mtetra
.394 0 .034 r
.57178 .55826 .5774 .55203 .58853 .54869 .58303 .55733 Mtetra
.467 .054 .173 r
.58303 .55733 .58853 .54869 .59971 .54534 .59435 .55688 Mtetra
.53 .157 .279 r
.59435 .55688 .59971 .54534 .61094 .54197 .60576 .55767 Mtetra
.567 .231 .358 r
.60576 .55767 .61094 .54197 .62221 .53859 .61729 .55978 Mtetra
.598 .289 .416 r
.61729 .55978 .62221 .53859 .63352 .53519 .62897 .56416 Mtetra
.636 .346 .461 r
.62897 .56416 .63352 .53519 .64488 .53178 .64093 .57386 Mtetra
.704 .426 .501 r
.64093 .57386 .64488 .53178 .65629 .52836 .65377 .60321 Mtetra
.65 .399 .525 r
.65377 .60321 .65629 .52836 .66774 .52493 .66676 .62952 Mtetra
.559 .333 .529 r
.66676 .62952 .66774 .52493 .67924 .52148 .67869 .62616 Mtetra
.463 .257 .514 r
.67869 .62616 .67924 .52148 .69079 .51801 .68923 .59304 Mtetra
.39 .191 .485 r
.68923 .59304 .69079 .51801 .70238 .51453 .69945 .55673 Mtetra
.424 .19 .452 r
.69945 .55673 .70238 .51453 .71403 .51104 .71057 .54008 Mtetra
.42 .159 .41 r
.71057 .54008 .71403 .51104 .72572 .50753 .72197 .52874 Mtetra
.397 .11 .355 r
.72197 .52874 .72572 .50753 .73745 .50401 .73349 .51967 Mtetra
.358 .039 .281 r
.73349 .51967 .73745 .50401 .74924 .50048 .74512 .51192 Mtetra
.311 0 .182 r
.74512 .51192 .74924 .50048 .76108 .49693 .75685 .50541 Mtetra
.231 0 .053 r
.75685 .50541 .76108 .49693 .77296 .49336 .76864 .49937 Mtetra
.127 0 0 r
.76864 .49937 .77296 .49336 .78489 .48978 .78051 .4939 Mtetra
0 0 0 r
.78051 .4939 .78489 .48978 .79688 .48619 .79245 .48874 Mtetra
.79245 .48874 .79688 .48619 .80891 .48258 .80444 .48383 Mtetra
.323 .801 .731 r
.80444 .48383 .80891 .48258 .82099 .47895 .8165 .47911 Mtetra
.447 .882 .862 r
.8165 .47911 .82099 .47895 .83313 .47531 .82861 .47451 Mtetra
.533 .914 .938 r
.82861 .47451 .83313 .47531 .84531 .47166 .84078 .47003 Mtetra
.588 .916 .973 r
.84078 .47003 .84531 .47166 .85755 .46799 .853 .46562 Mtetra
.622 .903 .985 r
.853 .46562 .85755 .46799 .86983 .4643 .86528 .46126 Mtetra
.643 .884 .985 r
.86528 .46126 .86983 .4643 .88217 .4606 .87761 .45695 Mtetra
.656 .864 .978 r
.87761 .45695 .88217 .4606 .89457 .45688 .88999 .45267 Mtetra
.664 .843 .969 r
.88999 .45267 .89457 .45688 .90701 .45315 .90242 .44841 Mtetra
.669 .824 .958 r
.90242 .44841 .90701 .45315 .91951 .4494 .91491 .44416 Mtetra
.672 .806 .947 r
.91491 .44416 .91951 .4494 .93206 .44563 .92745 .43992 Mtetra
.674 .79 .936 r
.92745 .43992 .93206 .44563 .94466 .44185 .94005 .43567 Mtetra
.675 .774 .925 r
.94005 .43567 .94466 .44185 .95732 .43805 .95269 .43142 Mtetra
.676 .76 .914 r
.95269 .43142 .95732 .43805 .97003 .43424 .96539 .42716 Mtetra
.634 .733 .92 r
.39262 .59207 .39889 .59791 .40936 .59516 .4031 .58969 Mtetra
.631 .746 .931 r
.4031 .58969 .40936 .59516 .41987 .59239 .41362 .5873 Mtetra
.627 .76 .942 r
.41362 .5873 .41987 .59239 .43042 .58962 .42419 .58492 Mtetra
.62 .774 .954 r
.42419 .58492 .43042 .58962 .44102 .58686 .4348 .58256 Mtetra
.612 .788 .966 r
.4348 .58256 .44102 .58686 .45166 .58411 .44546 .58023 Mtetra
.6 .803 .978 r
.44546 .58023 .45166 .58411 .46234 .58137 .45617 .57795 Mtetra
.583 .818 .988 r
.45617 .57795 .46234 .58137 .47307 .57866 .46692 .57572 Mtetra
.558 .831 .997 r
.46692 .57572 .47307 .57866 .48384 .57598 .47772 .57358 Mtetra
.522 .841 .999 r
.47772 .57358 .48384 .57598 .49466 .57334 .48857 .57153 Mtetra
.467 .841 .989 r
.48857 .57153 .49466 .57334 .50553 .57077 .49948 .56962 Mtetra
.388 .824 .955 r
.49948 .56962 .50553 .57077 .51644 .56828 .51043 .56785 Mtetra
.27 .771 .879 r
.51043 .56785 .51644 .56828 .5274 .5659 .52144 .56632 Mtetra
.12 .671 .746 r
.52144 .56632 .5274 .5659 .53842 .56364 .5325 .56503 Mtetra
.059 0 0 r
.5325 .56503 .53842 .56364 .54948 .56158 .54362 .56411 Mtetra
.228 0 0 r
.54362 .56411 .54948 .56158 .5606 .55976 .55481 .56365 Mtetra
.363 0 0 r
.55481 .56365 .5606 .55976 .57178 .55826 .56607 .56376 Mtetra
.471 0 .046 r
.56607 .56376 .57178 .55826 .58303 .55733 .57742 .56484 Mtetra
.532 .103 .171 r
.57742 .56484 .58303 .55733 .59435 .55688 .58885 .5668 Mtetra
.593 .203 .273 r
.58885 .5668 .59435 .55688 .60576 .55767 .60042 .57072 Mtetra
.628 .271 .345 r
.60042 .57072 .60576 .55767 .61729 .55978 .61213 .57681 Mtetra
.66 .328 .4 r
.61213 .57681 .61729 .55978 .62897 .56416 .62406 .58639 Mtetra
.702 .389 .444 r
.62406 .58639 .62897 .56416 .64093 .57386 .63637 .60352 Mtetra
.785 .486 .482 r
.63637 .60352 .64093 .57386 .65377 .60321 .64989 .64867 Mtetra
.731 .451 .504 r
.64989 .64867 .65377 .60321 .66676 .62952 .66361 .6893 Mtetra
.547 .304 .498 r
.66361 .6893 .66676 .62952 .67869 .62616 .67581 .68599 Mtetra
.216 .043 .418 r
.67581 .68599 .67869 .62616 .68923 .59304 .686 .6386 Mtetra
0 0 .312 r
.686 .6386 .68923 .59304 .69945 .55673 .6957 .58645 Mtetra
.205 0 .343 r
.6957 .58645 .69945 .55673 .71057 .54008 .70661 .56234 Mtetra
.242 0 .308 r
.70661 .56234 .71057 .54008 .72197 .52874 .71785 .54576 Mtetra
.225 0 .246 r
.71785 .54576 .72197 .52874 .73349 .51967 .72927 .53266 Mtetra
.181 0 .16 r
.72927 .53266 .73349 .51967 .74512 .51192 .7408 .52172 Mtetra
.136 0 .053 r
.7408 .52172 .74512 .51192 .75685 .50541 .75246 .51274 Mtetra
.038 0 0 r
.75246 .51274 .75685 .50541 .76864 .49937 .7642 .50462 Mtetra
0 0 0 r
.7642 .50462 .76864 .49937 .78051 .4939 .77603 .49748 Mtetra
.77603 .49748 .78051 .4939 .79245 .48874 .78793 .49091 Mtetra
.34 .792 .65 r
.78793 .49091 .79245 .48874 .80444 .48383 .7999 .48479 Mtetra
.457 .883 .797 r
.7999 .48479 .80444 .48383 .8165 .47911 .81193 .47904 Mtetra
.546 .928 .893 r
.81193 .47904 .8165 .47911 .82861 .47451 .82403 .47353 Mtetra
.603 .938 .947 r
.82403 .47353 .82861 .47451 .84078 .47003 .83618 .46825 Mtetra
.639 .93 .971 r
.83618 .46825 .84078 .47003 .853 .46562 .84839 .46312 Mtetra
.66 .912 .979 r
.84839 .46312 .853 .46562 .86528 .46126 .86066 .45811 Mtetra
.673 .89 .977 r
.86066 .45811 .86528 .46126 .87761 .45695 .87298 .4532 Mtetra
.68 .869 .97 r
.87298 .4532 .87761 .45695 .88999 .45267 .88536 .44837 Mtetra
.685 .848 .961 r
.88536 .44837 .88999 .45267 .90242 .44841 .89779 .44359 Mtetra
.687 .829 .951 r
.89779 .44359 .90242 .44841 .91491 .44416 .91027 .43884 Mtetra
.688 .811 .941 r
.91027 .43884 .91491 .44416 .92745 .43992 .92281 .43413 Mtetra
.688 .794 .93 r
.92281 .43413 .92745 .43992 .94005 .43567 .93539 .42943 Mtetra
.688 .779 .92 r
.93539 .42943 .94005 .43567 .95269 .43142 .94803 .42473 Mtetra
.688 .765 .91 r
.94803 .42473 .95269 .43142 .96539 .42716 .96071 .42002 Mtetra
.617 .729 .926 r
.3863 .58619 .39262 .59207 .4031 .58969 .39679 .58417 Mtetra
.614 .741 .937 r
.39679 .58417 .4031 .58969 .41362 .5873 .40732 .58215 Mtetra
.608 .754 .948 r
.40732 .58215 .41362 .5873 .42419 .58492 .4179 .58015 Mtetra
.6 .767 .959 r
.4179 .58015 .42419 .58492 .4348 .58256 .42853 .57818 Mtetra
.589 .78 .971 r
.42853 .57818 .4348 .58256 .44546 .58023 .43921 .57627 Mtetra
.573 .793 .982 r
.43921 .57627 .44546 .58023 .45617 .57795 .44994 .57442 Mtetra
.552 .805 .992 r
.44994 .57442 .45617 .57795 .46692 .57572 .46072 .57267 Mtetra
.521 .815 .999 r
.46072 .57267 .46692 .57572 .47772 .57358 .47155 .57103 Mtetra
.477 .819 .999 r
.47155 .57103 .47772 .57358 .48857 .57153 .48243 .56955 Mtetra
.413 .811 .984 r
.48243 .56955 .48857 .57153 .49948 .56962 .49336 .56826 Mtetra
.323 .783 .944 r
.49336 .56826 .49948 .56962 .51043 .56785 .50435 .56719 Mtetra
.193 .717 .859 r
.50435 .56719 .51043 .56785 .52144 .56632 .5154 .56645 Mtetra
.037 .607 .721 r
.5154 .56645 .52144 .56632 .5325 .56503 .52651 .56605 Mtetra
.14 0 0 r
.52651 .56605 .5325 .56503 .54362 .56411 .53769 .56616 Mtetra
.3 0 0 r
.53769 .56616 .54362 .56411 .55481 .56365 .54894 .5669 Mtetra
.424 0 0 r
.54894 .5669 .55481 .56365 .56607 .56376 .56027 .5684 Mtetra
.523 .035 .038 r
.56027 .5684 .56607 .56376 .57742 .56484 .57169 .57112 Mtetra
.581 .134 .154 r
.57169 .57112 .57742 .56484 .58885 .5668 .58323 .57502 Mtetra
.637 .228 .252 r
.58323 .57502 .58885 .5668 .60042 .57072 .59491 .58117 Mtetra
.672 .293 .32 r
.59491 .58117 .60042 .57072 .61213 .57681 .60676 .58992 Mtetra
.704 .349 .372 r
.60676 .58992 .61213 .57681 .62406 .58639 .61885 .60252 Mtetra
.745 .409 .415 r
.61885 .60252 .62406 .58639 .63637 .60352 .63133 .62249 Mtetra
.831 .513 .452 r
.63133 .62249 .63637 .60352 .64989 .64867 .64496 .66983 Mtetra
.809 .492 .453 r
.64496 .66983 .64989 .64867 .66361 .6893 .6588 .71185 Mtetra
.495 .191 .38 r
.6588 .71185 .66361 .6893 .67581 .68599 .67113 .70855 Mtetra
0 0 0 r
.67113 .70855 .67581 .68599 .686 .6386 .68148 .65977 Mtetra
.797 .739 .215 r
.68148 .65977 .686 .6386 .6957 .58645 .69128 .60543 Mtetra
0 0 .083 r
.69128 .60543 .6957 .58645 .70661 .56234 .7022 .57846 Mtetra
0 0 .111 r
.7022 .57846 .70661 .56234 .71785 .54576 .71341 .55881 Mtetra
0 0 .059 r
.71341 .55881 .71785 .54576 .72927 .53266 .72478 .54301 Mtetra
0 0 0 r
.72478 .54301 .72927 .53266 .7408 .52172 .73628 .52978 Mtetra
.73628 .52978 .7408 .52172 .75246 .51274 .74791 .51881 Mtetra
.74791 .51881 .75246 .51274 .7642 .50462 .75962 .509 Mtetra
.75962 .509 .7642 .50462 .77603 .49748 .77143 .50041 Mtetra
.402 .81 .604 r
.77143 .50041 .77603 .49748 .78793 .49091 .78331 .49258 Mtetra
.501 .895 .745 r
.78331 .49258 .78793 .49091 .7999 .48479 .79526 .48537 Mtetra
.575 .942 .849 r
.79526 .48537 .7999 .48479 .81193 .47904 .80729 .47866 Mtetra
.63 .958 .914 r
.80729 .47866 .81193 .47904 .82403 .47353 .81937 .4723 Mtetra
.662 .953 .95 r
.81937 .4723 .82403 .47353 .83618 .46825 .83152 .46626 Mtetra
.683 .937 .966 r
.83152 .46626 .83618 .46825 .84839 .46312 .84372 .46044 Mtetra
.694 .915 .97 r
.84372 .46044 .84839 .46312 .86066 .45811 .85599 .45481 Mtetra
.699 .893 .968 r
.85599 .45481 .86066 .45811 .87298 .4532 .86831 .44932 Mtetra
.702 .871 .961 r
.86831 .44932 .87298 .4532 .88536 .44837 .88068 .44395 Mtetra
.703 .851 .953 r
.88068 .44395 .88536 .44837 .89779 .44359 .89311 .43866 Mtetra
.703 .832 .944 r
.89311 .43866 .89779 .44359 .91027 .43884 .90559 .43344 Mtetra
.703 .814 .934 r
.90559 .43344 .91027 .43884 .92281 .43413 .91812 .42826 Mtetra
.702 .798 .925 r
.91812 .42826 .92281 .43413 .93539 .42943 .9307 .42311 Mtetra
.701 .783 .915 r
.9307 .42311 .93539 .42943 .94803 .42473 .94332 .41797 Mtetra
.7 .769 .905 r
.94332 .41797 .94803 .42473 .96071 .42002 .956 .41282 Mtetra
.601 .724 .931 r
.37994 .58026 .3863 .58619 .39679 .58417 .39043 .5786 Mtetra
.596 .735 .942 r
.39043 .5786 .39679 .58417 .40732 .58215 .40098 .57693 Mtetra
.589 .747 .952 r
.40098 .57693 .40732 .58215 .4179 .58015 .41157 .5753 Mtetra
.579 .759 .964 r
.41157 .5753 .4179 .58015 .42853 .57818 .42222 .57371 Mtetra
.565 .77 .975 r
.42222 .57371 .42853 .57818 .43921 .57627 .43292 .57219 Mtetra
.547 .781 .985 r
.43292 .57219 .43921 .57627 .44994 .57442 .44366 .57076 Mtetra
.521 .79 .994 r
.44366 .57076 .44994 .57442 .46072 .57267 .45446 .56946 Mtetra
.486 .796 .999 r
.45446 .56946 .46072 .57267 .47155 .57103 .46532 .56831 Mtetra
.436 .795 .996 r
.46532 .56831 .47155 .57103 .48243 .56955 .47623 .56735 Mtetra
.365 .781 .979 r
.47623 .56735 .48243 .56955 .49336 .56826 .48719 .56664 Mtetra
.268 .745 .935 r
.48719 .56664 .49336 .56826 .50435 .56719 .49821 .56622 Mtetra
.134 .672 .848 r
.49821 .56622 .50435 .56719 .5154 .56645 .5093 .56619 Mtetra
0 .559 .712 r
.5093 .56619 .5154 .56645 .52651 .56605 .52045 .5666 Mtetra
.194 0 0 r
.52045 .5666 .52651 .56605 .53769 .56616 .53168 .56762 Mtetra
.346 0 0 r
.53168 .56762 .53769 .56616 .54894 .5669 .54298 .56939 Mtetra
.464 0 0 r
.54298 .56939 .54894 .5669 .56027 .5684 .55437 .57206 Mtetra
.558 .052 .01 r
.55437 .57206 .56027 .5684 .57169 .57112 .56587 .57605 Mtetra
.615 .148 .122 r
.56587 .57605 .57169 .57112 .58323 .57502 .57748 .58144 Mtetra
.667 .237 .217 r
.57748 .58144 .58323 .57502 .59491 .58117 .58925 .58907 Mtetra
.704 .301 .281 r
.58925 .58907 .59491 .58117 .60676 .58992 .6012 .5994 Mtetra
.735 .355 .331 r
.6012 .5994 .60676 .58992 .61885 .60252 .61338 .61333 Mtetra
.772 .408 .368 r
.61338 .61333 .61885 .60252 .63133 .62249 .6259 .63291 Mtetra
.857 .515 .404 r
.6259 .63291 .63133 .62249 .64496 .66983 .63933 .67352 Mtetra
.883 .507 .324 r
.63933 .67352 .64496 .66983 .6588 .71185 .65291 .70851 Mtetra
.603 .852 .991 r
.65291 .70851 .6588 .71185 .67113 .70855 .66529 .70519 Mtetra
.961 .786 .62 r
.66529 .70519 .67113 .70855 .68148 .65977 .67606 .66342 Mtetra
.997 .831 .555 r
.67606 .66342 .68148 .65977 .69128 .60543 .68633 .61581 Mtetra
.739 .817 .349 r
.68633 .61581 .69128 .60543 .7022 .57846 .6974 .58921 Mtetra
0 0 0 r
.6974 .58921 .7022 .57846 .71341 .55881 .70866 .56821 Mtetra
.70866 .56821 .71341 .55881 .72478 .54301 .72006 .55079 Mtetra
.72006 .55079 .72478 .54301 .73628 .52978 .73157 .53604 Mtetra
.73157 .53604 .73628 .52978 .74791 .51881 .74319 .52351 Mtetra
.74319 .52351 .74791 .51881 .75962 .509 .7549 .51238 Mtetra
.515 .863 .607 r
.7549 .51238 .75962 .509 .77143 .50041 .7667 .50256 Mtetra
.582 .925 .724 r
.7667 .50256 .77143 .50041 .78331 .49258 .77858 .49364 Mtetra
.635 .962 .818 r
.77858 .49364 .78331 .49258 .79526 .48537 .79053 .48546 Mtetra
.672 .975 .884 r
.79053 .48546 .79526 .48537 .80729 .47866 .80255 .47788 Mtetra
.698 .972 .925 r
.80255 .47788 .80729 .47866 .81937 .4723 .81463 .47074 Mtetra
.711 .957 .948 r
.81463 .47074 .81937 .4723 .83152 .46626 .82678 .464 Mtetra
.719 .937 .958 r
.82678 .464 .83152 .46626 .84372 .46044 .83899 .45753 Mtetra
.722 .914 .96 r
.83899 .45753 .84372 .46044 .85599 .45481 .85125 .4513 Mtetra
.722 .892 .957 r
.85125 .4513 .85599 .45481 .86831 .44932 .86357 .44527 Mtetra
.721 .871 .952 r
.86357 .44527 .86831 .44932 .88068 .44395 .87595 .43938 Mtetra
.72 .851 .944 r
.87595 .43938 .88068 .44395 .89311 .43866 .88837 .43361 Mtetra
.718 .833 .936 r
.88837 .43361 .89311 .43866 .90559 .43344 .90085 .42792 Mtetra
.716 .816 .927 r
.90085 .42792 .90559 .43344 .91812 .42826 .91338 .42229 Mtetra
.714 .8 .919 r
.91338 .42229 .91812 .42826 .9307 .42311 .92596 .41671 Mtetra
.712 .786 .91 r
.92596 .41671 .9307 .42311 .94332 .41797 .93858 .41114 Mtetra
.71 .772 .901 r
.93858 .41114 .94332 .41797 .956 .41282 .95124 .40556 Mtetra
.583 .718 .936 r
.37353 .57429 .37994 .58026 .39043 .5786 .38403 .57296 Mtetra
.578 .729 .946 r
.38403 .57296 .39043 .5786 .40098 .57693 .39458 .57164 Mtetra
.569 .739 .956 r
.39458 .57164 .40098 .57693 .41157 .5753 .40519 .57035 Mtetra
.558 .75 .967 r
.40519 .57035 .41157 .5753 .42222 .57371 .41585 .56912 Mtetra
.542 .759 .977 r
.41585 .56912 .42222 .57371 .43292 .57219 .42657 .56798 Mtetra
.521 .768 .987 r
.42657 .56798 .43292 .57219 .44366 .57076 .43733 .56695 Mtetra
.493 .774 .994 r
.43733 .56695 .44366 .57076 .45446 .56946 .44815 .56606 Mtetra
.454 .776 .998 r
.44815 .56606 .45446 .56946 .46532 .56831 .45903 .56536 Mtetra
.4 .771 .993 r
.45903 .56536 .46532 .56831 .47623 .56735 .46997 .56489 Mtetra
.326 .751 .974 r
.46997 .56489 .47623 .56735 .48719 .56664 .48096 .5647 Mtetra
.228 .712 .93 r
.48096 .5647 .48719 .56664 .49821 .56622 .49202 .56485 Mtetra
.095 .637 .847 r
.49202 .56485 .49821 .56622 .5093 .56619 .50314 .56546 Mtetra
0 .529 .721 r
.50314 .56546 .5093 .56619 .52045 .5666 .51433 .56657 Mtetra
.22 0 0 r
.51433 .56657 .52045 .5666 .53168 .56762 .52559 .56836 Mtetra
.367 0 0 r
.52559 .56836 .53168 .56762 .54298 .56939 .53694 .57098 Mtetra
.483 0 0 r
.53694 .57098 .54298 .56939 .55437 .57206 .54839 .57458 Mtetra
.575 .049 0 r
.54839 .57458 .55437 .57206 .56587 .57605 .55994 .57952 Mtetra
.637 .146 .068 r
.55994 .57952 .56587 .57605 .57748 .58144 .57162 .58599 Mtetra
.686 .229 .161 r
.57162 .58599 .57748 .58144 .58925 .58907 .58345 .5945 Mtetra
.725 .294 .225 r
.58345 .5945 .58925 .58907 .6012 .5994 .59547 .60558 Mtetra
.757 .346 .27 r
.59547 .60558 .6012 .5994 .61338 .61333 .60771 .61972 Mtetra
.787 .387 .296 r
.60771 .61972 .61338 .61333 .6259 .63291 .62022 .63737 Mtetra
.867 .488 .325 r
.62022 .63737 .6259 .63291 .63933 .67352 .63334 .66831 Mtetra
.857 .41 .017 r
.63334 .66831 .63933 .67352 .65291 .70851 .64656 .69371 Mtetra
.637 .584 .778 r
.64656 .69371 .65291 .70851 .66529 .70519 .65895 .69035 Mtetra
.86 .682 .659 r
.65895 .69035 .66529 .70519 .67606 .66342 .67019 .65813 Mtetra
.946 .774 .637 r
.67019 .65813 .67606 .66342 .68633 .61581 .68101 .6202 Mtetra
.952 .94 .616 r
.68101 .6202 .68633 .61581 .6974 .58921 .69229 .59551 Mtetra
.829 .921 .529 r
.69229 .59551 .6974 .58921 .70866 .56821 .70365 .57427 Mtetra
.744 .9 .513 r
.70365 .57427 .70866 .56821 .72006 .55079 .71511 .55605 Mtetra
.694 .899 .538 r
.71511 .55605 .72006 .55079 .73157 .53604 .72666 .54038 Mtetra
.669 .911 .586 r
.72666 .54038 .73157 .53604 .74319 .52351 .73831 .52673 Mtetra
.686 .944 .665 r
.73831 .52673 .74319 .52351 .7549 .51238 .75003 .51459 Mtetra
.697 .967 .738 r
.75003 .51459 .7549 .51238 .7667 .50256 .76185 .50379 Mtetra
.719 .986 .809 r
.76185 .50379 .7667 .50256 .77858 .49364 .77373 .49396 Mtetra
.734 .991 .864 r
.77373 .49396 .77858 .49364 .79053 .48546 .78569 .48495 Mtetra
.743 .985 .903 r
.78569 .48495 .79053 .48546 .80255 .47788 .79772 .47662 Mtetra
.749 .971 .928 r
.79772 .47662 .80255 .47788 .81463 .47074 .80981 .46878 Mtetra
.749 .952 .943 r
.80981 .46878 .81463 .47074 .82678 .464 .82196 .46139 Mtetra
.748 .931 .948 r
.82196 .46139 .82678 .464 .83899 .45753 .83418 .45434 Mtetra
.745 .909 .949 r
.83418 .45434 .83899 .45753 .85125 .4513 .84645 .44756 Mtetra
.741 .888 .947 r
.84645 .44756 .85125 .4513 .86357 .44527 .85877 .44101 Mtetra
.738 .868 .941 r
.85877 .44101 .86357 .44527 .87595 .43938 .87115 .43464 Mtetra
.734 .85 .935 r
.87115 .43464 .87595 .43938 .88837 .43361 .88358 .4284 Mtetra
.73 .833 .928 r
.88358 .4284 .88837 .43361 .90085 .42792 .89606 .42227 Mtetra
.727 .817 .92 r
.89606 .42227 .90085 .42792 .91338 .42229 .90859 .41622 Mtetra
.724 .802 .912 r
.90859 .41622 .91338 .42229 .92596 .41671 .92117 .41021 Mtetra
.722 .788 .904 r
.92117 .41021 .92596 .41671 .93858 .41114 .93379 .40423 Mtetra
.72 .775 .896 r
.93379 .40423 .93858 .41114 .95124 .40556 .94645 .39825 Mtetra
.566 .712 .94 r
.36707 .56828 .37353 .57429 .38403 .57296 .37758 .56726 Mtetra
.56 .722 .949 r
.37758 .56726 .38403 .57296 .39458 .57164 .38814 .56626 Mtetra
.55 .731 .959 r
.38814 .56626 .39458 .57164 .40519 .57035 .39876 .56529 Mtetra
.538 .74 .969 r
.39876 .56529 .40519 .57035 .41585 .56912 .40944 .5644 Mtetra
.52 .747 .978 r
.40944 .5644 .41585 .56912 .42657 .56798 .42017 .56361 Mtetra
.498 .754 .987 r
.42017 .56361 .42657 .56798 .43733 .56695 .43095 .56293 Mtetra
.468 .757 .993 r
.43095 .56293 .43733 .56695 .44815 .56606 .44179 .56243 Mtetra
.428 .756 .995 r
.44179 .56243 .44815 .56606 .45903 .56536 .45269 .56213 Mtetra
.374 .748 .99 r
.45269 .56213 .45903 .56536 .46997 .56489 .46365 .56209 Mtetra
.301 .726 .972 r
.46365 .56209 .46997 .56489 .48096 .5647 .47467 .56236 Mtetra
.207 .687 .933 r
.47467 .56236 .48096 .5647 .49202 .56485 .48576 .563 Mtetra
.084 .618 .862 r
.48576 .563 .49202 .56485 .50314 .56546 .49691 .56414 Mtetra
0 .521 .755 r
.49691 .56414 .50314 .56546 .51433 .56657 .50813 .56582 Mtetra
.211 0 0 r
.50813 .56582 .51433 .56657 .52559 .56836 .51944 .56821 Mtetra
.355 0 0 r
.51944 .56821 .52559 .56836 .53694 .57098 .53083 .57147 Mtetra
.475 0 0 r
.53083 .57147 .53694 .57098 .54839 .57458 .54232 .57574 Mtetra
.572 .017 0 r
.54232 .57574 .54839 .57458 .55994 .57952 .55392 .58134 Mtetra
.641 .118 0 r
.55392 .58134 .55994 .57952 .57162 .58599 .56565 .58846 Mtetra
.695 .203 .073 r
.56565 .58846 .57162 .58599 .58345 .5945 .57753 .59747 Mtetra
.738 .272 .141 r
.57753 .59747 .58345 .5945 .59547 .60558 .58959 .60883 Mtetra
.773 .326 .188 r
.58959 .60883 .59547 .60558 .60771 .61972 .60187 .62285 Mtetra
.8 .364 .211 r
.60187 .62285 .60771 .61972 .62022 .63737 .61438 .63956 Mtetra
.868 .467 .27 r
.61438 .63956 .62022 .63737 .63334 .66831 .62741 .66683 Mtetra
.852 .398 .108 r
.62741 .66683 .63334 .66831 .64656 .69371 .64052 .68867 Mtetra
.637 .8 .961 r
.64052 .68867 .64656 .69371 .65895 .69035 .65295 .68528 Mtetra
.933 .793 .683 r
.65295 .68528 .65895 .69035 .67019 .65813 .66442 .65659 Mtetra
.971 .826 .642 r
.66442 .65659 .67019 .65813 .68101 .6202 .67551 .6223 Mtetra
.97 .931 .676 r
.67551 .6223 .68101 .6202 .69229 .59551 .68694 .59852 Mtetra
.943 .959 .672 r
.68694 .59852 .69229 .59551 .70365 .57427 .69841 .57737 Mtetra
.907 .974 .682 r
.69841 .57737 .70365 .57427 .71511 .55605 .70994 .55884 Mtetra
.871 .985 .705 r
.70994 .55884 .71511 .55605 .72666 .54038 .72156 .54262 Mtetra
.844 .992 .738 r
.72156 .54262 .72666 .54038 .73831 .52673 .73325 .52827 Mtetra
.828 .998 .779 r
.73325 .52827 .73831 .52673 .75003 .51459 .74501 .51543 Mtetra
.814 1 .82 r
.74501 .51543 .75003 .51459 .76185 .50379 .75685 .5039 Mtetra
.806 .997 .857 r
.75685 .5039 .76185 .50379 .77373 .49396 .76876 .49337 Mtetra
.799 .988 .888 r
.76876 .49337 .77373 .49396 .78569 .48495 .78074 .4837 Mtetra
.791 .974 .91 r
.78074 .4837 .78569 .48495 .79772 .47662 .79278 .47473 Mtetra
.784 .958 .925 r
.79278 .47473 .79772 .47662 .80981 .46878 .80489 .46631 Mtetra
.776 .939 .934 r
.80489 .46631 .80981 .46878 .82196 .46139 .81706 .45837 Mtetra
.77 .919 .937 r
.81706 .45837 .82196 .46139 .83418 .45434 .82928 .45079 Mtetra
.763 .9 .938 r
.82928 .45079 .83418 .45434 .84645 .44756 .84157 .44352 Mtetra
.756 .881 .935 r
.84157 .44352 .84645 .44756 .85877 .44101 .8539 .4365 Mtetra
.751 .863 .931 r
.8539 .4365 .85877 .44101 .87115 .43464 .86629 .42968 Mtetra
.745 .846 .926 r
.86629 .42968 .87115 .43464 .88358 .4284 .87873 .42302 Mtetra
.741 .831 .92 r
.87873 .42302 .88358 .4284 .89606 .42227 .89122 .41647 Mtetra
.737 .816 .913 r
.89122 .41647 .89606 .42227 .90859 .41622 .90376 .41001 Mtetra
.734 .802 .906 r
.90376 .41001 .90859 .41622 .92117 .41021 .91634 .40361 Mtetra
.731 .79 .899 r
.91634 .40361 .92117 .41021 .93379 .40423 .92896 .39725 Mtetra
.729 .778 .892 r
.92896 .39725 .93379 .40423 .94645 .39825 .94162 .39088 Mtetra
.549 .706 .943 r
.36056 .56222 .36707 .56828 .37758 .56726 .37108 .5615 Mtetra
.542 .715 .952 r
.37108 .5615 .37758 .56726 .38814 .56626 .38166 .56079 Mtetra
.532 .723 .961 r
.38166 .56079 .38814 .56626 .39876 .56529 .39229 .56013 Mtetra
.518 .73 .97 r
.39229 .56013 .39876 .56529 .40944 .5644 .40297 .55954 Mtetra
.5 .736 .978 r
.40297 .55954 .40944 .5644 .42017 .56361 .41372 .55906 Mtetra
.477 .74 .986 r
.41372 .55906 .42017 .56361 .43095 .56293 .42452 .55872 Mtetra
.446 .741 .991 r
.42452 .55872 .43095 .56293 .44179 .56243 .43538 .55856 Mtetra
.406 .738 .992 r
.43538 .55856 .44179 .56243 .45269 .56213 .4463 .55862 Mtetra
.353 .727 .987 r
.4463 .55862 .45269 .56213 .46365 .56209 .45728 .55895 Mtetra
.283 .705 .97 r
.45728 .55895 .46365 .56209 .47467 .56236 .46833 .55962 Mtetra
.196 .667 .937 r
.46833 .55962 .47467 .56236 .48576 .563 .47944 .56068 Mtetra
.082 .605 .877 r
.47944 .56068 .48576 .563 .49691 .56414 .49062 .56224 Mtetra
0 .52 .788 r
.49062 .56224 .49691 .56414 .50813 .56582 .50188 .56438 Mtetra
.189 0 0 r
.50188 .56438 .50813 .56582 .51944 .56821 .51322 .56724 Mtetra
.327 0 0 r
.51322 .56724 .51944 .56821 .53083 .57147 .52465 .57096 Mtetra
.448 0 0 r
.52465 .57096 .53083 .57147 .54232 .57574 .53618 .5757 Mtetra
.55 0 0 r
.53618 .5757 .54232 .57574 .55392 .58134 .54782 .58169 Mtetra
.627 .075 0 r
.54782 .58169 .55392 .58134 .56565 .58846 .55959 .58914 Mtetra
.686 .16 0 r
.55959 .58914 .56565 .58846 .57753 .59747 .57151 .59831 Mtetra
.734 .231 .032 r
.57151 .59831 .57753 .59747 .58959 .60883 .5836 .60955 Mtetra
.772 .286 .075 r
.5836 .60955 .58959 .60883 .60187 .62285 .59589 .62306 Mtetra
.799 .322 .089 r
.59589 .62306 .60187 .62285 .61438 .63956 .60841 .63877 Mtetra
.871 .441 .179 r
.60841 .63877 .61438 .63956 .62741 .66683 .62136 .66357 Mtetra
.819 .338 0 r
.62136 .66357 .62741 .66683 .64052 .68867 .63441 .68313 Mtetra
.642 .785 .95 r
.63441 .68313 .64052 .68867 .65295 .68528 .64688 .67972 Mtetra
.923 .791 .697 r
.64688 .67972 .65295 .68528 .66442 .65659 .65852 .65325 Mtetra
.955 .811 .662 r
.65852 .65325 .66442 .65659 .67551 .6223 .66982 .6214 Mtetra
.959 .889 .717 r
.66982 .6214 .67551 .6223 .68694 .59852 .68138 .59859 Mtetra
.957 .923 .729 r
.68138 .59859 .68694 .59852 .69841 .57737 .69296 .57791 Mtetra
.944 .951 .747 r
.69296 .57791 .69841 .57737 .70994 .55884 .70459 .55946 Mtetra
.923 .97 .77 r
.70459 .55946 .70994 .55884 .72156 .54262 .71628 .54304 Mtetra
.902 .981 .794 r
.71628 .54304 .72156 .54262 .73325 .52827 .72803 .52831 Mtetra
.881 .985 .821 r
.72803 .52831 .73325 .52827 .74501 .51543 .73984 .51502 Mtetra
.862 .984 .848 r
.73984 .51502 .74501 .51543 .75685 .5039 .75172 .50298 Mtetra
.846 .978 .871 r
.75172 .50298 .75685 .5039 .76876 .49337 .76367 .49193 Mtetra
.831 .968 .891 r
.76367 .49193 .76876 .49337 .78074 .4837 .77568 .48174 Mtetra
.817 .955 .906 r
.77568 .48174 .78074 .4837 .79278 .47473 .78775 .47225 Mtetra
.805 .94 .916 r
.78775 .47225 .79278 .47473 .80489 .46631 .79988 .46334 Mtetra
.794 .923 .923 r
.79988 .46334 .80489 .46631 .81706 .45837 .81207 .45492 Mtetra
.784 .906 .926 r
.81207 .45492 .81706 .45837 .82928 .45079 .82431 .44688 Mtetra
.775 .889 .926 r
.82431 .44688 .82928 .45079 .84157 .44352 .83662 .43918 Mtetra
.768 .873 .925 r
.83662 .43918 .84157 .44352 .8539 .4365 .84897 .43174 Mtetra
.761 .857 .921 r
.84897 .43174 .8539 .4365 .86629 .42968 .86137 .42451 Mtetra
.755 .842 .917 r
.86137 .42451 .86629 .42968 .87873 .42302 .87383 .41745 Mtetra
.75 .828 .912 r
.87383 .41745 .87873 .42302 .89122 .41647 .88633 .41052 Mtetra
.746 .815 .906 r
.88633 .41052 .89122 .41647 .90376 .41001 .89887 .40368 Mtetra
.742 .802 .9 r
.89887 .40368 .90376 .41001 .91634 .40361 .91146 .39691 Mtetra
.739 .791 .894 r
.91146 .39691 .91634 .40361 .92896 .39725 .92409 .39018 Mtetra
.737 .78 .887 r
.92409 .39018 .92896 .39725 .94162 .39088 .93675 .38345 Mtetra
.533 .7 .946 r
.35401 .55612 .36056 .56222 .37108 .5615 .36453 .55566 Mtetra
.525 .708 .954 r
.36453 .55566 .37108 .5615 .38166 .56079 .37512 .55522 Mtetra
.515 .714 .962 r
.37512 .55522 .38166 .56079 .39229 .56013 .38576 .55483 Mtetra
.501 .72 .97 r
.38576 .55483 .39229 .56013 .40297 .55954 .39646 .55453 Mtetra
.482 .724 .977 r
.39646 .55453 .40297 .55954 .41372 .55906 .40722 .55433 Mtetra
.459 .727 .984 r
.40722 .55433 .41372 .55906 .42452 .55872 .41804 .55428 Mtetra
.429 .726 .988 r
.41804 .55428 .42452 .55872 .43538 .55856 .42892 .55442 Mtetra
.39 .721 .989 r
.42892 .55442 .43538 .55856 .4463 .55862 .43986 .55479 Mtetra
.34 .709 .984 r
.43986 .55479 .4463 .55862 .45728 .55895 .45086 .55543 Mtetra
.276 .688 .97 r
.45086 .55543 .45728 .55895 .46833 .55962 .46193 .55643 Mtetra
.198 .654 .944 r
.46193 .55643 .46833 .55962 .47944 .56068 .47307 .55782 Mtetra
.098 .6 .897 r
.47307 .55782 .47944 .56068 .49062 .56224 .48428 .55972 Mtetra
0 .529 .829 r
.48428 .55972 .49062 .56224 .50188 .56438 .49556 .5622 Mtetra
0 .434 .734 r
.49556 .5622 .50188 .56438 .51322 .56724 .50694 .56539 Mtetra
.274 0 0 r
.50694 .56539 .51322 .56724 .52465 .57096 .5184 .56942 Mtetra
.393 0 0 r
.5184 .56942 .52465 .57096 .53618 .5757 .52996 .57443 Mtetra
.5 0 0 r
.52996 .57443 .53618 .5757 .54782 .58169 .54163 .58063 Mtetra
.586 .012 0 r
.54163 .58063 .54782 .58169 .55959 .58914 .55344 .58821 Mtetra
.654 .099 0 r
.55344 .58821 .55959 .58914 .57151 .59831 .56538 .59736 Mtetra
.709 .174 0 r
.56538 .59736 .57151 .59831 .5836 .60955 .5775 .60835 Mtetra
.75 .233 0 r
.5775 .60835 .5836 .60955 .59589 .62306 .5898 .62135 Mtetra
.776 .27 0 r
.5898 .62135 .59589 .62306 .60841 .63877 .60232 .63623 Mtetra
.861 .411 .097 r
.60232 .63623 .60841 .63877 .62136 .66357 .61523 .6593 Mtetra
.776 .28 0 r
.61523 .6593 .62136 .66357 .63441 .68313 .62824 .67731 Mtetra
.644 .777 .945 r
.62824 .67731 .63441 .68313 .64688 .67972 .64075 .67387 Mtetra
.916 .79 .707 r
.64075 .67387 .64688 .67972 .65852 .65325 .65252 .64891 Mtetra
.944 .803 .674 r
.65252 .64891 .65852 .65325 .66982 .6214 .66398 .61875 Mtetra
.942 .859 .73 r
.66398 .61875 .66982 .6214 .68138 .59859 .67566 .59672 Mtetra
.943 .887 .746 r
.67566 .59672 .68138 .59859 .69296 .57791 .68735 .57651 Mtetra
.938 .911 .767 r
.68735 .57651 .69296 .57791 .70459 .55946 .69907 .55826 Mtetra
.926 .93 .789 r
.69907 .55826 .70459 .55946 .71628 .54304 .71084 .54182 Mtetra
.912 .943 .811 r
.71084 .54182 .71628 .54304 .72803 .52831 .72266 .52692 Mtetra
.895 .949 .833 r
.72266 .52692 .72803 .52831 .73984 .51502 .73453 .51337 Mtetra
.877 .95 .854 r
.73453 .51337 .73984 .51502 .75172 .50298 .74646 .501 Mtetra
.861 .947 .871 r
.74646 .501 .75172 .50298 .76367 .49193 .75845 .48959 Mtetra
.844 .939 .886 r
.75845 .48959 .76367 .49193 .77568 .48174 .7705 .47901 Mtetra
.83 .93 .898 r
.7705 .47901 .77568 .48174 .78775 .47225 .78261 .46913 Mtetra
.816 .918 .906 r
.78261 .46913 .78775 .47225 .79988 .46334 .79477 .45982 Mtetra
.804 .905 .911 r
.79477 .45982 .79988 .46334 .81207 .45492 .80699 .45101 Mtetra
.794 .891 .914 r
.80699 .45101 .81207 .45492 .82431 .44688 .81926 .44258 Mtetra
.784 .877 .915 r
.81926 .44258 .82431 .44688 .83662 .43918 .83159 .4345 Mtetra
.776 .863 .914 r
.83159 .4345 .83662 .43918 .84897 .43174 .84396 .42668 Mtetra
.769 .85 .912 r
.84396 .42668 .84897 .43174 .86137 .42451 .85638 .41909 Mtetra
.763 .837 .909 r
.85638 .41909 .86137 .42451 .87383 .41745 .86886 .41167 Mtetra
.758 .825 .905 r
.86886 .41167 .87383 .41745 .88633 .41052 .88137 .40439 Mtetra
.753 .813 .9 r
.88137 .40439 .88633 .41052 .89887 .40368 .89393 .39721 Mtetra
.749 .802 .895 r
.89393 .39721 .89887 .40368 .91146 .39691 .90653 .3901 Mtetra
.746 .791 .889 r
.90653 .3901 .91146 .39691 .92409 .39018 .91917 .38302 Mtetra
.744 .781 .883 r
.91917 .38302 .92409 .39018 .93675 .38345 .93184 .37595 Mtetra
.517 .694 .949 r
.34741 .54998 .35401 .55612 .36453 .55566 .35794 .54976 Mtetra
.51 .701 .956 r
.35794 .54976 .36453 .55566 .37512 .55522 .36853 .54956 Mtetra
.499 .706 .963 r
.36853 .54956 .37512 .55522 .38576 .55483 .37919 .54942 Mtetra
.485 .71 .97 r
.37919 .54942 .38576 .55483 .39646 .55453 .3899 .54936 Mtetra
.467 .713 .976 r
.3899 .54936 .39646 .55453 .40722 .55433 .40067 .54941 Mtetra
.444 .714 .981 r
.40067 .54941 .40722 .55433 .41804 .55428 .41151 .54962 Mtetra
.415 .712 .985 r
.41151 .54962 .41804 .55428 .42892 .55442 .4224 .55001 Mtetra
.379 .706 .985 r
.4224 .55001 .42892 .55442 .43986 .55479 .43336 .55064 Mtetra
.333 .694 .981 r
.43336 .55064 .43986 .55479 .45086 .55543 .44439 .55155 Mtetra
.276 .674 .97 r
.44439 .55155 .45086 .55543 .46193 .55643 .45548 .5528 Mtetra
.207 .644 .95 r
.45548 .5528 .46193 .55643 .47307 .55782 .46664 .55445 Mtetra
.122 .6 .916 r
.46664 .55445 .47307 .55782 .48428 .55972 .47788 .55659 Mtetra
.025 .541 .866 r
.47788 .55659 .48428 .55972 .49556 .5622 .48919 .5593 Mtetra
0 .464 .797 r
.48919 .5593 .49556 .5622 .50694 .56539 .50059 .56269 Mtetra
0 .373 .71 r
.50059 .56269 .50694 .56539 .5184 .56942 .51208 .56689 Mtetra
.313 0 0 r
.51208 .56689 .5184 .56942 .52996 .57443 .52367 .57202 Mtetra
.419 0 0 r
.52367 .57202 .52996 .57443 .54163 .58063 .53538 .57826 Mtetra
.511 0 0 r
.53538 .57826 .54163 .58063 .55344 .58821 .5472 .58577 Mtetra
.586 .015 0 r
.5472 .58577 .55344 .58821 .56538 .59736 .55918 .59474 Mtetra
.649 .095 0 r
.55918 .59474 .56538 .59736 .5775 .60835 .57131 .60539 Mtetra
.697 .159 0 r
.57131 .60539 .5775 .60835 .5898 .62135 .58362 .61787 Mtetra
.725 .201 0 r
.58362 .61787 .5898 .62135 .60232 .63623 .59614 .63209 Mtetra
.842 .378 .01 r
.59614 .63209 .60232 .63623 .61523 .6593 .60903 .65411 Mtetra
.729 .228 0 r
.60903 .65411 .61523 .6593 .62824 .67731 .62201 .67122 Mtetra
.645 .77 .939 r
.62201 .67122 .62824 .67731 .64075 .67387 .63456 .66775 Mtetra
.911 .788 .713 r
.63456 .66775 .64075 .67387 .65252 .64891 .64644 .64364 Mtetra
.934 .793 .681 r
.64644 .64364 .65252 .64891 .66398 .61875 .65803 .61448 Mtetra
.923 .83 .736 r
.65803 .61448 .66398 .61875 .67566 .59672 .66981 .59307 Mtetra
.924 .851 .752 r
.66981 .59307 .67566 .59672 .68735 .57651 .6816 .57333 Mtetra
.92 .871 .772 r
.6816 .57333 .68735 .57651 .69907 .55826 .69341 .55537 Mtetra
.913 .888 .793 r
.69341 .55537 .69907 .55826 .71084 .54182 .70526 .53907 Mtetra
.903 .901 .813 r
.70526 .53907 .71084 .54182 .72266 .52692 .71715 .52418 Mtetra
.89 .909 .832 r
.71715 .52418 .72266 .52692 .73453 .51337 .72909 .51055 Mtetra
.876 .914 .85 r
.72909 .51055 .73453 .51337 .74646 .501 .74108 .49801 Mtetra
.862 .914 .865 r
.74108 .49801 .74646 .501 .75845 .48959 .75313 .48638 Mtetra
.847 .91 .878 r
.75313 .48638 .75845 .48959 .7705 .47901 .76522 .47554 Mtetra
.834 .904 .888 r
.76522 .47554 .7705 .47901 .78261 .46913 .77737 .46537 Mtetra
.821 .896 .895 r
.77737 .46537 .78261 .46913 .79477 .45982 .78957 .45576 Mtetra
.809 .887 .9 r
.78957 .45576 .79477 .45982 .80699 .45101 .80183 .44663 Mtetra
.799 .876 .903 r
.80183 .44663 .80699 .45101 .81926 .44258 .81413 .43788 Mtetra
.79 .865 .905 r
.81413 .43788 .81926 .44258 .83159 .4345 .82648 .42948 Mtetra
.782 .854 .905 r
.82648 .42948 .83159 .4345 .84396 .42668 .83888 .42134 Mtetra
.775 .843 .903 r
.83888 .42134 .84396 .42668 .85638 .41909 .85133 .41342 Mtetra
.769 .832 .901 r
.85133 .41342 .85638 .41909 .86886 .41167 .86382 .40569 Mtetra
.763 .821 .898 r
.86382 .40569 .86886 .41167 .88137 .40439 .87636 .39809 Mtetra
.759 .811 .894 r
.87636 .39809 .88137 .40439 .89393 .39721 .88894 .39059 Mtetra
.755 .801 .89 r
.88894 .39059 .89393 .39721 .90653 .3901 .90155 .38316 Mtetra
.752 .791 .885 r
.90155 .38316 .90653 .3901 .91917 .38302 .91421 .37578 Mtetra
.75 .782 .88 r
.91421 .37578 .91917 .38302 .93184 .37595 .92689 .3684 Mtetra
.503 .688 .951 r
.34076 .54378 .34741 .54998 .35794 .54976 .3513 .54378 Mtetra
.495 .694 .957 r
.3513 .54378 .35794 .54976 .36853 .54956 .3619 .5438 Mtetra
.485 .698 .963 r
.3619 .5438 .36853 .54956 .37919 .54942 .37256 .54387 Mtetra
.471 .701 .969 r
.37256 .54387 .37919 .54942 .3899 .54936 .38329 .54403 Mtetra
.453 .703 .974 r
.38329 .54403 .3899 .54936 .40067 .54941 .39408 .5443 Mtetra
.432 .703 .979 r
.39408 .5443 .40067 .54941 .41151 .54962 .40493 .54472 Mtetra
.405 .7 .981 r
.40493 .54472 .41151 .54962 .4224 .55001 .41584 .54533 Mtetra
.372 .693 .982 r
.41584 .54533 .4224 .55001 .43336 .55064 .42682 .54617 Mtetra
.331 .681 .979 r
.42682 .54617 .43336 .55064 .44439 .55155 .43787 .54729 Mtetra
.281 .663 .97 r
.43787 .54729 .44439 .55155 .45548 .5528 .44898 .54874 Mtetra
.223 .638 .956 r
.44898 .54874 .45548 .5528 .46664 .55445 .46017 .55057 Mtetra
.151 .601 .931 r
.46017 .55057 .46664 .55445 .47788 .55659 .47143 .55287 Mtetra
.072 .555 .897 r
.47143 .55287 .47788 .55659 .48919 .5593 .48277 .55572 Mtetra
0 .494 .849 r
.48277 .55572 .48919 .5593 .50059 .56269 .49419 .5592 Mtetra
0 .423 .79 r
.49419 .5592 .50059 .56269 .51208 .56689 .50571 .56344 Mtetra
0 .344 .722 r
.50571 .56344 .51208 .56689 .52367 .57202 .51733 .56853 Mtetra
0 .257 .647 r
.51733 .56853 .52367 .57202 .53538 .57826 .52905 .57465 Mtetra
.396 0 0 r
.52905 .57465 .53538 .57826 .5472 .58577 .5409 .58193 Mtetra
.472 0 0 r
.5409 .58193 .5472 .58577 .55918 .59474 .55289 .59054 Mtetra
.539 0 0 r
.55289 .59054 .55918 .59474 .57131 .60539 .56503 .60071 Mtetra
.592 .056 0 r
.56503 .60071 .57131 .60539 .58362 .61787 .57735 .61259 Mtetra
.631 .112 0 r
.57735 .61259 .58362 .61787 .59614 .63209 .58987 .62632 Mtetra
.817 .351 0 r
.58987 .62632 .59614 .63209 .60903 .65411 .60275 .64834 Mtetra
.711 .214 0 r
.60275 .64834 .60903 .65411 .62201 .67122 .61575 .66558 Mtetra
.641 .786 .951 r
.61575 .66558 .62201 .67122 .63456 .66775 .62833 .66209 Mtetra
.916 .797 .714 r
.62833 .66209 .63456 .66775 .64644 .64364 .64028 .63778 Mtetra
.929 .785 .681 r
.64028 .63778 .64644 .64364 .65803 .61448 .65196 .60857 Mtetra
.903 .801 .736 r
.65196 .60857 .65803 .61448 .66981 .59307 .66383 .5876 Mtetra
.901 .814 .753 r
.66383 .5876 .66981 .59307 .6816 .57333 .67571 .56841 Mtetra
.898 .832 .772 r
.67571 .56841 .6816 .57333 .69341 .55537 .68762 .55089 Mtetra
.894 .848 .791 r
.68762 .55089 .69341 .55537 .70526 .53907 .69955 .53489 Mtetra
.887 .862 .81 r
.69955 .53489 .70526 .53907 .71715 .52418 .71152 .52019 Mtetra
.878 .873 .827 r
.71152 .52019 .71715 .52418 .72909 .51055 .72353 .50662 Mtetra
.867 .88 .843 r
.72353 .50662 .72909 .51055 .74108 .49801 .73559 .49406 Mtetra
.856 .883 .857 r
.73559 .49406 .74108 .49801 .75313 .48638 .74769 .48234 Mtetra
.844 .883 .868 r
.74769 .48234 .75313 .48638 .76522 .47554 .75984 .47136 Mtetra
.832 .881 .878 r
.75984 .47136 .76522 .47554 .77737 .46537 .77204 .461 Mtetra
.822 .876 .885 r
.77204 .461 .77737 .46537 .78957 .45576 .78428 .45117 Mtetra
.811 .869 .89 r
.78428 .45117 .78957 .45576 .80183 .44663 .79657 .4418 Mtetra
.802 .862 .894 r
.79657 .4418 .80183 .44663 .81413 .43788 .80892 .4328 Mtetra
.793 .853 .895 r
.80892 .4328 .81413 .43788 .82648 .42948 .8213 .42412 Mtetra
.786 .844 .896 r
.8213 .42412 .82648 .42948 .83888 .42134 .83373 .41571 Mtetra
.779 .835 .895 r
.83373 .41571 .83888 .42134 .85133 .41342 .84621 .40751 Mtetra
.773 .826 .894 r
.84621 .40751 .85133 .41342 .86382 .40569 .85873 .39949 Mtetra
.768 .817 .891 r
.85873 .39949 .86382 .40569 .87636 .39809 .87129 .39161 Mtetra
.764 .808 .888 r
.87129 .39161 .87636 .39809 .88894 .39059 .88389 .38383 Mtetra
.76 .799 .885 r
.88389 .38383 .88894 .39059 .90155 .38316 .89653 .37612 Mtetra
.757 .791 .881 r
.89653 .37612 .90155 .38316 .91421 .37578 .9092 .36844 Mtetra
.755 .783 .876 r
.9092 .36844 .91421 .37578 .92689 .3684 .9219 .36078 Mtetra
.489 .683 .952 r
.33406 .53754 .34076 .54378 .3513 .54378 .34461 .53773 Mtetra
.482 .687 .957 r
.34461 .53773 .3513 .54378 .3619 .5438 .35522 .53793 Mtetra
.472 .691 .963 r
.35522 .53793 .3619 .5438 .37256 .54387 .36589 .53819 Mtetra
.459 .693 .968 r
.36589 .53819 .37256 .54387 .38329 .54403 .37663 .53854 Mtetra
.443 .694 .972 r
.37663 .53854 .38329 .54403 .39408 .5443 .38743 .539 Mtetra
.423 .693 .976 r
.38743 .539 .39408 .5443 .40493 .54472 .3983 .5396 Mtetra
.398 .689 .978 r
.3983 .5396 .40493 .54472 .41584 .54533 .40923 .54038 Mtetra
.369 .682 .978 r
.40923 .54038 .41584 .54533 .42682 .54617 .42023 .54139 Mtetra
.334 .672 .976 r
.42023 .54139 .42682 .54617 .43787 .54729 .43129 .54265 Mtetra
.292 .656 .97 r
.43129 .54265 .43787 .54729 .44898 .54874 .44243 .54424 Mtetra
.243 .634 .96 r
.44243 .54424 .44898 .54874 .46017 .55057 .45364 .54619 Mtetra
.186 .605 .943 r
.45364 .54619 .46017 .55057 .47143 .55287 .46492 .54857 Mtetra
.123 .569 .921 r
.46492 .54857 .47143 .55287 .48277 .55572 .47629 .55146 Mtetra
.052 .523 .89 r
.47629 .55146 .48277 .55572 .49419 .5592 .48774 .55493 Mtetra
0 .469 .853 r
.48774 .55493 .49419 .5592 .50571 .56344 .49928 .55909 Mtetra
0 .409 .81 r
.49928 .55909 .50571 .56344 .51733 .56853 .51092 .56403 Mtetra
0 .341 .761 r
.51092 .56403 .51733 .56853 .52905 .57465 .52267 .5699 Mtetra
0 .274 .712 r
.52267 .5699 .52905 .57465 .5409 .58193 .53454 .57679 Mtetra
0 .202 .661 r
.53454 .57679 .5409 .58193 .55289 .59054 .54654 .58493 Mtetra
0 .132 .61 r
.54654 .58493 .55289 .59054 .56503 .60071 .55869 .59448 Mtetra
0 .061 .559 r
.55869 .59448 .56503 .60071 .57735 .61259 .57101 .60571 Mtetra
0 0 .483 r
.57101 .60571 .57735 .61259 .58987 .62632 .58352 .61922 Mtetra
.81 .357 0 r
.58352 .61922 .58987 .62632 .60275 .64834 .59642 .64275 Mtetra
.759 .27 0 r
.59642 .64275 .60275 .64834 .61575 .66558 .60946 .66162 Mtetra
.616 .841 .986 r
.60946 .66162 .61575 .66558 .62833 .66209 .6221 .6581 Mtetra
.938 .821 .704 r
.6221 .6581 .62833 .66209 .64028 .63778 .63408 .6321 Mtetra
.934 .786 .673 r
.63408 .6321 .64028 .63778 .65196 .60857 .64579 .60132 Mtetra
.888 .777 .733 r
.64579 .60132 .65196 .60857 .66383 .5876 .65773 .58051 Mtetra
.879 .783 .752 r
.65773 .58051 .66383 .5876 .67571 .56841 .66971 .56192 Mtetra
.876 .799 .77 r
.66971 .56192 .67571 .56841 .68762 .55089 .6817 .54497 Mtetra
.874 .815 .788 r
.6817 .54497 .68762 .55089 .69955 .53489 .69372 .52939 Mtetra
.869 .828 .805 r
.69372 .52939 .69955 .53489 .71152 .52019 .70577 .51503 Mtetra
.863 .841 .821 r
.70577 .51503 .71152 .52019 .72353 .50662 .71786 .50166 Mtetra
.855 .85 .836 r
.71786 .50166 .72353 .50662 .73559 .49406 .72998 .48921 Mtetra
.847 .855 .849 r
.72998 .48921 .73559 .49406 .74769 .48234 .74215 .47751 Mtetra
.838 .858 .86 r
.74215 .47751 .74769 .48234 .75984 .47136 .75436 .46648 Mtetra
.828 .859 .869 r
.75436 .46648 .75984 .47136 .77204 .461 .76661 .45603 Mtetra
.819 .857 .876 r
.76661 .45603 .77204 .461 .78428 .45117 .7789 .44605 Mtetra
.81 .853 .881 r
.7789 .44605 .78428 .45117 .79657 .4418 .79124 .43651 Mtetra
.802 .848 .885 r
.79124 .43651 .79657 .4418 .80892 .4328 .80362 .42731 Mtetra
.795 .842 .887 r
.80362 .42731 .80892 .4328 .8213 .42412 .81605 .41842 Mtetra
.788 .835 .888 r
.81605 .41842 .8213 .42412 .83373 .41571 .82852 .40978 Mtetra
.782 .828 .888 r
.82852 .40978 .83373 .41571 .84621 .40751 .84103 .40135 Mtetra
.776 .82 .887 r
.84103 .40135 .84621 .40751 .85873 .39949 .85358 .39308 Mtetra
.772 .813 .886 r
.85358 .39308 .85873 .39949 .87129 .39161 .86616 .38495 Mtetra
.768 .805 .883 r
.86616 .38495 .87129 .39161 .88389 .38383 .87879 .37691 Mtetra
.764 .798 .88 r
.87879 .37691 .88389 .38383 .89653 .37612 .89145 .36895 Mtetra
.761 .791 .877 r
.89145 .36895 .89653 .37612 .9092 .36844 .90414 .36102 Mtetra
.759 .784 .873 r
.90414 .36102 .9092 .36844 .9219 .36078 .91687 .3531 Mtetra
.477 .678 .953 r
.32731 .53126 .33406 .53754 .34461 .53773 .33786 .5316 Mtetra
.47 .681 .958 r
.33786 .5316 .34461 .53773 .35522 .53793 .34848 .53197 Mtetra
.461 .684 .962 r
.34848 .53197 .35522 .53793 .36589 .53819 .35917 .53239 Mtetra
.449 .685 .966 r
.35917 .53239 .36589 .53819 .37663 .53854 .36992 .53289 Mtetra
.434 .685 .97 r
.36992 .53289 .37663 .53854 .38743 .539 .38074 .53351 Mtetra
.416 .684 .973 r
.38074 .53351 .38743 .539 .3983 .5396 .39162 .53425 Mtetra
.394 .68 .975 r
.39162 .53425 .3983 .5396 .40923 .54038 .40257 .53518 Mtetra
.369 .674 .975 r
.40257 .53518 .40923 .54038 .42023 .54139 .41359 .5363 Mtetra
.339 .664 .974 r
.41359 .5363 .42023 .54139 .43129 .54265 .42467 .53768 Mtetra
.304 .65 .969 r
.42467 .53768 .43129 .54265 .44243 .54424 .43583 .53935 Mtetra
.265 .632 .962 r
.43583 .53935 .44243 .54424 .45364 .54619 .44706 .54135 Mtetra
.219 .609 .951 r
.44706 .54135 .45364 .54619 .46492 .54857 .45837 .54375 Mtetra
.171 .581 .937 r
.45837 .54375 .46492 .54857 .47629 .55146 .46976 .5466 Mtetra
.118 .546 .918 r
.46976 .5466 .47629 .55146 .48774 .55493 .48123 .54998 Mtetra
.063 .506 .895 r
.48123 .54998 .48774 .55493 .49928 .55909 .4928 .55396 Mtetra
.009 .462 .87 r
.4928 .55396 .49928 .55909 .51092 .56403 .50446 .55863 Mtetra
0 .412 .84 r
.50446 .55863 .51092 .56403 .52267 .5699 .51623 .56412 Mtetra
0 .365 .813 r
.51623 .56412 .52267 .5699 .53454 .57679 .52812 .57047 Mtetra
0 .308 .78 r
.52812 .57047 .53454 .57679 .54654 .58493 .54013 .57796 Mtetra
0 .255 .749 r
.54013 .57796 .54654 .58493 .55869 .59448 .55228 .58668 Mtetra
0 .194 .711 r
.55228 .58668 .55869 .59448 .57101 .60571 .56459 .59695 Mtetra
0 .093 .635 r
.56459 .59695 .57101 .60571 .58352 .61922 .57709 .60974 Mtetra
.739 .307 0 r
.57709 .60974 .58352 .61922 .59642 .64275 .58998 .63349 Mtetra
.606 .168 0 r
.58998 .63349 .59642 .64275 .60946 .66162 .60301 .65283 Mtetra
.65 .699 .882 r
.60301 .65283 .60946 .66162 .6221 .6581 .61568 .64927 Mtetra
.893 .749 .695 r
.61568 .64927 .6221 .6581 .63408 .6321 .62772 .62275 Mtetra
.903 .742 .671 r
.62772 .62275 .63408 .6321 .64579 .60132 .63949 .59168 Mtetra
.86 .739 .728 r
.63949 .59168 .64579 .60132 .65773 .58051 .65152 .57152 Mtetra
.852 .749 .749 r
.65152 .57152 .65773 .58051 .66971 .56192 .66359 .55384 Mtetra
.852 .766 .767 r
.66359 .55384 .66971 .56192 .6817 .54497 .67567 .53767 Mtetra
.852 .784 .784 r
.67567 .53767 .6817 .54497 .69372 .52939 .68778 .52269 Mtetra
.85 .799 .801 r
.68778 .52269 .69372 .52939 .70577 .51503 .69992 .50881 Mtetra
.847 .813 .816 r
.69992 .50881 .70577 .51503 .71786 .50166 .71208 .49578 Mtetra
.842 .824 .831 r
.71208 .49578 .71786 .50166 .72998 .48921 .72428 .48355 Mtetra
.837 .832 .843 r
.72428 .48355 .72998 .48921 .74215 .47751 .73651 .47197 Mtetra
.83 .837 .853 r
.73651 .47197 .74215 .47751 .75436 .46648 .74878 .46098 Mtetra
.823 .84 .862 r
.74878 .46098 .75436 .46648 .76661 .45603 .76109 .45051 Mtetra
.815 .84 .868 r
.76109 .45051 .76661 .45603 .7789 .44605 .77344 .44046 Mtetra
.808 .839 .874 r
.77344 .44046 .7789 .44605 .79124 .43651 .78582 .4308 Mtetra
.801 .836 .878 r
.78582 .4308 .79124 .43651 .80362 .42731 .79825 .42146 Mtetra
.795 .832 .88 r
.79825 .42146 .80362 .42731 .81605 .41842 .81072 .4124 Mtetra
.789 .827 .882 r
.81072 .4124 .81605 .41842 .82852 .40978 .82323 .40358 Mtetra
.783 .821 .882 r
.82323 .40358 .82852 .40978 .84103 .40135 .83577 .39494 Mtetra
.778 .815 .882 r
.83577 .39494 .84103 .40135 .85358 .39308 .84836 .38647 Mtetra
.774 .809 .881 r
.84836 .38647 .85358 .39308 .86616 .38495 .86098 .37812 Mtetra
.771 .803 .879 r
.86098 .37812 .86616 .38495 .87879 .37691 .87364 .36986 Mtetra
.767 .796 .876 r
.87364 .36986 .87879 .37691 .89145 .36895 .88633 .36166 Mtetra
.765 .79 .874 r
.88633 .36166 .89145 .36895 .90414 .36102 .89905 .35351 Mtetra
.763 .784 .871 r
.89905 .35351 .90414 .36102 .91687 .3531 .91179 .34535 Mtetra
.466 .673 .954 r
.32051 .52493 .32731 .53126 .33786 .5316 .33107 .52541 Mtetra
.46 .676 .958 r
.33107 .52541 .33786 .5316 .34848 .53197 .3417 .52591 Mtetra
.452 .678 .961 r
.3417 .52591 .34848 .53197 .35917 .53239 .3524 .52647 Mtetra
.441 .679 .965 r
.3524 .52647 .35917 .53239 .36992 .53289 .36317 .5271 Mtetra
.427 .678 .968 r
.36317 .5271 .36992 .53289 .38074 .53351 .374 .52783 Mtetra
.412 .677 .97 r
.374 .52783 .38074 .53351 .39162 .53425 .3849 .52869 Mtetra
.393 .673 .972 r
.3849 .52869 .39162 .53425 .40257 .53518 .39586 .52972 Mtetra
.371 .667 .972 r
.39586 .52972 .40257 .53518 .41359 .5363 .4069 .53093 Mtetra
.346 .658 .971 r
.4069 .53093 .41359 .5363 .42467 .53768 .41801 .53237 Mtetra
.318 .646 .968 r
.41801 .53237 .42467 .53768 .43583 .53935 .42918 .53408 Mtetra
.287 .632 .963 r
.42918 .53408 .43583 .53935 .44706 .54135 .44044 .53608 Mtetra
.253 .613 .956 r
.44044 .53608 .44706 .54135 .45837 .54375 .45177 .53844 Mtetra
.218 .591 .947 r
.45177 .53844 .45837 .54375 .46976 .5466 .46318 .54119 Mtetra
.181 .566 .935 r
.46318 .54119 .46976 .5466 .48123 .54998 .47468 .5444 Mtetra
.145 .537 .922 r
.47468 .5444 .48123 .54998 .4928 .55396 .48627 .54811 Mtetra
.112 .506 .907 r
.48627 .54811 .4928 .55396 .50446 .55863 .49796 .5524 Mtetra
.082 .472 .891 r
.49796 .5524 .50446 .55863 .51623 .56412 .50975 .55735 Mtetra
.064 .441 .876 r
.50975 .55735 .51623 .56412 .52812 .57047 .52164 .563 Mtetra
.046 .405 .858 r
.52164 .563 .52812 .57047 .54013 .57796 .53366 .56952 Mtetra
.047 .375 .841 r
.53366 .56952 .54013 .57796 .55228 .58668 .54581 .57697 Mtetra
.053 .342 .82 r
.54581 .57697 .55228 .58668 .56459 .59695 .55811 .58557 Mtetra
.046 .296 .786 r
.55811 .58557 .56459 .59695 .57709 .60974 .57056 .59588 Mtetra
0 .024 .597 r
.57056 .59588 .57709 .60974 .58998 .63349 .58332 .61427 Mtetra
.174 .262 .715 r
.58332 .61427 .58998 .63349 .60301 .65283 .5962 .6288 Mtetra
.616 .509 .709 r
.5962 .6288 .60301 .65283 .61568 .64927 .60884 .6252 Mtetra
.763 .595 .669 r
.60884 .6252 .61568 .64927 .62772 .62275 .62103 .60339 Mtetra
.81 .64 .671 r
.62103 .60339 .62772 .62275 .63949 .59168 .63301 .57762 Mtetra
.804 .673 .72 r
.63301 .57762 .63949 .59168 .65152 .57152 .64517 .55989 Mtetra
.814 .703 .743 r
.64517 .55989 .65152 .57152 .66359 .55384 .65735 .54383 Mtetra
.821 .729 .763 r
.65735 .54383 .66359 .55384 .67567 .53767 .66954 .52888 Mtetra
.827 .752 .781 r
.66954 .52888 .67567 .53767 .68778 .52269 .68174 .51481 Mtetra
.83 .772 .798 r
.68174 .51481 .68778 .52269 .69992 .50881 .69396 .50159 Mtetra
.83 .788 .812 r
.69396 .50159 .69992 .50881 .71208 .49578 .70621 .48905 Mtetra
.828 .802 .826 r
.70621 .48905 .71208 .49578 .72428 .48355 .71848 .47714 Mtetra
.825 .812 .837 r
.71848 .47714 .72428 .48355 .73651 .47197 .73078 .46578 Mtetra
.821 .819 .847 r
.73078 .46578 .73651 .47197 .74878 .46098 .74312 .45491 Mtetra
.816 .823 .856 r
.74312 .45491 .74878 .46098 .76109 .45051 .75549 .44448 Mtetra
.81 .826 .862 r
.75549 .44448 .76109 .45051 .77344 .44046 .76789 .43442 Mtetra
.805 .826 .867 r
.76789 .43442 .77344 .44046 .78582 .4308 .78033 .4247 Mtetra
.799 .825 .871 r
.78033 .4247 .78582 .4308 .79825 .42146 .79281 .41527 Mtetra
.794 .822 .874 r
.79281 .41527 .79825 .42146 .81072 .4124 .80532 .40608 Mtetra
.789 .819 .876 r
.80532 .40608 .81072 .4124 .82323 .40358 .81787 .39711 Mtetra
.784 .815 .877 r
.81787 .39711 .82323 .40358 .83577 .39494 .83046 .38831 Mtetra
.78 .81 .877 r
.83046 .38831 .83577 .39494 .84836 .38647 .84308 .37965 Mtetra
.776 .805 .876 r
.84308 .37965 .84836 .38647 .86098 .37812 .85574 .37111 Mtetra
.773 .8 .875 r
.85574 .37111 .86098 .37812 .87364 .36986 .86843 .36266 Mtetra
.77 .795 .873 r
.86843 .36266 .87364 .36986 .88633 .36166 .88115 .35426 Mtetra
.768 .789 .871 r
.88115 .35426 .88633 .36166 .89905 .35351 .8939 .3459 Mtetra
.766 .784 .868 r
.8939 .3459 .89905 .35351 .91179 .34535 .90668 .33755 Mtetra
.457 .669 .955 r
.31365 .51855 .32051 .52493 .33107 .52541 .32423 .51914 Mtetra
.451 .672 .958 r
.32423 .51914 .33107 .52541 .3417 .52591 .33487 .51976 Mtetra
.444 .673 .961 r
.33487 .51976 .3417 .52591 .3524 .52647 .34558 .52042 Mtetra
.434 .673 .963 r
.34558 .52042 .3524 .52647 .36317 .5271 .35636 .52116 Mtetra
.422 .673 .966 r
.35636 .52116 .36317 .5271 .374 .52783 .36721 .52199 Mtetra
.409 .67 .968 r
.36721 .52199 .374 .52783 .3849 .52869 .37812 .52294 Mtetra
.393 .667 .969 r
.37812 .52294 .3849 .52869 .39586 .52972 .38911 .52403 Mtetra
.375 .661 .969 r
.38911 .52403 .39586 .52972 .4069 .53093 .40016 .5253 Mtetra
.354 .654 .968 r
.40016 .5253 .4069 .53093 .41801 .53237 .41129 .52677 Mtetra
.332 .644 .966 r
.41129 .52677 .41801 .53237 .42918 .53408 .42249 .52847 Mtetra
.309 .632 .963 r
.42249 .52847 .42918 .53408 .44044 .53608 .43377 .53044 Mtetra
.284 .617 .958 r
.43377 .53044 .44044 .53608 .45177 .53844 .44512 .5327 Mtetra
.259 .6 .952 r
.44512 .5327 .45177 .53844 .46318 .54119 .45656 .5353 Mtetra
.235 .582 .944 r
.45656 .5353 .46318 .54119 .47468 .5444 .46808 .53828 Mtetra
.214 .561 .936 r
.46808 .53828 .47468 .5444 .48627 .54811 .4797 .54166 Mtetra
.198 .539 .926 r
.4797 .54166 .48627 .54811 .49796 .5524 .4914 .5455 Mtetra
.188 .517 .916 r
.4914 .5455 .49796 .5524 .50975 .55735 .50321 .54982 Mtetra
.187 .495 .904 r
.50321 .54982 .50975 .55735 .52164 .563 .51512 .55467 Mtetra
.195 .474 .891 r
.51512 .55467 .52164 .563 .53366 .56952 .52715 .56005 Mtetra
.217 .455 .873 r
.52715 .56005 .53366 .56952 .54581 .57697 .5393 .56602 Mtetra
.249 .437 .85 r
.5393 .56602 .54581 .57697 .55811 .58557 .55157 .57258 Mtetra
.297 .424 .822 r
.55157 .57258 .55811 .58557 .57056 .59588 .56398 .57959 Mtetra
.241 .338 .763 r
.56398 .57959 .57056 .59588 .58332 .61427 .57657 .59007 Mtetra
.444 .399 .713 r
.57657 .59007 .58332 .61427 .5962 .6288 .58927 .59746 Mtetra
.606 .474 .675 r
.58927 .59746 .5962 .6288 .60884 .6252 .60185 .5938 Mtetra
.692 .529 .662 r
.60185 .5938 .60884 .6252 .62103 .60339 .6142 .57904 Mtetra
.74 .58 .677 r
.6142 .57904 .62103 .60339 .63301 .57762 .62643 .56113 Mtetra
.761 .635 .721 r
.62643 .56113 .63301 .57762 .64517 .55989 .63873 .54664 Mtetra
.783 .675 .745 r
.63873 .54664 .64517 .55989 .65735 .54383 .65102 .53257 Mtetra
.796 .704 .764 r
.65102 .53257 .65735 .54383 .66954 .52888 .66331 .51904 Mtetra
.805 .73 .781 r
.66331 .51904 .66954 .52888 .68174 .51481 .67561 .50607 Mtetra
.812 .752 .797 r
.67561 .50607 .68174 .51481 .69396 .50159 .68792 .4936 Mtetra
.815 .77 .811 r
.68792 .4936 .69396 .50159 .70621 .48905 .70025 .48163 Mtetra
.816 .785 .823 r
.70025 .48163 .70621 .48905 .71848 .47714 .7126 .47012 Mtetra
.815 .796 .834 r
.7126 .47012 .71848 .47714 .73078 .46578 .72498 .45904 Mtetra
.812 .804 .843 r
.72498 .45904 .73078 .46578 .74312 .45491 .73738 .44835 Mtetra
.809 .81 .851 r
.73738 .44835 .74312 .45491 .75549 .44448 .74981 .43801 Mtetra
.805 .813 .857 r
.74981 .43801 .75549 .44448 .76789 .43442 .76227 .42798 Mtetra
.801 .815 .863 r
.76227 .42798 .76789 .43442 .78033 .4247 .77477 .41824 Mtetra
.797 .815 .866 r
.77477 .41824 .78033 .4247 .79281 .41527 .7873 .40875 Mtetra
.792 .814 .869 r
.7873 .40875 .79281 .41527 .80532 .40608 .79986 .39948 Mtetra
.788 .812 .871 r
.79986 .39948 .80532 .40608 .81787 .39711 .81245 .39039 Mtetra
.784 .809 .872 r
.81245 .39039 .81787 .39711 .83046 .38831 .82508 .38145 Mtetra
.781 .805 .873 r
.82508 .38145 .83046 .38831 .84308 .37965 .83775 .37265 Mtetra
.777 .802 .872 r
.83775 .37265 .84308 .37965 .85574 .37111 .85044 .36394 Mtetra
.775 .797 .871 r
.85044 .36394 .85574 .37111 .86843 .36266 .86317 .35532 Mtetra
.772 .793 .87 r
.86317 .35532 .86843 .36266 .88115 .35426 .87592 .34675 Mtetra
.77 .789 .868 r
.87592 .34675 .88115 .35426 .8939 .3459 .88871 .33821 Mtetra
.768 .784 .866 r
.88871 .33821 .8939 .3459 .90668 .33755 .90152 .32967 Mtetra
.449 .666 .955 r
.30675 .51212 .31365 .51855 .32423 .51914 .31734 .5128 Mtetra
.444 .668 .957 r
.31734 .5128 .32423 .51914 .33487 .51976 .32799 .51351 Mtetra
.437 .669 .96 r
.32799 .51351 .33487 .51976 .34558 .52042 .33871 .51426 Mtetra
.429 .669 .962 r
.33871 .51426 .34558 .52042 .35636 .52116 .34951 .51508 Mtetra
.419 .668 .964 r
.34951 .51508 .35636 .52116 .36721 .52199 .36037 .51598 Mtetra
.407 .666 .966 r
.36037 .51598 .36721 .52199 .37812 .52294 .3713 .51699 Mtetra
.394 .662 .966 r
.3713 .51699 .37812 .52294 .38911 .52403 .3823 .51813 Mtetra
.379 .657 .967 r
.3823 .51813 .38911 .52403 .40016 .5253 .39338 .51943 Mtetra
.363 .651 .966 r
.39338 .51943 .40016 .5253 .41129 .52677 .40452 .5209 Mtetra
.346 .643 .965 r
.40452 .5209 .41129 .52677 .42249 .52847 .41575 .52257 Mtetra
.328 .633 .962 r
.41575 .52257 .42249 .52847 .43377 .53044 .42705 .52446 Mtetra
.311 .622 .959 r
.42705 .52446 .43377 .53044 .44512 .5327 .43843 .5266 Mtetra
.295 .608 .954 r
.43843 .5266 .44512 .5327 .45656 .5353 .44989 .52902 Mtetra
.281 .594 .949 r
.44989 .52902 .45656 .5353 .46808 .53828 .46143 .53173 Mtetra
.27 .579 .942 r
.46143 .53173 .46808 .53828 .4797 .54166 .47307 .53475 Mtetra
.265 .564 .935 r
.47307 .53475 .4797 .54166 .4914 .5455 .4848 .53811 Mtetra
.268 .549 .926 r
.4848 .53811 .4914 .5455 .50321 .54982 .49663 .54177 Mtetra
.275 .532 .915 r
.49663 .54177 .50321 .54982 .51512 .55467 .50856 .5458 Mtetra
.297 .521 .901 r
.50856 .5458 .51512 .55467 .52715 .56005 .5206 .55008 Mtetra
.325 .506 .882 r
.5206 .55008 .52715 .56005 .5393 .56602 .53275 .55461 Mtetra
.363 .495 .858 r
.53275 .55461 .5393 .56602 .55157 .57258 .54501 .55925 Mtetra
.424 .494 .827 r
.54501 .55925 .55157 .57258 .56398 .57959 .55738 .56338 Mtetra
.46 .475 .787 r
.55738 .56338 .56398 .57959 .57657 .59007 .56986 .56747 Mtetra
.54 .468 .724 r
.56986 .56747 .57657 .59007 .58927 .59746 .58242 .5692 Mtetra
.61 .486 .687 r
.58242 .5692 .58927 .59746 .60185 .5938 .59496 .56548 Mtetra
.661 .518 .679 r
.59496 .56548 .60185 .5938 .6142 .57904 .60743 .5563 Mtetra
.701 .565 .698 r
.60743 .5563 .6142 .57904 .62643 .56113 .61985 .54471 Mtetra
.736 .624 .734 r
.61985 .54471 .62643 .56113 .63873 .54664 .63226 .53304 Mtetra
.762 .663 .753 r
.63226 .53304 .63873 .54664 .65102 .53257 .64464 .52083 Mtetra
.778 .693 .77 r
.64464 .52083 .65102 .53257 .66331 .51904 .65703 .50869 Mtetra
.789 .718 .786 r
.65703 .50869 .66331 .51904 .67561 .50607 .66942 .49678 Mtetra
.797 .74 .799 r
.66942 .49678 .67561 .50607 .68792 .4936 .68181 .48507 Mtetra
.801 .757 .812 r
.68181 .48507 .68792 .4936 .70025 .48163 .69422 .4737 Mtetra
.805 .772 .823 r
.69422 .4737 .70025 .48163 .7126 .47012 .70665 .46262 Mtetra
.805 .784 .833 r
.70665 .46262 .7126 .47012 .72498 .45904 .71909 .45185 Mtetra
.804 .793 .841 r
.71909 .45185 .72498 .45904 .73738 .44835 .73156 .44136 Mtetra
.803 .799 .848 r
.73156 .44136 .73738 .44835 .74981 .43801 .74406 .43115 Mtetra
.8 .803 .854 r
.74406 .43115 .74981 .43801 .76227 .42798 .75658 .4212 Mtetra
.797 .806 .859 r
.75658 .4212 .76227 .42798 .77477 .41824 .76913 .41147 Mtetra
.794 .807 .863 r
.76913 .41147 .77477 .41824 .7873 .40875 .78171 .40195 Mtetra
.791 .807 .865 r
.78171 .40195 .7873 .40875 .79986 .39948 .79433 .39261 Mtetra
.787 .806 .867 r
.79433 .39261 .79986 .39948 .81245 .39039 .80697 .38344 Mtetra
.784 .804 .869 r
.80697 .38344 .81245 .39039 .82508 .38145 .81965 .37439 Mtetra
.781 .801 .869 r
.81965 .37439 .82508 .38145 .83775 .37265 .83235 .36546 Mtetra
.778 .798 .869 r
.83235 .36546 .83775 .37265 .85044 .36394 .84509 .35662 Mtetra
.776 .795 .869 r
.84509 .35662 .85044 .36394 .86317 .35532 .85785 .34785 Mtetra
.774 .792 .868 r
.85785 .34785 .86317 .35532 .87592 .34675 .87065 .33913 Mtetra
.772 .788 .866 r
.87065 .33913 .87592 .34675 .88871 .33821 .88347 .33043 Mtetra
.771 .784 .864 r
.88347 .33043 .88871 .33821 .90152 .32967 .89632 .32173 Mtetra
.442 .663 .955 r
.29979 .50564 .30675 .51212 .31734 .5128 .31039 .5064 Mtetra
.438 .664 .957 r
.31039 .5064 .31734 .5128 .32799 .51351 .32106 .50718 Mtetra
.432 .665 .959 r
.32106 .50718 .32799 .51351 .33871 .51426 .33179 .508 Mtetra
.425 .665 .961 r
.33179 .508 .33871 .51426 .34951 .51508 .3426 .50887 Mtetra
.417 .664 .962 r
.3426 .50887 .34951 .51508 .36037 .51598 .35348 .50983 Mtetra
.407 .662 .964 r
.35348 .50983 .36037 .51598 .3713 .51699 .36443 .51088 Mtetra
.396 .659 .964 r
.36443 .51088 .3713 .51699 .3823 .51813 .37545 .51204 Mtetra
.384 .654 .964 r
.37545 .51204 .3823 .51813 .39338 .51943 .38654 .51334 Mtetra
.372 .649 .964 r
.38654 .51334 .39338 .51943 .40452 .5209 .39771 .51479 Mtetra
.359 .642 .963 r
.39771 .51479 .40452 .5209 .41575 .52257 .40896 .5164 Mtetra
.346 .634 .961 r
.40896 .5164 .41575 .52257 .42705 .52446 .42028 .5182 Mtetra
.335 .626 .958 r
.42028 .5182 .42705 .52446 .43843 .5266 .43168 .5202 Mtetra
.325 .615 .954 r
.43168 .5202 .43843 .5266 .44989 .52902 .44317 .52241 Mtetra
.318 .605 .95 r
.44317 .52241 .44989 .52902 .46143 .53173 .45474 .52485 Mtetra
.315 .594 .944 r
.45474 .52485 .46143 .53173 .47307 .53475 .4664 .5275 Mtetra
.317 .583 .938 r
.4664 .5275 .47307 .53475 .4848 .53811 .47815 .53038 Mtetra
.327 .573 .929 r
.47815 .53038 .4848 .53811 .49663 .54177 .49 .53343 Mtetra
.339 .56 .918 r
.49 .53343 .49663 .54177 .50856 .5458 .50195 .53669 Mtetra
.364 .552 .904 r
.50195 .53669 .50856 .5458 .5206 .55008 .514 .53999 Mtetra
.392 .542 .886 r
.514 .53999 .5206 .55008 .53275 .55461 .52616 .54331 Mtetra
.427 .534 .864 r
.52616 .54331 .53275 .55461 .54501 .55925 .53842 .54646 Mtetra
.478 .534 .837 r
.53842 .54646 .54501 .55925 .55738 .56338 .55078 .54886 Mtetra
.519 .531 .808 r
.55078 .54886 .55738 .56338 .56986 .56747 .56323 .55037 Mtetra
.571 .53 .77 r
.56323 .55037 .56986 .56747 .58242 .5692 .57574 .54998 Mtetra
.626 .544 .741 r
.57574 .54998 .58242 .5692 .59496 .56548 .58827 .54622 Mtetra
.671 .568 .731 r
.58827 .54622 .59496 .56548 .60743 .5563 .60079 .53906 Mtetra
.703 .601 .739 r
.60079 .53906 .60743 .5563 .61985 .54471 .61328 .52999 Mtetra
.729 .638 .756 r
.61328 .52999 .61985 .54471 .63226 .53304 .62577 .51999 Mtetra
.751 .666 .767 r
.62577 .51999 .63226 .53304 .64464 .52083 .63824 .50921 Mtetra
.766 .691 .78 r
.63824 .50921 .64464 .52083 .65703 .50869 .65071 .49822 Mtetra
.777 .714 .793 r
.65071 .49822 .65703 .50869 .66942 .49678 .66317 .48722 Mtetra
.786 .733 .804 r
.66317 .48722 .66942 .49678 .68181 .48507 .67565 .47624 Mtetra
.791 .75 .815 r
.67565 .47624 .68181 .48507 .69422 .4737 .68813 .46543 Mtetra
.795 .764 .824 r
.68813 .46543 .69422 .4737 .70665 .46262 .70063 .45477 Mtetra
.797 .775 .833 r
.70063 .45477 .70665 .46262 .71909 .45185 .71315 .44431 Mtetra
.797 .784 .84 r
.71315 .44431 .71909 .45185 .73156 .44136 .72568 .43405 Mtetra
.797 .791 .847 r
.72568 .43405 .73156 .44136 .74406 .43115 .73824 .42398 Mtetra
.795 .796 .852 r
.73824 .42398 .74406 .43115 .75658 .4212 .75082 .41411 Mtetra
.794 .799 .856 r
.75082 .41411 .75658 .4212 .76913 .41147 .76343 .40442 Mtetra
.791 .8 .86 r
.76343 .40442 .76913 .41147 .78171 .40195 .77607 .39489 Mtetra
.789 .801 .862 r
.77607 .39489 .78171 .40195 .79433 .39261 .78873 .38552 Mtetra
.786 .801 .864 r
.78873 .38552 .79433 .39261 .80697 .38344 .80143 .37627 Mtetra
.783 .8 .866 r
.80143 .37627 .80697 .38344 .81965 .37439 .81415 .36714 Mtetra
.781 .798 .866 r
.81415 .36714 .81965 .37439 .83235 .36546 .8269 .35811 Mtetra
.779 .796 .866 r
.8269 .35811 .83235 .36546 .84509 .35662 .83968 .34915 Mtetra
.777 .793 .866 r
.83968 .34915 .84509 .35662 .85785 .34785 .85249 .34025 Mtetra
.775 .79 .865 r
.85249 .34025 .85785 .34785 .87065 .33913 .86532 .3314 Mtetra
.773 .787 .864 r
.86532 .3314 .87065 .33913 .88347 .33043 .87818 .32256 Mtetra
.772 .784 .863 r
.87818 .32256 .88347 .33043 .89632 .32173 .89107 .31372 Mtetra
.437 .66 .955 r
.29278 .49911 .29979 .50564 .31039 .5064 .30339 .49992 Mtetra
.433 .661 .957 r
.30339 .49992 .31039 .5064 .32106 .50718 .31407 .50076 Mtetra
.428 .662 .958 r
.31407 .50076 .32106 .50718 .33179 .508 .32482 .50163 Mtetra
.422 .662 .96 r
.32482 .50163 .33179 .508 .3426 .50887 .33565 .50255 Mtetra
.415 .66 .961 r
.33565 .50255 .3426 .50887 .35348 .50983 .34654 .50354 Mtetra
.407 .659 .962 r
.34654 .50354 .35348 .50983 .36443 .51088 .35751 .50461 Mtetra
.399 .656 .962 r
.35751 .50461 .36443 .51088 .37545 .51204 .36855 .50578 Mtetra
.389 .652 .962 r
.36855 .50578 .37545 .51204 .38654 .51334 .37966 .50706 Mtetra
.38 .648 .962 r
.37966 .50706 .38654 .51334 .39771 .51479 .39085 .50847 Mtetra
.371 .643 .961 r
.39085 .50847 .39771 .51479 .40896 .5164 .40212 .51001 Mtetra
.362 .636 .959 r
.40212 .51001 .40896 .5164 .42028 .5182 .41346 .51171 Mtetra
.356 .63 .957 r
.41346 .51171 .42028 .5182 .43168 .5202 .42489 .51355 Mtetra
.35 .622 .953 r
.42489 .51355 .43168 .5202 .44317 .52241 .4364 .51555 Mtetra
.349 .614 .95 r
.4364 .51555 .44317 .52241 .45474 .52485 .448 .5177 Mtetra
.351 .606 .945 r
.448 .5177 .45474 .52485 .4664 .5275 .45968 .51999 Mtetra
.358 .598 .938 r
.45968 .51999 .4664 .5275 .47815 .53038 .47146 .52241 Mtetra
.372 .591 .93 r
.47146 .52241 .47815 .53038 .49 .53343 .48333 .52489 Mtetra
.388 .582 .919 r
.48333 .52489 .49 .53343 .50195 .53669 .4953 .52743 Mtetra
.414 .577 .905 r
.4953 .52743 .50195 .53669 .514 .53999 .50737 .52987 Mtetra
.442 .57 .887 r
.50737 .52987 .514 .53999 .52616 .54331 .51953 .53214 Mtetra
.474 .564 .866 r
.51953 .53214 .52616 .54331 .53842 .54646 .5318 .53405 Mtetra
.515 .562 .841 r
.5318 .53405 .53842 .54646 .55078 .54886 .54415 .5352 Mtetra
.549 .56 .818 r
.54415 .5352 .55078 .54886 .56323 .55037 .55659 .53543 Mtetra
.588 .564 .795 r
.55659 .53543 .56323 .55037 .57574 .54998 .5691 .53411 Mtetra
.635 .579 .774 r
.5691 .53411 .57574 .54998 .58827 .54622 .58163 .53031 Mtetra
.674 .599 .763 r
.58163 .53031 .58827 .54622 .60079 .53906 .59418 .524 Mtetra
.701 .621 .764 r
.59418 .524 .60079 .53906 .61328 .52999 .60672 .51614 Mtetra
.721 .644 .772 r
.60672 .51614 .61328 .52999 .62577 .51999 .61926 .50731 Mtetra
.74 .667 .779 r
.61926 .50731 .62577 .51999 .63824 .50921 .6318 .49771 Mtetra
.754 .69 .79 r
.6318 .49771 .63824 .50921 .65071 .49822 .64434 .48772 Mtetra
.766 .711 .8 r
.64434 .48772 .65071 .49822 .66317 .48722 .65688 .47752 Mtetra
.776 .729 .81 r
.65688 .47752 .66317 .48722 .67565 .47624 .66943 .4672 Mtetra
.782 .745 .819 r
.66943 .4672 .67565 .47624 .68813 .46543 .68199 .45691 Mtetra
.787 .758 .827 r
.68199 .45691 .68813 .46543 .70063 .45477 .69455 .44665 Mtetra
.79 .769 .834 r
.69455 .44665 .70063 .45477 .71315 .44431 .70714 .4365 Mtetra
.791 .778 .84 r
.70714 .4365 .71315 .44431 .72568 .43405 .71974 .42646 Mtetra
.792 .784 .846 r
.71974 .42646 .72568 .43405 .73824 .42398 .73236 .41654 Mtetra
.791 .789 .851 r
.73236 .41654 .73824 .42398 .75082 .41411 .745 .40677 Mtetra
.79 .793 .855 r
.745 .40677 .75082 .41411 .76343 .40442 .75767 .39713 Mtetra
.789 .795 .858 r
.75767 .39713 .76343 .40442 .77607 .39489 .77036 .38761 Mtetra
.787 .796 .86 r
.77036 .38761 .77607 .39489 .78873 .38552 .78308 .37821 Mtetra
.785 .796 .862 r
.78308 .37821 .78873 .38552 .80143 .37627 .79582 .36892 Mtetra
.783 .796 .863 r
.79582 .36892 .80143 .37627 .81415 .36714 .80859 .35972 Mtetra
.781 .795 .864 r
.80859 .35972 .81415 .36714 .8269 .35811 .82139 .3506 Mtetra
.779 .793 .864 r
.82139 .3506 .8269 .35811 .83968 .34915 .83422 .34155 Mtetra
.777 .791 .864 r
.83422 .34155 .83968 .34915 .85249 .34025 .84707 .33254 Mtetra
.776 .789 .864 r
.84707 .33254 .85249 .34025 .86532 .3314 .85995 .32356 Mtetra
.775 .787 .863 r
.85995 .32356 .86532 .3314 .87818 .32256 .87285 .3146 Mtetra
.774 .784 .862 r
.87285 .3146 .87818 .32256 .89107 .31372 .88578 .30565 Mtetra
.433 .659 .955 r
.28572 .49254 .29278 .49911 .30339 .49992 .29634 .49339 Mtetra
.429 .659 .957 r
.29634 .49339 .30339 .49992 .31407 .50076 .30704 .49426 Mtetra
.425 .659 .958 r
.30704 .49426 .31407 .50076 .32482 .50163 .3178 .49516 Mtetra
.42 .659 .959 r
.3178 .49516 .32482 .50163 .33565 .50255 .32864 .49611 Mtetra
.415 .658 .96 r
.32864 .49611 .33565 .50255 .34654 .50354 .33955 .49712 Mtetra
.408 .656 .96 r
.33955 .49712 .34654 .50354 .35751 .50461 .35053 .4982 Mtetra
.401 .654 .961 r
.35053 .4982 .35751 .50461 .36855 .50578 .36159 .49937 Mtetra
.394 .651 .961 r
.36159 .49937 .36855 .50578 .37966 .50706 .37272 .50062 Mtetra
.387 .647 .96 r
.37272 .50062 .37966 .50706 .39085 .50847 .38394 .50198 Mtetra
.381 .643 .959 r
.38394 .50198 .39085 .50847 .40212 .51001 .39522 .50345 Mtetra
.375 .638 .958 r
.39522 .50345 .40212 .51001 .41346 .51171 .40659 .50503 Mtetra
.372 .633 .956 r
.40659 .50503 .41346 .51171 .42489 .51355 .41804 .50672 Mtetra
.37 .628 .953 r
.41804 .50672 .42489 .51355 .4364 .51555 .42958 .50852 Mtetra
.372 .622 .949 r
.42958 .50852 .4364 .51555 .448 .5177 .4412 .5104 Mtetra
.378 .617 .945 r
.4412 .5104 .448 .5177 .45968 .51999 .45291 .51236 Mtetra
.387 .611 .939 r
.45291 .51236 .45968 .51999 .47146 .52241 .46472 .51437 Mtetra
.403 .607 .931 r
.46472 .51437 .47146 .52241 .48333 .52489 .47661 .51635 Mtetra
.42 .601 .921 r
.47661 .51635 .48333 .52489 .4953 .52743 .4886 .51828 Mtetra
.446 .598 .908 r
.4886 .51828 .4953 .52743 .50737 .52987 .50069 .52001 Mtetra
.473 .594 .893 r
.50069 .52001 .50737 .52987 .51953 .53214 .51287 .52145 Mtetra
.503 .591 .875 r
.51287 .52145 .51953 .53214 .5318 .53405 .52514 .52242 Mtetra
.538 .59 .854 r
.52514 .52242 .5318 .53405 .54415 .5352 .53751 .52264 Mtetra
.571 .59 .833 r
.53751 .52264 .54415 .5352 .55659 .53543 .54995 .52188 Mtetra
.604 .592 .812 r
.54995 .52188 .55659 .53543 .5691 .53411 .56245 .51985 Mtetra
.64 .6 .794 r
.56245 .51985 .5691 .53411 .58163 .53031 .575 .516 Mtetra
.672 .616 .784 r
.575 .516 .58163 .53031 .59418 .524 .58757 .51034 Mtetra
.695 .635 .785 r
.58757 .51034 .59418 .524 .60672 .51614 .60015 .50339 Mtetra
.716 .657 .79 r
.60015 .50339 .60672 .51614 .61926 .50731 .61275 .49543 Mtetra
.734 .677 .795 r
.61275 .49543 .61926 .50731 .6318 .49771 .62535 .48669 Mtetra
.748 .697 .803 r
.62535 .48669 .6318 .49771 .64434 .48772 .63795 .47747 Mtetra
.759 .715 .81 r
.63795 .47747 .64434 .48772 .65688 .47752 .65056 .46793 Mtetra
.769 .73 .817 r
.65056 .46793 .65688 .47752 .66943 .4672 .66317 .45815 Mtetra
.775 .744 .825 r
.66317 .45815 .66943 .4672 .68199 .45691 .67579 .4483 Mtetra
.781 .756 .831 r
.67579 .4483 .68199 .45691 .69455 .44665 .68843 .4384 Mtetra
.784 .766 .837 r
.68843 .4384 .69455 .44665 .70714 .4365 .70107 .42852 Mtetra
.786 .774 .842 r
.70107 .42852 .70714 .4365 .71974 .42646 .71374 .41868 Mtetra
.787 .78 .846 r
.71374 .41868 .71974 .42646 .73236 .41654 .72642 .40892 Mtetra
.787 .785 .85 r
.72642 .40892 .73236 .41654 .745 .40677 .73912 .39924 Mtetra
.787 .789 .854 r
.73912 .39924 .745 .40677 .75767 .39713 .75185 .38964 Mtetra
.786 .791 .856 r
.75185 .38964 .75767 .39713 .77036 .38761 .76459 .38014 Mtetra
.785 .792 .859 r
.76459 .38014 .77036 .38761 .78308 .37821 .77737 .37073 Mtetra
.784 .793 .86 r
.77737 .37073 .78308 .37821 .79582 .36892 .79016 .3614 Mtetra
.782 .793 .861 r
.79016 .3614 .79582 .36892 .80859 .35972 .80298 .35215 Mtetra
.781 .792 .862 r
.80298 .35215 .80859 .35972 .82139 .3506 .81583 .34295 Mtetra
.779 .791 .863 r
.81583 .34295 .82139 .3506 .83422 .34155 .8287 .33381 Mtetra
.778 .79 .863 r
.8287 .33381 .83422 .34155 .84707 .33254 .8416 .32471 Mtetra
.777 .788 .862 r
.8416 .32471 .84707 .33254 .85995 .32356 .85453 .31563 Mtetra
.775 .786 .862 r
.85453 .31563 .85995 .32356 .87285 .3146 .86747 .30657 Mtetra
.775 .784 .861 r
.86747 .30657 .87285 .3146 .88578 .30565 .88044 .2975 Mtetra
.429 .657 .955 r
.2786 .48591 .28572 .49254 .29634 .49339 .28924 .48679 Mtetra
.426 .657 .956 r
.28924 .48679 .29634 .49339 .30704 .49426 .29995 .48768 Mtetra
.423 .657 .957 r
.29995 .48768 .30704 .49426 .3178 .49516 .31073 .48861 Mtetra
.419 .657 .958 r
.31073 .48861 .3178 .49516 .32864 .49611 .32158 .48958 Mtetra
.415 .656 .959 r
.32158 .48958 .32864 .49611 .33955 .49712 .33251 .49059 Mtetra
.409 .655 .959 r
.33251 .49059 .33955 .49712 .35053 .4982 .34351 .49167 Mtetra
.404 .653 .959 r
.34351 .49167 .35053 .4982 .36159 .49937 .35459 .49282 Mtetra
.399 .65 .959 r
.35459 .49282 .36159 .49937 .37272 .50062 .36574 .49404 Mtetra
.394 .647 .959 r
.36574 .49404 .37272 .50062 .38394 .50198 .37697 .49534 Mtetra
.39 .644 .958 r
.37697 .49534 .38394 .50198 .39522 .50345 .38828 .49673 Mtetra
.387 .64 .956 r
.38828 .49673 .39522 .50345 .40659 .50503 .39967 .4982 Mtetra
.386 .637 .955 r
.39967 .4982 .40659 .50503 .41804 .50672 .41115 .49974 Mtetra
.387 .633 .952 r
.41115 .49974 .41804 .50672 .42958 .50852 .42271 .50135 Mtetra
.391 .629 .949 r
.42271 .50135 .42958 .50852 .4412 .5104 .43436 .50299 Mtetra
.399 .626 .945 r
.43436 .50299 .4412 .5104 .45291 .51236 .44609 .50465 Mtetra
.41 .622 .939 r
.44609 .50465 .45291 .51236 .46472 .51437 .45792 .5063 Mtetra
.427 .62 .932 r
.45792 .5063 .46472 .51437 .47661 .51635 .46984 .50784 Mtetra
.445 .617 .923 r
.46984 .50784 .47661 .51635 .4886 .51828 .48185 .50926 Mtetra
.47 .615 .912 r
.48185 .50926 .4886 .51828 .50069 .52001 .49396 .51041 Mtetra
.496 .613 .898 r
.49396 .51041 .50069 .52001 .51287 .52145 .50616 .5112 Mtetra
.524 .612 .882 r
.50616 .5112 .51287 .52145 .52514 .52242 .51845 .51148 Mtetra
.555 .613 .865 r
.51845 .51148 .52514 .52242 .53751 .52264 .53083 .51103 Mtetra
.586 .615 .848 r
.53083 .51103 .53751 .52264 .54995 .52188 .54328 .50963 Mtetra
.615 .618 .831 r
.54328 .50963 .54995 .52188 .56245 .51985 .55579 .50715 Mtetra
.645 .626 .816 r
.55579 .50715 .56245 .51985 .575 .516 .56836 .50327 Mtetra
.672 .638 .807 r
.56836 .50327 .575 .516 .58757 .51034 .58095 .49798 Mtetra
.694 .654 .806 r
.58095 .49798 .58757 .51034 .60015 .50339 .59358 .49158 Mtetra
.713 .671 .807 r
.59358 .49158 .60015 .50339 .61275 .49543 .60622 .48423 Mtetra
.73 .688 .81 r
.60622 .48423 .61275 .49543 .62535 .48669 .61886 .47612 Mtetra
.743 .704 .815 r
.61886 .47612 .62535 .48669 .63795 .47747 .63152 .46749 Mtetra
.754 .719 .82 r
.63152 .46749 .63795 .47747 .65056 .46793 .64419 .45846 Mtetra
.763 .733 .825 r
.64419 .45846 .65056 .46793 .66317 .45815 .65686 .44914 Mtetra
.77 .745 .83 r
.65686 .44914 .66317 .45815 .67579 .4483 .66955 .43966 Mtetra
.776 .755 .835 r
.66955 .43966 .67579 .4483 .68843 .4384 .68225 .43006 Mtetra
.779 .764 .839 r
.68225 .43006 .68843 .4384 .70107 .42852 .69496 .42042 Mtetra
.782 .772 .844 r
.69496 .42042 .70107 .42852 .71374 .41868 .70768 .41077 Mtetra
.784 .778 .847 r
.70768 .41077 .71374 .41868 .72642 .40892 .72042 .40113 Mtetra
.784 .782 .851 r
.72042 .40113 .72642 .40892 .73912 .39924 .73319 .39154 Mtetra
.785 .786 .853 r
.73319 .39154 .73912 .39924 .75185 .38964 .74597 .38199 Mtetra
.784 .788 .856 r
.74597 .38199 .75185 .38964 .76459 .38014 .75877 .37251 Mtetra
.783 .789 .858 r
.75877 .37251 .76459 .38014 .77737 .37073 .77159 .36309 Mtetra
.782 .79 .859 r
.77159 .36309 .77737 .37073 .79016 .3614 .78444 .35373 Mtetra
.781 .79 .86 r
.78444 .35373 .79016 .3614 .80298 .35215 .79732 .34443 Mtetra
.78 .79 .861 r
.79732 .34443 .80298 .35215 .81583 .34295 .81021 .33517 Mtetra
.779 .789 .861 r
.81021 .33517 .81583 .34295 .8287 .33381 .82314 .32595 Mtetra
.778 .788 .861 r
.82314 .32595 .8287 .33381 .8416 .32471 .83608 .31677 Mtetra
.777 .787 .861 r
.83608 .31677 .8416 .32471 .85453 .31563 .84905 .3076 Mtetra
.776 .786 .861 r
.84905 .3076 .85453 .31563 .86747 .30657 .86205 .29845 Mtetra
.775 .784 .86 r
.86205 .29845 .86747 .30657 .88044 .2975 .87506 .28929 Mtetra
.426 .656 .955 r
.27143 .47923 .2786 .48591 .28924 .48679 .28208 .48012 Mtetra
.424 .656 .956 r
.28208 .48012 .28924 .48679 .29995 .48768 .2928 .48103 Mtetra
.422 .656 .957 r
.2928 .48103 .29995 .48768 .31073 .48861 .3036 .48197 Mtetra
.418 .656 .957 r
.3036 .48197 .31073 .48861 .32158 .48958 .31447 .48294 Mtetra
.415 .655 .958 r
.31447 .48294 .32158 .48958 .33251 .49059 .32541 .48396 Mtetra
.411 .653 .958 r
.32541 .48396 .33251 .49059 .34351 .49167 .33643 .48503 Mtetra
.407 .652 .958 r
.33643 .48503 .34351 .49167 .35459 .49282 .34753 .48615 Mtetra
.403 .65 .958 r
.34753 .48615 .35459 .49282 .36574 .49404 .3587 .48734 Mtetra
.399 .648 .958 r
.3587 .48734 .36574 .49404 .37697 .49534 .36995 .48858 Mtetra
.397 .645 .957 r
.36995 .48858 .37697 .49534 .38828 .49673 .38129 .48989 Mtetra
.396 .642 .956 r
.38129 .48989 .38828 .49673 .39967 .4982 .3927 .49126 Mtetra
.397 .64 .954 r
.3927 .49126 .39967 .4982 .41115 .49974 .4042 .49266 Mtetra
.399 .637 .952 r
.4042 .49266 .41115 .49974 .42271 .50135 .41578 .4941 Mtetra
.405 .635 .949 r
.41578 .4941 .42271 .50135 .43436 .50299 .42746 .49553 Mtetra
.415 .634 .945 r
.42746 .49553 .43436 .50299 .44609 .50465 .43922 .49693 Mtetra
.427 .632 .94 r
.43922 .49693 .44609 .50465 .45792 .5063 .45107 .49827 Mtetra
.444 .631 .934 r
.45107 .49827 .45792 .5063 .46984 .50784 .46302 .49945 Mtetra
.463 .63 .926 r
.46302 .49945 .46984 .50784 .48185 .50926 .47506 .50045 Mtetra
.486 .631 .916 r
.47506 .50045 .48185 .50926 .49396 .51041 .48719 .50114 Mtetra
.512 .631 .905 r
.48719 .50114 .49396 .51041 .50616 .5112 .49941 .50142 Mtetra
.538 .632 .891 r
.49941 .50142 .50616 .5112 .51845 .51148 .51172 .50117 Mtetra
.567 .633 .877 r
.51172 .50117 .51845 .51148 .53083 .51103 .52411 .50023 Mtetra
.595 .637 .862 r
.52411 .50023 .53083 .51103 .54328 .50963 .53658 .49843 Mtetra
.621 .641 .849 r
.53658 .49843 .54328 .50963 .55579 .50715 .54911 .49568 Mtetra
.649 .649 .837 r
.54911 .49568 .55579 .50715 .56836 .50327 .5617 .49176 Mtetra
.674 .66 .828 r
.5617 .49176 .56836 .50327 .58095 .49798 .57432 .48667 Mtetra
.694 .672 .824 r
.57432 .48667 .58095 .49798 .59358 .49158 .58698 .48061 Mtetra
.712 .685 .823 r
.58698 .48061 .59358 .49158 .60622 .48423 .59966 .47367 Mtetra
.727 .699 .824 r
.59966 .47367 .60622 .48423 .61886 .47612 .61235 .46602 Mtetra
.74 .713 .826 r
.61235 .46602 .61886 .47612 .63152 .46749 .62507 .45783 Mtetra
.75 .726 .829 r
.62507 .45783 .63152 .46749 .64419 .45846 .63779 .4492 Mtetra
.759 .737 .832 r
.63779 .4492 .64419 .45846 .65686 .44914 .65052 .44024 Mtetra
.766 .748 .836 r
.65052 .44024 .65686 .44914 .66955 .43966 .66327 .43106 Mtetra
.772 .757 .839 r
.66327 .43106 .66955 .43966 .68225 .43006 .67602 .42171 Mtetra
.776 .765 .843 r
.67602 .42171 .68225 .43006 .69496 .42042 .68879 .41226 Mtetra
.779 .771 .846 r
.68879 .41226 .69496 .42042 .70768 .41077 .70158 .40276 Mtetra
.781 .776 .849 r
.70158 .40276 .70768 .41077 .72042 .40113 .71438 .39323 Mtetra
.782 .78 .851 r
.71438 .39323 .72042 .40113 .73319 .39154 .72719 .38371 Mtetra
.783 .784 .853 r
.72719 .38371 .73319 .39154 .74597 .38199 .74003 .37421 Mtetra
.782 .786 .855 r
.74003 .37421 .74597 .38199 .75877 .37251 .75289 .36474 Mtetra
.782 .787 .857 r
.75289 .36474 .75877 .37251 .77159 .36309 .76577 .35531 Mtetra
.782 .788 .858 r
.76577 .35531 .77159 .36309 .78444 .35373 .77867 .34592 Mtetra
.781 .788 .859 r
.77867 .34592 .78444 .35373 .79732 .34443 .7916 .33658 Mtetra
.78 .788 .86 r
.7916 .33658 .79732 .34443 .81021 .33517 .80454 .32727 Mtetra
.779 .788 .86 r
.80454 .32727 .81021 .33517 .82314 .32595 .81752 .31799 Mtetra
.778 .787 .86 r
.81752 .31799 .82314 .32595 .83608 .31677 .83051 .30873 Mtetra
.777 .786 .86 r
.83051 .30873 .83608 .31677 .84905 .3076 .84353 .29948 Mtetra
.777 .785 .86 r
.84353 .29948 .84905 .3076 .86205 .29845 .85657 .29025 Mtetra
.776 .784 .859 r
.85657 .29025 .86205 .29845 .87506 .28929 .86963 .28101 Mtetra
.424 .655 .955 r
.2642 .4725 .27143 .47923 .28208 .48012 .27487 .4734 Mtetra
.423 .655 .956 r
.27487 .4734 .28208 .48012 .2928 .48103 .2856 .47432 Mtetra
.421 .655 .956 r
.2856 .47432 .2928 .48103 .3036 .48197 .29641 .47526 Mtetra
.418 .654 .957 r
.29641 .47526 .3036 .48197 .31447 .48294 .3073 .47623 Mtetra
.415 .654 .957 r
.3073 .47623 .31447 .48294 .32541 .48396 .31826 .47723 Mtetra
.412 .653 .957 r
.31826 .47723 .32541 .48396 .33643 .48503 .3293 .47828 Mtetra
.409 .651 .957 r
.3293 .47828 .33643 .48503 .34753 .48615 .34041 .47938 Mtetra
.406 .65 .957 r
.34041 .47938 .34753 .48615 .3587 .48734 .35161 .48053 Mtetra
.404 .648 .957 r
.35161 .48053 .3587 .48734 .36995 .48858 .36288 .48172 Mtetra
.402 .646 .956 r
.36288 .48172 .36995 .48858 .38129 .48989 .37423 .48296 Mtetra
.402 .644 .955 r
.37423 .48296 .38129 .48989 .3927 .49126 .38567 .48423 Mtetra
.405 .643 .954 r
.38567 .48423 .3927 .49126 .4042 .49266 .3972 .48552 Mtetra
.408 .642 .952 r
.3972 .48552 .4042 .49266 .41578 .4941 .4088 .48681 Mtetra
.415 .641 .95 r
.4088 .48681 .41578 .4941 .42746 .49553 .4205 .48807 Mtetra
.425 .641 .946 r
.4205 .48807 .42746 .49553 .43922 .49693 .43229 .48926 Mtetra
.438 .641 .943 r
.43229 .48926 .43922 .49693 .45107 .49827 .44417 .49035 Mtetra
.455 .642 .937 r
.44417 .49035 .45107 .49827 .46302 .49945 .45614 .49124 Mtetra
.474 .643 .931 r
.45614 .49124 .46302 .49945 .47506 .50045 .4682 .49191 Mtetra
.497 .645 .923 r
.4682 .49191 .47506 .50045 .48719 .50114 .48036 .49224 Mtetra
.522 .647 .913 r
.48036 .49224 .48719 .50114 .49941 .50142 .4926 .49214 Mtetra
.548 .65 .902 r
.4926 .49214 .49941 .50142 .51172 .50117 .50494 .4915 Mtetra
.574 .653 .889 r
.50494 .4915 .51172 .50117 .52411 .50023 .51735 .4902 Mtetra
.602 .657 .877 r
.51735 .4902 .52411 .50023 .53658 .49843 .52984 .48809 Mtetra
.627 .662 .865 r
.52984 .48809 .53658 .49843 .54911 .49568 .54239 .48512 Mtetra
.652 .669 .853 r
.54239 .48512 .54911 .49568 .5617 .49176 .555 .48116 Mtetra
.674 .678 .845 r
.555 .48116 .5617 .49176 .57432 .48667 .56766 .47621 Mtetra
.693 .689 .841 r
.56766 .47621 .57432 .48667 .58698 .48061 .58035 .47039 Mtetra
.711 .701 .839 r
.58035 .47039 .58698 .48061 .59966 .47367 .59307 .46375 Mtetra
.726 .712 .838 r
.59307 .46375 .59966 .47367 .61235 .46602 .60582 .45643 Mtetra
.738 .724 .838 r
.60582 .45643 .61235 .46602 .62507 .45783 .61857 .44855 Mtetra
.748 .734 .839 r
.61857 .44855 .62507 .45783 .63779 .4492 .63135 .44021 Mtetra
.757 .744 .841 r
.63135 .44021 .63779 .4492 .65052 .44024 .64414 .43151 Mtetra
.764 .753 .843 r
.64414 .43151 .65052 .44024 .66327 .43106 .65694 .42256 Mtetra
.77 .76 .844 r
.65694 .42256 .66327 .43106 .67602 .42171 .66975 .41339 Mtetra
.774 .767 .847 r
.66975 .41339 .67602 .42171 .68879 .41226 .68258 .4041 Mtetra
.777 .772 .849 r
.68258 .4041 .68879 .41226 .70158 .40276 .69542 .39471 Mtetra
.779 .777 .85 r
.69542 .39471 .70158 .40276 .71438 .39323 .70828 .38526 Mtetra
.78 .78 .852 r
.70828 .38526 .71438 .39323 .72719 .38371 .72115 .37579 Mtetra
.781 .783 .854 r
.72115 .37579 .72719 .38371 .74003 .37421 .73404 .36632 Mtetra
.781 .785 .855 r
.73404 .36632 .74003 .37421 .75289 .36474 .74696 .35686 Mtetra
.781 .786 .857 r
.74696 .35686 .75289 .36474 .76577 .35531 .75989 .34742 Mtetra
.781 .787 .858 r
.75989 .34742 .76577 .35531 .77867 .34592 .77284 .338 Mtetra
.78 .787 .858 r
.77284 .338 .77867 .34592 .7916 .33658 .78582 .32861 Mtetra
.779 .787 .859 r
.78582 .32861 .7916 .33658 .80454 .32727 .79882 .31925 Mtetra
.79882 .31925 .80454 .32727 .81752 .31799 .81184 .30991 Mtetra
.778 .786 .859 r
.81184 .30991 .81752 .31799 .83051 .30873 .82489 .30059 Mtetra
.777 .785 .859 r
.82489 .30059 .83051 .30873 .84353 .29948 .83796 .29128 Mtetra
.83796 .29128 .84353 .29948 .85657 .29025 .85105 .28196 Mtetra
.776 .784 .859 r
.85105 .28196 .85657 .29025 .86963 .28101 .86416 .27265 Mtetra
.423 .654 .955 r
.25692 .46572 .2642 .4725 .27487 .4734 .2676 .46662 Mtetra
.422 .654 .956 r
.2676 .46662 .27487 .4734 .2856 .47432 .27835 .46753 Mtetra
.42 .654 .956 r
.27835 .46753 .2856 .47432 .29641 .47526 .28917 .46846 Mtetra
.418 .654 .956 r
.28917 .46846 .29641 .47526 .3073 .47623 .30008 .46942 Mtetra
.416 .653 .957 r
.30008 .46942 .3073 .47623 .31826 .47723 .31106 .47042 Mtetra
.413 .652 .957 r
.31106 .47042 .31826 .47723 .3293 .47828 .32211 .47145 Mtetra
.411 .651 .957 r
.32211 .47145 .3293 .47828 .34041 .47938 .33325 .47252 Mtetra
.409 .65 .956 r
.33325 .47252 .34041 .47938 .35161 .48053 .34446 .47363 Mtetra
.407 .648 .956 r
.34446 .47363 .35161 .48053 .36288 .48172 .35575 .47478 Mtetra
.407 .647 .956 r
.35575 .47478 .36288 .48172 .37423 .48296 .36713 .47595 Mtetra
.407 .646 .955 r
.36713 .47595 .37423 .48296 .38567 .48423 .37859 .47715 Mtetra
.41 .645 .954 r
.37859 .47715 .38567 .48423 .3972 .48552 .39013 .47833 Mtetra
.414 .645 .952 r
.39013 .47833 .3972 .48552 .4088 .48681 .40177 .47951 Mtetra
.422 .645 .95 r
.40177 .47951 .4088 .48681 .4205 .48807 .41349 .48063 Mtetra
.432 .646 .948 r
.41349 .48063 .4205 .48807 .43229 .48926 .4253 .48165 Mtetra
.445 .648 .945 r
.4253 .48165 .43229 .48926 .44417 .49035 .43721 .48254 Mtetra
.462 .651 .941 r
.43721 .48254 .44417 .49035 .45614 .49124 .4492 .48322 Mtetra
.481 .654 .936 r
.4492 .48322 .45614 .49124 .4682 .49191 .46129 .48364 Mtetra
.503 .657 .929 r
.46129 .48364 .4682 .49191 .48036 .49224 .47347 .48371 Mtetra
.527 .662 .921 r
.47347 .48371 .48036 .49224 .4926 .49214 .48575 .48333 Mtetra
.553 .666 .912 r
.48575 .48333 .4926 .49214 .50494 .4915 .4981 .48242 Mtetra
.579 .671 .902 r
.4981 .48242 .50494 .4915 .51735 .4902 .51054 .48087 Mtetra
.605 .677 .892 r
.51054 .48087 .51735 .4902 .52984 .48809 .52306 .47857 Mtetra
.63 .683 .882 r
.52306 .47857 .52984 .48809 .54239 .48512 .53564 .47547 Mtetra
.654 .691 .872 r
.53564 .47547 .54239 .48512 .555 .48116 .54828 .47148 Mtetra
.676 .699 .864 r
.54828 .47148 .555 .48116 .56766 .47621 .56097 .46658 Mtetra
.695 .708 .858 r
.56097 .46658 .56766 .47621 .58035 .47039 .57369 .46089 Mtetra
.712 .717 .853 r
.57369 .46089 .58035 .47039 .59307 .46375 .58645 .45442 Mtetra
.726 .726 .851 r
.58645 .45442 .59307 .46375 .60582 .45643 .59924 .4473 Mtetra
.738 .735 .849 r
.59924 .4473 .60582 .45643 .61857 .44855 .61205 .43963 Mtetra
.748 .744 .848 r
.61205 .43963 .61857 .44855 .63135 .44021 .62487 .43149 Mtetra
.756 .751 .848 r
.62487 .43149 .63135 .44021 .64414 .43151 .63771 .42297 Mtetra
.763 .758 .849 r
.63771 .42297 .64414 .43151 .65694 .42256 .65057 .41417 Mtetra
.768 .764 .849 r
.65057 .41417 .65694 .42256 .66975 .41339 .66343 .40513 Mtetra
.772 .769 .85 r
.66343 .40513 .66975 .41339 .68258 .4041 .67632 .39594 Mtetra
.775 .774 .851 r
.67632 .39594 .68258 .4041 .69542 .39471 .68921 .38663 Mtetra
.778 .777 .852 r
.68921 .38663 .69542 .39471 .70828 .38526 .70213 .37723 Mtetra
.779 .78 .853 r
.70213 .37723 .70828 .38526 .72115 .37579 .71505 .3678 Mtetra
.78 .782 .854 r
.71505 .3678 .72115 .37579 .73404 .36632 .728 .35833 Mtetra
.78 .784 .855 r
.728 .35833 .73404 .36632 .74696 .35686 .74097 .34887 Mtetra
.78 .785 .856 r
.74097 .34887 .74696 .35686 .75989 .34742 .75396 .33941 Mtetra
.78 .785 .857 r
.75396 .33941 .75989 .34742 .77284 .338 .76696 .32997 Mtetra
.78 .786 .858 r
.76696 .32997 .77284 .338 .78582 .32861 .77999 .32054 Mtetra
.779 .786 .858 r
.77999 .32054 .78582 .32861 .79882 .31925 .79304 .31113 Mtetra
.779 .786 .859 r
.79304 .31113 .79882 .31925 .81184 .30991 .80612 .30174 Mtetra
.778 .785 .859 r
.80612 .30174 .81184 .30991 .82489 .30059 .81921 .29235 Mtetra
.81921 .29235 .82489 .30059 .83796 .29128 .83233 .28298 Mtetra
.777 .784 .859 r
.83233 .28298 .83796 .29128 .85105 .28196 .84547 .2736 Mtetra
.84547 .2736 .85105 .28196 .86416 .27265 .85864 .26422 Mtetra
.422 .654 .955 r
.24958 .45888 .25692 .46572 .2676 .46662 .26027 .45977 Mtetra
.421 .654 .956 r
.26027 .45977 .2676 .46662 .27835 .46753 .27104 .46067 Mtetra
.42 .653 .956 r
.27104 .46067 .27835 .46753 .28917 .46846 .28188 .4616 Mtetra
.418 .653 .956 r
.28188 .4616 .28917 .46846 .30008 .46942 .2928 .46255 Mtetra
.416 .652 .956 r
.2928 .46255 .30008 .46942 .31106 .47042 .3038 .46352 Mtetra
.414 .651 .956 r
.3038 .46352 .31106 .47042 .32211 .47145 .31487 .46453 Mtetra
.412 .651 .956 r
.31487 .46453 .32211 .47145 .33325 .47252 .32602 .46558 Mtetra
.41 .65 .956 r
.32602 .46558 .33325 .47252 .34446 .47363 .33725 .46666 Mtetra
.409 .649 .956 r
.33725 .46666 .34446 .47363 .35575 .47478 .34857 .46776 Mtetra
.409 .648 .955 r
.34857 .46776 .35575 .47478 .36713 .47595 .35996 .46889 Mtetra
.41 .647 .955 r
.35996 .46889 .36713 .47595 .37859 .47715 .37145 .47002 Mtetra
.413 .648 .954 r
.37145 .47002 .37859 .47715 .39013 .47833 .38301 .47114 Mtetra
.417 .648 .953 r
.38301 .47114 .39013 .47833 .40177 .47951 .39467 .47223 Mtetra
.425 .649 .952 r
.39467 .47223 .40177 .47951 .41349 .48063 .40642 .47324 Mtetra
.435 .652 .951 r
.40642 .47324 .41349 .48063 .4253 .48165 .41825 .47415 Mtetra
.447 .655 .948 r
.41825 .47415 .4253 .48165 .43721 .48254 .43018 .4749 Mtetra
.464 .659 .946 r
.43018 .4749 .43721 .48254 .4492 .48322 .44221 .47543 Mtetra
.482 .663 .942 r
.44221 .47543 .4492 .48322 .46129 .48364 .45432 .47567 Mtetra
.504 .669 .937 r
.45432 .47567 .46129 .48364 .47347 .48371 .46653 .47556 Mtetra
.529 .675 .931 r
.46653 .47556 .47347 .48371 .48575 .48333 .47883 .47499 Mtetra
.554 .682 .924 r
.47883 .47499 .48575 .48333 .4981 .48242 .49121 .47389 Mtetra
.58 .688 .915 r
.49121 .47389 .4981 .48242 .51054 .48087 .50368 .47217 Mtetra
.607 .695 .906 r
.50368 .47217 .51054 .48087 .52306 .47857 .51622 .46972 Mtetra
.631 .702 .896 r
.51622 .46972 .52306 .47857 .53564 .47547 .52883 .46652 Mtetra
.656 .709 .887 r
.52883 .46652 .53564 .47547 .54828 .47148 .54151 .46249 Mtetra
.677 .717 .879 r
.54151 .46249 .54828 .47148 .56097 .46658 .55423 .45763 Mtetra
.696 .725 .873 r
.55423 .45763 .56097 .46658 .57369 .46089 .567 .45201 Mtetra
.713 .733 .867 r
.567 .45201 .57369 .46089 .58645 .45442 .5798 .44565 Mtetra
.727 .741 .863 r
.5798 .44565 .58645 .45442 .59924 .4473 .59263 .43865 Mtetra
.738 .748 .86 r
.59263 .43865 .59924 .4473 .61205 .43963 .60548 .4311 Mtetra
.748 .754 .857 r
.60548 .4311 .61205 .43963 .62487 .43149 .61835 .42307 Mtetra
.757 .76 .856 r
.61835 .42307 .62487 .43149 .63771 .42297 .63124 .41466 Mtetra
.763 .765 .855 r
.63124 .41466 .63771 .42297 .65057 .41417 .64415 .40595 Mtetra
.768 .77 .854 r
.64415 .40595 .65057 .41417 .66343 .40513 .65707 .39698 Mtetra
.772 .774 .854 r
.65707 .39698 .66343 .40513 .67632 .39594 .67001 .38784 Mtetra
.775 .777 .854 r
.67001 .38784 .67632 .39594 .68921 .38663 .68296 .37856 Mtetra
.777 .779 .854 r
.68296 .37856 .68921 .38663 .70213 .37723 .69592 .36919 Mtetra
.778 .781 .855 r
.69592 .36919 .70213 .37723 .71505 .3678 .70891 .35976 Mtetra
.779 .783 .855 r
.70891 .35976 .71505 .3678 .728 .35833 .72191 .35029 Mtetra
.78 .784 .856 r
.72191 .35029 .728 .35833 .74097 .34887 .73493 .3408 Mtetra
.73493 .3408 .74097 .34887 .75396 .33941 .74797 .33132 Mtetra
.78 .785 .857 r
.74797 .33132 .75396 .33941 .76696 .32997 .76103 .32184 Mtetra
.779 .785 .857 r
.76103 .32184 .76696 .32997 .77999 .32054 .77411 .31237 Mtetra
.779 .785 .858 r
.77411 .31237 .77999 .32054 .79304 .31113 .78721 .30291 Mtetra
.778 .785 .858 r
.78721 .30291 .79304 .31113 .80612 .30174 .80034 .29347 Mtetra
.80034 .29347 .80612 .30174 .81921 .29235 .81349 .28403 Mtetra
.778 .784 .858 r
.81349 .28403 .81921 .29235 .83233 .28298 .82666 .2746 Mtetra
.777 .784 .858 r
.82666 .2746 .83233 .28298 .84547 .2736 .83985 .26516 Mtetra
.83985 .26516 .84547 .2736 .85864 .26422 .85307 .25572 Mtetra
.422 .654 .955 r
.24218 .452 .24958 .45888 .26027 .45977 .25289 .45287 Mtetra
.421 .653 .956 r
.25289 .45287 .26027 .45977 .27104 .46067 .26367 .45375 Mtetra
.42 .653 .956 r
.26367 .45375 .27104 .46067 .28188 .4616 .27453 .45466 Mtetra
.418 .653 .956 r
.27453 .45466 .28188 .4616 .2928 .46255 .28546 .45559 Mtetra
.417 .652 .956 r
.28546 .45559 .2928 .46255 .3038 .46352 .29648 .45655 Mtetra
.415 .651 .956 r
.29648 .45655 .3038 .46352 .31487 .46453 .30757 .45754 Mtetra
.413 .65 .956 r
.30757 .45754 .31487 .46453 .32602 .46558 .31874 .45856 Mtetra
.411 .649 .956 r
.31874 .45856 .32602 .46558 .33725 .46666 .32999 .45961 Mtetra
.411 .649 .955 r
.32999 .45961 .33725 .46666 .34857 .46776 .34133 .46068 Mtetra
.411 .648 .955 r
.34133 .46068 .34857 .46776 .35996 .46889 .35274 .46177 Mtetra
.35274 .46177 .35996 .46889 .37145 .47002 .36425 .46286 Mtetra
.414 .649 .955 r
.36425 .46286 .37145 .47002 .38301 .47114 .37584 .46393 Mtetra
.418 .65 .954 r
.37584 .46393 .38301 .47114 .39467 .47223 .38751 .46496 Mtetra
.425 .652 .954 r
.38751 .46496 .39467 .47223 .40642 .47324 .39928 .46592 Mtetra
.434 .655 .953 r
.39928 .46592 .40642 .47324 .41825 .47415 .41114 .46675 Mtetra
.446 .659 .952 r
.41114 .46675 .41825 .47415 .43018 .4749 .4231 .46742 Mtetra
.462 .665 .95 r
.4231 .46742 .43018 .4749 .44221 .47543 .43515 .46786 Mtetra
.48 .671 .948 r
.43515 .46786 .44221 .47543 .45432 .47567 .44729 .46801 Mtetra
.502 .679 .945 r
.44729 .46801 .45432 .47567 .46653 .47556 .45952 .4678 Mtetra
.526 .687 .941 r
.45952 .4678 .46653 .47556 .47883 .47499 .47185 .46713 Mtetra
.552 .696 .935 r
.47185 .46713 .47883 .47499 .49121 .47389 .48426 .46592 Mtetra
.578 .705 .929 r
.48426 .46592 .49121 .47389 .50368 .47217 .49676 .46411 Mtetra
.606 .714 .921 r
.49676 .46411 .50368 .47217 .51622 .46972 .50933 .46158 Mtetra
.631 .722 .913 r
.50933 .46158 .51622 .46972 .52883 .46652 .52198 .45832 Mtetra
.656 .73 .904 r
.52198 .45832 .52883 .46652 .54151 .46249 .53469 .45425 Mtetra
.679 .738 .895 r
.53469 .45425 .54151 .46249 .55423 .45763 .54745 .44938 Mtetra
.698 .745 .888 r
.54745 .44938 .55423 .45763 .567 .45201 .56025 .44377 Mtetra
.715 .751 .88 r
.56025 .44377 .567 .45201 .5798 .44565 .5731 .43743 Mtetra
.729 .757 .875 r
.5731 .43743 .5798 .44565 .59263 .43865 .58597 .43047 Mtetra
.741 .762 .87 r
.58597 .43047 .59263 .43865 .60548 .4311 .59887 .42295 Mtetra
.75 .766 .866 r
.59887 .42295 .60548 .4311 .61835 .42307 .61179 .41496 Mtetra
.758 .77 .862 r
.61179 .41496 .61835 .42307 .63124 .41466 .62473 .40657 Mtetra
.764 .773 .86 r
.62473 .40657 .63124 .41466 .64415 .40595 .63769 .39788 Mtetra
.769 .776 .858 r
.63769 .39788 .64415 .40595 .65707 .39698 .65066 .38892 Mtetra
.773 .778 .857 r
.65066 .38892 .65707 .39698 .67001 .38784 .66365 .37979 Mtetra
.775 .78 .856 r
.66365 .37979 .67001 .38784 .68296 .37856 .67665 .3705 Mtetra
.777 .781 .856 r
.67665 .3705 .68296 .37856 .69592 .36919 .68967 .36112 Mtetra
.778 .782 .856 r
.68967 .36112 .69592 .36919 .70891 .35976 .70271 .35167 Mtetra
.779 .783 .856 r
.70271 .35167 .70891 .35976 .72191 .35029 .71576 .34217 Mtetra
.779 .784 .856 r
.71576 .34217 .72191 .35029 .73493 .3408 .72884 .33266 Mtetra
.78 .784 .856 r
.72884 .33266 .73493 .3408 .74797 .33132 .74193 .32313 Mtetra
.779 .784 .857 r
.74193 .32313 .74797 .33132 .76103 .32184 .75504 .31361 Mtetra
.75504 .31361 .76103 .32184 .77411 .31237 .76818 .3041 Mtetra
.76818 .3041 .77411 .31237 .78721 .30291 .78133 .29459 Mtetra
.778 .784 .858 r
.78133 .29459 .78721 .30291 .80034 .29347 .79451 .2851 Mtetra
.79451 .2851 .80034 .29347 .81349 .28403 .80771 .27561 Mtetra
.777 .784 .858 r
.80771 .27561 .81349 .28403 .82666 .2746 .82093 .26613 Mtetra
.82093 .26613 .82666 .2746 .83985 .26516 .83418 .25664 Mtetra
.777 .783 .858 r
.83418 .25664 .83985 .26516 .85307 .25572 .84745 .24714 Mtetra
.422 .654 .955 r
.23472 .44505 .24218 .452 .25289 .45287 .24545 .4459 Mtetra
.421 .653 .955 r
.24545 .4459 .25289 .45287 .26367 .45375 .25625 .44677 Mtetra
.42 .653 .955 r
.25625 .44677 .26367 .45375 .27453 .45466 .26712 .44765 Mtetra
.419 .652 .955 r
.26712 .44765 .27453 .45466 .28546 .45559 .27807 .44856 Mtetra
.417 .652 .955 r
.27807 .44856 .28546 .45559 .29648 .45655 .2891 .44949 Mtetra
.415 .651 .955 r
.2891 .44949 .29648 .45655 .30757 .45754 .30021 .45046 Mtetra
.414 .65 .955 r
.30021 .45046 .30757 .45754 .31874 .45856 .3114 .45146 Mtetra
.412 .649 .955 r
.3114 .45146 .31874 .45856 .32999 .45961 .32267 .45249 Mtetra
.411 .648 .955 r
.32267 .45249 .32999 .45961 .34133 .46068 .33402 .45354 Mtetra
.33402 .45354 .34133 .46068 .35274 .46177 .34546 .45461 Mtetra
.34546 .45461 .35274 .46177 .36425 .46286 .35698 .45568 Mtetra
.413 .649 .955 r
.35698 .45568 .36425 .46286 .37584 .46393 .36859 .45672 Mtetra
.416 .651 .955 r
.36859 .45672 .37584 .46393 .38751 .46496 .38029 .45773 Mtetra
.422 .654 .955 r
.38029 .45773 .38751 .46496 .39928 .46592 .39208 .45866 Mtetra
.431 .658 .956 r
.39208 .45866 .39928 .46592 .41114 .46675 .40397 .45947 Mtetra
.441 .663 .956 r
.40397 .45947 .41114 .46675 .4231 .46742 .41595 .46012 Mtetra
.456 .67 .955 r
.41595 .46012 .4231 .46742 .43515 .46786 .42802 .46053 Mtetra
.473 .678 .955 r
.42802 .46053 .43515 .46786 .44729 .46801 .44019 .46066 Mtetra
.494 .688 .953 r
.44019 .46066 .44729 .46801 .45952 .4678 .45245 .46042 Mtetra
.519 .698 .951 r
.45245 .46042 .45952 .4678 .47185 .46713 .4648 .45972 Mtetra
.545 .709 .947 r
.4648 .45972 .47185 .46713 .48426 .46592 .47725 .45849 Mtetra
.572 .72 .943 r
.47725 .45849 .48426 .46592 .49676 .46411 .48978 .45665 Mtetra
.602 .732 .936 r
.48978 .45665 .49676 .46411 .50933 .46158 .50239 .45409 Mtetra
.629 .742 .929 r
.50239 .45409 .50933 .46158 .52198 .45832 .51507 .45079 Mtetra
.656 .751 .92 r
.51507 .45079 .52198 .45832 .53469 .45425 .52781 .44669 Mtetra
.68 .759 .91 r
.52781 .44669 .53469 .45425 .54745 .44938 .54061 .44178 Mtetra
.7 .764 .902 r
.54061 .44178 .54745 .44938 .56025 .44377 .55346 .43614 Mtetra
.718 .769 .893 r
.55346 .43614 .56025 .44377 .5731 .43743 .56635 .42976 Mtetra
.733 .773 .885 r
.56635 .42976 .5731 .43743 .58597 .43047 .57927 .42275 Mtetra
.744 .776 .879 r
.57927 .42275 .58597 .43047 .59887 .42295 .59222 .41519 Mtetra
.754 .778 .873 r
.59222 .41519 .59887 .42295 .61179 .41496 .60519 .40716 Mtetra
.761 .78 .868 r
.60519 .40716 .61179 .41496 .62473 .40657 .61818 .39873 Mtetra
.767 .781 .865 r
.61818 .39873 .62473 .40657 .63769 .39788 .63118 .38999 Mtetra
.771 .782 .862 r
.63118 .38999 .63769 .39788 .65066 .38892 .64421 .38099 Mtetra
.774 .783 .86 r
.64421 .38099 .65066 .38892 .66365 .37979 .65724 .3718 Mtetra
.777 .783 .858 r
.65724 .3718 .66365 .37979 .67665 .3705 .6703 .36247 Mtetra
.778 .784 .857 r
.6703 .36247 .67665 .3705 .68967 .36112 .68337 .35304 Mtetra
.779 .784 .857 r
.68337 .35304 .68967 .36112 .70271 .35167 .69646 .34354 Mtetra
.78 .784 .856 r
.69646 .34354 .70271 .35167 .71576 .34217 .70956 .334 Mtetra
.70956 .334 .71576 .34217 .72884 .33266 .72269 .32444 Mtetra
.72269 .32444 .72884 .33266 .74193 .32313 .73583 .31487 Mtetra
.779 .784 .857 r
.73583 .31487 .74193 .32313 .75504 .31361 .749 .3053 Mtetra
.749 .3053 .75504 .31361 .76818 .3041 .76219 .29574 Mtetra
.778 .784 .857 r
.76219 .29574 .76818 .3041 .78133 .29459 .7754 .28618 Mtetra
.7754 .28618 .78133 .29459 .79451 .2851 .78863 .27664 Mtetra
.778 .783 .858 r
.78863 .27664 .79451 .2851 .80771 .27561 .80188 .26711 Mtetra
.777 .783 .858 r
.80188 .26711 .80771 .27561 .82093 .26613 .81516 .25757 Mtetra
.81516 .25757 .82093 .26613 .83418 .25664 .82846 .24804 Mtetra
.82846 .24804 .83418 .25664 .84745 .24714 .84178 .23849 Mtetra
.422 .654 .955 r
.22721 .43805 .23472 .44505 .24545 .4459 .23795 .43888 Mtetra
.422 .653 .955 r
.23795 .43888 .24545 .4459 .25625 .44677 .24876 .43971 Mtetra
.421 .653 .955 r
.24876 .43971 .25625 .44677 .26712 .44765 .25965 .44057 Mtetra
.42 .652 .955 r
.25965 .44057 .26712 .44765 .27807 .44856 .27062 .44145 Mtetra
.418 .651 .955 r
.27062 .44145 .27807 .44856 .2891 .44949 .28167 .44237 Mtetra
.416 .65 .955 r
.28167 .44237 .2891 .44949 .30021 .45046 .2928 .44331 Mtetra
.414 .649 .955 r
.2928 .44331 .30021 .45046 .3114 .45146 .30401 .44429 Mtetra
.412 .648 .955 r
.30401 .44429 .3114 .45146 .32267 .45249 .31529 .4453 Mtetra
.411 .648 .955 r
.31529 .4453 .32267 .45249 .33402 .45354 .32666 .44634 Mtetra
.41 .648 .955 r
.32666 .44634 .33402 .45354 .34546 .45461 .33812 .4474 Mtetra
.409 .648 .955 r
.33812 .4474 .34546 .45461 .35698 .45568 .34966 .44847 Mtetra
.41 .649 .956 r
.34966 .44847 .35698 .45568 .36859 .45672 .36129 .44952 Mtetra
.412 .651 .956 r
.36129 .44952 .36859 .45672 .38029 .45773 .37301 .45054 Mtetra
.416 .654 .957 r
.37301 .45054 .38029 .45773 .39208 .45866 .38482 .45148 Mtetra
.423 .659 .958 r
.38482 .45148 .39208 .45866 .40397 .45947 .39672 .45232 Mtetra
.432 .665 .959 r
.39672 .45232 .40397 .45947 .41595 .46012 .40872 .453 Mtetra
.446 .673 .96 r
.40872 .453 .41595 .46012 .42802 .46053 .42082 .45345 Mtetra
.462 .682 .961 r
.42082 .45345 .42802 .46053 .44019 .46066 .43301 .45363 Mtetra
.482 .694 .961 r
.43301 .45363 .44019 .46066 .45245 .46042 .4453 .45343 Mtetra
.506 .707 .961 r
.4453 .45343 .45245 .46042 .4648 .45972 .45769 .45278 Mtetra
.533 .721 .96 r
.45769 .45278 .4648 .45972 .47725 .45849 .47016 .4516 Mtetra
.562 .735 .957 r
.47016 .4516 .47725 .45849 .48978 .45665 .48273 .44979 Mtetra
.594 .75 .951 r
.48273 .44979 .48978 .45665 .50239 .45409 .49537 .44725 Mtetra
.624 .762 .945 r
.49537 .44725 .50239 .45409 .51507 .45079 .50809 .44395 Mtetra
.655 .773 .936 r
.50809 .44395 .51507 .45079 .52781 .44669 .52088 .43981 Mtetra
.682 .781 .925 r
.52088 .43981 .52781 .44669 .54061 .44178 .53372 .43484 Mtetra
.704 .786 .915 r
.53372 .43484 .54061 .44178 .55346 .43614 .54662 .42911 Mtetra
.723 .789 .905 r
.54662 .42911 .55346 .43614 .56635 .42976 .55955 .42262 Mtetra
.738 .791 .895 r
.55955 .42262 .56635 .42976 .57927 .42275 .57252 .4155 Mtetra
.749 .791 .887 r
.57252 .4155 .57927 .42275 .59222 .41519 .58551 .40782 Mtetra
.758 .791 .88 r
.58551 .40782 .59222 .41519 .60519 .40716 .59853 .39967 Mtetra
.765 .791 .874 r
.59853 .39967 .60519 .40716 .61818 .39873 .61157 .39112 Mtetra
.77 .79 .869 r
.61157 .39112 .61818 .39873 .63118 .38999 .62463 .38227 Mtetra
.774 .789 .865 r
.62463 .38227 .63118 .38999 .64421 .38099 .6377 .37317 Mtetra
.777 .788 .862 r
.6377 .37317 .64421 .38099 .65724 .3718 .65079 .36388 Mtetra
.778 .787 .86 r
.65079 .36388 .65724 .3718 .6703 .36247 .66389 .35447 Mtetra
.78 .786 .858 r
.66389 .35447 .6703 .36247 .68337 .35304 .67701 .34495 Mtetra
.78 .786 .857 r
.67701 .34495 .68337 .35304 .69646 .34354 .69015 .33538 Mtetra
.78 .785 .857 r
.69015 .33538 .69646 .34354 .70956 .334 .70331 .32577 Mtetra
.78 .784 .856 r
.70331 .32577 .70956 .334 .72269 .32444 .71649 .31614 Mtetra
.71649 .31614 .72269 .32444 .73583 .31487 .72969 .30652 Mtetra
.779 .784 .856 r
.72969 .30652 .73583 .31487 .749 .3053 .74291 .29689 Mtetra
.779 .783 .857 r
.74291 .29689 .749 .3053 .76219 .29574 .75615 .28728 Mtetra
.778 .783 .857 r
.75615 .28728 .76219 .29574 .7754 .28618 .76941 .27768 Mtetra
.76941 .27768 .7754 .28618 .78863 .27664 .78269 .26809 Mtetra
.777 .783 .857 r
.78269 .26809 .78863 .27664 .80188 .26711 .796 .25851 Mtetra
.777 .783 .858 r
.796 .25851 .80188 .26711 .81516 .25757 .80933 .24893 Mtetra
.80933 .24893 .81516 .25757 .82846 .24804 .82268 .23935 Mtetra
.82268 .23935 .82846 .24804 .84178 .23849 .83606 .22976 Mtetra
.423 .654 .955 r
.21963 .431 .22721 .43805 .23795 .43888 .23039 .43179 Mtetra
.23039 .43179 .23795 .43888 .24876 .43971 .24122 .43259 Mtetra
.422 .653 .955 r
.24122 .43259 .24876 .43971 .25965 .44057 .25213 .43342 Mtetra
.421 .652 .955 r
.25213 .43342 .25965 .44057 .27062 .44145 .26312 .43427 Mtetra
.419 .651 .955 r
.26312 .43427 .27062 .44145 .28167 .44237 .27418 .43515 Mtetra
.417 .65 .954 r
.27418 .43515 .28167 .44237 .2928 .44331 .28533 .43608 Mtetra
.415 .649 .954 r
.28533 .43608 .2928 .44331 .30401 .44429 .29655 .43704 Mtetra
.412 .648 .954 r
.29655 .43704 .30401 .44429 .31529 .4453 .30786 .43804 Mtetra
.41 .647 .955 r
.30786 .43804 .31529 .4453 .32666 .44634 .31924 .43907 Mtetra
.408 .647 .955 r
.31924 .43907 .32666 .44634 .33812 .4474 .33072 .44013 Mtetra
.406 .647 .955 r
.33072 .44013 .33812 .4474 .34966 .44847 .34228 .44122 Mtetra
.406 .648 .956 r
.34228 .44122 .34966 .44847 .36129 .44952 .35392 .4423 Mtetra
.406 .649 .957 r
.35392 .4423 .36129 .44952 .37301 .45054 .36566 .44336 Mtetra
.408 .653 .958 r
.36566 .44336 .37301 .45054 .38482 .45148 .37749 .44436 Mtetra
.413 .658 .96 r
.37749 .44436 .38482 .45148 .39672 .45232 .38941 .44527 Mtetra
.42 .664 .962 r
.38941 .44527 .39672 .45232 .40872 .453 .40143 .44604 Mtetra
.431 .673 .964 r
.40143 .44604 .40872 .453 .42082 .45345 .41355 .4466 Mtetra
.444 .684 .967 r
.41355 .4466 .42082 .45345 .43301 .45363 .42577 .4469 Mtetra
.463 .698 .969 r
.42577 .4469 .43301 .45363 .4453 .45343 .43808 .44683 Mtetra
.486 .713 .971 r
.43808 .44683 .4453 .45343 .45769 .45278 .45049 .44632 Mtetra
.514 .731 .972 r
.45049 .44632 .45769 .45278 .47016 .4516 .463 .44527 Mtetra
.545 .749 .971 r
.463 .44527 .47016 .4516 .48273 .44979 .4756 .44358 Mtetra
.581 .768 .968 r
.4756 .44358 .48273 .44979 .49537 .44725 .48828 .44112 Mtetra
.615 .783 .962 r
.48828 .44112 .49537 .44725 .50809 .44395 .50105 .43786 Mtetra
.651 .797 .953 r
.50105 .43786 .50809 .44395 .52088 .43981 .51388 .43369 Mtetra
.683 .806 .941 r
.51388 .43369 .52088 .43981 .53372 .43484 .52677 .42861 Mtetra
.708 .81 .929 r
.52677 .42861 .53372 .43484 .54662 .42911 .53971 .42273 Mtetra
.729 .811 .916 r
.53971 .42273 .54662 .42911 .55955 .42262 .5527 .41606 Mtetra
.745 .81 .904 r
.5527 .41606 .55955 .42262 .57252 .4155 .56571 .40873 Mtetra
.756 .808 .894 r
.56571 .40873 .57252 .4155 .58551 .40782 .57876 .40084 Mtetra
.765 .805 .885 r
.57876 .40084 .58551 .40782 .59853 .39967 .59182 .39248 Mtetra
.771 .802 .878 r
.59182 .39248 .59853 .39967 .61157 .39112 .60491 .38374 Mtetra
.775 .798 .872 r
.60491 .38374 .61157 .39112 .62463 .38227 .61802 .37471 Mtetra
.778 .796 .867 r
.61802 .37471 .62463 .38227 .6377 .37317 .63114 .36544 Mtetra
.78 .793 .863 r
.63114 .36544 .6377 .37317 .65079 .36388 .64428 .35602 Mtetra
.781 .791 .861 r
.64428 .35602 .65079 .36388 .66389 .35447 .65743 .34647 Mtetra
.781 .789 .859 r
.65743 .34647 .66389 .35447 .67701 .34495 .67061 .33684 Mtetra
.781 .787 .857 r
.67061 .33684 .67701 .34495 .69015 .33538 .6838 .32717 Mtetra
.781 .786 .856 r
.6838 .32717 .69015 .33538 .70331 .32577 .69701 .31747 Mtetra
.781 .785 .856 r
.69701 .31747 .70331 .32577 .71649 .31614 .71023 .30777 Mtetra
.78 .784 .856 r
.71023 .30777 .71649 .31614 .72969 .30652 .72348 .29807 Mtetra
.779 .783 .856 r
.72348 .29807 .72969 .30652 .74291 .29689 .73675 .28839 Mtetra
.73675 .28839 .74291 .29689 .75615 .28728 .75005 .27872 Mtetra
.778 .782 .856 r
.75005 .27872 .75615 .28728 .76941 .27768 .76336 .26907 Mtetra
.777 .782 .857 r
.76336 .26907 .76941 .27768 .78269 .26809 .7767 .25944 Mtetra
.7767 .25944 .78269 .26809 .796 .25851 .79007 .24982 Mtetra
.79007 .24982 .796 .25851 .80933 .24893 .80345 .2402 Mtetra
.777 .783 .858 r
.80345 .2402 .80933 .24893 .82268 .23935 .81686 .23058 Mtetra
.776 .783 .858 r
.81686 .23058 .82268 .23935 .83606 .22976 .83029 .22096 Mtetra
.425 .655 .955 r
.212 .42389 .21963 .431 .23039 .43179 .22277 .42464 Mtetra
.424 .654 .955 r
.22277 .42464 .23039 .43179 .24122 .43259 .23362 .4254 Mtetra
.424 .653 .955 r
.23362 .4254 .24122 .43259 .25213 .43342 .24455 .42619 Mtetra
.422 .652 .954 r
.24455 .42619 .25213 .43342 .26312 .43427 .25555 .42701 Mtetra
.42 .651 .954 r
.25555 .42701 .26312 .43427 .27418 .43515 .26663 .42786 Mtetra
.418 .649 .954 r
.26663 .42786 .27418 .43515 .28533 .43608 .2778 .42876 Mtetra
.415 .648 .954 r
.2778 .42876 .28533 .43608 .29655 .43704 .28904 .4297 Mtetra
.412 .647 .954 r
.28904 .4297 .29655 .43704 .30786 .43804 .30036 .43069 Mtetra
.408 .646 .954 r
.30036 .43069 .30786 .43804 .31924 .43907 .31176 .43173 Mtetra
.405 .645 .955 r
.31176 .43173 .31924 .43907 .33072 .44013 .32325 .43282 Mtetra
.402 .645 .955 r
.32325 .43282 .33072 .44013 .34228 .44122 .33483 .43393 Mtetra
.4 .646 .956 r
.33483 .43393 .34228 .44122 .35392 .4423 .34649 .43506 Mtetra
.397 .647 .958 r
.34649 .43506 .35392 .4423 .36566 .44336 .35824 .4362 Mtetra
.397 .65 .959 r
.35824 .4362 .36566 .44336 .37749 .44436 .37009 .4373 Mtetra
.399 .655 .962 r
.37009 .4373 .37749 .44436 .38941 .44527 .38203 .43833 Mtetra
.402 .661 .964 r
.38203 .43833 .38941 .44527 .40143 .44604 .39407 .43925 Mtetra
.41 .671 .968 r
.39407 .43925 .40143 .44604 .41355 .4466 .40621 .43998 Mtetra
.42 .683 .972 r
.40621 .43998 .41355 .4466 .42577 .4469 .41844 .44048 Mtetra
.436 .698 .976 r
.41844 .44048 .42577 .4469 .43808 .44683 .43078 .44063 Mtetra
.458 .716 .979 r
.43078 .44063 .43808 .44683 .45049 .44632 .44322 .44035 Mtetra
.486 .737 .983 r
.44322 .44035 .45049 .44632 .463 .44527 .45576 .43952 Mtetra
.52 .76 .984 r
.45576 .43952 .463 .44527 .4756 .44358 .46839 .43801 Mtetra
.561 .784 .982 r
.46839 .43801 .4756 .44358 .48828 .44112 .48112 .43569 Mtetra
.601 .804 .977 r
.48112 .43569 .48828 .44112 .50105 .43786 .49393 .43249 Mtetra
.645 .821 .968 r
.49393 .43249 .50105 .43786 .51388 .43369 .50681 .42829 Mtetra
.683 .831 .954 r
.50681 .42829 .51388 .43369 .52677 .42861 .51975 .42308 Mtetra
.712 .835 .94 r
.51975 .42308 .52677 .42861 .53971 .42273 .53274 .41699 Mtetra
.736 .834 .925 r
.53274 .41699 .53971 .42273 .5527 .41606 .54578 .41006 Mtetra
.753 .831 .911 r
.54578 .41006 .5527 .41606 .56571 .40873 .55885 .40244 Mtetra
.765 .825 .899 r
.55885 .40244 .56571 .40873 .57876 .40084 .57194 .39426 Mtetra
.773 .819 .889 r
.57194 .39426 .57876 .40084 .59182 .39248 .58506 .38561 Mtetra
.778 .813 .881 r
.58506 .38561 .59182 .39248 .60491 .38374 .5982 .37659 Mtetra
.781 .808 .874 r
.5982 .37659 .60491 .38374 .61802 .37471 .61136 .36732 Mtetra
.783 .803 .868 r
.61136 .36732 .61802 .37471 .63114 .36544 .62453 .35783 Mtetra
.784 .798 .864 r
.62453 .35783 .63114 .36544 .64428 .35602 .63772 .3482 Mtetra
.784 .794 .861 r
.63772 .3482 .64428 .35602 .65743 .34647 .65092 .33848 Mtetra
.784 .791 .859 r
.65092 .33848 .65743 .34647 .67061 .33684 .66414 .32871 Mtetra
.783 .789 .857 r
.66414 .32871 .67061 .33684 .6838 .32717 .67738 .31891 Mtetra
.782 .787 .856 r
.67738 .31891 .6838 .32717 .69701 .31747 .69064 .3091 Mtetra
.781 .785 .856 r
.69064 .3091 .69701 .31747 .71023 .30777 .70392 .29931 Mtetra
.78 .784 .855 r
.70392 .29931 .71023 .30777 .72348 .29807 .71722 .28953 Mtetra
.779 .783 .855 r
.71722 .28953 .72348 .29807 .73675 .28839 .73055 .27978 Mtetra
.779 .782 .856 r
.73055 .27978 .73675 .28839 .75005 .27872 .7439 .27006 Mtetra
.778 .782 .856 r
.7439 .27006 .75005 .27872 .76336 .26907 .75727 .26036 Mtetra
.777 .782 .856 r
.75727 .26036 .76336 .26907 .7767 .25944 .77066 .25069 Mtetra
.777 .782 .857 r
.77066 .25069 .7767 .25944 .79007 .24982 .78408 .24103 Mtetra
.776 .782 .857 r
.78408 .24103 .79007 .24982 .80345 .2402 .79752 .23138 Mtetra
.776 .782 .858 r
.79752 .23138 .80345 .2402 .81686 .23058 .81098 .22173 Mtetra
.776 .783 .858 r
.81098 .22173 .81686 .23058 .83029 .22096 .82447 .21208 Mtetra
.427 .656 .955 r
.2043 .41673 .212 .42389 .22277 .42464 .21509 .41742 Mtetra
.426 .655 .955 r
.21509 .41742 .22277 .42464 .23362 .4254 .22596 .41814 Mtetra
.426 .654 .954 r
.22596 .41814 .23362 .4254 .24455 .42619 .23691 .41888 Mtetra
.424 .652 .954 r
.23691 .41888 .24455 .42619 .25555 .42701 .24793 .41965 Mtetra
.422 .651 .954 r
.24793 .41965 .25555 .42701 .26663 .42786 .25903 .42047 Mtetra
.419 .649 .953 r
.25903 .42047 .26663 .42786 .2778 .42876 .27021 .42134 Mtetra
.416 .647 .953 r
.27021 .42134 .2778 .42876 .28904 .4297 .28146 .42226 Mtetra
.412 .645 .953 r
.28146 .42226 .28904 .4297 .30036 .43069 .2928 .42325 Mtetra
.407 .644 .953 r
.2928 .42325 .30036 .43069 .31176 .43173 .30422 .4243 Mtetra
.403 .643 .954 r
.30422 .4243 .31176 .43173 .32325 .43282 .31573 .42541 Mtetra
.397 .642 .955 r
.31573 .42541 .32325 .43282 .33483 .43393 .32732 .42658 Mtetra
.393 .642 .956 r
.32732 .42658 .33483 .43393 .34649 .43506 .339 .42778 Mtetra
.388 .643 .957 r
.339 .42778 .34649 .43506 .35824 .4362 .35076 .42902 Mtetra
.384 .645 .959 r
.35076 .42902 .35824 .4362 .37009 .4373 .36262 .43025 Mtetra
.382 .649 .962 r
.36262 .43025 .37009 .4373 .38203 .43833 .37458 .43145 Mtetra
.381 .655 .965 r
.37458 .43145 .38203 .43833 .39407 .43925 .38663 .43258 Mtetra
.384 .664 .969 r
.38663 .43258 .39407 .43925 .40621 .43998 .39879 .43356 Mtetra
.389 .676 .974 r
.39879 .43356 .40621 .43998 .41844 .44048 .41104 .43434 Mtetra
.401 .692 .979 r
.41104 .43434 .41844 .44048 .43078 .44063 .4234 .43481 Mtetra
.419 .713 .985 r
.4234 .43481 .43078 .44063 .44322 .44035 .43587 .43486 Mtetra
.444 .737 .99 r
.43587 .43486 .44322 .44035 .45576 .43952 .44843 .43437 Mtetra
.479 .766 .994 r
.44843 .43437 .45576 .43952 .46839 .43801 .4611 .43318 Mtetra
.525 .797 .995 r
.4611 .43318 .46839 .43801 .48112 .43569 .47387 .43111 Mtetra
.574 .825 .992 r
.47387 .43111 .48112 .43569 .49393 .43249 .48672 .42807 Mtetra
.632 .85 .983 r
.48672 .42807 .49393 .43249 .50681 .42829 .49965 .42383 Mtetra
.683 .863 .968 r
.49965 .42383 .50681 .42829 .51975 .42308 .51265 .4184 Mtetra
.719 .865 .951 r
.51265 .4184 .51975 .42308 .53274 .41699 .5257 .41199 Mtetra
.746 .861 .933 r
.5257 .41199 .53274 .41699 .54578 .41006 .5388 .40468 Mtetra
.764 .853 .917 r
.5388 .40468 .54578 .41006 .55885 .40244 .55192 .39664 Mtetra
.776 .843 .903 r
.55192 .39664 .55885 .40244 .57194 .39426 .56507 .38805 Mtetra
.782 .833 .891 r
.56507 .38805 .57194 .39426 .58506 .38561 .57824 .37901 Mtetra
.787 .824 .881 r
.57824 .37901 .58506 .38561 .5982 .37659 .59143 .36964 Mtetra
.788 .815 .874 r
.59143 .36964 .5982 .37659 .61136 .36732 .60464 .36004 Mtetra
.789 .808 .868 r
.60464 .36004 .61136 .36732 .62453 .35783 .61786 .35027 Mtetra
.788 .802 .864 r
.61786 .35027 .62453 .35783 .63772 .3482 .63109 .3404 Mtetra
.788 .797 .86 r
.63109 .3404 .63772 .3482 .65092 .33848 .64435 .33047 Mtetra
.786 .793 .858 r
.64435 .33047 .65092 .33848 .66414 .32871 .65762 .32051 Mtetra
.785 .789 .856 r
.65762 .32051 .66414 .32871 .67738 .31891 .67091 .31056 Mtetra
.784 .787 .855 r
.67091 .31056 .67738 .31891 .69064 .3091 .68422 .30063 Mtetra
.782 .784 .855 r
.68422 .30063 .69064 .3091 .70392 .29931 .69755 .29073 Mtetra
.781 .783 .854 r
.69755 .29073 .70392 .29931 .71722 .28953 .71091 .28088 Mtetra
.779 .782 .855 r
.71091 .28088 .71722 .28953 .73055 .27978 .72428 .27106 Mtetra
.778 .781 .855 r
.72428 .27106 .73055 .27978 .7439 .27006 .73768 .26128 Mtetra
.777 .781 .855 r
.73768 .26128 .7439 .27006 .75727 .26036 .75111 .25154 Mtetra
.777 .78 .856 r
.75111 .25154 .75727 .26036 .77066 .25069 .76456 .24183 Mtetra
.776 .781 .857 r
.76456 .24183 .77066 .25069 .78408 .24103 .77803 .23214 Mtetra
.77803 .23214 .78408 .24103 .79752 .23138 .79153 .22246 Mtetra
.775 .782 .858 r
.79153 .22246 .79752 .23138 .81098 .22173 .80505 .21279 Mtetra
.80505 .21279 .81098 .22173 .82447 .21208 .8186 .20311 Mtetra
.429 .657 .955 r
.19654 .4095 .2043 .41673 .21509 .41742 .20735 .41014 Mtetra
.429 .656 .955 r
.20735 .41014 .21509 .41742 .22596 .41814 .21824 .4108 Mtetra
.429 .654 .954 r
.21824 .4108 .22596 .41814 .23691 .41888 .2292 .41148 Mtetra
.427 .653 .953 r
.2292 .41148 .23691 .41888 .24793 .41965 .24024 .41221 Mtetra
.425 .651 .953 r
.24024 .41221 .24793 .41965 .25903 .42047 .25136 .41298 Mtetra
.421 .648 .952 r
.25136 .41298 .25903 .42047 .27021 .42134 .26256 .41382 Mtetra
.417 .646 .952 r
.26256 .41382 .27021 .42134 .28146 .42226 .27383 .41472 Mtetra
.412 .644 .952 r
.27383 .41472 .28146 .42226 .2928 .42325 .28519 .4157 Mtetra
.406 .642 .952 r
.28519 .4157 .2928 .42325 .30422 .4243 .29663 .41676 Mtetra
.4 .64 .953 r
.29663 .41676 .30422 .4243 .31573 .42541 .30814 .41791 Mtetra
.392 .638 .954 r
.30814 .41791 .31573 .42541 .32732 .42658 .31975 .41914 Mtetra
.385 .637 .955 r
.31975 .41914 .32732 .42658 .339 .42778 .33144 .42043 Mtetra
.377 .637 .957 r
.33144 .42043 .339 .42778 .35076 .42902 .34322 .4218 Mtetra
.369 .638 .959 r
.34322 .4218 .35076 .42902 .36262 .43025 .35509 .42321 Mtetra
.362 .641 .961 r
.35509 .42321 .36262 .43025 .37458 .43145 .36706 .42462 Mtetra
.354 .645 .965 r
.36706 .42462 .37458 .43145 .38663 .43258 .37912 .42603 Mtetra
.351 .653 .969 r
.37912 .42603 .38663 .43258 .39879 .43356 .39129 .42732 Mtetra
.347 .663 .973 r
.39129 .42732 .39879 .43356 .41104 .43434 .40356 .42849 Mtetra
.352 .679 .978 r
.40356 .42849 .41104 .43434 .4234 .43481 .41593 .42938 Mtetra
.362 .7 .984 r
.41593 .42938 .4234 .43481 .43587 .43486 .42842 .42989 Mtetra
.381 .726 .99 r
.42842 .42989 .43587 .43486 .44843 .43437 .44101 .42989 Mtetra
.417 .761 .995 r
.44101 .42989 .44843 .43437 .4611 .43318 .45371 .42914 Mtetra
.47 .801 .999 r
.45371 .42914 .4611 .43318 .47387 .43111 .46652 .42742 Mtetra
.532 .84 .999 r
.46652 .42742 .47387 .43111 .48672 .42807 .47942 .42459 Mtetra
.61 .875 .991 r
.47942 .42459 .48672 .42807 .49965 .42383 .49241 .42033 Mtetra
.68 .895 .975 r
.49241 .42033 .49965 .42383 .51265 .4184 .50547 .41462 Mtetra
.726 .896 .956 r
.50547 .41462 .51265 .4184 .5257 .41199 .51859 .40778 Mtetra
.759 .888 .937 r
.51859 .40778 .5257 .41199 .5388 .40468 .53174 .39996 Mtetra
.778 .876 .918 r
.53174 .39996 .5388 .40468 .55192 .39664 .54493 .39137 Mtetra
.789 .861 .903 r
.54493 .39137 .55192 .39664 .56507 .38805 .55813 .38224 Mtetra
.794 .847 .891 r
.55813 .38224 .56507 .38805 .57824 .37901 .57136 .3727 Mtetra
.797 .835 .88 r
.57136 .3727 .57824 .37901 .59143 .36964 .5846 .36286 Mtetra
.796 .823 .873 r
.5846 .36286 .59143 .36964 .60464 .36004 .59786 .35287 Mtetra
.796 .814 .866 r
.59786 .35287 .60464 .36004 .61786 .35027 .61113 .34274 Mtetra
.794 .806 .862 r
.61113 .34274 .61786 .35027 .63109 .3404 .62442 .33258 Mtetra
.791 .799 .859 r
.62442 .33258 .63109 .3404 .64435 .33047 .63772 .3224 Mtetra
.789 .794 .856 r
.63772 .3224 .64435 .33047 .65762 .32051 .65104 .31223 Mtetra
.787 .79 .855 r
.65104 .31223 .65762 .32051 .67091 .31056 .66438 .30212 Mtetra
.785 .786 .854 r
.66438 .30212 .67091 .31056 .68422 .30063 .67774 .29205 Mtetra
.783 .784 .853 r
.67774 .29205 .68422 .30063 .69755 .29073 .69113 .28204 Mtetra
.781 .782 .853 r
.69113 .28204 .69755 .29073 .71091 .28088 .70453 .27209 Mtetra
.779 .78 .854 r
.70453 .27209 .71091 .28088 .72428 .27106 .71796 .26221 Mtetra
.778 .78 .854 r
.71796 .26221 .72428 .27106 .73768 .26128 .73142 .25238 Mtetra
.777 .779 .855 r
.73142 .25238 .73768 .26128 .75111 .25154 .7449 .24259 Mtetra
.776 .779 .856 r
.7449 .24259 .75111 .25154 .76456 .24183 .7584 .23285 Mtetra
.775 .779 .856 r
.7584 .23285 .76456 .24183 .77803 .23214 .77193 .22314 Mtetra
.775 .78 .857 r
.77193 .22314 .77803 .23214 .79153 .22246 .78549 .21345 Mtetra
.775 .781 .858 r
.78549 .21345 .79153 .22246 .80505 .21279 .79907 .20376 Mtetra
.775 .782 .859 r
.79907 .20376 .80505 .21279 .8186 .20311 .81267 .19407 Mtetra
.433 .659 .955 r
.18872 .40222 .19654 .4095 .20735 .41014 .19955 .40279 Mtetra
.433 .657 .954 r
.19955 .40279 .20735 .41014 .21824 .4108 .21046 .40337 Mtetra
.432 .655 .953 r
.21046 .40337 .21824 .4108 .2292 .41148 .22144 .40399 Mtetra
.431 .653 .953 r
.22144 .40399 .2292 .41148 .24024 .41221 .2325 .40465 Mtetra
.428 .651 .952 r
.2325 .40465 .24024 .41221 .25136 .41298 .24364 .40538 Mtetra
.424 .648 .951 r
.24364 .40538 .25136 .41298 .26256 .41382 .25486 .40617 Mtetra
.419 .645 .951 r
.25486 .40617 .26256 .41382 .27383 .41472 .26615 .40705 Mtetra
.413 .642 .951 r
.26615 .40705 .27383 .41472 .28519 .4157 .27752 .40802 Mtetra
.406 .639 .951 r
.27752 .40802 .28519 .4157 .29663 .41676 .28897 .40909 Mtetra
.397 .636 .952 r
.28897 .40909 .29663 .41676 .30814 .41791 .3005 .41027 Mtetra
.388 .634 .952 r
.3005 .41027 .30814 .41791 .31975 .41914 .31212 .41157 Mtetra
.378 .632 .953 r
.31212 .41157 .31975 .41914 .33144 .42043 .32382 .41298 Mtetra
.365 .63 .955 r
.32382 .41298 .33144 .42043 .34322 .4218 .33561 .4145 Mtetra
.353 .629 .957 r
.33561 .4145 .34322 .4218 .35509 .42321 .34749 .41611 Mtetra
.339 .629 .959 r
.34749 .41611 .35509 .42321 .36706 .42462 .35946 .41779 Mtetra
.324 .631 .961 r
.35946 .41779 .36706 .42462 .37912 .42603 .37153 .41951 Mtetra
.312 .636 .965 r
.37153 .41951 .37912 .42603 .39129 .42732 .38371 .42121 Mtetra
.297 .642 .967 r
.38371 .42121 .39129 .42732 .40356 .42849 .39599 .42286 Mtetra
.289 .655 .97 r
.39599 .42286 .40356 .42849 .41593 .42938 .40838 .4243 Mtetra
.286 .672 .972 r
.40838 .4243 .41593 .42938 .42842 .42989 .42088 .42543 Mtetra
.292 .696 .974 r
.42088 .42543 .42842 .42989 .44101 .42989 .43349 .42609 Mtetra
.322 .735 .978 r
.43349 .42609 .44101 .42989 .45371 .42914 .44622 .42597 Mtetra
.373 .782 .982 r
.44622 .42597 .45371 .42914 .46652 .42742 .45907 .42485 Mtetra
.448 .837 .984 r
.45907 .42485 .46652 .42742 .47942 .42459 .47202 .42241 Mtetra
.565 .897 .983 r
.47202 .42241 .47942 .42459 .49241 .42033 .48507 .41811 Mtetra
.671 .93 .971 r
.48507 .41811 .49241 .42033 .50547 .41462 .4982 .41194 Mtetra
.735 .931 .954 r
.4982 .41194 .50547 .41462 .51859 .40778 .51139 .40445 Mtetra
.774 .917 .934 r
.51139 .40445 .51859 .40778 .53174 .39996 .52461 .39592 Mtetra
.796 .899 .915 r
.52461 .39592 .53174 .39996 .54493 .39137 .53786 .38659 Mtetra
.804 .878 .9 r
.53786 .38659 .54493 .39137 .55813 .38224 .55113 .37676 Mtetra
.808 .86 .887 r
.55113 .37676 .55813 .38224 .57136 .3727 .56441 .3666 Mtetra
.808 .843 .877 r
.56441 .3666 .57136 .3727 .5846 .36286 .57771 .3562 Mtetra
.805 .829 .87 r
.57771 .3562 .5846 .36286 .59786 .35287 .59102 .34573 Mtetra
.802 .818 .863 r
.59102 .34573 .59786 .35287 .61113 .34274 .60434 .3352 Mtetra
.799 .808 .859 r
.60434 .3352 .61113 .34274 .62442 .33258 .61768 .3247 Mtetra
.795 .8 .856 r
.61768 .3247 .62442 .33258 .63772 .3224 .63103 .31423 Mtetra
.792 .794 .854 r
.63103 .31423 .63772 .3224 .65104 .31223 .6444 .30384 Mtetra
.789 .789 .852 r
.6444 .30384 .65104 .31223 .66438 .30212 .65779 .29354 Mtetra
.786 .785 .852 r
.65779 .29354 .66438 .30212 .67774 .29205 .6712 .28332 Mtetra
.783 .782 .852 r
.6712 .28332 .67774 .29205 .69113 .28204 .68464 .2732 Mtetra
.781 .78 .852 r
.68464 .2732 .69113 .28204 .70453 .27209 .6981 .26316 Mtetra
.779 .779 .852 r
.6981 .26316 .70453 .27209 .71796 .26221 .71158 .25321 Mtetra
.777 .778 .853 r
.71158 .25321 .71796 .26221 .73142 .25238 .72509 .24333 Mtetra
.776 .778 .854 r
.72509 .24333 .73142 .25238 .7449 .24259 .73862 .23351 Mtetra
.775 .778 .855 r
.73862 .23351 .7449 .24259 .7584 .23285 .75219 .22375 Mtetra
.774 .778 .856 r
.75219 .22375 .7584 .23285 .77193 .22314 .76577 .21403 Mtetra
.774 .779 .857 r
.76577 .21403 .77193 .22314 .78549 .21345 .77939 .20433 Mtetra
.774 .78 .858 r
.77939 .20433 .78549 .21345 .79907 .20376 .79303 .19464 Mtetra
.774 .781 .859 r
.79303 .19464 .79907 .20376 .81267 .19407 .80669 .18495 Mtetra
.437 .661 .955 r
.18084 .39488 .18872 .40222 .19955 .40279 .19169 .39536 Mtetra
.438 .659 .954 r
.19169 .39536 .19955 .40279 .21046 .40337 .20262 .39586 Mtetra
.437 .657 .953 r
.20262 .39586 .21046 .40337 .22144 .40399 .21362 .3964 Mtetra
.435 .654 .952 r
.21362 .3964 .22144 .40399 .2325 .40465 .22471 .39699 Mtetra
.432 .651 .951 r
.22471 .39699 .2325 .40465 .24364 .40538 .23586 .39765 Mtetra
.428 .648 .95 r
.23586 .39765 .24364 .40538 .25486 .40617 .2471 .39839 Mtetra
.422 .644 .95 r
.2471 .39839 .25486 .40617 .26615 .40705 .2584 .39923 Mtetra
.415 .64 .949 r
.2584 .39923 .26615 .40705 .27752 .40802 .26979 .40018 Mtetra
.406 .636 .949 r
.26979 .40018 .27752 .40802 .28897 .40909 .28126 .40126 Mtetra
.396 .633 .95 r
.28126 .40126 .28897 .40909 .3005 .41027 .2928 .40248 Mtetra
.384 .628 .95 r
.2928 .40248 .3005 .41027 .31212 .41157 .30443 .40385 Mtetra
.371 .625 .951 r
.30443 .40385 .31212 .41157 .32382 .41298 .31614 .40536 Mtetra
.354 .621 .952 r
.31614 .40536 .32382 .41298 .33561 .4145 .32793 .40705 Mtetra
.337 .618 .954 r
.32793 .40705 .33561 .4145 .34749 .41611 .33982 .40889 Mtetra
.316 .615 .955 r
.33982 .40889 .34749 .41611 .35946 .41779 .3518 .41086 Mtetra
.292 .613 .956 r
.3518 .41086 .35946 .41779 .37153 .41951 .36388 .41297 Mtetra
.269 .613 .957 r
.36388 .41297 .37153 .41951 .38371 .42121 .37605 .41514 Mtetra
.238 .612 .954 r
.37605 .41514 .38371 .42121 .39599 .42286 .38833 .41737 Mtetra
.213 .617 .951 r
.38833 .41737 .39599 .42286 .40838 .4243 .40073 .41949 Mtetra
.186 .623 .944 r
.40073 .41949 .40838 .4243 .42088 .42543 .41323 .42143 Mtetra
.165 .635 .931 r
.41323 .42143 .42088 .42543 .43349 .42609 .42586 .42301 Mtetra
.176 .667 .921 r
.42586 .42301 .43349 .42609 .44622 .42597 .43862 .4238 Mtetra
.204 .706 .908 r
.43862 .4238 .44622 .42597 .45907 .42485 .45149 .42363 Mtetra
.288 .776 .905 r
.45149 .42363 .45907 .42485 .47202 .42241 .4645 .42188 Mtetra
.471 .887 .925 r
.4645 .42188 .47202 .42241 .48507 .41811 .47762 .41755 Mtetra
.649 .957 .936 r
.47762 .41755 .48507 .41811 .4982 .41194 .49083 .41064 Mtetra
.747 .966 .934 r
.49083 .41064 .4982 .41194 .51139 .40445 .5041 .40212 Mtetra
.793 .946 .923 r
.5041 .40212 .51139 .40445 .52461 .39592 .5174 .39261 Mtetra
.817 .92 .906 r
.5174 .39261 .52461 .39592 .53786 .38659 .53072 .38229 Mtetra
.823 .893 .892 r
.53072 .38229 .53786 .38659 .55113 .37676 .54405 .37158 Mtetra
.822 .869 .881 r
.54405 .37158 .55113 .37676 .56441 .3666 .55739 .36065 Mtetra
.82 .849 .871 r
.55739 .36065 .56441 .3666 .57771 .3562 .57075 .34959 Mtetra
.814 .833 .864 r
.57075 .34959 .57771 .3562 .59102 .34573 .58411 .33856 Mtetra
.809 .819 .858 r
.58411 .33856 .59102 .34573 .60434 .3352 .59748 .32757 Mtetra
.804 .808 .855 r
.59748 .32757 .60434 .3352 .61768 .3247 .61087 .31668 Mtetra
.799 .799 .852 r
.61087 .31668 .61768 .3247 .63103 .31423 .62427 .30591 Mtetra
.794 .792 .85 r
.62427 .30591 .63103 .31423 .6444 .30384 .63769 .29527 Mtetra
.79 .787 .849 r
.63769 .29527 .6444 .30384 .65779 .29354 .65114 .28478 Mtetra
.787 .783 .849 r
.65114 .28478 .65779 .29354 .6712 .28332 .6646 .27441 Mtetra
.783 .78 .849 r
.6646 .27441 .6712 .28332 .68464 .2732 .67809 .26417 Mtetra
.781 .778 .85 r
.67809 .26417 .68464 .2732 .6981 .26316 .6916 .25405 Mtetra
.778 .776 .851 r
.6916 .25405 .6981 .26316 .71158 .25321 .70513 .24404 Mtetra
.776 .776 .852 r
.70513 .24404 .71158 .25321 .72509 .24333 .7187 .23413 Mtetra
.775 .775 .853 r
.7187 .23413 .72509 .24333 .73862 .23351 .73229 .22429 Mtetra
.774 .776 .855 r
.73229 .22429 .73862 .23351 .75219 .22375 .74591 .21452 Mtetra
.773 .776 .856 r
.74591 .21452 .75219 .22375 .76577 .21403 .75956 .20479 Mtetra
.772 .777 .857 r
.75956 .20479 .76577 .21403 .77939 .20433 .77323 .1951 Mtetra
.772 .779 .858 r
.77323 .1951 .77939 .20433 .79303 .19464 .78693 .18542 Mtetra
.772 .78 .859 r
.78693 .18542 .79303 .19464 .80669 .18495 .80066 .17574 Mtetra
.443 .663 .955 r
.17289 .38748 .18084 .39488 .19169 .39536 .18377 .38786 Mtetra
.443 .661 .954 r
.18377 .38786 .19169 .39536 .20262 .39586 .19472 .38826 Mtetra
.443 .658 .952 r
.19472 .38826 .20262 .39586 .21362 .3964 .20575 .3887 Mtetra
.441 .655 .951 r
.20575 .3887 .21362 .3964 .22471 .39699 .21685 .3892 Mtetra
.437 .652 .95 r
.21685 .3892 .22471 .39699 .23586 .39765 .22803 .38978 Mtetra
.432 .648 .949 r
.22803 .38978 .23586 .39765 .2471 .39839 .23928 .39045 Mtetra
.426 .643 .948 r
.23928 .39045 .2471 .39839 .2584 .39923 .25061 .39124 Mtetra
.418 .639 .947 r
.25061 .39124 .2584 .39923 .26979 .40018 .26201 .39216 Mtetra
.408 .634 .947 r
.26201 .39216 .26979 .40018 .28126 .40126 .27349 .39324 Mtetra
.396 .629 .947 r
.27349 .39324 .28126 .40126 .2928 .40248 .28505 .39448 Mtetra
.381 .623 .948 r
.28505 .39448 .2928 .40248 .30443 .40385 .29668 .39592 Mtetra
.365 .617 .948 r
.29668 .39592 .30443 .40385 .31614 .40536 .3084 .39756 Mtetra
.344 .611 .949 r
.3084 .39756 .31614 .40536 .32793 .40705 .3202 .39942 Mtetra
.32 .605 .949 r
.3202 .39942 .32793 .40705 .33982 .40889 .33209 .4015 Mtetra
.292 .598 .949 r
.33209 .4015 .33982 .40889 .3518 .41086 .34407 .40381 Mtetra
.257 .59 .948 r
.34407 .40381 .3518 .41086 .36388 .41297 .35615 .40635 Mtetra
.219 .583 .944 r
.35615 .40635 .36388 .41297 .37605 .41514 .36832 .40907 Mtetra
.166 .57 .934 r
.36832 .40907 .37605 .41514 .38833 .41737 .38059 .412 Mtetra
.116 .561 .918 r
.38059 .412 .38833 .41737 .40073 .41949 .39298 .41498 Mtetra
.052 .544 .887 r
.39298 .41498 .40073 .41949 .41323 .42143 .40549 .41797 Mtetra
0 .525 .838 r
.40549 .41797 .41323 .42143 .42586 .42301 .41811 .42078 Mtetra
0 .535 .792 r
.41811 .42078 .42586 .42301 .43862 .4238 .43088 .42281 Mtetra
0 .547 .738 r
.43088 .42281 .43862 .4238 .45149 .42363 .44378 .42392 Mtetra
.065 .629 .729 r
.44378 .42392 .45149 .42363 .4645 .42188 .45683 .42306 Mtetra
.339 .819 .802 r
.45683 .42306 .4645 .42188 .47762 .41755 .47003 .4187 Mtetra
.616 .958 .867 r
.47003 .4187 .47762 .41755 .49083 .41064 .48334 .41083 Mtetra
.756 .989 .893 r
.48334 .41083 .49083 .41064 .5041 .40212 .4967 .40097 Mtetra
.814 .972 .899 r
.4967 .40097 .5041 .40212 .5174 .39261 .51009 .39014 Mtetra
.841 .941 .889 r
.51009 .39014 .5174 .39261 .53072 .38229 .52349 .37851 Mtetra
.844 .907 .88 r
.52349 .37851 .53072 .38229 .54405 .37158 .5369 .36667 Mtetra
.839 .878 .871 r
.5369 .36667 .54405 .37158 .55739 .36065 .5503 .35481 Mtetra
.832 .854 .862 r
.5503 .35481 .55739 .36065 .57075 .34959 .56371 .34296 Mtetra
.824 .835 .857 r
.56371 .34296 .57075 .34959 .58411 .33856 .57713 .3313 Mtetra
.816 .819 .852 r
.57713 .3313 .58411 .33856 .59748 .32757 .59056 .31979 Mtetra
.809 .807 .849 r
.59056 .31979 .59748 .32757 .61087 .31668 .604 .30849 Mtetra
.802 .797 .847 r
.604 .30849 .61087 .31668 .62427 .30591 .61745 .29739 Mtetra
.797 .79 .846 r
.61745 .29739 .62427 .30591 .63769 .29527 .63093 .28649 Mtetra
.791 .784 .846 r
.63093 .28649 .63769 .29527 .65114 .28478 .64442 .2758 Mtetra
.787 .78 .846 r
.64442 .2758 .65114 .28478 .6646 .27441 .65793 .26528 Mtetra
.783 .777 .847 r
.65793 .26528 .6646 .27441 .67809 .26417 .67147 .25494 Mtetra
.78 .774 .848 r
.67147 .25494 .67809 .26417 .6916 .25405 .68503 .24475 Mtetra
.777 .773 .849 r
.68503 .24475 .6916 .25405 .70513 .24404 .69863 .23469 Mtetra
.775 .773 .851 r
.69863 .23469 .70513 .24404 .7187 .23413 .71225 .22475 Mtetra
.773 .773 .852 r
.71225 .22475 .7187 .23413 .73229 .22429 .7259 .2149 Mtetra
.772 .773 .854 r
.7259 .2149 .73229 .22429 .74591 .21452 .73957 .20513 Mtetra
.771 .774 .856 r
.73957 .20513 .74591 .21452 .75956 .20479 .75328 .19542 Mtetra
.77 .776 .857 r
.75328 .19542 .75956 .20479 .77323 .1951 .76702 .18575 Mtetra
.77 .778 .859 r
.76702 .18575 .77323 .1951 .78693 .18542 .78078 .1761 Mtetra
.771 .779 .86 r
.78078 .1761 .78693 .18542 .80066 .17574 .79457 .16645 Mtetra
.45 .666 .955 r
.16488 .38002 .17289 .38748 .18377 .38786 .17578 .38028 Mtetra
.45 .663 .953 r
.17578 .38028 .18377 .38786 .19472 .38826 .18676 .38056 Mtetra
.45 .66 .951 r
.18676 .38056 .19472 .38826 .20575 .3887 .19781 .38089 Mtetra
.448 .656 .95 r
.19781 .38089 .20575 .3887 .21685 .3892 .20894 .38128 Mtetra
.444 .652 .948 r
.20894 .38128 .21685 .3892 .22803 .38978 .22014 .38176 Mtetra
.439 .648 .947 r
.22014 .38176 .22803 .38978 .23928 .39045 .23141 .38234 Mtetra
.432 .643 .946 r
.23141 .38234 .23928 .39045 .25061 .39124 .24276 .38306 Mtetra
.423 .637 .945 r
.24276 .38306 .25061 .39124 .26201 .39216 .25418 .38393 Mtetra
.412 .631 .944 r
.25418 .38393 .26201 .39216 .27349 .39324 .26567 .38499 Mtetra
.398 .624 .944 r
.26567 .38499 .27349 .39324 .28505 .39448 .27724 .38625 Mtetra
.381 .617 .944 r
.27724 .38625 .28505 .39448 .29668 .39592 .28889 .38774 Mtetra
.361 .61 .944 r
.28889 .38774 .29668 .39592 .3084 .39756 .30062 .38948 Mtetra
.337 .601 .944 r
.30062 .38948 .3084 .39756 .3202 .39942 .31242 .39151 Mtetra
.307 .591 .944 r
.31242 .39151 .3202 .39942 .33209 .4015 .32431 .39384 Mtetra
.271 .58 .942 r
.32431 .39384 .33209 .4015 .34407 .40381 .33629 .39649 Mtetra
.226 .566 .938 r
.33629 .39649 .34407 .40381 .35615 .40635 .34835 .39948 Mtetra
.173 .549 .929 r
.34835 .39948 .35615 .40635 .36832 .40907 .36052 .4028 Mtetra
.1 .523 .909 r
.36052 .4028 .36832 .40907 .38059 .412 .37278 .40649 Mtetra
.022 .495 .877 r
.37278 .40649 .38059 .412 .39298 .41498 .38515 .41044 Mtetra
0 .448 .816 r
.38515 .41044 .39298 .41498 .40549 .41797 .39764 .41465 Mtetra
0 .391 .723 r
.39764 .41465 .40549 .41797 .41811 .42078 .41025 .41897 Mtetra
.24 0 0 r
.41025 .41897 .41811 .42078 .43088 .42281 .42301 .42277 Mtetra
.338 0 0 r
.42301 .42277 .43088 .42281 .44378 .42392 .4359 .42651 Mtetra
.281 0 0 r
.4359 .42651 .44378 .42392 .45683 .42306 .44897 .4278 Mtetra
0 0 0 r
.44897 .4278 .45683 .42306 .47003 .4187 .46226 .42342 Mtetra
.512 .877 .657 r
.46226 .42342 .47003 .4187 .48334 .41083 .47571 .41334 Mtetra
.772 .995 .801 r
.47571 .41334 .48334 .41083 .4967 .40097 .4892 .40077 Mtetra
.844 .984 .864 r
.4892 .40077 .4967 .40097 .51009 .39014 .50269 .38811 Mtetra
.867 .946 .865 r
.50269 .38811 .51009 .39014 .52349 .37851 .51618 .37489 Mtetra
.864 .908 .861 r
.51618 .37489 .52349 .37851 .5369 .36667 .52966 .36174 Mtetra
.853 .877 .856 r
.52966 .36174 .5369 .36667 .5503 .35481 .54314 .34882 Mtetra
.843 .851 .85 r
.54314 .34882 .5503 .35481 .56371 .34296 .55661 .33613 Mtetra
.831 .831 .847 r
.55661 .33613 .56371 .34296 .57713 .3313 .57009 .32378 Mtetra
.821 .815 .844 r
.57009 .32378 .57713 .3313 .59056 .31979 .58357 .31174 Mtetra
.812 .802 .842 r
.58357 .31174 .59056 .31979 .604 .30849 .59706 .30001 Mtetra
.804 .793 .841 r
.59706 .30001 .604 .30849 .61745 .29739 .61057 .28858 Mtetra
.798 .785 .841 r
.61057 .28858 .61745 .29739 .63093 .28649 .62409 .27743 Mtetra
.792 .779 .842 r
.62409 .27743 .63093 .28649 .64442 .2758 .63763 .26655 Mtetra
.787 .775 .843 r
.63763 .26655 .64442 .2758 .65793 .26528 .6512 .2559 Mtetra
.782 .772 .844 r
.6512 .2559 .65793 .26528 .67147 .25494 .66479 .24546 Mtetra
.778 .77 .846 r
.66479 .24546 .67147 .25494 .68503 .24475 .67841 .23521 Mtetra
.775 .769 .847 r
.67841 .23521 .68503 .24475 .69863 .23469 .69205 .22512 Mtetra
.773 .769 .849 r
.69205 .22512 .69863 .23469 .71225 .22475 .70573 .21517 Mtetra
.771 .77 .851 r
.70573 .21517 .71225 .22475 .7259 .2149 .71944 .20534 Mtetra
.77 .771 .853 r
.71944 .20534 .7259 .2149 .73957 .20513 .73318 .19559 Mtetra
.769 .772 .855 r
.73318 .19559 .73957 .20513 .75328 .19542 .74695 .18592 Mtetra
.768 .774 .857 r
.74695 .18592 .75328 .19542 .76702 .18575 .76075 .17628 Mtetra
.768 .776 .859 r
.76075 .17628 .76702 .18575 .78078 .1761 .77457 .16668 Mtetra
.769 .778 .861 r
.77457 .16668 .78078 .1761 .79457 .16645 .78843 .15707 Mtetra
.457 .67 .955 r
.1568 .3725 .16488 .38002 .17578 .38028 .16773 .37262 Mtetra
.459 .666 .952 r
.16773 .37262 .17578 .38028 .18676 .38056 .17874 .37276 Mtetra
.458 .663 .95 r
.17874 .37276 .18676 .38056 .19781 .38089 .18982 .37295 Mtetra
.456 .658 .948 r
.18982 .37295 .19781 .38089 .20894 .38128 .20097 .37321 Mtetra
.452 .653 .946 r
.20097 .37321 .20894 .38128 .22014 .38176 .21219 .37357 Mtetra
.447 .648 .944 r
.21219 .37357 .22014 .38176 .23141 .38234 .22349 .37404 Mtetra
.439 .642 .943 r
.22349 .37404 .23141 .38234 .24276 .38306 .23486 .37467 Mtetra
.429 .636 .942 r
.23486 .37467 .24276 .38306 .25418 .38393 .2463 .37547 Mtetra
.417 .628 .941 r
.2463 .37547 .25418 .38393 .26567 .38499 .25781 .37648 Mtetra
.402 .621 .94 r
.25781 .37648 .26567 .38499 .27724 .38625 .26939 .37773 Mtetra
.384 .612 .94 r
.26939 .37773 .27724 .38625 .28889 .38774 .28105 .37925 Mtetra
.361 .602 .94 r
.28105 .37925 .28889 .38774 .30062 .38948 .29278 .38108 Mtetra
.333 .591 .939 r
.29278 .38108 .30062 .38948 .31242 .39151 .30459 .38326 Mtetra
.298 .577 .938 r
.30459 .38326 .31242 .39151 .32431 .39384 .31648 .38582 Mtetra
.255 .561 .934 r
.31648 .38582 .32431 .39384 .33629 .39649 .32845 .38881 Mtetra
.199 .54 .927 r
.32845 .38881 .33629 .39649 .34835 .39948 .3405 .39226 Mtetra
.129 .512 .912 r
.3405 .39226 .34835 .39948 .36052 .4028 .35265 .39622 Mtetra
.036 .471 .88 r
.35265 .39622 .36052 .4028 .37278 .40649 .36489 .40073 Mtetra
0 .415 .825 r
.36489 .40073 .37278 .40649 .38515 .41044 .37724 .4058 Mtetra
0 .331 .722 r
.37724 .4058 .38515 .41044 .39764 .41465 .38969 .41148 Mtetra
.367 0 0 r
.38969 .41148 .39764 .41465 .41025 .41897 .40227 .41777 Mtetra
.49 0 0 r
.40227 .41777 .41025 .41897 .42301 .42277 .41497 .42454 Mtetra
.673 .147 0 r
.41497 .42454 .42301 .42277 .4359 .42651 .42772 .43493 Mtetra
.601 .138 .124 r
.42772 .43493 .4359 .42651 .44897 .4278 .44073 .4421 Mtetra
.301 0 .082 r
.44073 .4421 .44897 .4278 .46226 .42342 .45416 .4377 Mtetra
0 0 0 r
.45416 .4377 .46226 .42342 .47571 .41334 .46785 .42169 Mtetra
.732 .915 .554 r
.46785 .42169 .47571 .41334 .4892 .40077 .48157 .40239 Mtetra
.876 .993 .798 r
.48157 .40239 .4892 .40077 .50269 .38811 .49519 .38668 Mtetra
.895 .949 .834 r
.49519 .38668 .50269 .38811 .51618 .37489 .50878 .3714 Mtetra
.883 .907 .84 r
.50878 .3714 .51618 .37489 .52966 .36174 .52235 .3567 Mtetra
.867 .873 .839 r
.52235 .3567 .52966 .36174 .54314 .34882 .53589 .34257 Mtetra
.851 .845 .837 r
.53589 .34257 .54314 .34882 .55661 .33613 .54943 .32897 Mtetra
.838 .825 .836 r
.54943 .32897 .55661 .33613 .57009 .32378 .56297 .3159 Mtetra
.825 .808 .834 r
.56297 .3159 .57009 .32378 .58357 .31174 .57651 .3033 Mtetra
.815 .796 .834 r
.57651 .3033 .58357 .31174 .59706 .30001 .59005 .29115 Mtetra
.806 .786 .835 r
.59005 .29115 .59706 .30001 .61057 .28858 .60361 .2794 Mtetra
.798 .779 .835 r
.60361 .2794 .61057 .28858 .62409 .27743 .61718 .26802 Mtetra
.791 .773 .837 r
.61718 .26802 .62409 .27743 .63763 .26655 .63078 .25696 Mtetra
.785 .769 .839 r
.63078 .25696 .63763 .26655 .6512 .2559 .64439 .2462 Mtetra
.78 .767 .841 r
.64439 .2462 .6512 .2559 .66479 .24546 .65804 .2357 Mtetra
.776 .765 .843 r
.65804 .2357 .66479 .24546 .67841 .23521 .67171 .22541 Mtetra
.773 .765 .845 r
.67171 .22541 .67841 .23521 .69205 .22512 .68542 .21532 Mtetra
.771 .765 .848 r
.68542 .21532 .69205 .22512 .70573 .21517 .69915 .20538 Mtetra
.768 .766 .85 r
.69915 .20538 .70573 .21517 .71944 .20534 .71292 .19558 Mtetra
.767 .767 .853 r
.71292 .19558 .71944 .20534 .73318 .19559 .72672 .18588 Mtetra
.766 .769 .855 r
.72672 .18588 .73318 .19559 .74695 .18592 .74055 .17626 Mtetra
.766 .772 .858 r
.74055 .17626 .74695 .18592 .76075 .17628 .75441 .16669 Mtetra
.766 .774 .86 r
.75441 .16669 .76075 .17628 .77457 .16668 .76831 .15715 Mtetra
.766 .777 .862 r
.76831 .15715 .77457 .16668 .78843 .15707 .78223 .14761 Mtetra
.467 .674 .954 r
.14865 .36491 .1568 .3725 .16773 .37262 .15962 .36487 Mtetra
.468 .67 .951 r
.15962 .36487 .16773 .37262 .17874 .37276 .17065 .36485 Mtetra
.468 .665 .949 r
.17065 .36485 .17874 .37276 .18982 .37295 .18176 .36488 Mtetra
.466 .66 .946 r
.18176 .36488 .18982 .37295 .20097 .37321 .19295 .36498 Mtetra
.462 .655 .944 r
.19295 .36498 .20097 .37321 .21219 .37357 .2042 .36519 Mtetra
.456 .649 .942 r
.2042 .36519 .21219 .37357 .22349 .37404 .21552 .36553 Mtetra
.448 .642 .94 r
.21552 .36553 .22349 .37404 .23486 .37467 .22691 .36604 Mtetra
.438 .635 .938 r
.22691 .36604 .23486 .37467 .2463 .37547 .23837 .36674 Mtetra
.425 .626 .937 r
.23837 .36674 .2463 .37547 .25781 .37648 .2499 .36767 Mtetra
.409 .617 .936 r
.2499 .36767 .25781 .37648 .26939 .37773 .2615 .36888 Mtetra
.389 .607 .935 r
.2615 .36888 .26939 .37773 .28105 .37925 .27317 .3704 Mtetra
.364 .595 .934 r
.27317 .3704 .28105 .37925 .29278 .38108 .28491 .37228 Mtetra
.334 .581 .933 r
.28491 .37228 .29278 .38108 .30459 .38326 .29672 .37457 Mtetra
.295 .564 .931 r
.29672 .37457 .30459 .38326 .31648 .38582 .30861 .37733 Mtetra
.245 .543 .926 r
.30861 .37733 .31648 .38582 .32845 .38881 .32057 .38063 Mtetra
.182 .516 .916 r
.32057 .38063 .32845 .38881 .3405 .39226 .33261 .38452 Mtetra
.097 .477 .895 r
.33261 .38452 .3405 .39226 .35265 .39622 .34474 .3891 Mtetra
0 .424 .856 r
.34474 .3891 .35265 .39622 .36489 .40073 .35695 .39442 Mtetra
0 .342 .779 r
.35695 .39442 .36489 .40073 .37724 .4058 .36926 .40065 Mtetra
0 .231 .649 r
.36926 .40065 .37724 .4058 .38969 .41148 .38167 .40785 Mtetra
.49 0 0 r
.38167 .40785 .38969 .41148 .40227 .41777 .39419 .41626 Mtetra
.637 .075 0 r
.39419 .41626 .40227 .41777 .41497 .42454 .4068 .42647 Mtetra
.799 .336 .137 r
.4068 .42647 .41497 .42454 .42772 .43493 .41932 .44518 Mtetra
.712 .288 .24 r
.41932 .44518 .42772 .43493 .44073 .4421 .43221 .45985 Mtetra
.344 0 .156 r
.43221 .45985 .44073 .4421 .45416 .4377 .44579 .45544 Mtetra
0 0 0 r
.44579 .45544 .45416 .4377 .46785 .42169 .45981 .43188 Mtetra
.864 .924 .534 r
.45981 .43188 .46785 .42169 .48157 .40239 .47381 .40417 Mtetra
.923 .973 .759 r
.47381 .40417 .48157 .40239 .49519 .38668 .48759 .38493 Mtetra
.916 .93 .805 r
.48759 .38493 .49519 .38668 .50878 .3714 .50129 .36745 Mtetra
.896 .89 .817 r
.50129 .36745 .50878 .3714 .52235 .3567 .51495 .35113 Mtetra
.876 .858 .82 r
.51495 .35113 .52235 .3567 .53589 .34257 .52857 .33575 Mtetra
.856 .832 .822 r
.52857 .33575 .53589 .34257 .54943 .32897 .54218 .32126 Mtetra
.841 .813 .823 r
.54218 .32126 .54943 .32897 .56297 .3159 .55578 .30747 Mtetra
.827 .798 .824 r
.55578 .30747 .56297 .3159 .57651 .3033 .56937 .29435 Mtetra
.815 .786 .825 r
.56937 .29435 .57651 .3033 .59005 .29115 .58297 .28181 Mtetra
.805 .777 .827 r
.58297 .28181 .59005 .29115 .60361 .2794 .59658 .26977 Mtetra
.796 .77 .829 r
.59658 .26977 .60361 .2794 .61718 .26802 .61021 .25819 Mtetra
.789 .766 .832 r
.61021 .25819 .61718 .26802 .63078 .25696 .62385 .247 Mtetra
.783 .762 .834 r
.62385 .247 .63078 .25696 .64439 .2462 .63752 .23616 Mtetra
.778 .761 .837 r
.63752 .23616 .64439 .2462 .65804 .2357 .65122 .22561 Mtetra
.774 .76 .84 r
.65122 .22561 .65804 .2357 .67171 .22541 .66495 .21533 Mtetra
.77 .76 .843 r
.66495 .21533 .67171 .22541 .68542 .21532 .67871 .20525 Mtetra
.767 .76 .846 r
.67871 .20525 .68542 .21532 .69915 .20538 .69251 .19536 Mtetra
.765 .762 .849 r
.69251 .19536 .69915 .20538 .71292 .19558 .70633 .18562 Mtetra
.764 .764 .852 r
.70633 .18562 .71292 .19558 .72672 .18588 .72019 .17599 Mtetra
.763 .766 .855 r
.72019 .17599 .72672 .18588 .74055 .17626 .73409 .16645 Mtetra
.763 .769 .858 r
.73409 .16645 .74055 .17626 .75441 .16669 .74802 .15696 Mtetra
.763 .772 .861 r
.74802 .15696 .75441 .16669 .76831 .15715 .76198 .14751 Mtetra
.763 .776 .863 r
.76198 .14751 .76831 .15715 .78223 .14761 .77598 .13806 Mtetra
.478 .678 .953 r
.14044 .35727 .14865 .36491 .15962 .36487 .15144 .35703 Mtetra
.479 .674 .95 r
.15144 .35703 .15962 .36487 .17065 .36485 .16251 .35682 Mtetra
.479 .669 .947 r
.16251 .35682 .17065 .36485 .18176 .36488 .17366 .35667 Mtetra
.477 .663 .944 r
.17366 .35667 .18176 .36488 .19295 .36498 .18487 .35659 Mtetra
.473 .657 .941 r
.18487 .35659 .19295 .36498 .2042 .36519 .19615 .35662 Mtetra
.467 .65 .938 r
.19615 .35662 .2042 .36519 .21552 .36553 .2075 .35679 Mtetra
.459 .642 .936 r
.2075 .35679 .21552 .36553 .22691 .36604 .21892 .35715 Mtetra
.448 .634 .934 r
.21892 .35715 .22691 .36604 .23837 .36674 .23041 .35771 Mtetra
.435 .625 .932 r
.23041 .35771 .23837 .36674 .2499 .36767 .24196 .35853 Mtetra
.418 .614 .931 r
.24196 .35853 .2499 .36767 .2615 .36888 .25357 .35965 Mtetra
.398 .602 .93 r
.25357 .35965 .2615 .36888 .27317 .3704 .26525 .36112 Mtetra
.372 .589 .928 r
.26525 .36112 .27317 .3704 .28491 .37228 .277 .36301 Mtetra
.34 .573 .926 r
.277 .36301 .28491 .37228 .29672 .37457 .28882 .36537 Mtetra
.299 .553 .923 r
.28882 .36537 .29672 .37457 .30861 .37733 .3007 .36827 Mtetra
.246 .528 .917 r
.3007 .36827 .30861 .37733 .32057 .38063 .31266 .37181 Mtetra
.178 .496 .905 r
.31266 .37181 .32057 .38063 .33261 .38452 .32469 .37606 Mtetra
.086 .449 .882 r
.32469 .37606 .33261 .38452 .34474 .3891 .33679 .38117 Mtetra
0 .389 .841 r
.33679 .38117 .34474 .3891 .35695 .39442 .34898 .3872 Mtetra
0 .294 .758 r
.34898 .3872 .35695 .39442 .36926 .40065 .36125 .39442 Mtetra
0 .174 .628 r
.36125 .39442 .36926 .40065 .38167 .40785 .37361 .40293 Mtetra
.533 0 0 r
.37361 .40293 .38167 .40785 .39419 .41626 .38607 .4131 Mtetra
.689 .145 0 r
.38607 .4131 .39419 .41626 .4068 .42647 .39861 .42592 Mtetra
.851 .406 .151 r
.39861 .42592 .4068 .42647 .41932 .44518 .41094 .45033 Mtetra
.788 .348 .202 r
.41094 .45033 .41932 .44518 .43221 .45985 .42372 .47011 Mtetra
.197 0 0 r
.42372 .47011 .43221 .45985 .44579 .45544 .43742 .46567 Mtetra
.884 .93 .549 r
.43742 .46567 .44579 .45544 .45981 .43188 .45172 .43695 Mtetra
.981 .913 .626 r
.45172 .43695 .45981 .43188 .47381 .40417 .46598 .40346 Mtetra
.947 .92 .752 r
.46598 .40346 .47381 .40417 .48759 .38493 .47991 .38152 Mtetra
.921 .887 .782 r
.47991 .38152 .48759 .38493 .50129 .36745 .49372 .36219 Mtetra
.897 .858 .795 r
.49372 .36219 .50129 .36745 .51495 .35113 .50748 .34448 Mtetra
.876 .833 .801 r
.50748 .34448 .51495 .35113 .52857 .33575 .52118 .32801 Mtetra
.856 .812 .806 r
.52118 .32801 .52857 .33575 .54218 .32126 .53486 .31272 Mtetra
.84 .796 .81 r
.53486 .31272 .54218 .32126 .55578 .30747 .54851 .29831 Mtetra
.825 .783 .813 r
.54851 .29831 .55578 .30747 .56937 .29435 .56216 .28474 Mtetra
.813 .773 .816 r
.56216 .28474 .56937 .29435 .58297 .28181 .57582 .27186 Mtetra
.802 .766 .819 r
.57582 .27186 .58297 .28181 .59658 .26977 .58948 .2596 Mtetra
.793 .76 .823 r
.58948 .2596 .59658 .26977 .61021 .25819 .60316 .24787 Mtetra
.786 .757 .826 r
.60316 .24787 .61021 .25819 .62385 .247 .61686 .23659 Mtetra
.78 .754 .83 r
.61686 .23659 .62385 .247 .63752 .23616 .63058 .22572 Mtetra
.774 .753 .834 r
.63058 .22572 .63752 .23616 .65122 .22561 .64434 .21517 Mtetra
.77 .753 .837 r
.64434 .21517 .65122 .22561 .66495 .21533 .65812 .20492 Mtetra
.766 .753 .841 r
.65812 .20492 .66495 .21533 .67871 .20525 .67194 .1949 Mtetra
.764 .755 .845 r
.67194 .1949 .67871 .20525 .69251 .19536 .68579 .18509 Mtetra
.761 .757 .849 r
.68579 .18509 .69251 .19536 .70633 .18562 .69968 .17543 Mtetra
.76 .76 .852 r
.69968 .17543 .70633 .18562 .72019 .17599 .71361 .1659 Mtetra
.759 .763 .855 r
.71361 .1659 .72019 .17599 .73409 .16645 .72757 .15647 Mtetra
.759 .766 .859 r
.72757 .15647 .73409 .16645 .74802 .15696 .74156 .14709 Mtetra
.759 .77 .862 r
.74156 .14709 .74802 .15696 .76198 .14751 .7556 .13776 Mtetra
.76 .774 .865 r
.7556 .13776 .76198 .14751 .77598 .13806 .76966 .12842 Mtetra
.49 .683 .952 r
.13216 .34956 .14044 .35727 .15144 .35703 .1432 .34911 Mtetra
.491 .678 .948 r
.1432 .34911 .15144 .35703 .16251 .35682 .15431 .34868 Mtetra
.491 .672 .945 r
.15431 .34868 .16251 .35682 .17366 .35667 .16549 .34831 Mtetra
.489 .666 .941 r
.16549 .34831 .17366 .35667 .18487 .35659 .17674 .34801 Mtetra
.485 .659 .938 r
.17674 .34801 .18487 .35659 .19615 .35662 .18806 .34784 Mtetra
.479 .651 .935 r
.18806 .34784 .19615 .35662 .2075 .35679 .19944 .34781 Mtetra
.471 .643 .932 r
.19944 .34781 .2075 .35679 .21892 .35715 .21089 .34797 Mtetra
.461 .634 .929 r
.21089 .34797 .21892 .35715 .23041 .35771 .2224 .34836 Mtetra
.448 .623 .927 r
.2224 .34836 .23041 .35771 .24196 .35853 .23398 .34902 Mtetra
.431 .612 .925 r
.23398 .34902 .24196 .35853 .25357 .35965 .24561 .35001 Mtetra
.41 .599 .923 r
.24561 .35001 .25357 .35965 .26525 .36112 .25731 .35138 Mtetra
.384 .584 .921 r
.25731 .35138 .26525 .36112 .277 .36301 .26907 .3532 Mtetra
.352 .566 .918 r
.26907 .3532 .277 .36301 .28882 .36537 .2809 .35555 Mtetra
.31 .544 .914 r
.2809 .35555 .28882 .36537 .3007 .36827 .29278 .35852 Mtetra
.257 .516 .908 r
.29278 .35852 .3007 .36827 .31266 .37181 .30473 .3622 Mtetra
.189 .481 .896 r
.30473 .3622 .31266 .37181 .32469 .37606 .31675 .36671 Mtetra
.098 .432 .874 r
.31675 .36671 .32469 .37606 .33679 .38117 .32884 .37219 Mtetra
0 .369 .835 r
.32884 .37219 .33679 .38117 .34898 .3872 .341 .37875 Mtetra
0 .278 .764 r
.341 .37875 .34898 .3872 .36125 .39442 .35324 .38665 Mtetra
0 .166 .657 r
.35324 .38665 .36125 .39442 .37361 .40293 .36556 .39602 Mtetra
.49 0 0 r
.36556 .39602 .37361 .40293 .38607 .4131 .37798 .40718 Mtetra
.642 .112 0 r
.37798 .40718 .38607 .4131 .39861 .42592 .39049 .42077 Mtetra
.85 .39 .033 r
.39049 .42077 .39861 .42592 .41094 .45033 .40281 .445 Mtetra
.784 .289 0 r
.40281 .445 .41094 .45033 .42372 .47011 .4156 .46433 Mtetra
.632 .827 .975 r
.4156 .46433 .42372 .47011 .43742 .46567 .42934 .45986 Mtetra
.932 .813 .705 r
.42934 .45986 .43742 .46567 .45172 .43695 .44375 .4315 Mtetra
.946 .806 .674 r
.44375 .4315 .45172 .43695 .46598 .40346 .45814 .39812 Mtetra
.921 .838 .745 r
.45814 .39812 .46598 .40346 .47991 .38152 .47218 .37533 Mtetra
.904 .832 .764 r
.47218 .37533 .47991 .38152 .49372 .36219 .4861 .35492 Mtetra
.885 .816 .775 r
.4861 .35492 .49372 .36219 .50748 .34448 .49994 .33625 Mtetra
.867 .801 .784 r
.49994 .33625 .50748 .34448 .52118 .32801 .51372 .31902 Mtetra
.849 .788 .791 r
.51372 .31902 .52118 .32801 .53486 .31272 .52746 .3031 Mtetra
.834 .776 .796 r
.52746 .3031 .53486 .31272 .54851 .29831 .54118 .28823 Mtetra
.82 .766 .802 r
.54118 .28823 .54851 .29831 .56216 .28474 .55489 .27432 Mtetra
.808 .758 .807 r
.55489 .27432 .56216 .28474 .57582 .27186 .5686 .26121 Mtetra
.798 .753 .811 r
.5686 .26121 .57582 .27186 .58948 .2596 .58231 .24879 Mtetra
.789 .749 .816 r
.58231 .24879 .58948 .2596 .60316 .24787 .59604 .23699 Mtetra
.781 .746 .821 r
.59604 .23699 .60316 .24787 .61686 .23659 .6098 .22568 Mtetra
.775 .745 .826 r
.6098 .22568 .61686 .23659 .63058 .22572 .62357 .21483 Mtetra
.77 .745 .83 r
.62357 .21483 .63058 .22572 .64434 .21517 .63738 .20434 Mtetra
.765 .745 .835 r
.63738 .20434 .64434 .21517 .65812 .20492 .65122 .19416 Mtetra
.762 .747 .839 r
.65122 .19416 .65812 .20492 .67194 .1949 .6651 .18424 Mtetra
.759 .749 .843 r
.6651 .18424 .67194 .1949 .68579 .18509 .67901 .17454 Mtetra
.757 .752 .848 r
.67901 .17454 .68579 .18509 .69968 .17543 .69296 .16501 Mtetra
.755 .755 .852 r
.69296 .16501 .69968 .17543 .71361 .1659 .70695 .15561 Mtetra
.755 .759 .856 r
.70695 .15561 .71361 .1659 .72757 .15647 .72098 .14631 Mtetra
.754 .763 .859 r
.72098 .14631 .72757 .15647 .74156 .14709 .73505 .13708 Mtetra
.755 .767 .863 r
.73505 .13708 .74156 .14709 .7556 .13776 .74915 .12789 Mtetra
.756 .772 .866 r
.74915 .12789 .7556 .13776 .76966 .12842 .76329 .11869 Mtetra
.503 .689 .951 r
.12381 .34178 .13216 .34956 .1432 .34911 .13489 .34109 Mtetra
.505 .683 .946 r
.13489 .34109 .1432 .34911 .15431 .34868 .14605 .34042 Mtetra
.505 .676 .942 r
.14605 .34042 .15431 .34868 .16549 .34831 .15727 .33979 Mtetra
.503 .669 .938 r
.15727 .33979 .16549 .34831 .17674 .34801 .16856 .33926 Mtetra
.499 .661 .934 r
.16856 .33926 .17674 .34801 .18806 .34784 .17992 .33884 Mtetra
.493 .653 .93 r
.17992 .33884 .18806 .34784 .19944 .34781 .19134 .33857 Mtetra
.485 .644 .927 r
.19134 .33857 .19944 .34781 .21089 .34797 .20282 .3385 Mtetra
.475 .634 .924 r
.20282 .3385 .21089 .34797 .2224 .34836 .21436 .33867 Mtetra
.462 .623 .921 r
.21436 .33867 .2224 .34836 .23398 .34902 .22597 .33912 Mtetra
.446 .61 .918 r
.22597 .33912 .23398 .34902 .24561 .35001 .23763 .33992 Mtetra
.426 .597 .916 r
.23763 .33992 .24561 .35001 .25731 .35138 .24935 .34112 Mtetra
.4 .58 .913 r
.24935 .34112 .25731 .35138 .26907 .3532 .26112 .34282 Mtetra
.368 .561 .91 r
.26112 .34282 .26907 .3532 .2809 .35555 .27296 .34508 Mtetra
.327 .538 .905 r
.27296 .34508 .2809 .35555 .29278 .35852 .28485 .34801 Mtetra
.276 .508 .898 r
.28485 .34801 .29278 .35852 .30473 .3622 .2968 .35174 Mtetra
.21 .472 .887 r
.2968 .35174 .30473 .3622 .31675 .36671 .30881 .35638 Mtetra
.123 .423 .866 r
.30881 .35638 .31675 .36671 .32884 .37219 .32088 .36209 Mtetra
.014 .358 .831 r
.32088 .36209 .32884 .37219 .341 .37875 .33302 .36904 Mtetra
0 .273 .772 r
.33302 .36904 .341 .37875 .35324 .38665 .34522 .37741 Mtetra
0 .166 .681 r
.34522 .37741 .35324 .38665 .36556 .39602 .35751 .38742 Mtetra
0 .045 .557 r
.35751 .38742 .36556 .39602 .37798 .40718 .36989 .39928 Mtetra
.574 .07 0 r
.36989 .39928 .37798 .40718 .39049 .42077 .38238 .4131 Mtetra
.811 .345 0 r
.38238 .4131 .39049 .42077 .40281 .445 .39474 .43577 Mtetra
.648 .17 0 r
.39474 .43577 .40281 .445 .4156 .46433 .40756 .45339 Mtetra
.645 .698 .884 r
.40756 .45339 .4156 .46433 .42934 .45986 .42134 .44888 Mtetra
.887 .75 .705 r
.42134 .44888 .42934 .45986 .44375 .4315 .4358 .42214 Mtetra
.916 .766 .68 r
.4358 .42214 .44375 .4315 .45814 .39812 .45026 .39024 Mtetra
.901 .797 .736 r
.45026 .39024 .45814 .39812 .47218 .37533 .4644 .36713 Mtetra
.891 .796 .749 r
.4644 .36713 .47218 .37533 .4861 .35492 .47841 .34593 Mtetra
.874 .786 .76 r
.47841 .34593 .4861 .35492 .49994 .33625 .49234 .32653 Mtetra
.857 .775 .769 r
.49234 .32653 .49994 .33625 .51372 .31902 .5062 .30874 Mtetra
.841 .765 .778 r
.5062 .30874 .51372 .31902 .52746 .3031 .52 .29234 Mtetra
.826 .755 .785 r
.52 .29234 .52746 .3031 .54118 .28823 .53378 .27715 Mtetra
.813 .748 .792 r
.53378 .27715 .54118 .28823 .55489 .27432 .54755 .26301 Mtetra
.802 .743 .798 r
.54755 .26301 .55489 .27432 .5686 .26121 .56131 .24977 Mtetra
.791 .739 .804 r
.56131 .24977 .5686 .26121 .58231 .24879 .57508 .2373 Mtetra
.783 .736 .81 r
.57508 .2373 .58231 .24879 .59604 .23699 .58886 .2255 Mtetra
.775 .735 .816 r
.58886 .2255 .59604 .23699 .6098 .22568 .60266 .21424 Mtetra
.769 .735 .821 r
.60266 .21424 .6098 .22568 .62357 .21483 .6165 .20347 Mtetra
.764 .735 .827 r
.6165 .20347 .62357 .21483 .63738 .20434 .63036 .19309 Mtetra
.759 .737 .832 r
.63036 .19309 .63738 .20434 .65122 .19416 .64426 .18304 Mtetra
.756 .739 .837 r
.64426 .18304 .65122 .19416 .6651 .18424 .65819 .17326 Mtetra
.753 .742 .842 r
.65819 .17326 .6651 .18424 .67901 .17454 .67217 .16371 Mtetra
.751 .746 .847 r
.67217 .16371 .67901 .17454 .69296 .16501 .68618 .15434 Mtetra
.75 .75 .852 r
.68618 .15434 .69296 .16501 .70695 .15561 .70023 .14511 Mtetra
.75 .754 .856 r
.70023 .14511 .70695 .15561 .72098 .14631 .71433 .13598 Mtetra
.749 .759 .86 r
.71433 .13598 .72098 .14631 .73505 .13708 .72847 .12692 Mtetra
.75 .764 .864 r
.72847 .12692 .73505 .13708 .74915 .12789 .74264 .1179 Mtetra
.751 .77 .868 r
.74264 .1179 .74915 .12789 .76329 .11869 .75685 .10887 Mtetra
.518 .694 .949 r
.11539 .33394 .12381 .34178 .13489 .34109 .12652 .33298 Mtetra
.52 .688 .944 r
.12652 .33298 .13489 .34109 .14605 .34042 .13773 .33202 Mtetra
.519 .681 .939 r
.13773 .33202 .14605 .34042 .15727 .33979 .149 .33112 Mtetra
.517 .673 .934 r
.149 .33112 .15727 .33979 .16856 .33926 .16033 .33031 Mtetra
.514 .664 .93 r
.16033 .33031 .16856 .33926 .17992 .33884 .17173 .32961 Mtetra
.509 .655 .925 r
.17173 .32961 .17992 .33884 .19134 .33857 .18319 .32906 Mtetra
.501 .645 .921 r
.18319 .32906 .19134 .33857 .20282 .3385 .19471 .32872 Mtetra
.491 .635 .917 r
.19471 .32872 .20282 .3385 .21436 .33867 .20629 .3286 Mtetra
.479 .623 .914 r
.20629 .3286 .21436 .33867 .22597 .33912 .21793 .32879 Mtetra
.463 .61 .91 r
.21793 .32879 .22597 .33912 .23763 .33992 .22962 .32934 Mtetra
.444 .595 .907 r
.22962 .32934 .23763 .33992 .24935 .34112 .24137 .3303 Mtetra
.419 .577 .903 r
.24137 .3303 .24935 .34112 .26112 .34282 .25317 .33178 Mtetra
.39 .558 .899 r
.25317 .33178 .26112 .34282 .27296 .34508 .26502 .33385 Mtetra
.351 .533 .894 r
.26502 .33385 .27296 .34508 .28485 .34801 .27692 .33665 Mtetra
.302 .503 .887 r
.27692 .33665 .28485 .34801 .2968 .35174 .28887 .3403 Mtetra
.241 .467 .876 r
.28887 .3403 .2968 .35174 .30881 .35638 .30088 .34494 Mtetra
.159 .418 .858 r
.30088 .34494 .30881 .35638 .32088 .36209 .31294 .35075 Mtetra
.056 .355 .828 r
.31294 .35075 .32088 .36209 .33302 .36904 .32505 .35792 Mtetra
0 .275 .779 r
.32505 .35792 .33302 .36904 .34522 .37741 .33723 .36664 Mtetra
0 .171 .7 r
.33723 .36664 .34522 .37741 .35751 .38742 .34948 .37715 Mtetra
0 .055 .593 r
.34948 .37715 .35751 .38742 .36989 .39928 .36182 .38964 Mtetra
0 0 .478 r
.36182 .38964 .36989 .39928 .38238 .4131 .37427 .40399 Mtetra
.789 .329 0 r
.37427 .40399 .38238 .4131 .39474 .43577 .38659 .42671 Mtetra
.653 .172 0 r
.38659 .42671 .39474 .43577 .40756 .45339 .3994 .4442 Mtetra
.647 .741 .918 r
.3994 .4442 .40756 .45339 .42134 .44888 .41322 .43964 Mtetra
.901 .773 .711 r
.41322 .43964 .42134 .44888 .4358 .42214 .42777 .41295 Mtetra
.918 .769 .68 r
.42777 .41295 .4358 .42214 .45026 .39024 .44235 .38091 Mtetra
.892 .776 .727 r
.44235 .38091 .45026 .39024 .4644 .36713 .45658 .35718 Mtetra
.879 .769 .737 r
.45658 .35718 .4644 .36713 .47841 .34593 .47069 .33526 Mtetra
.863 .759 .747 r
.47069 .33526 .47841 .34593 .49234 .32653 .48469 .31526 Mtetra
.846 .75 .757 r
.48469 .31526 .49234 .32653 .5062 .30874 .49862 .29703 Mtetra
.831 .741 .765 r
.49862 .29703 .5062 .30874 .52 .29234 .51249 .28031 Mtetra
.817 .734 .774 r
.51249 .28031 .52 .29234 .53378 .27715 .52633 .26493 Mtetra
.804 .729 .782 r
.52633 .26493 .53378 .27715 .54755 .26301 .54014 .25071 Mtetra
.793 .725 .789 r
.54014 .25071 .54755 .26301 .56131 .24977 .55396 .23745 Mtetra
.783 .723 .796 r
.55396 .23745 .56131 .24977 .57508 .2373 .56777 .22504 Mtetra
.774 .722 .804 r
.56777 .22504 .57508 .2373 .58886 .2255 .58161 .21333 Mtetra
.768 .722 .81 r
.58161 .21333 .58886 .2255 .60266 .21424 .59547 .20221 Mtetra
.761 .723 .817 r
.59547 .20221 .60266 .21424 .6165 .20347 .60935 .19159 Mtetra
.757 .725 .823 r
.60935 .19159 .6165 .20347 .63036 .19309 .62327 .18138 Mtetra
.753 .728 .829 r
.62327 .18138 .63036 .19309 .64426 .18304 .63722 .17152 Mtetra
.749 .731 .835 r
.63722 .17152 .64426 .18304 .65819 .17326 .65122 .16194 Mtetra
.747 .735 .841 r
.65122 .16194 .65819 .17326 .67217 .16371 .66525 .15259 Mtetra
.745 .739 .847 r
.66525 .15259 .67217 .16371 .68618 .15434 .67933 .14342 Mtetra
.744 .744 .852 r
.67933 .14342 .68618 .15434 .70023 .14511 .69345 .13439 Mtetra
.744 .749 .857 r
.69345 .13439 .70023 .14511 .71433 .13598 .70761 .12546 Mtetra
.744 .755 .862 r
.70761 .12546 .71433 .13598 .72847 .12692 .72182 .11661 Mtetra
.744 .761 .866 r
.72182 .11661 .72847 .12692 .74264 .1179 .73607 .10778 Mtetra
.746 .767 .87 r
.73607 .10778 .74264 .1179 .75685 .10887 .75036 .09896 Mtetra
.533 .7 .946 r
.1069 .32604 .11539 .33394 .12652 .33298 .11809 .32477 Mtetra
.535 .693 .941 r
.11809 .32477 .12652 .33298 .13773 .33202 .12934 .32351 Mtetra
.535 .685 .935 r
.12934 .32351 .13773 .33202 .149 .33112 .14066 .32229 Mtetra
.533 .677 .93 r
.14066 .32229 .149 .33112 .16033 .33031 .15205 .32116 Mtetra
.53 .668 .925 r
.15205 .32116 .16033 .33031 .17173 .32961 .1635 .32015 Mtetra
.525 .658 .92 r
.1635 .32015 .17173 .32961 .18319 .32906 .17501 .31928 Mtetra
.517 .647 .915 r
.17501 .31928 .18319 .32906 .19471 .32872 .18657 .31861 Mtetra
.508 .636 .911 r
.18657 .31861 .19471 .32872 .20629 .3286 .19819 .31818 Mtetra
.497 .624 .906 r
.19819 .31818 .20629 .3286 .21793 .32879 .20987 .31804 Mtetra
.482 .61 .902 r
.20987 .31804 .21793 .32879 .22962 .32934 .2216 .31826 Mtetra
.464 .595 .898 r
.2216 .31826 .22962 .32934 .24137 .3303 .23338 .3189 Mtetra
.441 .576 .893 r
.23338 .3189 .24137 .3303 .25317 .33178 .24521 .32008 Mtetra
.414 .556 .888 r
.24521 .32008 .25317 .33178 .26502 .33385 .25708 .32186 Mtetra
.378 .532 .883 r
.25708 .32186 .26502 .33385 .27692 .33665 .269 .3244 Mtetra
.333 .502 .875 r
.269 .3244 .27692 .33665 .28887 .3403 .28097 .32783 Mtetra
.277 .465 .865 r
.28097 .32783 .28887 .3403 .30088 .34494 .29298 .33231 Mtetra
.203 .418 .849 r
.29298 .33231 .30088 .34494 .31294 .35075 .30503 .33805 Mtetra
.109 .358 .823 r
.30503 .33805 .31294 .35075 .32505 .35792 .31713 .34526 Mtetra
0 .283 .783 r
.31713 .34526 .32505 .35792 .33723 .36664 .32928 .35414 Mtetra
0 .184 .718 r
.32928 .35414 .33723 .36664 .34948 .37715 .34149 .36501 Mtetra
0 .072 .625 r
.34149 .36501 .34948 .37715 .36182 .38964 .35377 .37804 Mtetra
0 0 .522 r
.35377 .37804 .36182 .38964 .37427 .40399 .36616 .3931 Mtetra
.774 .332 0 r
.36616 .3931 .37427 .40399 .38659 .42671 .37839 .41699 Mtetra
.665 .194 0 r
.37839 .41699 .38659 .42671 .3994 .4442 .39113 .43547 Mtetra
.647 .754 .928 r
.39113 .43547 .3994 .4442 .41322 .43964 .405 .43087 Mtetra
.909 .779 .706 r
.405 .43087 .41322 .43964 .42777 .41295 .41969 .4031 Mtetra
.917 .761 .674 r
.41969 .4031 .42777 .41295 .44235 .38091 .43441 .36979 Mtetra
.881 .752 .716 r
.43441 .36979 .44235 .38091 .45658 .35718 .44874 .34526 Mtetra
.866 .742 .725 r
.44874 .34526 .45658 .35718 .47069 .33526 .46294 .32269 Mtetra
.849 .732 .735 r
.46294 .32269 .47069 .33526 .48469 .31526 .47702 .30225 Mtetra
.833 .724 .745 r
.47702 .30225 .48469 .31526 .49862 .29703 .491 .28375 Mtetra
.818 .718 .754 r
.491 .28375 .49862 .29703 .51249 .28031 .50493 .2669 Mtetra
.805 .713 .763 r
.50493 .2669 .51249 .28031 .52633 .26493 .51882 .2515 Mtetra
.792 .709 .773 r
.51882 .2515 .52633 .26493 .54014 .25071 .53268 .23734 Mtetra
.782 .707 .781 r
.53268 .23734 .54014 .25071 .55396 .23745 .54655 .22422 Mtetra
.773 .707 .79 r
.54655 .22422 .55396 .23745 .56777 .22504 .56041 .21197 Mtetra
.765 .707 .798 r
.56041 .21197 .56777 .22504 .58161 .21333 .57429 .20047 Mtetra
.759 .709 .805 r
.57429 .20047 .58161 .21333 .59547 .20221 .5882 .18957 Mtetra
.753 .711 .813 r
.5882 .18957 .59547 .20221 .60935 .19159 .60214 .17919 Mtetra
.748 .715 .82 r
.60214 .17919 .60935 .19159 .62327 .18138 .61611 .16922 Mtetra
.745 .718 .827 r
.61611 .16922 .62327 .18138 .63722 .17152 .63012 .15961 Mtetra
.742 .723 .834 r
.63012 .15961 .63722 .17152 .65122 .16194 .64418 .15027 Mtetra
.74 .728 .84 r
.64418 .15027 .65122 .16194 .66525 .15259 .65827 .14116 Mtetra
.738 .733 .846 r
.65827 .14116 .66525 .15259 .67933 .14342 .67241 .13224 Mtetra
.737 .738 .852 r
.67241 .13224 .67933 .14342 .69345 .13439 .6866 .12345 Mtetra
.737 .744 .858 r
.6866 .12345 .69345 .13439 .70761 .12546 .70083 .11476 Mtetra
.737 .751 .863 r
.70083 .11476 .70761 .12546 .72182 .11661 .71511 .10614 Mtetra
.738 .757 .868 r
.71511 .10614 .72182 .11661 .73607 .10778 .72944 .09755 Mtetra
.74 .764 .873 r
.72944 .09755 .73607 .10778 .75036 .09896 .74381 .08896 Mtetra
.55 .706 .943 r
.09834 .31807 .1069 .32604 .11809 .32477 .10959 .31646 Mtetra
.551 .698 .937 r
.10959 .31646 .11809 .32477 .12934 .32351 .1209 .31486 Mtetra
.551 .69 .931 r
.1209 .31486 .12934 .32351 .14066 .32229 .13228 .31331 Mtetra
.549 .681 .925 r
.13228 .31331 .14066 .32229 .15205 .32116 .14372 .31183 Mtetra
.546 .671 .919 r
.14372 .31183 .15205 .32116 .1635 .32015 .15522 .31046 Mtetra
.541 .661 .914 r
.15522 .31046 .1635 .32015 .17501 .31928 .16678 .30923 Mtetra
.535 .65 .909 r
.16678 .30923 .17501 .31928 .18657 .31861 .1784 .30819 Mtetra
.526 .638 .903 r
.1784 .30819 .18657 .31861 .19819 .31818 .19007 .30737 Mtetra
.516 .625 .898 r
.19007 .30737 .19819 .31818 .20987 .31804 .20179 .30684 Mtetra
.502 .611 .893 r
.20179 .30684 .20987 .31804 .2216 .31826 .21356 .30667 Mtetra
.487 .595 .888 r
.21356 .30667 .2216 .31826 .23338 .3189 .22539 .3069 Mtetra
.465 .577 .882 r
.22539 .3069 .23338 .3189 .24521 .32008 .23725 .30767 Mtetra
.441 .556 .876 r
.23725 .30767 .24521 .32008 .25708 .32186 .24916 .30905 Mtetra
.409 .532 .87 r
.24916 .30905 .25708 .32186 .269 .3244 .26111 .31119 Mtetra
.369 .502 .862 r
.26111 .31119 .269 .3244 .28097 .32783 .27309 .31425 Mtetra
.319 .467 .852 r
.27309 .31425 .28097 .32783 .29298 .33231 .28512 .31839 Mtetra
.253 .422 .837 r
.28512 .31839 .29298 .33231 .30503 .33805 .29717 .32387 Mtetra
.168 .366 .815 r
.29717 .32387 .30503 .33805 .31713 .34526 .30926 .33092 Mtetra
.061 .294 .782 r
.30926 .33092 .31713 .34526 .32928 .35414 .32139 .33981 Mtetra
0 .199 .726 r
.32139 .33981 .32928 .35414 .34149 .36501 .33355 .35092 Mtetra
0 .085 .644 r
.33355 .35092 .34149 .36501 .35377 .37804 .34577 .3645 Mtetra
0 0 .543 r
.34577 .3645 .35377 .37804 .36616 .3931 .35808 .38045 Mtetra
.77 .35 0 r
.35808 .38045 .36616 .3931 .37839 .41699 .37016 .40624 Mtetra
.684 .23 0 r
.37016 .40624 .37839 .41699 .39113 .43547 .3828 .42643 Mtetra
.647 .748 .923 r
.3828 .42643 .39113 .43547 .405 .43087 .39671 .42178 Mtetra
.912 .774 .696 r
.39671 .42178 .405 .43087 .41969 .4031 .41157 .39221 Mtetra
.914 .75 .664 r
.41157 .39221 .41969 .4031 .43441 .36979 .42646 .35689 Mtetra
.871 .731 .705 r
.42646 .35689 .43441 .36979 .44874 .34526 .4409 .33137 Mtetra
.853 .718 .713 r
.4409 .33137 .44874 .34526 .46294 .32269 .45517 .30816 Mtetra
.835 .707 .723 r
.45517 .30816 .46294 .32269 .47702 .30225 .46932 .28737 Mtetra
.818 .699 .733 r
.46932 .28737 .47702 .30225 .491 .28375 .48336 .26877 Mtetra
.803 .694 .744 r
.48336 .26877 .491 .28375 .50493 .2669 .49734 .25199 Mtetra
.79 .69 .754 r
.49734 .25199 .50493 .2669 .51882 .2515 .51127 .23675 Mtetra
.779 .688 .764 r
.51127 .23675 .51882 .2515 .53268 .23734 .52518 .22284 Mtetra
.769 .689 .774 r
.52518 .22284 .53268 .23734 .54655 .22422 .53908 .21 Mtetra
.761 .69 .783 r
.53908 .21 .54655 .22422 .56041 .21197 .55299 .19807 Mtetra
.754 .692 .792 r
.55299 .19807 .56041 .21197 .57429 .20047 .56692 .18689 Mtetra
.748 .695 .801 r
.56692 .18689 .57429 .20047 .5882 .18957 .58088 .17631 Mtetra
.743 .699 .81 r
.58088 .17631 .5882 .18957 .60214 .17919 .59486 .16625 Mtetra
.739 .704 .818 r
.59486 .16625 .60214 .17919 .61611 .16922 .60889 .1566 Mtetra
.736 .708 .825 r
.60889 .1566 .61611 .16922 .63012 .15961 .62296 .14729 Mtetra
.733 .714 .833 r
.62296 .14729 .63012 .15961 .64418 .15027 .63707 .13826 Mtetra
.732 .72 .84 r
.63707 .13826 .64418 .15027 .65827 .14116 .65122 .12944 Mtetra
.73 .726 .846 r
.65122 .12944 .65827 .14116 .67241 .13224 .66543 .1208 Mtetra
.73 .732 .853 r
.66543 .1208 .67241 .13224 .6866 .12345 .67968 .11229 Mtetra
.73 .739 .859 r
.67968 .11229 .6866 .12345 .70083 .11476 .69399 .10387 Mtetra
.73 .746 .865 r
.69399 .10387 .70083 .11476 .71511 .10614 .70834 .09551 Mtetra
.731 .753 .87 r
.70834 .09551 .71511 .10614 .72944 .09755 .72274 .08719 Mtetra
.733 .761 .876 r
.72274 .08719 .72944 .09755 .74381 .08896 .73719 .07886 Mtetra
.567 .712 .94 r
.08971 .31003 .09834 .31807 .10959 .31646 .10102 .30806 Mtetra
.568 .703 .933 r
.10102 .30806 .10959 .31646 .1209 .31486 .1124 .30609 Mtetra
.568 .694 .926 r
.1124 .30609 .1209 .31486 .13228 .31331 .12384 .30416 Mtetra
.566 .685 .92 r
.12384 .30416 .13228 .31331 .14372 .31183 .13534 .3023 Mtetra
.563 .674 .914 r
.13534 .3023 .14372 .31183 .15522 .31046 .1469 .30054 Mtetra
.559 .664 .907 r
.1469 .30054 .15522 .31046 .16678 .30923 .15852 .2989 Mtetra
.552 .652 .901 r
.15852 .2989 .16678 .30923 .1784 .30819 .17019 .29744 Mtetra
.545 .64 .895 r
.17019 .29744 .1784 .30819 .19007 .30737 .18192 .29619 Mtetra
.536 .627 .889 r
.18192 .29619 .19007 .30737 .20179 .30684 .1937 .29521 Mtetra
.524 .612 .883 r
.1937 .29521 .20179 .30684 .21356 .30667 .20552 .29456 Mtetra
.51 .597 .877 r
.20552 .29456 .21356 .30667 .22539 .3069 .21739 .2943 Mtetra
.491 .578 .87 r
.21739 .2943 .22539 .3069 .23725 .30767 .22931 .29456 Mtetra
.47 .558 .863 r
.22931 .29456 .23725 .30767 .24916 .30905 .24126 .2954 Mtetra
.442 .534 .856 r
.24126 .2954 .24916 .30905 .26111 .31119 .25325 .29699 Mtetra
.407 .505 .847 r
.25325 .29699 .26111 .31119 .27309 .31425 .26527 .29951 Mtetra
.364 .472 .837 r
.26527 .29951 .27309 .31425 .28512 .31839 .27732 .30312 Mtetra
.304 .429 .823 r
.27732 .30312 .28512 .31839 .29717 .32387 .28938 .30813 Mtetra
.231 .376 .804 r
.28938 .30813 .29717 .32387 .30926 .33092 .30147 .31479 Mtetra
.131 .307 .775 r
.30147 .31479 .30926 .33092 .32139 .33981 .31358 .32348 Mtetra
0 .214 .728 r
.31358 .32348 .32139 .33981 .33355 .35092 .3257 .33471 Mtetra
0 .097 .653 r
.3257 .33471 .33355 .35092 .34577 .3645 .33784 .34882 Mtetra
0 0 .551 r
.33784 .34882 .34577 .3645 .35808 .38045 .35005 .36585 Mtetra
.775 .378 0 r
.35005 .36585 .35808 .38045 .37016 .40624 .36192 .39436 Mtetra
.718 .281 0 r
.36192 .39436 .37016 .40624 .3828 .42643 .37441 .41704 Mtetra
.647 .742 .919 r
.37441 .41704 .3828 .42643 .39671 .42178 .38836 .41235 Mtetra
.916 .768 .682 r
.38836 .41235 .39671 .42178 .41157 .39221 .40342 .38018 Mtetra
.913 .739 .652 r
.40342 .38018 .41157 .39221 .42646 .35689 .41852 .34204 Mtetra
.862 .711 .693 r
.41852 .34204 .42646 .35689 .4409 .33137 .43306 .31532 Mtetra
.84 .695 .701 r
.43306 .31532 .4409 .33137 .45517 .30816 .44742 .29147 Mtetra
.82 .682 .712 r
.44742 .29147 .45517 .30816 .46932 .28737 .46162 .27047 Mtetra
.802 .674 .723 r
.46162 .27047 .46932 .28737 .48336 .26877 .4757 .25197 Mtetra
.787 .669 .734 r
.4757 .25197 .48336 .26877 .49734 .25199 .48971 .23548 Mtetra
.774 .667 .745 r
.48971 .23548 .49734 .25199 .51127 .23675 .50368 .22061 Mtetra
.763 .667 .756 r
.50368 .22061 .51127 .23675 .52518 .22284 .51763 .20715 Mtetra
.755 .669 .767 r
.51763 .20715 .52518 .22284 .53908 .21 .53157 .19477 Mtetra
.747 .672 .777 r
.53157 .19477 .53908 .21 .55299 .19807 .54552 .18329 Mtetra
.741 .676 .788 r
.54552 .18329 .55299 .19807 .56692 .18689 .55949 .17256 Mtetra
.736 .681 .797 r
.55949 .17256 .56692 .18689 .58088 .17631 .57349 .16241 Mtetra
.731 .686 .807 r
.57349 .16241 .58088 .17631 .59486 .16625 .58753 .15277 Mtetra
.728 .692 .815 r
.58753 .15277 .59486 .16625 .60889 .1566 .6016 .14351 Mtetra
.726 .698 .824 r
.6016 .14351 .60889 .1566 .62296 .14729 .61572 .13457 Mtetra
.724 .705 .832 r
.61572 .13457 .62296 .14729 .63707 .13826 .62989 .12589 Mtetra
.723 .711 .839 r
.62989 .12589 .63707 .13826 .65122 .12944 .64411 .11742 Mtetra
.722 .719 .847 r
.64411 .11742 .65122 .12944 .66543 .1208 .65838 .1091 Mtetra
.721 .726 .854 r
.65838 .1091 .66543 .1208 .67968 .11229 .6727 .1009 Mtetra
.722 .733 .86 r
.6727 .1009 .67968 .11229 .69399 .10387 .68707 .09279 Mtetra
.722 .741 .867 r
.68707 .09279 .69399 .10387 .70834 .09551 .7015 .08474 Mtetra
.723 .749 .873 r
.7015 .08474 .70834 .09551 .72274 .08719 .71598 .0767 Mtetra
.725 .758 .879 r
.71598 .0767 .72274 .08719 .73719 .07886 .73051 .06866 Mtetra
.584 .718 .936 r
.081 .30192 .08971 .31003 .10102 .30806 .09238 .29956 Mtetra
.585 .709 .928 r
.09238 .29956 .10102 .30806 .1124 .30609 .10383 .2972 Mtetra
.584 .699 .921 r
.10383 .2972 .1124 .30609 .12384 .30416 .11534 .29486 Mtetra
.583 .689 .914 r
.11534 .29486 .12384 .30416 .13534 .3023 .12691 .29259 Mtetra
.58 .678 .908 r
.12691 .29259 .13534 .3023 .1469 .30054 .13853 .2904 Mtetra
.576 .667 .901 r
.13853 .2904 .1469 .30054 .15852 .2989 .15022 .28832 Mtetra
.57 .656 .894 r
.15022 .28832 .15852 .2989 .17019 .29744 .16195 .2864 Mtetra
.564 .643 .887 r
.16195 .2864 .17019 .29744 .18192 .29619 .17374 .28466 Mtetra
.556 .63 .88 r
.17374 .28466 .18192 .29619 .1937 .29521 .18558 .28316 Mtetra
.545 .615 .874 r
.18558 .28316 .1937 .29521 .20552 .29456 .19747 .28197 Mtetra
.533 .6 .866 r
.19747 .28197 .20552 .29456 .21739 .2943 .2094 .28113 Mtetra
.517 .581 .859 r
.2094 .28113 .21739 .2943 .22931 .29456 .22137 .28077 Mtetra
.499 .562 .851 r
.22137 .28077 .22931 .29456 .24126 .2954 .23339 .28094 Mtetra
.475 .538 .842 r
.23339 .28094 .24126 .2954 .25325 .29699 .24543 .28184 Mtetra
.445 .511 .832 r
.24543 .28184 .25325 .29699 .26527 .29951 .25749 .28362 Mtetra
.409 .48 .821 r
.25749 .28362 .26527 .29951 .27732 .30312 .26959 .28646 Mtetra
.358 .439 .808 r
.26959 .28646 .27732 .30312 .28938 .30813 .28169 .29074 Mtetra
.297 .392 .791 r
.28169 .29074 .28938 .30813 .30147 .31479 .2938 .29665 Mtetra
.21 .327 .766 r
.2938 .29665 .30147 .31479 .31358 .32348 .3059 .30477 Mtetra
.089 .241 .727 r
.3059 .30477 .31358 .32348 .3257 .33471 .318 .31567 Mtetra
0 .13 .666 r
.318 .31567 .3257 .33471 .33784 .34882 .33007 .3299 Mtetra
0 0 .57 r
.33007 .3299 .33784 .34882 .35005 .36585 .34216 .34795 Mtetra
.769 .406 0 r
.34216 .34795 .35005 .36585 .36192 .39436 .35372 .38048 Mtetra
.752 .342 0 r
.35372 .38048 .36192 .39436 .37441 .41704 .36596 .40708 Mtetra
.647 .73 .91 r
.36596 .40708 .37441 .41704 .38836 .41235 .37995 .40234 Mtetra
.921 .759 .664 r
.37995 .40234 .38836 .41235 .40342 .38018 .39529 .36615 Mtetra
.91 .723 .637 r
.39529 .36615 .40342 .38018 .41852 .34204 .41065 .32386 Mtetra
.844 .679 .678 r
.41065 .32386 .41852 .34204 .43306 .31532 .42529 .29601 Mtetra
.819 .662 .688 r
.42529 .29601 .43306 .31532 .44742 .29147 .4397 .27194 Mtetra
.798 .651 .7 r
.4397 .27194 .44742 .29147 .46162 .27047 .45393 .25116 Mtetra
.781 .645 .712 r
.45393 .25116 .46162 .27047 .4757 .25197 .46805 .23313 Mtetra
.766 .642 .725 r
.46805 .23313 .4757 .25197 .48971 .23548 .48208 .21729 Mtetra
.756 .643 .737 r
.48208 .21729 .48971 .23548 .50368 .22061 .49607 .20307 Mtetra
.745 .645 .749 r
.49607 .20307 .50368 .22061 .51763 .20715 .51004 .19029 Mtetra
.738 .649 .761 r
.51004 .19029 .51763 .20715 .53157 .19477 .52401 .17855 Mtetra
.732 .654 .773 r
.52401 .17855 .53157 .19477 .54552 .18329 .538 .16769 Mtetra
.726 .66 .784 r
.538 .16769 .54552 .18329 .55949 .17256 .55201 .15754 Mtetra
.723 .667 .794 r
.55201 .15754 .55949 .17256 .57349 .16241 .56605 .14792 Mtetra
.719 .673 .805 r
.56605 .14792 .57349 .16241 .58753 .15277 .58013 .13878 Mtetra
.717 .681 .814 r
.58013 .13878 .58753 .15277 .6016 .14351 .59426 .12998 Mtetra
.715 .688 .823 r
.59426 .12998 .6016 .14351 .61572 .13457 .60843 .12148 Mtetra
.713 .696 .832 r
.60843 .12148 .61572 .13457 .62989 .12589 .62266 .11321 Mtetra
.713 .703 .84 r
.62266 .11321 .62989 .12589 .64411 .11742 .63693 .10511 Mtetra
.712 .711 .848 r
.63693 .10511 .64411 .11742 .65838 .1091 .65127 .09717 Mtetra
.712 .719 .855 r
.65127 .09717 .65838 .1091 .6727 .1009 .66565 .08931 Mtetra
.713 .728 .862 r
.66565 .08931 .6727 .1009 .68707 .09279 .6801 .08154 Mtetra
.713 .736 .869 r
.6801 .08154 .68707 .09279 .7015 .08474 .6946 .07381 Mtetra
.715 .745 .876 r
.6946 .07381 .7015 .08474 .71598 .0767 .70915 .06609 Mtetra
.716 .754 .882 r
.70915 .06609 .71598 .0767 .73051 .06866 .72376 .05837 Mtetra
.601 .724 .931 r
.07222 .29375 .081 .30192 .09238 .29956 .08368 .29097 Mtetra
.601 .714 .923 r
.08368 .29097 .09238 .29956 .10383 .2972 .0952 .28818 Mtetra
.601 .703 .916 r
.0952 .28818 .10383 .2972 .11534 .29486 .10678 .28542 Mtetra
.599 .693 .908 r
.10678 .28542 .11534 .29486 .12691 .29259 .11842 .2827 Mtetra
.596 .682 .901 r
.11842 .2827 .12691 .29259 .13853 .2904 .13012 .28005 Mtetra
.593 .671 .894 r
.13012 .28005 .13853 .2904 .15022 .28832 .14188 .27749 Mtetra
.588 .659 .886 r
.14188 .27749 .15022 .28832 .16195 .2864 .15368 .27506 Mtetra
.583 .646 .879 r
.15368 .27506 .16195 .2864 .17374 .28466 .16555 .27278 Mtetra
.576 .633 .871 r
.16555 .27278 .17374 .28466 .18558 .28316 .17746 .27071 Mtetra
.567 .618 .863 r
.17746 .27071 .18558 .28316 .19747 .28197 .18941 .26889 Mtetra
.557 .603 .855 r
.18941 .26889 .19747 .28197 .2094 .28113 .20142 .26737 Mtetra
.543 .585 .846 r
.20142 .26737 .2094 .28113 .22137 .28077 .21346 .26628 Mtetra
.529 .566 .837 r
.21346 .26628 .22137 .28077 .23339 .28094 .22554 .26565 Mtetra
.509 .543 .827 r
.22554 .26565 .23339 .28094 .24543 .28184 .23766 .26567 Mtetra
.485 .518 .816 r
.23766 .26567 .24543 .28184 .25749 .28362 .24979 .26648 Mtetra
.456 .489 .804 r
.24979 .26648 .25749 .28362 .26959 .28646 .26195 .26827 Mtetra
.413 .45 .79 r
.26195 .26827 .26959 .28646 .28169 .29074 .27411 .27147 Mtetra
.368 .411 .774 r
.27411 .27147 .28169 .29074 .2938 .29665 .28627 .27619 Mtetra
.292 .35 .751 r
.28627 .27619 .2938 .29665 .3059 .30477 .2984 .28332 Mtetra
.191 .274 .721 r
.2984 .28332 .3059 .30477 .318 .31567 .31049 .29337 Mtetra
.043 .167 .669 r
.31049 .29337 .318 .31567 .33007 .3299 .32251 .30734 Mtetra
0 0 .553 r
.32251 .30734 .33007 .3299 .34216 .34795 .33439 .32747 Mtetra
.853 .508 0 r
.33439 .32747 .34216 .34795 .35372 .38048 .34524 .37061 Mtetra
.904 .499 .105 r
.34524 .37061 .35372 .38048 .36596 .40708 .35688 .40778 Mtetra
.393 .852 .853 r
.35688 .40778 .36596 .40708 .37995 .40234 .37095 .403 Mtetra
.984 .831 .612 r
.37095 .403 .37995 .40234 .39529 .36615 .38693 .35614 Mtetra
.943 .746 .608 r
.38693 .35614 .39529 .36615 .41065 .32386 .40285 .3031 Mtetra
.837 .661 .663 r
.40285 .3031 .41065 .32386 .42529 .29601 .41762 .27305 Mtetra
.795 .629 .675 r
.41762 .27305 .42529 .29601 .4397 .27194 .43206 .24911 Mtetra
.772 .618 .688 r
.43206 .24911 .4397 .27194 .45393 .25116 .4463 .22907 Mtetra
.755 .614 .701 r
.4463 .22907 .45393 .25116 .46805 .23313 .46041 .21193 Mtetra
.74 .612 .715 r
.46041 .21193 .46805 .23313 .48208 .21729 .47445 .1972 Mtetra
.733 .616 .729 r
.47445 .1972 .48208 .21729 .49607 .20307 .48845 .18396 Mtetra
.724 .62 .742 r
.48845 .18396 .49607 .20307 .51004 .19029 .50243 .17214 Mtetra
.718 .627 .755 r
.50243 .17214 .51004 .19029 .52401 .17855 .51642 .16128 Mtetra
.714 .635 .768 r
.51642 .16128 .52401 .17855 .538 .16769 .53044 .15122 Mtetra
.71 .643 .78 r
.53044 .15122 .538 .16769 .55201 .15754 .54448 .14179 Mtetra
.707 .651 .792 r
.54448 .14179 .55201 .15754 .56605 .14792 .55856 .13283 Mtetra
.705 .66 .803 r
.55856 .13283 .56605 .14792 .58013 .13878 .57268 .12428 Mtetra
.704 .669 .813 r
.57268 .12428 .58013 .13878 .59426 .12998 .58685 .11602 Mtetra
.703 .677 .823 r
.58685 .11602 .59426 .12998 .60843 .12148 .60108 .10801 Mtetra
.702 .686 .832 r
.60108 .10801 .60843 .12148 .62266 .11321 .61536 .1002 Mtetra
.702 .695 .84 r
.61536 .1002 .62266 .11321 .63693 .10511 .62969 .09254 Mtetra
.702 .704 .849 r
.62969 .09254 .63693 .10511 .65127 .09717 .64409 .08499 Mtetra
.702 .713 .857 r
.64409 .08499 .65127 .09717 .66565 .08931 .65854 .07752 Mtetra
.703 .722 .864 r
.65854 .07752 .66565 .08931 .6801 .08154 .67306 .07011 Mtetra
.704 .731 .871 r
.67306 .07011 .6801 .08154 .6946 .07381 .68763 .06273 Mtetra
.705 .74 .879 r
.68763 .06273 .6946 .07381 .70915 .06609 .70226 .05536 Mtetra
.707 .75 .885 r
.70226 .05536 .70915 .06609 .72376 .05837 .71695 .04798 Mtetra
.617 .729 .926 r
.06337 .2855 .07222 .29375 .08368 .29097 .07491 .28228 Mtetra
.618 .718 .918 r
.07491 .28228 .08368 .29097 .0952 .28818 .08651 .27906 Mtetra
.617 .708 .91 r
.08651 .27906 .0952 .28818 .10678 .28542 .09817 .27584 Mtetra
.615 .697 .902 r
.09817 .27584 .10678 .28542 .11842 .2827 .10989 .27266 Mtetra
.613 .686 .895 r
.10989 .27266 .11842 .2827 .13012 .28005 .12166 .26952 Mtetra
.61 .675 .887 r
.12166 .26952 .13012 .28005 .14188 .27749 .13349 .26645 Mtetra
.606 .663 .879 r
.13349 .26645 .14188 .27749 .15368 .27506 .14538 .26348 Mtetra
.601 .65 .871 r
.14538 .26348 .15368 .27506 .16555 .27278 .15732 .26062 Mtetra
.595 .637 .863 r
.15732 .26062 .16555 .27278 .17746 .27071 .16931 .25791 Mtetra
.588 .623 .854 r
.16931 .25791 .17746 .27071 .18941 .26889 .18135 .25541 Mtetra
.58 .608 .845 r
.18135 .25541 .18941 .26889 .20142 .26737 .19343 .25314 Mtetra
.569 .591 .835 r
.19343 .25314 .20142 .26737 .21346 .26628 .20556 .25122 Mtetra
.557 .572 .825 r
.20556 .25122 .21346 .26628 .22554 .26565 .21773 .24966 Mtetra
.541 .551 .814 r
.21773 .24966 .22554 .26565 .23766 .26567 .22993 .24864 Mtetra
.522 .527 .802 r
.22993 .24864 .23766 .26567 .24979 .26648 .24216 .24829 Mtetra
.5 .501 .789 r
.24216 .24829 .24979 .26648 .26195 .26827 .25441 .24876 Mtetra
.466 .466 .774 r
.25441 .24876 .26195 .26827 .27411 .27147 .26665 .25053 Mtetra
.434 .433 .758 r
.26665 .25053 .27411 .27147 .28627 .27619 .27891 .25358 Mtetra
.37 .377 .737 r
.27891 .25358 .28627 .27619 .2984 .28332 .2911 .25907 Mtetra
.296 .316 .712 r
.2911 .25907 .2984 .28332 .31049 .29337 .30325 .26737 Mtetra
.178 .224 .672 r
.30325 .26737 .31049 .29337 .32251 .30734 .31528 .27987 Mtetra
0 .031 .572 r
.31528 .27987 .32251 .30734 .33439 .32747 .32701 .3004 Mtetra
.825 .523 0 r
.32701 .3004 .33439 .32747 .34524 .37061 .33726 .35093 Mtetra
.872 .52 .022 r
.33726 .35093 .34524 .37061 .35688 .40778 .34834 .39591 Mtetra
.643 .692 .881 r
.34834 .39591 .35688 .40778 .37095 .403 .36245 .39109 Mtetra
.935 .734 .607 r
.36245 .39109 .37095 .403 .38693 .35614 .37894 .33628 Mtetra
.909 .69 .595 r
.37894 .33628 .38693 .35614 .40285 .3031 .39531 .2757 Mtetra
.803 .614 .646 r
.39531 .2757 .40285 .3031 .41762 .27305 .41013 .24513 Mtetra
.76 .587 .662 r
.41013 .24513 .41762 .27305 .43206 .24911 .42454 .22255 Mtetra
.74 .581 .677 r
.42454 .22255 .43206 .24911 .4463 .22907 .43874 .20416 Mtetra
.726 .581 .692 r
.43874 .20416 .4463 .22907 .46041 .21193 .45282 .18857 Mtetra
.712 .582 .708 r
.45282 .18857 .46041 .21193 .47445 .1972 .46683 .17541 Mtetra
.708 .591 .723 r
.46683 .17541 .47445 .1972 .48845 .18396 .48082 .16352 Mtetra
.7 .597 .738 r
.48082 .16352 .48845 .18396 .50243 .17214 .49481 .15293 Mtetra
.697 .607 .752 r
.49481 .15293 .50243 .17214 .51642 .16128 .50881 .14315 Mtetra
.694 .617 .766 r
.50881 .14315 .51642 .16128 .53044 .15122 .52284 .13403 Mtetra
.692 .627 .779 r
.52284 .13403 .53044 .15122 .54448 .14179 .53691 .12545 Mtetra
.691 .637 .791 r
.53691 .12545 .54448 .14179 .55856 .13283 .55102 .11723 Mtetra
.69 .647 .802 r
.55102 .11723 .55856 .13283 .57268 .12428 .56518 .10935 Mtetra
.69 .657 .813 r
.56518 .10935 .57268 .12428 .58685 .11602 .5794 .1017 Mtetra
.69 .667 .823 r
.5794 .1017 .58685 .11602 .60108 .10801 .59367 .09423 Mtetra
.69 .677 .833 r
.59367 .09423 .60108 .10801 .61536 .1002 .608 .08692 Mtetra
.69 .687 .842 r
.608 .08692 .61536 .1002 .62969 .09254 .62239 .07972 Mtetra
.691 .696 .85 r
.62239 .07972 .62969 .09254 .64409 .08499 .63685 .0726 Mtetra
.692 .706 .859 r
.63685 .0726 .64409 .08499 .65854 .07752 .65137 .06554 Mtetra
.693 .716 .867 r
.65137 .06554 .65854 .07752 .67306 .07011 .66595 .05851 Mtetra
.694 .725 .874 r
.66595 .05851 .67306 .07011 .68763 .06273 .68059 .05151 Mtetra
.695 .735 .882 r
.68059 .05151 .68763 .06273 .70226 .05536 .6953 .04451 Mtetra
.697 .745 .889 r
.6953 .04451 .70226 .05536 .71695 .04798 .71008 .03748 Mtetra
.634 .733 .92 r
.05443 .27718 .06337 .2855 .07491 .28228 .06606 .27351 Mtetra
.633 .723 .912 r
.06606 .27351 .07491 .28228 .08651 .27906 .07775 .26983 Mtetra
.632 .712 .904 r
.07775 .26983 .08651 .27906 .09817 .27584 .08949 .26614 Mtetra
.631 .701 .896 r
.08949 .26614 .09817 .27584 .10989 .27266 .10129 .26247 Mtetra
.629 .69 .888 r
.10129 .26247 .10989 .27266 .12166 .26952 .11315 .25883 Mtetra
.626 .679 .88 r
.11315 .25883 .12166 .26952 .13349 .26645 .12507 .25522 Mtetra
.623 .667 .872 r
.12507 .25522 .13349 .26645 .14538 .26348 .13704 .25168 Mtetra
.619 .655 .863 r
.13704 .25168 .14538 .26348 .15732 .26062 .14906 .2482 Mtetra
.614 .642 .854 r
.14906 .2482 .15732 .26062 .16931 .25791 .16114 .24483 Mtetra
.608 .628 .845 r
.16114 .24483 .16931 .25791 .18135 .25541 .17327 .24159 Mtetra
.602 .613 .835 r
.17327 .24159 .18135 .25541 .19343 .25314 .18544 .23852 Mtetra
.593 .597 .825 r
.18544 .23852 .19343 .25314 .20556 .25122 .19767 .23567 Mtetra
.585 .58 .814 r
.19767 .23567 .20556 .25122 .21773 .24966 .20993 .23309 Mtetra
.572 .56 .802 r
.20993 .23309 .21773 .24966 .22993 .24864 .22224 .23089 Mtetra
.558 .539 .789 r
.22224 .23089 .22993 .24864 .24216 .24829 .23458 .22919 Mtetra
.542 .515 .775 r
.23458 .22919 .24216 .24829 .25441 .24876 .24695 .22809 Mtetra
.516 .484 .76 r
.24695 .22809 .25441 .24876 .26665 .25053 .25932 .22804 Mtetra
.495 .456 .742 r
.25932 .22804 .26665 .25053 .27891 .25358 .27171 .22893 Mtetra
.449 .41 .723 r
.27171 .22893 .27891 .25358 .2911 .25907 .28404 .23194 Mtetra
.401 .362 .7 r
.28404 .23194 .2911 .25907 .30325 .26737 .29632 .2373 Mtetra
.324 .294 .67 r
.29632 .2373 .30325 .26737 .31528 .27987 .30849 .24646 Mtetra
.137 .148 .607 r
.30849 .24646 .31528 .27987 .32701 .3004 .32029 .26386 Mtetra
0 0 .201 r
.32029 .26386 .32701 .3004 .33726 .35093 .33044 .31197 Mtetra
0 0 .315 r
.33044 .31197 .33726 .35093 .34834 .39591 .34139 .35539 Mtetra
.573 .428 .646 r
.34139 .35539 .34834 .39591 .36245 .39109 .35541 .35048 Mtetra
.82 .595 .597 r
.35541 .35048 .36245 .39109 .37894 .33628 .37188 .29709 Mtetra
.836 .606 .591 r
.37188 .29709 .37894 .33628 .39531 .2757 .38821 .2388 Mtetra
.747 .551 .63 r
.38821 .2388 .39531 .2757 .41013 .24513 .40291 .21124 Mtetra
.712 .536 .649 r
.40291 .21124 .41013 .24513 .42454 .22255 .41718 .1919 Mtetra
.698 .538 .667 r
.41718 .1919 .42454 .22255 .43874 .20416 .43127 .17635 Mtetra
.69 .545 .684 r
.43127 .17635 .43874 .20416 .45282 .18857 .44528 .16314 Mtetra
.68 .551 .702 r
.44528 .16314 .45282 .18857 .46683 .17541 .45924 .15205 Mtetra
.679 .564 .718 r
.45924 .15205 .46683 .17541 .48082 .16352 .4732 .14189 Mtetra
.675 .574 .735 r
.4732 .14189 .48082 .16352 .49481 .15293 .48717 .13278 Mtetra
.674 .587 .75 r
.48717 .13278 .49481 .15293 .50881 .14315 .50117 .12427 Mtetra
.673 .599 .764 r
.50117 .12427 .50881 .14315 .52284 .13403 .51521 .11625 Mtetra
.673 .611 .778 r
.51521 .11625 .52284 .13403 .53691 .12545 .52929 .10861 Mtetra
.674 .624 .791 r
.52929 .10861 .53691 .12545 .55102 .11723 .54343 .10122 Mtetra
.674 .635 .803 r
.54343 .10122 .55102 .11723 .56518 .10935 .55763 .09407 Mtetra
.675 .647 .814 r
.55763 .09407 .56518 .10935 .5794 .1017 .57189 .08706 Mtetra
.676 .658 .825 r
.57189 .08706 .5794 .1017 .59367 .09423 .5862 .08019 Mtetra
.677 .669 .834 r
.5862 .08019 .59367 .09423 .608 .08692 .60059 .07341 Mtetra
.678 .679 .844 r
.60059 .07341 .608 .08692 .62239 .07972 .61503 .06669 Mtetra
.679 .689 .853 r
.61503 .06669 .62239 .07972 .63685 .0726 .62955 .06003 Mtetra
.68 .7 .861 r
.62955 .06003 .63685 .0726 .65137 .06554 .64413 .05339 Mtetra
.682 .71 .869 r
.64413 .05339 .65137 .06554 .66595 .05851 .65878 .04677 Mtetra
.683 .72 .877 r
.65878 .04677 .66595 .05851 .68059 .05151 .67349 .04016 Mtetra
.684 .73 .885 r
.67349 .04016 .68059 .05151 .6953 .04451 .68828 .03354 Mtetra
.686 .741 .893 r
.68828 .03354 .6953 .04451 .71008 .03748 .70314 .02689 Mtetra
.649 .738 .914 r
.04542 .2688 .05443 .27718 .06606 .27351 .05714 .26466 Mtetra
.648 .727 .906 r
.05714 .26466 .06606 .27351 .07775 .26983 .06892 .2605 Mtetra
.647 .716 .898 r
.06892 .2605 .07775 .26983 .08949 .26614 .08075 .25633 Mtetra
.646 .705 .89 r
.08075 .25633 .08949 .26614 .10129 .26247 .09264 .25216 Mtetra
.644 .694 .882 r
.09264 .25216 .10129 .26247 .11315 .25883 .10459 .248 Mtetra
.642 .683 .873 r
.10459 .248 .11315 .25883 .12507 .25522 .11659 .24384 Mtetra
.639 .671 .865 r
.11659 .24384 .12507 .25522 .13704 .25168 .12865 .2397 Mtetra
.636 .659 .856 r
.12865 .2397 .13704 .25168 .14906 .2482 .14077 .23558 Mtetra
.632 .647 .847 r
.14077 .23558 .14906 .2482 .16114 .24483 .15294 .23151 Mtetra
.628 .634 .837 r
.15294 .23151 .16114 .24483 .17327 .24159 .16516 .2275 Mtetra
.623 .62 .827 r
.16516 .2275 .17327 .24159 .18544 .23852 .17744 .22356 Mtetra
.617 .604 .816 r
.17744 .22356 .18544 .23852 .19767 .23567 .18977 .21974 Mtetra
.61 .588 .803 r
.18977 .21974 .19767 .23567 .20993 .23309 .20215 .21604 Mtetra
.602 .57 .791 r
.20215 .21604 .20993 .23309 .22224 .23089 .21458 .21254 Mtetra
.593 .551 .777 r
.21458 .21254 .22224 .23089 .23458 .22919 .22706 .2093 Mtetra
.582 .529 .761 r
.22706 .2093 .23458 .22919 .24695 .22809 .23957 .20639 Mtetra
.565 .504 .745 r
.23957 .20639 .24695 .22809 .25932 .22804 .25211 .2041 Mtetra
.552 .479 .726 r
.25211 .2041 .25932 .22804 .27171 .22893 .26469 .20231 Mtetra
.524 .444 .707 r
.26469 .20231 .27171 .22893 .28404 .23194 .27724 .20186 Mtetra
.499 .409 .684 r
.27724 .20186 .28404 .23194 .29632 .2373 .28978 .20284 Mtetra
.461 .364 .659 r
.28978 .20284 .29632 .2373 .30849 .24646 .30225 .20628 Mtetra
.376 .286 .625 r
.30225 .20628 .30849 .24646 .32029 .26386 .31446 .21552 Mtetra
.017 .009 .502 r
.31446 .21552 .32029 .26386 .33044 .31197 .32546 .24622 Mtetra
.228 .13 .53 r
.32546 .24622 .33044 .31197 .34139 .35539 .33703 .2737 Mtetra
.539 .347 .568 r
.33703 .2737 .34139 .35539 .35541 .35048 .35078 .26867 Mtetra
.679 .453 .572 r
.35078 .26867 .35541 .35048 .37188 .29709 .36629 .23103 Mtetra
.718 .492 .582 r
.36629 .23103 .37188 .29709 .38821 .2388 .38175 .19005 Mtetra
.666 .472 .613 r
.38175 .19005 .38821 .2388 .40291 .21124 .39603 .17054 Mtetra
.648 .475 .635 r
.39603 .17054 .40291 .21124 .41718 .1919 .41003 .15682 Mtetra
.644 .487 .656 r
.41003 .15682 .41718 .1919 .43127 .17635 .42393 .14556 Mtetra
.644 .503 .676 r
.42393 .14556 .43127 .17635 .44528 .16314 .43781 .13572 Mtetra
.641 .517 .696 r
.43781 .13572 .44528 .16314 .45924 .15205 .45168 .12722 Mtetra
.645 .535 .714 r
.45168 .12722 .45924 .15205 .4732 .14189 .46558 .11922 Mtetra
.645 .55 .732 r
.46558 .11922 .4732 .14189 .48717 .13278 .47952 .11183 Mtetra
.648 .566 .749 r
.47952 .11183 .48717 .13278 .50117 .12427 .49351 .10477 Mtetra
.65 .581 .764 r
.49351 .10477 .50117 .12427 .51521 .11625 .50755 .09796 Mtetra
.653 .596 .779 r
.50755 .09796 .51521 .11625 .52929 .10861 .52165 .09135 Mtetra
.655 .61 .792 r
.52165 .09135 .52929 .10861 .54343 .10122 .53581 .08486 Mtetra
.657 .624 .804 r
.53581 .08486 .54343 .10122 .55763 .09407 .55003 .07848 Mtetra
.659 .636 .816 r
.55003 .07848 .55763 .09407 .57189 .08706 .56432 .07217 Mtetra
.661 .648 .827 r
.56432 .07217 .57189 .08706 .5862 .08019 .57868 .06591 Mtetra
.663 .66 .837 r
.57868 .06591 .5862 .08019 .60059 .07341 .59311 .05969 Mtetra
.665 .672 .846 r
.59311 .05969 .60059 .07341 .61503 .06669 .60761 .05348 Mtetra
.667 .682 .855 r
.60761 .05348 .61503 .06669 .62955 .06003 .62218 .04729 Mtetra
.669 .693 .864 r
.62218 .04729 .62955 .06003 .64413 .05339 .63683 .04109 Mtetra
.67 .704 .872 r
.63683 .04109 .64413 .05339 .65878 .04677 .65154 .03489 Mtetra
.672 .714 .88 r
.65154 .03489 .65878 .04677 .67349 .04016 .66633 .02868 Mtetra
.673 .725 .888 r
.66633 .02868 .67349 .04016 .68828 .03354 .68119 .02245 Mtetra
.675 .736 .896 r
.68119 .02245 .68828 .03354 .70314 .02689 .69613 .01619 Mtetra
.664 .741 .908 r
.03634 .26033 .04542 .2688 .05714 .26466 .04815 .25572 Mtetra
.662 .73 .9 r
.04815 .25572 .05714 .26466 .06892 .2605 .06002 .25108 Mtetra
.661 .719 .892 r
.06002 .25108 .06892 .2605 .08075 .25633 .07194 .24643 Mtetra
.66 .709 .884 r
.07194 .24643 .08075 .25633 .09264 .25216 .08393 .24175 Mtetra
.658 .698 .876 r
.08393 .24175 .09264 .25216 .10459 .248 .09597 .23704 Mtetra
.656 .687 .867 r
.09597 .23704 .10459 .248 .11659 .24384 .10806 .23232 Mtetra
.654 .676 .858 r
.10806 .23232 .11659 .24384 .12865 .2397 .12022 .22757 Mtetra
.652 .664 .849 r
.12022 .22757 .12865 .2397 .14077 .23558 .13243 .2228 Mtetra
.649 .652 .84 r
.13243 .2228 .14077 .23558 .15294 .23151 .1447 .21801 Mtetra
.646 .64 .829 r
.1447 .21801 .15294 .23151 .16516 .2275 .15703 .21319 Mtetra
.643 .626 .818 r
.15703 .21319 .16516 .2275 .17744 .22356 .16942 .20835 Mtetra
.639 .612 .807 r
.16942 .20835 .17744 .22356 .18977 .21974 .18187 .20349 Mtetra
.635 .597 .794 r
.18187 .20349 .18977 .21974 .20215 .21604 .19438 .1986 Mtetra
.63 .581 .78 r
.19438 .1986 .20215 .21604 .21458 .21254 .20695 .19369 Mtetra
.625 .563 .765 r
.20695 .19369 .21458 .21254 .22706 .2093 .21959 .18876 Mtetra
.619 .544 .749 r
.21959 .18876 .22706 .2093 .23957 .20639 .23228 .1838 Mtetra
.612 .524 .731 r
.23228 .1838 .23957 .20639 .25211 .2041 .24504 .17882 Mtetra
.604 .501 .71 r
.24504 .17882 .25211 .2041 .26469 .20231 .25786 .17381 Mtetra
.595 .478 .69 r
.25786 .17381 .26469 .20231 .27724 .20186 .27074 .16878 Mtetra
.585 .452 .666 r
.27074 .16878 .27724 .20186 .28978 .20284 .28368 .16372 Mtetra
.574 .425 .641 r
.28368 .16372 .28978 .20284 .30225 .20628 .29669 .15864 Mtetra
.562 .398 .616 r
.29669 .15864 .30225 .20628 .31446 .21552 .30977 .15353 Mtetra
.549 .368 .588 r
.30977 .15353 .31446 .21552 .32546 .24622 .32291 .1484 Mtetra
.532 .329 .551 r
.32291 .1484 .32546 .24622 .33703 .2737 .33611 .14324 Mtetra
.524 .312 .535 r
.33611 .14324 .33703 .2737 .35078 .26867 .34938 .13806 Mtetra
.34938 .13806 .35078 .26867 .36629 .23103 .36272 .13285 Mtetra
.532 .329 .551 r
.36272 .13285 .36629 .23103 .38175 .19005 .37612 .12761 Mtetra
.549 .368 .588 r
.37612 .12761 .38175 .19005 .39603 .17054 .3896 .12235 Mtetra
.562 .398 .616 r
.3896 .12235 .39603 .17054 .41003 .15682 .40314 .11706 Mtetra
.574 .425 .641 r
.40314 .11706 .41003 .15682 .42393 .14556 .41674 .11175 Mtetra
.585 .452 .666 r
.41674 .11175 .42393 .14556 .43781 .13572 .43042 .10641 Mtetra
.595 .478 .69 r
.43042 .10641 .43781 .13572 .45168 .12722 .44417 .10104 Mtetra
.604 .501 .71 r
.44417 .10104 .45168 .12722 .46558 .11922 .45799 .09564 Mtetra
.612 .524 .731 r
.45799 .09564 .46558 .11922 .47952 .11183 .47187 .09021 Mtetra
.619 .544 .748 r
.47187 .09021 .47952 .11183 .49351 .10477 .48583 .08476 Mtetra
.625 .563 .765 r
.48583 .08476 .49351 .10477 .50755 .09796 .49986 .07928 Mtetra
.63 .581 .78 r
.49986 .07928 .50755 .09796 .52165 .09135 .51397 .07377 Mtetra
.635 .597 .794 r
.51397 .07377 .52165 .09135 .53581 .08486 .52814 .06824 Mtetra
.639 .612 .807 r
.52814 .06824 .53581 .08486 .55003 .07848 .54239 .06267 Mtetra
.643 .626 .818 r
.54239 .06267 .55003 .07848 .56432 .07217 .55671 .05708 Mtetra
.646 .639 .829 r
.55671 .05708 .56432 .07217 .57868 .06591 .57111 .05145 Mtetra
.649 .652 .839 r
.57111 .05145 .57868 .06591 .59311 .05969 .58558 .0458 Mtetra
.652 .664 .849 r
.58558 .0458 .59311 .05969 .60761 .05348 .60013 .04012 Mtetra
.654 .676 .858 r
.60013 .04012 .60761 .05348 .62218 .04729 .61476 .0344 Mtetra
.656 .687 .867 r
.61476 .0344 .62218 .04729 .63683 .04109 .62946 .02866 Mtetra
.658 .698 .876 r
.62946 .02866 .63683 .04109 .65154 .03489 .64424 .02289 Mtetra
.66 .709 .884 r
.64424 .02289 .65154 .03489 .66633 .02868 .6591 .01709 Mtetra
.661 .719 .892 r
.6591 .01709 .66633 .02868 .68119 .02245 .67403 .01125 Mtetra
.662 .73 .9 r
.67403 .01125 .68119 .02245 .69613 .01619 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 233.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00n?ooool4o`000003oa0@4?oooooooooo06Wooooo003jooooo`03o`00
0?oooooooooo06_ooooo003jooooo`03o`000?oooooooooo06_ooooo003jooooo`03o`000?oooooo
oooo06_ooooo003jooooo`03o`000?oooooooooo06_ooooo003jooooo`03o`000?oooooooooo06_o
oooo003jooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Oooooo`00
n?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Goooool00?oooooo
1Oooool01Ol@413ooooooooooooooooo410@05oooooo003oooooo`Gooooo00Go0000oooooooooooo
ooooo`00001Oooooo`00ooooool5ooooo`05o`000?ooooooooooooooool00000Goooool00?oooooo
1Oooool01Ol@413ooooooooooooooooo410@05oooooo003oooooo`Gooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`1Oooooo`00o_ooool2o`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Oooooo`00
noooool3o`000003ooooool0003ooooo06Oooooo003iooooo`;o00001?ooool2o`0006Oooooo003f
ooooo`?o00001Oooool01?nY^^Ko0000ooooool0001Vooooo`00loooool3o`0000Gooooo1?nY^^H0
0ol0003oZK[Vo`00001Vooooo`00lOooool3o`0000Gooooo0_nY^>@4ojVjiP04o`000?nY^^KoZK[V
o`0006Gooooo002jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<
ob4Q8Ol0003o8B4Qolc<c00Oooooo`?o00000oooool00ol0003oooooooooo`05ojVhi0?oZK[V00Go
0000ojVji_n/_>Goooooo`00001Tooooo`00^_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B407Oooool2o`0000Kooooo0_nX]N87ojVhi003
ojVji_n/_>Go000000?o[;cU00?o0000ooooooooool0H_ooool00;[ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`05o`000?ooooooooooooooool000006_ooool3o`0000Cooooo00?oZ;;PojRe
h_nX]N801?nX]N85ojVhi004ojbihon/_>Go[;cUo`0000?o[;cU00?oooooo`000?ooool0H_ooool0
0;[ooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S806?oo
ool2o`0000Cooooo1OnX/^06ojRehP03ojVhi?n/^N?o[;WS00?o[;WS0_n/_>D01?l0003o[;cUojbl
iOn/_>D2o`0006;ooooo002jooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Gooooo0ol000001Ooooooo0000ooooooooooooYjoM00KoZ;;P1OnX]N800on/
]^7o[;WSojbih`04ojbih`;o[;cU00Ko0000ojbliOn/_>Go[kgTooooool0001Rooooo`00^_ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400Booooo`?o0000
1?ooool5ojN_g@KoZ;;P00?oZ;GRojbfhOn/]^400on/]^46ojbih`03ojbliOl0003o[kgT00?o[kgT
00?oooooo`000?ooool0H?ooool00;[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l000004?ooool2o`0000Gooooo00?oYjgKojN_gOnW[md01?nW[md5ojRbh003
oj^dgon/]^7o[;KQ00Co[;KQ1On/^N<00on_^^;o[kgTo`000005ojnmi003ooooool0003ooooo05oo
oooo002jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY
00gooooo0ol00004ooooo`GoYjgK1_nW[md00onX/^3oZkCOoj^dg`03oj^dg`Ko[;KQ00?o[;WSojnj
h_n_^^800on_^^800ol0003o[kgTojnmi002ojnmi003ok:nhooooooo0000063ooooo003Jooooo`?o
00001?ooool00onVZMWoYjgKojN]f`04ojN]f`GoYjoM00?oZk7Moj^dgon[]=l01?n[]=l5ojbfh@03
ojjhh?n_^^;o[k[R00Co[k[R00?o0000ojnmi?n__N@01?nb_^<00ooooooo0000ooooo`1Nooooo`00
eoooool3o`0000?ooooo00?o0000oooooonVZMT00onVZMT6ojN]f`03ojN_gOn[/MgoZk7M00?oZk7M
1_n[]=l00on/]^7o[[SPojjhh003ojjhh0Go[k[R00?o0000ojnmi?nb_^<01?nb_^<2ooooo`03o`00
0?oooooooooo05cooooo003Eooooo`;o00001_ooool00onVY]KoYZWIojJYf@04ojJYf@CoYjgK00?o
ZZkJoj^agOn[/Md01On[/Md4oj^dg`03ojjeg_n^^>3o[[SP00Go[[SP1?n_^^800ol0003o/KcQok:n
h`05ok:nh`03ooooool0003ooooo05gooooo003Booooo`?o00001Oooool5ojJVePKoYZWI00?oYjgK
ojZ^f_nZ[]X00_nZ[]X7oj^ag@03oj^dgon^]Mko[[GN00;o[[GN1on^^>001?n_^^;o/KcQok6lhOl0
0002ok6lh@Co/[kS0_nd_n82o`0005gooooo003@ooooo`;o00001_ooool00onUXmCoYZKFojJVeP04
ojJVePGoYZWI00?oZZcHojZ^f_nZ[]X01?nZ[]X5oj^ag@03ojjcg?n^]Mko[[GN00Co[[GN1On^^>00
1Ona^Moo/KcQok6lhOna_>7o000000?o/KcQ00?o/[kSokBoh_nd_n800ond_n800ooooooo0000oooo
o`1Kooooo`00cOooool3o`000003ooooool0003ooooo00;ooooo1OnUXm@6ojJVeP03ojJYfOnZ[=So
ZZcH00?oZZcH1OnZ[]X3oj^ag@Co[[?L1_n^]Mh00on^^>3o/KWOok6ig`03ok6ig`;o/KcQ00Co0000
ok6lhOna_>7o];gQ1ond_n800ol0003oooooooooo`1Jooooo`00b_ooool3o`0000Gooooo00?o0000
ojBPdOnUXm@01OnUXm@5ojJVeP03ojVXe_nZ[=SoZZcH00CoZZcH1_nZ[]X00on[/Mgo[[?Lojjcg003
ojjcg0Go[[GN00?o/KOMok6igona^Ml01Ona^Ml00ona_>7o0000okBmh@03okBmh@Go];oR00?o]l7Q
ooooool00000Foooool00<Sooooo0_l00004ooooo`03oj>Lc_nTX=7oY:3A00CoY:3A1_nUXm@00onV
Y]KoZJSFojVXeP03ojVXePGoZZcH1OnZ[]X00on]/=[o[[?Lojjcg005ojjcg003ojjeg_na]mgo/KOM
00?o/KOM1Ona^Ml00ond^mko];gQo`000004okBmh@?o];oR1?ng`N400ol0003oooooooooo`1Ioooo
o`00aOooool3o`0000Cooooo1?nSW<h6ojBPd@CoYJ?D00?oZJGCojVXe_nYZ=H01?nYZ=H6ojZ/f003
ojZ^f_n]/=[o[K3J00?o[K3J1On^/m`00ona]=_o/KOMok6gg@04ok6gg@?o/KWO1?nd^mh00ol0003o
];gQokBmh@03okBmh@03okBoh_ng`N7o]l7Q00Co]l7Q00?o0000ooooooooool0F?ooool008cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo0ol00004ooooo`03oj:HbonSW<koXic>00?oXic>1_nTX=43ojFSe0?oZJGC1OnYZ=H5ojZ/
f003ojf]f?n]/=[o[K3J00Co[K3J0on^/m`4ok6df`Ko/KOM00?o/KWOokBkg_nd^mh00ond^mh00ol0
003o];gQokBmh@02okBmh@03okNnh?ng`N7o]l7Q00Co]l7Q00?o^L;Qooooool00000FOooool008co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So
8B4Q01oooooo0ol00003ooooo`03o`000?nRV<_oXYS;00?oXYS;1OnSW<h6ojBPd@03ojFSe?nYYM?o
ZJGC00?oZJGC1OnYZ=H00onZ[=So[JgHojf]f003ojf]f0Ko[K3J00?o[[?Lok6dfona]=/00ona]=/5
ok6gg@03ok>hgOnd^mko];_N00Co];_N00?o0000okBmhOng_^001?ng_^03okO1h@Co^L;Q00?o0000
ooooooooool0Eoooool008cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000007Oooool2o`0000Gooooo00?oXIC7oj:HbonRV</01?nRV</5oj>LcPGoY:3A00?o
Z:;@ojVUdonYYM<01?nYYM<4ojVXeP03ojf[eOn][MSo[JgH00Go[JgH1?n]/=X00on`/]Wo/KCKok6d
f`05ok6df`03ok6ggOnc^=go/kSM00?o/kSM1Ond^mh00onf_=ko0000okNnh005okNnh003okO1hOni
`^7o^L;Q00?o^L;Q00?oooooo`000?l00000Eoooool008cooooo00Go0000ooooooooooooooooo`00
000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B406_ooool3o`0000Cooooo1OnQU<L5oj:Hb`KoXic>
00?oY:3AojRRd?nXX]000onXX]06ojVUd`03ojVXe_n]ZmGo[J_E00;o[J_E1on][MP00on]/=[o/;;I
ok2bf@02ok2bf@Go/KCK00?o/kKKok>hgOnc^=d01?nc^=d3okBkgP?o][cN00?o0000okNnh?ng_^00
0ong_^000oni_moo^L;QokW2h@05okW2h@03ooooool0003ooooo05Kooooo002<ooooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<01Oooooo0ol00005ooooo`03
oin@`onQU<OoXIC700CoXIC71_nRV</4oj>LcP03ojROcOnXX]3oZ:;@00CoZ:;@1OnYYM<00on]Z=?o
[J_Eojf[e@04ojf[e@Go[JgH00?o/:oGok2bfOn`/]T01?n`/]T3ok6df`?o/kKK1_nc^=d00ond^mko
][cNokJlgP02okJlgP04o`000?ng_^3o]kkPokNnh0Co^KoO1Oni`^400onk`^3oooooo`000009oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000iooooo`00S?ooool01Ol@
413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool05oooool2o`0000?ooooo00?o0000
ooooooooool01?nOT<<6oj6Da`GoXYS;00?oXic>ojROcOnXWld00onXWld6ojRRd003ojVUdon]Z=?o
[JSC00?o[JSC1_n]ZmD00on][MSo/:oGok2_e`03ok2_e`Ko/;;I00?o/KCKok>ffonc]]/00onc]]/4
ok>hg@;o][[L1?nf_=h00ol0003o][cNokNnh006okVog`03okW2hOnk`^3o^l;P00?o^l;P00?ooooo
o`000?ooool01oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0>Oooool008cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgM
gOl@413oV9RH01Cooooo0ol00005ooooo`;oWX^o1OnOT<<6oj6Da`CoXYS;00?oYic:ojROcOnXWld0
1?nXWld5ojRRd003ojbUd?n]Z=?o[JSC00Co[JSC1On]ZmD00on`[MGo/:oGok2_e`04ok2_e`Go/;;I
00?o/kCIok>ffonc]]/01Onc]]/00onc^=go][[LokJjg003okJjg0?o][cN00?o0000okRmgOnh_Md0
1Oni_ml00onk`=ko^l;Pok_2h005ok_2h003ooooool0003ooooo00Kooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^03[ooooo002<ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool01?o<c<coA4A4o`000?l@410@ooooo`;o00001?ooool00onLQ[_oWX^ooij;_`04oij;
_`GoWi331_nQU<L00onRV<_oYic:ojNLbP02ojNLbPGoZ9o=0onXX]04ojbUd0Go[JSC0on]ZmD4ok2]
e@Ko/:oG00?o/;;Iok>dfOnc]=T00onc]=T5ok>ff`03okJhf_nf^]co][[L00Go][[L00?o][cNokRm
gOl000000onh_Md3okVog`?o^l3N1Onk`^000onm`mooooooo`000007ooooo`05o`000?oooooooooo
ooooool000003Oooool00onHV9So8B4Qonk^kP0iooooo`00[_ooool3o`0000Cooooo1?nLQ[/5oij;
_`GoWi331OnQU<L00onWV<OoYic:ojNLbP04ojNLbPGoZ9o=00?oZ:;@ojbUd?n/YM000on/YM06ojfX
d`03ojf[eOn`[MGo/:gE00?o/:gE1On`[mL00onc/MOo/kCIok>df@04ok>df@?o/kKK1?nf^=X5okJj
g004okRkg?nh_Mgo^;gMo`0000Co^;gM00?o^KoOok_0g_nk`=h00onk`=h3ok_2h0?o_L?O00?ooooo
o`000?ooool01Oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0>?oo
ool00:cooooo0_l000000ooooooo0000ooooo`02ooooo`03oiZ0]OnLQ[_oW8Jk00?oW8Jk1OnNRkl6
oin@``03oj6DaonWV<OoYiS700?oYiS71OnWW<X4ojROc@03ojbRcOn/YM3o[:G@00Co[:G@1On]Z=<0
0on`Z];o/:gEok2]e@04ok2]e@?o/:oG1?nc/ML6ok>df@03ok>ffonf^=[o][SJ00?o][SJ0onf^]`4
okRkg003okRmgOl0003o^;gM00;o^;gM00?o^[kMok_0g_nk`=h01Onk`=h00onk`^3o_L?Ookg3g`03
okg3g`03ooooool0003ooooo00Cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oo
oooooooo03Oooooo002Yooooo`?o00000oooool00ol0003oVX2eoiZ0]@02oiZ0]@GoW8Jk1_nNRkl4
oin@``03ojJD`onWV<OoYiS700CoYiS71_nWW<X00onXWlgo[:;=ojbRc@02ojbRc@Ko[:G@00?o[JSC
ok2Zd_n`Z]800on`Z]86ok2]e@03ok2_eonc/MOo/k7G00?o/k7G1Onc]=T00onf]]Wo][SJokJhfP05
okJhfP03okJjg?nh^mco^;_L00?o^;_L00?o^;gMo`000?nh_Md01?nj_]d5ok_0gP03okc1g_nm`moo
_L?O00?o_L?O00Co_/CNooooool0003o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@400iooooo`00Y_ooool3o`0000Gooooo00?oV7Z`oiZ0]OnJP;D0
1?nJP;D5oib6^`GoWX^o00?oWi33ojJD`onVU<<00onVU<<5ojNHa`GoYic:00?o[9o:ojbRcOn/X/d0
1?n/X/d4ojbUd003ok2Xd?n`Z];o/:[B00Go/:[B1?n`[MD00onc[mCo/k7Gok>ae`05ok>ae`03ok>d
fOnf]]Wo][KI00?o][KI1Onf^=X00onh^M[o^;_LokRkg005okRkg003o`000?nj_]go^[kM00?o^[kM
0onk`=h4okc1gP?o_L?O0onna=h00ooooooo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<03Wooooo002Tooooo`;o00001_ooool4oiQj/0Go
VX2e1OnLQ[/4oij;_`03ojF@_onVU<?oYYC300CoYYC31_nWV<L00onWW<[o[9o:ojbObP03ojbObPGo
[:;=0on/YM03ok2Xd0Oo/:[B00?o/:gEok>_e?nc[m@00_nc[m@5ok>ae`03okJceonf]]Wo][KI00Co
][KI0onf^=X4okRifPGo^;_L00?o^[gKo`000?nj_]d01Onj_]d00onk`=ko_<7Nokc1gP04okc1gP03
okg3gonna=ko_/CN00;o_/CN0_ooool00ol0003oooooooooo`1?ooooo`00XOooool4o`0000Cooooo
0_nELjX5oiQj/0GoVX2e1OnLQ[/3oij;_`?oYI2o1_nVU<<4ojNHa`03ojbLaon/Wl[o[9o:00Co[9o:
1_n/X/d00on/YM3o/:S@ok2Xd003ok2Xd0Go/:[B00?o/jgBok>_e?nc[m@01?nc[m@3ok>ae`?o][?G
1_nf]]T00onf^=[o^;WJokRifP03okRifP?o^;_L0onj_M/00ol0003o^[kMokZng@03okZng@03okc0
g?nl`Mko_<7N00Co_<7N00?o_/;Mokk4g_nna=h01?nna=h00ooooooo0000ooooo`1@ooooo`00Wooo
ool2o`0000Cooooo00?o0000oiEcZ_nELjX00onELjX5oiQj/0GoVX2e1_nLQ[/00onNRkooYI2oojF@
_`02ojF@_`KoYYC30onWV<L3ojbLa`Go[9o:1On/X/d00on`YLgo/:S@ok2Xd004ok2Xd0?o/:[B1?nc
[M86ok>_e003ok>aeonf/mOo][?G00?o][?G1?nf]]T2okRhf0Ko^;WJ00?o^;_LokZmfonj_M/00_nj
_M/00ol0003o^[gKokZng@05okc0g0?o_<7N1?nn`]d4okk4gP;o`<GN00?oooooo`000?ooool0Cooo
ool009cooooo0ol00004ooooo`?oTVbT1_nELjX5oiQj/0GoVX2e1?nLQ[/00onUS;_oYI2oojF@_`04
ojF@_`KoYYC300?oYiS7ojbLaon/W<L00_n/W<L6ojbObP03ojbRcOn`YLgo/:G=00?o/:G=1_n`Z=00
0on`Z];o/jgBok>]dP03ok>]dPGo/joD00?o][;DokJceonf/mL01Onf/mL00onf]]Wo^;SHokRhf003
okRhf0Co^;WJ0_nj^mX4okZmf`03o`000?nl_]_o_<3L00Ko_<3L00?o_<7Nokk2gOnn`]d01?nn`]d0
0onna=ko`<GNol35gP03ol35gP03ooooool0003ooooo04kooooo002Jooooo`;o00001Oooool00on?
IIgoTVbToi9/Y003oi9/Y0GoUG>Z1OnHN[05oiZ0]@03oib6^onUS;_oYHbk00?oYHbk1OnUT;l5ojJD
``03ojbI`on/W<Oo[9c700Co[9c71?n/WlX00on`Xl[o/:G=ok2Uc@04ok2Uc@Go/:S@00?o]:_@ok>]
d_nc[M801?nc[M83ok>_e0Co][;D1Onf/mL00oni]]Ko^;SHokRhf005okRhf003okRif_nj^m[o^[_J
00?o^[_J0onj_M/00ol0003o_;kKokbnf`05okc0g003okk1g?nn`]go_/;M00Co_/;M00?o_l?Mol35
g_o0aMh01Oo0aMh00ol0003oooooooooo`1=ooooo`00HOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool07oooool3o`0000Cooooo1?n?IId5oi9/
Y0GoUG>Z1OnHN[04oiZ0]@03ojF8]_nUS;_oYHbk00CoYHbk1OnUT;l3ojJD``Co[9W31On/W<L3ojbO
bP?o/:?:1On`YLd3ok2Xd0Co]:_@1_nc[M800onc[mCo][;DokJbe003okJbe0?o][?G1?ni]]H5okRh
f003okZif?nj^m[o^[_J00Go^[_J00?o^[gKokbnfol000000_nl_]/3okc0g0Co_/7L0onn`]d4oko3
g@Go`<GN00?o`LGMooooool00000C_ooool0067ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1oooool00ol0003oooooooooo`0Mooooo`?o00000oooool00ol0003oooooohaNUP05ohmU
W@GoTVbT1OnELjX6oiQj/0;oVX2e0onUR;H5ojF<^`KoYI2o00?oYYC3ojbI`on/VL<00on/VL<6ojbL
a`03ojbOb_n`Xl[o/:?:00?o/:?:1On`YLd00on`Z=3o]:_@okB[d003okB[d0Go/jgB00?o]k3BokJb
e?nf/]@01Onf/]@00onf/mOo^KKFokVfeP03okVfeP?o^;SH1?nj^MP5okZkfP05okblf_nl_]_o_;kK
okbnfol000000_nl_]/00onl`=co_/7Lokk1g004okk1g003okk2gOno`mgo_l?M00?o_l?M0oo0aMh4
ol75g@;o0000COooool0067ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00007?ooool2
o`0000Kooooo0on<GYH6ohmUW@CoTVbT1OnELjX6oiQj/003oiZ0]OnUR;KoYHRf00;oYHRf1_nUS;/4
ojF@_`03ojbF_on/VL?o[9W300Co[9W31On/W<L00onaX<Oo/:?:ok2SbP04ok2SbPCo/:G=00?o]:S=
okB[d?ndZm001OndZm000onc[M;o]k3BokN`dP03okN`dPGo][;D00?o^KCDokVfe_ni]]H01Oni]]H0
0onh^=So^[WHokZif003okZif0?o^[_J1?nl_=X2okbnf`04o`000?nl_]_o_[oKokjof`Go_/7L00?o
_l;Loko3gOno`md01Ono`md00oo0aMko`LGMol75g@04ol75g@03o`000?oooooooooo04_ooooo001Q
ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0000Jooooo`?o0000
1Oooool2ohQDS@CoS5jF1_n?IId5oi9/Y0GoUG>Z1?nHN[000onTQ;;oYHRfojF8]P04ojF8]PGoYHbk
00?oYI2oojbF_on/U[l00on/U[l6ojbI``;o[9c71?naX<L6ok2SbP03ok2UcOndZ<go]:S=00;o]:S=
1OndZm000ong[]3o]k3BokN`dP04okN`dP?o][;D1?ni]=@5okVfeP03ok^heonj^MSo^[WH00Go^[WH
00?o^[_Jokblf_nl_=X00onl_=X2okbnf`03o`000?nn_m_o_[oK00;o_[oK0onn`M`3oko2g0Go_l?M
00?o`LCLol75gOo1aMd01?o1aMd00oo2a]goooooo`00001<ooooo`00HOooool01Ol0003ooooooooo
oooooooo000000_ooooo00CogMgMoeEEEOoooooo00006?ooool2o`0000Gooooo00?oQTn8ohQDSOn8
E8d00_n8E8d5ohaNUPGoSfFM1OnBK:@5oiEcZP03oiQj/?nTQ;;oY8Bb00;oY8Bb1_nUR;H4ojF<^`03
ojbB_?n/U[oo[9Jo00Co[9Jo1_n/VL<00on/W<Oo/J37ok6Pa`03ok6Pa`Go/:?:00?o]:K:okBXcOnd
Z<d01?ndZ<d3okB[d0?o]jk@1_ng/=800onf/]Co^KCDokVde003okVde0?o^KKF1?nk^=L5okZif003
okbkf?nl_=[o_;cJ00Go_;cJ00?o_;kKo`000?nn_m/01?nn_m/00onn`Mco_l;Loko2g002oko2g0?o
_l?M1?o1a=`3ol75g@Co`/KM00?oooooo`000?ooool0B_ooool0067ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03ogMgMoo<c<co000001Gooooo0ol00002ooooo`03o`000?ooooooQTn800?o
QTn81?n8E8d5ohaNUPGoSfFM1OnBK:@5oiEcZPKoY8Bb1OnUR;H3ojF<^`?o[9:l1On/U[l5ojbI``03
ok6Ma?naX<Oo/J3700Co/J370on`XlX4okBVbPKo]:S=00?o]:_@okN^d?ng[]000ong[]04okN`dP03
okVbd_ni]=Co^KCD00Go^KCD00?o^KKFok^heonk^=L00onk^=L3okZif0Co_;_H1Onl_=X00onn_][o
_[oKo`000004okjof`03oko1fono`]co_l;L00Co_l;L00?o_l?Mol74g?o1a=`01?o1a=`00oo1aMgo
`/KMol;6g@04ol;6g@03o`000?oooooooooo04Wooooo001Qooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00oo^k^koA4A4o`00000Cooooo`;o00001Oooool6ohI?R0CoR5B=1On<GYH5ohmUW@Go
TVbT1?nELjX2ojB0[@GoY8Bb1_nUR;H00onUS;_o[9:lojbB_002ojbB_0Ko[9Jo0_n/VL<4ok6Ma0Ko
/J3700?o/:?:okBVb_ndY/X00ondY/X5okBXc@03okR/c_ng[]3o]jk@00Co]jk@0ong/=83okVbdPGo
^KCD00?o^kKEok^heonk^=L01Onk^=L00onj^MSo_;_Hokbkf003okbkf0?o_;cJ1?nn_]X00ol0003o
_[oKokjof`04oko1f`Co_l;L00?o`L?Kol74g?o1a=`01?o1a=`00oo2aMco`/KMol;6g@04ol;6g@03
ol?6g?oooooo000004[ooooo001Qooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo
0000ooooo`0?ooooo`?o00001Oooool8ohI?R0CoR5B=1On<GYH5ohmUW@KoTVbT0_nELjX3ojB0[@Go
Y8Bb1OnUR;H00on]T;Oo[9:lojbB_004ojbB_0Go[9Jo00?o[9W3ok6Ma?naWL@00onaWL@5ok6Pa`03
okFTaondY/[o]:K:00Co]:K:0ondZ<d4okR/cPKo]jk@00?o]k3BokVbd_ni/]800oni/]83okVde0?o
^kKE1Onk^=L00onm^]Oo_;_Hokbkf005okbkf003okblf_nn_][o_[kJ00?o_[kJ00?o0000okjofono
`M/01?no`M/3oko2g0?o`L?K0oo1a=`4ol;5g0?o`/KM1?o3a]`00ooooooo0000ooooo`18ooooo`00
Poooool2o`0000Gooooo0_n8E8d9ohI?R0GoR5B=1?n<GYH5ohmUW@KoTVbT00?oUG>ZojB0[OnTP:d0
0_nTP:d5ojB4/PCoYHRf0_n]T;L6ojbB_0Co[9Jo00?o/Y_0ok6Ma?naWL@01?naWL@3ok6Pa`Co]JC7
1_ndY/X00ondZ<go^:c>okR/cP03okR/cPGo]jk@00?o^[7@okVbd_ni/]801Oni/]800oni]=Co^kKE
ok^fe@03ok^fe@?o^kSG0onm^]L5okbkf003okjmf?nn_][o_[kJ00Co_[kJ00?o0000oko1fono`M/0
1Ono`M/00ono`]co`L?Kol73f`03ol73f`03ol74g?o2aMco`/GL00Co`/GL00?o`/KMol?6g?o3a]`0
1?o3a]`00ol0003oooooooooo`17ooooo`00P?ooool3o`0000;ooooo00?o0000oooooon<GYH01?n8
E8d9ohI?R0GoR5B=1On<GYH5ohmUW@CoTVbT00?oY7bWojB0[OnTP:d01?nTP:d5ojB4/P;oYHRf1?n]
T;L5ojbB_0?o[9Jo0onbVl06ok6Ma003ok6PaoneY<Oo]JC700Co]JC71?ndY/X00oniZ/_o^:c>okR/
cP04okR/cP?o]jk@1?nj/M05okVbdP03okbedonk]]Go^kKE00Go^kKE00?o^kSGokfjeonm^]L00onm
^]L3okbkf0?o_[gH0onn_]X2oknofP03o`000?no_m[o_l7K00Co_l7K00?o`L;Kol73foo1`m/00oo1
`m/2ol;4f`Go`/GL00?o`lGLol?6g?o3a]`01?o3a]`00oo4a]co0000o`000018ooooo`00OOooool3
o`0000Cooooo1?n<GYH4ohQDS@WoQTn81On8E8d5ohaNUPGoSfFM0_nBK:@3ojAlY`KoY82]1OnTQ;80
0onUR;Ko[I2gojf@]`03ojf@]`Ko[9:l00?o[9Jook:K`?nbVl000_nbVl06ok6Ma0Oo]JC70ondY/X3
okVZb`Ko^:c>00?o]jk@okZad?nj/M000onj/M03okVbdPCo_;GC1Onk]]D00onm^MGo_K[Gokfje`05
okfje`03okbkf?nn_MSo_[gH00?o_[gH00Ko_[kJoknof_no_m[o_koJo`000?no_mX3oko1f`Co`L;K
0oo1`m/4ol;4f`?o`/GL0oo3aM`3ol?6g0Coa<KL00?oooooo`000?ooool0A_ooool007_ooooo0_l0
0005ooooo`03ohmUWOn<GYKoS5jF00?oS5jF1?n8E8d9ohI?R0GoR5B=1On<GYH5ohmUW@03oi9/Y?nT
O:OoY7bW00?oY7bW1OnTP:d4ojB4/P03ojj=/on]T;Oo[I2g00Co[I2g1On/T[`00oncV;co/Y_0ok:K
`004ok:K`0Co/Ig40_nfX/@7okFTa`03okBVb_niZ/_o^J[;00?o^J[;1?nh[<h00onk[lko^[7@okZa
d005okZad003okVbd_nl]M?o_;GC00?o_;GC0onk]]D4okfie@Go_K[G00?o_kcGokjmf?nn_MP00onn
_MP00oo0_]So_koJoknofP02oknofP04o`000?no_m[o_koJoko1f`Ko`L;K00?o`L?Kol;4foo2a=/0
1?o2a=/00oo2aMco`lGLol?5g003ol?5g003ol?6g?o4a]coa<KL00Coa<KL00?o0000ooooooooool0
AOooool007Sooooo0ol00005ooooo`?oSfFM1On<GYH4ohQDS@WoQTn81On8E8d5ohaNUPGoSfFM1_nT
O:L6ojB0[@;oY8Bb0on^SK<6ojf@]`;o[9:l1?ncV;`5ok:K`0?o/Ig40onfX/@6okFTa`03okVXb?ni
Z/_o^J[;00Co^J[;0onh[<h3ok^_cPGo^[7@00?o_KCAokbedonl]M<01Onl]M<00onk]]Go_KWEokfi
e@03okfie@?o_K[G1?no_=L3okjmf0?o`;kH0ono_mX00ol0003o_koJol71fP06ol72f`03ol;3f_o2
a=_o`/CK00Co`/CK00?o`lCKol?5g?o3aM`00oo3aM`7olC6g003olC7g?oooooo000004Kooooo001f
ooooo`;o00000_ooool00ol0003oooooooooo`02oi9/Y0CoSfFM1On<GYH4ohQDS@WoQTn81On8E8d5
ohaNUPGoSfFM1_nTO:L6ojB0[@03ojB4/_n^SK?o[Xfc00;o[Xfc1_n]T;L00on/T[co/iRlok>H_003
ok>H_0Ko/Y_000?o/Ig4okJRa?nfX/@00onfX/@4okFTa`?o^JS81_niZ//00onh[<ko^jo>ok^_cP03
ok^_cP?o^[7@0onm]=45okbed`03okjgdonm^MGo_KWE00Go_KWE00?o_K[Goknleono_=L01?no_=L0
0onn_MSo`;kHol2nf003ol2nf0;o_koJ00Co0000ol71f_o1`M[o`L7J0oo1`]/4ol;3fP?o`/CK1?o3
a=/3ol?5g0Koa<KL1?o4am`00ooooooo0000ooooo`14ooooo`00Loooool3o`0000Cooooo00?oUG>Z
o`000?nBK:@00_nBK:@4ohmUW@GoS5jF1?n8E8d9ohI?R0GoR5B=1_n<GYH3ohmUW@03ojEiX_nTO:Oo
Y7bW00CoY7bW1_nTP:d6ojj=/`Go[I2g1_ncV;`5ok:K`003okNP`OnfX/Co]Z;400Co]Z;40oneY<L4
okVXb0Go^J[;00?o_:k<ok^_c_nk[lh01Onk[lh00onj/M3o_KCAokfdd@02okfdd@?o_;GC1?nn]m<5
okfie@03oknkeOno_=Oo_kcG00Co_kcG00?o`;gGol2nf?o0_]P01Oo0_]P00ono_m[o0000ol71fP03
ol71fP03ol72foo2`m[o`/?J00Co`/?J00?o`/CKol?4foo3a=/01?o3a=/00oo3aMcoa<KLolC6g004
olC6g0Koa<OL00?o0000ooooooooool0@oooool0077ooooo0_l00005ooooo`?oUG>Z1?nBK:@4ohmU
W@GoS5jF1?n8E8d9ohI?R0GoR5B=1_n<GYH2ohmUW@?oYGVR1OnTO:L5ojB0[@03ok2;[on^SK?o[Xfc
00Co[Xfc1?n]T;L2okFG^@Ko/iRl0_nbVl04okNP`@Ko]Z;400?o]JC7okVXb?niZ<P00oniZ<P3okVZ
b`Co_:k<1Onk[lh00onn//oo_KCAokfdd@04okfdd@03okbedonn]m?o_[OC00?o_[OC0onm^MD4oknk
e@Co_kcG0oo0_ML5ol2nf003ol70fOo1`M[o000000?o`L7J00?o`/;Jol;3f_o2`mX01?o2`mX00oo3
a=[o`lCKol?4f`04ol?4f`03olC5foo4a]coa<KL00Coa<KL1_o4am`00oo5amcoooooo`000014oooo
o`00=oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00008_ooool3o`00
00Gooooo00?oV7Z`oiEcZ_nELjX00_nELjX4oi9/Y0GoSfFM1?n<GYH4ohQDS@WoQTn81On8E8d6ohaN
UP03ohmUWOnUNJ;oYGVR00;oYGVR1_nTO:L3ojB0[@?o/8^_1On^SK<3ojf@]`?o]INi1_ncV;`00onb
Vl3o]j31okNP`@03okNP`@Go]Z;400?o^jO5okVXb?niZ<P01OniZ<P00oniZ/_o_:k<okb^c003okb^
c0Co^jo>0onn//l5okfdd@Oo_[OC00?o_KWEoknkeOno^mD00ono^mD3oknle`Co`;gG0oo0_]P4ol70
f@03o`000?o1`M[o`L7J00?o`/;J0oo2`mX4ol?4fPCo`lCK0oo4aM/4olC6g0;oa<KK1?o4am`3olG7
g0;o0000@oooool003Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A401oooooo0ol00002ooooo`03o`000?oooooooooo00CoV7Z`1OnELjX4
oi9/Y0CoSfFM1?n<GYH4ohQDS@WoQTn81On8E8d6ohaNUPGoYGVR1_nTO:L2ojB0[@Co/8^_1_n^SK<0
0on]T;Oo]INiokFG^@03okFG^@Go/iRl1_ngX<43okJRa0Co^jO51OniZ<P00onm[LWo_:k<okb^c004
okb^c0?o^jo>1?nn//l4okfdd@;o_kOA1Onn]m<00oo0^]Co_k_Eoknke@05oknke@03oknleoo0_MOo
`;gG00Co`;gG00?o`;kHol70fOo1`=T01?o1`=T00ol0003o`/;Jol;2fP03ol;2fP03ol;3f_o3a=[o
`lCJ00?o`lCJ0oo3a=/4olC5f`?oa<KL0oo4a]/3olC7g0GoaLOL00?o0000ooooooooool01oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool08ooo
ool003Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^01kooooo0_l0
0005ooooo`;oVX2e1OnHN[05oiEcZPCoTVbT1?n?IId4ohaNUPCoR5B=2On6ChP6ohQDS@GoS5jF1OnU
NJ86ojAlY`03ojB0[On`Rjoo/8^_00?o/8^_1_n^SK<6okFG^@Co/iRl0_niW[d6okNP`@03okJRa?nk
YlGo^jO500?o^jO51?niZ<P3okf]b@Ko_:k<00?o^jo>okjbconn//l00onn//l3okfdd@Co_kOA0onn
]m<3ol2je0Go_k_E00?o`KgFol2meoo0_ML01?o0_ML00oo2_mOo`L3Iol70f@04ol70f@03ol;1fOl0
003o`/;J00Co`/;J1oo3a=X00oo3a=_oa<GKolC5f`04olC5f`03olC6g?o4a]_oa<KK00?oa<KK00?o
a<OLolG7g?o5am`00oo5am`00oo5am_oooooo`000008ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?ooool003Oooooo00Go0000oooooooooooooooo
o`00000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0ol00004ooooo`03oib6^onJP;GoVX2e00?oVX2e
1OnHN[04oiEcZPCoTVbT1?n?IId4ohaNUPCoR5B=2On6ChP6ohQDS@CoS5jF00?oZWRLojEiX_nUNJ80
0onUNJ86ojAlY`Ko/8^_1On^SK<00onfU;Go]INiokFG^@04okFG^@?o/iRl0oniW[d6okNP`@Ko^jO5
0oniZ<P4okf]b@Go_:k<00?o_k7=okjbconn//l01Onn//l00onm]=7o_kOAokngd@04okngd@03okjg
doo0^]Co`;[D00?o`;[D0ono^mD3ol6meP?o`;gG1?o2_mL3ol70f@?o`/7I00?o0000ol;2f_o2`]X0
0_o2`]X2ol?3fPGo`lCJ00?oa<CJolC5foo4aM/01?o4aM/6olC6f`03olG7foo5amcoaLOL00?oaLOL
0oo5am/00ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0002Go
oooo000gooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Gooooo`;o
00001Oooool4oib6^`CoVX2e1OnHN[04oiEcZPCoTVbT1?n?IId4ohaNUPCoR5B=2_n6ChP5ohQDS@?o
S5jF0onZN9`4ojEiXPGoY7bW0_nbRJX5ok2;[`Co[Xfc0onfU;D6okFG^@03ok>H_?niW[go^Ijm00?o
^Ijm1?ngX<42okbV`PKo^jO500?o^JS8okf]bOnm[LT00onm[LT3okb^c0Co_k7=1Onn//l00oo0]]3o
_kOAokngd@04okngd@03ol6id_o0^]Co`;[D00Go`;[D00?o_k_Eol6me_o1_MH00oo1_MH00oo0_MOo
`[oGol:oe`04ol:oe`03ol70fOo2`MWo`/7I00;o`/7I00Co0000ol;2f_o2`][o`/;J1?o3`mX3ol?4
fP?oa<CJ0oo4aM/7olC6f`?oaLOK0oo5am`5olG7f`03o`000?oooooooooo00Gooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002Kooooo000gooooo`05oa0@4?oooooo
ooooooooool@41003oooool00ol0003oooooooooo`0Cooooo`?o00000_ooool01?l0003ooooooooo
oonNRkl5oib6^`CoVX2e1OnHN[04oiEcZPCoTVbT1?n?IId4ohaNUPCoR5B=2_n6ChP5ohQDS@;oS5jF
1?nZN9`5ojEiXP?oY7bW0onbRJX6ok2;[`;o[Xfc1?nfU;D5okFG^@03ok^M^_niW[go^Ijm00Co^Ijm
0ongX<43okbV`PKo^jO51onm[LT00onl[/co_k7=oknac@03oknac@?o_[;?1?o0]]04okngd@?o`KWB
1Oo0^]@00oo2_=Co`KgFol6meP03ol6meP03ol>oe_o2_mOo`[oG00Go`[oG1Oo2`MT00ol0003o`/7I
ol;2fP06ol?3fP03ol?4f_o4a=[oa<CJ00?oa<CJ00?oa<GKolC6foo4a]/01Oo4a]/5olG7f`03olG7
g?o5am_oaLOK00?oaLOK00?oa/OKooooool000001_ooool01Ol0003ooooooooooooooooo000000_o
oooo00CogMgMoeEEEOoooooo00009_ooool003Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooooiRHV?l@41004oooool2o`0000Kooooo0onNRkl5oib6^`GoVX2e1?nHN[04
oiEcZPCoTVbT1?n?IId4ohaNUPCoR5B=2_n6ChP5ohQDS@03ohaNU_nZN9coZWRL00?oZWRL1OnUNJ82
ojAlY`Co/XVZ1_n`Rjl00on^SK?o]YBeokJD]@03okJD]@Co]INi0onkWKX6okVN_@03okNP`OnlY/;o
_:K200?o_:K21?nkYlD2okn/aPKo_Jg91ono/Ld00onn//oo`;K@ol2fd003ol2fd0?o_kOA1?o1^M83
ol2je0Co`[cD0oo1_MH3ol>oePGo`[oG0_o3`MP4ol;1f@03o`000?o3`mWo`l?J00Go`l?J1_o4a=X0
0oo4aM[oa<KKolC6f`04olC6f`03olG6foo5am_oaLOK00WoaLOK0oo6am/00ol0003oooooooooo`04
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`00=oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00@ooooo`?o0000
1Oooool2oin@``GoWX^o1OnLQ[/4oiZ0]@CoV7Z`1?nELjX4oi9/Y0CoSfFM1?n<GYH4ohQDS@[oQTn8
1On8E8d6ojYhW0GoYGVR00?oY7bWok:9Z_nbRJX01?nbRJX5ok2;[`Oo]YBe0_neUkT4ok^M^PGo^Ijm
00?o_ZFookbV`_nlY/801?nlY/83ok^Wa@Co_jc61?nm[LT2ol6abPGo_k7=00?o`[G>ol2fd?o0]]00
1Oo0]]000ono]m7o`KWBol6idP04ol6idP03ol2je?o2_=Co`[cD00Co`[cD00?o`KgFol>oe_o3_mH0
0oo3_mH3ol:oe`?o`l7H0oo2`MT01?o3`mWo0000ol?3fOo3`mT3ol?3fPOoa<CJ0oo4aMX3olC6f`Co
aLKK2Oo5am/5olK7f`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4
A?l000009_ooool005Wooooo0ol00005ooooo`03oj6DaonOT<?oWi3300?oWi331?nNRkl5oib6^`Co
VX2e1OnHN[04oiEcZPCoTVbT0on?IId4ohaNUPCoR5B=2_n6ChP5ohQDS@KoZWRL1OnUNJ87ok:9ZPGo
/8^_00?o^IBaokJD]OnfU;D01?nfU;D00oneUkWo^ifjok^M^P03ok^M^PCo^Ijm0onnYKl6okbV`P03
ok^WaOno[<Ko_jc600?o_jc60onm[LT4ol6abP?o_k7=0oo2]Lh5ol2fd0;o`[WA1Oo1^M800oo3_=?o
`[cDol:le004ol:le003ol>neOo3_mKo`koF00Go`koF00?o`[oGol?1f?o3`MP00oo3`MP01?o2`MWo
`l?Iol?3fOl00003ol?3f@03ol?3f_o4a=[oa<CJ00Goa<CJ1Oo4aMX00oo4a]_oaLKKolG6f`04olG6
f`OoaLOK1Oo6am/00oo6b=_oooooo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`0Uooooo`00Eoooool2o`0000?ooooo00?o0000ooooooooool01?nQU<L4oin@
``CoWX^o1OnLQ[/5oiZ0]@CoV7Z`1?nELjX4oi9/Y0?oSfFM1On<GYH3ohQDS@[oQTn81?n8E8d00ong
OICoZWRLojYhW004ojYhW0GoYGVR1onbRJX4ok2;[`;o^IBa1_nfU;D7ok^M^P;o^Ijm1?nnYKl5okbV
`P03ol6[a?no[<Ko_jc600Go_jc600?o_Jg9ol6ab_o1/LX01?o1/LX00ono/Lgo`[G>ol:ecP03ol:e
cP?o`;K@1?o2^M43ol6idP?o`kcC1?o2_=@3ol>ne@Go`koF00?oa<3Gol?1f?o3`MP00oo3`MP2olC2
f0;o`l?I00Co0000ol?3fOo3`mWoa<CI1_o4a=X00oo5aM[oa<GJolC5fP03olC5fPSoaLKK1Oo5am/6
olK7f`?oa/SK00?o0000ooooooooool0??ooool005Cooooo0ol00005ooooo`;oXYS;1OnQU<L4oin@
``GoWX^o1OnLQ[/4oiZ0]@CoV7Z`1?nELjX4oi9/Y0CoSfFM1?n<GYH3ohQDS@[oQTn81?n8E8d00ong
OICoZWRLojYhW004ojYhW0CoYGVR0_nfRJH7ok:9ZP;o/8^_1?niU;45okJD]@03okfL]onkWK[o^ifj
00Co^ifj00?o^IjmokjU_onnYKl00onnYKl4okbV`P?o`J_41Ono[<H00oo2/<So`K7:ol6abP04ol6a
bP03ol>dc?o2]Lko`[G>00Go`[G>00?o`;K@ol:idOo2^M401?o2^M400oo1^M;o`kcCol>ld`02ol>l
d`?o`[cD1?o3_]D3ol>oePCoa<3G0oo3`MP4olC2f003ol?3fOl0003o`l?I00?oa<CI0oo4a=X4olG5
fP?oa<GJ2_o5a]/3olG7f`Koa/OK1Oo6b=/00ol0003oooooooooo`0kooooo`00D_ooool2o`0000Go
oooo00?oXic>oj:HbonRV</00onRV</4oj6Da`GoWi331?nNRkl5oib6^`;oVX2e0_n=N[T4ohIa]0Co
OfR_0omfGJP00onBK:CoSfFMohmUW@02ohmUW@CoS5jF0on8E8d:ohI?R0CoR5B=0_ngOI@6ojYhW0;o
YGVR0onfRJH7ok:9ZP03ok2;[oniU;7o^IBa00?o^IBa1?nfU;D2okfL]`Ko^ifj1onnYKl2okbV`PCo
`J_41?no[<H3ol:`b0Co`K7:0oo3]<`5ol:ecP03olBhcoo2^M7o`[WA00Co`[WA00?oa;cBol>ldoo3
_=<01?o3_=<00oo2_=Co`kkEol>ne@04ol>ne@03ol>oe_o4`=Ooa<3G00Coa<3G00?o`l7HolC2f?o4
`]P01?o4`]P00ol0003oa<CIolC4f@03olC4f@03olC4f_o5aM[oaLGJ00CoaLGJ00?oa<GJolG6foo5
a]/02_o5a]/00oo5am_oa/OKolK7f`04olK7f`Koa/SK00?oooooo`000?ooool0>oooool004oooooo
0ol00005ooooo`CoXic>1?nRV</5oj6Da`CoWi330_nNRkl2oiB7`PGoT86n1?n=N[T4ohIa]0CoOfR_
1?mfGJP2of19W`;oSfFM1?n<GYH3ohQDS@[oQTn80on8E8d3okMmU0KoZWRL0_nUNJ83okJ9YPOo/XVZ
1_niU;43okJD]@Co_Ibg1OnkWKX00oo1Y;co_ZFookjU_`04okjU_`03okbV`_o1ZlCo`J_400?o`J_4
0ono[<H4ol:`b0?o`K7:1?o3]<`4ol:ecP?oa;S?1?o2^M43olBldPCo`kcC0_o5_]@5ol>ne@03olG0
e_o4`=Ooa<3G00Coa<3G00?oaL;GolC2f?o4`]P01?o4`]P00oo5`mWo0000olC4f@03olC4f@03olG5
fOo5aM[oaLGJ00GoaLGJ3?o5a]/8olK7f`Ooa/SK00?o0000ooooooooool0>_ooool004gooooo0_l0
0002ooooo`05o`000?oooooooooooooooonTX=401OnSW<h4oj:Hb`GoXIC70_nOT<<2oiN=aPGoU8O2
1?n@PKh5ohej^@CoQW6d0omoJ:l4ogIMZ0?oH4VO00?oSfFMohaNU_n<GYH00_n<GYH3ohQDS@[oQTn8
0on8E8d3okMmU0KoZWRL00?oYGVRokJ9Y_nfRJH00onfRJH6ok:9ZPOo^IBa00?o]YBeokfL]onmW;L0
0onmW;L4ok^M^P;o`JBl1_nnYKl7ol6[a003okn/a_o2/<So`[3800Co`[3800?o`K7:ol>dc?o3]<`0
0oo3]<`3ol:ecPCoa;S?0oo2^M44olBldP?o`kcC1?o5_]@3ol>ne@?oaL3F0oo4`=L4olG2e`?oa<;H
0oo5`mT01?l0003oa<CIolC4fOo4a=T3olG5f@OoaLGJ2Oo5a]/;olK7f`Ooa/SK00?o0000oooooooo
ool0>Oooool004[ooooo0ol00005ooooo`03o`000?nTX=7oY:3A00;oY:3A1?nSW<h5oj:Hb`?oXIC7
00?oVY7:oiN=a_nGSLH00onGSLH4oiB7`PGoT86n1?n=N[T4ohIa]0CoOfR_0omfGJP4of19W`CoS5jF
0on8E8d:ohI?R0;oR5B=1?ngOI@6ojYhW0Ko]XVV1OnbRJX2okfD[@Ko^IBa1_nmW;L3ok^M^PCo`JBl
1?nnYKl2ol>Z`@Ko`J_41oo2/<P7ol>dc003ol:ec_o4^<ooa;S?00Coa;S?00?o`[WAolBld_o4_=80
1?o4_=800oo3_=?oaKkDolFne004olFne003ol>neOo5`=KoaL3F00?oaL3F00?oa<3GolG2eoo5`]L0
1?o5`]L00oo4`]SoaL?IolG3f@02olG3f@03o`000?o5`mWoa<CI00GoaLGI1oo5aMX7olG6f`coa/OK
1oo6b=/00ooooooo0000ooooo`0iooooo`00B?ooool2o`0000Gooooo0_nUXm@6ojBPd@GoXic>1?nR
V</00onQU<OoVY7:oiZAbP02oiZAbPCoUhg61OnDQl84oi21_PCoSGZi1?n6LK@4ogmX[`CoMUfX0omP
BIl4ohaNUP?oR5B=2_n6ChP2ohQDS@Co]gfD1_nZN9`6okJ9YPCo/XVZ0onmU:d6okVD/@Oo_Ibg00?o
^ifjol6T_?o1Y;`00oo1Y;`3okjU_`Co`j[11?o1Zl@2olB`aPGo`[380_o5]<X5ol>dc003olJhcOo4
^<ooa;S?00Goa;S?1_o4_=800oo6_]?oaKkDolFne004olFne003olK0eOo5`=KoaL3F00CoaL3F1oo5
`]L5olG3f@03o`000?o5a=WoaLGI00CoaLGI1oo5aMX00oo6a][oaLKKolG6f`03olG6f`goa/OK2Oo6
b=/00ol0003oooooooooo`0hooooo`008?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^023ooooo0ol0
0004ooooo`03ojJVeonUXmCoYJ?D00?oYJ?D1OnTX=45oj>LcP;oXYS;0_nLU/d5oiZAbPGoUhg61?nD
Ql84oi21_PCoSGZi1?n6LK@4ogmX[`CoMUfX0omPBIl01?l40X3oS5jFohaNU_n<GYH3ohQDS@[oQTn8
0_n8E8d4okMmU0GoZWRL00?o_hfQokJ9Y_nfRJH01OnfRJH2ok:9ZPCo_IB]1OniU;42ol6M/`Ko_Ibg
1oo1Y;`00onnYKoo`j[1ol>Z`@03ol>Z`@?o`J_41?o4/<H3ol:`b0CoaKC:0oo3]<`3olJhc@Goa;S?
0_o6_=04olBldP?oa[kC1?o5_]@3olK0e@CoaL3F0_o6`]L5olG2e`;oaL?H1?o5`mT00ol0003oaLCI
olG4f@03olG5f@KoaLGJ1?o6a]X3olG6f`goa/OK2_o6b=/00ooooooo0000ooooo`0hooooo`008?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo0ol00003ooooo`03o`000?ooooooYZKG00?oYZKG
1OnUXm@5ojBPd@;oXic>0_nMV]05oibFc@GoVY7:1?nGSLH4oiB7`PGoT86n0on=N[T4ohIa]0CoOfR_
1?mfGJP3of19W`04o`@2P?n<GYKoS5jFohaNUP?oR5B=2_n6ChP00on8E8go]gfDokMmU003okMmU0Go
ZWRL0_noSJ46okJ9YP03ok:9Z_nmU:go_IB]00?o_IB]1?niU;43ol6M/`Go_Ibg0_o4Y;T6ol6T_0Oo
`j[100?o`J_4olB`a_o4/<H01?o4/<H00oo2/<SoaKC:olFdbP04olFdbP03ol>dc?o6^<goa[S=00?o
a[S=0oo4^<l3olJld0?oa;cB1?o6_]<3olFne0Coa/3E0oo5`=H4olK2e`?oaL;G0oo5`mP3olG3f@;o
aLCI00Co0000olG4fOo5a=WoaLGI1_o5aMX6olK6fP03olG6foo6am_oa/OK00_oa/OK2oo6b=/2oooo
o`03o`000?oooooooooo03Kooooo000Pooooo`05oa0@4?ooooooooooooooool@41006oooool2o`00
00Gooooo0_nVZMT6ojJVe`GoYJ?D0_nTX=42oinNd`GoWI[@1OnLU/d4oiZAbPCoUhg61OnDQl84oi21
_PCoSGZi1?n6LK@3ogmX[`CoMUfX0omPBIl01?l40X3oS5jFohaNU_n<GYH3ohQDS@[oQTn800?oR5B=
okMmU?ngOI@00ongOI@4ojYhW0?o_hfQ1_nfRJH7okfD[@;o^IBa1?o1WK<4okfL]`?oa:Bi1Oo1Y;`2
olJZ_PGo`j[100?oak33olB`a_o4/<H01Oo4/<H7olFdbPOoa[S=00?oa;S?olJld?o6_=000oo6_=00
0oo4_=;oa[kColJnd`04olJnd`03olFne?o6`=Goa/3E00Coa/3E00?oaL3FolK2eoo6`]L01?o6`]L0
0oo5`]OoaL?HolG3f003olG3f007olG3fOo5a=WoaLCIolG4fOl0003oaLCIolK5f@05olG5fPOoa/KJ
00?oa/OJolK7foo6am/02oo6am/=olK8f`03ooooool0003ooooo03Oooooo000Pooooo`05o`000?oo
ooooooooooooool000006?ooool3o`0000Cooooo00?oYjgKojJYfOnVZMT00onVZMT5ojJVe`CoYJ?D
00?oX:;FoinNdonOW]<00onOW]<5oifJd0CoW9K=1OnJTLX4oiN=aP;oU8O20_n:PlH4ohAk`P?oOWBm
00?oSGZiohIa]?n6LK@00_n6LK@4ogmX[`?oMUfX1?mPBIl00ol40X3oS5jFohaNUP03ohQDS@[oQTn8
00?oR5B=okMmU?ngOI@01?ngOI@2ojYhW0Co_hfQ1_nfRJH7okfD[@03okVD/Oo1WK?o`Ifc00Co`Ifc
0_nmW;L4olBT^@Co`JBl0oo6Z[h4ol>Z`@?oak331Oo4/<H2olRda`GoaKC:0_o8^L/5olJhc@03olRl
coo6_=3oa[c@00?oa[c@0_o7_]85olJnd`03olO1e?o6`=Goa/3E00Coa/3E00?oal;FolK2eoo6`]L0
1?o6`]L00oo6`mOoaL?HolG3f003olG3f003olK4f?o5a=WoaLCI00;oaLCI00Co0000olK5fOo6aMWo
a/GI0oo5aMX7olK6fP?oa/OJ3Oo6am/=olK8f`03ooooool0003ooooo03Kooooo000Pooooo`05o`00
0?ooooooooooooooool000005_ooool3o`0000Cooooo1?nW[M/5ojJYf@GoYZKG00?oYJ?Doj2Re_nP
X]H00_nPX]H5oinNd`CoWI[@1OnLU/d2oiZAbP;oTXo=1?n>RLT4ohZ3aPCoQ7_21?mnM;d3og9X^@03
ohIa]?moJ:ooOfR_00;oOfR_0omfGJP4of19W`03o`@2P?n<GYKoS5jF00?oR5B=2_n6ChP7okMmU0;o
ZWRL1?noSJ45okJ9YP;o`YJY1_nmU:d7ol6M/`03okfL]oo4Y;Woa:Bi00Coa:Bi0_o1Y;`4olJZ_P?o
`j[11?o7/<<4olB`aP?ob;C71?o5]<X3olRib`?oa[S=1?o8_<l3olJld0CoakkB0oo6_]<3olO1e0?o
a/3E1?o7`]H3olK2e`Coa/?G0oo5`mP3olK4f0?oaLCI00?o0000olK5fOo6aMT00_o6aMT00oo5aM[o
a/KJolK6fP05olK6fPGoa/OJ3Oo6am/<olK8f`;ooooo00?o0000ooooooooool0=?ooool0023ooooo
00Go410@oooooooooooooooooa0@400Cooooo`?o00000oooool00ol0003oooooojN_g@06ojN]f`Go
YZWI0_nVY]L2oj6Uf0KoX:;F1?nOW]<5oifJd0;oW9K=0_nEU=05oi:?c@CoSXW91?n:PlH4ohAk`P?o
OWBm1?mbJ;T3ofIL/`04ogmX[omfGJSoMUfXogIMZ0CoH4VO0_l40X001?n<GYKoR5B=ohQDSOn8E8d:
ohI?R0Oo]gfD00?oZWRLokn=XOnoSJ400onoSJ44okJ9YP?o`YJY1_nmU:d7ol6M/`Ooa:Bi00?o`JBl
olJZ__o6Z[h01?o6Z[h00oo3Z/7oak33olN```03olN```?oa;361?o8]<L3olFdbPGob;W;00?oa[S=
olRlcoo8_<l01?o8_<l00oo6_=3oakkBolNndP04olNndP03olJndoo7`MCoal7D00?oal7D00?oa/3E
olO2e_o7`]H01?o7`]H00oo6`]Ooa/?GolK3e`04olK3e`03olG3f?o6a=Soa/CH00?oa/CH00?oaLCI
olK5fOl000001?o6aMT6olK6fPKoa/OJ3Oo6am/>olK8f`03ooooool0003ooooo03Gooooo000Poooo
o`05ogMgMonHV9SooooooiRHV?mgMgL04Oooool2o`0000Gooooo00?oZ;;PojN_gOnW[md00_nW[md6
ojN]f`;oYZWI0_nRZ=/5oj6Uf0GoX:;F1OnOW]<2oifJd0;oUiSC1OnEU=04oi:?c@CoSXW91?n:PlH4
ohAk`PCoOWBm0ombJ;T4ofIL/`;oDT^[0_mfGJP3of19W`;o10:000CoS5jFohQDSOn8E8goR5B=2On6
ChP00on]Li;o]gfDokMmU005okMmU003ojYhW?noSJ7o_hfQ00Co_hfQ0_nfRJH4ol:FZ@Go_IB]0_o5
W[06ol6M/`03olNU]_o4Y;Woa:Bi00Coa:Bi1oo6Z[h7olN```03olB`a_o8]<Oob;C700Cob;C700?o
aKC:olRiboo8^L/01?o8^L/6olRlc`03olVod?o7_];oakkB00CoakkB00?obL7ColO1e?o7`M@01?o7
`M@00oo8`mGoal;FolO2eP03olO2eP03olO4eoo6`mOoa/?G00Coa/?G00?oalGHolK4f?o6a=P00oo6
a=P3olK5f@04o`000?o6aMWoa/GIolK5f@Goa/KJ1oo6amX<olK7fa7oa/SK0_l0000eooooo`008?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo0ol00005ooooo`CoZ;;P1?nW[md4ojN]f`03oj>[
gOnRZ=_oXZSK00?oXZSK1OnQYMP5oj2ReP;oWikC0_nJW=D5oiNHd`CoUIC@1?nBSld4ohj9b@CoRX?6
1?n4Nl84ogid_@CoLVRi0omVG;<3oe9;Z`04ogIMZ?mPBIooH4VOof19W`;o10:000CoS5jFohQDSOn8
E8goR5B=2On6ChP00on]Li;o]gfDokMmU005okMmU0Oo_hfQ0_nfRJH4ol:FZ@Co_IB]0oo5W[05ol6M
/`;oajFf1_o4Y;T00oo9Zk_oaZZnolJZ_P04olJZ_P03olZ``Oo7/<?oak3300Coak331oo8]<L7olRi
b`03olZmcOo8_<oob;c?00;ob;c?0oo9_m04olNndP?obL7C1?o7`M@3olS3e@?oal;F0oo7a=L3olK3
e`CoalGH0oo6a=P4olK5f@03o`000?o6aMWoa/GI00Goa/KJ1oo6amX<olK7fa;oa/SK0_ooool00ol0
003oooooooooo`0booooo`00<?ooool3o`000003ooooool0003ooooo00;ooooo0_nX]N85ojRbh0Go
YjoM00?oYjgKoj>[gOnSZmd00_nSZmd5oj:Xf`GoXJGH0_nPX]H2oi^Pf0GoVYcE1?nGV=<4oiFDd0Go
TXo=1?n>RLT4ohZ3aP?oQ7_21?mnM;d4og9X^@CoIUbc0omBBj/3of19W`?o10:00on8E8d9ohI?R003
ojecT_ngOICo]gfD00Go]gfD1onoSJ400onfRJKo`YJYol:FZ@04ol:FZ@;o_IB]1?o5W[04ol6M/`Co
ajFf1?o4Y;T3olV[^`CoaZZn0oo:/<44olN```;ob[G51Oo8]<L2ol^ib@Gob;W;0_o:_Ld3olRlc`Co
bKo@0oo7_]84olW1d`?oal7D1Oo8`mD00oo7`]KoalCGolO4e`03olO4e`03olK3eoo7aMSoalGH00Co
alGH00?oa/CHolK5fOo6aMT00_o6aMT2o`000003olK5fOo6a][oa/KJ00?oa/KJ1oo6amX;olK7faGo
a/SK00?oooooo`000?ooool0<oooool002kooooo0_l00005ooooo`03o`000?nX]N;oZ;GR00?oZ;GR
1OnX/^02ojN_g@?oY:kO1OnSZmd5oj:Xf`;oXJGH0_nMY=X5oi^Pf0CoVYcE1?nGV=<5oiFDd0CoTXo=
1?n>RLT4ohZ3aPCoQ7_20omnM;d4og9X^@CoIUbc0omBBj/3of19W`?o10:00on8E8d8ohI?R0?o[G>B
1_ngOI@7okn=X@Oo`YJY00?o_IB]olFN/?o5W[001?o5W[02ol6M/`GoajFf0oo4Y;T4olV[^`?oaZZn
1?o:/<43olN```Cob[G50oo8]<L4ol^ib@?ob;W;1?o:_Ld00oo8_<oobKo@olVod004olVod003olNn
d_o9`M?obL7C00CobL7C00?oal7DolS3eOo8`mD00oo8`mD00oo8a=KoalCGolO4e`04olO4e`03olS5
f?o7aMSoalGH00?oalGH00?oalKIolK5fOo6aMT00ol000000oo6aMWo0000olK6fP04olK6fPWoa/OJ
2Oo6am/GolK8f`03ooooool0003ooooo03;ooooo000[ooooo`?o00001Oooool4ojVhi0GoZ;GR0_nX
/^02ojBah@KoY:kO1OnSZmd2oj:Xf`;oWZOL1OnMY=X4oi^Pf0CoVYcE1OnGV=<4oiFDd0;oTXo=0_n:
SM04ohF6c@CoOh390omgMlH00on4Nl;oOWBmogid_@02ogid_@?oLVRi1?mVG;<3oe9;Z`03ob<UVomP
BIooH4VO00?o10:000?o>R67ohQDSOn8E8d02?n6ChP3ojecTPGo]gfD0_oFViL6okn=X@03olfMYOo2
UZWo`YJY00Co`YJY1oo5W[000oo1WK?oajFfolNU]P05olNU]P03olBT^Oo9Zk_obJ^k00CobJ^k00?o
aZZnolZ``Oo:/<401?o:/<400oo7/<?ob[G5olZea@04olZea@03olRdaoo;^LWobkW900CobkW900?o
b;W;olZmcOo:_Ld00oo:_Ld7olVod003ol_2d_o9`M?obL7C00?obL7C00?obLCDolS3eOo8`mD00oo8
`mD3olS4ePCoalCG0oo8aMP3olO5f004olO6fOl0003o0000o`0000;oa/GI0oo7a]T01?l0003oa/KJ
olK6f_o6a]X;olK7fPOoa/OK6?o6b=/2ooooo`03o`000?oooooooooo033ooooo000Zooooo`;o0000
1Oooool2ojVjiPGoZKST0onX]N800onU]>?oY;7QojBah@03ojBah@KoY:kO0_nSZmd2oinZg`GoWZOL
1?nMY=X5oi^Pf0CoVYcE0_nGV=<2oi6Ge@CoSY;C1On:SM04ohF6c@CoOh390omgMlH3ofm^`P04ogid
_OmbJ;WoLVRiog9X^@CoIUbc0omBBj/2ob<UV`;oH4VO0_l40X000olj8HOoR5B=ohQDS@07ohI?R0Co
[G>B1OngOI@2omJKU`Go_hfQ0_o=WJD6ol:FZ@03ol^Q[?o5W[3oaIj`00CoaIj`2?o7YKH7olV[^`Oo
b[311oo:]LD6ol^ib@03olfnc?o:_Lgob[g=00?ob[g=0_o<`<l5olVod0?obl;B0oo9`M<3olW4e0?o
b<?E1?o8a=H3olO4e`Gob<GH0ol00003olO6f@03olK5fOo7a]WoalKI00?oalKI00?o0000olK6f_o6
amX02oo6amX5olK7fa_oa/SK00?oooooo`000?ooool0<Oooool002[ooooo0ol00002ooooo`GoZK[V
1OnY^>@01?nX]N;oYKCSojFdhonU]><5ojBah@CoY:kO00?oX:gQoinZgonOZ]l00onOZ]l5oijWg0Co
WJCJ0_nKX=P2oiJOfPCoU9_H1OnAUmD4ohjBd`CoRXg@1?n5Q/d4ogn0b@CoMgO60om_K/82oeiP_0;o
LVRi0omVG;<4oe9;Z`03ob<UVomPBIooH4VO00;o10:000?o>R67ohQDSOn8E8d01on6ChP4ojecTPGo
]gfD0_oFViL5okn=X@;ocIfU1Oo2UZT2ol^Q[0KoaIj`00?oc:JcolNU]_o7YKH01Oo7YKH00oo=[;Wo
bJ^kolV[^`04olV[^`03olfa__o:/<7ob[3100?ob[310_o>]/<5olZea@;ocK[81?o;^LT3olfnc0?o
b[g=1?o<`<l3olVod0Gobl;B00?obL7ColW4e?o9a=@00oo9a=@00oo8`mGob<CFolS4eP04olS4eP04
olO4eoo8aMSob<GHolS5f0?o00001Oo7a]T00oo7amWoalKIolO6f@04olO6f@03olO7f_l0003oa/OJ
00?oa/OJ0_o7amX7olK7fP?oa/OK7Oo6b=/00ooooooo0000ooooo`0`ooooo`00:_ooool00ol0003o
ooooo`000003ojVmj0GoZK[V0_nY^>@2ojFgi@GoYKCS1OnT/N400onT[]ooX:gQoj2]h@02oj2]h@Go
Wj[O1OnNYm`2oifTfP03oiRSg?nFWm[oUYoJ00?oUYoJ1?nDVmP5oi6Ge@CoSY;C1?n:SM04ohF6c@Co
Oh390omgMlH4ofm^`P?oGV2l1?mVG;<3oe9;Z`;o8bFK00?oH4VOo`@2P?l40X000_lj8HL00on8E8go
QTn8ohI?R005ohI?R0Co[G>B1OngOI@2omJKU`Co_hfQ1?o=WJD4ol:FZ@;obj6/1Oo5W[02olbV/`Ko
ajFf0_o=[;T5olV[^`;ocK6n1?o:/<43oljf``Cob[G50oo=^/P3ol^ib@GocKk<00?ob[g=olc0coo<
`<l01?o<`<l00oo9_m3obl;Bol_2dP03ol_2dP03ol_5e?o9a=CobLCD00CobLCD00?ob/GFolS4e_o8
a=H00oo8a=H00oo9a]Oob<GHo`000002o`000004olS5f?o8a]Sob<KHolS6f0?oalKI0oo7amT3olO6
f@?oalOJ00Co0000olK7f_o6am[oa/OJ1?o7amX7olK7fP03olK7foo6b=_oa/SK01goa/SK00?ooooo
o`000?ooool01oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`04oooool002[ooooo00?o0000ojVmj?nY_NP01?nY_NP2ojVjiP?oYK[W1?nU
]nD5ojFdh`;oY;7Q0onQ/><5oj2]h@GoWj[O0_nNYm`2oiVVgPCoV:?L1OnFWmX4oiBKf0CoTIOE1?n>
T]<4ohZ=d0CoQHK=1?moP<T4ogMgaP?oKfk20omNH;`2od]@]P;oIUbc0omBBj/3ob<UV`;o10:00_lj
8HL00on8E8goQTn8ohI?R004ohI?R0Go[G>B1?ngOI@3omJKU`Co_hfQ1?o=WJD3ol:FZ@Cobj6/1?o5
W[03olbV/`CoajFf0oo=[;T4olV[^`?ocK6n0oo:/<44oljf``?ob[G51Oo=^/P00oo;^LWocKk<olfn
c004olfnc0Koc<3?00?ocLCAol_2d_o;`]800oo;`]83ol_5e0CobLCD0oo:aMH3olS4eP?o00000oo8
aMP5olS6f003olO6fOo7amWoalOI00?oalOI00?oalKIolO7f_o7amX00oo7amX00ol0003oa/OJolO7
fP04olO7fPKoa/OJ00?oalSKolK8foo6b=/07oo6b=/00ol0003oooooooooo`06ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0Cooooo`00
7oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool01?nY_NP2ojJlj@Go
YK[W1?nU]nD2ojFdh`?oXK?U1OnQ/><5oj2]h@;oWj[O0_nKZN45oiVVgPCoV:?L1?nFWmX5oiBKf0Co
TIOE1?n>T]<4ohZ=d0CoQHK=0omoP<T4ogMgaPCoKfk20omNH;`3od]@]P?oDT^[0olS9I/2o`@2P0;o
>R6700?oR5B=ohI?R?n6ChP01?n6ChP5ojecTPCo]gfD0ooFViL3okn=X@GocIfU0oo2UZT4ol^Q[0?o
aIj`1?o<Y[<3olNU]PGocJbi0_o9Zk/5olfa_P03olZ``Oo>]/?oc[K300Coc[K300?ob[G5olfjb?o=
^/P01?o=^/P6olfnc0;oc/;>1?o<`<l3olg4d@?obl;B1?o;aM@3olW4e0Cob/GF0ol00004olW6e`03
olS5f?o8a]Sob<KH00?ob<KH00?ob<OIolO7fOo7amT00oo7amT8olO7fP03o`000?o7am[oalOJ00Co
alOJ0oo6amX4olO8fb3oa/SK00?oooooo`000?ooool01_ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`00000Cooooo`007oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0ol000000oooooooZKgXojJlj@04ojJlj@GoYK[W0_nU]nD2oj6fi`GoXK?U1OnQ/><2
oj2]h@;oW:cS1OnKZN44oiVVgPGoV:?L1?nFWmX2oiBKf0;oSY[J1?n;UMP4ohN@ePCoPX_C1?mlQ=03
ogAmc@04ogn0bOmgMlKoMgO6ogMgaPCoKfk20omNH;`3od]@]P03obdi[?mBBj_oDT^[00?o8bFK0_l4
0X03ocXQQ`KoQTn81On]Li84okMmU0CoeY^G0_noSJ46olfMY@03ol:FZOo;XJcobj6/00?obj6/0_o5
W[06olbV/`03olNU]_o=[;WocJbi00CocJbi00?obJ^kolfa__o=/Kh01?o=/Kh7oljf``OocK[800?o
d;o:olfnc?o=_/`00_o=_/`3olk2cP?oc<3?1Oo=a=400oo;`];oblGDol_5e004ol_5e004olW4e?o:
aMKob/GFol[5eP;o000000?ob/OGolW6eoo9a]L00oo9a]L00oo9amSob<KHolS6f003olS6f0?ob<OI
0oo7amT9olO7fP03o`000?o7am[oalOJ00GoalOJ00?oa/OJolO8foo7b=/01?o7b=/;olK8f`03olO8
foo6b=_oa/SK01;oa/SK00?oooooo`000?ooool01Oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000oiRHV?ooooooV9RHob4Q8@0Cooooo`007oooool01Ol@413ooooooooooooooooo410@
00Gooooo00?o0000ooooooooool00_ooool6ojJlj@;oYK[W0_nR^NT5oj6fi`GoXK?U0_nQ/><3oib_
i@CoW:cS1?nKZN45oiVVgP;oV:?L0_nCX]h4oi6Ng0GoSY[J1?n;UMP4ohN@ePCoPX_C1?mlQ=03ogAm
c@?oJG?:00CoMgO6ofm^`_m_K/;oKfk20omNH;`4od]@]P03obdi[?mBBj_oDT^[00;o8bFK0_l40X03
ocXQQ`?oQTn80_n9F946ojecTP?o]gfD1OoFViL00onoSJ7ocIfUolfMY@05olfMY@03ol:FZOo;XJco
bj6/00Cobj6/00?oaIj`olbV/oo<Y[<01?o<Y[<7olf/^@OocK6n00?odKO1oljf`oo>]/<01?o>]/<0
0ooA^lKocK[8olfjb003olfjb0;od;o:0oo=_/`5olk2cP03olc0coo=a=7ocLCA00CocLCA1_o;aM@0
0oo<amGob/GFo`000002o`000004ol[5e_o:amOob/OGol[7e`?obLKG0oo9amP3olS6f0Gob<OI00?o
alOIolO7f_o7amX02Oo7amX00ol0003oalOJolO7fP03olO7fPSoalSK1Oo6b=/2olO8f`?oa/SK0oo7
b=/DolK8f`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`04oooool001oooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo00?ooooo1?nV_>T2oj:kj`CoX[WY1OnQ]^L2oj6ci@?oWK;V1OnL[nD4oib/h`Co
VjWQ0_nIY]h2oiFUh@GoTj;N1?nAW]`5ohjJfPCoRiGH0on7T=H4oh:;d`CoO8C@1?mdOLd3ofUcbP?o
GVW600CoKfk2oeiP_?mNH;coGV2l0om;D;H2obdi[005oe9;ZolS9I_o8bFKob<UVol40X000olj8HL5
ohUHT@Ko[G>B0ongOI@5omJKU`03okn=XOo=WJGocIfU00GocIfU1oo;XJ`7olbV/`03om6^]_o=[;Wo
cJbi00CocJbi00?odK:kolfa__o=/Kh00oo=/Kh3om6g`@Coc[K30ooA^lH3olfjb0Cod;o:00?ocKk<
olk2c_o>`/h01?o>`/h00oo@aM3ocLCAolg4d@03olg4d@;oc/KC0oo;aM@01?o<amGo0000o`000?l0
0003ol[5ePGob/OG00?obLKGolW7f?o9amP00oo9amP00oo8a]Sob<OIolS7f@03olS7f@03olS8f_o7
am[oalOJ00?oalOJ00?oalSJolO7f_o7amX01?o7amX00oo7b=[o0000olO7fP02olO7fP[oalSK0oo6
b=/4olO8f`03olK8foo7b=_oalSK00?oalSK4oo6b=/00ooooooo0000ooooo`04ooooo`05oa0@4?oo
ooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Eooooo`007oooool01Ol0003ooooooooo
oooooooo000000Gooooo0_l00005ooooo`03ojJljOnR^n_oX[_[00?oX[_[1?nR^NT2oj6fi`?oWKGX
1OnM/^H5oib_i@CoW:cS0_nKZN400onFZ>;oUJGQoiFUh@03oiFUh@GoTj;N1?nAW]`4ohjJfPCoRiGH
0on7T=H4oh:;d`CoO8C@1?mdOLd4ofUcbP?oGVW60_m:FL001?mNH;coBe2fod]@]_m;D;H3obdi[0?o
8bFK00Co10:0ocXQQolj8HOo>R671On9F946ojecTP?o]gfD1OoFViL8olfMY@Oobj6/00?odJV`olbV
/oo<Y[<00oo<Y[<2om6^]PGocJbi0ooA/[/3olfa_PCodKO10oo>]/<5om6kaP03olfjb?o@_l[od;o:
00?od;o:00?odLC=olk2c_o>`/h00oo>`/h3om35d0?ocLCA1?o>a]<3o`0000Coc<OE00?ob/GFol[7
eoo:amL00oo:amL00oo:b=SobLOHolW7f003olW7f003olW8fOo8amWob<OI00?ob<OI0oo8b=X3olO7
fP?oalSJ0oo7amX4olO8fP03o`000?o7am[oalSK00_oalSK00?oa/SKolO8foo7b=/02Oo7b=/5olK8
f`;oalSK3Oo6b=/2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413o
V9RH01Gooooo000Oooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`06
ooooo`GoX[_[0_nR^NT2oijgj`GoWKGX1OnM/^H2oib_i@;oV:kV1?nGZn@4oiJXhPGoUJGQ1OnCX]h4
oi6Ng0CoSY[J1?n;UMP3ohN@ePCoPX_C1?mlQ=03ogAmc@CoJG?:0omNJLH3odYI`0CoBe2f0_l]>J`3
ob<UV`;o10:00_lj8HL5ohUHT@Oo[G>B0_ngOI@5omJKU`03onR`V?o=WJGocIfU00CocIfU0_oFZJT5
ol^Q[0;odJV`1?o<Y[<4om6^]P?ocJbi1?oA/[/3olfa_PGodKO100?oc[K3om6ka_oA^lH00ooA^lH0
0ooC`LSod;o:om2obP03om2obP?odLC=0oo>`/h5om35d003olg4dOo>a]?oc/KC00?o000000?oc/WE
olc7eOo<amD00oo<amD00oo<b=Oob/OGol[7e`03ol[7e`?ob/SH0oo9amP3olW8f@?ob<OI1Oo8b=X0
0oo7am[oalSJolO8fP03olO8fP03olO7f_o7b=[oalSJ00?oalSJ00?o0000olO8foo7b=/06?o7b=/3
olK8f`CoalSK3?o6b=/00ooooooo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool01?o<c<coA4A4o`000?l@410Cooooo`007oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
00?o0000ooooooooool01oooool2oj:kj`?oWK[]1?nN]n/5oifej0;oWK;V0_nI/NP5oiR^iPCoUj_T
1?nFZ>85oiFUh@;oTj;N0_n>XN44oh^Mg`CoR9WM1?n4U=/3ogn?f@CoNHWG0omaP]@00omlQ=3oM7g=
ogAmc@02ogAmc@?oJG?:1?mNJLH3odYI`0?oBe2f0ol]>J`2ob<UV`;o10:00_lj8HL5ohUHT@Oo[G>B
00?o]gfDomJKUooFViL01?oFViL00ooX/9SocIfUolfMY@04olfMY@;oeZVY1?o;XJ`3om6Y/0?oc:Jc
1OoA[[H3olf/^@GodK:k00?ocK6nom6g`OoA]l401?oA]l45om6kaP?odl780oo@_lX5om74c@03olk2
c_o@aM3od<G@00?od<G@00Cod<WCo`000?l0003o00000_o>a]<3olk9e@?oc<OE0oo<b=L3ol[7e`Go
b/SH00?obLOHolW8fOo9b=T00oo9b=T00oo8amWob<SJolS8fP04olS8fPgoalSJ00?o0000olO8foo7
b=/06?o7b=/00oo6b=_oalSKolO8f`03olO8f`goa/SK00?oooooo`000?ooool0:_ooool001oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oooooooooo00Wooooo1OnM^^d4oijgj`;o
WKGX0onI/nX4oiVaj0CoV:kV1OnGZn@4oiJXhP;oUJGQ0_n@Y><5ohjQh@CoRigO1?n8VMd4ohBDf`?o
OhoI1?miRML3og62e0?oJ7[B00?oM7g=ofUcb_mYLlX00_mYLlX3oeiYaP?oBUW00_l`A[P01?m;D;Ko
;CV/obdi[?l]>J`2ob<UV`;o10:00_lj8HL5ohUHT@Oo[G>B00?o]gfDomJKUooFViL00ooFViL2onR`
V0GocIfU0ooFZJT4ol^Q[0CodJV`0_o<Y[<6om6^]P03olf/^OoA/[_odK:k00CodK:k1_oA]l42omBm
``?odK_61OoC`LP00oo@_l[odLC=om74c@03om74c@03om?8d?o@aM3od<G@00;od<G@0ol000001?o@
bM?oc/KColk6doo>a]<5olk9e@03olc7eOo<b=Ooc<SG00?oc<SG00?ob/OGol[8f?o:b=P00oo:b=P0
0oo:bMWobLSIolW8f@03olW8f@?obLSJ1_o8b=X=olO8fP03o`000?o7b=_oalSK01koalSK3Oo6b=/0
0ol0003oooooooooo`0Yooooo`00:?ooool3o`0000[ooooo1OnM^^d2oijgj`;oVKK/1OnI/nX4oiVa
j0CoV:kV0_nGZn@2oi>ZiPGoTJOT1?n@Y><4ohjQh@CoRigO1?n8VMd4ohBDf`CoOhoI1?miRML3og62
e0?oJ7[B0omKL<h01?mYLl[oGVW6oeiYa_mNJLH3odYI`0?o<4Jh00OoBe2fobdi[?l]>Jco00NBob<U
Vol003?o10:000;o>R671On9F947ojecTP03okMmU?oFViOoeY^G00?oeY^G0ooX/9P4olfMY@?oeZVY
0oo;XJ`5om6Y/003olbV/ooA[[KodJjf00GodJjf1ooA/[/00ooE^KkodKO1om6g`@02om6g`@Coe;g3
00?odK_6om?1b?oC`LP01?oC`LP5om74c@?odlS@0ol00005om39d`03olk6doo>bMGoc/WE00?oc/WE
00?ocL_Golc8eoo<b=L00oo<b=L3olc:f0?ob/SH0oo:bMT3olW8f@GobLSJ1_o8b=X<olO8fP03olO8
fol0003oalSK01ooalSK2oo6b=/00oo6b=coooooo`00000Zooooo`00:?ooool00ol0003ooooooooo
o`0;ooooo`;oWK[]0_nI^Nh5oiVfk0GoVK?Z1?nI/NP2oiR^iP;oU:gX1?nCZ^H5oi6Wi0CoT:CS1?n>
XN44oh^Mg`CoR9WM1?n4U=/4ogn?f@?oNHWG1?maP]@3ofQjdP?oFg3>0_m<I<X2oeiYaP?oBUW00ol`
A[P3obdi[003o`07T_lS9I_o10:000;o>R671On9F947ojecTP03okMmU?oFViOoeY^G00?oeY^G0ooX
/9P3olfMY@GoeZVY0_o;XJ`5om6Y/0SodJjf00?oeKBiom6b^ooA/[/00ooA/[/2omFi_P?odKO11OoD
_L<7om?1b004omG6booAa<godLC=om74c@;odlS@0_l000000ooCb=3od<G@om39d`05om39d`Goc/WE
0oo=bmL3olc8e`Goc<[H00?ob/SHol[9fOo:bMT00oo:bMT00oo9b=WobLSJolW8fP03olW8fP03olS9
f_o8b=[ob<SJ00Cob<SJ2oo7b=X2olO8f`03o`000?o7b=_oalSK01goalSK1_o6b=/2olK8g0?oa/SK
0oo6b=`00ooooooo0000ooooo`0Xooooo`00:?ooool00ol0003oooooooooo`0<ooooo`CoVKW^1OnI
]^`2oiVcjP?oUK;[0onE/>T5oiB]j0CoTj[V1OnAYn@4oi2Th`;oSZ7Q00?oRJ3SohJLh_n6W>800_n6
W>84oh:Hh0CoOI?N1?mhS]`3og68f`04ogV9eomaP]CoLH;Dog62e0CoJ7[B0omKL<h3odaTbP?oBUW0
0ol`A[P01_l;:Z_o;CV/obdi[?l01i;o8bFKo`@2P0?o>R671?n9F947ojecTPKoeY^G0ooX/9P3olfM
Y@GoeZVY00?obj6/om6Y/?oAZK001?oAZK000ooG/K?odJjfom6^]P04om6^]P;oeKBi1?oA/[/4omFi
_P03om6g`OoD_L?oe;g300Coe;g300?oel?7om?1b?oC`LP00ooC`LP3omG6b`04om74cOl0003o0000
o`0000?odlS@00?odlcBom39doo@bM<00oo@bM<2om3;e@?oc/WE1Oo=bmL00oo<b=Ooc<[Holc:f003
olc:f003ol_:fOo:bMWob/WI00?ob/WI00?obLWJolW8f_o9b=X00oo9b=X3olS9fPKob<SJ2Oo7b=X4
olO8f`03o`000?o7b=_oalSK01_oalSK1_o6b=/4olK8g003olK8foo6b=coa/SL00?oa/SL00?o0000
ooooooooool09oooool002Sooooo0_l0000>ooooo`CoVKW^0_nI]^`3oiFek@GoUK;[0onE/>T5oiB]
j0CoTj[V0_nAYn@2ohfViPCoRj?U1?n9X><4ohJLhPCoPYSP1?mmTmh4ogR>g0?oLHSK0omXPMP01?ma
P]CoJ7[BofQjd_mXN]83oe]`cP?oC6C:0_leDl@01?m:FL3o<4Jhoc16^?l`A[P2o`/ZZ`04obdi[?l0
1i;o00NBo`@2P0?o>R671?n9F947ojecTPGoeY^G1OoX/9P00oo=WJGoeZVYomJYZ@04omJYZ@KodJV`
0_oG/K<5om6^]P?oeKBi0ooA/[/5omFi_PKoe;g30ooG`lL3om?1b0;oeLK;0ol00005om?8d0?odlcB
0oo@bM<4om3;e@03olk9eOo=bmOocL_G00CocL_G1Oo<b]P3ol_:f@?ob/WI0oo9bMX3olW8fPGob<WJ
1_o8b=X6olO8fPOoalSK00?o0000olO8foo7b=/06Oo7b=/6olK8f`Coa/SL00?oa/WLolK8g?o6b=`0
1?o6b=`2o`0002Sooooo000Xooooo`03o`000?oooooooooo00kooooo0_nI^Nh2oiFgk`GoUKG]1OnE
/^/3oiF`j@;oU:gX0on@[>T4ohnYj0CoSJKV1?n;XnD4ohVPh`CoQYcR1?n2V>04ogfCgPCoN8kL0oma
R=/3ofR1f0?oGGSF00CoJ7[Boe]`c_mKL<koFg3>0om<I<X2ocECa004odYI`?l`A[So<4Jhoc16^0;o
2bZ[00?o;CV/o`07T_l40X000olj8HL4ohUHT@Oo[G>B1OoFViL5onR`V003olfMYOoFZJWoeZVY00Co
eZVY00?of:f]om6Y/?oAZK000ooAZK03omNa/`?odJjf1OoE];T00ooA/[_oeKVnomFi_P04omFi_P03
omRo`OoD_L?oe;g300;oe;g31OoG`lL01?oC`LSo0000o`000?l00002omG6b`;oel_?0ooCb=05om?<
dP03om39doo@bmGod<_E00?od<_E00?oclgGolg;eoo=bmL00oo=bmL2olg<f0?oc<[H1Oo;b]T00oo:
bMWobLWJolW9fP03olW9fP03olW8f_o8bM[ob<WJ00Cob<WJ1Oo8b=X00oo7b=_oalSJolO8fP03olO8
fPSoalSK00?o0000olO8foo7b=/05oo7b=/00oo7bM_oa/SKolK8f`03olK8f`;oa/WL0oo6b=`3olK9
g0Koa/SL00?oooooo`000?ooool09_ooool002Oooooo00?o0000ooooooooool04?ooool4oiFgk`Go
UKG]0_nE/^/2oi6ak@CoT:o[1On@[>T4ohnYj0?oSJKV1On;XnD4ohVPh`CoQYcR1?n2V>04ogfCgP?o
N8kL0omaR=/4ofR1f0?oGGSF0_m=KM801?mKL<koC6C:odaTb_m<I<X3ocECa0?o<4Jh0ol;:Z/00ol0
1i;o000cocXQQ`02ocXQQ`CoRERA1_n]Li800ooAV9SoeY^GomJKU`03omJKU`Goj;2H1_oFZJT2omR]
[@CodJV`1?oG/K<3om6^]PGoeKBi1_oE^Kh3omRo`@?oe;g30ooG`lL3o`0000CoeLK;1?oGbll00ooC
b=3odlcBom?<dP03om?<dP03om?>eOo@bmGod<_E00?od<_E0oo?cML3olg;e`CocLcH00?oc<[Hol_:
fOo;b]T00oo;b]T00oo:bm[obLWJolW9fP03olW9fP;obL[J1oo8bMX3olS8fP?oalSK0oo7b=X:olO8
f`03o`000?o7b=_oalSK013oalSK00CoalWKolO8foo7b=_oalSK1?o7bM/3olK8f`Coa/WL00?oa/SL
olK9g?o6bM`00oo6bM`6olK8g003o`000?oooooooooo02Gooooo000Wooooo`03o`000?oooooooooo
017ooooo1?nE]nl2oiFek@?oTK?^1?nA/Nd4oi2_j`GoT:cY1?n?ZNP3ohfViP;oRj?U0_n6XnL4ohBO
i@CoP9cT1?mlV><4ogNCh@?oL8kP00?oN8kLog68fomaR=/01?mXPMP4oeeheP?oCFgB0om<I<X2ocEC
a0;o5Sfj00Ko<4Jho`/ZZol;:Z_o2bZ[o`07T_l003<3ocXQQ`CoRERA1_n]Li82om6HV0CoeY^G1OoX
/9P6omJYZ@?of:f]0ooAZK05omNa/`03om6^]_oE];WoeKBi00CoeKBi00?ofK^lomFi__oE^Kh00_oE
^Kh5omRo`@03omBm`ooG`lOo000000;o000000?oel?7omW9b_oIbLX00ooEa//5omO;c`GodlcB0ooC
c]D3om3;e@GoclgG00?ocL_Golg<f?o=c=P00_o=c=P00oo<c=[obl[Iol_:f@03ol_:f@?ob/_J0oo9
bMX4olW:fPOob<WJ00?ob<SJolO8foo7b=/00oo7b=/00oo7b=[oalSKolO8f`0:olO8f`03o`000?o7
b=_oalSK00goalSK1?o7bM/00oo7b=_oalWKolO9f`04olO9f`03olK8foo6bMcoa/WL00Woa/WL1_o6
b=`00ooooooo0000ooooo`0Uooooo`009oooool3o`0001;ooooo1OnA]_04oi6ckPCoTK7]1?n@[n/2
oi2/j@;oRj_[1?n:ZNT4ohRVj0CoQZ?W1?n4WnD4oh2Li0CoO9SS1?mgTn43og2>h0?oJ8SN0omXPMP4
oeeheP?oCFgB0_lkH<d01?m<I<[o=E?4ocECa?leDl@2oaHm^P05oc16^?l;:Z_o2bZ[o`00SOl01i80
0olj8HL5ohUHT@Go[G>B0_oAV9P3omJKU`Koj;2H00?olKjKomJYZOoFZJT00_oFZJT4omR][@;odJV`
1_oG/K<6omFd^@?ofK^l0ooE^Kh4omRo`@?o00000ooG`lL4omW9bP03omG6booGblooel_?00?oel_?
0_oGd=83om?<dPGodlkE00?od<_Eolo=eoo?cML00oo?cML2olo>f@?ocLcH0oo<c=X3ol_:f@Gob/_J
00?obLWJolW:f_o9b]X00oo9b]X6olS9fP03olS9foo7b=_oalSK01;oalSK00?o0000olO8foo7b=/0
2oo7b=/;olO9f`03olO9g?o6bMcoa/WL00_oa/WL1_o6b=`00ooooooo0000ooooo`0Tooooo`009ooo
ool00ol0003oooooooooo`0Cooooo`GoTKK`1?nA/nh2oi6ak@;oSK3^1?n<[^`4oh^[j`CoRZWY1?n8
Y^P4ohJSi`CoQ9oU1?n0W>@3ogbHh`CoMi?Q1?m`S^02ofR8gP?oGX3L00CoJ87Hoeehe_mMN=KoGGSF
1?m=KM83oc]Pc@;o=E?40olF?KX3o`/ZZ`04o`07T_lj8HOo>R67ocXQQ`GoRERA1?n]Li83om6HV0?o
eY^G1OoX/9P2oo6nV`?oeZVY1_oH[Jd00ooAZK3oek6comNa/`04omNa/`03omZg]_oE];WoeKBi00;o
eKBi1OoI^k`00ooE^Kkof;o1omRo`@03o`000003omRo`OoKa/Coel?700;oel?71OoIbLX5omO;c`Co
em3B00?odlcBom?>eOoCc]D00ooCc]D2om;@f0?oclgG1Oo?c]T00oo=c=Soc<cJolc<fP03olc<fP03
ol_:fOo:bm[ob/_J00?ob/_J00?obL_KolW:f_o9b]X00oo9b]X2olS9f`?ob<WJ1?o8bM/ColO8f`03
o`000?o7b=_oalSK00WoalSK2oo7bM/4olO9g0coa/WL1Oo6b=`00oo5b=coooooo`00000Uooooo`00
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool05?ooool2oi6fl0?oS;Ca0on=/^l5ohf`
kPCoS:k/1?n;Zn/4ohZYj@CoR:KX1?n6XnL4ohBOi@CoP9cT0omlV><3ogNCh@CoL8kP0omXR=h3oej0
g0?oDGOJ00CoGGSFode]d_m=KM;oCFgB0olkH<d2ob5>aP03ocECa?lF?K[o5Sfj00?o2bZ[00Co002=
ocXQQolj8HOo>R671On9F944ojecTP?odIRH0ooFViL5onR`V0;olKjK0ooFZJT6omR][@Koek6c0_oJ
]kH3omFd^@KofK^l00?of;o1o`000?l000000ooH_l43om_6a003omO3aooIbL[ofLW:00?ofLW:0_oK
clh3omO;c`Goem3B1OoCc]D4om;@f003olo=eoo?c]WoclkI00?oclkI00?ocLkJolc<f_o<c=X00oo<
c=X3ol_<f`?ob/_J0oo9bm/3olW:fPCob<WK00?ob<WJolS9foo8bM/01?o8bM/ColO8f`03o`000?o7
b=_oalSK00OoalSK2oo7bM/5olO9g0goa/WL0oo6b=`3olG8g003ooooool0003ooooo02?ooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo0_l0000Gooooo`CoS;Ca0on=/^l5ohf`kPCoS:k/
1?n;Zn/2ohZYj@;oQZS[1?n4YNX4oh:Rj@?oOioW1?mkW>H3ogJHi@?oL9?T00?oMi?Qog2>h?m`S^00
0_m`S^03ofR8gP?oGX3L0omAMmX2od1/eP03ode]d_lkH<go>f3=00;o>f3=0_lQC/H3oaHm^P;o2bZ[
00Co002=o`00D?lj8HOo>R671On9F944ojecTP?odIRH0ooFViL5onR`V0?olKjK00?oeZVYomR][OoH
[Jd01OoH[Jd00ooL][7oek6comNa/`02omNa/`Cof[Nf00?oeKBiomVk_?oI^k`00ooI^k`3o`0000Co
f;o11?oKa/@5omW9bPCoflo>00?oel_?omO@d_oGd=800ooGd=82omKCeP?odlkE1OoBd=P5olo>f@?o
cLkJ0oo<c=X5ol_<f`03ol[;f_o9bm_obL_K00?obL_K00?obL[JolS9foo8bM/02Oo8bM/2olO9fa?o
alSK00?o0000olO8foo7b=/01Oo7b=/:olO9f`SoalWL3Oo6bM`00oo6b=coaLSLolG8g003olG8g003
ooooool0003ooooo02;ooooo0004ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00;ooooo0_l0000Iooooo`CoS;Ca0on=/^l2ohf`kP?o
R:o_1?n8[Nh3ohN[k0GoQZS[1?n4YNX4oh:Rj@?oOioW1?mkW>H3ogJHi@CoL9?T0omYS^<3of28hP04
ofR8g_mNP=coGX3Loej0g0?oDGOJ0om0K=H3oc]Pc@?o8Dk60_lF?KX01?l08J[o2bZ[o`00SOl003<2
ocXQQ`GoRERA0on]Li84om6HV0;oeY^G1OoX/9P4oo6nV`03omJYZOoH[Jgof:f]00Cof:f]0_oL][43
omNa/`Gof[Nf0ooI^k`3o`000003omVk_?oL`[oog<:o00?of;o11OoKa/@01?oMcLSofLW:omW9b_oI
bLX5om_?cP;ofmCB0ooGd=84omKCeP03om?>eOoBd=Sod]3H00?od]3H0_o@dMX3olo>f@GocLkJ00?o
c<cJol_<foo;c=/00oo;c=/00oo:c=_obL_KolW;f`05olW;f`[ob<WK1?o7bM/ColO8f`03o`000?o7
b=_oalSK00;oalSK2oo7bM/:olO9g0_oa/WL00?oaLWMolG8g?o5b=`00oo5b=`00oo5b=goooooo`00
000Sooooo`001?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01Wooooo1?n8/o84ohRal0CoR:o_1?n8
[Nh3ohN[k0GoQZS[1?n4YNX4oh:Rj@?oOioW0omkW>H4ogJHi@CoL9?T0omYS^<3of28hP?oEH3O00Co
GX3Loe5gf_mAMm[oDGOJ0_m0K=H2ob]Md004oc]PcOlQC/Ko8Dk6ob5>aP;o03Jj00Co5Sfjo`0QZ_l;
:Z_o002=0_lj8HL5ohUHT@?o[G>B1?oAV9P2omJKU`Goj;2H1?oa_Y/7omR][@;og;Ja0ooG/K<5omZg
]P?o00000ooI^k`4omc2_`03omRo`OoKa/CoflK400?oflK40ooMcLP00ooIbL[oflo>om_?cP04om_?
cP?ofmCB00?oem3BomKCe_oFdmH00ooFdmH2omCDf0?od]3H1?o@dMX00oo?c]WocLkJolg>fP03olg>
fP03olc>foo;c=_oblcK00?oblcK0oo:c=/7olW;f`Sob<WK1Oo7bM/ColO8f`04o`000?o7b=_oalSK
olO8f`_oalWK2_o7bM`00oo7b]coa/WLolK9g003olK9g0;oa/WM0oo6bM`3olG9g@?oaLSL0oo5b=d0
0ooooooo0000ooooo`0Qooooo`001?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool06_oo
ool4ohRclPCoR;7`1?n8[nl4ohR]kP?oQj_/0_n6Z>/2oh:Wk0CoP:G[1?mmX^X3ogZOj@?oMYcX00?o
NicVogJHiOmfV>D00_mfV>D4og2Ci0?oJHkS0omPR>83oeF0g`;oAWOM00CoDGOJod1/e_m0K=Ko@6cF
0ol[GM03ob5>aP;o03Jj0_l08JX00ol008go001@ocXQQ`05ohUHT@?o[G>B1OoAV9P00ooFViOoj;2H
onR`V003onR`V0ColKjK00?oj;VSomR][OoH[Jd00ooH[Jd4ombf/@04omNa/ooJ]kKof[NfomZg]P?o
00000_oM_KT3omVk_0Gog<:o00?oglW2om_6a?oKa/@00_oKa/@4omg=b003on3EcOoKclkoflo>00?o
flo>1?oKe=85omKCePCoe=CH00?od]3Hom3Af_o@dMX00oo@dMX2oloAf`?ocLkJ0oo<c]/3ol_<f`Go
b/cK1_o9bm/6olS9f`KoalWK5Oo7b=/00ol0003oalSKolO9f`09olO9f`_oalWL0oo7b]`3olK9g0Co
a/WM00?oa/WLolG9gOo5bMd00oo5bMd00oo5b=coaLSMolG8g@03olG8g@03ooooool0003ooooo023o
oooo0004ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Kooooo0_l0000Looooo`CoR;?b0_n8/O02ohF`l@CoQ:k`0on4[>l4oh>YkPCo
PZO/1?n0YN/4ogfRjP?oNYoY1?mfW>P4og6Hj0?oJi?W0omSS^H01?mYS^?oH8SRof28h_mPR>83oeF0
g`?oAWOM0om0K=H2ob]Md0;o3d_800So8Dk6o`0f^_l0=[[o03Jjo`0QZ_l008go001@ocXQQ`GoRERA
0_n]Li86om6HV003omJKUooX/9Soj;2H00;oj;2H1?oa_Y/2onRiX`Cof:f]1OoL][401?oJ]kKo0000
o`000?l00002omZg]P?ogKfi0ooI^k`5omc2_`;oglW20ooKa/@4omg=b0;oh=G=0ooKclh4om_DdP;o
fMSF0ooFdmH4omCDf003om;Efoo@dM[od=7J00?od=7J1?o?dM/00oo=c][oc<kKolc>f`03olc>f`03
ol_<foo:c=_ob/cK00?ob/cK00?obLcLolW;foo9bm/00oo9bm/2olS:f`?ob<WK1oo7bM/GolO8f`03
o`000?o7bM_oalWK00OoalWK2oo7bM`5olO:g003olK9g?o6bMgoa/WM00;oa/WM00?oa/[MolG9gOo5
bMd01Oo5bMd4olG8g@03olC8gOoooooo0000027ooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Looooo`CoQ;7b1?n5/?44ohB^l0?oQ:c_1?n3ZNh4oh:Wk0?oP:G[1?mmX^X4ogZO
j@CoMYcX1?maV>P3of^Ci`?oHhkV0omIR>@01?mPR>;oEH3OoeF0gomEP=l2odIgg@?o<f_I00?o@6cF
ob]Md?l[GM000_l?BlP3o`0f^P;o026Z00?o001@ocXQQolj8HL01?n9F942ojecTPKodIRH1OoX/9P4
oo6nV`?oj;VS0ooH[Jd3ombf/@?o00001?oJ]kH5omfm^@03omVk_?oL`[oog<:o00?og<:o1?oObL80
0ooKa/CogLg8omg=b002omg=b0Coh=G=00?oflo>om_Dd_oKe=800_oKe=84omWHeP03omKCe_oDe=So
e=CH00;oe=CH0ooBeM/3om3AfPCocm7K00?ocM7Lolc>foo<c]/00oo<c]/2ol_>g0?ob/cK1?o9c=`3
olW;f`Cob<[K00?ob<WKolO9foo7bM/01Oo7bM/IolO8f`03o`000?o7bM_oalWK00GoalWK2_o7bM`6
olO:g0;oa/[M0oo6bMd3olK:g@OoaLWM00?oaLSMolC8gOo4b=d00_o4b=d00ooooooo0000ooooo`0O
ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`Co00001Oooool00ol0003oooooooooo`0Mooooo`CoQ;7b1?n5/?44ohB^l0?oQ:c_1?n3
ZNh4oh:Wk0?oP:G[1?mmX^X4ogZOj@CoMYcX1?maV>P2of^Ci`CoHhkV0omIR>@3odf0h`03oeF0gom6
MmgoAWOM00?o<f_I0_lKFm800ol[GM3o3d_8o`m;b003o`0f^P04o`0QZ_l0053o>R67ocXQQ`CoRERA
0_n]Li86om6HV0Goj;2H1?oa_Y/3onRiX`;of:f]00Gog;Jao`000?l0003o0000ombf/@03omjk]0?o
f[Nf1OoM_KT5omc2_`GoglW21?oMcLP5on3Ec@04on3KdOoKe=;ofmCBom_DdPGofMSF00CoemWIomCD
f?oDe=Soe=CH1OoBeM/00oo@dM[ocm7KoloAf`02oloAf`?ocM7L0oo<c]/4ol_>g003ol[<foo9c=co
bLcL00CobLcL00?obL_KolS:foo8b]/00_o8b]/9olO9faWoalSK00?o0000olO9foo7bM/01?o7bM/5
olO9g0;oal[L0oo7bM`6olO:g0Coa/[M00?oa/WMolK:gOo6b]d00oo6b]d5olG9g@03olG9g_o4b=go
a<SM00;oa<SM00Coa<SNo`000?oooooo00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`00_ooool002Kooooo00?o0000ooooooooool0
7_ooool2ohBalP;oP;3c1?n1[_83oh6]l@CoP:_`1?moZNl3ogjWkPCoO:C]1?miX^`4ogJOj`?oLYc[
1?m]V>X3ofJDj@?oHhkV1?mIR>@3odf0h`;o?GOP1?lcJmT2oa]KdP;o3d_800Co03:io`0f^_l0=[[o
01RW0_l005000olj8HOoRERAohUHT@02ohUHT@03ojecT_oAV9SodIRH00GodIRH00?okk^KonR`V?oX
/9P00_oX/9P3oo6nV`Goj;VS0_l00004ombf/@?og[^d0_oJ]kH6omfm^@04on74_?oL`[oog<:oomc2
_`KoglW200Coh]36omg=b?oMcLSogLg81?oPeLd3on3Kd@03om_Dd_oIf=KofMSF00?ofMSF0ooGfMT0
0ooDe=Sod]GKom;Ef`03om;Ef`;od=GM0oo?dM/5olgAg003olc>foo;c]coblkL00;oblkL0_o9cMd5
olW<g0;ob<_L0oo8b]/;olO9faKoalSK0oo7bM/00ol0003oalWKolO9f`04olO9f`?oalWL1?o7b]`0
0oo7bMcoal[LolO:g004olO:g0Coa/[M00?oa/_MolK:gOo6b]d00oo6b]d01?o6b]koaLWMolG9gOo5
bMd4olG9gP;oa<SM0oo4b=h00ooooooo0000ooooo`07ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@02ooooo`009Oooool3o`00023ooooo
1?n0/?<4oh6^lP?oPJga1?n0Zo04ognYk`?oOZO^1?mlY>d4ogVRk0CoMYo[0ombW>/4offHjP?oIYCY
0_mNSnP01?mSS^KoFHSToeV8i?mIR>@4odf0h`;o?GOP0olcJmT3oa]KdP;o3d_800Ko03:io`0f^_l0
6:Oo01RWo`00D?lj8HL4ohUHT@03ojecT_oAV9SodIRH00GodIRH00Cokk^KonR`V?oX/9Soj;2H1?oa
_Y/2onRiX`?o00001OoL][45omjk]003omZg]_oM_KWogKfi00?ogKfi0ooQa;`00ooL`[ooglW2omo9
`P04omo9`P?oh]3600?ogLg8on3EcOoPeLd00_oPeLd4on3Kd@;ogMoF0ooIf=H4omOIf@;oe=[L0ooB
eM/4om3Eg@03oloAfoo=dMcocM7L00?ocM7L0_o;d=d3ol_>g0CobLgM0oo9c=`4olS;g003olS:foo7
bM_oalWK00WoalWK5_o7b=/5olO9f`03o`000?o7bM_oalWK00CoalWK00?oalWLolO:g?o7b]`02?o7
b]`2olO;g@?oa/[M0oo6bmd2olK:g@Coa/[N00?oaLWMolG9g_o5bMh00oo5bMh00oo4b=goa<SNolC8
gP03olC8gP03ooooool0003ooooo00Kooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`00
0?ooooooooooooooool000000_ooool002Gooooo00?o0000ooooooooool08Oooool4oh2`l`CoPJkb
0on1[O44oh2[l0CoOjW_0omnYnh4ogbTk@CoNJ;/1?mfWn/3og:Lj`?oKISZ1?mVU>T3oej?j0;oDhWW
00CoFHSTodf0hom=P>?oCH3S0olmMn000olXJm_o<f_Ioa]KdP02oa]KdP;o04S800Ko3d_8o`0b^Ol0
=[[o01RWo`00D?lj8HL4ohUHT@03ojecT_oAV9SodIRH00CodIRH0oo_^i/2onR`V0?olKjK0ol00003
onRiX`03onVmY_oL][7og;Ja00;og;Ja1OoN^k@5omfm^@CohLBl00?oi<^oomo9`_oObL800ooObL84
on;@aP04onGKbooPeLgoh=G=on3Ec@Goh=_A0ooMgmH00ooIf=KoemWIomOIf@02omOIf@Coe=[L00?o
d]GKom3EgOo@eMd00_o@eMd3olkDgP?ocM7L1?o;d=d00oo;c]cobLgMolW=g@04olW=g@03olW<g?o8
bmcob<_L00;ob<_L00?oal[LolO9foo7bM/02?o7bM/GolO8f`KoalWK00?o0000olO9foo7bM/00oo7
bM/;olO:g0Coal_M00?oa/[MolK;gOo6bmd00_o6bmd00oo6b]goa/[NolK:gP02olK:gP03olG;g_o5
bMkoaLWN00?oaLWN0_o4bMh4olC8gP;o`lSN00?oooooo`000?ooool01Oooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P02ooooo`009Oooool00ol0003ooooo
ooooo`0Rooooo`CoOJkc0omm[O84ogf/l@GoOJ[`0omlZ?03ogZVk`CoN:C^0omfX^d4og:Ok@CoKYc/
0_mXVN`00om]V>[oIYCYofJDj@02ofJDj@?oGXoX0omCRNL2odJ2i@04odf0holmMn3o?GOPocegh0;o
:6_K0olKFm82o`18b0;o03:i00?o01RWo`00D?l005000on9F9400onBKJGodIRHom6HV005om6HV0?o
kk^K0_oX/9P3o`0000Goj;VS0ooY_JH3ombf/@Gog[^d00CohL2gomfm^OoM_KWogKfi1OoQa;`2onC;
_`?oglW21?oRd<H3onGKb`03on3EcOoPfm7oh=_A00?oh=_A0ooMgmH2om[Pf`?oemWI1?oDf]`2om7I
gP?od=GM1Oo>e=h00oo=dMcobm3Mol_@g@03ol_@g@KobLgM0_o8c=d3olS;g0?oal[L2?o7bM/AolO8
f`03olO8f_o7b=_oalSK00?oalSK1Oo7bM/3olS9f`03o`000?o7bM_oalWK00coal[L1Oo7bmd4olK;
g@;oa/_N0oo6b]h3olG;gP?oaLWN1?o4bMh00oo4b=ko`lSNol?8gP03ol?8gP03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`00_oo
ool002Gooooo0_l0000Tooooo`CoOJkc0omm[O84ogf/l@GoOJ[`0omlZ?03ogZVk`CoN:C^0omfX^d4
og:Ok@CoKYc/0omXVN`3of:Ej`?oFY3[00CoGXoXoe>9iomCRNOoDhWW0om6P^D2ocEhh`05ocegh?lX
Jm_o:6_Ko`iJdolKFm800ol0B<P01Ol0<[Wo01FTo`00D?l0053oRERA00?oTVfU1ooAV9P2onnkV`?o
00000ooa_Y/5onRiX`?ojKfV0_oL][45omjk]0;ohL2g0ooM_KT4on74_0Coi<^o00?oglW2on;@a_oR
d<H00_oRd<H4onGKb`;oiN?A0ooPfm43omgOePCof^3K00?oemWIomCJg?oDf]`00_oDf]`4om7IgP03
om3EgOo>e=koc]CN00?oc]CN00?obm;Ool_@gOo;d=d00oo;d=d2olW>gP?obLgM1Oo8c=d00oo8bmco
al[LolO:g003olO:g0GoalWK3Oo7b=/2olO8fP?oalSK0oo7b=X3olO8f`GoalWK1Oo8bM/00ol0003o
al[LolO:g003olO:g003olS;g?o7b]coal[L00?oal[L2?o7bmd00oo6bmgoa/_NolK;gP03olK;gP03
olK:g_o5bmkoaL_N00?oaL_N00?oaLWNolC9g_o4bMh00_o4bMh00oo3b]oo`lSNol?8gP03ol?8gP03
ol;8gooooooo000000Gooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooo
okZj^_l@41000_ooool002Gooooo00?o0000ooooooooool09?ooool4ogf^l`?oOJgb1?mm[?42ogfZ
l0;oNZWa1?miZ?02ogNVl003ogZVkomhY>koN:C^00;oN:C^0omfX^d4og:Ok@CoKYc/0omXVN`3of:E
j`CoFY3[0_m?RnT01?mCRNOoAX;UodJ2iOm6P^D2ocEhh`;o7fcM00?o:6_Ko`iJdol>F]<00_l0B<P2
o`0_]`;o001@1OnBKJD5om6HV0?o00000_o_^i/4oo6nV`Goj;VS1?oY_JH00ooL][7og[^domjk]002
omjk]0CohL2g00?ogKfion74_?oQa;`00ooQa;`4onC;_`04onOD`ooRd<Koh]36on;@aPGoiM_;0ooU
hm401?oPfm7ogMoFomgOe_oMgmH5om[Pf`04omKPg_oDf]coe=[LomCJg0GodMWN1Oo>e=h3ol_Bg`?o
bm3M1?o9c]h00oo9cMgob<cMolS<g@03olS<g@03olO;g?o7b]coal[L00?oal[L0_o7bM`3olO9f`go
alSK1?o7b=X00oo7b=_oalSJolO8fP03olO8fP03olO8foo7bM_oalWK00;oalWK1_o8bM/2olS:f`03
o`000?o7b]coal[L00Cob<_L00?oal[LolO;gOo7bmd02?o7bmd00oo7c=koa/_NolK;gP03olK;gP;o
a/cN1?o5bmh2olG;g`?oa<WN0oo3b]l3ol?8gP?o`/SO0_l00004ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000;ooooo000Uooooo`03o`000?oooooooooo
02Kooooo0omj[O<4ogZ/l`CoNZ_b0omjZO44ogVXl0CoMjK`0_meY>l4og:Rk`CoKio^1?m[WNh2ofFJ
kP04ofRIk?mRUN_oHYG[of:Ej`CoFY3[0_m?RnT3od64j003odJ2iOleN>?o=GSS00?o7fcM00Co3U[C
o`16aol0A/Oo04S80_l0;kL00ol0053oTVfUoi9]Y@03oi9]Y@;odIRH0ol00005onnkV`03oo_DW?oa
_Y_olKjK00Goj;VS1OoY_JH5omjk]0CohL2g00?oi<Jjon74_?oQa;`00_oQa;`5onC;_`;oimC300?o
h]36onGKbooUfl/00ooUfl/3onGSd@?oh^SG00?ogMoFom[PfooJh=/00ooJh=/3omKPgP03omCJg?oA
fMkodMWN00?odMWN0_o>en03olkDgPGobm;O00?obm3MolW>g_o9c]h00_o9c]h2olS=gP?ob<cM1?o7
bm`3olO:g0CoalWL00?oalWKolO8foo7b=/02oo7b=/<olO8fP?oalWK1_o8bM/3olS:f`03o`000?o7
b]cob<_L00Cob<_L1Oo7bmd2olO<g@?oal_M0oo7c=h3olK;gPCoa/cN00?oaL_NolG;goo5bml00oo5
bml00oo4bMko`l[Ool?:g`03ol?:g`03ol?8g_o2b=oo`/SO00;o`/SO00?oooooo`000?ooool00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@02ooooo`00
9?ooool3o`0002Sooooo0omj[O<4ogZ/l`CoNZ_b0omjZO44ogVXl0CoMjK`0_meY>l4og:Rk`CoKio^
1?m[WNh2ofFJkP?oGiK]00?oHYG[oeZ@jomJT>/00_mJT>/2odn;j@?o@HCX0_l`NnD00oleN>?o7fcM
oam/g@02o`=Ke0;o04K70_l0;kL00ol0053oTVfUoi9]Y@02oi9]Y@?o00000ooAV9P4onnkV`;onmBL
0_oa_Y/5onRiX`GojKfV00CojKnYomjk]?oN^kCog[^d1OoQ`;L2onC6^P;ohLBl1OoTbkl3onOD``;o
jn?80ooUfl/3onGSd@Coh^SG0_oMj=`3om[Pf`?oe^3N0ooBg^43om7IgPCoc]OP00?oc]CNol_Bgoo;
d]l00oo;d]l2olW@g`?obLkN1?o8cMh00oo8c=goal_LolO;g004olO;g003olO:g?o7bMcoalWL00;o
alWL00?oa/SKolO8foo7b=/01?o7b=/00oo6am_oalSKolO8f`03olO8f`;oalOJ3Oo7b=X00oo7bM_o
b<WKolS9f`04olS9f`Cob<[K00?ob<_Lo`000?o8bm`01Oo8bm`3olO;g@CoalcM00?oal_MolO<g_o7
c=h00oo7c=h00oo6bmkoa/cNolK<gP02olK<gP03olG<goo5bmooaL_O00?oaL_O00?oa<_Pol?:goo3
b]l00oo3b]l00oo2b^3o`/SOol;8g`02ol;8g`;o`LSP00?oooooo`000?ooool06Oooool002Cooooo
00?o0000ooooooooool0:?ooool4ogN/m0CoMj_c0omgZ_84ogNXlPCoMZOa0omdY_43og:Tl0CoLZ;_
1?m_Wnh4of^MkP;oII[^0omOU^d4oeNBk@?oC8g/0om1Q>P3oc1ki@;o7fcM0_l3Fm@2o`16a`04o`0_
]ol0053o001@oi9]Y@;o000000?oTVfUom6HV?oAV9P00ooAV9P4onnkV`?onmBL00?olKjKonRiXooX
^J<00_oX^J<5onVmYP;ojKnY0ooN^k@4on70]`Coi<Jj00?ohLBlonC;_ooTbkl00_oTbkl4onOD``?o
jn?800CoiM_;onGSdOoUhm7oiN?A1?oRj=L4omgXg004om[PfooFh=koe^3NomKPgPGod]kQ00?odMWN
olkGh?o>en000_o>en02olcEh@?obm;O1Oo9d=l00oo9c]kob<gNolS=gP02olS=gP;oal_M1Oo7bm`2
olK9g0?oalWL0oo6b=/3olO8f`Coa/OK0oo7b=/4olO7fP_oalSJ00?ob<WJolS9foo8bM/01Oo8bM/3
olS:f`?ob<_L00?o0000olS;g?o8bm`01?o8bm`00oo7bmgoalcMolO<g@02olO<g@03olO=g_o7c=ko
alcN00?oalcN0_o6cMl3olK<gP?oaLcO0oo5bml3olC;h0;o`l[O1?o2b^000oo2b=oo`LSPol78h003
ol78h003ooooool0003ooooo01Sooooo000Tooooo`03o`000?oooooooooo02Wooooo1?mg[?@4ogN[
l`?oMj[b1?mgZ?84ogJWl@?oM:Ka1?mbY?03og2Rl0?oK:3_1?mXWNl3of>Kk`?oGiK]1?mGT^d3odb=
k0;o?XOZ00?o@HCXoc1kiOl`NnD00_lIK]l00olOK=go0e_Do`=Ke002o`16a`?o00000onBKJD4om6H
V0Gokk^K0ooke9`5onRiX`GojKfV0ooY_jT00ooN^kCohL2gon70]`03on70]`Coi<Jj1?oTbkl4onOD
``Cojn?80_oZk/h00ooUhm7oh^SGon;Xe`02on;Xe`CogNSL0ooHj>400ooFh=kod]kQom;Nh@03om;N
h@;oc]cS0oo>en04olcEh@03ol_Bgoo9d=oobM3O00?obM3O0_o7c]l3olS=gPCoal_M0oo7bm`4olK9
g003olO9g?o6b=_oa/SK00?oa/SK00?oalSKolK7foo6am/01?o6am/00oo7b=_oalOJolO7fP03olO7
fP[oalSJ0oo8bMX7olS9f`03olS:foo8bmcob<_L00?ob<_L00?o0000olS;g?o8bm`00_o8bm`2olS<
g@?oalcM0oo7cMh3olO<gPCoa/gO00?oa/cNolG<goo5c=l00oo5c=l00oo5bmooa<_PolC;h002olC;
h003ol?:goo2b^3o`/[P00;o`/[P00?o`L[Qol78h?o1b>000oo1b>000onob>7oooooo`00000Ioooo
o`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Zooooo`CoMjcd1?mgZo<3ogNZlPCoMjSb1?mfYo43
ogBVl@CoLZC`0om`X_03ofbPk`CoJ9g_0omSVnl2oefHk`03oenFkOmGT^goEi;]00;oEi;]0om<SN`3
ocj7jP03obeniol`NnGo6FkO00;o6FkO0ol000000ol0A/Oo001@oi9]Y@04oi9]Y@?odIRH1?o_^i/4
oo_DW004on_2ZOoX^J?oj;VSonRiX`GojKfV1?oY_jT00ooZ`ZcohL2gon70]`02on70]`Goi<Jj00Co
i/blonC;_ooTbkooi<^o1?oWe<<4on_Sb0;oj^k>0ooUl]D00ooRj=OogNSLomgXg002omgXg0Cof>SQ
00Cod^CTom;NhOoBg^7od]kQ1Oo>g><00oo>en3oc=GQolcEh@02olcEh@?obM;Q0oo9d=l4olO>g`03
olS=g_o7bmgoal_M00Coal_M00?oal_LolK9g?o6bM`00_o6bM`00oo6b=coa/SKolK8f`03olK8f`Oo
a/OK0_o6amX6olO7fPSoalSJ1Oo8bMX5olS9f`03olS:foo8bmcob<_L00Cob<_L00Co0000olS;g?o8
bmcob<_L1?o8c=d00oo7c=goalgNolO=gP03olO=gP03olO<g_o6cMooa/gO00;oa/gO00?oa/kPolG<
goo5c=l00oo5c=l00oo5cN7oa<_PolC;h002olC;h0;o`lcQ0oo2b^03ol7:h@?o`LSP0onob>400ooo
oooo0000ooooo`0Gooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo0_l0000]ooooo`CoM:_d0omeZ_<4ogFYl`;oM:Sb1?mcYo84og:U
l@?oL:Ca0om]X_401?m`X_3oK:3_ofbPkom/X>l4ofRMk`?oHi__1?mMV>l3oeFDkP;oBi3^00GoC8g/
ocj7j_lnQn[o?XOZobeni`03o`0000;o05kE00?o0e_Do`15aOl005001OnBKJD3om6HV0Cokk^K0ook
e9`3on_2Z@;oj;VS1OoY_JH4onVoZ@;oj/:/0_oQ`;L5onC6^P?oi/bl00?oi<^oonOD`ooWe<<00_oW
e<<4on_Sb0?oj^k>0ooUl]D01?oMl]gogNSLomgXg?oMj=`4omSXh@?od^CT00?od]kQolkLhoo>g><0
0oo>g><2ol_Hi0?oc=GQ1Oo9d^400oo9d=ooalkOolO>g`02olO>g`03olK<goo7bmgoal_M00Coal_M
0_o6bMd3olK9g0?oa/SL0oo6b=/6olK7f`Goa/OJ1_o7amX5olO8fP03olS8f_o8bM[ob<WJ00?ob<WJ
1Oo8bM/3olS:f`Kob<_L00?o0000olS;g?o8c=d00oo8c=d00oo8cMkoalgNolO=gP03olO=gP;oalkO
0oo6cMl3olK>h0;oaLcO1?o5cN400oo4bn3o`lcQol?<h@03ol?<h@03ol;:h?o1b^7o`L[Q00?o`L[Q
00?o`LSPoko8hOnob>400onob>42o`0001Oooooo0009ooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02gooooo1?mdZo@3ogFZl`CoMJWc
0_mdZ?84og>WlPCoLZGa0om`Y?44offRl@?oJZ3`1?mVW_02of:Ll003of>KkomMV>ooGIS_00;oGIS_
0omEU>h3od^@kP?o00000_l]O^L00olFL^7o6FkOo`1Ne@02o`1Ne@03o`00D?nBKJGoTVfU00?oTVfU
0ooAV9P4onnkV`?onmBL1?o[`ZT00ooX^J?ojKfVonVmYP02onVmYPCojKnY1?oZ`Z`00ooQ`;Ooi<Jj
onC6^P02onC6^PCoi/bl0_o[e[h2onOD``Cojn?80ooZk/h3onGbe@?ogO;M00?ogNSLomSXhOoHj>40
0_oHj>43om;Ti0?ocN3V0oo>g><4ol_Hi003olcEhOo9d^7obM;Q00?obM;Q0_o7d>43olO>g`?oa/cO
0oo7bmd5olK9g@03olK9g?o6b=coa/SL00?oa/SL00?oa/SKolK7foo6am/01?o6am/5olK7fP03olO6
f_o7am[oalOJ00GoalOJ0oo7b=X3olS8fP?ob<WJ1Oo8bM/5olS:f`Gob<_L00?obLgMo`000?o8c=d0
0_o8c=d3olS=gP?oalgN1?o7c]l00oo6cMooa/kPolK>h002olK>h003olG<goo5cN7oaLgQ00;oaLgQ
0_o4c^84ol?<h@;o`/cR1?o1b^42ol3:hPCo_lSQ00?o_/ORooooool000005oooool000Wooooo00Go
0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
;_ooool3og>Zm0CoLjWc0omcZ?<3og:Wl`CoLjOb1?mbYO43og2Tl@CoKJ;a0omZX?04ofJNl0?oHYc`
0omLV_03oeFGl0?o000000?oBi3^ocj;kOlnRnd00_l^Q>X00ol]O^Oo5W;QoaIbh@03o`1Ne@GoTVfU
0_oAV9P4onnkV`?onmBL1Oo[`ZT5onVmYPCojKnY1?oZ`Z`4onC6^PGoi/bl0oo[e[h01?oWe<?ojn?8
on_Sb?o[hlP3on[^cP?oiO;E0ooMl]d4omO`h`04omSXhOoBi>Cod^CTom;Ti0GocN3V00?oc]cSol_H
i?o;f>@00_o;f>@2olSEi0?obM;Q1Oo7d>400oo7c]ooa/cOolK<g`03olK<g`03olO;gOo6bMgoa/WM
00?oa/WM00?oaLSLolK8g?o6b=`00oo6b=`00oo5am_oa/OKolK7f`03olK7f`;oa/KJ0oo6amX4olO6
fPOoalOJ00?oalSJolS8f_o8b=X00oo8b=X00oo8bM[ob<WKolS9f`02olS9f`03olW:foo8b]_ob<[K
00?ob<[K0_o9bm`3olS;g0;obLgM00?o0000olW=gOo8c=d01Oo8cMh00oo7cMkoalkOolO>g`02olO>
g`03olO?h?o6c^3oa/kP00;oa/kP0_o6cn43olG=h@Coa<kR00?o`lcQol;<h_o2c>800oo2c>800oo1
b^7o`<[Rol3:hP03ol3:hP03oko8hOnnan;o_/OR00;o_/OR00?oooooo`000?ooool05Oooool000Wo
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool0
0ol0003oooooooooo`0`ooooo`?oLj[d1?mcZO<3og>Xl`CoLZOc1?maY_82og2UlPCoKZCb1?m/Xo42
ofVQl@03ofZPl?mVW_3oIYk`00;oIYk`0omRW?02oebJl0?o000000GoEIO`odbCl?m<To3oC9?`od^@
kP02ocj;k@?o;XCZ0olFL^400ol0HmOoTVfUoi9]Y@03oi9]Y@;odIRH1?o_^i/3oo_DW0Gojl:Y00?o
j/B^onVmY_oY_JH00_oY_JH3onVoZ@Goj/:/00CojlB^onC6^_oTa[[oi<Jj1?oVc;`4on_F_P;ol^_0
00Cojn?8on[^c_oZk/koj^k>0ooUl]D3omgbg@Coeo3S0ooAjnL00ooBi>CocN3VolgPiP03olgPiP;o
bMcW0oo;f>@4olSEi003olWBhOo7d>7oam3Q00?oam3Q00?oaLgPolK<goo6c=l00oo6c=l2olG:gP?o
a/WM1?o5b=`3olK8g0?oaLOK0oo6am/4olK6fP03olK7f_o7a][oalKJ00CoalKJ1Oo7amX00oo8amWo
b<SJolS8fP03olS8fP;ob<WJ0oo8bM/3olW:f`?ob<[K1?o9bm`00oo8bmcobLgMolW=g@02olW=g@03
o`000?o8cMkob<gN00?ob<gN0_o8cml3olO>g`?oaloP00?oa/kPolK?hOo6cn400oo6cn400oo5cN7o
a<kRolC>hP02olC>hP03ol?>hoo2c>;o`/cR00?o`/cR00?o`LgSol3:h_o0b^800oo0b^800onnb^?o
_/ORokk7hP02okk7hP03okc7hooooooo000001Kooooo0009ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`06ooooo`?o0000<Oooool3og>Zm0CoLjWc0omcZ?<4og:Wl`Co
LJKb0_m`YO84ofjTlPCoK:?a1?mYXO42ofFOl@;oHIga0ol00002oebJl0?oEIO`0om<To03od6?k`?o
;XCZ0_lHN^D00olFL^7o001@oi9]Y@04oi9]Y@04om6HV?o_^i_okk^KonnkV`?onmBL1Oo[`ZT3on[4
[P;ojKfV1?oY_jT4on[2[0?ojlB^00?oi<JjonK<_?oVc;`00ooVc;`4on_F_P;ol^_00oo/nL82on3n
c004onGbeOoMl]gogO;Momgbg@?oeo3S1?oAjnL2ol_VjP?ocN3V1Oo9g>L00oo;f>Cob=GTolSEi002
olSEi0?oaM7S0oo7d>43olG=h0?oa/cO1?o5b]h00oo6bMgoaLSLolG8g004olG8g003olK8g?o5am_o
aLOK00?oaLOK00?oa/OKolK6f_o6a]X00_o6a]X00oo6a]WoalKJolO6fP04olO6fP;oalKI0oo7amX3
olS7f@?ob<SJ1?o8bMX00oo8bM_obL[KolW:f`03olW:f`03olS:foo9bmcobL_L00;obL_L0_o9cM`3
olW=g@;obLkM00Co0000olS=g_o8cMkob<gN1?o8cml01?o7c]ooaloPolO?h?o7cn02olO@h@Coa/oQ
0_o5d>83olC>hP?o`lkS0oo2c>83ol7=h`03ol3:h_nnb^?o_/[S00?o_/[S00?o_/ORokc7honlan<0
0_nlan<00ooooooo0000ooooo`0Dooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0booooo`OoLJWd1?maZ?<3og2Wl`?oKjKc
0om^YO84ofjTlPCoK:?a1?mYXO400omUWo7o0000o`000003of6Ml@?oG9ca0_mFVO401?mEUo3oC9?`
odbCl?m<To03od6?k`;o<X[]00Co;XCZoaQjiOlHN^Go67[U1OnBKJD4onnkV`?onmBL1Oo[`ZT4on[4
[P04onVmY_oY_jWojKnYonVoZ@Goj/:/0oo[a:h00ooZa:koi/blonK<_002onK<_0CojmJn0oobjl03
onci`P;oh?k<0_oHnmd3om3hiP03omO`hooAjnOodN_W00;odN_W1?o;i^X00oo=h>KobMcWolWLi`03
olWLi`;oa]OW0oo8eN@5olGAh`03olO@hOo5cN3oaLgP00?oaLgP00?oa/cOolG:g_o5b]h00_o5b]h2
olC7g@GoaLSL00?oa<KKolG7foo5am/00oo5am/2olG6fP?oa/KJ0oo6a]T3olO6fPGoalKI00?oalOJ
olS7fOo8amT00oo8amT00oo8b=[ob<WJolS9fP02olS9fP03olW9f_o9b]_obL[K00?obL[K0_o9bm/3
olW;g0CobLgL00?obLgMolW>gOo9c]d00_o9c]d00ol0003ob<gNolS?g`03olS?g`04olS@h?o7cn3o
aloPolO?h0Coam3Q00?oa/oQolG@h_o5d>800oo5d>800oo4c^;o`lkSol?>h`03ol?>h`05ol;<h_o1
cN?o`LgSol7=honocND01Onnb^<00onmb^Co_<OSokc7h`04okc7h`03ooooool0003ooooo01?ooooo
0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0
<oooool7og6Ym0CoLJSc0om`Yo<3ofnVl`CoKZGb1?m]Y?82of^SlP;oJ:;b0ol00002ofFQlPCoHIga
0omLW?44oeJIl@03odjGlOm<To3o@Ho_00;o@Ho_1?lbR^d01?lQPnWoTVfUoi9]YOnBKJD2ojBah@Co
kk^K0ooke9`4on_2Z@Goj/B^1?oY_jT4on[2[0CojlB^0_oZa:h2onK<_0CojmJn0oobjl03onci`P;o
h?k<0_oHnmd3om3hiPCobo;/00?odN_Wol_Vj_o;i^X00_o;i^X3olOPj`?obMcW1?o6enL00oo8eNCo
aM7SolGAh`03olGAh`03ol?>h_o5cN3oaLgP00?oaLgP0_o3b]l3olG:gPCoa<OM0oo5b=`3olC6f`?o
aLOK1?o5a]X00oo6a][oa/KIolK6f@03olK6f@03olO6f_o7a]WoalKI00CoalKI1Oo8amT2olS8f@?o
b<WJ0oo9bMX3olW:f`CobL_K00?obL_LolW=g?o9cM`00_o9cM`2ol[>g@CobLkM00Co0000olS?goo8
cmoob<oO1?o8d>000oo7cn3oam3QolO@h@02olO@h@;oa]7S1?o5d>82olCAi0Co`lkS00Co`/oTol7=
hoo1cN?o`LgS0onocND3okk:h`?o_L[T1?nlan<00onjanCo0000o`00000Dooooo`008oooool00ol0
003oooooooooo`0eooooo`;oKjWd1?m`Z?@4ofnXl`;oKjOc00CoL:OcofnVlom_Y_?oKjKc1?m^YO84
offTlP?o00000omXX_84ofFQlP?oHIob0_mMWO800omLW?7oEYWaoeJIl@02oeJIl@?oCYOa00?oAICa
od6?kolbR^d00olbR^d6ojBah@;okk^K0ooke9`5on_2Z@Goj/B^00CojLJbonVoZOoY_jWojKnY1?oZ
`Z`3on_4[PCoj/B^00Coi/blon_F__o[e[kojmJn0oobjl03onci`P;oh?k<0_oHnmd3om3hiPCobo;/
0_o6j^l3ol_VjPGoan3[00?obMcWolKGioo6enL00_o6enL2ol?CiP?oaM7S1?o3c^83olG=h0Co`l[O
00?oaL[NolC7gOo4amd01?o4amd00oo5b=coa<KKolC6f`03olC6f`03olG7foo5a][oaLKJ00;oaLKJ
00?oaLCIolK6fOo6a]T00oo6a]T00oo6aMWoalKIolO6f@06olO6f@?ob<OI1?o8b=T00oo8bM[obLWJ
olW9fP03olW9fP03olW:foo9bm_obL_K00;obL_K0_o:c=`3olW=g0Cob/kM00KobLkMolW?g_o9cmko
bLoNo`000?o8cml4olS@h0;ob=;Q0oo7d>44olKAh`03olG@h_o4dNCoa=7T00?oa=7T00?o`lkSol;?
i?o2cn@00_o2cn@00oo1cN?o_lgUoko=i@03oko=i@03okk:honmb^Co_L[T00?o_L[T00?o_<OSok[7
i?njan@00_njan@00ooooooo0000ooooo`0Booooo`008oooool2o`0003Oooooo0_m_ZO@4og2Xm0Co
KjSc0om_Yo<4ofjVl`;oKJGc00CoK:Cco`000?l0003o00000omZXo84ofRRlPCoIJ7b0omQWo83oefM
lP?oF9cb0omAV_801?m>Uo7oAICaodFDlOm5U?43ocV@l0GoY;7Q0_o_^i/3oo_DW0Cojl:Y1OoZa:h2
onW6/P;ojKnY1?oZ`Z`4on_4[PCoj/B^00Col/j/on_F__o[e[kojmJn0oobjl02onci`P;oh?k<0_oH
nmd3om3hiP?obo;/1Oo6j^l00oo;i^[oan3[olOPj`03olOPj`?o`m[Z00?oa]OWol?Ci_o3dnH00oo3
dnH00oo5dN?o`lkRol?>hP04ol?>hP03olG=h?o3b]oo`l[O00;o`l[O00?o`/ONolC7gOo4amd01?o4
amd00oo3aMcoa<KKolC6f`03olC6f`;oa<GJ0oo5a]X3olG4f@?oa/KI0oo6aMT8olO6f@03olS7fOo8
b=Wob<SI00?ob<SI1Oo9bMX2ol[;fP?obL_K1?o:c=`00oo9cMcob/kMol[>g@02ol[>g@03ol[@g_o9
cmkobLoN00;obLoN00?obM7Po`000?o8d>000_o8d>04olSBh@03olO@hOo6dN?oa]7S00;oa]7S00?o
aM?TolCAi?o4dN@00oo4dN@00oo3d^Go`/oTol;?i002ol;?i0;o`=3V1?nocND2okg=iPCo_L[T00?o
^l[Vok[7i?njan@00_njan@2okS6i@03ooooool0003ooooo017ooooo000Rooooo`03o`000?oooooo
oooo03Oooooo0om^Z?@4og2Xm0CoKjSc0om_Yo<3ofjVl`?o00001?m/Y?<4ofZSlP?oIj;b0omUX_<3
of:Pl`04of6Ol_mMWO;oGIgboefMlP?oF9cb0omAV_83odZIlP04odFDlOliT?3o>I3`ocV@l0GoY;7Q
00?okk^Koo_DW?nU^^P01Oo[`ZT5on[4[P?ojLJb00?ojKnYon[2[?oZ`Z`00_oZ`Z`4on_4[PCoj/B^
0_obcZ`01_o[e[kol^_0oo;[`?objl3ok?W2omg/R0;o^nZ=00CoaOk=ol7mi?o1oNCo`OgT0onomnl0
0oo;l^coa^[_olKZk`03olKZk`?o`^?_00?oan3[ol?Jj_o3f^X00oo3f^X00oo0e>Wo`m?Vol?CiP03
ol?CiP;o`LkT1Oo3c^82ol;:h@?o`l[O0oo2amh3olC7g@Co`lGL0oo4a]/4olC5fP03olG6f_o5a=Wo
aLCI00?oaLCI00?oa/KIolK5fOo6aMT00oo6aMT6olO6f@03olS7f?o8b=Wob<SI00?ob<SI0_o9b=T3
olW9fPCob/_J00?obL_Kol[<g?o:c=`00_o:c=`00oo;c]cob/kMol[>g@02ol[>g@?ob]3N0_o9cmh3
olWAh003o`000?o8d>3ob=;Q00?ob=;Q0_o8dn<3olKAh`?oaM?T0_o4dN@4ol?Bi@03ol;?i?o0d>Ko
`=3V00?o`=3V00?o_lgUokg=i_nmcNH00onmcNH00onmb^Co^l[Vok_:iP02ok_:iP03ok[7i?nha^Go
^<KU00?o^<KU00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool0>?ooool7ofjX
m0KoKZOc0ol000001?m]Y_?oK:GcofbUlom/YO<4ofbTl`CoJZ?b0omWX_83ofFRl`CoHZ3c0omNWo<2
oeZNl`04oeRLl_mAV_;oDI[boe6JlPCoBYWb0_m1Uo800oliT?3oY;7QojBah@02ofCJfPCoYK[X1?o[
`ZT4on[4[PCojLJb00?oj<Ndon[2[?oZ`Z`00_oZ`Z`3on_4[PCoj/B^0oobcZ`3oo_YX0?ogNb800?o
^nZ=olGncOo1oN@00_o1oN@3okogk`Co_>kd00?oa^[_ol;Skoo2hnl00_o2hnl3okkLkP?o`m[Z0oo0
e>T3ol?CiPCo`LkT00?o`lkRol;:hOo2b^401?o2b^400oo3b]oo`/ONol;7gP03ol;7gP03olC7gOo3
aMco`lGL00Co`lGL00?oa<KKolC5f_o4aMX00_o4aMX00oo4`mWoaLCIolG4f@03olG4f@03olK4f?o6
aMWoa/GI00?oa/GI0_o7aMP3olO6f@Cob<OH0oo8b=T4olW8f@03olW9f_o:bm[ob/_J00;ob/_J00Co
blcKol[<g?o:c=cob/cL1?o;c]`2ol[>g@Cob]3N00?obLoNolWAh?o9dN000_o9dN000ol0003obM?Q
olSBh@02olSBh@Cob=?S00?oa]7SolGCi?o5dn@00_o5dn@00oo4dNCo`m;Uol?Bi@02ol?Bi@;o`]?W
1?o0d>H00onnd>Oo_LgVokg=iP03okg=iP03ok_=ionkb^Ko^l[V00;o^l[V0_nhbNL4okS6i@03okG5
i_oooooo0000017ooooo000Rooooo`03o`000?oooooooooo03Wooooo1om^Z?@2ofjWl`?o00000_m^
Yo<3offVl`CoK:Gc1?m[YO<2ofVTl`?oIj?c00CoIj;bofFRlomUX_?oIJ;c1?mRX?<3oejOl`CoFYkc
00?oEYkdoe6Jl_m:VO800om:VO83od6GlP;o>9Ga00?o;8c]ojFjj?nU^^P00onU^^P2on_2Z@Goj/B^
1?oYa[82onS7]0;oj/:/1?o[a:h4on[4[P?ol/j/0ookjJ02omg/R003ok_ZSOo5o/go`OgT00;o`OgT
0onomnl4okc^m0;o^NGd0oo2hnl5okkLkP03ol?Jj_o0e>Wo`=CY00?o`=CY00?o`m?Vol7>i?o1c^@0
0_o1c^@2oko:h`Go`/[Q00?o`LOOol;7g_o2amh00oo2amh2ol;5g0Go`lGL0_o3`mX3olC5fP?oa<?I
0oo5a=T3olK4f0?oa/GI1?o7aMP00oo7a]Wob<OHolS7f004olS7f003olS8fOo9b=WobLSI00;obLSI
00Cob/WIol[;f_o:bm[ob/_J1?o;c=/00oo:c=coblkLol_>g003ol_>g003ol[>gOo:d=kob]3N00;o
b]3N0_o;d]l3olWAh0;obM?Q00?o0000olWChOo8d^401?o8dn<00oo7eNGoaM?TolGCi002olGCi0?o
a=CV00?o`m;Uol;Cioo2dnL00oo2dnL00oo0d>Ko_]3Wokk@i`02okk@i`03okg=i_nkcNOo^lgW00?o
^lgW00?o^l[VokS9ionhbNL00onhbNL00onha^Go]LGVokG5iP02okG5iP03ooooool0003ooooo00oo
oooo000Rooooo`;o0000??ooool3offXm004offWm?l0003o0000o`0000?oKJOd0_m]Yo<01?m^Yo?o
KJKcoffVlom]Y_<4ofbUl`CoJjGc0_mYY?<4ofNSl`?oIJ;c1?mSX_<2of2Ql`03oejOlomJW_?oFYkc
00;oFYkc0omFW_@4oe2Mm003odZLm?m1Uo;o>9Ga00;o>9Ga1OnU^^P00oo[`ZWoj/B^on[4[P02on[4
[PCojLJb1?oXak@00ooZ`ZcojlB^on_4[P02on_4[P?oj/B^0oobcZ`3oo_YX0;ogNb800Co^nZ=oige
gOnMmMgoWOGM0onVm>l00onomnoo_>kdokc^m006okWUm003ol;Skonng>ko_]c^00?o_]c^0_nleN`4
ol3Dj@;o_/oW0oo1c^@4oko:h`?o`/[Q0oo1aml3ol;7gPCo`/GL00?o`lGLol?3f_o3`mX01?o3`mX0
0oo4aM[oa<?IolC3f@03olC3f@03olG4fOo6a=Soa/CH00?oa/CH00?oa/GIolO5f?o7aMP00_o7aMP0
0oo8aMSob<OHolS7f004olS7f004olW7f?o9b=WobLSIolW8f@Cob/WI00?ob/_Jol_<foo;c=/00oo;
c=/5ol_>g0;oc=3M0oo:d=h4ol_Bg`03olWAh?o9dn7obM?Q00;obM?Q00?o0000olWEhoo8dn<00_o8
dn<3olOEi@03olGCi?o4e>Koa=CV00;oa=CV0_o3e^P4ol;Ci`03okoCjOnnd>Oo_]3W00;o_]3W0_nl
d>T4ok_=i`;o^LgY1?nhbNL00onfbNSo]LGVokG5iP04okG5iP03o`000?oooooooooo00Oooooo1?l0
0001oa0@407ooooo0Oooool002;ooooo00?o0000ooooooooool0??ooool00om]Z?Co0000o`000007
offWm0?oKJOc1?m/Y_<2of^Ul`CoJZGc0omYY?<4ofNSl`?oIJ;c1?mSX_<3of2Ql`?oGJ7d0omJXO@0
0omFW_CoD9gdoe2Mm002oe2Mm0?oBYcd00CoA9cdocRElOnU^^SoYK[X0onU_N/4on[4[PCojLJb1?oX
ak@01?oVaKKojlB^on_4[_o[a:h4on[4[P?ol/j/0ookjJ000ooMk8So^nZ=oigeg@05ojKdk`;oZnkh
0on^iOT4okWUm0?o^=gc00?o_]c^okcEk?nleN`01?nleN`00oo0e>Wo_/oWokk?i`03okk?i`03ol7>
i?nob^?o_l[S00Co_l[S00?o`/[Qol77goo1aml00oo1aml00oo2amko`/GLol;5g002ol;5g0;o`L;K
1Oo3`mX00oo3`]Woa<?IolC3f@03olC3f@03olG2f?o6a=Soa/CH00?oa/CH0_o6`mL3olO5f0?ob<GH
0oo8amP4olW7f003olW8fOo:bMWob/WI00;ob/WI00?obl_Jol_<foo;c=/00oo;c=/2olc>f`?oblkL
1?o<d=d00oo:d=kobm;Ool_Bg`02ol_Bg`;obmCQ0oo9dn401Oo9eN?o0000olWEhoo9eN?ob=?S00?o
amGU0_o6enL3olCDiPCo`mKX00?o`]?WokoCjOnodnT00_nodnT00onnd>Oo_=3Yokc@j@03okc@j@03
ok_=ionicNWo^LgY00?o^LgY00?o^<WWokK9j?nfbNP00_nfbNP4okG5iP03ok?4iooooooo000000[o
oooo00?o0000ooooooooool00_ooool002;ooooo00?o0000ooooooooool0>_ooool3o`0000[oKJOd
0om]Yo<4ofbVl`;oJjGc1?mZYO<4ofVTl`?oIjCc0_mVXo<00omUX_?oHj;cof>Rl`02of>Rl`?oH:7c
0omMXO@4oeZQm0?oEZ7e0omBXOH00om:W?CoA9cdojFmj`05ojFmj`;oj/B^1?oYa[85onS7]0;oi/Ff
0_o[a:h3on[4[PCol/j/0_okjJ02omg/R0CoN>?/00?oY_C_oj_^n?n[k_P01_n^iOT00oniiOCo^=gc
okSMl`02okSMl`?o]]G`1?nleN`2ok[?jPCo_/oW0_nlb^D5oko:h`;o_/KQ1?o1aml2oko4g@?o`/GL
1?o1`]/3ol?3fP?o`l;I0oo4`mT3olG2f0?oa/CH1?o6`mL00oo7aMSob<GHolS5f003olS5f003olS7
f?o9amSobLOH00;obLOH0_o:b=P3ol[9f@?obl_J0oo;c=/4olc>f`03ol_>g?o<d=goc=3M00;oc=3M
0_o<dmh3ol_Bg`CobmCQ00KobM?QolWEhoo9eN?obMGSo`000?o9f>D3olOEi@Coa]OW00?oa=CVol?F
j?o3e^P00_o3e^P00oo1en[o_m?YokoCj@02okoCj@;o_MC[1?nld>T2ok[Aj`Co^LgY00?o]/c[okK9
j?nfbNP00onfbNP00oneaNKo/lCWok?4i`03ok?4i`03ooooool0003ooooo00Sooooo00?o0000oooo
ooooool00_ooool002;ooooo0ol0000gooooo`?o00001?ooool:offWm0KoK:Kd0om[Y_<4ofZUl`Co
JJCc0omWY?<3ofJSl`CoI:?d0omRXo@2of2Sm003oefQm?mJXOCoFZ7d00;oFZ7d0omFXOD4oe:QmP03
odnRmonU_N_oYKg[00CoYKg[00?oj/B^onW6/_oYa[800_oYa[84onS7]0Coi/Ff00CojlB^on[4[_oZ
a:koj/B^0oobcZ`2oo_YX0;ogNb80omhhn`3oi3Un`?oW=om0on^iOT4ojkLm`03okSMlonfeO3o]]G`
00Co]]G`00?o_=G/ok[?j_njcnX00onjcnX00onncnOo_<[Uokc:i@03okc:i@03oko:honna^7o_/KQ
00Co_/KQ00?o`LOOoko4gOnoa=d00onoa=d00oo2aMco`L;Kol72f`04ol72f`03ol?3f_o3`]Wo`l;I
00?o`l;I00?oa<?IolG2f?o5`]P00oo5`]P00oo6a=Soa/?GolK3e`02olK3e`03olO3e_o8aMSob<GH
00?ob<GH0_o9a]L3olW7f0Cob/SH00?ob/WIol_;f_o;bmX00oo;bmX00oo;c=_oc<kKolc>f`02olc>
f`;ocM3L0oo<d=d4olcCgP03ol_Bgoo;e>7obmCQ00;obmCQ0_o;en<3olWEh`04olWHiOl0003obMSU
olOEi@Coa]OW0_o4fNT3ol?Fj0?o`MOZ00?o_m?YokgDjonme>/00onme>/00onld>Wo^]7[ok[Aj`03
ok[Aj`03okW=jOnfc>_o]/c[00;o]/c[0_nfbNP3ok?8jPCo/lCW00?o/<?Xooooool000002Oooool0
0ol0003oooooooooo`02ooooo`008Oooool2o`0003Kooooo0ol00008ooooo`;oK:Od2?m]Yo@6ofbV
m0CoJjKc1?mZYO<2ofVUl`?oJ:Cc00CoIjCcofJSlomVXo?oIZ?c1?mTXo@3of:Sm0CoH:?d0omNXoD2
oebTmP03oeJQmOmBXOKoDZ7f00;oDZ7f00CoCj;gojFmjonU_N_oYKg[0onU_n`4onW6/PCoj<Nd1?oV
aKH4on[4[P?ol/j/0_okjJ000ooMk8SoL]Kkog;Fn`02og;Fn`03oi3UnonLgogoW=om00;oW=om0onQ
fO/4ojkLm`;o[]Cd1OnfeO02okG?k@Co^/oZ0_nibNL4okc:i@;o^lGR1Onna^400onm`mko_lCMoko4
g@03oko4g@03oko1foo1`]_o`L;K00Co`L;K00?o`L3Iol?2fOo3`]T00oo3`]T00oo3`=OoaL;HolG2
f003olG2f0;oaL7F0oo6`mL3olO3eP?ob<GH1?o9a]L00oo9amSob/SHol[8f003ol[8f0Gobl_J0_o<
cMX3olc>f`CocM3L00?oc=3MolcCg_o<dmh00_o<dmh2olgFh0?obmCQ1?o;en<01Oo9eN?obMSUolWH
iOo9f>Go000000;ob=[W00?oa]OWolCIjOo4fNT00oo4fNT01?o3e^So`MOZol7Gj_o1enX2okkHk@Co
_MC[0_njeNd4ok[Aj`03okO@kOnfc>_o]/c[00;o]/c[0_ncc>`5ok?8jP03ok?4ion``nSo/<?X00;o
/<?X00?oooooo`000?ooool01oooool00ol0003oooooooooo`02ooooo`0000Co<S8bo`000?lb<S;o
k^k^1Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Cooooo00?o0000ooooooooool0<_ooool3o`0000cooooo2_m/Yo@3ofbVm0?oJjKd1?m[Y_<4ofZU
l`;oJJGc1?mXY?<4ofNTm0?oIJCd0_mTY?@00omRXoCoH:?dof2Sm002of2Sm0?oGZ?e1?mLY?H3oeZU
m`03oeVWn?nU_ncoYKo/00CoYKo/0_oYa[84onS7]0Goi/Ff00?ohkndon[4[_oZa:h01?obcZ`00ook
jJ3ogNb8o`000002og;Fn`CoR=Oo00?oW=omoj7InonQfO/01?nQfO/00on^g?Oo[]CdojkDm003ojkD
m003okKEl?necngo]Lo]00Co]Lo]00?o^/oZokW9ionibNL00onibNL00onlb^Go^lGRok_5hP03ok_5
hP?o_/KQ0onm`mh3oko4g@?o_l7K0oo1`]/4ol70f@?o`l;I0oo3`=L3olG2f0CoaL7F00?oa/?GolO3
e_o7`mH00oo7`mH00oo8aMSobLKGolW6e`03olW6e`Gob/SH0_o<b]P3ol_;fPCoc<gJ00?oc<kKolg@
g?o=d=`00_o=d=`2olkCg@?oc=?N1?o=e^000oo;e>7obmOSol_Gh`02ol_Gh`;obm[U00GobMSUolSJ
ioo8f^Oo0000olSJi`02olKLj@Coa=WY0_o2fn/00oo1en[o_]S]okkHk@03okkHk@03okgDjonjeNgo
^]G]00?o^]G]00?o^]7[okO@kOngd>d00_ngd>d00onfc>_o/lc/ok?<k003ok?<k0;o/lSZ0_n`an/6
ok33j0;o00001oooool00ol0003oooooooooo`02ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo02oooooo0ol0000@ooooo`[oK:Od0om/Y_@7of^Vm0?oJZGd0omYYO@4ofRTl`CoIjCd0omUY?@3
ofBTm0CoHjCd0_mRYOD00omNXoGoG:CfoebTmP02oebTmP?oFZGg00?oFJOhojFok?nU_n`01?nU_n`0
1?oYa[;oj<NdonS7]?oXak@5onK5]P?ohknd00Coj/B^oo;>[?obcZcol/j/0_okjJ001?l0003oN<go
ogS=oomhcOl2ohSGo`GoT]?m0_nQfO/3ojGBm`Co[]Cd0on^c_04okG?k@;o]<WZ1?nibNL00onga>Co
^lGRok_5hP05ok_5hP03okk6hOnm`mko_L?N00?o_L?N00?o_lCMoko1fono`M/00ono`M/00oo1`]_o
`L3Iol70f@04ol70f@03ol?2fOo3`=Oo`l3G00?o`l3G00?oaL;HolG1e_o5`MH00oo5`MH5olO3eP03
olS4e_o9a]OobLKG00?obLKG0_o:amL3ol[8f0Coc<[H00?obl_Jolc=f_o<cMX00_o<cMX2olk@f`?o
cM3L1?o>dmd00oo<dmkocMKPolgFh002olgFh0;ocMWR00?obmOSol_JiOo;f^D00_o;f^D2ol[Mi`?o
b=[W00Go0000olKLjOo6g>Woa]cYolCIj@03ol;Kj`;o`=c^1?nnf>d00onkfNoo^]G]ok[Ek@03ok[E
k@03okOEkongd>go]m3]00;o]m3]0_ncd>l4ok?<k003ok3;k_n`an_o/<O[00?o/<O[0on``nP2ojg2
j@03ooooool0003ooooo00Kooooo00?o0000ooooooooool00_ooool000?ooooo00?o410@oooooooo
ool02oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00;ooooo0_l0000]ooooo`?o
00005?ooool:ofbWm0?oK:Kd1om[Y_@3ofZUm0CoJJGd0omXYO@3ofNUm0?oIZGd00CoIJCdofBTm?mT
Y?CoI:Cd1?mSY?@3of:Um@CoHJKf1?mQYoL3ojFok0;oYL7]1?oXak@5onK5]P?ohknd0_o^d;@2oo;>
[004oo_YX?l0003oN<googS=o`CoQ/cn0onBdod3oiW=nPGoYM;g00?o[]Cdojk>l?n^c_001?n^c_00
0onecngo]<WZokC9jP03okC9jP03okW9ionga>Co]lCT00;o]lCT1OnkaN82ok[1g`Co_L?N00?o_;oL
oko1fono`M/00ono`M/00ono_]Wo`L3Iol70f@04ol70f@03ol6neoo3`=Oo`l3G00?o`l3G00?oa;oF
olG1e_o5`MH00oo5`MH2olK1e@?oal?F0oo8a=H3olW6e`Cob/OG00?ob/SHolc:f?o<b]P00_o<b]P2
olg<f@?oc<gJ1?o>d=/00oo=d=coc]?MolkCg@02olkCg@;oc]KO0oo=e^02olgIhP;ocMcT0oo;f^D4
ol[Mi`06olSJioo6g>Woa]cYo`000?o6g>Woa=o/0oo2fn/4ol3LkP03okkHkOnkfNoo^mW_00;o^mW_
00?o^]G]okOEkongeNl00ongeNl00ongd>go/m3_ok?@k`03ok?@k`03ok?<k?n`bnko/<_^00;o/<_^
0_n`an/3ojc6k0Go[L;Y00?o0000ooooooooool00oooool00omEEEGoIVIVo`000004ooooo`000ooo
ool00ol0003oooooooooo`0<ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`0Yooooo`?o00006?ooool:ofbWm0KoJjKd1_mZY_@00omZYOCoJJGdofVU
m002ofVUm0?oJ:Gd0omWYO@8ofJUm0?oIJGe0_mUY_D00omRYOGoHJKfof6VmP02of6VmPCoHJOg1OnU
`Nd2onS7]0Goi/Ff1?oS_k@3onk@]003oo;>[?oRkXcoN/Cn00;oN/Cn0_n6c?h4oho8n`GoVLgj0_nU
d_L3ojK<l`Go[/k`0_n^an`4okC9jP03ok?3i_nga>Co]lCT00Co]lCT00?o^lGRok[1gonj`Ml01?nj
`Ml00onm`mko_;oLokbog002okbog0?o_l7K0ono_]T3ol70f@Co`KkG0oo3`=L3olBoeP?oaL7F1?o6
`MD00oo7`mKob<CFolS4eP03olS4eP03olW6eoo:amOob/OG00;ob/OG0_o<b=L3olc:f0CocLcI00?o
c<gJolk@foo>d=/00_o>d=/2oloCg0?oc]?M1?o>e]l00oo=e^3ocMWRolgIhP04olgLi003ol_JiOo:
gNOob]gW00;ob]gW0oo8h>X00oo6g>Woa=o/o`000002olCOk003ol;Kjoo0g>ko`=c^00;o`=c^00?o
_=k`ok_IkonkfNl00_nkfNl3okSIl@;o]mG_1?nce?42ok?@k`;o/<o`1?n`bnh2ojc:k`Go[<K/0_n]
`^T2ooooo`03o`000?oooooooooo00[ooooo0003ooooo`03o`000?oooooooooo00cooooo00?oEEEE
olc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool09ooo
ool2o`0001gooooo2Om/Yo@6of^Vm0SoJZKd0omYYO@5ofRUm003ofNUm?mVYOCoIZGd00KoIZGd0omU
YOD4ofFVm@?oIZOf0omVZOH00omXZoOoYL7]ojG1k@03ojG1k@03onS7]?oVaKKoi/Ff00;oi/Ff1?oS
_k@4onk@]003on;^S?mja?koN/Cn00CoQL;k1On?b?/2oiW=nP?oWLSf1OnVc?<00on^c_3o[/O/ojk7
k004ojk7k003okC9j_nc`nKo/l?V00;o/l?V1?nga>@2okO0h@Go^/7O00?o^[gLokbog?nl_m`01?nl
_m`00ono`M_o_kkIoknnf@03oknnf@03ol70fOo1_]Oo`KkG00Co`KkG00?o`l3GolBoe_o4_mH00oo4
_mH00oo5`MKoa/7EolK1e@02olK1e@03olO1e?o8a=Kob<CF00?ob<CF0_o:a=D3ol[7e`Coc<SG00?o
c<[Holg<fOo=c=T00_o=c=T2olo?f@?oc]3K1?o?dm`00oo>dmgoc]KOolkFg`02olkFg`;ocm[Q00?o
cMWRolgLi?o=g>@00_o=g>@2olcPi`?ob]gW0oo8h>X01Oo6hngoa=o/olCOk?l0003oa=o/00?o`N7_
00?o`=c^okcNl?nlg_000_nlg_000onkfNoo^=WaokSIl@02okSIl@;o/mWc1?nce?400on_e??o/<o`
ok3?l003ok3?l003ok3;k_n/b^oo[<[_00?o[<[_0_n/a^`6ooooo`03o`000?oooooooooo00[ooooo
0003ooooo`03oa0@4?oooooooooo00cooooo00?oZJVYogMgMoooool00oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo02Gooooo0ol0000Pooooo`KoK:Od0om[Yo@6of^Vm0SoJZKd0omY
YO@7ofRUm0KoIjGd0omWY_@00omUYOGoIJKeofFVm@02ofFVm@?oIZOf0omVZOH00omXZoOoYL7]ojG1
k@03ojFmj`Coi/Ff1?oS_k@4onk@]003on;^S?ml_?_oO;ck00GoQL;k0_n?b?/3oiC4m`GoWLSf0_nV
c?<4ojO5k`Co[/O/00?o[/;Xok?3i_nc`nH01?nc`nH00onga>Co]l3QokO0h@03okO0h@?o^/7O0onj
_M`4okbog003okblfOno_]Wo_kkI00?o_kkI0_no^mH5ol6ne`03ol:le?o4_mKoa;oF00?oa;oF0_o5
_]@3olK1e@?oal7D0oo8a=H4ol[4e@03ol[7eoo<b=Ooc<SG00?oc<SG00CocL_Golg<fOo=c=WocLcI
1?o?cmT00oo>d=_ocm?LoloCg002oloCg0;od=ON0oo>e]l2oloJh@;ocmkS0oo=g>@4olcPi`04ol[M
ioo8h>[ob>3ZolSPjP?oa^?]00?oa=o/ol7Qkol000000_o1hNl2okgSlP;o_=k`1?nhg_<00onhfO7o
/mWcok?Il`03ok?Il`03ok?DlOn_e??o[mCc00;o[mCc0_n`co03ojc>lPCo[<[_2_ooool00ol0003o
ooooooooo`09ooooo`0000CoV9RHoooooonHV9SoMgMg2oooool01Ol@413ooooooooooooooooo<S8b
00Cooooo00?o0000ooooooooool01Oooool3o`0002;ooooo0ol0000Sooooo`OoK:Od0om[Yo@7of^V
m0?oJZKd1?mYY_@5ofVUm0GoJ:Gd1_mWYO@4ofNVm0CoJ:Oe0omYZ?D2of^YmP03ofJYm_nU_N_oYKg[
00CoYKg[0_oVaKH4on>o]0Cok]2d00?oh^j<ogblnon3^oP00_n3^oP5oh^on0GoU<Cg0_nMb?H3oio3
l@KoYlG_00?o[/O/ojk2j?n^`^P00_n^`^P4ok?3iP03ok:nhong`>7o]l3Q00Go]l3Q00?o^/7OokZm
g?nj_M`00onj_M`00onl_mco_;cIokblf@02okblf@?o_kkI1?no^mH3ol6ne`?o`[cD0oo4_mH4olFn
e003olK1eOo7`MCoal7D00?oal7D00?ob<CFol[4eOo:a=D00oo:a=D5olc8e`?ocL_G00?ocLcIolo?
fOo?cmT00oo?cmT01?o@d]_ocm?LoloCg?o?dm`4om3GgP03olkFgoo?f^7ocm[Q00CocmkS00?ocMcT
olcPioo<h>L00_o<h>L3ol_Tj@04olSPj_o6hngoa^?]olKSk@?o`nK`00Co`N7_o`000?nmho;o_N?b
0_nhi?@4okSNl`;o/mkf0oncfO<3ojoImP;o[mCc0on[d_D5ojc>lP03ojc:kooooooooooo00[ooooo
00?o0000ooooooooool02Oooool00004oc8b<_l0003o<S8bonk^kP_ooooo1Ol00004ooooo`Co0000
1?ooool00ol0003oooooooooo`0Oooooo`?o00009oooool4ofbWm0KoJjOd1om[Y_@3ofZVm0CoJJKd
1_mYYO@7ofRUm0;oJ:Kd00?oIjGdofNVm?mWY_@00_mWY_@4ofRWm@?oJJSe0om[ZOH6ojFmj`04onK5
]_oS_kCohkndon>o]0Gok]2d00?oh^j<ogbfn?n3^oP00on3^oP5oh^on0;oU<Cg0onH_o<5oio3l@?o
YlG_0onW`>/5ojk2j003ok?3i_nb_^?o/[kS00;o/[kS1Ong`>42okJkg@Co^[gL00?o^KWIokblfOnl
_=T01?nl_=T00ono_]Wo_k_FoknkeP04oknkeP03ol6neoo2_=Co`[cD00?o`[cD00?oa;oFolFne?o5
_]@00oo5_]@5olO1e003olW2doo:a=Gob/CE00?ob/CE0_o<a]D3olc8e`CocL_G1Oo?cmT3om3Bf`03
oloCg?o@emkod=ON00;od=ON0_oAfn000oo?f^7ocmkSoloNh`02oloNh`?ocn?V00?oc>3Wol_TjOo;
i>T00_o;i>T2olSWk@03olKSkOo3i_3o`nK`00;o`nK`0_nnj?800onmho;o0000okSTm003okSTm004
okSNloncg_Ko/mkfok?NmP;o[]kh1?n_fOH2ojWGn0GoZm;e0_n/c_8?ooooo`03o`000?oooooooooo
00Wooooo000Pooooo`03o`000?oooooooooo01cooooo0ol0000[ooooo`CoK:Od1_m[Yo@3of^Vm0So
JZKd1OmYY_@4ofVUm0OoJ:Gd1?mXY_@2ofVVm0CoJZOd0om/Z?D01?mYZ?GoJjWfof^Ym_m[ZOH3ojFm
j`;oYK;R1?oS_k@4onk@]004on;^S?ml]_SoO;Khogbfn0CoPk_h0_n;_oP3ohnlm0GoV;oc0_nO`o43
oj6mk@KoYl3[0_n^`^P3ojfli@Go/[kS00?o]l3QokJkgOnf^md01?nf^md00onj_Mco^KWIokVif@02
okVif@Co_;cI00?o_;WFoknke_no^mH01?no^mH00ono^MCo`[cDol:le003ol:le003ol>kdoo5_]Co
aKkD00?oaKkD0_o6_]<3olO1e0?obL;C0oo:a=D4olc6e@03olc8eoo=bmOocL_G00;ocL_G0_o?cML3
olo?f@Cod=;K00Cod]OLom3Gg_o@emkod=ON0ooAfn001?oBh>;ocmkSoloNhoo?g^<3oloSiP;ocNOY
0oo;i>T2olSWk@?oaN__00Co`nK`okkXl_nnj?;o_^Sb0_nhjOD01?l0003o^>CdokSTm?nhi?@2ok;T
m`03ok?Nm_n^g_So[]kh00?o[]kh00?o[mWfojWGn?nYeoP00onYeoP2oj_BmA?ooooo00?o0000oooo
ooooool02Oooool0023ooooo00?o0000ooooooooool06Oooool3o`00033ooooo0om/Yo@6of^Wm0?o
JjKd2?mZY_@6ofVVm0GoJJGd1OmXYO@4ofRVm0;oJJKd1?mZYo@4ofbXm@;oKZ[e1_nU/^82on>o]0Co
k]2d0_oRkX`4oh6dmPCoR;Se1On?_?@2oiRol`?oV[__1OnQ_Nd4ojO0j`03ojNjion]_>Go[KcU00Co
[KcU0_nb_^<3ok:ig`Go][_M00?o][OJokVifOni^MT01?ni^MT00onl_=Wo_;WFokbieP02okbieP?o
_k_F1?no^M@3ol:le0?o`k_C0oo5_]@4olJnd`03olO1e?o9`]?obL;C00?obL;C00?ob/CEolc6eOo<
a]D00_o<a]D2olk8e@?ocL_G1?o?cML00oo?cmWod=;Kom3Bf`02om3Bf`?od]OL00Cod=ONom7Kh?oA
fn3odM_P0ooBh>801?o?g^?ocn?VoloSi_o?hnH4olgWj@03ol_TjOo8ingob>O]00?oaN__0_nok_80
0onnj?;o^>WeokSYm@03okSYm@04o`000?nbi?Oo/^Cgok;Tm`?o[>?j0_n^g_P3ojOMnP?oZMOh5ooo
ool00ol0003oooooooooo`09ooooo`008?ooool2o`0001Oooooo0ol0000dooooo`?oK:Od2_m[Yo@6
ofZVm0OoJJKd2_mYYO@3ofVVm0?oJZKd1?mZYo@4ofbXm@;oKZ[e1_nU/^800ooS_kCok]2donk@]002
onk@]003on;^S?mk/OKoNk7f00CoPKCf1?n8^?D2ohnlm0;oT[Sa1_nJ^nl5oj6mk@03ojO0jonW^^Oo
Yk[W00;oYk[W1?n]_>D00on]]n7o/[WOok:ig`04ok:ig`?o][_M0onf]mX4okVif@03okVfe_nl^MKo
_;WF00Co_;WF00?o_k_Foknie?no^M@01?no^M@00oo2_=Co`k_Col>kd`03ol>kd`03olFne?o6_]?o
a[kC00?oa[kC1Oo9`]<2ol_3dP?oc<KE1?o>b=D00oo=bmOoclgGolo=e`02olo=e`;od]7H0oo@d]/3
om;Gg004om?Kg_oAfn3odM_Pom7Kh0?od^3R0ooBiND00oo?hnKocNOYolgWj@02olgWj@;obnc/00Co
b>O]olG[koo5jnooaN__0_nok_83okS_m@;o^>We0onaj_P00ol0003o[>?jojcSnP02ojcSnP;oY>;l
0_nWgOXLooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo01Cooooo0ol0
000hooooo`CoK:Od2Om[Yo@6ofZVm0[oJJKd1omYYO@3ofVVm0CoJZKd1?m/Yo@4ofjXm003og2Ym?nU
/^;oYK;R00;oYK;R0onQdoT2onk@]004on;^S?mn/??oO[3cogj`l`CoQ;;c1On;]O84oi:hl@KoV[__
0_nQ_Nd3oj6hj@GoYk[W00?o[KcUojfghOn]]n400_n]]n46ok:ig`03okJkgOnf]m[o][OJ00?o][OJ
00?o^KWIokVfe_ni]]H00_ni]]H4okbieP;o_KKC1Ono^M@00oo1^=7o`k_Col>kd`03ol>kd`03olBj
dOo6_]?oa[kC00?oa[kC0_o8_]43olW2d`Cobl?B00?oc<KEolk8eOo>b=D00oo>b=D01?o@bmGoclgG
olo=eoo?cML4om;Af004om3BfooBemcod]OLom;Gg0?odm_N00CodM_Pom;Ph_oBh>;od^3R0ooBiND3
om3[i`04olgWjOo;k>cobnc/ol_/k0?oa_3_00?oaN__oko^l_nok_800onhkoD2ojk_m`;o/N[h0_nX
jOX00ol0003oZ>WjojcSnP03ojCRo1oooooo00?o0000ooooooooool02Oooool001oooooo00?o0000
ooooooooool04_ooool2o`0003cooooo1?m/Yo@9of^Wm0?oJZKd0_mYY_@00omZY_CoJJKdofVVm008
ofVVm0OoJJGd0omYY_@4ofZVm0CoK:Od1?m^Z?@00om`ZOCoYK;Roj7Cn@05oj7Cn@03onk@]?mi[OCo
O[3c00?oO[3c1?n4/_<5oh^elPCoT[Sa0onJ^nl3oi^fj`GoXKSY0_nW^^L2ojNeh`Ko[KOQ0onb^Ml2
ok6ef`Go][OJ00?o][?FokVfe_ni]]H01?ni]]H00onl^MKo_KKCokffd`03okffd`?o_kWD0oo1^=43
ol>kd`?oa;[A0oo6_]<4olRnd@03olW2doo;`m;obl?B00?obl?B1Oo>b=D3om3;e@03olo=eooBdMSo
d]7H00;od]7H0ooDe]X01?oBemcodm_Nom?Kg_oCfmh3omCQh004om;Ph_oBiNGod^GUom;Ui@?od>_W
0_o>l>X00oo;k>coa_3_olK`k`02olK`k`;o_o?a00?o_nkbokS_mOnhkoD00on^koL3oj?^n0;oZ>Wj
00CoWnOlo`000?nOiocoY>;l8_ooool00ol0003oooooooooo`08ooooo`007oooool00ol0003ooooo
ooooo`0?ooooo`?o0000?oooool6ofbWm0OoJjOd0omZY_@7ofVVm0GoJ:Kd00?oJJKdofVUm?mYYO@0
1OmYYO@3ofVVm0CoJjKd0om/Y_@4ofnWl`?oLZSc1?nQdoT4ogV]m0CoO[3c1?n4/_<2oh^elP?oSK;_
1OnC]>d5oi^fj`;oXKSY0_nQ/nD5ojNeh`Co[KOQ00?o[K;Mok6efona]M/01?na]M/3okJgfP?o][?F
1?ni]]H00onj/];o_KKCokffd`05okffd`03oknie?o1^=7o`KSA00?o`KSA00?o`k_ColBjdOo4^]40
0oo4^]400oo6_]?ob;kAolRnd@03olRnd@Gobl?B0_o>aM83olk8e@Cod<_E00CodloFom;Af?oBdMSo
d]7H1?oDe]X3om?KgP?oe>7P0ooEin<01?oBiNGod>_Wom3[ioo@jnL2olk`jP?ob?G/00Coa_3_okoc
lOnolo7o_o?a0_nfm?82ojWcl`03ojk_monSk_SoXnkh00;oXnkh0_nFj_T2oioWo003ooooool0003o
oooo02;ooooo00?o0000ooooooooool02?ooool001oooooo0_l0000=ooooo`?o0000@oooool6ofbW
m0OoJjOd0_mZYo@00omZY_CoJJKdofVVm005ofVVm0KoJ:Kd1_mXYO@01?mYYOCoJJKdofVVm?mYY_@4
of^Vm0?oK:Kd1?m_Yo<3og:Xl`03oj7CnOmfZ_?oMZ[c00;oMZ[c1?mjZo84oh2]l@CoQZo`1?n=/^l5
oi>dk@;oVkK[0_nK/NL5oj6ci@GoYkGS00?o[KOQojfbgOn]/]d00_n]/]d6ok6ef`03okJgf_nf/mKo
][?F00;o][?F0oni]]H3okZbdPGo_KKC00?o_[C@ol6hdOo1^=400oo1^=400oo2]looa;[AolBjd@03
olBjd@03olJjcoo8_]7ob;kA00?ob;kA0_o:_m03ol_3dPCoc/GB00?oc/SEom3;eOo@bmD00_o@bmD3
om??eP03om;Af?oDe][oe=KJ00;oe=KJ0_oFfm`01?oCfmkoe>7PomCQh?oDhN03omGWh`?oe>kU00?o
d>_Wolk`j_o>l>X00oo8mN`2okohk@03okoclOnfm?;o]_Cb00?oZO?c0onJl?800onSk_SoU^[ioiKZ
n@06ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02?ooool001oooooo00?o0000
ooooooooool02Oooool3o`0004Oooooo1_m/Yo@7of^Wm0?oJZOd1_mYY_@7ofRVm0OoJ:Gd1?mYYO@2
ofZUl`?oK:Kc00?oK:KdofnWlom_Yo<00_m_Yo<4og:Xl`CoMZ[c1?mjZo84oh2]l@CoQZo`1?n=/^l2
oi>dk@;oU;3Z1OnK/NL5oj6ci@;oYkGS0onW/=l5ojfbg@Co/KGK00?o/K3GokJce_nf/mH01?nf/mH0
0oni]]Ko^[;BokZbdP02okZbdP?o_KKC1?nn]=03ol6hd@?o`[O?0oo4^]43olJjc`?ob;kA1?o:_m00
0oo;`m;oc/GBolk5dP02olk5dP;od<SB0oo@bmD4om??eP04omKDeooDe][oe=KJomCFfP?oe]_L0_oH
h]h01?oDhN3oeNOSomGWhooEin<3omC^i@;odOCW00Coc_3ZolSek?o8mNcob?G/0_non>d2ok;hk0;o
XOGY00GoZO?coi[`l_nJl?;oV_3bohSYl00:ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool02?ooool001oooooo00?o0000ooooooooool01_ooool3o`0004_ooooo1om/Yo@6of^Wm0?o
JZOd1_mYY_@4ofRVm0[oJ:Gd1?mYYO@2ofZUl`CoK:Kc1?m_Y_<3og:WlPCoMZSb1?mkZO44oh6[k`Co
Qjc^1?n=[^`5oiB`jPGoVk7W0_nQ/nD2oj6^h@KoYk3O1On]/]d00ona]M_o/K3Gok6`e`02ok6`e`Co
][?F00?o]ZoBokZbd_nj/]801?nj/]800onm]]?o_[C@okjdd004okjdd003ol6hdOo2]loo`[O?00?o
`[O?00?oa;[AolJjcoo6^/l00oo6^/l00oo8_]7ob[o@olZod002olZod0;ocL7?0oo>aM84om38dP03
om3;eOoCcmKodloF00;odloF0ooFe=L01?oDe][oe]_LomKKg?oFfm`3omSRgP;of>SP00CoeNOSomC^
iOoDk^Goe>kU0_oAm>L3ol[ij004olSek?non>go/_S/ok;hk0;oXOGY0on;kN@?ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool02?ooool001oooooo0ol00003ooooo`?o0000Coooool7
ofbWm0KoJjOd0omZYo@4ofVWm0KoJ:Kd3OmXYO@3ofVUl`CoK:Kc1?m_Y_<3og:WlPCoMZSb1?mkZO44
oh6[k`CoQjc^1?n=[^`5oiB`jP;oVk7W0_nJ[N@5oj6^h@KoYk3O0_n]/]d2ojb]f0Ko/K3G00?o][?F
okJ_d_nf[m800_nf[m84okZbdP03okZ`conn]=3o_[C@00Co_[C@00?o_k;=ol:gcoo2]ll00oo2]ll0
0oo4]/coa[[?olJjc`03olJjc`;obK_=0oo:_m04olg1c`03olk5d_o@b=;od<SB00?od<SB00CodlgC
om??e_oCcmKodloF1?oFe=L3omKKg0?of>;N0ooHj>02omS`hP03omC^iOoAm>OodOCW00?ob_WX00Co
__cWojcih_n/nN;oTo7I0omdh/`00on;kNCoooooooooo`0@ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool02?ooool001kooooo0_l00002ooooo`?o0000Doooool4offWm0KoK:Od0om[
Yo@3ofZWm0CoJJOd0omXY_@3ofNVm0?oIjGd0omVYO@7ofRUm0CoJJGc1?m/YO<2ofjUlP?oLJGa00?o
LZObogJXl_mfZ?800_mfZ?84og^Yl@CoPJ__1?n7[>h4ohf^k0;oU;3Z0_nDZnH5oiZ]i0GoXJkQ0onW
/=l2ojJ[fPGo[:gH1?na/=L00ona[=;o]ZoBokJ_dP04okJ_dP03okZbd_nj/<oo^[3?00;o^[3?0onn
]=04oknbc@?o`[O?0oo4]/`3olJjc`CobK_=00?ob[o@olg1coo=`Ll00oo=`Ll5om38dP?odlgC00?o
dloFomKDeooFe=L00_oFe=L2omSJf@04omKKg?oHh]kof>;NomSRgP?of>SP0ooHl>801?oDmnCodOCW
ol[ij?o:nNP2okkli`;o[?WR00?oTo7IogCRc?mdh/`05_ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00Sooooo000Dooooo`Co000000?o410@ooooooooool00oooool4o`0005Oooooo
1?m]Yo@6ofbWm0?oJjOd1?mZYoD2ofVWm@?oJ:Ke00CoJ:KdofNVm?mWY_CoIjKd0omWYO@4ofJUm0?o
IZCd0_mWY?@00omXYOCoJJGcofVUl`02ofVUl`CoK:Gc0_m^YO84og6Ul@CoMZK`0omkYnl4oh2Xk@Co
QZW[1?n=Z^T5oiB[iPGoVZgT0_nQ[^42oj2Yg@KoYZ_J1On/[MP00ona/=Oo/JcBok6/dP02ok6/dPCo
]ZoB00?o]Z_>okZ`conj/<l01?nj/<l00onn]=3o_k;=oknbc@04oknbc@03ol:gcoo4]/coa;K<00?o
a;K<00?oa[[?olVkcOo9^ld00oo9^ld5olg1c`;od<G?0oo@b=84om?=d`04omOBe?oFe=Ooe]CGomKD
e`?of=[I0_oKh]/01?oHh]kof>SPomSXh?oHj>03omS`hP03omCgi?o<o>?oc?cS00;o^ogM00Go__cW
ojcih_n/nN;oElZVo`00000Hooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01ooo
ool001Kooooo00?o0000ooooooooool01Oooool2o`0005_ooooo1_m]Z?@2ofbXm004ofbWm?m[YoCo
JjOdof^Wm0CoJZOe0_mYYoD4ofRVm@CoIjKe00?oIZGeofNUm?mVYO@00omVYO@3ofJTm0?oIjCd1?mX
Y?<3ofZTl`?oK:Cb1?maYO44ogJVl0?oNjO_1?n0Z>d4ohJYj`CoSJ[Y1OnDZnH2oiZ]i0;oVZSP1OnP
ZMd5ojJ[fPCo[:gH00?o[:SCok6/d_na[=800ona[=83okJ_dP?o]Z_>1?nj/<l00onk[L_o_k;=oknb
c@05oknbc@Koa;K<1Oo9^ld2olbmc0?ocL7?1?o@aLl00oo@b=;odlgCom?=d`02om?=d`?oem;D00Co
e]CGomSJfOoHf]Wof=[I0ooKh]/2omcYg@05omSXh?oHl>;of?3RomS`h_oDmn@00_o<o><2ok_mg@;o
X_KA00?oElZVooooooooool06_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Oo
oooo000Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0FOooool6offXm0?oK:Sd
1?m[Z?D3ofZWm@;oJ:Oe1?mXY_D4ofNVm@;oIZGe1?mUYO@3ofFTm0;oIJ?d00?oIjCdofRTlomXY?<0
0_mXY?<3ofZTl`CoK:Cb0om`Y?43ogBTk`?oNJC^00?oNjO_oh2XkOn0Z>d00_n0Z>d4ohJYj`CoSJ[Y
0_nDZnH2oi:Wh`GoVZSP1OnPZMd5ojJ[fP03ojb]f?n/Z=?o[:SC00;o[:SC1Ona[=800onf[m;o]Z_>
okJ[cP02okJ[cP?o^[3?0onk[L/5oknbc@;o`K3:1?o4]/`2olJfb`?obK_=1?o<_L`00oo=`Lood<G?
om35c`03om35c`04omC9cooCcM?odlgCom?=d`Coem;D0_oJfMH01?oHf]Wofn;Kom_RfooKh]/3omcY
g@;og?;N00Cof?3RomCgi?o<o>?oc?cS0_nkoMd00onRm]7oooooooooo`0Nooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool01oooool001Kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1Iooooo`?oKZSd0om]Z?@2ofbXm@03ofbXm?m[Z?GoJjSe00;oJjSe0omZYoD3ofRW
m@?oIjOe0omVY_D3ofBUm@CoIJGd0omUY?@4ofFSm0;oIZ?c0omWX_800omZY??oK:CbofbTlP02ofbT
lP?oL:Ca0omdY>l4ogVTkP?oOjG/1?n5YNT4ohbViPGoTZOS1?nJZ>06oj2Yg@;oYZ_J0_nVY]H5ojbX
d`Co/JcB00?o/JO>okJ[c_nfZlh01?nfZlh00onj/<oo^jg;ok^]b`03ok^]b`?o_k;=0oo1/<X3olBf
c0Coa[K;00?obK_=olbmc?o<_L`00oo<_L`5om35c`?oe<W?00?odlgComOBe?oGd]@00_oGd]@3om[I
eP?ofn;K0ooLjMd2omcbgP;of?[N0_o>om/00onho<ooU>biofK?VP0Qooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool01oooool001Kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1Iooooo`?oKZSd0om]Z?@3ofbXm@CoJjSe0omZZ?D3ofRWm@?oIjOe0omVY_D4ofBUm@?o
HjCe0_mSXo@00omUY?CoIJ?dofFSm002ofFSm0;oIZ?c1?mWX_83ofZRl@?oKJ7`00CoL:CaogBTkomd
Y>ooM:C_1?miY>h3ognUk0CoQJGY1?n<Y^H5oi:Wh`CoVZSP0onPZMd2oijTf@GoYZKF1On/Z=<00ona
[=;o/JO>ok6WcP02ok6WcPCo]Z_>00?o]jS:ok^]bonk[L/01Onk[L/00ono//go`K3:ol6`bP03ol6`
bP03olBfc?o6]/_oa[K;00?oa[K;1Oo<_L`2olo0c0?od<G?1?oDbLl01?oHd=3oem;DomOBe?oGd]@3
om[IeP;ogN7G00Cofn;KomcYgOoLjMgog>WM0_oLl]h2omSjgP;oc_oK00?o^?c?ofK?V_mVciX08ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo000Fooooo`03o`000?oooooo
oooo00[ooooo0_l0001Jooooo`CoKjSd00?oKZWdoffXm?m/Z?D00_m/Z?D4of^Xm@?oJZSe0omXYoD4
ofJWmP03ofBVm_mVY_GoI:Ge00?oI:Ge0omSY?D3of>Sm0?oHZ?d0omSX_<4ofNRlP?oJZ;a1?m]XO03
og6Qk`CoMZ7]0_mlXNX00omoYNcoQJGYohFUj@02ohFUj@CoS:KV0_nBYn<2oi6Rh0GoV:?L1OnNY=T5
ojJVeP;o[:SC0_n/Xlh6ok6WcP03okJ[c_ngZ<[o]jS:00;o]jS:1Onk[L/00onmZ/Oo`K3:ol6`bP03
ol6`bP03olB`aoo6]/_oa[K;00?oa[K;0_o9]lT3olbmc0Cocl3<00?od<G?omC9cooDbLl00_oDbLl3
omS@d004omOBe?oJfMKof]WFom[IeP?ogN7G0_oPjMT00ooLjMgog?;NomcbgP02omSjgP;oc_oK00?o
^?c?o`000?ooool09Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo000F
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0F?ooool4ofnXm0;oKZWd1?m]ZOD3
ofbYm@?oJZSf0_mXZ?H00omXYoGoIZOfofJWmP02ofJWmP;oI:Kf1?mSYOD3of6Tm@;oGj?e00CoHj?d
of:Sm?mRXoCoHZ?d1?mSX_<2ofBQlP?oIZ3a00?oJZ;aoffQl?m]XO000_m]XO03og6Qk`CoMZ7]0oml
XNX4oh>Qi`CoRJ7T1?nAX^05oiRSg0CoWZCI1?nVY]H00onUX=3o[:?>ojbScP03ojbScPCo/JO>00?o
/J;8okNXb_ngZ<X01?ngZ<X3ok^]b`?o_J[70oo1/<X3olB`a`?oa[K;1?o9]lT00oo<_Lcocl3<olo0
c003olo0c004omC5c?oDbLooe<W?omC9c`Cof=3@0_oLem801?oJfMKogN7GomgQeooMhML3on3Yf@;o
h??J00Gog?_IomSjg_o>om_oc_oKo`00000Yooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool01oooool001Cooooo00?oEEEEofIVI_l000003oooool00ol0003oooooooooo`1Hooooo`?o
LJWd0om`ZO@4offYm@?oK:We0omZZ?H3ofRXmPCoIZOf0_mSY_H4of>Um@?oHJCe0omOXoD2oenRm003
of:Sm?mSX_?oHj;c00;oHj;c0_mTXO84ofJPl@?oJ9o`0om]W^h00omaXNooMZ7]ogJQk@02ogJQk@?o
O:7Z1?n3XNL4ohVQi0CoTJ;P1OnHXm`4oijTf@03ojJVe_nUX=3oYJ3@00;oYJ3@1?n/Xlh3ok6WcP?o
/J;81_ngZ<X00onk[L_o_J[7okfZa`03okfZa`03ol6`b_o4/<Ooa;3700?oa;3700?oa[K;olVgbOo9
]lT00oo9]lT5olo0c0?oe<G<00?oe<W?omS@d?oHd=000_oHd=03omcGdP?ogN7G0ooPjMT2on3cfP;o
g?_I00?od?oAok;g_?ooool0:_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oo
oooo000Wooooo`03o`000?oooooooooo05Sooooo0omaZO@3og2Ym0CoKZ[e0om/Z_H2ofZYmP04ofZX
m_mXZ?KoJ:SfofRXmPCoIZOf0_mSY_H4of6UmP;oGZCf00CoHJCeoenSmOmOXoGoGj?e0omOX_@4oejP
l`;oGiob1?mVX?43ofROl0?oKIk^1?maWN`3ogRMj@03ogbQj_n3XNOoPj7W00;oPj7W1?n9XN@4oi6R
h0;oV:?L0_nFWMT4oifNe0GoYJ3@1On/Xlh00onaYlko/J;8ok6Rb002ok6Rb0Go]jS:00?o^:C5okfZ
aonmZ/L01?nmZ/L6olB`a`KobKO900Coc[[7olo0c?o?`<cocl3<1?oDaL`01?oIc<gof=3@omS@d?oH
d=04omcGdP03on3OdooMhMOoh>WI00;oh>WI0_oPlmX2omckf@03om3odOnbmkcooooo02cooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`06ooooo`00:?ooool2o`0005[ooooo00?oLZ[d
og6Ym?m`ZO@00_m`ZO@4ofjZm@?oK:[f0omZZOH3ofRYmPCoIJSf0_mRYoH4of6UmP?oGZCf0omLX_D2
oe^Qm003oenRm?mNX??oGZ3c00;oGZ3c0omOWo82of2Ml@?oHic`00CoJ9o`offNk_m]W^koKIk^1?ma
WN`3ogRMj@CoOYcU1?n6W>44ohjLg@GoUYgI1?nMW]@4ojFPd0Co[:?>00?o[9g8ok6Rb?naX/P00ona
X/P3okNXbPCo^:C51?nmZ/L2ol2Za0Coa;370_o7/LD4olVgb@?oc[[700?ocl3<omC5c?oDaL`00ooD
aL`2omW<c@03omS@d?oLem;og=OB00;og=OB0_oPgm<2on?Xe003on3YfOoPlm[oh??J00;og?_I00?o
d?oAojoaZ_ooool0;_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Kooooo000Z
ooooo`03o`000?oooooooooo05Sooooo0_mbZ_@4og6[m0?oKj_e1?m]ZoH00om[ZoKoJZWfofRYmP02
ofRYmPCoIJSf0omRYoH3oenVmP;oFjCf00CoGZCfoebRmOmLX_GoG:;e0omKXO@3oeVOl`?oFIgc00?o
Giobof2MlOmPWO400omSW?03ofNKkP03offNk_maWNcoLIg/00;oLIg/0omhWNT4ogjLi@CoQYcQ1?n>
W=d4oiJMf@CoWIkD1OnUX=000on/Xlko[9g8ojbMb002ojbMb0Go/J;800?o]jS:okRTaOnhY<D00onh
Y<D3okfZa`?o`:[40oo4/<L3olNaa@?obKO91?o>^/L5omC5c0?ofLc=00Cog]?>omcGd_oLem;og=OB
0_oPgm<3on?Xe0;oiO;E0_oQo=800ooColOo[o6Zooooo`0`ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool01_ooool002_ooooo00?o0000ooooooooool0F?ooool2ogB[m0CoLJ_d0om_
ZoD4off[mP;oJj_f1?mXZ_L3ofBYm`;oHJSg00CoHZOfoenVm_mOY_KoGjKf0omKY?H4oeRRmP03oeFP
mOmKXOCoFIoc00;oFIoc1?mIWO<2oeVKl@?oHic`1?mWVnh3of^Ij`?oLYWX00?oN9gYogjLiOmnW>D0
0_mnW>D3ohJLh@CoSYcM1OnFWMT4oifNe0;oYJ3@0_nSVL/5ojbMb0Co/J;800?o/ik3okRTaOnhY<D0
1OnhY<D00onmZ/Oo`:[4ol2Za003ol2Za003olB`aoo7/LGoak7500?oak7500?obKO9oljjaoo>^/L0
0oo>^/L01?oC`<Ooe<G<omC5c?oDaL`4omW<c@;og]?>00?og=OBon3OdooPgm<00ooSj=@3onGbe@;o
hOcB00?o[o6Zooooooooool0<?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Ko
oooo000/ooooo`03o`000?oooooooooo05Sooooo0_mdZo@4og>/m@?oLJcf1?m_[?H2ofb/m`CoJ:[g
0omTZOL3of6Xm`CoG:Kg00?oF:Cgoe^Tm_mHX_H00omHX_H2oeFPm@;oDigd00?oFIocoeVMlomIWO<0
0_mIWO<3oeVKl@03oe^Il?mSW?3oIi_^00?oIi_^0om[VN/3og:Ij0CoNIST0on0Uml00on6W>7oSYcM
ohjLg@02ohjLg@;oUYgI0_nBUmD4oiZGc`GoXiW;1On/WLP00onaX/So/ik3ok>N``02ok>N``Go^:C5
00?o^Z?1ol2Za?o0Z/@01?o0Z/@6olNaa@Goc[[70ooC`<L00ooDaLcofLc=omW<c@02omW<c@?og]?>
00?ohmc?on3OdooSj=@00_oSj=@3onGbe@;ohOcB00?o[o6Zooooooooool0<_ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00Kooooo000]ooooo`03o`000?oooooooooo05Oooooo0omg
[?@4og>/m@?oLJcf1?m_[?H3ofb/m`?oJ:_g1?mTZ_P00omOZOSoHJSgoebVm`03oebVm`;oF:Cg1?mC
X_H2odnOm@?oDigd0omAV_<3oe2Hl@03oeVKlOmKVO3oFiW`00?oGiO^0omSU>/01?m[VN_oLYWXog:I
j?mbVNP4ogVHi0?oP9OO1?n9UmX5oi:Ge@CoVYO?1?nSVL/4ojbMb003ojbI`oncW/?o/ik300Co/ik3
0onhY<D3okZS`@Co`:[40_o3ZL04olNaa@;obkC30oo>^/L4om?0a`04om[8b?oIc<gofLc=omW<c@Co
g]?>00Cohmc?onOVd?oWi]3ohnSD0ooUl]D2on7ldP03oj_YU_oooooooooo03Cooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`06ooooo`00;_ooool2o`0005Sooooo1?mg[?@3ogF]m@Co
Ljgf0om`[OL4off]m`03ofV]n?mXZoOoI:[h00?oI:[h0omOZOP3oeZWm`;oE:Cg1?mCX_H3odnOm@03
od^Km?mCWOCoDI[c00;oDI[c0om@V?43oe6El0?oGiO^0omSU>/3ofVCi`04og:Ij?miV>CoNISTogVH
i0CoP9OO1?n9UmX4oi:Ge@CoVYO?1OnSVL/00on/WLSo[9W3ojbI``02ojbI``Ko/ik300?o^:C5okZS
`OnjXl400_njXl43ol2Za0?o`jW00oo7/LD4ol^d``03oljjaooC`<Oodl3700?odl370_oJb<P00ooI
c<gog]?>omkCcP02omkCcP;ohmc?0_oWi]02onWac`04onGbeOoQo=;ohOcBoj_YUSOooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`06ooooo`00<?ooool00ol0003oooooooooo`1Foooo
o`CoMjcd0ome[OD4og>]mP?oL:gg1?m][OL2ofV]n0CoI:ch0omNZ_P2oeRXn004oeZWmomDY?OoE:Cg
oeBTm`?oCj7f0_m8WOD00om?WoGoBi_dod^Km002odNHlP04oe6Jlom@V?7oD9Saoe2Hl@?oDIG`0_mC
T^d01?mOUnkoHiC[of>DjomSU>/3ofVCi`?oLI7S00?oNISToh2Ggon0Uml00_n0Uml3ohVGfPCoTYOE
1OnJUll2oj>Ib`;oXYC61On/VL<5ok>N``03ok>I_OnjXl7o^Z?100Co^Z?100?o`:[4ol>Y`?o3ZL00
0oo3ZL000oo7/LGobkC3ol^d``03ol^d``Godl370ooJb<P01?oOd<Wog]?>omkCc_oNdlh2on?Lc`?o
inK@0_oYlLl2onKkb`03omSm_?oooooooooo03Oooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`05ooooo`00<Oooool00ol0003oooooooooo`1Fooooo`CoNZgc0omh[_D4ogJ_mP?oLZog
1?m_[oP2ofZ_n@CoI:ch0omNZ_P3oeRXn0CoDJGg00?oBJ7fodnQm_m8WOD00_m8WOD2od:Il`?oAiSb
0_m5U?401?m@V?7oDIG`oe6El?mAUO02oe>Bk@?oEXo[00CoHiC[ofVCiomYTnOoJI?W0omaTN<4ogV@
g@?oPhoG00?oRIOJoi:GeOnBUmD00_nBUmD2oiZGc`;oUY3;1OnRU<H4ojbI``?o/ik31?ncVKd5okZS
`@Ko`jW01_o;]<<01?oB^/?odl37om?0aooC`<L4om[8b0;ogm3900?og]?>on?LcooSg<l00ooWi]02
onWac`;oi__;00?of?flooooooooool0>Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00Gooooo000booooo`03o`000?oooooooooo05Kooooo1?mj[O<3ogR^m@CoMZof0omb[oL4ofn_
n0?oJZoi0omT[_T3oej/n@;oEZWi00?oF:Shoe6UmomAYOL00_mAYOL2odVQmP;o@9cd00KoB9geod:I
lom2VO?o@YWcocbDlOm7V?83odFDl@;o@i3_00?oDIG`oe>BkOmCT^d00omFSn/3oef=i`04ofVCioma
TN?oLI7Sog6Ah`CoNI3M0on3SmL4ohb?d@GoUY3;1?nRU<H5ojbI``03ok>N`oncVKgo/iVm00?o/iVm
1?njXl42okbO^`Go`jW000?ob:bnol^d`oo;]<<00_o;]<<3om:j``03om?0aooJb<Sof/S800;of/S8
0ooOd<T2onCIbP03on?LcooWi]3oinK@00;ojO7?0_oVnl/00ooHoKcoooooooooo`0kooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool01Oooool003?ooooo0_l0001Hooooo`?oOJkc0omk
[o@4ogR`mP?oMK7g1?ma/OP3ofban@;oIK3j00CoI:kioej/nOmN[?WoGZci1?mFZOT3odfVn0;o@j7f
0om0W?@2ocNGlP03od:IlollU?7o?9Ca00;o=Xo_00CoAICaod>@kom3T>oo@i3_0_m4S>d3oeJ?j`?o
GHgW0omTR^801?maTN?oNI3MogV@gOmiT=d4oh>?e`CoS8oA1?nFT</4oj:DaPCo[9W300?oZi6kok>I
_OncVKd01?ncVKd3okZS`@?o_9nk1?o3ZL02olR/_P?obkC31?oB^/<01?oJa<Cof/S8om[8b?oJb<P4
omo@b@;oi=W:00CojN?;onOVd?oYlLoojO7?0_oVnl/2omSm_3gooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`05ooooo`00=Oooool00ol0003oooooooooo`1Fooooo`?oOJkc0omk[o@4
ogR`mP?oMK7g1?ma/OP3ofban@CoIK3j1?mN[_X2oeF/n@;oBZOh00KoCJKhod>Qm_m3XOKo@j7focRK
lom0W?@3ocNGlP;o;Y3_0olfSnl2oc:9k@03od>@kom4S>goA8c]00;oAXSZ00CoEXo[oef=iomMSNOo
GHgW0omTR^82off8g@03ogV@gOn3SmOoPhoG00;oPhoG1?n<Sm44oiJ@b`GoXYC600?o[9W3oj^A^on[
TK/00_n[TK/6ok>I_@03okZS`OnlWk_o_9nk00;o_9nk0oo3ZL04olR/_P03ol^d`ooB^/?od[[300?o
d[[30_oJa<@00ooJb<Sogm39omo@b@02omo@b@?oi=W:00?ojN?;ong^bOo]k/T00_o/n<D2omkl]3oo
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`00=_ooool00ol0003ooooo
ooooo`1Fooooo`?oP;3c1?mn/O@4ogbbmPCoN;?h0omc/oT3ofjcnP?oIk?k1?mO/O/2oeB^nPCoBZOh
0olnX_D01?l_V_7o>9_cob^DkolgUo82obj@k`;o9HW/00Ko=Xo_oc:9kOlbRNgo<XW]oc24j_m4S>d2
odJ8jP;oC8GV00?oGHgWofB:h_mTR^800_mTR^83off8g@CoPhoG0on<Sm45oiJ@b`?oXYC600?oX8^m
oj^A^on[TK/00on[TK/6ok>I_@Ko_9nk00?o`jW0olR/__o8[;h00oo8[;h5om:j``?of/C400Coh<c5
omo@bOoOd<Wogm390ooTfLX2onWSb`;okNk90_o/n<D2omkl]43ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`05ooooo`00=oooool00ol0003oooooooooo`1Fooooo`?oP;3c1?mn/O@2
ogbbmP;oOkCf1?ml]OP3ogNfn@;oLKKk00CoK[?jofNcnomW/o_oIk?k1?mO/O/3oeB^nP?oAjWh0_li
Xo@00olnX_Go;i[aobnJl@02oanAj`03ob^DkolNRn_o9HW/00;o9HW/0_lLPNP00olbRNgo<8CZoc24
jP02odJ8jP?oC8GV0omTR^83off8g@CoNXSF0on4Qlh00on<Sm7oUY3;oiJ@b`02oiJ@b`03oj:Da_nP
RkgoX8^m00;oX8^m1On[TK/4ok>I_@;o/i2b1OnlWk/6olR/_P04om2c__oB^/?od[[3om:j``Cof/C4
0_oPc<D01?oOd<Woi=W:onCIb_oTfLX2onWSb`;okNk90_o/n<D2omkl]4;ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`05ooooo`00>?ooool2o`0005Oooooo0on4/O85oh:cm0?oOkCf
1?ml]OP3ogNfn@CoLKKk0omZ]_`4of6do0?oEK7k00?oAZchodNYn?liXo@00oliXo@01?lVVNko7i7[
oanAjolOTN/2o`f5h`03oaj;jolURNco787X00;o787X00Co57SToc24j_l_O^Oo;gkW0_m<QNH3oe>1
h@04ofB:h_m]R=goKHSMoff8g@CoNXSF0on4Qlh4oi:7a@GoX8^m1On[TK/3ok>I_@?o/i2b1?nlWk/2
ol:R^0Cob:bn0oo@/kh00ooB^/?of/C4om[4a002om[4a0?oh<c50_oUe<D00ooTfL[ojN?;onWSb`02
ong^b@;ok?S50_oNo;A3ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool0
03[ooooo00?o0000ooooooooool0EOooool3ohBalP;oP[?d0on6]O@3oh>fmPCoP;Sh0omk^OX4ogFj
n`CoKKWl1?mS^?d3oeNen`03odJ`n?m6[?So=:Cc00?o=:Cc00?o7iWZoa:>iOlOTN/00ol=QN<01?l0
N=[o0WKNo`9fg_lLPNP2oaAhi0;o;gkW00?o<GWTodb5i_mCPN400_mCPN42oeanf`03off8gOmjR=Ko
NXSF00;oNXSF1?n4Qlh4oi:7a@GoX8^m1On[TK/00oncVKgo/i2bok>@/P02ok>@/P?o_9nk0oo2X[P3
olR/_PCod;>n1?oJa<@4on3<a@;oiMC50_o[g/D00ooYhl_okNk9ong^b@02oncha@03omkl]?oooooo
oooo04?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`00>oooool00ol0
003oooooooooo`1Eooooo`CoR;?b1?n6]O@3oh>fmPCoP;Sh0omk^OX4ogFjn`;oKKWl0omb_Od3ofNl
o@;oF[[l00CoEkGkodJ`n?m6/?SoA[3h1?lbYo401_lIVNGo1X[Moa:>iOl0O]Wo3HGSo`1hfP?o0WKN
00Co06WGoaAhi?l@L>3o;gkW0_laNN@3oe>1h@?oG7kK0omjR=H4ohB7cPCoTXO51OnPRkd4oj^A^`03
ojV4[OncT;;o/i2b00Co/i2b00?o_9nkol:R^?o2X[P00oo2X[P00oo8[;kod;>nom2c_P03om2c_P04
omZo_ooJa<Cof/C4om[4a0?oh<c50ooUe<D2on_Na@05oo3Ya?o]k/Wok?S5onchaOoXnJh0Aoooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo000looooo`03o`000?oooooooooo
05Gooooo0_n8/o83ohbdl@?oR[Oc0on8^OH5ohBjn0?oOkcj1?mj_O`4og:mo@?oIkcm1?mJ^_`3odRd
n0Co<Z[_00So59[Po`27e?l6R]go07K<o`1nfOl0K<[o06S?o`9fgP;o06WG0_l@L>02oc5ii003ocMd
gomCPN7oG7kK00;oG7kK0om/O]<01?mjR=KoQ8O>ohB7c_n4Qlh4oi:7a@GoX8^m0on[TK/2ojV4[@Ko
/i2b1_o2X[P5om2c_P?of[no00Cof/C4on3<aOoPc<Goh<c50ooUe<D3on_Na@03oo3Ya?oalkoolO>o
00;oj?V^Aoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo000mooooo`;o
0000E_ooool5ohbdl@?oR[Oc0on8^OH2ohBjn0?oRKgh1?n5_oX4ogo1o0CoMl7n0om]`Oh4oenoo@;o
CKWh0omC`?T00olj]^ko=:o^oaFNg003oaFNg009o`1fc?l0GkGo06S?o`1G`_l0JMOo05g@oa1`h?l;
Im_o<GWT00;o=gCO0omLO]/3ofand`?oMGW900?oQ8O>oi:7aOnBQlD00_nBQlD5oj2;_@03oj^A^onY
Q:goZHB]00;oZHB]1OncT;800onmU:go`Z:hol:R^003ol:R^004olf/^?o@/kkod;>nom2c_PCof[no
00CohLS0on3<aOoPc<Goh<c50_oUe<D3on_Na@;ol>W40_oalkl00ooXnJkoooooooooo`17ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool003oooooo00?o0000ooooooooool0
E?ooool2ohbdl@?oT;K`0on?^?85ohbkm@?oRKgh1?n5_oX2ogo1o0?oQLCl1?mna_h3ogC6o`;oI/Gn
1?m_boh3oeg7nP;oA;k_1?mBb?42oc6gf`;o05O20_l0GM02o`]Wf`;o=gCO00?o?foIoeanfom/O]<0
0om/O]<3ogEib@?oRWNi00CoTXO5oj2;_OnPRkgoX8^m0_nLO:l5ojV4[@Co/i2b0_nmU:d4ol:R^0;o
cJbh0oo@/kh4omZo_`;ohLS000Coh<c5onGDaOoUe<GoiMC50_o[g/D2oo3Ya0;olO>o00?oj?V^okkV
Poooool0BOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo0010ooooo`03
o`000?oooooooooo05Cooooo1On@]_03ohnhlP;oS;_e0onA_O@4ohjom`CoR/;j0_n5a?`2ohc7o0Go
QL[n0omlbol2ofo;oPCoN]7o0_mYco/2ogOGo@?oQ]km0_meg?L2ooooo`04o`1G`_l0A[Ko05g@o`1>
a`;o35oG00?o=gCOocm_fOloKmT00om/O]<4ogEib@?oRWNi1OnLO:l5ojV4[@?o/i2b0onmU:d3ol:R
^0CocJbh00?od;>nomZo_ooJ_kl00_oJ_kl3on78`0;oi]3000CoiMC5on_NaOo[g/Gojmk50_o`jL@0
0ooalkooj?V^onSi[P1<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool0
047ooooo00?o0000ooooooooool0E?ooool2oi2fl0?oUKO_1?nC^_84oi6mm0;oS[og0_nD`_H5oi35
n@?oS<Ol0_n5b_h4ohg>o@;oQM3o0on>e?l2ohGGo`CoTMco0_n6g_d7ooooo`;o04Jf00Go04k7o`aO
eol<GmOo35oGocm_f@02oda/dP03ofandomeNLWoMGW900;oMGW91?n:MkT5oial[`GoZHB]0_ncT;84
okfD[@;o`Z:h1?o=[;P4omZo_`CohLS00_oVd<02oncI`003on_NaOo`jLCol>W400;olO>o00?oj?V^
omC[Qoooool0Boooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo0012oooo
o`;o0000EOooool5oiFgk`;oTk[b0_nH_?44oiJol`CoU<;f0_n@aOT3oiK7n0CoT/_k0_n=c_d4oiGA
o0;oS]Co0onHf?d2oi7Lo`gooooo00Co04Jfo`0cZOl<GmOo35oG0_l=Em43oda/dP?oMGW91?n:MkT5
oial[`GoZHB]00?o/i2bokfD[OnmU:d00onmU:d00oo2X[SocJbholf/^003olf/^004ombm^_oJ_koo
f[noomZo_`?ohLS00ooVd<02oncI`0;olN>n00Col>W4oo7c_ooamJcoe>^7C_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00?ooooo0014ooooo`03o`000?oooooooooo05?ooooo0_nE
]nl3oiVikPCoV;ca1?nF_o<2oiC2mP?oVLCe1?nFaoP2oi;;n`?oVLgj0_nEdO`4oicCn`;oV=Sm4_oo
ool00ol0<jWo046oo`aOe`02o`eGd@;oC6cB0_lmE/<2ogEib@?oRWNi1OnLO:l5ojV4[@Ko_IB]1Oo=
[;P3ombm^P04omZo_ooQb<3ohLS0on78`0?oi]300oo/fL02oo7S_P03ooC/^_oamJcolOF/053ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`00AOooool00ol0003ooooooooo
o`1Dooooo`CoVKW^0_nH_?42oifmk`GoVl7b0_nIa?D2oik6m0GoW<Wg0_nIcOX3oj3?n0;oW=?k6?oo
ool01?l0@Koo3EOAo`eGdOl=Em42oda/dP;o?EK300?oMGW9ohYg^On:MkT00_n:MkT4oial[`GoZHB]
1_nmU:d01?o?Xj_ocJbholf/^?o=[;P4ombm^P04on?6^ooQb<3ohLS0on78`0?oi]300_o/fL03oo7S
_P03ooC/^_oamJcoe>^7057ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03oooo
o`00A_ooool00ol0003oooooooooo`1Dooooo`CoWK[]1?nM_Nl2oi_1lP?oX<;a1?nNa_@2oic9m`Co
X/_e0_nPcoPLooooo`05o`0QW?l=Em7o3EOAo`];bOm<K=800olmE/<4ohYg^@CoW7b_1?nYQ:d2ok67
Z@Co_IB]0_o?Xj/3olf/^0Cog;fj0_oSa[/01?oQb<3oi]30onK@`?oVd<03oncI`0;olN>n00?om>bj
oo7e[?oamJ`0D_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo0017oooo
o`03o`000?oooooooooo05Cooooo1?nM^^d2oifmk`;oXKk^1OnP`_42oik6m0?oXlOb0_nRboDQoooo
o`05o`0QW?l0<KKo3EOAo`];bOm<K=800olmE/<3ohYg^@GoW7b_0_nYQ:d3ok67Z@Co_IB]0oo?Xj/0
0oo=[;Sog;fjombm^P02ombm^P?ohlJk00?oilflonK@`?oVd<000oo/fL03oo7S_P03ooC/^_oamJco
_M5I05?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`00B?ooool2o`00
05Kooooo1?nR^n/3oj6nkP;oX<;a1?nU`nl2oj?7lRKooooo00?o036fo`];bOl;BlT00olmE/<2og5V
]P;oRWNi1?nLO:l00onYQ:go/HNYok67Z@02ok67Z@?o_IB]1?o?Xj/4ombm^PCohlJk0_oWcK`00ooV
d<3ok=W0oncI`003oo7S_P03ooC/^_oamJcoe>^705Gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`03ooooo`00B_ooool00ol0003oooooooooo`1Dooooo`;oX[_[0_nV_>T4ojG0k0;o
YL?_:oooool00ol0<KKo2d_9o`];b@02oceF``CoLFJf0_nLO:l2oi]i[0Go/HNY0onmU:d4olnSZ`04
onNmZooL_K[og;fjombm^P?ohlJk0ooWcK`2oncD_003oncI`?oahkkolN>n00;om>bj00?olOF/okgA
FOooool0EOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo001;ooooo`03
o`000?oooooooooo05Cooooo1?nV_>T2ojG0k2oooooo00?o01NRo`];bOlmE/<00_lmE/<3og5V]PCo
VgV/1_naQjT00onmU:gocj>[olnSZ`02olnSZ`?oikf[00?og;fjon?6^ooSa[/00_oSa[/3onO=_0;o
k=Bl0_oafkX01Ooahkkom>bjooC/^_ocl9go_M5I05Kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`02ooooo`00C?ooool00ol0003oooooooooo`1Dooooo`;oY[cY<oooool01?l05j;o
2d_9oceF`olmE/<3og5V]PGoVgV/1OnaQjT00onmU:gocj>[olnSZ`02olnSZ`?oikf[1?oSa[/3onO=
_0?ok=Bl0_oafkX2ooGS]`03ooS^[OnmdEWooooo05Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`02ooooo`00COooool2o`0005Cooooo00?o0000ooooooooool0<oooool00ol05j;o
00JHoceF``04og5V]PCoVgV/1OnaQjT5olnSZ`?oikf[00?oklV/on?6^ooSa[/01?oWcK`2oncD_0?o
lM^j0_oehkL00oocl9go_M5Iooooo`1Hooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00_ooool004oooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0dooooo`03o`0G
X_lmE/?oLFJf00?oLFJf1?nKNJ`5ok67Z@04ol>HZoo?Xj_ocj>[olnSZ`?oikf[0oo_bJ`01?oSa[_o
ilflonO=_?oWcK`3oncD_0;olM^j0_oehkL00oohkZgolo2Mooooo`1Iooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00_ooool0053ooooo00?o0000ooooooooool0D?ooool00ol0003o
ooooooooo`0eooooo`03o`06V?lmE/?oLFJf00;oLFJf1?nKNJ`4ok67Z@;o`iR[0oo?Xj/3onNmZ`?o
klV/00?okLR^onO=_?oWcK`00oo/e;`3oo7K^P;omN>g00?on>j]okgAFOooool0F_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo001Aooooo`03o`000?oooooooooo04oooooo
00?o0000ooooooooool0=Oooool00ol007_o00JHog5V]P02og5V]PCoVgV/1?naQjT2ol>HZ`;ocj>[
1?oW_J/3ono9[0;okLR^00?oilfloncD_?o/e;`00ooafkX2ooGS]`03ooS^[Oocl9goomB>05cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`00D_ooool2o`0004oooooo00?o
0000ooooooooool0=_ooool01?l01YSo;4>gog5V]_maI[H5oi]i[0;o/HNY1?o3V:/01?o?Xj_oikf[
onNmZooW_J/3ono9[0?okLR^0_o_bjh00oo/e;colM^joo7K^P02ooGS]`;on>j]0_ooe8iMooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool005Cooooo00?o0000ooooooooool0
C?ooool00ol0003oooooooooo`0gooooo`04o`06V?l/@kOoLFJfog5V]PCoVgV/00?o/HNYol>HZoo3
V:/00oo3V:/01?o?Xj_oikf[onNmZooW_J/3ono9[0?okLR^0_o_bjh2oo7=[003oo7K^_oehkOomN>g
00;on>j]00?oomB>ooooooooool0G?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
007ooooo001Eooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0=oooool01?l01YSo
;4>goba3]omaI[H4oi]i[003ok67ZOo3V:_o`iR[00?o`iR[0ooW_J/3ono9[0?okLR^0oo_bjh2oo7=
[0;om<nY0_ohdj@00oobaZ?oomB>ooooo`1Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00Oooool005Kooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0hooooo`?o
;4>g0_nKNJ`2oif2]@Ko`iR[00?oi;naonNmZooW_J/00oo_bJ`3ong8[P;okl^^0ooacJ`2ooC?Z@;o
n=>T00?ol/JSoooDS_ooool0Goooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo007o
oooo001Gooooo`;o0000B_ooool00ol0003oooooooooo`0hooooo`03o`06V?l/@kOo;4>g00CoWH:e
1Oo3V:/3onBo/@04onNmZoo_bJcoklV/ono9[0;okLR^0oo_bjh2oo7=[0;om<nY0_ohdj@00oobaZ?o
omB>oooDSP1Qooooo`05o`000?ooooooooooooooool000000oooool005Wooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`0iooooo`;o;4>g1OnMP[D4ol>HZ`?oi;na00?ol=:dono9[?o_
bJ`00oo]b:h3ono;[P;olLf/0_odcjT2ooSCY003oo;6Xoooe8koomB>067ooooo00Go0000oooooooo
ooooooooo`000003ooooo`00F_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo03[o
oooo0ol/@kL4oif2]@?o`iR[1?oT_k42oo3B]004ono9[?o]b:kokLR^ong8[P;okl^^0ooacJ`2ooC?
Z@;on=>T00?ol/JSoooDS_ooe8h0H_ooool01?l0003oooooooooool00003ooooo`00Foooool00ol0
003oooooooooo`14ooooo`03o`000?oooooooooo03_ooooo0_l/@kL4oif2]@?o`iR[0ooT_k43oo3B
]003on[<]_o]b:kokLR^00?okl^^0_oacJ`2ooC?Z@;on=>T0_obaZ<00oooe8koooooooooo`1Roooo
o`03o`000?oooooo000000?ooooo001Looooo`;o0000A?ooool00ol0003oooooooooo`0looooo`03
oba3]onMP[GoWH:e00;oWH:e0oo3V:/3onBo/@?ol=:d0_oZc;H00oo]b:kokl^^ono;[P03oo7=[0;o
m<nY0_ohdj@2oo;6X`03oooDS_oooooooooo06;ooooo00Co0000oooooooooooo00000_ooool005ko
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0looooo`03oba3]onMP[GoWH:e00?o
WH:e00Co`iR[onBo/OoT_k7oi;na0oo`d[@3on[<]P03onW9]_o_bjkokl^^00;olLf/0oodcjT2ooSC
Y003oo;6Xoooe8koomB>06Gooooo00?o0000ooooool000000_ooool005oooooo00?o0000oooooooo
ool0@?ooool00ol0003oooooooooo`0mooooo`03oba3]onMP[GoWH:e00;oWH:e00Co`iR[onBo/OoT
_k7oi;na0oo`d[@3on[<]P;ojLVf00?okl^^oo7=[?oacJ`00_odcjT2ooSCY0;ol/JS0_ooe8iVoooo
o`;o00000_ooool0063ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0nooooo`;o
WH:e0_nV/^44onBo/@;ol=:d0ooZc;H3onW9]P;oj/Zd00?olLf/ooC?ZOodcjT00_ohdj@2oo;6X`;o
omB>IOooool3o`0000;ooooo001Qooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
?_ooool5ojJbh@;oi;na0oo`d[@3on[<]P?ojLVf0_oZb[@2onc:/P03ooC?ZOohdjCon=>T00;ol/JS
0_ooe8iQooooo`Co00001Oooool006;ooooo0_l0000nooooo`03o`000?oooooooooo03oooooo1OnV
/^400ooT_k7ol=:doo3B]004on[<]P;ojLVf0ooZb[@2onc:/P;ok/^^0oobaZ<00oooe8kooooooooo
o`1Mooooo`?o00002Oooool006Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`10
ooooo`;oY[;Q1?nMeo`01?o`d[Coj/bfon[<]_oZc;H3onW9]P;oj/Zd0oo/b[82onk;[P04omb^Z?ob
aZ?oomB>oooDSU_ooooo1?l0000<ooooo`00IOooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo04;ooooo0_nMeo`4ojC9l`;oj/bf0ooYbKH2on[:]0?ok<Zb0_o^bjh2omb^Z003oooDS_of
bIkooooo05Kooooo1?l0000@ooooo`00I_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo04?ooooo1_nTbO<00ooZc;KojLVfonW9]P03on[:]0;ok<Zb0_o^bjh3omb^Z0;om/VNDoooool4
o`0001Cooooo001Wooooo`;o0000>Oooool00ol0003oooooooooo`14ooooo`?oY<Wc0onUaO02onW9
]P;oj/Zd0oo/b[82onk;[P?og:jX0_ofbIi?ooooo`Co00006?ooool006Wooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`15ooooo`KoYLG`00?ojLVfon[:]?oZb[@00oo/b[82onk;[P?o
g:jX00?om/VNooooooooool0Boooool3o`0001cooooo001Zooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool0A_ooool3ojG5l0?oY<Ka0_oZb[@2onc:/P;ok/^^0ooL[ZP2ooK9WTWooooo
1?l0000Oooooo`00Joooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo04Oooooo1_nT
a_43onc:/P;ok/^^0ooL[ZP2ooK9WTGooooo1?l0000Sooooo`00K?ooool2o`0003Cooooo00?o0000
ooooooooool0B?ooool3ojC6l@?oY<Sc0_o/b[82onk;[P?og:jX0_ofbIi1ooooo`Co00009oooool0
06kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`19ooooo`KoY<Sc0_o^bjh4omb^
Z003ooK9W_oooooooooo03cooooo1?l0000[ooooo`00Koooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo04[ooooo0onTb?<2oj?<mP;ok/^^0ooL[ZP2ooK9WS_ooooo0ol0000_ooooo`00
L?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04_ooooo1OnSc?H01?o^bjkog:jX
omb^Z?oL[ZP2ooK9WSOooooo1?l0000booooo`00LOooool2o`0002oooooo00?o0000ooooooooool0
C?ooool2oj?<mP;oXiG71?oL[ZP00oofbIko0000ooooo`0booooo`Co0000=_ooool007?ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`1<ooooo`GoXiG70ooL[ZP00oofbIkooooooooo
o`0^ooooo`Co0000>_ooool007Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1=
ooooo`GoXiG70_oL[ZP00oofbIkoooooooooo`0Zooooo`Co0000?_ooool007Gooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`1>ooooo`GoXiG70_ofbIhYooooo`?o0000@_ooool007Ko
oooo0_l0000Yooooo`03o`000?oooooooooo053ooooo0_nSULL3oi[JoBKooooo1?l00015ooooo`00
N?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo053ooooo1?nJf_dSooooo`Co0000
BOooool007Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Aooooo`03oi[JoOoo
oooooooo01oooooo1?l0001=ooooo`00N_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo073ooooo0ol0001Aooooo`00Noooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
06cooooo1?l0001Dooooo`00O?ooool2o`0002?ooooo00?o0000ooooooooool0J?ooool4o`0005So
oooo001nooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0I?ooool4o`0005cooooo
001oooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0H?ooool4o`00063ooooo0020
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0GOooool3o`0006Cooooo0021oooo
o`;o00007_ooool00ol0003oooooooooo`1Iooooo`Co0000Ioooool008?ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`1Eooooo`Co0000Joooool008Cooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`1Aooooo`Co0000Koooool008Gooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`1=ooooo`Co0000Loooool008Kooooo0_l0000Iooooo`03o`000?oooooo
oooo04[ooooo0ol0001gooooo`00R?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
04Kooooo1?l0001jooooo`00ROooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04;o
oooo1?l0001nooooo`00R_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03kooooo
1?l00022ooooo`00Roooool2o`0001Cooooo00?o0000ooooooooool0>oooool3o`0008Kooooo002=
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0=oooool4o`0008Wooooo002>oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<oooool4o`0008gooooo002?ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0;oooool4o`00097ooooo002@ooooo`;o0000
3oooool00ol0003oooooooooo`0[ooooo`Co0000UOooool009;ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Xooooo`?o0000VOooool009?ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Uooooo`Co0000W?ooool009Cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Qooooo`Co0000X?ooool009Gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Mooooo`Co0000Y?ooool009Kooooo0_l00008ooooo`03o`000?oooooooooo01Wooooo
1?l0002Xooooo`00V?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo0ol0
002/ooooo`00VOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo1?l0002_
ooooo`00V_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0002coooo
o`00Voooool2o`0000?ooooo00?o0000ooooooooool02_ooool4o`000;Oooooo002Mooooo`04o`00
0?ooooooooooo`0000Sooooo1?l0002kooooo`00W_ooool00ol0003oooooo`000005ooooo`?o0000
_oooool009oooooo0_l000000ooooooo0000o`000002o`000<;ooooo002Pooooo`;o0000a_ooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.875, 0}} -> {-0.0894212, 0.00543257, \
0.00364432, 0.00364432}}],

Cell["Fig. 6.10 Exercise (15).", "Caption",
  CellTags->"Fig. 6.10"],

Cell[TextData[{
  "(16)",
  StyleBox[" A wire with square cross section is defined by ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[
              StyleBox[\(\(-1\) < x < 1, \(-1\) < y < 1\),
                FontWeight->"Plain"], TraditionalForm]]]]], 
        TraditionalForm]]],
  ". ",
  StyleBox["It is held at fixed temperature ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(T\_o\),
          FontWeight->"Plain"], TraditionalForm]]],
  StyleBox[", and is embedded in insulation with thermal diffusivitiy ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox["\[Chi]",
          FontWeight->"Plain"], TraditionalForm]]],
  ", ",
  StyleBox["also in the shape of a square  ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(-2\) < x < 2, \(-2\) < y < 2\),
          FontWeight->"Plain"], TraditionalForm]]],
  ". ",
  StyleBox["The surface of the insulation is at temperature ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(T\_1\),
          FontWeight->"Plain"], TraditionalForm]]],
  ". ",
  StyleBox["Find and plot as a surface plot the equilibrium temperature ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(T(x, y)\),
          FontWeight->"Plain"], TraditionalForm]]],
  " ",
  StyleBox["in the insulator, using simultaneous overrelaxation.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  StyleBox["(17)",
    FontWeight->"Bold"],
  " The bottom a cubic box has a pyramidal cusp. The box walls are defined by \
the equations ",
  Cell[BoxData[
      \(TraditionalForm\`z = 1, y = 0, y = 1, x = 0, x = 1, 
      z = x\ \((for\ x < 1/2)\), \ z = y\ \((for\ y < 1/2)\), 
      z = 1 - x\ \((for\ x > 1/2)\), z = 1 - y\ \ \((for\ y > 1/2)\)\)]],
  " .  The potential on the pyramidal cusp is held fixed at ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(V\_0\), "=", 
            RowBox[{"2", " ", 
              StyleBox["V",
                FontSlant->"Plain"]}]}], ","}], TraditionalForm]]],
  " but the potential on the other box walls is zero. Using the direct method \
in three dimensions on a 10-by-10-by-10 grid, solve for the potential \
everywhere inside the box. Plot the result for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, 1/2, z)\)]],
  " as a contour plot."
}], "Text"],

Cell[TextData[{
  StyleBox["(18)",
    FontWeight->"Bold"],
  " It is easy to convince oneself that it is not possible to find any \
rectangular grid that will fit the  grounded triangular enclosure shown in \
Fig. ",
  ButtonBox["6.11",
    ButtonData:>"Fig. 6.11",
    ButtonStyle->"Hyperlink"],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`a = 1, b\  = \ 1, \ c = \@3\)]],
  ". One can either content oneself with an order-",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " approximation to the solution using the methods discussed in Sec. ",
  ButtonBox["6.2.2",
    ButtonData:>"c:22",
    ButtonStyle->"Hyperlink"],
  ", or else attempt to find a better way of matching the boundary \
conditions. One way to do so is as follows. Choose the grid so that the \
bottom and left sides fall on the grid. This requires that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["y",
                FontSlant->"Italic"]}]], "=", \(b/M\_y\)}], 
        TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], " ", "=", " ", \(a/P\)}], 
        TraditionalForm]]],
  "  for integers ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`M\_y\)]],
  ". With these choices, the grid in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " must run out to ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(x\_j\), "=", 
            RowBox[{"j", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}]}], ",", "  ", 
          RowBox[{"j", Cell[TextData[{
              "=0,1,2,...",
              Cell[BoxData[
                  \(TraditionalForm\`M\_x\)]],
              " "
            }]]}]}], TraditionalForm]]],
  " where ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(M\_x\), "=", 
          RowBox[{"Ceiling", "[", 
            RowBox[{"c", "/", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}], "]"}]}], TraditionalForm]]],
  " . However, the right side of the triangle does not fall on the grid."
}], "Text",
  CellTags->"i:62"],

Cell[TextData[{
  "\tSince we wish to set the potential on the right side of the triangle \
equal to zero, we will use the following averaging technique. The equation \
for the triangle's right edge is ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_R\)(y) = \(-\((c - a)\)\) y/b\  + \ c\)]],
  ". For each value of ",
  Cell[BoxData[
      \(TraditionalForm\`y\_k\)]],
  " on the grid, this edge cuts between grid points ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(j + 1\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(j\)\(=\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`g(k)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g(k)\)]],
  " is given by Eq. ",
  ButtonBox["(6.2.37)",
    ButtonData:>"(6.2.37)",
    ButtonStyle->"Hyperlink"],
  ". The zero of potential should fall at ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_R\)(y\_k)\)]],
  ", not at ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(j + 1\)\)]],
  ". If we assume that the potential varies linearly between the grid points, \
this implies that  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0", " ", "=", " ", 
          RowBox[{
            RowBox[{
              SubscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], 
                "2"], \(\[Phi]\_\(\(j\)\(\ \)\(k\)\(\ \)\)\)}], "+", " ", 
            RowBox[{
              SubscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "1"], 
              " ", \(\[Phi]\_\(j + 1\ k\)\)}]}]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`j = g(k)\)]],
  ", and where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], "2"], " ", "=", 
          " ", \(x\_\(j + 1\) - \(x\_R\)(y\_k)\)}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], "1"], 
          "=", \(\(x\_R\)(y\_k) - x\_j\)}], TraditionalForm]]],
  " (see the figure)."
}], "Text"],

Cell[TextData[{
  "\tTherefore the interior points are defined by ",
  Cell[BoxData[
      \(TraditionalForm\`0 < k < M\_y\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`0 < j \[LessEqual] \ g(k)\)]],
  ", with the points ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(g(k) + 1\ k\)\)]],
  "defined in terms of the interior points by"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[\(\[Phi]\_\(g(k) + 1\ k\)\),
              "TraditionalForm"], "=", 
            RowBox[{
              RowBox[{"-", 
                SubscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], "1"]}], 
              RowBox[{\(\[Phi]\_\(\(g(k)\)\ k\)\), "/", 
                SubscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], "2"]}]}]}]}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "Implement this procedure and solve for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y)\)]],
  "using the direct method, assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]/\[Epsilon]\_o = x\)]],
  " and taking  ",
  Cell[BoxData[
      \(TraditionalForm\`M\_y = \(P = 10\)\)]],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .35156 
%%ImageSize: 1280 450 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000744048 0.00837054 0.000744048 [
[ 0 0 0 0 ]
[ 1 .35156 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .35156 L
0 .35156 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .00837 translate
.95238 .33482 scale
3840 string
1280 450 8 [1280 0 0 450 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFF000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
0000000000000000000000000000000B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
0000000000000000000B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
0000000B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
0000000000000B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000000000000B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0EFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{321.875, 113.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006B0000SB000`400?l00000o`00003ooooooonC
ooooo`00oooooonCooooo`00oooooonCooooo`00oooooonCooooo`002_oooooo0?ooogd0oooo3?oo
ool000[oooooo`3ooomm0?ooo`cooooo000:ooooool0ooooO@3oool<ooooo`002_oooom80?ooo`80
ZZZZo`3ooolc0?ooo`cooooo000:ooooodH0oooo00H0eMGE030`<010@400P820071`L03Zj^[o0?oo
oc40oooo3?ooool000[oooooAP3oool00`0i>CT0@4100?ooo`020?ooo`0308j>SP3oool0oooo0?l0
oooo;`3oool<ooooo`002_oooom60?ooo`030000002_[jl0oooo0?l0oooo=03oool<ooooo`002_oo
oom60?ooo`0301`L702o_kl0oooo0?l0oooo=03oool<ooooo`002_oooom60?ooo`04075aL@2ZZZX0
oooo0?ooo`80ZZZZo`3ooola0?ooo`cooooo000:ooooodL0oooo00D0L71`0>[ZjP3oool0<30`09FE
U@3o0?oooc40oooo3?ooool000[oooooB03oool00`36a/H0ZZZZ0=GEe@3o0?oooc80oooo3?ooool0
00[oooooo`3ooomm0?ooo`cooooo000:oooooa<0oooo00<0_kno0820P03oool0G`3oool00`2ZZZX0
[jn_0?ooo`3o0?ooo`D0oooo3?ooool000[ooooo403oool00`3Shn<0P82000000002000000030>?S
h`3oool0oooo05d0oooo0`0000000`1ZJVX0a/K60?ooo`3o0?ooo`80oooo3?ooool000[ooooo3P3o
ool00`2EUID0>CTi000000040000000308j>SP3oool0oooo05`0oooo00<0ZZZZ0000000000000`00
00000`0L71`0P8200>?Sh`3o0?ooo`cooooo000:ooooo`X0oooo00<0j^[Z09FEU@1@D50020000000
0`1EEED0oooo0?ooo`1L0?ooo`0305EEE@000000000000H0000000<0@410092@T03De=@0o03oool<
ooooo`002_ooool80?ooo`030:ZZZP10@400000000X0000000<0>CTi0:ZZZP2ZZZX0G02ZZZX00`0i
>CT00000000000090000000302/[:`2>SXh0hn?S0?T0oooo3?ooool000[ooooo1`3oool00`2ZZZX0
LG5a0000001g0000000303Ti>@2ZZZX0j^[Z0?P0oooo3?ooool000[ooooo2@3oool0103_knl0ZZZZ
05EEE@0@41080000000305EEE@3oool0oooo05`0oooo00<0EEEE0000000000001`0000000`0`<300
UIFE0=oOg`3k0?ooo`cooooo000:ooooo``0oooo00<0j^[Z08j>SP0E5AD01P0000000`2>SXh0oooo
0?ooo`1L0?ooo`030:ZZZP000000000000@0000000<05ADE075aL@3Shn<0a`3oool00`1aLG40hn?S
0?ooo`0d0?ooo`cooooo000:ooooo`l0oooo00<0_kno06][J`0P82000`0000000`3EeMD0oooo0?oo
o`1L0?ooo`070=GEe@00000000000000000@4100EEEE0:ZZZP390?ooo`030820P0000000ZZZZ03D0
oooo3?ooool000[ooooo4P3oool00`36a/H0LG5a06YZJP1P0?ooo`03075aL@1ZJVX0ZZZZ0</0oooo
00<0hn?S01DE5@1aLG40=P3oool<ooooo`002_oooooo0?oood@0oooo00<0EEEE01DE5@3Shn<0=P3o
ool<ooooo`002_oooooo0?oood<0oooo00<0UIFE0000002@T900=`3oool<ooooo`002_oooooo0?oo
od80oooo00<0j^[Z0000000i>CT0>03oool<ooooo`002_oooooo0?oood80oooo00<0JVYZ00000036
a/H0>03oool<ooooo`002_oooooo0?oood40oooo00<0_kno0000002EUID0>@3oool<ooooo`002_oo
oolY0?ooo`070:ZZZP000000>CTi0=GEe@0L71`0>CTi0>[ZjP3o0?oooa40oooo00<071`L0410@03o
ool0>@3oool<ooooo`002_oooolY0?ooo`0700000020P800oooo06YZJP000000oooo0>[ZjP3o0?oo
oa00oooo00<0LG5a0000002ZZZX0>P3oool<ooooo`002_oooolY0?ooo`050410@02_[jl0oooo0;no
_`000000o`3ooolA0?ooo`030;no_`000000EEEE03/0oooo3?ooool000[ooooo:P3oool01020P800
a/K60;no_`00003o0?oooa40oooo00<0:b/[01`L703oool0>`3oool<ooooo`002_ooool[0?ooo`03
0>?Sh`20P80000000?l0oooo403oool00`2>SXh000000<K6aP0l0?ooo`cooooo000:ooooobT0oooo
00D0JVYZ092@T03oool0_kno01DE5@3o0?ooo`l0oooo00<0gmoO01DE5@1PH600?@3oool<ooooo`00
2_oooolY0?ooo`050>?Sh`20P800ZZZZ05EEE@2ZZZX0o`3oool?0?ooo`0305EEE@000000j^[Z03d0
oooo3?ooool000[ooooo4`3oool00`2o_kl0L71`0410@00g0?ooo`040=oOg`10@400P8200<o?cnX0
oooo00<0ZZZZ0000002ZZZX0?P3oool<ooooo`002_ooool@0?ooo`030<K6aP1ZJVX0000000<00000
00<0ZZZZ0?ooo`3oool0=03oool01`2o_kl0000000000000000071`L0820P03Shn<0iP3oool00`3S
hn<071`L05EEE@0o0?ooo`cooooo000:ooooo`h0oooo00<0UIFE01`L700000001@0000000`1aLG40
oooo0?ooo`0d0?ooo`030:ZZZP000000000000@0000000<0>CTi0:ZZZP3oool0h`3oool00`1EEED0
00000;no_`0o0?ooo`cooooo000:ooooo`X0oooo00<0e=CD09FEU@1@D5002@0000000`1EEED0oooo
0?ooo`0d0?ooo`030820P0000000000000H0000000@05ADE05EEE@2PX:00j^[Zg`3oool00`2`/;00
000006YZJP100?ooo`cooooo000:ooooo`L0oooo00<0hn?S08j>SP0[:b/0300000000`0L71`0EEEE
05EEE@0d05EEE@0301DE5@000000000000X0000000<0@4100:ZZZP3oool0g03oool00`0[:b/0>CTi
0?ooo`100?ooo`cooooo000:ooooo`T0oooo00<0P82003Ti>@0000002P0000000`0L71`0EEEE05EE
E@0d05EEE@0301DE5@000000000000T0000000<0>CTi0:ZZZP3oool0g03oool00`2>SXh000000<K6
aP110?ooo`cooooo000:ooooo`/0oooo00<0j^[Z092@T00[:b/0200000000`1EEED0oooo0?ooo`0d
0?ooo`03051@D0000000000000H0000000<0@4100820P03Ogml0gP3oool00`2o_kl00000071`L012
0?ooo`cooooo000:ooooo`h0oooo00<0eMGE05EEE@0000001@0000000`2ZZZX0oooo0?ooo`0d0?oo
o`030820P0000000000000@0000000<0EEEE0=GEe@3oool0h03oool201`L70030>[ZjP3oool0oooo
0400oooo3?ooool000[ooooo4@3oool00`2o_kl0LG5a00000002000000030>?Sh`3oool0oooo03@0
oooo00H0eMGE0000000000000000075aL@2o_koS0?ooo`0309FEU@000000SXj>04<0oooo3?ooool0
00[ooooo4`3oool00`3Zj^X0T92@09FEU@0h0?ooo`80UIFE00<0gmoO0?ooo`3oool0hP3oool00`3Z
j^X0410@05EEE@140?ooo`cooooo000:ooooool0oooo=P3oool00`0i>CT05ADE0?ooo`140?ooo`co
oooo000:ooooo`/0oooo00D0a/K601DE5@000000:b/[0>?Sh`070?ooo`050>[ZjP0i>CT0000001`L
701aLG40203oool01020P80000000000001EEED80?ooo`050<K6aP0L71`0000001`L702o_kl0203o
ool0101EEED0000001DE5@1aLG480?ooo`0508j>SP0E5AD0000003Ti>@3Zj^X01`3oool01@3EeMD0
71`L0000000E5AD0ZZZZ00P0oooo00@0LG5a000000000000JVYZ203oool01@2>SXh071`L0000000i
>CT0hn?S00L0oooo00D0hn?S0410@0000000000009FEU@080?ooo`05075aL@000000000005EEE@3Z
j^X0Z03oool00`2o_kl0000009FEU@150?ooo`cooooo000:ooooo`X0oooo00<0_kno000000000000
0P0000000`0E5AD0ZZZZ0;no_`050;no_`03030`<000000000000080000000<0T92@0;no_`2o_kl0
102o_kl00`20P800000000000002000000030410@02o_kl0_kno00@0_kno00<0[jn_000000000000
0P0000000`0@4100eMGE0?ooo`050?ooo`030410@000000000000080000000<0UIFE0?ooo`3oool0
103oool00`2EUID000000000000200000003030`<03oool0oooo00@0oooo00<0j^[Z020P80000000
0`0000000`2`/;00oooo0?ooo`040?ooo`030410@000000000000080000000<0UIFE0?ooo`3oool0
103oool00`2`/;000000000000020000000301DE5@3Ogml0oooo00@0oooo00<0j^[Z02/[:`000000
0`0000000`2EUID0oooo0?ooo`040?ooo`03071`L000000000000080000000<0L71`0?ooo`3oool0
203oool00`2o_kl0oooo0?ooo`2K0?ooo`03030`<00[:b/0kno_04D0oooo3?ooool000[ooooo2P3o
ool00`1EEED000000000001>000000H0EEEE1@0000000`0L71`0EEEE05EEE@0405EEE@0302/[:`00
0000000000<0000000<0@41005EEE@1EEED00`1EEED00`0i>CT00000000000030000000501`L701E
EED0EEEE075aL@2o_kl00P3oool00`0[:b/00000000000020000000301DE5@3oool0oooo00P0oooo
00<05ADE0?ooo`3oool0VP3oool00`1aLG4000000>?Sh`160?ooo`cooooo000:ooooo`X0oooo00<0
EEEE0000000000000`0000000`2EUID0oooo0?ooo`030?ooo`030=GEe@000000000000<0000000<0
D51@0?ooo`3oool0103oool00`0[:b/0000000000003000000030;no_`3oool0oooo00<0oooo00<0
P8200000000000000`0000000`1oOgl0_kno0;no_`030;no_`030:ZZZP000000000000<0000000<0
5ADE0;no_`2o_kl0102o_kl00`0[:b/00000000000030000000309FEU@2o_kl0_kno00<0_kno00<0
Ogmo0000000000000`0000000`1PH600P8200820P0040820P0D0000000<05ADE0820P020P8001020
P8000`10@40000000000000300000003051@D020P800P82000<0P82000<0EEEE0000000000000`00
00001@0[:b/0P82001DE5@000000clo?0080oooo00<0820P0000000000000P0000000`0@4100oooo
0?ooo`070?ooo`030;no_`000000UIFE09X0oooo00<0_kno00000020P800A`3oool<ooooo`002_oo
ool:0?ooo`030:ZZZP000000000000<0000000<0SXj>0?ooo`3oool0103oool00`0[:b/000000000
00020000000309FEU@3oool0oooo00@0oooo00<0SXj>0000000000000P0000000`0L71`0oooo0?oo
o`040?ooo`030;no_`000000000000<0000000<0a/K60?ooo`3oool0103oool00`0i>CT000000000
000200000003075aL@3oool0oooo00@0oooo00<0SXj>0000000000000P0000000`0E5AD0oooo0?oo
o`040?ooo`030>?Sh`0E5AD0000000<0000000<0UIFE0?ooo`3oool0103oool00`0i>CT000000000
000200000003075aL@3oool0oooo00@0oooo00<0ZZZZ0000000000000`0000000`3EeMD0oooo0?oo
o`030?ooo`030>?Sh`0L71`0000000<0000000@0LG5a0=GEe@000000SXj>0`3oool00`1ZJVX00000
000000020000000305EEE@3oool0oooo00L0oooo00<0EEEE0000000i>CT0V@3oool0103Zj^X071`L
01`L703Zj^Y70?ooo`cooooo000:ooooo`/0oooo00L0ZZZZ01DE5@000000:b/[05EEE@000000_kno
00D0oooo00D0eMGE01`L700000000000075aL@080?ooo`0506YZJP00000000000410@03Shn<01`3o
ool01@2ZZZX071`L0000000L71`0ZZZZ00L0oooo00D0hn?S0410@00000000000075aL@080?ooo`05
08j>SP000000000001`L703EeMD01`3oool01@2o_kl071`L0000000E5AD0SXj>00L0oooo00D0hn?S
05EEE@000000000005EEE@080?ooo`0508j>SP000000000001`L7036a/H01`3oool02036a/H0@410
000000000000P8200?ooo`1EEED071`L103oool01P3Zj^X0EEEE000000000000>CTi0>[ZjPP0oooo
00D0hn?S00000000000000000>?Sh`2H0?ooo`030820P0000000ZZZZ04P0oooo3?ooool000[ooooo
303oool01`3?cll0_kno0=oOg`3oool0P820010@402o_kl01@3oool00`3Zj^X0_kno0=CDe00:0?oo
o`80_kno00<0kno_0?ooo`3oool01`3oool00`3De=@0_kno0=CDe0090?ooo`030>o_k`2o_kl0clo?
00X0oooo00<0clo?0;no_`3Zj^X02@3oool00`3De=@0_kno0<o?c`0:0?ooo`80_kno2P3oool00`3D
e=@0_kno0>[ZjP090?ooo`070=oOg`2o_kl0_kno0?ooo`2ZZZX0410@0=GEe@060?ooo`80_kno2P3o
ool01@20P8000000000000000000P82009L0oooo00<0j^[Z010@401ZJVX0B@3oool<ooooo`002_oo
oolA0?ooo`030820P0000000ZZZZ06X0oooo00<0j^[Z01`L701ZJVX04`3oool40000000301`L703o
ool0oooo09D0oooo00<0>CTi01DE5@3oool0B@3oool<ooooo`002_oooolB0?ooo`0305EEE@000000
UIFE06T0oooo00<0P8200000003Zj^X04P3oool00`2ZZZX0000000000003000000030;no_`3oool0
oooo09<0oooo00<0SXj>0000002EUID0BP3oool<ooooo`002_oooolC0?ooo`030:ZZZP0@4100P820
06L0oooo00<0j^[Z010@402ZZZX04`3oool00`1`L70000000000000300000003071`L03oool0oooo
0980oooo00<0clo?00000010@400B`3oool<ooooo`002_oooolD0?ooo`030;no_`000000EEEE06H0
oooo00<0>CTi0410@03oool04`3oool00`0[:b/00000000000030000000302/[:`3oool0oooo05P0
oooo00<0EEEE0820P03oool02`3oool0103Shn<0JVYZ05EEE@2EUIDX0?ooo`0305EEE@0L71`0hn?S
04/0oooo3?ooool000[ooooo5@3oool0102ZZZX0000006YZJP1EEED200000003075aL@3oool0oooo
00H0oooo00D0P820000000000000:b/[0>?Sh`070?ooo`050<K6aP0L71`000000000002o_kl0203o
ool0101ZJVX000000000001aLG480?ooo`050:ZZZP000000000001`L702o_kl01`3oool01@3EeMD0
71`L000000000000ZZZZ00P0oooo00@0SXj>000000000000EEEE203oool01@2ZZZX000000000000L
71`0ZZZZ00L0oooo00D0hn?S0410@0000000000006YZJP0C0?ooo`030>?Sh`000000000000D00000
00<0hn?S0?ooo`3oool0E`3oool00`1aLG40ZZZZ08j>SP0:0?ooo`030>?Sh`000000EEEE0080ZZZZ
00<0LG5a0>?Sh`3oool00P3oool00`2o_kl0a/K60?ooo`070?ooo`0308j>SP3Zj^X0oooo01D0oooo
00<0a/K60000002>SXh0C03oool<ooooo`002_oooolF0?ooo`030;no_`000000000000<0000000<0
H61P0?ooo`3oool0103oool00`2EUID00000000000020000000302/[:`3oool0oooo00@0oooo00<0
gmoO01DE5@0000000`0000000`3EeMD0oooo0?ooo`040?ooo`0306YZJP00000000000080000000<0
:b/[0?ooo`3oool0103oool00`2EUID000000000000200000003020P803oool0oooo00D0oooo00<0
<30`0000000000000P0000000`2PX:00oooo0?ooo`040?ooo`0306YZJP00000000000080000000<0
:b/[0?ooo`3oool0103oool00`2`/;00000000000003000000030=oOg`3oool0oooo00@0oooo00<0
@4100000000000000P0000000`20P800oooo0?ooo`0@0?ooo`0306YZJP000000000000D0000000<0
P8200?ooo`3oool0F03oool00`2o_kl05ADE0?ooo`090?ooo`030=GEe@0E5AD0oooo00<0oooo00D0
ZZZZ0?ooo`3oool0eMGE092@T00:0?ooo`03071`L03Zj^X0oooo01<0oooo00<0j^[Z01DE5@10@400
5`3oool00`3Zj^X0_kno0?ooo`0<0?ooo`030=CDe02o_kl0gmoO02@0oooo3?ooool000[ooooo5`3o
ool5000000030410@03oool0oooo00@0oooo00<071`L0000000000000`0000000`2ZZZX0oooo0?oo
o`030?ooo`0309FEU@000000000000<0000000<0EEEE0?ooo`3oool0103oool6000000H0oooo00<0
71`L0000000000000`0000000`2ZZZX0oooo0?ooo`030?ooo`030<K6aP000000000000<0000000<0
@4100?ooo`3oool0103oool6000000H0oooo00<0EEEE0000000000000`0000000`20P800oooo0?oo
o`030?ooo`030<K6aP000000000000@000004P3oool80000000301`L703oool0oooo05P0oooo00<0
_kno0000003oool02P3oool00`36a/H0UIFE0:ZZZP020:ZZZP0703Ti>@3oool0oooo01`L703Zj^X0
oooo0>?Sh`020:ZZZP080=GEe@36a/H0ZZZZ0:ZZZP36a/H0oooo0;no_`1aLG4D0?ooo`0303Ti>@00
0000eMGE01L0oooo00<0ZZZZ06YZJP0i>CT02`3oool00`1ZJVX0000005EEE@0205EEE@030>?Sh`3o
ool0oooo0080oooo00<0ZZZZ0?ooo`3oool01P3oool00`2o_kl0oooo0?ooo`0B0?ooo`cooooo000:
oooooaL0oooo1@0000000`10@400oooo0?ooo`040?ooo`0301`L70000000000000<0000000<0ZZZZ
0?ooo`3oool00`3oool00`2EUID00000000000030000000305EEE@3oool0oooo00@0oooo1P000006
0?ooo`0301`L70000000000000<0000000<0ZZZZ0?ooo`3oool00`3oool00`36a/H0000000000003
000000030410@03oool0oooo00@0oooo1P0000060?ooo`0305EEE@000000000000<0000000<0P820
0?ooo`3oool00`3oool00`36a/H000000000000400000140oooo00<0eMGE0000000000001`000000
0`36a/H0oooo0?ooo`1G0?ooo`030;no_`000000oooo00X0oooo00T0LG5a000000000000000003Ti
>@2ZZZX0oooo08j>SP1EEED00`3oool01P1ZJVX0>CTi0?ooo`3Shn<0000006YZJP<0oooo00<00000
0>[ZjP3oool04@3oool00`2o_kl00000075aL@0J0?ooo`0305EEE@2ZZZX0oooo00T0oooo00<00000
0>?Sh`3oool00P3oool01P36a/H0j^[Z0?ooo`3oool0LG5a0>?Sh`P0oooo00<0j^[Z075aL@3oool0
4P3oool<ooooo`002_oooolG0?ooo`03051@D000000000000080000000<0L71`0?ooo`3oool0103o
ool00`2EUID0000000000002000000030410@03oool0oooo00@0oooo00<0gmoO01DE5@0000000P00
00000`0@4100eMGE0?ooo`050?ooo`0306YZJP00000000000080000000<0@4100?ooo`3oool0103o
ool00`2EUID000000000000200000003030`<03oool0oooo00D0oooo00<0<30`0000000000000P00
00000`2`/;00oooo0?ooo`040?ooo`0306YZJP00000000000080000000<0@4100?ooo`3oool0103o
ool00`2`/;000000000000020000000301DE5@3Ogml0oooo00@0oooo00<0j^[Z0000000000000`00
00000`2EUID0oooo0?ooo`0@0?ooo`090>[ZjP2PX:00P82005EEE@000000@41006][J`2PX:00e=CD
05X0oooo00@0_kno0000003oool0gmoO1`20P800103Ogml0oooo0;no_`2@T9050?ooo`030410@02E
UID0oooo0080oooo00D0P82005EEE@3_knl0:b/[0410@0040?ooo`030410@02_[jl0oooo0140oooo
00<0<30`02/[:`3Zj^X06P3oool00`1EEED0P8200?ooo`090?ooo`03092@T03EeMD0oooo0080oooo
00D0e=CD0;no_`3oool0T92@0:ZZZP0:0?ooo`030;no_`1EEED0oooo0140oooo3?ooool000[ooooo
5`3oool01P3Zj^X0EEEE00000000000071`L0410@0L0oooo00D0JVYZ000000000000:b/[0>?Sh`07
0?ooo`050<K6aP0L71`000000000002ZZZX0203oool0101ZJVX000000000001aLG480?ooo`0508j>
SP000000000001`L702o_kl01`3oool01@3EeMD071`L000000000000SXj>00P0oooo00@0SXj>0000
00000000EEEE203oool01@2>SXh000000000000L71`0ZZZZ00H0oooo00<0EEEE00000010@4000P00
00000`1ZJVX0oooo0?ooo`0E0?ooo`030000003oool0oooo05`0oooo00@0_kno0000003oool0j^[Z
1`2ZZZX01`3Zj^X0oooo0?ooo`1EEED0SXj>0820P02ZZZX00P3oool00`000000ZZZZ0?ooo`020?oo
o`040820P01EEED0EEEE05EEE@D0oooo00<0EEEE0820P03oool0403oool00`1aLG4000000>?Sh`0K
0?ooo`0305EEE@20P800oooo00T0oooo00<0_kno01`L700000000P000000100L71`0j^[Z0?ooo`10
@4020?ooo`080>[ZjP1EEED000000:ZZZP3Shn<0:b/[01`L702>SXh20?ooo`0303Ti>@3EeMD0oooo
00<0oooo00<0P8200:ZZZP3oool0103oool01P2ZZZX0@41001`L702ZZZX0j^[Z0?ooo`cooooo000:
oooooa/0oooo00@0j^[Z0410@00E5AD0_kno1`3oool00`3Zj^X0oooo0?ooo`090?ooo`030>o_k`3o
ool0oooo01H0oooo00<0j^[Z0?ooo`3oool02@3oool00`3Zj^X0oooo0?ooo`0F0?ooo`030>o_k`3o
ool0oooo00D0oooo00D0_kno0000002ZZZX0oooo0>[ZjP0I0?ooo`030000003oool0oooo05`0oooo
00<0_kno0000003oool02P3oool02@20P800D51@0?ooo`3oool000000=GEe@3oool000000:ZZZP03
0?ooo`040820P00[:b/0<30`0>[ZjPD0oooo00<0EEEE0820P03oool03`3oool00`3?cll000000820
P00L0?ooo`0405EEE@20P800oooo0=CDe0H0_kno00@0e=CD0?ooo`2`/;00EEEE0P2o_kl01@3De=@0
oooo0?ooo`2ZZZX0H61P00<0oooo00H0ZZZZ0000003oool0ZZZZ010@403Zj^X30?ooo`80P820103o
ool00`20P800ZZZZ0?ooo`050?ooo`030820P01EEED0oooo0080oooo3?ooool000[ooooo7@3oool0
0`1EEED000000;no_`1H0?ooo`0302/[:`1EEED0oooo01/0oooo00<000000?ooo`3oool0G03oool0
102o_kl000000?ooo`3Zj^X70:ZZZP0;0>[ZjP3oool0EEEE0820P03oool0j^[Z0000002ZZZX0oooo
01`L702ZZZX00`3oool01020P800EEEE0:ZZZP3Shn<50?ooo`0305EEE@2EUID0oooo00l0oooo00<0
@41001`L703Zj^X0703oool0101EEED0P8200?ooo`2>SXh605EEE@0708j>SP3oool0oooo08j>SP1a
LG40UIFE0<K6aP020?ooo`0305EEE@20P800oooo0080oooo00D0ZZZZ0000002o_kl000000;no_`04
0?ooo`030:ZZZP10@400oooo00<0oooo00<0P8200:ZZZP3oool01@3oool00`20P800EEEE0?ooo`02
0?ooo`cooooo000:oooooah0oooo00<0EEEE01DE5@3Shn<0EP3oool00`2>SXh05ADE0>?Sh`0L0?oo
o`030000003oool0oooo05`0oooo00@0P8200000003oool0eMGE1`1EEED02`3EeMD0oooo0<K6aP1Z
JVX0oooo0:ZZZP000000EEEE0?ooo`1EEED0LG5a00<0oooo00D0P82005EEE@3oool0a/K60:ZZZP04
0?ooo`0301`L702o_kl0oooo00h0oooo00<0ZZZZ0000002ZZZX07@3oool00`1EEED0P8200?ooo`09
0?ooo`090=GEe@000000hn?S0?ooo`0i>CT0a/K60?ooo`1EEED0P82000<0oooo00@0ZZZZ00000010
@400LG5a1@3oool0102ZZZX0@4100?ooo`2>SXh205EEE@0502/[:`0i>CT0EEEE05EEE@2>SXh00`3o
ool00`20P800EEEE0?ooo`020?ooo`cooooo000:oooooal0oooo00<0H61P01DE5@3?cll0E03oool0
0`3Ogml05ADE0820P00M0?ooo`030000003oool0oooo05`0oooo00<0gmoO09FEU@3oool02`3oool2
0;no_`060:n_[`3Zj^X0oooo0?ooo`3EeMD0:b/[0`3oool02P20P800EEEE0?ooo`3De=@0P8200:2P
X03Zj^X0oooo0=oOg`0[:b/?0?ooo`030>[ZjP0E5AD0D51@01h0oooo00<0EEEE0820P03oool02@3o
ool01020P800@4100?ooo`3oool205EEE@030?ooo`1EEED0P82000<0oooo00@0ZZZZ0000001`L700
j^[Z1@3oool0102ZZZX0@4100?ooo`3De=@20;no_`05061PH01oOgl0_kno0;no_`3De=@00`3oool0
0`20P800EEEE0?ooo`020?ooo`cooooo000:ooooob00oooo00<0EEEE01DE5@2ZZZX0D`3oool00`1E
EED071`L0?ooo`0M0?ooo`030000003oool0oooo0740oooo00H0SXj>0;no_`3oool0oooo0820P01E
EED60?ooo`0306YZJP3Shn<0oooo00h0oooo00<0>CTi0000003EeMD07P3oool0101EEED0P8200?oo
o`1EEED60000000405EEE@3oool0ZZZZ05EEE@80oooo00D0000005EEE@3Zj^X0ZZZZ06YZJP030?oo
o`050:ZZZP000000oooo0<K6aP3EeMD0103oool00`2>SXh0P8200?ooo`030?ooo`030820P02ZZZX0
oooo00D0oooo00<0P82005EEE@3oool00P3oool<ooooo`002_oooolQ0?ooo`0406YZJP000000ZZZZ
0?ooo`80ZZZZ00<0eMGE0?ooo`3oool01`3oool00`3Shn<0ZZZZ0<K6aP0:0?ooo`80ZZZZ2P3oool0
0`2o_kl0ZZZZ0<K6aP090?ooo`030>?Sh`2ZZZX0_kno00X0oooo00<0_kno0:ZZZP3Zj^X02@3oool0
0`36a/H0ZZZZ0<K6aP030?ooo`030<K6aP000000a/K600<0oooo00<0j^[Z0:ZZZP2ZZZX0603oool0
0`000000oooo0?ooo`1M0?ooo`030<K6aP3oool0oooo0180oooo00D0P8200?ooo`3oool0P82005EE
E@050?ooo`030>?Sh`2EUID0oooo00h0oooo00<0ZZZZ0000001aLG407P3oool00`3EeMD0EEEE0820
P00;0?ooo`08075aL@2>SXh0P820075aL@2ZZZX0j^[Z0>?Sh`10@4030?ooo`070:ZZZP000000oooo
0>?Sh`10@400LG5a0<K6aP020?ooo`0305EEE@2ZZZX0oooo00<0oooo00<0P8200:ZZZP3oool01@3o
ool00`20P800EEEE0?ooo`020?ooo`cooooo000:ooooob80oooo00<0P8200000000`<3000`000000
0`1[Jf/0oooo0?ooo`050?ooo`050820P000000000000000000`<3001`3oool01P3Zj^X0820P0000
000000005ADE0:ZZZPL0oooo00D0EEEE0000000000000000051@D0070?ooo`060:2PX00000000000
0000000E5AD0gmoO1P3oool01P3Zj^X0:b/[000000000000410@0:ZZZPL0oooo00T0EEEE00000000
000000000410@03Ogml0j^[Z02/[:`1PH6000`3oool01P2o_kl0410@000000000000410@0=GEeAH0
oooo00<000000?ooo`3oool0G03oool00`3Ogml0EEEE0?ooo`0C0?ooo`050>o_k`3De=@0j^[Z092@
T020P8001@3oool00`2o_kl0oooo0?ooo`0>0?ooo`03020P8010@400oooo03<0oooo00H0L71`0>[Z
jP3oool0oooo0:ZZZP0000060?ooo`030=GEe@10@400oooo00@0oooo00<0`<300=GEe@3oool01@3o
ool00`20P800EEEE0?ooo`020?ooo`cooooo000:ooooob<0oooo00<0EEEE0000000000000`000000
0`2ZZZX0oooo0?ooo`030?ooo`030;no_`000000000000<0000000<0ZZZZ0?ooo`3oool0103oool0
0`1EEED0000000000003000000H0oooo00<0LG5a0000000000000`0000000`2ZZZX0oooo0?ooo`04
0?ooo`D0000000<0P8200?ooo`3oool0103oool00`1EEED0000000000003000000H0oooo00<0UIFE
0000000000000`0000001020P800EEEE0000003Zj^X30?ooo`D0000000<0EEEE0?ooo`3oool0503o
ool00`000000oooo0?ooo`2<0?ooo`03075aL@000000hn?S03@0oooo00H0j^[Z05EEE@3oool0oooo
0:ZZZP0000060?ooo`0305EEE@3Shn<0oooo00/0oooo00<0ZZZZ05EEE@1EEED00`3oool<ooooo`00
2_oooolS0?ooo`0305EEE@000000000000<0000000<0ZZZZ0?ooo`3oool00`3oool00`2EUID00000
000000030000000305EEE@3oool0oooo00@0oooo00<071`L0000000000000`0000000`2o_kl0oooo
0?ooo`030?ooo`0305EEE@000000000000<0000000<0ZZZZ0?ooo`3oool00`3oool00`36a/H00000
00000003000000030410@03oool0oooo00@0oooo00<071`L0000000000000`0000000`2ZZZX0oooo
0?ooo`030?ooo`030820P0000000000000<0000000<0EEEE0000002>SXh00`3oool00`36a/H00000
00000004000001H0oooo00<000000?ooo`3oool0R`3oool00`36a/H0000006YZJP0Q0?ooo`03075a
L@2EUID0oooo0180oooo00D0hn?S08j>SP3Zj^X0EEEE000000050?ooo`030:ZZZP3Shn<0oooo00d0
oooo00<0P820075aL@3oool00P3oool<ooooo`002_oooolS0?ooo`0306YZJP000000000000<00000
00<0ZZZZ0?ooo`3oool00`3oool00`2_[jl0000000000003000000030820P03oool0oooo00@0oooo
00<0@4100000000000000`0000000`3Ogml0oooo0?ooo`030?ooo`0306YZJP000000000000<00000
00<0ZZZZ0?ooo`3oool00`3oool00`3Zj^X000000000000300000003061PH03oool0oooo00@0oooo
00<0@4100000000000000`0000000`3EeMD0oooo0?ooo`030?ooo`03092@T0000000000000@00000
00<0@4100?ooo`3oool00P3oool00`3Zj^X00000000000030000000302/[:`3oool0oooo01@0oooo
00<000000?ooo`3oool0RP3oool0103_knl05ADE01DE5@3_knlQ0?ooo`030>[ZjP3_knl0oooo01H0
oooo00<0e=CD0?ooo`3oool0603oool<ooooo`002_oooolT0?ooo`0501DE5@00000000000000000L
71`01`3oool01@0i>CT00000000000000000:b/[00L0oooo00<0hn?S0000000000000P0000000`2>
SXh0oooo0?ooo`050?ooo`0501`L70000000000000000010@4001`3oool00`1ZJVX0000000000002
000000030>[ZjP3oool0oooo00@0oooo00<0hn?S0000000000000P0000000`2>SXh0oooo0?ooo`05
0?ooo`0301`L7000000000000080000000<05ADE0>?Sh`3oool0103oool00`2>SXh0000000000002
000000030>?Sh`3oool0oooo01@0oooo00<000000?ooo`3oool0RP3oool00`20P80000000<K6aP1F
0?ooo`cooooo000:ooooob@0oooo00L0kno_0820P020P800T92@01DE5@10@400kno_00H0oooo00@0
UIFE071`L020P800gmoO203oool0103?cll0P820071`L02o_kl90?ooo`04092@T020P800UIFE0>o_
k`P0oooo00@0UIFE06][J`20P800e=CD203oool0103Zj^X0P82006][J`2`/;090?ooo`0509FEU@20
P800Jf][00000020P8001`3oool0102`/;00Jf][0820P02o_klG0?ooo`030000003oool0oooo08T0
oooo00<0eMGE010@401ZJVX0E`3oool<ooooo`002_oooolX0?ooo`030>?Sh`0L71`0@41004H0oooo
0P0L71`S0?ooo`030000003oool0oooo06/0oooo00<0i>CT08F6Q`2BTi@03@3oool00`11@T<0Ti>D
0=OGe`0;0?ooo`0301`L700[:b/0oooo00P0oooo00<0bLW:075aLP39bLT01@3oool00`1gN7T0QHJ7
0<W9bP140?ooo`cooooo000:ooooobT0oooo00@0hn?S01DE5@0L71`0j^[Z@`3oool00`2EUID00000
0<K6aP0S0?ooo`030000003oool0oooo05l0oooo00D0P820000000000000@4100>?Sh`050?ooo`04
0<W9bP0d=CH02``>01lP8Ph0oooo00D0i>CT00/<3P0;30h0@D930<;2``080?ooo`030:ZZZP000000
ZZZZ00L0oooo00@0QHJ700/<3P0;30h0G5eN1`3oool0100d=CH02``>02HW:@2JVY]20?ooo`cooooo
000:ooooobX0oooo00@0kno_0410@00`<300j^[Z@@3oool00`3Zj^X0820P0820P00T0?ooo`030000
003oool0oooo05h0oooo00<0UIFE0000000000000P0000001P0[:b/0oooo0?ooo`32`/<0MWMh01lP
8P<02``>00<0U9FF0?ooo`3oool03@3oool01`1aLG802``>00/<3P0;30h0=3Df075bL`3AdM80103o
ool00`3Zj^X0820P0410@0040?ooo`030>_[j`2^[Zl0IfQY00@02``>00<0dM;B0?ooo`3oool01@3o
ool01`2DUIH02``>00/<3P0;30h07b0R05aMGP2c/k@01P3oool01P3EeMD0@410000000000000L71`
0>[ZjS<0oooo3?ooool000[ooooo;03oool00`10@40071`L0>?Sh`100?ooo`0305EEE@0[:b/0oooo
02@0oooo00<000000?ooo`3oool0103oool01@3Shn<0EEEE03Ti>@1EEED0JVYZ05D0oooo00L0>CTi
000000000000000000410@051@H0B4U:00L02``>00<0`/;30?ooo`3oool03@3oool00`2^[Zl02``>
00/<3P0500/<3P0:05aMGP2JVY/0oooo05EEE@0E5AD0hn?S0?ooo`3Ti>@0Ti>D04Q9BPL02``>203o
ool00`32`/<02``>00/<3P0500/<3P0604Q9BP2CTi@0i>CT0?ooo`3Shn<071`L100000000`1aLG40
oooo0?ooo`0a0?ooo`cooooo000:ooooob`0oooo00@0j^[Z01`L700L71`0j^[Z?P3oool00`36a/H0
00000:ZZZP0U0?ooo`030000003oool0oooo00@0oooo00H0ZZZZ0410@03oool0oooo0;no_`0i>CUD
0?ooo`0401`L700000000@4200H720X02``>00<0@D5105EEE@1EEED03P1EEED:00/<3P0400H72021
PH40bLW:03@e=PT02``>00<02@T;05EEE@1EEED01`1EEED:00/<3P0305aMGP2?Shl0000000@00000
00<071`L0?ooo`3oool0<@3oool<ooooo`002_ooool]0?ooo`050>[ZjP10@400<30`0:ZZZP20P800
0P10@4000`2`/;00oooo0?ooo`060?ooo`050;2`/010@400@4100820P03Zj^X01`3oool01@3De=@0
H61P0410@01EEED0clo?00L0oooo00D0kno_0820P010@400@41009FEU@080?ooo`050;no_`1@D500
@410071`L03Zj^X01P3oool01P3_knl05ADE00000010@400EEEE0;no_b<0oooo00<000000?ooo`3o
ool0103oool00`2ZZZX0@4100?ooo`020?ooo`030410@02EUID0oooo0580oooo00D0P82000000003
0`@01PH700T:300900/<3P03069RHP20P800P82000d0P82000<0EeMH00/<3P0;30h01`0;30h01P08
2@/0<34b0=7AdP32`/<0MWMh03@e=PP02``>00<02@X<0820P020P8001P20P8000`1RHV802``>00/<
3P0700/<3P0303@e=P1fMgP0PX:300D0000000<05ADE0?ooo`3oool0<@3oool<ooooo`002_ooool_
0?ooo`0306YZJP000000000000<0000000<0SXj>0?ooo`3oool0103oool00`2ZZZX0000000000002
0000000303Ti>@3oool0oooo00@0oooo00<0hn?S01`L700000000`0000000`3Shn<0oooo0?ooo`04
0?ooo`0306YZJP00000000000080000000<0JVYZ0?ooo`3oool0103oool00`2ZZZX0000000000002
0000000303Ti>@3oool0oooo00@0oooo00<0JVYZ0000000000000`0000000`2ZZZX0oooo0?ooo`0P
0?ooo`030000003oool0oooo00@0oooo00<0ZZZZ0410@03oool00P3oool205EEEE@0oooo00L0JVYZ
000000000000:b/[0<S8b025QXL09RLY00H02``>00<0[Zj_0?ooo`3oool03@3oool00`2^[Zl02``>
00/<3P0400/<3P050452@`2CTi@0EUIF00000036a/H0103oool00`3Ti>@0LG5b00/<3P0600/<3P03
0>_[j`3oool0oooo00D0oooo00<0`/;300/<3P0;30h0100;30h00`0V9bT0QHJ70>CTi0030?ooo`03
05EEE@00000000000080000000<0ZZZZ0?ooo`3oool0<@3oool<ooooo`002_ooool_0?ooo`030;no
_`000000000000<0000000<0EEEE0?ooo`3oool0103oool00`1EEED0000000000003000000030>[Z
jP3oool0oooo00<0oooo00<0ZZZZ0000000000000`0000000`2>SXh0oooo0?ooo`040?ooo`D00000
00<0@4100?ooo`3oool0103oool00`1EEED0000000000003000000030>?Sh`3oool0oooo0080oooo
00<0hn?S01DE5@000000100000000`1ZJVX0oooo0?ooo`0P0?ooo`030000003oool0oooo00@0oooo
00<0ZZZZ0410@03oool00P3oool00`0L71`0EEEE0?ooo`1E0?ooo`030>?Sh`3oool0oooo0080oooo
00<0bLW:05aMGP0;30h00`0;30h00`1aLG<0oooo0?ooo`0=0?ooo`030452A00;30h02``>00802``>
00H0G5eN0=OGe`3oool0hn?S0000001aLG480?ooo`030:j^[`18BDX02``>00<02``>00<0[Zj_0?oo
o`3oool01@3oool00`1aLG<02``>00/<3P0200/<3P030452@`2^[Zl0oooo00D0oooo00D0hn?S0410
@0000000000006YZJP0d0?ooo`cooooo000:ooooobl0oooo00<0_kno0000000000000`0000000`10
@400oooo0?ooo`040?ooo`0301DE5@000000000000<0000000<0_kno0?ooo`3oool00`3oool00`1Z
JVX00000000000030000000305EEE@3oool0oooo00@0oooo1@0000000`0`<300oooo0?ooo`040?oo
o`0301DE5@000000000000<0000000<0ZZZZ0?ooo`3oool00P3oool00`10@400410@000000040000
00030410@03oool0oooo0200oooo00<000000?ooo`3oool0103oool01`2ZZZX0820P0=CDe03oool0
X:2P0000002o_kl0G@3oool01P3[jn/0[Zj_06MXJ@0O82806Q/M0=KGe`d0oooo00D0[Zj_00/<3P0Z
:b`0LG9c0;>c]0040?ooo`0302/[:`0`<300oooo00X0oooo00D0jn_[0:BTY@1LGEh02``>03Tj>`06
0?ooo`060>_[j`0J6ad07b0R05aMGP2TY:D0jn_[2P3oool00`3Zj^X0oooo0?ooo`0d0?ooo`cooooo
000:ooooobl0oooo00<0eMGE0000000000000`0000000`1EEED0oooo0?ooo`040?ooo`03075aL@00
0000000000<000001P3oool00`36a/H0000000000003000000030:ZZZP3oool0oooo00@0oooo00<0
5ADE0000000000000P0000000`10@400oooo0?ooo`040?ooo`03075aL@000000000000<00000103o
ool00`2EUID000000:ZZZP05000000030820P03oool0oooo0200oooo00<000000?ooo`3oool0103o
ool01P2ZZZX0@410075aL@0000005ADE0:ZZZV80oooo00<0`/;309:CU03oool0303oool00`1gN7T0
bLW:0?ooo`050?ooo`03075aL@000000ZZZZ00l0oooo00<0VYZK0<W9b@3oool0103oool01@2BTi@0
`/;30?ooo`3oool0JVYZ00@0EEEE?P3oool<ooooo`002_ooool`0?ooo`0308j>SP0L71`000000080
000000<0SXj>0?ooo`3oool0103oool00`3Shn<0:b/[00000002000000030:ZZZP3oool0oooo00D0
oooo00D0LG5a000000000000000005EEE@070?ooo`060:ZZZP0L71`000000000000L71`0_kno1P3o
ool00`3Shn<0>CTi00000002000000030:ZZZP3oool0oooo0080oooo00@0:b/[075aL@3oool0LG5a
0`0000000`0i>CT0j^[Z0?ooo`0Q0?ooo`030000003oool0oooo00@0oooo00<0ZZZZ0410@03oool0
L@3oool01@3Shn<0SXj>05EEE@2>SXh0hn?S00D0oooo00<0eMGE0000000i>CT06`3oool01P2o_kl0
>CTi05EEE@1EEED0>CTi0;no_cd0oooo3?ooool000[ooooo<@3oool01P3Zj^X0_kno0;no_`2PX:00
00000820P0H0oooo00@0kno_0;no_`2_[jl0j^[Z2@3oool00`3?cll0ZZZZ0;no_`090?ooo`030>[Z
jP2o_kl0_kno00X0oooo00<0_kno0:ZZZP3Ogml0103oool00`1ZJVX0820P0>[ZjP020?ooo`030=CD
e02_[jl0_kno02@0oooo00<000000?ooo`3oool0103oool00`2ZZZX0@4100?ooo`1c0?ooo`030000
003oool0oooo00D0oooo00<0@41001DE5@3Zj^X0703oool20=CDe080oooo00<0gmoO0?ooo`3oool0
>`3oool<ooooo`002_oooole0?ooo`030:ZZZP000000P8200340oooo00<0a/K60000002ZZZX0:P3o
ool00`000000oooo0?ooo`030?ooo`030>[ZjP1EEED0@41007@0oooo00<000000?ooo`3oool0103o
ool00`2ZZZX000000<K6aP0N0?ooo`030<K6aP2o_kl0oooo03h0oooo3?ooool000[ooooo=P3oool0
0`2o_kl0410@0820P00_0?ooo`030>o_k`0E5AD0@41002/0oooo00<000000?ooo`3oool01@3oool0
0`3Ogml0oooo0?ooo`1O0?ooo`030<o?c`2o_kl0_kno00D0_kno00<0clo?0;no_`2o_kl00P3oool3
0;no_`<0oooo00<000000?ooo`3oool00`3oool00`3EeMD05ADE051@D00<0?ooo`0309FEU@10@400
P82000<0P82000/0H61P00000010@400gmoO06][J`3Zj^X0oooo0;no_`000000P8200>[ZjP030?oo
o`03092@T02o_kl0oooo03d0oooo3?ooool000[ooooo=`3oool0102o_kl0000003Ti>@3Zj^X]0?oo
o`0306YZJP0L71`0hn?S02/0oooo00<000000?ooo`3oool0I`3oool00`20P800LG5a0:ZZZP030:ZZ
ZP05075aL@000000P8200>?Sh`2ZZZX00P3oool00`2>SXh05ADE0>?Sh`030?ooo`030000003oool0
oooo00<0oooo00<071`L0000003Zj^X03@3oool00`1EEED0oooo0?ooo`020?ooo`0909FEU@000000
a/K60?ooo`3Shn<0a/K60?ooo`1aLG40EEEE0080oooo00D0j^[Z0?ooo`3oool0_kno01`L700n0?oo
o`cooooo000:ooooocP0oooo00<0a/K601`L7010@400;03oool00`3Shn<05ADE08j>SP0/0?ooo`03
0000003oool0oooo06L0oooo00<0eMGE05EEE@3oool00`3oool02@1aLG4000000=GEe@3oool0a/K6
0>[ZjP3oool071`L09FEU@040?ooo`030000003oool0oooo0080oooo00<0ZZZZ0000002>SXh03P3o
ool00`1ZJVX0hn?S0?ooo`020?ooo`030410@00L71`0oooo0080oooo00@0a/K60;no_`000000eMGE
0P3oool01@2EUID0oooo0?ooo`20P800000003h0oooo3?ooool000[ooooo>@3oool01@3Zj^X0<30`
0410@03Zj^X0oooo0080_kno00<0j^[Z0?ooo`3oool01`3oool00`3Ogml0_kno0=CDe00:0?ooo`80
_kno2P3oool0103?cll0_kno0=oOg`3oool20410@0H0oooo00<0j^[Z0;no_`3De=@0903oool00`00
0000oooo0?ooo`1X0?ooo`070410@03EeMD0oooo0?ooo`3_knl0000002/[:`030?ooo`030;no_`1E
EED0:b/[00<0oooo00<0j^[Z0?ooo`0000000`3oool00`3Zj^X0820P0410@00?0?ooo`070;no_`20
P800oooo0?ooo`3EeMD0000009FEU@040?ooo`03030`<01ZJVX0oooo0080oooo00D0X:2P02/[:`10
@40000000820P00n0?ooo`cooooo000:ooooocX0oooo00@0j^[Z01`L700L71`0EEEE0`0000000`2Z
ZZX0oooo0?ooo`050?ooo`050:ZZZP00000000000000001EEED01`3oool01P3EeMD071`L00000000
000071`L0>[ZjPL0oooo00L0LG5a000000000000000003Ti>@000000eMGE00D0oooo00D0ZZZZ0000
00000000000001`L700S0?ooo`030000003oool0oooo06P0oooo00L0a/K6075aL@3oool0oooo09FE
U@000000ZZZZ00<0oooo00<0ZZZZ0000003Shn<0103oool00`2>SXh05ADE0?ooo`020?ooo`0305EE
E@0E5AD0hn?S0100oooo00D071`L0>[ZjP3oool0LG5a01DE5@040?ooo`0308j>SP0[:b/0a/K600@0
oooo00<0hn?S0:ZZZP3EeMD0?`3oool<ooooo`002_oooolk0?ooo`030>?Sh`0L71`0000000@00000
00<0eMGE0?ooo`3oool00`3oool00`36a/H0000000000003000000030<K6aP3oool0oooo00@0oooo
00<0EEEE0000000000000P0000000`1EEED0oooo0?ooo`040?ooo`030:ZZZP000000000000<00000
00<0LG5a0?ooo`3oool00`3oool00`3EeMD00000000000030000000309FEU@3oool0oooo0200oooo
00<000000?ooo`3oool0J@3oool01@0L71`0j^[Z0?ooo`1EEED071`L00@0oooo00<0:b/[05EEE@3o
ool01@3oool01P3Zj^X0oooo0?ooo`3EeMD000000820P140oooo00D0SXj>0:ZZZP3oool0000006YZ
JP030?ooo`040>?Sh`000000ZZZZ0:ZZZTH0oooo3?ooool000[ooooo1P3oool00`3_knl0e=CD0?oo
o`0c0?ooo`0305EEE@000000000000<0000000<0[jn_0?ooo`3oool00`3oool00`20P80000000000
00030000000306YZJP3oool0oooo00@0oooo00<0820P0000000000000P0000000`0@4100oooo0?oo
o`040?ooo`0305EEE@000000000000<0000000<0UIFE0?ooo`3oool00`3oool00`2PX:0000000000
000300000003051@D03oool0oooo0200oooo00<000000?ooo`3oool0J@3oool01@2EUID0X:2P0>[Z
jP000000UIFE00<0oooo00@0JVYZ0410@03oool0ZZZZ203oool00`10@4005ADE0>o_k`0A0?ooo`05
0>[ZjP1PH600P8200000002o_kl00P3oool01`3Ogml0EEEE0410@03?cll0e=CD0820P03De=@0A03o
ool<ooooo`002_ooool70?ooo`80ZZZZ<`3oool00`1EEED0000000000003000000030;no_`3oool0
oooo00<0oooo00<0SXj>0000000000000`0000000`1aLG40oooo0?ooo`040?ooo`0302/[:`000000
00000080000000<05ADE0?ooo`3oool0103oool00`1EEED0000000000003000000030:ZZZP3oool0
oooo00<0oooo00<0ZZZZ0000000000000`0000000`1EEED0oooo0?ooo`0P0?ooo`030000003oool0
oooo06X0oooo00<0EEEE075aL@0E5AD00`3oool01`2>SXh0EEEE06YZJP3oool0SXj>0820P03Shn<0
1@3oool00`2>SXh000000<K6aP0C0?ooo`0306YZJP00000071`L04h0oooo3?ooool000[ooooo203o
ool00`1EEED0eMGE0?ooo`0a0?ooo`030:ZZZP000000000000<0000000<0eMGE0?ooo`3oool00`3o
ool00`3Shn<0000000000003000000030<K6aP3oool0oooo00@0oooo00<0JVYZ0000000000000P00
00000`1EEED0oooo0?ooo`040?ooo`030:ZZZP000000000000<0000000<0a/K60?ooo`3oool00`3o
ool00`3Zj^X00000000000030000000309FEU@3oool0oooo0200oooo00<000000?ooo`3oool0AP3o
ool00`2o_kl0oooo0?ooo`0Q0?ooo`0306YZJP000000EEEE00h0oooo00<0hn?S0000001EEED0503o
ool00`2ZZZX0000008j>SP1>0?ooo`cooooo000:ooooo`0:0>[ZjP1@D500EEEE0;no_`2PX:00EEEE
0<o?c`3oool0eMGE061PH3<0oooo00<0[jn_0000000000000P0E5AD00`3?cll0oooo0?ooo`040?oo
o`050=CDe00`<300000001DE5@2`/;001`3oool01P3_knl0P820000000000000P8200>o_k`L0oooo
00D0_kno020P80000000@4100=CDe0070?ooo`050=CDe010@400000001DE5@2EUID08`3oool00`00
0000oooo0?ooo`160?ooo`030<o?c`20P800oooo0240oooo00<0_kno0000002_[jl03P3oool00`10
@40000000=oOg`0E0?ooo`0302/[:`3Zj^X0oooo04d0oooo3?ooool000[ooooo00L0EEEE0410@03o
ool0a/K601DE5@2ZZZX0j^[Z0080oooo00<05ADE0?ooo`3oool0=@3oool00`1EEED000000:ZZZP0N
0?ooo`030>?Sh`0E5AD0SXj>02d0oooo00D0hn?S0820P01EEED0EEEE0000000205EEE@030820P036
a/H0oooo04@0oooo0P2>SXhR0?ooo`0303Ti>@3oool0oooo00`0oooo00<0UIFE0000002>SXh0IP3o
ool<ooooo`002_ooool01P1aLG40P8200?ooo`3oool0@4100:ZZZP<0oooo00<0@4100<K6aP3oool0
=P3oool00`20P80000000:ZZZP0M0?ooo`0305EEE@0[:b/0oooo02`0oooo00<0_kno000000000000
1`0000000`36a/H0oooo0?ooo`0j0?ooo`050<K6aP0i>CT0@41005EEE@1aLG400`3oool00`3Shn<0
71`L0?ooo`0`0?ooo`0301DE5@0i>CT0oooo06H0oooo3?ooool000[ooooo00H0oooo0820P02o_kl0
oooo0410@02ZZZX30?ooo`030410@02ZZZX0oooo03L0oooo00<0P8200000002PX:006`3oool00`2Z
ZZX000000;no_`0^0?ooo`0301DE5@000000000000D0000000<0:b/[0?ooo`3oool0>`3oool205EE
E@80oooo00<0_kno051@D03oool00P3oool00`0[:b/0_kno0?ooo`0^0?ooo`0305EEE@0@4100j^[Z
06L0oooo3?ooool000[ooooo0`3oool00`2ZZZX0:b/[0:ZZZP030?ooo`030410@02ZZZX0oooo03P0
oooo00<0ZZZZ0000002ZZZX06@3oool00`3Zj^X0000005EEE@0_0?ooo`0308j>SP000000000000D0
000000<0SXj>0?ooo`3oool0>`3oool205EEE@<0oooo00H0@4100>?Sh`3oool0oooo05EEE@20P80^
0?ooo`030:ZZZP000000UIFE06P0oooo3?ooool000[ooooo00H0_kno051@D03oool0oooo0410@02o
_kl30?ooo`03030`<03Zj^X0oooo03T0oooo00<0X:2P00000020P800603oool00`1@D500:b/[0>[Z
jP0`0?ooo`03010@40000000000000<0000000<0410@0>[ZjP3oool0?03oool205EEE@<0oooo00H0
@4100:ZZZP3oool0oooo05EEE@20P80]0?ooo`040=oOg`0E5AD0:b/[0>o_kfP0oooo3?ooool000[o
oooo00D0oooo0820P02ZZZX0SXj>05EEE@040?ooo`0302/[:`3oool0oooo03X0oooo00D0a/K601DE
5@1EEED0oooo0=GEe@020:ZZZPT0oooo00@0hn?S0:ZZZP2EUID0hn?S1@3oool01`36a/H000000>?S
h`3oool0_kno08j>SP2o_kl0;@3oool00`10@4000000000000030000000305EEE@3oool0oooo03`0
oooo0P1EEED30?ooo`0600000036a/H0oooo0?ooo`1EEED0P820;@3oool00`1EEED000000>?Sh`1Y
0?ooo`cooooo000:ooooo`P0oooo00<0SXj>09FEU@3oool0?03oool00`2o_kl0000001`L70030000
000302/[:`3Shn<0oooo00D0oooo00<0eMGE0000000000000P0000000`2ZZZX0oooo0?ooo`020?oo
o`0401`L701EEED0oooo05EEE@<0000000<0EEEE0?ooo`3oool0:P3oool00`20P800000000000003
0000000309FEU@3oool0oooo03`0oooo00H0EEEE01`L703EeMD0oooo05EEE@0E5AD30?ooo`0303Ti
>@2o_kl0oooo02/0oooo00<0hn?S0000002>SXh0JP3oool<ooooo`002_ooool70?ooo`030>[ZjP1E
EED0oooo03h0oooo00<0UIFE0000000000000`0000000`1ZJVX0oooo0?ooo`040?ooo`03051@D000
000000000080000000P0@4100?ooo`3oool0oooo05EEE@0E5AD0gmoO0;no_`D0000000<0ZZZZ0?oo
o`3oool0:@3oool00`2o_kl0000000000003000000030=oOg`3oool0oooo03`0oooo0P1EEED01020
P800@41005EEE@3?cll20?ooo`030>[ZjP0E5AD0kno_02/0oooo00<0kno_02/[:`0`<300J`3oool<
ooooo`002_ooool60?ooo`030>[ZjP2>SXh0oooo03l0oooo00<0ZZZZ0000000000000`0000000`1E
EED0oooo0?ooo`040?ooo`H000000P3oool01@2o_kl0000008j>SP3oool0EEEE00D0000000<0EEEE
0?ooo`3oool0:P3oool01@0L71`00000000000000000>CTi03l0oooo0P1EEED60?ooo`03075aL@2Z
ZZX0oooo02/0oooo00<0P8200000002o_kl0J`3oool<ooooo`002_oooom80?ooo`030:ZZZP000000
000000<0000000<0EEEE0?ooo`3oool0103oool00`10@4000000000000020000000502/[:`3oool0
oooo0410@00i>CT00P3oool00`2ZZZX00000000000030000000308j>SP3oool0oooo02X0oooo00D0
LG5a000000000000000008j>SP0o0?ooo`80EEEE1@3oool00`3Zj^X0EEEE0?ooo`0/0?ooo`0301DE
5@1EEED0oooo06/0oooo3?ooool000[oooooB@3oool00`1EEED0000000000002000000030:ZZZP3o
ool0oooo00@0oooo00<0/;2`0000000000000P0000001@2@T900oooo0:ZZZP0@4100j^[Z00<0oooo
00H0:b/[00000000000000000410@03Zj^X/0?ooo`050>[ZjP0E5AD000000000003Zj^X0?P3oool0
0`3Ogml0EEEE05EEE@050?ooo`030:n_[`3oool0oooo02/0oooo00<0EEEE010@403Zj^X0K03oool<
ooooo`002_oooom:0?ooo`060:ZZZP1EEED0EEEE0410@00L71`0hn?S1P3oool0203Shn<0EEEE05EE
E@36a/H0oooo0>?Sh`000000P8201@3oool00`20P800EEEE09FEU@0_0?ooo`03075aL@000000LG5a
07@0oooo00<0SXj>0000002EUID0K@3oool<ooooo`002_oooom=0?ooo`040>[ZjP0L71`071`L0>[Z
jPX0oooo00<0>CTi01`L703Zj^X0=`3oool00`36a/H000000<K6aP1c0?ooo`030>[ZjP00000071`L
06h0oooo3?ooool000[oooooCP3oool0103Zj^X0@410020P802o_kl80?ooo`030:2PX0000000_kno
03T0oooo00<0@4100?ooo`3oool0LP3oool00`1`L70000000=GEe@1^0?ooo`cooooo000:oooooe00
oooo00<0P8200000002o_kl01`3oool00`0E5AD0LG5a0?ooo`0i0?ooo`030>[ZjP3oool0oooo0740
oooo00<0a/K60000002>SXh0K`3oool<ooooo`002_oooomA0?ooo`0305EEE@0E5AD0hn?S00D0oooo
00<0LG5a01DE5@3oool0[P3oool00`0L71`0:b/[0?ooo`1_0?ooo`cooooo000:oooooe80oooo00<0
H61P01DE5@2o_kl00`3oool00`3?cll000000:2PX02^0?ooo`0306YZJP000000_kno0700oooo3?oo
ool000[oooooD`3oool01`1EEED000000:ZZZP3Shn<0EEEE02/[:`0L71`0[P3oool00`2o_kl00000
05EEE@1a0?ooo`cooooo000:oooooe@0oooo00<0UIFE010@400000000`0000000`1@D500oooo0?oo
o`2[0?ooo`03030`<00[:b/0j^[Z0740oooo3?ooool000[oooooE@3oool00`10@400000000000003
00000:`0oooo00<0SXj>0000003Shn<0LP3oool<ooooo`002_oooomE0?ooo`030410@00000000000
00<00000Z`3oool00`3Shn<0000005EEE@1c0?ooo`cooooo000:oooooeD0oooo00<0L71`00000000
00000P0000000`0@4100oooo0?ooo`2X0?ooo`040>o_k`0[:b/05ADE0=oOgg<0oooo3?ooool000[o
ooooE@3oool00`3Zj^X0>CTi00000002000000030;no_`3oool0oooo0:P0oooo00<0UIFE0000002Z
ZZX05P3oool02@3Zj^X0SXj>05EEE@20P800hn?S0?ooo`2ZZZX0EEEE0:ZZZP060?ooo`030<K6aP3E
eMD0oooo04`0oooo3?ooool000[oooooE`3oool20:ZZZP030>?Sh`3oool0oooo0:T0oooo00<05ADE
03Ti>@3oool0603oool01P000000_kno0?ooo`3Zj^X00000075aL@@0oooo00H0a/K60>[ZjP2ZZZX0
000001DE5@3Shn<40?ooo`030;no_`3oool0oooo04D0oooo3?ooool000[oooooo`3oool50?ooo`03
05EEE@0@4100j^[Z01T0oooo00D000000;no_`3Zj^X0<30`0820P0040?ooo`070:2PX02o_kl0oooo
0?ooo`2o_kl0gmoO06][J`040?ooo`030<o?c`20P800oooo04D0oooo3?ooool000[oooooo`3oool4
0?ooo`030:ZZZP000000UIFE01X0oooo00@000000;no_`1EEED0@410103oool00`3Shn<0JVYZ0?oo
o`040?ooo`030>?Sh`36a/H0oooo00<0oooo00<0SXj>0:ZZZP3oool0A03oool<ooooo`002_oooooo
0?ooo`@0oooo00<0:b/[01`L703oool00P3oool01`1ZJVX0a/K60?ooo`3Zj^X0>CTi0000002ZZZX0
203oool03P3Shn<0JVYZ0>?Sh`3oool0eMGE0000000L71`0eMGE0?ooo`000000P8200:ZZZP2EUID0
SXj>0`3oool00`1aLG40ZZZZ0?ooo`040?ooo`030<K6aP1EEED0oooo00<0oooo00<0hn?S05EEE@3o
ool0A03oool<ooooo`002_oooooo0?ooo`<0oooo00<0UIFE0000003EeMD0103oool01`2ZZZX0oooo
0=oOg`000000ZZZZ0?ooo`3De=@01P2o_kl0203?cll0oooo0=oOg`3De=@0oooo0:2PX00E5AD0j^[Z
0P3oool01P000000_kno0?ooo`3oool0:b/[0820P080oooo00<000000=oOg`3oool0103oool202/[
:`030>o_k`3oool0oooo0080oooo00<0820P0?ooo`3oool0@`3oool<ooooo`002_oooooo0?ooo`80
oooo00<0a/K60000001ZJVX01@3oool0103Shn<0a/K605EEE@1aLG420?ooo`0308j>SP1EEED0EEEE
00@0EEEE00L0P8200?ooo`3oool0a/K60>?Sh`0E5AD0a/K600<0oooo00@000000;no_`3oool0oooo
0P1EEED00`3oool0ZZZZ000000050?ooo`040;no_`000000hn?S0:ZZZP@0oooo00<0@4100:ZZZP3o
ool0@`3oool<ooooo`002_oooooo0?ooo`80oooo00<071`L0000003Zj^X01P3oool00`2ZZZX05ADE
0>?Sh`0=0?ooo`0305EEE@10@400oooo00<0oooo00T000000;no_`3oool0j^[Z00000036a/H0oooo
0:ZZZP0000001@3oool0101ZJVX0EEEE0?ooo`2o_kl40?ooo`030410@02ZZZX0oooo04<0oooo3?oo
ool000[oooooo`3oool10?ooo`03092@T0000000ZZZZ00H0oooo00<0j^[Z01DE5@1`L7003@3oool0
0`2ZZZX000000;2`/0020?ooo`070>o_k`2ZZZX0P8200:n_[`2o_kl0X:2P0>[ZjP020?ooo`030:ZZ
ZP000000oooo00<0oooo00D0j^[Z010@403EeMD0oooo0;no_`040?ooo`030410@02ZZZX0oooo04<0
oooo3?ooool000[oooooo`3oool00`3Shn<05ADE05EEE@070?ooo`80>CTi00D0j^[Z0<K6aP3oool0
oooo05EEE@06000000060410@03oool0j^[Z0000002>SXh0_kno303oool00`000000j^[Z0?ooo`02
0?ooo`03075aL@1EEED0oooo0080oooo00D0SXj>0?ooo`3oool0oooo02/[:`150?ooo`cooooo000:
ooooool0oooo00<0@410020P803Zj^X01P3oool01`2@T900@4100820P03_knl0P8200:ZZZP3_knl0
203oool01`3Zj^X0L71`0410@02o_kl0gmoO06][J`2o_kl02P3oool03`1EEED0[jn_0?ooo`3oool0
_kno0410@01`L700j^[Z0?ooo`3Ogml0Jf][0>[ZjP3oool0j^[Z0410@0150?ooo`cooooo000:oooo
ooh0oooo00<0SXj>0000002ZZZX09`3oool00`3Shn<0P8200?ooo`0:0?ooo`03075aL@2o_kl0oooo
04@0oooo3?ooool000[oooooo@3oool00`3Zj^X0000001`L700Y0?ooo`030820P03Shn<0oooo00P0
oooo00<0j^[Z05EEE@3oool0A@3oool<ooooo`002_ooooon0?ooo`030:ZZZP3EeMD0oooo02T0oooo
00<0ZZZZ0>o_k`3oool01`3oool00`2_[jl0oooo0?ooo`150?ooo`cooooo000:ooooool0ooooO@3o
ool<ooooo`00oooooonCooooo`00oooooonCooooo`00oooooonCooooo`00\
\>"],
  ImageRangeCache->{{{0, 401.312}, {140.375, 0}} -> {-35.4076, -11.2524, \
4.20749, 4.20749}}],

Cell[TextData[{
  "Fig. 6.11  (a) Triangular domain together with a possible choice of grid. \
The rightmost point in each row has  index ",
  Cell[BoxData[
      \(TraditionalForm\`j = g(k) + 1\)]],
  ".   (b)  Points ",
  Cell[BoxData[
      \(TraditionalForm\`g(k)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g(k)\  + 1\)]],
  " at the end of row ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "."
}], "Caption",
  CellTags->"Fig. 6.11"],

Cell[TextData[{
  StyleBox["(19)",
    FontWeight->"Bold"],
  " Solve for the potential created by a rectangular lattice of ions and \
electrons, with charges ",
  Cell[BoxData[
      \(TraditionalForm\`e\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(-e\)\)]],
  " respectively. (Actually, in  this two dimensional problem these are \
charged rods, not point charges, and ",
  Cell[BoxData[
      \(TraditionalForm\`e\)]],
  " is charge per unit length.) The positive \"ions\" are at positions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((i, \ 2  j)\)\(,\)\)\)]],
  " and the \"electrons\" are at positions ",
  Cell[BoxData[
      \(TraditionalForm\`\((i + 1/2, \ 2  j + 1/2)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " are integers. In the rectangular domain defined by ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)/4 < x < 3/4, \ 0 < y < 2\)]],
  ",solve for the potential using a FFT,  and  take a sufficiently fine grid \
to determine the potential at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 1/2, \ y = 3/4\)]],
  " to three significant figures."
}], "Text"],

Cell[TextData[{
  StyleBox["(20)",
    FontWeight->"Bold"],
  " The following charge density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x, y, z)\)]],
  ", defined in a cube,  is periodically-replicated throughout space. Find \
the potential at the center of the cube to three significant figures using \
the FFT method."
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x, y, 
          z)\  = \(\(A\ x\ y\ z\^2\ \((1 - x)\) \((1 - 
                y\^2)\) \((1 - z)\)\^2\)\(-\)\(A\/720\)\(\ \)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 1; \ 0 < y < 1; \ 0 < z < 1\)]],
  "."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["6.3 Numerical Eigenmode Methods", "Subtitle",
  FontColor->RGBColor[1, 0, 0],
  CellTags->{"i:39", "c:28"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["6.3.1 Introduction", "Subsubtitle",
  CellTags->"c:29"],

Cell[TextData[{
  "\tIn Chapter ",
  ButtonBox["4",
    ButtonData:>{"Chapter4.nb", None},
    ButtonStyle->"Hyperlink"],
  ", solutions to PDEs such as the wave, heat, and Schr\[ODoubleDot]dinger \
equations were developed using eigenmode expansions. However, such solutions \
were useful only for cases where the eigenmodes and eigenvalues could be \
determined analytically. In this section we show how the eigenmodes can be \
evaluated numerically. This provides us with certain advantages over the \
Galerkin and grid methods. In those methods, we had to step forward ",
  StyleBox["in time, laboriously calculating the solution at each ", "NE2"],
  "time step",
  StyleBox[". However, with knowledge of the eigenmodes and eigenvalues", 
    "NE2"],
  ",",
  StyleBox[" we c", "NE2"],
  "an use the general solution of the equations to bypass numerical time \
integration.  Once we have the eigenmodes, all we need do is evaluate some \
inner products over the initial conditions and source functions (if any), and \
we are done."
}], "Text"],

Cell["\<\
\t  Furthermore, for a given system we need evaluate the eigenmodes \
and eigenvalues only once. Once we have them, we can solve the problem for \
any given initial conditions or source functions. \
\>", "Text"],

Cell["\<\
\tHere we consider three numerical methods for determining the \
eigenmodes: a technique based on the finite-differenced PDE; a technique  \
based on the Galerkin method; and a  semi-analytic technique for 1D systems, \
based on the shooting method combined with WKB analysis.   This last method \
has excellent accuracy for the eigenvalues, but is rather difficult to \
implement, since the WKB eigenvalues first have to be evaluated in order to \
provide initial guesses in the shooting method. Also,  turning points, if \
any, have to be found in the process.  The grid and Galerkin eigenmode \
methods are, generally speaking, easier to program than the WKB-shooting \
method, but  are usually not as accurate, especially for high-order modes. \
\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["6.3.2 Grid-Method Eigenmodes", "Subsubtitle",
  CellTags->{"i:42", "c:30"}],

Cell[CellGroupData[{

Cell["General Theory", "Section",
  CellTags->"c:31"],

Cell["\tConsider the following 1D eigenvalue problem:", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) \[Psi]\_n = \(\[Lambda]\_n\) \[Psi]\_n\)]],
  ", "
}], "NE3",
  CellTags->"(6.3.1)"],

Cell[TextData[{
  "with homogeneous boundary conditions at ",
  Cell[BoxData[
      \(TraditionalForm\`x = a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x = b\)]],
  ". We will finite-difference the equation, so as to obtain a matrix \
eigenvalue problem of the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[
              RowBox[{
                RowBox[{
                  StyleBox["L",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "\[CenterDot]", 
                  StyleBox[
                    SubscriptBox["\[Psi]", 
                      StyleBox["n",
                        FontWeight->"Plain"]],
                    FontWeight->"Bold"]}], "=", 
                RowBox[{\(\[Lambda]\_n\), 
                  StyleBox[
                    SubscriptBox["\[Psi]", 
                      StyleBox["n",
                        FontWeight->"Plain"]],
                    FontWeight->"Bold"]}]}],
              "TraditionalForm"], ","}]}], TraditionalForm]]],
  " where ",
  Cell[BoxData[
      FormBox[
        StyleBox["L",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox["\[Psi]", 
            StyleBox["n",
              FontWeight->"Plain"]],
          FontWeight->"Bold"], TraditionalForm]]],
  " are discretized forms of the operator and eigenfunction respectively. We \
will then apply the intrinsic functions ",
  StyleBox["Eigenvalues",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Eigenvectors",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to ",
  Cell[BoxData[
      FormBox[
        StyleBox["L",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " in order to determine numerical approximations to the eigenvalues and \
eigenfunctions."
}], "Text"],

Cell[TextData[{
  "\tWe will discretize this ODE  on a uniform grid. For Dirichlet boundary \
conditions at both ends, we take ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(x\_j\), "=", 
          RowBox[{"a", "+", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], " ", "j"}]}]}], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0, 1, 2,  ... , M\)]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "=", \(\((b - a)\)/M\)}], 
        TraditionalForm]]],
  ". For von Neumann  conditions at both ends, as discussed in Sec. ",
  ButtonBox["6.2.1",
    ButtonData:>"c:14",
    ButtonStyle->"Hyperlink"],
  ", we take ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(x\_j\), "=", 
          RowBox[{"a", "+", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], " ", \((j - 1/2)\)}]}]}], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0, 1, 2,  .. , M, \)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "=", \(\((b - a)\)/\((M - 1)\)\)}], 
        TraditionalForm]]],
  ". On either of these grids Eq. ",
  ButtonBox["(6.3.1)",
    ButtonData:>"(6.3.1)",
    ButtonStyle->"Hyperlink"],
  " becomes a matrix equation for the interior points in the domain,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[Sum]\+\(k = 0\)\%M L\_\(j\ k\)\ \
\((\[Psi]\_n)\)\_\(\(\ \)\(k\)\) = \
\(\(\[Lambda]\_n\)(\[Psi]\_n)\)\_j\)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j = 1, 2, 3,  ... , M - 1, \)]]
}], "NE3",
  CellTags->"(6.3.2)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`L\_\(j\ k\)\)]],
  " is the difference form of the operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_n)\)\_k = \(\[Psi]\_n\)(x\_k)\)]],
  " is the ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "th element of the difference form of the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "th eigenmode."
}], "Text"],

Cell[TextData[{
  "\t For the end points, we must supplement  Eq. ",
  ButtonBox["(6.3.2)",
    ButtonData:>"(6.3.2)",
    ButtonStyle->"Hyperlink"],
  " with homogeneous boundary conditions. For Dirichlet conditions, we have \
",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_n)\)\_0 = \(\((\[Psi]\_n)\)\_M = 0\)\)]],
  ".  For ",
  "von Neumann ",
  " boundary conditions, we need to set the derivative of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  " equal to zero at the end points. According to Eq. ",
  ButtonBox["(6.2.20)",
    ButtonData:>"(6.2.20)",
    ButtonStyle->"Hyperlink"],
  ", we take ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_n)\)\_0 = \((\[Psi]\_n)\)\_1\)]],
  ". Similarly on the right side, ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_n)\)\_\(M - 1\) = \((\[Psi]\_n)\)\_M\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tFor Dirichlet boundary conditions, setting ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_n)\)\_0 = \(\((\[Psi]\_n)\)\_M = 0\)\)]],
  " in the sum of Eq. ",
  ButtonBox["(6.3.2)",
    ButtonData:>"(6.3.2)",
    ButtonStyle->"Hyperlink"],
  "  results in the following closed set of equations for the interior \
points:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[Sum]\+\(k = 1\)\%\(M - 1\)L\_\(j\ k\)\ \
\((\[Psi]\_n)\)\_\(\(\ \)\(k\)\) = \
\(\(\[Lambda]\_n\)(\[Psi]\_n)\)\_j\)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j = 1, 2, 3,  ... , M - 1. \)]]
}], "NE3",
  CellTags->"(6.3.3)"],

Cell["This matrix eigenvalue problem is shown schematically below:", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{GridBox[{
                    {\(L\_\(1\ 1\)\)},
                    {\(L\_\(2\ 1\)\)},
                    {"\[VerticalEllipsis]"},
                    {\(L\_\(M - 1\ \ 1\)\)}
                    }], GridBox[{
                    {\(L\_12\)},
                    {\(L\_22\)},
                    {"\[VerticalEllipsis]"},
                    {\(L\_\(M - 1\ \ 2\)\)}
                    }], GridBox[{
                    {"..."},
                    {"..."},
                    {"\[VerticalEllipsis]"},
                    {"..."}
                    }], GridBox[{
                    {\(L\_\(1\ M - 1\)\)},
                    {\(L\_\(2\ M - 1\)\)},
                    {"\[VerticalEllipsis]"},
                    {\(L\_\(M - 1\ \ M - 1\)\)}
                    }]}], ")"}], 
            RowBox[{"(", GridBox[{
                  {\(\((\[Psi]\_n)\)\_1\)},
                  {\(\((\[Psi]\_n)\)\_2\)},
                  {"\[VerticalEllipsis]"},
                  {\(\((\[Psi]\_n)\)\_\(M - 1\)\)}
                  }], ")"}]}], "=", 
          RowBox[{\(\[Lambda]\_\(\(n\)\(\ \)\)\), "(", GridBox[{
                {\(\((\[Psi]\_n)\)\_1\)},
                {\(\((\[Psi]\_n)\)\_2\)},
                {"\[VerticalEllipsis]"},
                {\(\(\ \)\(\((\[Psi]\_n)\)\_\(M - 1\)\)\)}
                }], ")"}]}], TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(6.3.4)"],

Cell[TextData[{
  "For ",
  "von Neumann ",
  " conditions, we set  ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_n)\)\_0 = \((\[Psi]\_n)\)\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_n)\)\_M = \((\[Psi]\_n)\)\_\(M - 1\)\)]],
  " in the sum in Eq. ",
  ButtonBox["(6.3.2)",
    ButtonData:>"(6.3.2)",
    ButtonStyle->"Hyperlink"],
  ". The resulting equations have the following form:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{GridBox[{
                  {\(L\_\(1\ 1\) + L\_\(1\ 0\)\), \(L\_\(1\ 2\)\), "..."},
                  {\(L\_\(2\ 1\) + L\_\(2\ 0\)\), \(L\_\(2\ 2\)\), "..."},
                  {"\[VerticalEllipsis]", "\[VerticalEllipsis]", 
                    "\[VerticalEllipsis]"},
                  {\(L\_\(M - 1\ \ 1\) + 
                      L\_\(M - 1\ \ 0\)\), \(L\_\(M - 1\ \ 2\)\), "..."}
                  }], GridBox[{
                  {\(L\_\(1\ M - 2\)\)},
                  {\(L\_\(2\ M - 2\)\)},
                  {"\[VerticalEllipsis]"},
                  {\(L\_\(M - 1\ \ M - 2\)\)}
                  }], GridBox[{
                  {\(L\_\(1\ M - 1\) + L\_\(1\ M\)\)},
                  {\(L\_\(2\ M - 1\) + L\_\(2\ M\)\)},
                  {"\[VerticalEllipsis]"},
                  {\(L\_\(M - 1\ \ M - 1\) + L\_\(M - 1\ M\)\)}
                  }]}], ")"}], 
          RowBox[{"(", GridBox[{
                {\(\((\[Psi]\_n)\)\_1\)},
                {\(\((\[Psi]\_n)\)\_2\)},
                {"\[VerticalEllipsis]"},
                {\(\((\[Psi]\_n)\)\_\(M - 1\)\)}
                }], ")"}]}], "=", 
        RowBox[{\(\[Lambda]\_\(\(n\)\(\ \)\)\), "(", GridBox[{
              {\(\((\[Psi]\_n)\)\_1\)},
              {\(\((\[Psi]\_n)\)\_2\)},
              {"\[VerticalEllipsis]"},
              {\(\((\[Psi]\_n)\)\_\(M - 1\)\)}
              }], ")"}]}], TraditionalForm]]]], "NE3",
  CellTags->"(6.3.5)"],

Cell[TextData[{
  "The first and last columns of the matrix have been modified to allow for \
the contributions of ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_n)\)\_0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_n)\)\_M\)]],
  " to each equation. "
}], "Text"],

Cell[TextData[{
  "\tWe can now extract the matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["L",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " and determine the eigenvalues and eigenvectors numerically. Two examples \
are considered below."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 1: 1D Heat Equation with Mixed Boundary Conditions", "Section",
  CellTags->"c:32"],

Cell["\<\
\tAs an example of this method, consider the operator appearing in \
the heat equation,\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`L\&^ = \[Chi] \[PartialD]\^2\/\[PartialD]x\^2\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "We will solve for the eigenmodes of this operator on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\([0, b]\)\)]],
  ", with a Dirichlet condition at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](0) = 0\)]],
  ",  and a ",
  "von Neumann ",
  " condition at ",
  Cell[BoxData[
      \(TraditionalForm\`x = b\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\^\[Prime]\)(b) = 0\)]],
  ". This operator has eigenfunctions of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_n\)(x) = 
        sin[\ \((n\  + \ 1/2)\)\ \[Pi]\ x/b]\)]],
  ", and eigenvalues ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_n = \ \(-\[Chi]\ [\((n\  + \ 1/2)\)\ \
\[Pi]\ /b]\^\(\(\ \)\(2\)\)\)\)]],
  ",   ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0, 1, 2,  ... \)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tFor this problem, the grid is chosen as ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(x\_j\), "=", " ", 
          RowBox[{"j", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ", with ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], "=", \(b/\((M - 1/2)\)\)}], ","}], 
        TraditionalForm]]],
  " so that ",
  Cell[BoxData[
      \(TraditionalForm\`x = b\)]],
  " falls halfway between the ",
  Cell[BoxData[
      \(TraditionalForm\`M - 1  st\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  "th points, as discussed previously in Sec. ",
  ButtonBox["6.2.1",
    ButtonData:>"c:14",
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell["\<\
\t  We can use a centered-difference scheme for the second \
derivative at the interior points, to obtain\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(\(L\)\(\ \)\)\_\(j\ k\)\), "=", " ", 
          RowBox[{"\[Chi]", "  ", 
            
            RowBox[{\((\[Delta]\_\(j + 1  k\) - \ 
                  2  \[Delta]\_\(j\ k\)\  + \[Delta]\_\(j - 1, k\))\), "/", 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"], " "}]}]}], 
        TraditionalForm]]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`j = 1, 2, \(\(...\)\(.\)\(\ \)\(M\)\) - 1\)]]
}], "NE3",
  CellTags->{"(2.4.49)", "(6.3.6)"}],

Cell[TextData[{
  " We then modify the  last column of the matrix equation to set the \
derivative of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  " equal to zero at ",
  Cell[BoxData[
      \(TraditionalForm\`x = b\)]],
  ",  according to Eq. ",
  ButtonBox["(6.3.5)",
    ButtonData:>"(6.3.5)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tBelow, we construct ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(L\_\(j\ k\)\)\(\ \)\)\)]],
  " (called",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          StyleBox["lmat",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  " in the module)."
}], "Text"],

Cell[BoxData[{
    RowBox[{\(Clear["\<Global`*\>"];\), "\n"}], "\[IndentingNewLine]", 
    RowBox[{\(creatematrix[M_]\), " ", ":=", " ", 
      RowBox[{"Module", "[", 
        RowBox[{\({L}\), ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
          
          RowBox[{\(L[j_, 
                k_] = \[Chi] \((KroneckerDelta[j + 1, k]\  + \ 
                      KroneckerDelta[j - 1, k]\  - 
                      2\ KroneckerDelta[j, k])\)/\[CapitalDelta]x\^2\), "  ", 
            ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                modify\ the\ rightmost\ column\ to\ acccount\ for\ von\ \
Neumann\ \(\(conditions\)\(:\)\)\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(L[j_, M - 1]\  = \ 
              L[j, M - 1]\  + \ L[j, M]\), ";", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \(lmat\  = \ 
              Table[L[j, k], {j, 1, M - 1}, {k, 1, M - 1}]\), ";"}]}], 
        "]"}]}]}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.132"],

Cell[TextData[{
  "Here is the form of the matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["L",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", keeping only six columns so as to show the structure:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(creatematrix[6];\)\), "\n", 
    \(MatrixForm[lmat]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.133"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-\(\(2\ \[Chi]\)\/\[CapitalDelta]x\^2\)\), \(\[Chi]\/\
\[CapitalDelta]x\^2\), "0", "0", "0"},
            {\(\[Chi]\/\[CapitalDelta]x\^2\), \(-\(\(2\ \[Chi]\)\/\
\[CapitalDelta]x\^2\)\), \(\[Chi]\/\[CapitalDelta]x\^2\), "0", "0"},
            {
              "0", \(\[Chi]\/\[CapitalDelta]x\^2\), \(-\(\(2\ \[Chi]\)\/\
\[CapitalDelta]x\^2\)\), \(\[Chi]\/\[CapitalDelta]x\^2\), "0"},
            {"0", 
              "0", \(\[Chi]\/\[CapitalDelta]x\^2\), \(-\(\(2\ \[Chi]\)\/\
\[CapitalDelta]x\^2\)\), \(\[Chi]\/\[CapitalDelta]x\^2\)},
            {"0", "0", 
              "0", \(\[Chi]\/\[CapitalDelta]x\^2\), \(-\(\[Chi]\/\
\[CapitalDelta]x\^2\)\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "We now determine the eigenvalues and eigenvectors, taking ",
  Cell[BoxData[
      \(TraditionalForm\`M = 100\)]],
  " points, and taking ",
  Cell[BoxData[
      \(TraditionalForm\`b = \[Pi]/2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi] = 1\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(b = Pi/2; \[Chi] = 1; 
    M = 100; \[CapitalDelta]x\  = \ 
      b/\((M - 1/2)\);\[IndentingNewLine]\), "\n", 
    \(\(creatematrix[100];\)\), "\n", 
    \(\[Lambda]\  = \ Eigenvalues[lmat // N]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.134"],

Cell[BoxData[
    \({\(-16045.68110597134`\), \(-16033.68608979855`\), \
\(-16013.70768205545`\), \(-15985.76579765333`\), \(-15949.88828967033`\), \
\(-15906.110921586554`\), \(-15854.477331634647`\), \(-15795.038989299937`\), \
\(-15727.855144014742`\), \(-15652.99276609707`\), \(-15570.526479993336`\), \
\(-15480.538489890992`\), \(-15383.11849777559`\), \(-15278.363614013977`\), \
\(-15166.378260552377`\), \(-15047.274066826614`\), \(-14921.169758487165`\), \
\(-14788.191039051075`\), \(-14648.470464597882`\), \(-14502.14731163479`\), \
\(-14349.367438262812`\), \(-14190.283138782399`\), \(-14025.052991882885`\), \
\(-13853.84170256815`\), \(-13676.819937974778`\), \(-13494.16415724763`\), \
\(-13306.056435641134`\), \(-13112.68428302317`\), \(-12914.240456960799`\), \
\(-12710.922770575555`\), \(-12502.933895358949`\), \(-12290.481159144985`\), \
\(-12073.776339441549`\), \(-11853.035452325665`\), \(-11628.478537114303`\), \
\(-11400.32943702403`\), \(-11168.815576039618`\), \(-10934.16773221247`\), \
\(-10696.619807616444`\), \(-10456.408595188888`\), \(-10213.773542690356`\), \
\(-9968.956514017875`\), \(-9722.201548109859`\), \(-9473.754615682703`\), \
\(-9223.86337404173`\), \(-8972.776920211207`\), \(-8720.745542628805`\), \
\(-8468.020471652802`\), \(-8214.853629130137`\), \(-7961.497377275222`\), \
\(-7708.2042671098125`\), \(-7455.226786714602`\), \(-7202.817109543798`\), \
\(-6951.226843052867`\), \(-6700.7067778909395`\), \(-6451.506637907241`\), \
\(-6203.874831220785`\), \(-5958.058202601891`\), \(-5714.301787411913`\), \
\(-5472.848567346623`\), \(-5233.939228226848`\), \(-4997.811920077521`\), \
\(-4764.702019734624`\), \(-4534.841896216433`\), \(-4308.460679092955`\), \
\(-4085.7840300846938`\), \(-3867.0339181180702`\), \(-3652.4283980620144`\), \
\(-3442.181393366048`\), \(-3236.5024828168703`\), \(-3035.596691625533`\), \
\(-2839.6642870539117`\), \(-2648.900578783973`\), \(-2463.495724228773`\), \
\(-2283.6345389794506`\), \(-2109.496312577035`\), \(-1941.2546297926847`\), \
\(-1779.0771975946732`\), \(-1623.1256779743921`\), \(-1473.5555267981708`\), \
\(-1330.5158388455052`\), \(-1194.1491991881287`\), \(-1064.5915410580958`\), \
\(-941.9720103466162`\), \(-826.4128368685833`\), \(-718.0292125212661`\), \
\(-616.9291764585001`\), \(-523.2135073949208`\), \(-436.9756231475416`\), \
\(-358.3014875148625`\), \(-287.26952458625425`\), \(-223.9505405671418`\), \
\(-168.4076531978349`\), \(-120.6962288363958`\), \(-80.86382726823345`\), \
\(-48.950154297493334`\), \(-24.987022167441065`\), \(-8.99831784932892`\), \
\(-0.999979231329795`\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "As expected, the eigenvalues are negative. In cell ",
  "6.",
  "135, we plot these eigenvalues in order of increasing absolute value and \
compare them with the exact eigenvalues, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\  = \ \(\(-\((2  n - 1)\)\^2\) = \(-1\)\), \
\(-9\), \(-25\), \(-49\),  ... \)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(\[Lambda]1\  = \ 
        Table[\(Reverse[\[Lambda]]\)[\([n]\)], {n, 1, 
            Length[\[Lambda]]}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(ListPlot[\[Lambda]1, DisplayFunction \[Rule] Identity];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Plot[\(-\((2  n - 1)\)^2\), {n, 1, 80}, 
        DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Show[%, %%, DisplayFunction \[Rule] $DisplayFunction, 
        AxesLabel \[Rule] {"\<n\>", \*"\"\<\!\(\[Lambda]\_n\)\>\""}];\)\)}], \
"Input",
  ShowCellTags->True,
  CellTags->"Cell 6.135"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00962001 0.603319 2.32825e-05 [
[.21621 .59082 -6 -9 ]
[.21621 .59082 6 0 ]
[.40861 .59082 -6 -9 ]
[.40861 .59082 6 0 ]
[.60101 .59082 -6 -9 ]
[.60101 .59082 6 0 ]
[.79341 .59082 -6 -9 ]
[.79341 .59082 6 0 ]
[.98581 .59082 -9 -9 ]
[.98581 .59082 9 0 ]
[1.025 .60332 0 -6 ]
[1.025 .60332 10 6 ]
[.01131 .02126 -36 -4.5 ]
[.01131 .02126 0 4.5 ]
[.01131 .13767 -36 -4.5 ]
[.01131 .13767 0 4.5 ]
[.01131 .25408 -36 -4.5 ]
[.01131 .25408 0 4.5 ]
[.01131 .37049 -36 -4.5 ]
[.01131 .37049 0 4.5 ]
[.01131 .48691 -30 -4.5 ]
[.01131 .48691 0 4.5 ]
[.02381 .64303 -7.625 0 ]
[.02381 .64303 7.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21621 .60332 m
.21621 .60957 L
s
[(20)] .21621 .59082 0 1 Mshowa
.40861 .60332 m
.40861 .60957 L
s
[(40)] .40861 .59082 0 1 Mshowa
.60101 .60332 m
.60101 .60957 L
s
[(60)] .60101 .59082 0 1 Mshowa
.79341 .60332 m
.79341 .60957 L
s
[(80)] .79341 .59082 0 1 Mshowa
.98581 .60332 m
.98581 .60957 L
s
[(100)] .98581 .59082 0 1 Mshowa
.125 Mabswid
.07191 .60332 m
.07191 .60707 L
s
.12001 .60332 m
.12001 .60707 L
s
.16811 .60332 m
.16811 .60707 L
s
.26431 .60332 m
.26431 .60707 L
s
.31241 .60332 m
.31241 .60707 L
s
.36051 .60332 m
.36051 .60707 L
s
.45671 .60332 m
.45671 .60707 L
s
.50481 .60332 m
.50481 .60707 L
s
.55291 .60332 m
.55291 .60707 L
s
.64911 .60332 m
.64911 .60707 L
s
.69721 .60332 m
.69721 .60707 L
s
.74531 .60332 m
.74531 .60707 L
s
.84151 .60332 m
.84151 .60707 L
s
.88961 .60332 m
.88961 .60707 L
s
.93771 .60332 m
.93771 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
gsave
1.025 .60332 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .02126 m
.03006 .02126 L
s
[(-25000)] .01131 .02126 1 0 Mshowa
.02381 .13767 m
.03006 .13767 L
s
[(-20000)] .01131 .13767 1 0 Mshowa
.02381 .25408 m
.03006 .25408 L
s
[(-15000)] .01131 .25408 1 0 Mshowa
.02381 .37049 m
.03006 .37049 L
s
[(-10000)] .01131 .37049 1 0 Mshowa
.02381 .48691 m
.03006 .48691 L
s
[(-5000)] .01131 .48691 1 0 Mshowa
.125 Mabswid
.02381 .04454 m
.02756 .04454 L
s
.02381 .06782 m
.02756 .06782 L
s
.02381 .0911 m
.02756 .0911 L
s
.02381 .11439 m
.02756 .11439 L
s
.02381 .16095 m
.02756 .16095 L
s
.02381 .18423 m
.02756 .18423 L
s
.02381 .20752 m
.02756 .20752 L
s
.02381 .2308 m
.02756 .2308 L
s
.02381 .27736 m
.02756 .27736 L
s
.02381 .30065 m
.02756 .30065 L
s
.02381 .32393 m
.02756 .32393 L
s
.02381 .34721 m
.02756 .34721 L
s
.02381 .39378 m
.02756 .39378 L
s
.02381 .41706 m
.02756 .41706 L
s
.02381 .44034 m
.02756 .44034 L
s
.02381 .46362 m
.02756 .46362 L
s
.02381 .51019 m
.02756 .51019 L
s
.02381 .53347 m
.02756 .53347 L
s
.02381 .55675 m
.02756 .55675 L
s
.02381 .58004 m
.02756 .58004 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -68.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(l) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
74.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03343 .6033 m
.03522 .60328 L
.03714 .60325 L
.04059 .60317 L
.0447 .60306 L
.04844 .60292 L
.05657 .60253 L
.06426 .60204 L
.08038 .60062 L
.09788 .59849 L
.13049 .59288 L
.16189 .58544 L
.19209 .57643 L
.22423 .56481 L
.25517 .55167 L
.28807 .53558 L
.31976 .51802 L
.35023 .49923 L
.38267 .47718 L
.41389 .45394 L
.44707 .42711 L
.47905 .39915 L
.50981 .37031 L
.54253 .33755 L
.57404 .30395 L
.60434 .26977 L
.6366 .23134 L
.66765 .19238 L
.70065 .14884 L
.73245 .10481 L
.76303 .06054 L
.79341 .01472 L
s
.008 w
.03343 .6033 Mdot
.04305 .60311 Mdot
.05267 .60274 Mdot
.06229 .60218 Mdot
.07191 .60144 Mdot
.08153 .60051 Mdot
.09115 .5994 Mdot
.10077 .5981 Mdot
.11039 .59663 Mdot
.12001 .59498 Mdot
.12963 .59315 Mdot
.13925 .59114 Mdot
.14887 .58896 Mdot
.15849 .5866 Mdot
.16811 .58408 Mdot
.17773 .58139 Mdot
.18735 .57853 Mdot
.19697 .57552 Mdot
.20659 .57234 Mdot
.21621 .56901 Mdot
.22583 .56553 Mdot
.23545 .5619 Mdot
.24507 .55812 Mdot
.25469 .5542 Mdot
.26431 .55015 Mdot
.27393 .54596 Mdot
.28355 .54165 Mdot
.29317 .5372 Mdot
.30279 .53264 Mdot
.31241 .52797 Mdot
.32203 .52318 Mdot
.33165 .51828 Mdot
.34127 .51328 Mdot
.35089 .50819 Mdot
.36051 .50301 Mdot
.37013 .49774 Mdot
.37975 .49238 Mdot
.38937 .48696 Mdot
.39899 .48146 Mdot
.40861 .4759 Mdot
.41823 .47028 Mdot
.42785 .4646 Mdot
.43747 .45888 Mdot
.44709 .45311 Mdot
.45671 .44731 Mdot
.46633 .44148 Mdot
.47595 .43562 Mdot
.48557 .42974 Mdot
.49519 .42385 Mdot
.50481 .41796 Mdot
.51443 .41206 Mdot
.52405 .40616 Mdot
.53367 .40028 Mdot
.54329 .39441 Mdot
.55291 .38856 Mdot
.56253 .38275 Mdot
.57215 .37696 Mdot
.58177 .37122 Mdot
.59139 .36552 Mdot
.60101 .35987 Mdot
.61063 .35428 Mdot
.62025 .34874 Mdot
.62987 .34328 Mdot
.63949 .33789 Mdot
.64911 .33258 Mdot
.65873 .32735 Mdot
.66835 .32221 Mdot
.67797 .31717 Mdot
.68759 .31222 Mdot
.69721 .30738 Mdot
.70683 .30264 Mdot
.71645 .29802 Mdot
.72607 .29352 Mdot
.73569 .28914 Mdot
.74531 .28489 Mdot
.75493 .28077 Mdot
.76455 .27678 Mdot
.77417 .27293 Mdot
.78379 .26923 Mdot
.79341 .26567 Mdot
.80303 .26227 Mdot
.81265 .25901 Mdot
.82227 .25592 Mdot
.83189 .25298 Mdot
.84151 .25021 Mdot
.85113 .2476 Mdot
.86075 .24516 Mdot
.87037 .24289 Mdot
.87999 .2408 Mdot
.88961 .23888 Mdot
.89923 .23714 Mdot
.90885 .23557 Mdot
.91847 .23419 Mdot
.92809 .23299 Mdot
.93771 .23197 Mdot
.94733 .23113 Mdot
.95695 .23048 Mdot
.96657 .23002 Mdot
.97619 .22974 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo0006ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0
h_ooool00ol0003oooooooooo`1@ooooo`001_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0>;ooooo
00?o0000ooooooooool0D?ooool000Co00000oooool00onHV9So8B4Qonk^kP09ooooo`04o`000?oo
oooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`03ooooo`?o0000hOooool00ol0003oooooooooo`1Aoooo
o`002?ooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;oooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0h?ooool00ol0003oooooooooo`1Booooo`002Oooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000001Oooool00ol0003oooooooooo`3Pooooo`03o`000?oooooooooo05;ooooo000:ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Ooo
ool00ol0003oooooooooo`3Oooooo`03o`000?oooooooooo05?ooooo0006ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`03o`000?oooooooooo0=kooooo00?o0000ooooooooool0E?ooool000Kooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ooooo
ooooo`3Nooooo`03o`000?oooooooooo05Cooooo000`ooooo`03o`000?oooooooooo0=gooooo00?o
0000ooooooooool0EOooool0033ooooo0_l0003Nooooo`03o`000?oooooooooo05Gooooo000`oooo
o`03o`000?oooooooooo0=cooooo00?o0000ooooooooool0E_ooool0033ooooo00?o0000oooooooo
ool0foooool00ol0003oooooooooo`1Gooooo`00<?ooool00ol0003oooooooooo`3Kooooo`03o`00
0?oooooooooo05Oooooo000`ooooo`03o`000?oooooooooo0=[ooooo00?o0000ooooooooool0F?oo
ool0033ooooo00?o0000ooooooooool0fOooool00ol0003oooooooooo`1Iooooo`00<?ooool00ol0
003oooooooooo`3Iooooo`03o`000?oooooooooo05Wooooo000`ooooo`;o0000fOooool00ol0003o
ooooooooo`1Jooooo`00<?ooool00ol0003oooooooooo`3Gooooo`03o`000?oooooooooo05_ooooo
000`ooooo`03o`000?oooooooooo0=Oooooo00?o0000ooooooooool0Foooool0033ooooo00?o0000
ooooooooool0e_ooool00ol0003oooooooooo`1Looooo`00<?ooool00ol0003oooooooooo`3Eoooo
o`03o`000?oooooooooo05gooooo000`ooooo`03o`000?oooooooooo0=Cooooo00?o0000oooooooo
ool0G_ooool0033ooooo00?o0000ooooooooool0e?ooool00ol0003oooooooooo`1Nooooo`00<?oo
ool2o`000=Cooooo00?o0000ooooooooool0Goooool0033ooooo00?o0000ooooooooool0d_ooool0
0ol0003oooooooooo`1Pooooo`00<?ooool00ol0003oooooooooo`3Booooo`03o`000?oooooooooo
063ooooo000`ooooo`03o`000?oooooooooo0=7ooooo00?o0000ooooooooool0HOooool0033ooooo
00?o0000ooooooooool0d?ooool00ol0003oooooooooo`1Rooooo`00<?ooool00ol0003ooooooooo
o`3@ooooo`03o`000?oooooooooo06;ooooo000`ooooo`03o`000?oooooooooo0<oooooo00?o0000
ooooooooool0Hoooool0033ooooo0_l0003?ooooo`03o`000?oooooooooo06Cooooo000`ooooo`03
o`000?oooooooooo0<kooooo00?o0000ooooooooool0I?ooool0033ooooo00?o0000ooooooooool0
cOooool00ol0003oooooooooo`1Uooooo`00<?ooool00ol0003oooooooooo`3<ooooo`03o`000?oo
oooooooo06Kooooo0006ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`1Woooo
o`001_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0<_ooooo00?o0000oooooooo
ool0Ioooool000Co00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`3:ooooo`03o`000?oo
oooooooo06Sooooo0008ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000005ooooo`?o0000bOooool00ol0003oooooooooo`1Yoooo
o`002Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool00ol0003oooooooooo`39ooooo`03o`000?oooooooooo06Wooooo
000:ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool0
0ol@413oooooooooo`03ooooo`03o`000?oooooooooo0<Sooooo00?o0000ooooooooool0J_ooool0
00Kooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`37ooooo`03o`000?oooooooooo
06_ooooo0006ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0aoooool00ol0003o
ooooooooo`1[ooooo`00<?ooool00ol0003oooooooooo`36ooooo`03o`000?oooooooooo06cooooo
000`ooooo`03o`000?oooooooooo0<Gooooo00?o0000ooooooooool0KOooool0033ooooo0_l00035
ooooo`03o`000?oooooooooo06kooooo000`ooooo`03o`000?oooooooooo0<Cooooo00?o0000oooo
ooooool0K_ooool0033ooooo00?o0000ooooooooool0`oooool00ol0003oooooooooo`1_ooooo`00
<?ooool00ol0003oooooooooo`32ooooo`03o`000?oooooooooo073ooooo000`ooooo`03o`000?oo
oooooooo0<7ooooo00?o0000ooooooooool0LOooool0033ooooo00?o0000ooooooooool0`?ooool0
0ol0003oooooooooo`1booooo`00<?ooool2o`000<7ooooo00?o0000ooooooooool0L_ooool0033o
oooo00?o0000ooooooooool0_oooool00ol0003oooooooooo`1cooooo`00<?ooool00ol0003ooooo
ooooo`2nooooo`03o`000?oooooooooo07Cooooo000`ooooo`03o`000?oooooooooo0;gooooo00?o
0000ooooooooool0MOooool0033ooooo00?o0000ooooooooool0_Oooool00ol0003oooooooooo`1e
ooooo`00<?ooool00ol0003oooooooooo`2looooo`03o`000?oooooooooo07Kooooo000`ooooo`03
o`000?oooooooooo0;_ooooo00?o0000ooooooooool0Moooool0033ooooo0_l0002kooooo`03o`00
0?oooooooooo07Sooooo000`ooooo`03o`000?oooooooooo0;Wooooo00?o0000ooooooooool0NOoo
ool0033ooooo00?o0000ooooooooool0^?ooool00ol0003oooooooooo`1jooooo`00<?ooool00ol0
003oooooooooo`2gooooo`03o`000?oooooooooo07_ooooo000`ooooo`03o`000?oooooooooo0;Ko
oooo00?o0000ooooooooool0O?ooool0033ooooo00?o0000ooooooooool0]Oooool00ol0003ooooo
ooooo`1mooooo`00<?ooool00ol0003oooooooooo`2dooooo`03o`000?oooooooooo07kooooo000`
ooooo`;o0000]?ooool00ol0003oooooooooo`1Fooooo`;o000000Coooooo`000?l0003ooooo0_l0
00001?oooooo0000o`000?ooool2o`0001_ooooo000`ooooo`03o`000?oooooooooo0;?ooooo00?o
0000ooooooooool0C_ooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo
0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000001_ooooo000`ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool0BOooool2o`000004ooooool0003o0000ooooo`;o
000000?oooooo`000?l000000_l0000Zooooo`00<?ooool00ol0003oooooooooo`2aooooo`03o`00
0?oooooooooo04Oooooo0_l000001?oooooo0000o`000?ooool2o`0003;ooooo000`ooooo`03o`00
0?oooooooooo0;3ooooo00?o0000ooooooooool0@_ooool2o`000004ooooool0003o0000ooooo`;o
0000>?ooool000Oooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Wo<S8bomgMgOoo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;3ooooo00?o0000oooooooo
ool0@?ooool4o`000003ooooool0003o000003_ooooo0009ooooo`03o`000?oooooooooo00Kooooo
00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0:oooooo
00?o0000ooooooooool0?_ooool2o`000003ooooool0003o0000043ooooo0004o`0000Gooooo00?o
0000ooooooooool01oooool01?l0003oooooooooool@4103ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00oooool3o`00
0:kooooo00?o0000ooooooooool0>Oooool2o`000004ooooool0003o0000ooooo`;o0000@oooool0
00Wooooo00?o0000ooooooooool01_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool0=oooool2o`000004oooo
ool0003o0000ooooo`;o0000A_ooool000Wooooo00?o0000ooooooooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0[Ooo
ool00ol0003oooooooooo`0dooooo`;o000000?oooooo`000?l00000C?ooool000Wooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03
o`000?oooooooooo0:cooooo00?o0000ooooooooool0<_ooool2o`000003ooooool0003o000004oo
oooo0009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo037ooooo1?l0001B
ooooo`001oooool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo03;ooooo0_l0001Dooooo`00<?oo
ool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02oooooo0_l0001Gooooo`00<?ooool2
o`000:[ooooo00?o0000ooooooooool0;Oooool2o`000003ooooool0003o000005Oooooo000`oooo
o`03o`000?oooooooooo0:Sooooo00?o0000ooooooooool0:oooool2o`000003ooooool0003o0000
05[ooooo000`ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool0:Oooool2o`000003
ooooool0003o000005gooooo000`ooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool0
9oooool2o`000003ooooool0003o0000063ooooo000`ooooo`03o`000?oooooooooo0:Gooooo00?o
0000ooooooooool0:?ooool2o`0006?ooooo000`ooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooooooool09_ooool2o`0006Kooooo000`ooooo`03o`000?oooooooooo0:?ooooo00?o0000oooo
ooooool09Oooool4o`0006Kooooo000`ooooo`;o0000Xoooool00ol0003oooooooooo`0Sooooo`;o
000000?oooooo`000?l00000J?ooool0033ooooo00?o0000ooooooooool0XOooool00ol0003ooooo
ooooo`0Tooooo`;o0000Joooool0033ooooo00?o0000ooooooooool0XOooool00ol0003ooooooooo
o`0Qooooo`;o0000K_ooool0033ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0O
ooooo`;o000000?oooooo`000?l00000K_ooool0033ooooo00?o0000ooooooooool0Woooool00ol0
003oooooooooo`0Pooooo`;o0000LOooool0033ooooo00?o0000ooooooooool0W_ooool00ol0003o
ooooooooo`0Nooooo`;o0000M?ooool0033ooooo00?o0000ooooooooool0WOooool00ol0003ooooo
ooooo`0Looooo`;o000000?oooooo`000?l00000M?ooool0033ooooo0_l0002Mooooo`03o`000?oo
oooooooo01gooooo0_l0001gooooo`00<?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooo
oooo01_ooooo0_l0001jooooo`00<?ooool00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo
01[ooooo1?l0001jooooo`00<?ooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo01_o
oooo0_l0001looooo`00<?ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo01Wooooo
0_l0001oooooo`00<?ooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo01Oooooo0_l0
00000ooooooo0000o`00001oooooo`00<?ooool00ol0003oooooooooo`2Fooooo`03o`000?oooooo
oooo01Sooooo0_l00022ooooo`00<?ooool2o`0009Kooooo00?o0000ooooooooool05_ooool2o`00
08Gooooo000`ooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool05oooool2o`0008Go
oooo000`ooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool05Oooool2o`0008Sooooo
000`ooooo`03o`000?oooooooooo09;ooooo00?o0000ooooooooool04oooool2o`000003ooooool0
003o000008Sooooo0007ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0TOooool00ol0003ooooooooo
o`0Dooooo`;o0000Roooool000Wooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0T?ooool00ol0
003oooooooooo`0Booooo`;o0000S_ooool000Co00001Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003ooooo
ooooo`2?ooooo`03o`000?oooooooooo01?ooooo0_l0002>ooooo`002Oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001Oooool3
o`0008gooooo0_l0000Cooooo`;o0000TOooool000Wooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooooooo
ool0S?ooool00ol0003oooooooooo`0Aooooo`Co0000TOooool000Wooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o
0000ooooooooool0Roooool00ol0003oooooooooo`0Booooo`;o0000Toooool000Wooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0@ooooo`;o0000U_ooool000Oo
oooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0Aooooo`;o0000
U_ooool0033ooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`0?ooooo`;o0000VOoo
ool0033ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0@ooooo`;o0000VOooool0
033ooooo0_l00027ooooo`03o`000?oooooooooo00kooooo0_l0002Looooo`00<?ooool00ol0003o
ooooooooo`24ooooo`;o00003_ooool2o`000003ooooool0003o000009cooooo000`ooooo`03o`00
0?oooooooooo08?ooooo00?o0000ooooooooool03_ooool2o`0009oooooo000`ooooo`03o`000?oo
oooooooo08;ooooo00?o0000ooooooooool03?ooool2o`000:;ooooo000`ooooo`03o`000?oooooo
oooo087ooooo00?o0000ooooooooool03Oooool2o`000:;ooooo000`ooooo`03o`000?oooooooooo
083ooooo00?o0000ooooooooool02oooool2o`000:Gooooo000`ooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool03?ooool2o`000:Gooooo000`ooooo`;o0000Ooooool00ol0003ooooo
ooooo`0;ooooo`;o0000Yoooool0033ooooo00?o0000ooooooooool0OOooool00ol0003ooooooooo
o`09ooooo`;o000000?oooooo`000?l00000Yoooool0033ooooo00?o0000ooooooooool0O?ooool0
0ol0003oooooooooo`0:ooooo`;o0000Z_ooool0033ooooo00?o0000ooooooooool0N_ooool2o`00
00[ooooo0_l0002]ooooo`00<?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00[o
oooo0_l0002]ooooo`00<?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Sooooo
0_l0002`ooooo`00<?ooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo00Wooooo0_l0
002`ooooo`00<?ooool2o`0007Kooooo0_l00009ooooo`;o0000/oooool0033ooooo00?o0000oooo
ooooool0M?ooool00ol0003oooooooooo`06ooooo`;o000000?oooooo`000?l00000/oooool0033o
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`07ooooo`;o0000]_ooool0033ooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`05ooooo`;o0000^Oooool0033ooooo00?o
0000ooooooooool0L?ooool2o`0000Sooooo0_l0002iooooo`00<?ooool00ol0003oooooooooo`1_
ooooo`03o`000?oooooooooo00Kooooo0_l0002kooooo`00<?ooool00ol0003oooooooooo`1^oooo
o`03o`000?oooooooooo00Oooooo0_l0002kooooo`00<?ooool2o`0006gooooo0_l00007ooooo`;o
0000__ooool0033ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`04ooooo`;o0000
00?oooooo`000?l00000__ooool0033ooooo00?o0000ooooooooool0J_ooool00ol0003ooooooooo
o`05ooooo`;o0000`Oooool0033ooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`03
ooooo`;o0000a?ooool000oooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`03o`000?oooooooooo06Oooooo0_l00006ooooo`;o0000a?ooool001;ooooo
00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo06Gooooo
0_l00005ooooo`;o0000aoooool000Kooooo1_l00007ooooo`04o`000?oooooooooooa0@40?ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@
413oooooooooo`03ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool00_ooool2o`00
0003ooooool0003o00000<Oooooo000Booooo`05ogMgMolb<S;oooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00?ooooo0ol0001Rooooo`;o00001Oooool2o`000<[ooooo000?ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`1Poooo
o`;o00001?ooool2o`000<gooooo000?ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00Gooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`02ooooo`Co0000cOoo
ool000oooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003o
ooooooooo`1Mooooo`;o00001Oooool2o`000<oooooo000?ooooo`Co00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo00;ooooo0_l0003B
ooooo`00<?ooool00ol0003oooooooooo`1Jooooo`;o00001Oooool2o`000=;ooooo000`ooooo`;o
0000F_ooool00ol0003oooooooooo`02ooooo`;o0000eOooool0033ooooo00?o0000ooooooooool0
Eoooool2o`0000;ooooo0_l000000ooooooo0000o`00003Eooooo`00<?ooool00ol0003ooooooooo
o`1Fooooo`03o`000?oooooooooo00;ooooo0_l0003Hooooo`00<?ooool00ol0003oooooooooo`1D
ooooo`;o00000_ooool2o`000=_ooooo000`ooooo`03o`000?oooooooooo05;ooooo0_l000001?oo
oooo0000o`000?ooool2o`000=_ooooo000`ooooo`03o`000?oooooooooo053ooooo1?l000000ooo
oooo0000o`00003Nooooo`00<?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00;o
0000hOooool0033ooooo0_l0001>ooooo`;o000000?oooooo`000?l00000hoooool0033ooooo00?o
0000ooooooooool0Boooool4o`000003ooooool0003o00000>?ooooo000`ooooo`03o`000?oooooo
oooo04Wooooo0ol000000ooooooo0000o`00003Vooooo`00<?ooool00ol0003oooooooooo`17oooo
o`;o000000?oooooo`000?l00000jOooool0033ooooo00?o0000ooooooooool0AOooool4o`000>co
oooo000`ooooo`03o`000?oooooooooo04?ooooo0ol000000ooooooo0000o`00003/ooooo`00<?oo
ool00ol0003oooooooooo`11ooooo`;o000000?oooooo`000?l00000koooool0033ooooo0_l0000o
ooooo`Go0000l_ooool0033ooooo00?o0000ooooooooool0;oooool5o`0000?ooooo00Cok^k^oc8b
<_l0003o<S8b1Ol0000[ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h0;?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0/
ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Wooooo
1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^013ooooo000`ooooo`03o`000?oooooooooo02oooooo00GoV9RHob4Q8Oo^k^koooooodA4
A003ooooo`03ogMgMonHV9Sooooo00?o0000;oooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`00<?ooool00ol0003oooooooooo`0`ooooo`03oiRH
V?lQ8B7ok^k^00Cooooo1?l000000ol@413oooooooooo`0[ooooo`Go00000oooool01Ol@413ooooo
oooooooooooo410@02cooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?oooooooooo
ooooool@4100;?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@oooooooooooooooo
oa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41004?ooool0033ooooo00?o0000ooooooooool0<Oooool00onHV9So
8B4Qonk^kP04o`000004ooooool0003o0000o`0002gooooo00CoA4A4omgMgOoooooo00001?ooool0
1Ol0003ooooooooooooooooo000002cooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`00
0?ooooooooooooooool00000;?ooool01Olb<S;oV9RHoooooonHV9So<S8b00?ooooo00Go0000oooo
ooooooooooooo`00000[ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000004?ooool0033ooooo00?o0000ooooooooool0<Ooo
ool4o`000003ooooool0003o000000?ooooo00?o0000ooooooooool0:oooool01?oMgMgoEEEEoooo
ool00004ooooo`05o`000?ooooooooooooooool00000;?ooool01Ol0003oEEEEo`000?l@413oc<c<
00?ooooo00Go0000ooooooooooooooooo`00000/ooooo`05olc<c?l0003o0000o`000?o<c<`00ooo
ool01Ol0003ooooooooooooooooo000002_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000@ooooo`00<?ooool00ol0003o
ooooooooo`0]ooooo`Go000000?oooooo`000?l000000_ooool01Ol@413ooooooooooooooooo410@
02kooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@02cooooo00?oEEEE
ohN7Qoooool01Oooool01Ol@413ooooooooooooooooo410@02cooooo00Go410@okZj^_oooooo^[Zj
oa0@4003ooooo`05oa0@4?ooooooooooooooool@4100:oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@013ooooo000`oooo
o`;o0000:oooool8o`000003oiRHV?l@413ooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0^
ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0/ooooo`03omgMgOl@
413oV9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0/ooooo`05o`000?nj^[[ooooookZj^_l0
00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`00<?ooool0
0ol0003oooooooooo`0Wooooo`Go00000oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0_ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0]ooooo`04olc<c?m4A4Co0000oa0@40?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0/
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Wooooo
00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0@ooooo`00<?ooool00ol0003oooooooooo`0Tooooo`Go0000ooooool=ooooo`00
<?ooool00ol0003oooooooooo`0Oooooo`Go000000?oooooo`000?l00000ooooool?ooooo`00<?oo
ool00ol0003oooooooooo`0Iooooo`So000000?oooooo`000?l00000ooooool8ooooo`04oa0@4?l0
003o0000ooooo`;o000000?o410@ooooooooool00Oooool0033ooooo00?o0000ooooooooool04ooo
ool2o`000003ooooool0003o000000?o000000?oooooo`000?l00000ooooool?ooooo`05o`000?oo
ooooooooooooool000001?ooool0033ooooo00?o0000ooooooooool02?ooool2o`000003ooooool0
003o000000_o0000oooooolEooooo`05o`000?ooooooooooooooool000001?ooool002Woooooool0
000/o`0000_ooooo00Go0000ooooooooooooooooo`000004ooooo`00<?ooool01Ol0003oooooo`00
0?l0003ooooo00;o000000?oooooo`000?l000001Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00kooooo00Go0000ohN7QoooooooZJVYo`000004ooooo`00<?ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03Oooool00ol@413o0000
ogMgM`02o`000003oiRHV?oooooooooo00;ooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000aoooo
o`04o`000?ooooooooooo`000?oooooo=?ooool0037ooooo00Co0000oooooooooooo0000oooooold
ooooo`00:_ooool01_l0003oQhN7oooooooooooogMgMoc8b<P;o00000_ooool00ol0003ooooooooo
o`3ooooooc;ooooo000Zooooo`07onk^k_lb<S;oV9RHoooooom4A4CoMgMgooooo`03o`000?oooooo
=Oooool002_ooooo00Gok^k^ob4Q8OnHV9So0000omgMg@3oooooocWooooo000/ooooo`03olc<c?l@
413o00000?oooooo>_ooool002gooooo00?oQhN7o`000?ooool0ooooooliooooo`00;Oooool00oo^
k^ko0000ooooo`3oooooocWooooo000]ooooo`03ohN7QomEEEGooooo0?oooooo>Oooool002cooooo
00?o0000odA4A?o^k^h0ooooooljooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.0273, -27004.8, \
0.436874, 180.511}}]
}, Open  ]],

Cell["\<\
The numerical eigenvalues track the exact eigenvalues reasonably \
well  for the lowest-order modes, but fail for the high-order modes. This is \
to be expected, given that the high-order modes vary rapidly and are not well \
approximated by our finite-difference equations.\
\>", "Text"],

Cell["\<\
\tBelow,  we take a closer look at the error in the eigenvalues, \
examining the difference between the  numerical and the exact eigenvalues : \
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(error\  = 
      Table[\[Lambda]1[\([n]\)]\  + \ \((2  n - 1)\)^2, {n, 1, 
          10}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.136"],

Cell[BoxData[
    \({0.000020768670204951434`, 0.0016821506710797962`, 
      0.01297783255893492`, 0.049845702506665646`, 0.13617273176654976`, 
      0.3037711636041962`, 0.5923468021651104`, 1.0494594328582139`, 
      1.7304754137457508`, 2.698512485137485`}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tThe error in the lowest eigenvalues is quite small.  By varying ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " (increasing or decreasing it by a factor of 2, say), one can easily \
convince oneself that the error in the eigenvalues scales as ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "2"], TraditionalForm]]],
  ", as expected from the second-order accuracy of the differenced \
derivatives. "
}], "Text"],

Cell[TextData[{
  "\tWe now determine the first few eigenfunctions associated with these \
eigenvalues, and compare them with the exact eigenfunctions. First we \
evaluate the eigenvectors of ",
  Cell[BoxData[
      FormBox[
        StyleBox["L",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(\[Psi]vec = Eigenvectors[lmat // N];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.137"],

Cell[TextData[{
  "These eigenvectors only involve the interior points in the domain. To \
properly define the eigenfunctions that are based on these eigenvectors, we \
need to include boundary points. One way to do so is to define a function ",
  StyleBox["\[Psi]val",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that equals the eigenvectors at the interior points, but also is defined \
at the boundary points:"
}], "Text"],

Cell[BoxData[{
    \(\(M = 100;\)\), "\n", 
    \(\[Psi]val[n_, j_]\  := \ \[Psi]vec[\([n, j]\)]\  /; \ 
        1 \[LessEqual] \ j \[LessEqual] \ M - 1\), "\n", 
    \(\(\[Psi]val[n_, 0]\  = \ 0;\)\), "\n", 
    \(\(\[Psi]val[n_, M]\  := \ \[Psi]vec[\([n, M - 1]\)];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.138"],

Cell[TextData[{
  "We can then interpolate these discrete eigenvectors in order to construct \
approximate eigenfunctions defined on ",
  Cell[BoxData[
      \(TraditionalForm\`\([0, b]\)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\[Psi][n_]\  := \ \(\[Psi][n]\  = \ 
        Interpolation[
          Table[{j\ \ \[CapitalDelta]x, \[Psi]val[M - n, j]}, {j, 0, 
              M}]]\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.139"],

Cell[TextData[{
  "In Cell ",
  ButtonBox["6.140",
    ButtonData:>"Cell 6.140",
    ButtonStyle->"Hyperlink"],
  ", we plot the eigenfunctions and compare them with the exact \
eigenfunctions, ",
  Cell[BoxData[
      \(TraditionalForm\`sin[\((2  n - 1)\)\ x]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2, 3,  ... \)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Graphics`;\)\), "\n", 
    \(\(Table[
        Plot[{\(\[Psi][n]\)[x]/\(\[Psi][n]\)[
                b], \((\(-1\))\)^\((n - 1)\)\ Sin[\((2  n - 1)\)\ x\ ]}, {x, 
            0, Pi/2}, AxesLabel \[Rule] {"\<x\>", "\<\[Psi]\>"}, 
          PlotLabel \[Rule] \ "\<n= \>" <> ToString[n], 
          PlotStyle \[Rule] {{Red, Dashing[{0.05, 0.05}]}, Blue}], {n, 1, 30, 
          6}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.140"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0.0147151 0.588604 [
[.17539 .00222 -12 -9 ]
[.17539 .00222 12 0 ]
[.32696 .00222 -9 -9 ]
[.32696 .00222 9 0 ]
[.47854 .00222 -12 -9 ]
[.47854 .00222 12 0 ]
[.63011 .00222 -3 -9 ]
[.63011 .00222 3 0 ]
[.78169 .00222 -12 -9 ]
[.78169 .00222 12 0 ]
[.93327 .00222 -9 -9 ]
[.93327 .00222 9 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 10 6 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[.5 .63053 -14 0 ]
[.5 .63053 14 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .01472 m
.17539 .02097 L
s
[(0.25)] .17539 .00222 0 1 Mshowa
.32696 .01472 m
.32696 .02097 L
s
[(0.5)] .32696 .00222 0 1 Mshowa
.47854 .01472 m
.47854 .02097 L
s
[(0.75)] .47854 .00222 0 1 Mshowa
.63011 .01472 m
.63011 .02097 L
s
[(1)] .63011 .00222 0 1 Mshowa
.78169 .01472 m
.78169 .02097 L
s
[(1.25)] .78169 .00222 0 1 Mshowa
.93327 .01472 m
.93327 .02097 L
s
[(1.5)] .93327 .00222 0 1 Mshowa
.125 Mabswid
.05412 .01472 m
.05412 .01847 L
s
.08444 .01472 m
.08444 .01847 L
s
.11476 .01472 m
.11476 .01847 L
s
.14507 .01472 m
.14507 .01847 L
s
.2057 .01472 m
.2057 .01847 L
s
.23602 .01472 m
.23602 .01847 L
s
.26633 .01472 m
.26633 .01847 L
s
.29665 .01472 m
.29665 .01847 L
s
.35728 .01472 m
.35728 .01847 L
s
.38759 .01472 m
.38759 .01847 L
s
.41791 .01472 m
.41791 .01847 L
s
.44822 .01472 m
.44822 .01847 L
s
.50885 .01472 m
.50885 .01847 L
s
.53917 .01472 m
.53917 .01847 L
s
.56948 .01472 m
.56948 .01847 L
s
.5998 .01472 m
.5998 .01847 L
s
.66043 .01472 m
.66043 .01847 L
s
.69074 .01472 m
.69074 .01847 L
s
.72106 .01472 m
.72106 .01847 L
s
.75138 .01472 m
.75138 .01847 L
s
.81201 .01472 m
.81201 .01847 L
s
.84232 .01472 m
.84232 .01847 L
s
.87264 .01472 m
.87264 .01847 L
s
.90295 .01472 m
.90295 .01847 L
s
.96358 .01472 m
.96358 .01847 L
s
.9939 .01472 m
.9939 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ .05 .05 ] 0 setdash
.02381 .01472 m
.06244 .0522 L
.10458 .0929 L
.14415 .13078 L
.18221 .16675 L
.22272 .20437 L
.26171 .23979 L
.30316 .27641 L
.34309 .31054 L
.3815 .34217 L
.42237 .37437 L
.46172 .40383 L
.49955 .43061 L
.53984 .45735 L
.57861 .48124 L
.61984 .50455 L
.65954 .52486 L
.69774 .54233 L
.73838 .55862 L
.77751 .572 L
.81909 .58367 L
.85916 .59239 L
.87754 .59554 L
.89771 .59839 L
.91765 .60058 L
.92854 .6015 L
.93871 .60219 L
.94354 .60247 L
.94878 .60272 L
.95341 .6029 L
.95832 .60306 L
.96273 .60317 L
.96524 .60322 L
.9676 .60326 L
.96976 .60329 L
.97173 .6033 L
.97277 .60331 L
.97391 .60331 L
.97509 .60332 L
.97619 .60332 L
s
0 0 1 r
[ ] 0 setdash
.02381 .01472 m
.06244 .0522 L
.10458 .0929 L
.14415 .13078 L
.18221 .16675 L
.22272 .20437 L
.26171 .23979 L
.30316 .27641 L
.34309 .31054 L
.3815 .34217 L
.42237 .37437 L
.46172 .40383 L
.49955 .43061 L
.53984 .45735 L
.57861 .48124 L
.61984 .50455 L
.65954 .52486 L
.69774 .54233 L
.73838 .55862 L
.77751 .572 L
.81909 .58367 L
.85916 .59239 L
.87754 .59554 L
.89771 .59839 L
.91765 .60058 L
.92854 .6015 L
.93871 .60219 L
.94354 .60247 L
.94878 .60272 L
.95341 .6029 L
.95832 .60306 L
.96273 .60317 L
.96524 .60322 L
.9676 .60326 L
.96976 .60329 L
.97173 .6033 L
.97277 .60331 L
.97391 .60331 L
.97509 .60332 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00@Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd07Oooool4o`000003oa0@4?oooooooooo01_ooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Eooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Wooooo`00@Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool04oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46oooo
o`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool07_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`0Fooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo02Kooooo0011ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09
ooooo`03o`000?oooooooooo01;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo01;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00_ooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool09Oooool0047ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool04oooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool04oooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`0Nooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo01Kooooo00?o0000oooo
ooooool03_ooool00omgMgOo<S8booooo`0Vooooo`00@Oooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05?ooool01Ol0003ooooo
oooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
01oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Gooooo`03o`000?oooooooooo00_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00Wooooo`00@Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00ol0003oooooooooo`0Fooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWo
MgMgooooo`03ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo0011ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool05_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool05_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0:Oooool0047ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0001Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00005Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00007_ooool00omEEEGoIVIVo`00
000Oooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000
5_ooool00omEEEGoIVIVo`00000=ooooo`Co0000:?ooool00?ooooooJOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooooc?ooooo0_l00002oooo
o`;o00003?ooool0027ooooo00?o0000ooooooooool0oooooolcooooo`06onk^k_lQ8B7oQhN7okZj
^_l0003ogMgM3?ooool0027ooooo00?o0000ooooooooool0ooooooldooooo`04omgMgOl0003o410@
olc<c0gooooo000Jooooo`Oo000000?o003oo`000?l00000ool0000Yo`0000_ooooo00Cok^k^ob4Q
8Ol@413ok^k^3Oooool0027ooooo00?o0000o`00ooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00_ooooo00Co8B4QogMgMomgMgOo<S8b3Oooool0027ooooo00?o0000oooo
ool00?l0;?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool07Oooool2o`0000;ooooo0_l0000<ooooo`008Oooool01?l0003oooooooooool00?oooooo
odCooooo000Qooooo`05o`000?ooooooooooooooool00?l0oooooom3ooooo`008Oooool00ol0003o
ooooooooo`02ooooo`03o`00oooooooooooo0?oooooo@?ooool0027ooooo00?o0000ooooooooool0
0oooool00ol00?ooooooooooo`3oooooocoooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o
003oooooooooool0oooooolnooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`00oooooooo
oooo0?oooooo?Oooool0027ooooo0ol00006ooooo`03o`00oooooooooooo0?oooooo??ooool0027o
oooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`3ooooooc_ooooo000Qooooo`03o`00
0?oooooooooo00Sooooo00?o003oooooooooool0ooooooljooooo`008Oooool00ol0003ooooooooo
o`09ooooo`;o003oooooooljooooo`008Oooool00ol0003oooooooooo`0;ooooo`03o`00oooooooo
oooo0?oooooo=oooool0027ooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`3ooooo
ocKooooo000Qooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool0ooooooleooooo`00
8Oooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo0?oooooo=?ooool0027ooooo00?o
0000ooooooooool03oooool00ol00?ooooooooooo`3ooooooc?ooooo000Qooooo`?o00004?ooool0
0ol00?ooooooooooo`3ooooooc;ooooo000Qooooo`03o`000?oooooooooo017ooooo00?o003ooooo
ooooool0oooooolaooooo`008Oooool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo0?oo
oooo<?ooool0027ooooo00?o0000ooooooooool04oooool00ol00?ooooooooooo`3ooooooboooooo
000Qooooo`03o`000?oooooooooo01Cooooo00?o003oooooooooool0ooooool^ooooo`008Oooool0
0ol0003oooooooooo`0Eooooo`03o`00oooooooooooo0?oooooo;Oooool0027ooooo00?o0000oooo
ooooool05_ooool00ol00?ooooooooooo`3oooooobcooooo000Qooooo`03o`000?oooooooooo01Oo
oooo00?o003oooooooooool0ooooool[ooooo`008Oooool00ol0003oooooooooo`0Hooooo`03o`00
oooooooooooo0?oooooo:_ooool0027ooooo0ol0000Iooooo`03o`00oooooooooooo0?oooooo:Ooo
ool0027ooooo00?o0000ooooooooool06_ooool00ol00?ooooooooooo`3oooooobSooooo000Qoooo
o`03o`000?oooooooooo01_ooooo00?o003oooooooooool0oooooolWooooo`008Oooool00ol0003o
ooooooooo`0Looooo`03o`00oooooooooooo0?oooooo9_ooool0027ooooo00?o0000ooooooooool0
7Oooool00ol00?ooooooooooo`3oooooobGooooo000Qooooo`03o`000?oooooooooo01kooooo00?o
003oooooooooool0oooooolTooooo`008Oooool00ol0003oooooooooo`0Oooooo`03o`00oooooooo
oooo0?oooooo8oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Gooooo00?o0000ooooooooool08?ooool00ol00?ooooooooooo`3oooooob;ooooo0007oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A005ooooo`03o`000?oooooooooo027ooooo00?o003oooooooooool0oooooolQooooo`001oooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0002;ooooo0_l0
0?ooooooob7ooooo0007ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP05ooooo`03o`000?oooooooooo02Cooooo00?o003oooooooooool0oooooolNooooo`001oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01?ooool00ol0003ooooooooo
o`0Uooooo`03o`00oooooooooooo0?oooooo7Oooool000Oooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09_ooool00ol00?oooooooooo
o`3ooooooacooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Gooooo00?o0000ooooooooool09oooool00ol00?ooooooooooo`3ooooooa_ooooo
0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Go
oooo00?o0000ooooooooool0:?ooool2o`00oooooooo6oooool0027ooooo00?o0000ooooooooool0
:Oooool00ooo003o003oooooo`3ooooooaWooooo000Qooooo`03o`000?oooooooooo02_ooooo00?o
003oooooooooool0oooooolGooooo`008Oooool00ol0003oooooooooo`0/ooooo`03o`00oooooooo
oooo0?oooooo5_ooool0027ooooo0ol0000]ooooo`03o`00oooooooooooo0?oooooo5Oooool0027o
oooo00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`3ooooooaCooooo000Qooooo`03o`00
0?oooooooooo02kooooo00?oo`00o`00ooooool0oooooolDooooo`008Oooool00ol0003ooooooooo
o`0_ooooo`03ool00?l00?oooooo0?oooooo4oooool0027ooooo00?o0000ooooooooool0<?ooool0
0ooo003o003oooooo`3ooooooa;ooooo000Qooooo`03o`000?oooooooooo037ooooo00?oo`00o`00
ooooool0oooooolAooooo`008Oooool00ol0003oooooooooo`0booooo`03ool00?l00?oooooo0?oo
oooo4?ooool0027ooooo00?o0000ooooooooool0<oooool00ooo003o003oooooo`3oooooo`oooooo
000Qooooo`03o`000?oooooooooo03Cooooo00?oo`00o`00ooooool0ooooool>ooooo`008Oooool3
o`0003Kooooo00?o003oooooooooool0ooooool<ooooo`008Oooool00ol0003oooooooooo`0goooo
o`03o`00oooooooooooo0?oooooo2oooool0027ooooo00?o0000ooooooooool0>?ooool00ol00?oo
ooooooooo`3oooooo`[ooooo000Qooooo`03o`000?oooooooooo03Wooooo00?o003oooooooooool0
ooooool9ooooo`008Oooool00ol0003oooooooooo`0jooooo`;o003oooooool9ooooo`008Oooool0
0ol0003oooooooooo`0looooo`03o`00oooooooooooo0?oooooo1_ooool0027ooooo00?o0000oooo
ooooool0?Oooool00ol00?ooooooooooo`3oooooo`Gooooo000Qooooo`03o`000?oooooooooo03ko
oooo00?o003oooooooooool0ooooool4ooooo`008Oooool00ol0003oooooooooo`0oooooo`03o`00
oooooooooooo0?oooooo0oooool0027ooooo0ol00010ooooo`03o`00oooooooooooo0?oooooo0_oo
ool0027ooooo00?o0000ooooooooool0@Oooool00ol00?ooooooooooo`3oooooo`7ooooo000Qoooo
o`03o`000?oooooooooo04;ooooo00?o003oooooooooool0ooooool0027ooooo00?o0000oooooooo
ool0@oooool00ol00?ooooooooooo`3nooooo`008Oooool00ol0003oooooooooo`14ooooo`03o`00
oooooooooooo0?gooooo000Qooooo`03o`000?oooooooooo04Gooooo00?o003oooooooooool0o?oo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0A_ooool2o`00oocooooo0007ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`18ooooo`03o`00oooooooooooo0?Wooooo0007ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0000Gooooo00?o0000ooooooooool0BOooool00ol00?ooooooooooo`3hooooo`001oooool0
1Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001_ooool3o`0004[ooooo
00?o003oooooooooool0moooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgM
gOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0Boooool00ol00?ooooooooooo`3fooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`1<ooooo`;o003om_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
onk^k_m4A4Co000000Kooooo00?o0000ooooooooool0C_ooool00ol00?ooooooooooo`3cooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01Oooool00ol0003o
ooooooooo`1?ooooo`03o`00oooooooooooo0?;ooooo000Qooooo`03o`000?oooooooooo053ooooo
00?o003oooooooooool0lOooool0027ooooo00?o0000ooooooooool0DOooool00ol00?oooooooooo
o`3`ooooo`008Oooool00ol0003oooooooooo`1Booooo`03o`00oooooooooooo0>oooooo000Qoooo
o`03o`000?oooooooooo05?ooooo0_l00?o_ooooo`008Oooool3o`0005Gooooo00?o003ooooooooo
ool0k?ooool0027ooooo00?o0000ooooooooool0E_ooool00ol00?ooooooooooo`3[ooooo`008Ooo
ool00ol0003oooooooooo`1Fooooo`03ool00?l00?oooooo0>_ooooo000Qooooo`03o`000?oooooo
oooo05Sooooo00?o003oooooooooool0jOooool0027ooooo00?o0000ooooooooool0FOooool2o`00
onWooooo000Qooooo`03o`000?oooooooooo05[ooooo00?oo`00o`00ooooool0ioooool0027ooooo
00?o0000ooooooooool0G?ooool00ol00?ooooooooooo`3Uooooo`008Oooool00ol0003ooooooooo
o`1Mooooo`03o`00oooooooooooo0>Cooooo000Qooooo`03o`000?oooooooooo05kooooo00?o003o
ooooooooool0hoooool0027ooooo0ol0001Oooooo`;o003ohoooool0027ooooo00?o0000oooooooo
ool0H?ooool00ooo003o003oooooo`3Qooooo`008Oooool00ol0003oooooooooo`1Qooooo`03ool0
0?l00?oooooo0>3ooooo000Qooooo`03o`000?oooooooooo06;ooooo00?oo`00o`00ooooool0gooo
ool0027ooooo00?o0000ooooooooool0I?ooool00ol00?ooooooooooo`3Mooooo`008Oooool00ol0
003oooooooooo`1Uooooo`03o`00oooooooooooo0=cooooo000Qooooo`03o`000?oooooooooo06Ko
oooo00?o003oooooooooool0foooool0027ooooo00?o0000ooooooooool0Ioooool00ol00?oooooo
ooooo`3Jooooo`008Oooool00ol0003oooooooooo`1Xooooo`03o`00oooooooooooo0=Wooooo000Q
ooooo`?o0000JOooool00ol00?ooooooooooo`3Hooooo`008Oooool00ol0003oooooooooo`1Zoooo
o`;o003of?ooool0027ooooo00?o0000ooooooooool0K?ooool00ol00?ooooooooooo`3Eooooo`00
8Oooool00ol0003oooooooooo`1]ooooo`03o`00oooooooooooo0=Cooooo000Qooooo`03o`000?oo
oooooooo06kooooo0_l00?oDooooo`008Oooool00ol0003oooooooooo`1`ooooo`03o`00oooooooo
oooo0=7ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c005ooooo`03o`000?oooooooooo077ooooo00?o003oooooooooool0d?oo
ool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooo
oonHV9So8B4Q00Gooooo00?o0000ooooooooool0L_ooool00ol00?ooo`00ooooo`3?ooooo`001ooo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo07?ooooo0_l00?o?ooooo`001oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000oiRHV?ooooooV9RHob4Q8@05ooooo`?o0000MOooool00ol00?ooooooooooo`3<oooo
o`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c005
ooooo`03o`000?oooooooooo07Kooooo00?o003oooooooooool0boooool000Oooooo00Go410@oooo
oooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Oooooo00?o0000ooooooooool0Moooool2
o`00ol_ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV007
ooooo`03o`000?oooooooooo07Wooooo00?o003oooooooooool0b?ooool000Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?o0000ooooooooool0N_oo
ool00ol00?ooooooooooo`37ooooo`008Oooool00ol0003oooooooooo`1kooooo`;o003oaoooool0
027ooooo00?o0000ooooooooool0OOooool00ol00?ooooooooooo`34ooooo`008Oooool00ol0003o
ooooooooo`1nooooo`03o`00oooooooooooo0<?ooooo000Qooooo`03o`000?oooooooooo07oooooo
0_l00?o3ooooo`008Oooool3o`00087ooooo00?o003oooooooooool0`?ooool0027ooooo00?o0000
ooooooooool0P_ooool00ol00?ooooooooooo`2oooooo`008Oooool00ol0003oooooooooo`23oooo
o`;o003o_oooool0027ooooo00?o0000ooooooooool0QOooool00ol00?ooooooooooo`2looooo`00
8Oooool00ol0003oooooooooo`26ooooo`03o`00oooo003ooooo0;_ooooo000Qooooo`03o`000?oo
oooooooo08Oooooo0_l00?nkooooo`008Oooool00ol0003oooooooooo`29ooooo`03o`00oooooooo
oooo0;Sooooo000Qooooo`03o`000?oooooooooo08[ooooo0_l00?nhooooo`008Oooool00ol0003o
ooooooooo`2<ooooo`03o`00oooooooooooo0;Gooooo000Qooooo`?o0000SOooool00ol00?oooooo
ooooo`2dooooo`008Oooool00ol0003oooooooooo`2>ooooo`;o003o]?ooool0027ooooo00?o0000
ooooooooool0T?ooool00ol00?ooo`00ooooo`2aooooo`008Oooool00ol0003oooooooooo`2Aoooo
o`;o003o/Oooool0027ooooo00?o0000ooooooooool0Toooool2o`00ojoooooo000Qooooo`03o`00
0?oooooooooo09Gooooo00?o003oooooooooool0[?ooool0027ooooo00?o0000ooooooooool0U_oo
ool2o`00ojcooooo000Qooooo`03o`000?oooooooooo09Sooooo0_l00?nZooooo`008Oooool00ol0
003oooooooooo`2Jooooo`03o`00oooooooooooo0:Oooooo000Qooooo`?o0000Voooool2o`00ojOo
oooo000Qooooo`03o`000?oooooooooo09gooooo00?o003oooooooooool0Y?ooool0027ooooo00?o
0000ooooooooool0W_ooool2o`00ojCooooo000Qooooo`03o`000?oooooooooo09oooooo00?oo`00
o`00ool00?l0X_ooool0027ooooo00?o0000ooooooooool0XOooool00ooo003o003oooooo`2Poooo
o`008Oooool00ol0003oooooooooo`2Sooooo`;o003oWoooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Gooooo00?o0000oooo
ooooool0Y?ooool00ooo003o003oooooo`2Mooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401Oooool00ol0003oooooooooo`2V
ooooo`;o003oW?ooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`2Xooooo`;o003oV_ooool000Oooooo00Go0000
ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801Oooool3o`000:[ooooo
0_l00?nHooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o
0000olc<c005ooooo`03o`000?oooooooooo0:_ooooo00?oo`00o`00ool00?l0U_ooool000Oooooo
00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001Oooool00ol0
003oooooooooo`2]ooooo`03ool00?l00?oooooo09Cooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Gooooo00?o0000ooooooooool0[oooool2
o`00oi?ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00Gooooo00?o0000ooooooooool0/Oooool2o`00oi7ooooo000Qooooo`03o`000?oooooo
oooo0;?ooooo0_l00?n?ooooo`008Oooool00ol0003oooooooooo`2eooooo`;o003oSOooool0027o
oooo00?o0000ooooooooool0]oooool00ol00?ooooooooooo`2:ooooo`008Oooool00ol0003ooooo
ooooo`2hooooo`;o003oR_ooool0027ooooo0ol0002jooooo`;o003oR?ooool0027ooooo00?o0000
ooooooooool0_?ooool00ol00?ooo`00ooooo`25ooooo`008Oooool00ol0003oooooooooo`2moooo
o`;o003oQOooool0027ooooo00?o0000ooooooooool0_oooool2o`00oh?ooooo000Qooooo`03o`00
0?oooooooooo0<7ooooo0ol00?n0ooooo`008Oooool00ol0003oooooooooo`33ooooo`03ool00?l0
0?oo003o07kooooo000Qooooo`03o`000?oooooooooo0<Kooooo0_l00?mlooooo`008Oooool00ol0
003oooooooooo`38ooooo`?o003oNOooool0027ooooo0ol0003;ooooo`;o003oMoooool0027ooooo
00?o0000ooooooooool0cOooool3o`00ogCooooo000Qooooo`03o`000?oooooooooo0=3ooooo0_l0
0?mbooooo`008Oooool00ol0003oooooooooo`3Booooo`;o003oL?ooool0027ooooo00?o0000oooo
ooooool0e?ooool3o`00ofgooooo000Qooooo`03o`000?oooooooooo0=Oooooo0ol00?mZooooo`00
8Oooool00ol0003oooooooooo`3Jooooo`?o003oIoooool0027ooooo00?o0000ooooooooool0gOoo
ool3o`00ofCooooo000Qooooo`03o`000?oooooooooo0>3ooooo0ol00?mQooooo`008Oooool3o`00
0>?ooooo0ol00?mNooooo`008Oooool00ol0003oooooooooo`3Vooooo`Go003oFOooool0027ooooo
00?o0000ooooooooool0joooool4o`00oeGooooo000Qooooo`03o`000?oooooooooo0>oooooo1?l0
0?mAooooo`008Oooool00ol0003oooooooooo`3cooooo`Co003oCOooool0027ooooo00?o0000oooo
ooooool0m_ooool00ooo003o003oo`00o`02o`00odWooooo000Qooooo`03o`000?oooooooooo0?_o
oooo1Ol00?m4ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0
ooooool1ooooo`Ko003o?_ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3oooooo`Oooooo1_l00?lhooooo`006_ooool00ol0003oooooooooo`04ooooo`?o0000ooooool=
oooooaCo003o9?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooo
odGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo
000000Kooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
Y?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00oooooo1?l000000ol@413o
ooooooooo`2Uooooo`00YOooool01Ol0003ooooooooooooooooo000000;ooooo1_l0000<ooooo`03
o`000?oooooooooo0:Oooooo000Pooooo`03okZj^_lb<S;ooooo08;ooooo00Go0000oooooooooooo
ooooo`00000Dooooo`03o`000?oooooooooo0:Oooooo000Qooooo`03o`000?oooooooooo087ooooo
00Go0000ooooooooooooooooo`000002ooooo`Ko00003?ooool00ol0003oooooooooo`2Wooooo`00
7oooool01OnHV9So410@o`000?l0003oZJVY087ooooo00Go0000ohN7QoooooooZJVYo`00000Doooo
o`03o`000?oooooooooo0:Oooooo000Oooooo`06o`000?nYZJWoEEEEoiRHV?mEEEGo^[ZjOoooool0
0ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01;ooooo00?o0000ooooooooool0Yoooool0
01oooooo00Ko<S8bonk^k_nHV9SoEEEEomgMgOl@412Iooooo`03o`000?oooooooooo0:Oooooo000O
ooooo`07okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c02Fooooo`03oeEEEOmVIVKo00000:Wooooo
000Oooooo`07onk^k_l0003oooooo`000?ooooooIVIVohN7Q`3ooooood?ooooo000Oooooo`04ofIV
I_nHV9Sooooooc8b<P;o^[Zj00?o0000ooooooooool0oooooom1ooooo`008_ooool00omVIVKoQhN7
ooooo`3oooooodCooooo000Rooooo`03ojVYZOm4A4Cooooo0?ooooooA?ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.184028, -0.0840035, \
0.00677079, 0.00697441}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0.309014 0.294305 [
[.17539 .29651 -12 -9 ]
[.17539 .29651 12 0 ]
[.32696 .29651 -9 -9 ]
[.32696 .29651 9 0 ]
[.47854 .29651 -12 -9 ]
[.47854 .29651 12 0 ]
[.63011 .29651 -3 -9 ]
[.63011 .29651 3 0 ]
[.78169 .29651 -12 -9 ]
[.78169 .29651 12 0 ]
[.93327 .29651 -9 -9 ]
[.93327 .29651 9 0 ]
[1.025 .30901 0 -6 ]
[1.025 .30901 10 6 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[.5 .63053 -14 0 ]
[.5 .63053 14 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30901 m
.17539 .31526 L
s
[(0.25)] .17539 .29651 0 1 Mshowa
.32696 .30901 m
.32696 .31526 L
s
[(0.5)] .32696 .29651 0 1 Mshowa
.47854 .30901 m
.47854 .31526 L
s
[(0.75)] .47854 .29651 0 1 Mshowa
.63011 .30901 m
.63011 .31526 L
s
[(1)] .63011 .29651 0 1 Mshowa
.78169 .30901 m
.78169 .31526 L
s
[(1.25)] .78169 .29651 0 1 Mshowa
.93327 .30901 m
.93327 .31526 L
s
[(1.5)] .93327 .29651 0 1 Mshowa
.125 Mabswid
.05412 .30901 m
.05412 .31276 L
s
.08444 .30901 m
.08444 .31276 L
s
.11476 .30901 m
.11476 .31276 L
s
.14507 .30901 m
.14507 .31276 L
s
.2057 .30901 m
.2057 .31276 L
s
.23602 .30901 m
.23602 .31276 L
s
.26633 .30901 m
.26633 .31276 L
s
.29665 .30901 m
.29665 .31276 L
s
.35728 .30901 m
.35728 .31276 L
s
.38759 .30901 m
.38759 .31276 L
s
.41791 .30901 m
.41791 .31276 L
s
.44822 .30901 m
.44822 .31276 L
s
.50885 .30901 m
.50885 .31276 L
s
.53917 .30901 m
.53917 .31276 L
s
.56948 .30901 m
.56948 .31276 L
s
.5998 .30901 m
.5998 .31276 L
s
.66043 .30901 m
.66043 .31276 L
s
.69074 .30901 m
.69074 .31276 L
s
.72106 .30901 m
.72106 .31276 L
s
.75138 .30901 m
.75138 .31276 L
s
.81201 .30901 m
.81201 .31276 L
s
.84232 .30901 m
.84232 .31276 L
s
.87264 .30901 m
.87264 .31276 L
s
.90295 .30901 m
.90295 .31276 L
s
.96358 .30901 m
.96358 .31276 L
s
.9939 .30901 m
.9939 .31276 L
s
.25 Mabswid
0 .30901 m
1 .30901 L
s
gsave
1.025 .30901 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .19129 m
.02756 .19129 L
s
.02381 .22072 m
.02756 .22072 L
s
.02381 .25015 m
.02756 .25015 L
s
.02381 .27958 m
.02756 .27958 L
s
.02381 .33844 m
.02756 .33844 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ .05 .05 ] 0 setdash
.02381 .30901 m
.04262 .4245 L
.06244 .52586 L
.06747 .546 L
.07286 .56451 L
.07751 .57778 L
.08255 .58915 L
.08564 .59449 L
.08848 .59832 L
.0912 .60097 L
.09258 .60193 L
.09335 .60235 L
.09409 .60269 L
.09474 .60292 L
.09545 .60311 L
.0967 .60328 L
.0974 .60328 L
.09815 .60321 L
.09886 .60308 L
.0995 .60289 L
.10076 .60238 L
.10147 .60199 L
.10212 .60157 L
.10458 .59948 L
.10704 .59659 L
.10928 .59327 L
.11432 .5834 L
.11898 .57141 L
.1234 .55761 L
.14407 .4661 L
.1824 .23372 L
.20178 .12527 L
.21282 .0765 L
.21787 .05838 L
.22318 .04247 L
.22789 .03126 L
.23038 .02647 L
.23304 .02224 L
.23549 .01916 L
.23772 .01707 L
.23879 .0163 L
.23996 .01563 L
.24106 .01517 L
.24208 .01489 L
.24325 .01474 L
.24451 .01479 L
.2457 .01504 L
.24679 .01543 L
.24806 .01609 L
.24945 .01706 L
Mistroke
.25197 .01947 L
.2546 .0229 L
.25741 .02756 L
.26245 .03846 L
.26782 .05357 L
.27276 .07043 L
.2839 .11797 L
.30408 .22944 L
.32454 .35733 L
.34362 .4688 L
.35306 .5152 L
.36198 .55138 L
.36692 .56765 L
.37227 .58203 L
.37464 .58724 L
.37714 .592 L
.37929 .59542 L
.38164 .59845 L
.38403 .60079 L
.38534 .60175 L
.38655 .60244 L
.38769 .6029 L
.38872 .60316 L
.38991 .60329 L
.39104 .60323 L
.39227 .60297 L
.39357 .60248 L
.39468 .60188 L
.3959 .60103 L
.39861 .59841 L
.40115 .59508 L
.40577 .58687 L
.40998 .57699 L
.41945 .54697 L
.42934 .50516 L
.43851 .45856 L
.45926 .33492 L
.47949 .20933 L
.4894 .15318 L
.49849 .10776 L
.50715 .07158 L
.51664 .04137 L
.52157 .02993 L
.52617 .02211 L
.52871 .01897 L
.53102 .01685 L
.5323 .016 L
.53298 .01564 L
.53369 .01532 L
.535 .01492 L
Mistroke
.53621 .01475 L
.53742 .01478 L
.53874 .01504 L
.53998 .01549 L
.54113 .0161 L
.54228 .01689 L
.54331 .01775 L
.54563 .02021 L
.54814 .02365 L
.55085 .0283 L
.55576 .03915 L
.5653 .0686 L
.57407 .10456 L
.61357 .33224 L
.63345 .45143 L
.65157 .53835 L
.65637 .5561 L
.66159 .57241 L
.66611 .58387 L
.67109 .5935 L
.67381 .59741 L
.67636 .60018 L
.67777 .60133 L
.67906 .60215 L
.67979 .60252 L
.68047 .6028 L
.68118 .60303 L
.68196 .60319 L
.68327 .60329 L
.68451 .60317 L
.68562 .60288 L
.68682 .60238 L
.68813 .60161 L
.68952 .60055 L
.69201 .598 L
.69454 .59456 L
.69695 .59051 L
.70146 .58091 L
.70631 .56774 L
.7116 .55022 L
.72992 .46733 L
.77063 .22064 L
.78948 .11738 L
.80009 .07195 L
.80984 .04095 L
.81482 .02953 L
.81768 .0244 L
.82029 .02067 L
.82304 .01771 L
.82456 .01651 L
Mistroke
.82525 .01606 L
.82599 .01565 L
.82662 .01536 L
.82731 .01511 L
.82854 .01482 L
.82923 .01475 L
.82997 .01474 L
.83066 .01481 L
.8313 .01492 L
.83255 .0153 L
.83324 .0156 L
.83387 .01593 L
.83625 .01766 L
.83759 .01896 L
.83903 .02064 L
.84165 .0244 L
.84678 .0343 L
.85149 .04637 L
.86122 .07955 L
.87031 .11955 L
.89097 .23435 L
.92986 .46966 L
.94003 .51918 L
.94539 .54143 L
.95109 .5617 L
.95606 .57629 L
.96154 .5889 L
.96394 .5932 L
.96653 .59699 L
.96897 .59977 L
.97121 .60162 L
.97244 .60235 L
.97359 .60285 L
.97485 .60319 L
.97555 .60329 L
.97619 .60332 L
Mfstroke
0 0 1 r
[ ] 0 setdash
.02381 .30901 m
.04262 .42451 L
.06244 .52587 L
.06747 .54603 L
.07286 .56454 L
.07751 .5778 L
.08255 .58918 L
.08564 .59452 L
.08848 .59834 L
.0912 .60099 L
.09258 .60195 L
.09335 .60238 L
.09409 .60272 L
.09474 .60295 L
.09545 .60314 L
.0967 .60331 L
.0974 .60331 L
.09815 .60324 L
.09886 .6031 L
.0995 .60292 L
.10076 .6024 L
.10147 .60201 L
.10212 .6016 L
.10458 .59951 L
.10704 .59662 L
.10928 .59329 L
.11432 .58343 L
.11898 .57143 L
.1234 .55764 L
.14407 .46612 L
.1824 .23371 L
.20178 .12525 L
.21282 .07648 L
.21787 .05835 L
.22318 .04245 L
.22789 .03123 L
.23038 .02644 L
.23304 .02221 L
.23549 .01914 L
.23772 .01704 L
.23879 .01626 L
.23996 .0156 L
.24106 .01514 L
.24208 .01486 L
.24325 .01472 L
.24451 .01477 L
.2457 .01501 L
.24679 .0154 L
.24806 .01606 L
.24945 .01703 L
Mistroke
.25197 .01945 L
.2546 .02288 L
.25741 .02753 L
.26245 .03844 L
.26782 .05354 L
.27276 .07041 L
.2839 .11795 L
.30408 .22943 L
.32454 .35733 L
.34362 .46881 L
.35306 .51522 L
.36198 .5514 L
.36692 .56767 L
.37227 .58206 L
.37464 .58727 L
.37714 .59202 L
.37929 .59544 L
.38164 .59848 L
.38403 .60083 L
.38534 .60178 L
.38655 .60246 L
.38769 .60292 L
.38872 .60319 L
.38991 .60332 L
.39104 .60326 L
.39227 .603 L
.39357 .60251 L
.39468 .60191 L
.3959 .60106 L
.39861 .59844 L
.40115 .59511 L
.40577 .58689 L
.40998 .57701 L
.41945 .54699 L
.42934 .50518 L
.43851 .45858 L
.45926 .33492 L
.47949 .20932 L
.4894 .15316 L
.49849 .10774 L
.50715 .07155 L
.51664 .04134 L
.52157 .02991 L
.52617 .02208 L
.52871 .01894 L
.53102 .01683 L
.5323 .01598 L
.53298 .01561 L
.53369 .01529 L
.535 .01489 L
Mistroke
.53621 .01472 L
.53742 .01475 L
.53874 .01501 L
.53998 .01547 L
.54113 .01608 L
.54228 .01686 L
.54331 .01772 L
.54563 .02017 L
.54814 .02362 L
.55085 .02828 L
.55576 .03912 L
.5653 .06858 L
.57407 .10454 L
.61357 .33224 L
.63345 .45145 L
.65157 .53837 L
.65637 .55612 L
.66159 .57244 L
.66611 .58389 L
.67109 .59353 L
.67381 .59744 L
.67636 .60021 L
.67777 .60136 L
.67906 .60219 L
.67979 .60255 L
.68047 .60283 L
.68118 .60306 L
.68196 .60322 L
.68327 .60332 L
.68451 .60319 L
.68562 .60291 L
.68682 .60241 L
.68813 .60164 L
.68952 .60058 L
.69201 .59802 L
.69454 .59458 L
.69695 .59053 L
.70146 .58094 L
.70631 .56777 L
.7116 .55024 L
.72992 .46735 L
.77063 .22064 L
.78948 .11737 L
.80009 .07193 L
.80984 .04092 L
.81482 .0295 L
.81768 .02438 L
.82029 .02065 L
.82304 .01768 L
.82456 .01648 L
Mistroke
.82525 .01603 L
.82599 .01563 L
.82662 .01534 L
.82731 .01508 L
.82854 .0148 L
.82923 .01472 L
.82997 .01472 L
.83066 .01478 L
.8313 .01489 L
.83255 .01527 L
.83324 .01557 L
.83387 .0159 L
.83625 .01763 L
.83759 .01894 L
.83903 .02062 L
.84165 .02437 L
.84678 .03428 L
.85149 .04634 L
.86122 .07952 L
.87031 .11953 L
.89097 .23434 L
.92986 .46967 L
.94003 .5192 L
.94539 .54145 L
.95109 .56172 L
.95606 .57632 L
.96154 .58892 L
.96394 .59323 L
.96653 .59703 L
.96897 .5998 L
.97121 .60164 L
.97244 .60237 L
.97359 .60286 L
.97485 .6032 L
.97555 .60329 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool000oooooo
1_l00005ooooo`03o`000?oooooooooo00Cooooo0ol00011ooooo`?o003oF?ooool4o`00oeSooooo
0ol00?m9ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03oooooo0ol0
0?l2ooooo`03o`00oooooooooooo05Cooooo0_l00?l2ooooo`;o003oE_ooool01Ol00?oooooooooo
oooooooo003o04Sooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo05;ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`1Cooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0AOoo
ool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0oooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool0D_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo057ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`14ooooo`006_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`1@ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0D?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo04Cooooo000Hooooo`03oeEEEOmVIVKo000000Ko
oooo00?o0000ooooooooool0?Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo053o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool0@oooool0027ooooo00?o0000ooooooooool0?Oooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo04oooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`1?ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0@oooool0027ooooo00?o
0000ooooooooool0?Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo04gooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`1=ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool0@oooool0027ooooo00?o0000ooooooooool0??ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo04cooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`1=
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0@_ooool0027ooooo0ol0000loooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool0Boooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo04gooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`12oooo
o`008Oooool00ol0003oooooooooo`0looooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool0Boooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo04cooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`11ooooo`008Oooool00ol0003oooooooooo`0kooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool0B_ooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo04_ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`11ooooo`008Ooo
ool00ol0003oooooooooo`0kooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0BOoo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo04_ooooo00?o003oooooooooool02ooo
ool00ol00?ooo`00ooooo`11ooooo`008Oooool00ol0003oooooooooo`0kooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool0BOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo04[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`10ooooo`008Oooool00ol0
003oooooooooo`0jooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0B?ooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo04Wooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`10ooooo`008Oooool00ol0003oooooooooo`0jooooo`03o`00oooooooooooo00go
oooo00?oo`00o`00ooooool0B?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo04Wo
oooo00?o003oooooooooool03Oooool00ol00?ooo`00ooooo`10ooooo`008Oooool00ol0003ooooo
ooooo`0iooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0Aoooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo04Sooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`0oooooo`008Oooool00ol0003oooooooooo`0iooooo`03o`00oooooooooooo00oooooo00?o
003oooooooooool0A_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo04Oooooo00?o
003oooooooooool03oooool00ol00?ooooooooooo`0oooooo`008Oooool3o`0003Wooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`16ooooo`03o`00oooooooooooo00oooooo00?o003o
ool00?ooool0Aoooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo03oooooo000Qoooo
o`03o`000?oooooooooo03Sooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`16oooo
o`03o`00oooooooooooo00oooooo00?o003oooooooooool0Aoooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo03kooooo000Qooooo`03o`000?oooooooooo03Sooooo00?o003ooooooooo
ool04Oooool00ol00?ooooooooooo`15ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool0A_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo03kooooo000Qooooo`03o`00
0?oooooooooo03Sooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`14ooooo`03ool0
0?l00?oooooo017ooooo00?o003oooooooooool0AOooool00ol00?ooooooooooo`0Aooooo`03o`00
oooooooooooo03kooooo000Qooooo`03o`000?oooooooooo03Sooooo00?o003oooooooooool04Ooo
ool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0AOoo
ool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo03kooooo000Qooooo`03o`000?oooooo
oooo03Oooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`14ooooo`03o`00oooooooo
oooo01;ooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooo
oooo03gooooo000Qooooo`03o`000?oooooooooo03Oooooo00?o003oooooooooool04oooool00ol0
0?ooooooooooo`13ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool0@oooool00ol0
0?ooooooooooo`0Cooooo`03o`00oooooooooooo03gooooo000Qooooo`03o`000?oooooooooo03Oo
oooo00?o003oooooooooool04oooool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo01;o
oooo00?o003oooooooooool0@oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo03go
oooo000Qooooo`03o`000?oooooooooo03Oooooo00?o003oooooooooool04oooool00ol00?oooooo
ooooo`13ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool0@oooool00ol00?oooooo
ooooo`0Cooooo`03o`00oooooooooooo03gooooo000Qooooo`03o`000?oooooooooo03Oooooo00?o
003oooooooooool04oooool00ooo003o003oooooo`12ooooo`03o`00oooooooooooo01Cooooo00?o
003oooooooooool0@_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo03cooooo000Q
ooooo`?o0000=_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo047ooooo00?o003o
ooooooooool05?ooool00ol00?ooooooooooo`11ooooo`03o`00oooooooooooo01Gooooo00?o003o
ooooooooool0??ooool0027ooooo00?o0000ooooooooool0=_ooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo047ooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`11oooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool0??ooool0027ooooo00?o0000oooooooo
ool0=_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo047ooooo00?o003ooooooooo
ool05?ooool00ol00?ooooooooooo`11ooooo`03o`00oooooooooooo01Gooooo00?o003ooooooooo
ool0??ooool0027ooooo00?o0000ooooooooool0=_ooool00ol00?ooooooooooo`0Fooooo`03o`00
oooooooooooo043ooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`10ooooo`03o`00
oooooooooooo01Kooooo00?o003oooooooooool0??ooool0027ooooo00?o0000ooooooooool0=_oo
ool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo03oooooo00?o003oooooooooool05_oo
ool00ol00?ooooooooooo`0oooooo`03o`00oooooooooooo01Kooooo00?oo`00o`00ooooool0??oo
ool0027ooooo00?o0000ooooooooool0=Oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooo
oooo03oooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0oooooo`03o`00oooooooo
oooo01Oooooo00?o003oooooooooool0>oooool0027ooooo00?o0000ooooooooool0=Oooool00ol0
0?ooooooooooo`0Gooooo`03o`00oooooooooooo03oooooo00?o003oooooooooool05_ooool00ol0
0?ooooooooooo`0oooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool0>oooool0027o
oooo00?o0000ooooooooool0=Oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo03oo
oooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0oooooo`03o`00oooooooooooo01Oo
oooo00?o003oooooooooool0>oooool0027ooooo00?o0000ooooooooool0=Oooool00ol00?oooooo
ooooo`0Hooooo`03o`00oooooooooooo03kooooo00?o003oooooooooool05_ooool00ol00?ooo`00
ooooo`0nooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0>oooool0027ooooo0ol0
000eooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0?Oooool00ol00?oooooooooo
o`0Hooooo`03o`00oooooooooooo03gooooo00?o003oooooooooool06Oooool00ol00?oooooooooo
o`0jooooo`008Oooool00ol0003oooooooooo`0dooooo`03ool00?l00?oooooo01Wooooo00?o003o
ooooooooool0?Oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo03gooooo00?o003o
ooooooooool06Oooool00ol00?ooooooooooo`0jooooo`008Oooool00ol0003oooooooooo`0doooo
o`03o`00oooooooooooo01Wooooo00?o003oooooooooool0?Oooool00ol00?ooooooooooo`0Hoooo
o`03o`00oooooooooooo03gooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0joooo
o`008Oooool00ol0003oooooooooo`0dooooo`03o`00oooooooooooo01Wooooo00?o003ooooooooo
ool0?Oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo03gooooo00?o003ooooooooo
ool06Oooool00ol00?ooooooooooo`0jooooo`008Oooool00ol0003oooooooooo`0dooooo`03o`00
oooooooooooo01Wooooo00?o003oooooooooool0??ooool00ooo003o003oooooo`0Iooooo`03o`00
oooo003ooooo03gooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0jooooo`008Ooo
ool00ol0003oooooooooo`0dooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool0>ooo
ool00ol00?ooooooooooo`0Iooooo`03o`00oooo003ooooo03gooooo00?o003oooooooooool06Ooo
ool00ol00?ooooooooooo`0jooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0cooooo`03ool0
0?l00?oooooo01_ooooo00?o003oooooooooool0>oooool00ol00?ooooooooooo`0Jooooo`03o`00
oooooooooooo03_ooooo00?o003oooooooooool06_ooool00ooo003o003oooooo`0jooooo`001ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo
00?o0000ooooooooool0<oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo03_ooooo
00?o003oooooooooool06_ooool00ol00?ooooooooooo`0kooooo`03o`00oooooooooooo01_ooooo
00?o003oooooooooool0>Oooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0cooooo`03o`00oooooooooooo01_ooooo
00?o003oooooooooool0>oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo03_ooooo
00?o003oooooooooool06oooool00ol00?ooooooooooo`0iooooo`001oooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool3o`0003?ooooo00?o003oooooooooool0
6oooool00ol00?ooooooooooo`0jooooo`03ool00?l00?oooooo01_ooooo00?o003oool00?ooool0
>oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo03Wooooo0007ooooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooooooo
ool0<oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo03[ooooo00?o003ooooooooo
ool06oooool00ol00?ooo`00ooooo`0kooooo`03o`00oooooooooooo01_ooooo00?o003ooooooooo
ool0>Oooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0<oooool00ol00?ooooooooooo`0Kooooo`03ool00?l00?oooooo03[o
oooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0iooooo`03ool00?l00?oooooo01co
oooo00?o003oooooooooool0>Oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0<oooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo03Wooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0iooooo`03
o`00oooooooooooo01gooooo00?o003oooooooooool0>?ooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0booooo`03o`00oooooooooooo01go
oooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo03Wo
oooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0hooooo`008Oooool00ol0003ooooo
ooooo`0booooo`03o`00oooooooooooo01gooooo00?o003oooooooooool0>?ooool00ooo003o003o
ooooo`0Mooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool07Oooool00ol00?oooooo
ooooo`0hooooo`008Oooool00ol0003oooooooooo`0booooo`03o`00oooooooooooo01gooooo00?o
003oooooooooool0>?ooool00ooo003o003oooooo`0Mooooo`03o`00oooooooooooo03Wooooo00?o
003oooooooooool07Oooool00ol00?ooooooooooo`0hooooo`008Oooool00ol0003oooooooooo`0b
ooooo`03o`00oooooooooooo01gooooo00?oo`00o`00ooooool0>?ooool00ol00?ooooooooooo`0M
ooooo`03o`00oooooooooooo03Sooooo00?oo`00o`00ooooool07_ooool00ol00?ooooooooooo`0h
ooooo`008Oooool00ol0003oooooooooo`0booooo`03o`00oooooooooooo01gooooo00?oo`00o`00
ooooool0>?ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo03Oooooo00?oo`00o`00
ooooool07_ooool00ol00?ooooooooooo`0hooooo`008Oooool3o`00037ooooo00?o003ooooooooo
ool07_ooool00ooo003o003oooooo`0hooooo`03o`00oooooooooooo01kooooo00?o003ooooooooo
ool0=oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo03Oooooo000Qooooo`03o`00
0?oooooooooo037ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0gooooo`03o`00
oooooooooooo01kooooo00?o003oooooooooool0=oooool00ol00?ooooooooooo`0Oooooo`03o`00
oooooooooooo03Oooooo000Qooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool07ooo
ool00ol00?ooooooooooo`0gooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool0=ooo
ool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo03Oooooo000Qooooo`03o`000?oooooo
oooo037ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0gooooo`03o`00oooooooo
oooo01kooooo00?o003oooooooooool0=oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooo
oooo03Oooooo000Qooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool07oooool00ooo
003o003oooooo`0fooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool0=_ooool00ol0
0?ooooooooooo`0Oooooo`03o`00oooooooooooo03Oooooo000Qooooo`03o`000?oooooooooo033o
oooo00?oo`00o`00ooooool08Oooool00ol00?ooooooooooo`0eooooo`03o`00oooooooooooo023o
oooo00?o003oooooooooool0=_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo03Oo
oooo000Qooooo`03o`000?oooooooooo033ooooo00?o003oooooooooool08Oooool00ol00?oooooo
ooooo`0eooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool0=Oooool00ooo003o003o
ooooo`0Qooooo`03o`00oooooooooooo03Kooooo000Qooooo`03o`000?oooooooooo033ooooo00?o
003oooooooooool08Oooool00ol00?ooooooooooo`0eooooo`03o`00oooooooooooo023ooooo00?o
003oooooooooool0=Oooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo03Kooooo000Q
ooooo`03o`000?oooooooooo033ooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`0e
ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool0=Oooool00ol00?ooooooooooo`0Q
ooooo`03o`00oooooooooooo03Kooooo000Qooooo`?o0000<?ooool00ol00?ooooooooooo`0Qoooo
o`03o`00oooooooooooo03Gooooo00?o003oooooooooool08?ooool00ooo003o003oooooo`0eoooo
o`03o`00oooooooooooo027ooooo00?o003oooooooooool0=_ooool0027ooooo00?o0000oooooooo
ool0;oooool00ooo003o003oooooo`0Sooooo`03o`00oooooooooooo03?ooooo00?o003ooooooooo
ool08Oooool00ooo003o003oooooo`0eooooo`03o`00oooooooooooo027ooooo00?o003ooooooooo
ool0=_ooool0027ooooo00?o0000ooooooooool0;oooool00ol00?ooooooooooo`0Sooooo`03o`00
oooooooooooo03?ooooo00?o003oooooooooool08Oooool00ooo003o003oooooo`0eooooo`03o`00
oooooooooooo027ooooo00?o003oool00?ooool0=_ooool0027ooooo00?o0000ooooooooool0;ooo
ool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo03?ooooo00?o003oooooooooool08_oo
ool00ol00?ooooooooooo`0dooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool0=Ooo
ool0027ooooo00?o0000ooooooooool0;oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooo
oooo03;ooooo00?oo`00o`00ooooool08oooool00ol00?ooooooooooo`0cooooo`03o`00oooooooo
oooo02?ooooo00?o003oooooooooool0=Oooool0027ooooo00?o0000ooooooooool0;oooool00ol0
0?ooooooooooo`0Sooooo`03o`00oooooooooooo03;ooooo00?oo`00o`00ooooool08oooool00ol0
0?ooooooooooo`0cooooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool0=Oooool0027o
oooo00?o0000ooooooooool0;oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo03;o
oooo00?o003oooooooooool08oooool00ooo003o003oooooo`0cooooo`03o`00oooooooooooo02?o
oooo00?o003oooooooooool0=Oooool0027ooooo00?o0000ooooooooool0;oooool00ol00?oooooo
ooooo`0Tooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool08oooool00ooo003o003o
ooooo`0cooooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool0=Oooool0027ooooo00?o
0000ooooooooool0;_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo037ooooo00?o
003oooooooooool09?ooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo02?ooooo00?o
003oool00?ooool0=Oooool0027ooooo00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`0U
ooooo`03o`00oooooooooooo033ooooo00?oo`00o`00ooooool09Oooool00ol00?ooooooooooo`0b
ooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool0=?ooool0027ooooo0ol0000^oooo
o`03o`00oooooooooooo02Gooooo00?o003oooooooooool0<?ooool00ooo003o003oooooo`0Uoooo
o`03o`00oooooooooooo037ooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0doooo
o`008Oooool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo02Gooooo00?o003ooooooooo
ool0<?ooool00ooo003o003oooooo`0Uooooo`03ool00?l00?oooooo037ooooo00?o003ooooooooo
ool09Oooool00ol00?ooooooooooo`0dooooo`008Oooool00ol0003oooooooooo`0^ooooo`03o`00
oooooooooooo02Gooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0Uooooo`03ool0
0?l00?oooooo037ooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0dooooo`008Ooo
ool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool0<?oo
ool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool09Ooo
ool00ol00?ooo`00ooooo`0dooooo`008Oooool00ol0003oooooooooo`0]ooooo`03o`00oooooooo
oooo02Oooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooo
oooo033ooooo00?o003oooooooooool09Oooool00ol00?ooo`00ooooo`0dooooo`008Oooool00ol0
003oooooooooo`0Nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@?ooooo00?o003o
o`000?l000000ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd05Oooool01oo^k^ko<S8bo`00
0?lb<S;ok^k^ooooool00?l00oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Eoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@03ooooool00?oooooo00?ooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo00?o003oooooooooool01?oo
ool4o`000003oa0@4?oooooooooo01cooooo1?l000001ol@413oooooooooooooooooo`00o`00oolQ
8B401?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Eooooo`03o`00ool0003o0000
00;o000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0P
ooooo`008Oooool00ol0003oooooooooo`0Nooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@?ooooo00Ko003ooiRHV?lQ8B7ok^k^oooooom4A4@7ooooo`03ogMgMolb<S;ooooo01Cooooo
00OoMgMgoiRHV?ooooooV9RHogMgMooooooo003o00?ooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
01Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q00?oo`00o`00ooooool00oooool0
0omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo01Oooooo00?o003oooooooooool01_ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00?ooooo00?o003oob4Q8OlQ8B401?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool05?ooool01?l00?oooooooooo
ool00006ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Oooooo`008Oooool00ol0003ooooooooo
o`0Nooooo`05oa0@4?ooooooooooooooool@41002_ooool01Ol00?oooooooiRHV?lQ8B7ok^k^00Wo
oooo00?o0000ooooooooool04oooool01ol@413ooooooooooooooooo410@ooooool00?l03_ooool0
0ol0003oooooooooo`0Cooooo`05oa0@4?ooooooooooooooool@41001oooool00ol00?oooooooooo
o`03ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool05oooool00ol00?oooooooooo
o`05ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool00ol00?oooooooooo
o`05ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool04oooool01?l00?oooooooooo
ool0000Aooooo`03o`000?oooooooooo01kooooo000Qooooo`03o`000?oooooooooo01kooooo00Go
0000ooooooooooooooooo`00000:ooooo`06o`00oooooooooooooiRHV?lQ8B7ok^k^1oooool00omg
MgOo<S8booooo`0Dooooo`07o`000?ooooooooooooooool0003oooooo`00o`0=ooooo`03ogMgMolb
<S;ooooo01Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00oooooooooooo00Cooooo
00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0Hooooo`03o`00oooooooooooo00Gooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00Kooooo
00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`0Dooooo`04o`00ooooooooooooo`00013o
oooo00?oMgMgoc8b<_ooool07oooool0027ooooo0ol0000Nooooo`05o`000?ooooooooooooooool0
00002_ooool01_l00?ooooooooooooooooooMgMgofIVIPCooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Eooooo`08o`000?ooooooooooooooool0003oooooo`00oooo0009ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`05Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o003oooooooooool01?oo
ool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06Oooool00ol00?oooooo
ooooo`05ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool00ol00?oooooo
ooooo`07ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Eooooo`04
o`00ooooooooooooo`0000gooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Pooooo`008Oooool00ol0
003oooooooooo`0Nooooo`05oa0@4?ooooooooooooooool@41002Oooool00ol00?ooooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05oooool02?l@413ooooooooooooo
oooo410@ooooool00?ooo`002Oooool00ol0003oooooooooo`0Gooooo`05oa0@4?oooooooooooooo
ool@41001oooool00ol00?ooooooooooo`04ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000oooo
ooooool06oooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool00_ooool00ooo003o003oooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool05oooool01?l00?ooooooooooool0000=ooooo`03o`000?oooooooooo02;ooooo000Qoooo
o`03o`000?oooooooooo01kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`07o`00oooooooo
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo01Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`02ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool05oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Oooooo00Go003ooooooooooooooooooa0@4003ooooo`03oc8b<_oooooo
oooo00;ooooo00?o0000ooooooooool06oooool00ol00?ooooooooooo`05ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool00_ooool00ooo003o003oooooo`05ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool00ol0003oooooooooo`0Hooooo`03o`00oooooooo000000gooooo00?o
0000ooooooooool08_ooool0027ooooo00?o0000ooooooooool07_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Wooooo00Oo003ooooooonHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000Fooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00_ooool00ol00?ooooooooooo`07ooooo`Co00005_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co003ooooooooooooooooo1Ol00004ooooo`Co00006ooo
ool00ol00?ooooooooooo`02ooooo`03oeEEEOmVIVKo0000023ooooo00?oEEEEofIVI_l000001?oo
ool00ol00?ooooooooooo`05ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0001Oooooo
00?o003oofIVI_l000003Oooool4o`00027ooooo000Qooooo`03o`000?oooooooooo02cooooo00?o
003oooooooooool0:Oooool00ol00?ooooooooooo`0/ooooo`03o`00oooooooooooo02[ooooo00?o
003oooooooooool0;?ooool00ol00?ooooooooooo`0Yooooo`03o`00oooooooooooo03;ooooo000Q
ooooo`03o`000?oooooooooo02cooooo00?o003oooooooooool0:Oooool00ol00?ooo`00ooooo`0/
ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool0;?ooool00ol00?ooooooooooo`0Y
ooooo`03o`00oooooooooooo03;ooooo000Qooooo`03o`000?oooooooooo02cooooo00?o003ooooo
ooooool0:Oooool00ol00?ooo`00ooooo`0/ooooo`03o`00oooooooooooo02[ooooo00?o003ooooo
ooooool0;?ooool00ol00?ooooooooooo`0Yooooo`03o`00oooooooooooo02Sooooo0_l00002oooo
o`;o00001?ooool0027ooooo00?o0000ooooooooool0:oooool00ol00?ooooooooooo`0Zooooo`03
o`00oooo003ooooo02cooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0/ooooo`03
o`00oooooooooooo02Wooooo00?o003oooooooooool0:?ooool01_o^k^ko8B4QohN7Qonj^[[o0000
omgMg@Cooooo000Qooooo`03o`000?oooooooooo02_ooooo00?o003oooooooooool0:oooool00ol0
0?ooooooooooo`0[ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool0:oooool00ooo
003o003oooooo`0[ooooo`03o`00oooooooooooo02Sooooo00CogMgMo`000?l@413oc<c<1Oooool0
01[ooooo1ol000000ol00?oo0000o`00000[o`000003o`00ool0003o000002_o000000?o003oo`00
0?l00000:ol000000ol00?oo0000o`00000[o`000003o`00ool0003o000002[o000000?o003oo`00
0?l00000:ol000000ol00?oo0000o`00000Lo`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0
027ooooo00?o003oooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00oooooooo0000
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool00oooool01?l00?ooooooooooool00009ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`05o`000?oooooo
ooooooooool00?l01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool00?l0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03o`000?l00?oooooo00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0<ooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03o`00
oooooooooooo02_ooooo00?o003oooooool00000:oooool01?l00?ooooooooooool0000Yooooo`03
o`00oooooooooooo00;ooooo00?o0000ooooooooool09oooool00ol00?ooooooooooo`03ooooo`03
o`000?oooooooooo02Cooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`0Sooooo`03
o`00oooooooooooo00Kooooo00?o0000ooooooooool07_ooool2o`0000;ooooo0_l00004ooooo`00
8Oooool00ol00?ooooooooooo`0[ooooo`03o`00oooooooooooo02_ooooo00?o003oooooooooool0
:_ooool00ol00?ooooooooooo`0/ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool0
:oooool00ol00?ooooooooooo`0aooooo`008Oooool00ol0003o003oooooo`0Zooooo`03o`00oooo
oooooooo02cooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0/ooooo`03o`00oooo
oooooooo02[ooooo00?o003oooooooooool0:oooool00ol00?ooooooooooo`0aooooo`008Oooool0
0ol0003o003oooooo`0Zooooo`03o`00oooooooooooo02cooooo00?o003oooooooooool0:_ooool0
0ol00?ooooooooooo`0]ooooo`03o`00oooooooooooo02Wooooo00?o003oooooooooool0;?ooool0
0ol00?ooooooooooo`0`ooooo`008Oooool00ol0003o003oooooo`0Zooooo`03o`00oooooooooooo
02gooooo00?o003oooooooooool0:?ooool00ol00?ooooooooooo`0^ooooo`03o`00oooooooooooo
02Sooooo00?o003oooooooooool0;Oooool00ol00?ooooooooooo`0`ooooo`008Oooool00ol0003o
003oooooo`0Zooooo`03o`00oooooooooooo02gooooo00?o003oooooooooool0:?ooool00ol00?oo
o`00ooooo`0^ooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool0;Oooool00ol00?oo
ooooooooo`0`ooooo`008Oooool00ol0003o003oooooo`0Zooooo`03o`00oooooooooooo02gooooo
00?o003oooooooooool0:?ooool00ol00?ooooooooooo`0^ooooo`03o`00oooooooooooo02Sooooo
00?o003oooooooooool0;Oooool00ol00?ooooooooooo`0`ooooo`008Oooool00ol0003o003oo`00
000Zooooo`03o`00oooooooooooo02gooooo00?o003oooooooooool0:?ooool00ol00?oooooooooo
o`0^ooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool0;Oooool00ol00?oooooooooo
o`0`ooooo`008Oooool00ol0003oooooo`00o`0Yooooo`03o`00oooo003ooooo02kooooo00?o003o
ooooooooool0:?ooool00ol00?ooooooooooo`0^ooooo`03o`00oooooooooooo02Sooooo00?o003o
ooooooooool0;Oooool00ol00?ooo`00ooooo`0`ooooo`008Oooool00ol0003oooooo`00o`0Yoooo
o`03o`00oooooooooooo02kooooo00?o003oooooooooool0:?ooool00ol00?ooooooooooo`0^oooo
o`03ool00?l00?oooooo02Oooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`0_oooo
o`008Oooool00ol0003oooooo`00o`0Yooooo`03o`00oooooooooooo02kooooo00?o003ooooooooo
ool09oooool00ol00?ooooooooooo`0_ooooo`03ool00?l00?oooooo02Oooooo00?o003ooooooooo
ool0;oooool00ol00?ooooooooooo`0_ooooo`008Oooool00ol0003oooooo`00o`0Yooooo`03o`00
oooooooooooo02oooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`0`ooooo`03o`00
oooooooooooo02Kooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`0_ooooo`008Ooo
ool00ol0003oooooo`00o`0Yooooo`03o`00oooooooooooo02oooooo00?o003oooooooooool09_oo
ool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool0;ooo
ool00ol00?ooooooooooo`0_ooooo`008Oooool00ol0003oooooo`00o`0Yooooo`03o`00oooooooo
oooo02oooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooo
oooo02Kooooo00?o003oooooooooool0;oooool00ol00?ooo`00ooooo`0_ooooo`008Oooool01?l0
003oooooooooool00?lXooooo`03o`00oooooooooooo02oooooo00?o003oooooooooool09_ooool0
0ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool0;oooool0
0ol00?ooo`00ooooo`0_ooooo`008Oooool01?l0003oooooooooool00?lWooooo`03o`00oooooooo
oooo033ooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`0`ooooo`03ool00?l00?oo
oooo02Gooooo00?o003oooooooooool0<?ooool00ol00?ooo`00ooooo`0_ooooo`008Oooool3o`00
0003o`00oooooooooooo02Gooooo00?o003oooooooooool0<?ooool00ol00?ooo`00ooooo`0Voooo
o`03o`00oooooooooooo033ooooo00?oo`00o`00ooooool09Oooool00ol00?ooooooooooo`0aoooo
o`03o`00oooooooooooo02kooooo000Qooooo`04o`000?ooooooooooo`00obOooooo00?o003ooooo
ooooool0<Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo03;ooooo00?o003ooooo
ooooool09?ooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo02kooooo000Qooooo`04
o`000?ooooooooooo`00obOooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`0Toooo
o`03o`00oooooooooooo03;ooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0aoooo
o`03o`00oooooooooooo02kooooo000Qooooo`05o`000?ooooooooooo`00oooo00009_ooool00ol0
0?ooooooooooo`0aooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool0<_ooool00ol0
0?ooooooooooo`0Sooooo`03ool00?l00?oooooo03;ooooo00?o003oooooooooool0;_ooool0027o
oooo00Go0000ooooooooooooooooo`00o`0Vooooo`03o`00oooooooooooo037ooooo00?o003ooooo
ooooool09?ooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo02?ooooo00?oo`00o`00
ooooool0<_ooool00ol00?ooooooooooo`0^ooooo`008Oooool01Ol0003ooooooooooooooooo003o
02Gooooo00?o003oooooooooool0<_ooool00ol00?ooo`00ooooo`0Tooooo`03o`00oooooooooooo
03?ooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo
02kooooo000Qooooo`05o`000?ooooooooooooooool00?l09Oooool00ol00?ooooooooooo`0boooo
o`03o`00oooo003ooooo02Cooooo00?o003oooooooooool0<oooool00ol00?ooooooooooo`0Roooo
o`03o`00oooooooooooo03?ooooo00?o003oooooooooool0;Oooool0027ooooo00Go0000oooooooo
ooooooooo`00o`0Uooooo`03o`00oooooooooooo03?ooooo00?o003oooooooooool08_ooool00ol0
0?ooooooooooo`0dooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool0<oooool00ol0
0?ooooooooooo`0]ooooo`008Oooool01_l0003ooooooooooooooooo003oool002Cooooo00?o003o
ooooooooool0<oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo03Cooooo00?o003o
ooooooooool08Oooool00ooo003o003oooooo`0dooooo`03o`00oooooooooooo02gooooo000Qoooo
o`?o000000?oooooo`00oooo00009?ooool00ol00?ooooooooooo`0cooooo`03o`00oooooooooooo
02;ooooo00?o003oooooooooool0=?ooool00ol00?ooooooooooo`0Qooooo`03ool00?l00?oooooo
03Cooooo00?o003oooooooooool0;Oooool0027ooooo00?o0000ooooooooool00_ooool00ol00?oo
ooooooooo`0Rooooo`03o`00oooooooooooo03?ooooo00?o003oool00?ooool08_ooool00ol00?oo
ooooooooo`0dooooo`03o`00oooooooooooo027ooooo00?oo`00o`00ooooool0=?ooool00ol00?oo
ooooooooo`0]ooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo027ooooo
00?o003oooooooooool0=?ooool00ol00?ooo`00ooooo`0Rooooo`03o`00oooooooooooo03Cooooo
00?o003oooooooooool08Oooool00ol00?ooooooooooo`0dooooo`03o`00oooooooooooo02gooooo
000Qooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool08Oooool00ol00?oooooooooo
o`0dooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool0=Oooool00ol00?oooooooooo
o`0Pooooo`03o`00oooooooooooo03Gooooo00?o003oooooooooool0;?ooool0027ooooo00?o0000
ooooooooool00_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo03Gooooo00?o003o
ooooooooool08Oooool00ol00?ooooooooooo`0eooooo`03o`00oooooooooooo01oooooo00?oo`00
o`00ooooool0=_ooool00ol00?ooooooooooo`0/ooooo`008Oooool00ol0003oooooooooo`02oooo
o`03o`00oooooooooooo027ooooo00?o003oooooooooool0=Oooool00ol00?ooooooooooo`0Poooo
o`03o`00oooooooooooo03Kooooo00?o003oooooooooool07oooool00ooo003o003oooooo`0foooo
o`03o`00oooooooooooo02cooooo000Qooooo`03o`000?oooooooooo00;ooooo00?o003oool00?oo
ool08Oooool00ol00?ooooooooooo`0eooooo`03o`00oooooooooooo023ooooo00?o003ooooooooo
ool0=_ooool00ol00?ooooooooooo`0Oooooo`03ool00?l00?oooooo03Kooooo00?o003ooooooooo
ool0;?ooool0027ooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`0Pooooo`03o`00
oooooooooooo03Gooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0fooooo`03o`00
oooooooooooo023ooooo00?o003oooooooooool0=Oooool00ol00?ooooooooooo`0/ooooo`008Ooo
ool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool0=_oo
ool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo03Kooooo00?o003oooooooooool07ooo
ool00ol00?ooooooooooo`0fooooo`03o`00oooo003ooooo02cooooo000Qooooo`03o`000?oooooo
oooo00?ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0gooooo`03o`00oooooooo
oooo01oooooo00?o003oooooooooool0=_ooool00ooo003o003oooooo`0Oooooo`03o`00oooooooo
oooo03Oooooo00?o003oooooooooool0:oooool0027ooooo0ol00003ooooo`03o`00oooooooooooo
01oooooo00?o003oooooooooool0=oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo
03Oooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0gooooo`03o`00oooooooooooo
02_ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool07oooool00ol00?oo
ooooooooo`0gooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool0>?ooool00ol00?oo
ooooooooo`0Nooooo`03o`00oooooooooooo03Oooooo00?o003oooooooooool0:oooool0027ooooo
00?o0000ooooooooool00oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo03Oooooo
00?o003oooooooooool07_ooool00ol00?ooooooooooo`0hooooo`03o`00oooooooooooo01kooooo
00?o003oooooooooool0=oooool00ol00?ooooooooooo`0[ooooo`008Oooool00ol0003ooooooooo
o`04ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool0=oooool00ol00?oooooooooo
o`0Nooooo`03o`00oooooooooooo03Sooooo00?o003oooooooooool07_ooool00ol00?oooooooooo
o`0gooooo`03o`00oooo003ooooo02_ooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o003o
ooooooooool07Oooool00ol00?ooo`00ooooo`0hooooo`03o`00oooooooooooo01kooooo00?o003o
ooooooooool0>?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo03Sooooo00?o003o
ool00?ooool0:oooool0027ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0Moooo
o`03o`00oooooooooooo03Wooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0ioooo
o`03o`00oooooooooooo01cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0Zoooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo01gooooo00?o003o
ooooooooool0>Oooool00ol00?ooooooooooo`0Looooo`03ool00?l00?oooooo03[ooooo00?o003o
ooooooooool07?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo02[ooooo0007oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool0
0ol0003oooooooooo`04ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool0>Oooool0
0ol00?ooooooooooo`0Looooo`03ool00?l00?oooooo03[ooooo00?o003oooooooooool07?ooool0
0ol00?ooooooooooo`0iooooo`03o`00oooooooooooo02[ooooo0007ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o003o
ooooooooool07?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo01cooooo00?o003o
ooooooooool0>_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo03Wooooo00?o003o
ool00?ooool0:_ooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00?ooooo0ol00005ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0>Oooool0
0ol00?ooooooooooo`0Looooo`03o`00oooooooooooo03[ooooo00?o003oooooooooool07?ooool0
0ol00?ooooooooooo`0iooooo`03o`00oooo003ooooo02[ooooo0007ooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool01Ooo
ool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo03[ooooo00?o003oooooooooool07?oo
ool00ol00?ooooooooooo`0jooooo`03o`00oooo003ooooo01_ooooo00?o003oooooooooool0>_oo
ool00ol00?ooo`00ooooo`0Zooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo01_ooooo00?o
003oooooooooool0>oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo03_ooooo00?o
003oooooooooool06_ooool00ol00?ooooooooooo`0kooooo`03o`00oooooooooooo02Wooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0kooooo`03o`00oooo
oooooooo01_ooooo00?o003oooooooooool0>oooool00ol00?ooooooooooo`0Jooooo`03o`00oooo
oooooooo03_ooooo00?o003oooooooooool0:Oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001Oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo01[ooooo00?o
003oooooooooool0>oooool00ol00?ooooooooooo`0Jooooo`03o`00oooo003ooooo03cooooo00?o
003oooooooooool06_ooool00ol00?ooooooooooo`0kooooo`03o`00oooooooooooo02Wooooo000Q
ooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0k
ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool0??ooool00ol00?ooooooooooo`0J
ooooo`03o`00oooooooooooo03_ooooo00?o003oooooooooool0:Oooool0027ooooo00?o0000oooo
ooooool01_ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo03cooooo00?o003ooooo
ooooool06_ooool00ol00?ooooooooooo`0looooo`03o`00oooooooooooo01Wooooo00?o003ooooo
ooooool0??ooool00ol00?ooooooooooo`0Yooooo`008Oooool00ol0003oooooooooo`06ooooo`03
o`00oooooooooooo01Wooooo00?o003oooooooooool0?Oooool00ol00?ooooooooooo`0Iooooo`03
o`00oooooooooooo03gooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0looooo`03
o`00oooooooooooo02Wooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool0
6Oooool00ol00?ooooooooooo`0mooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool0
?Oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo03gooooo00?o003oooooooooool0
:?ooool0027ooooo0ol00006ooooo`03o`00oooo003ooooo01Wooooo00?o003oooooooooool0?Ooo
ool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo03kooooo00?o003oooooooooool06?oo
ool00ol00?ooooooooooo`0mooooo`03o`00oooooooooooo02Sooooo000Qooooo`03o`000?oooooo
oooo00Oooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0mooooo`03o`00oooooooo
oooo01Sooooo00?o003oooooooooool0?_ooool00ol00?ooooooooooo`0Gooooo`03o`00oooo003o
oooo03kooooo00?o003oooooooooool0:?ooool0027ooooo00?o0000ooooooooool01oooool00ol0
0?ooooooooooo`0Gooooo`03o`00oooooooooooo03kooooo00?o003oooooooooool06?ooool00ol0
0?ooooooooooo`0nooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool0?_ooool00ol0
0?ooooooooooo`0Xooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo01Oo
oooo00?o003oooooooooool0?oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo03ko
oooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0nooooo`03o`00oooooooooooo02So
oooo000Qooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool05oooool00ol00?oooooo
ooooo`0oooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool0?oooool00ol00?oooooo
ooooo`0Fooooo`03o`00oooooooooooo03oooooo00?o003oooooooooool09oooool0027ooooo00?o
0000ooooooooool01oooool00ol00?ooo`00ooooo`0Fooooo`03ool00?l00?oooooo043ooooo00?o
003oooooooooool05_ooool00ol00?ooooooooooo`10ooooo`03o`00oooooooooooo01Kooooo00?o
003oooooooooool0?oooool00ol00?ooooooooooo`0Wooooo`008Oooool00ol0003oooooooooo`08
ooooo`03o`00oooooooooooo01Gooooo00?oo`00o`00ooooool0@?ooool00ol00?ooooooooooo`0F
ooooo`03o`00oooooooooooo043ooooo00?o003oooooooooool05Oooool00ol00?ooo`00ooooo`10
ooooo`03o`00oooooooooooo02Oooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`10ooooo`03o`00oooooooooooo01Kooooo00?o003ooooo
ooooool0@?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo043ooooo00?o003ooooo
ooooool09oooool0027ooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`0Eooooo`03
o`00oooooooooooo047ooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`10ooooo`03
o`00oooooooooooo01Gooooo00?o003oooooooooool0@?ooool00ol00?ooo`00ooooo`0Wooooo`00
8Oooool3o`0000Sooooo00?o003oooooooooool05?ooool00ooo003o003oooooo`12ooooo`03o`00
oooooooooooo01Cooooo00?o003oooooooooool0@Oooool00ol00?ooo`00ooooo`0Eooooo`03o`00
oooooooooooo047ooooo00?o003oooooooooool09_ooool0027ooooo00?o0000ooooooooool02?oo
ool00ol00?ooo`00ooooo`0Dooooo`03ool00?l00?oooooo04;ooooo00?o003oooooooooool05?oo
ool00ol00?ooooooooooo`12ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool0@_oo
ool00ol00?ooooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`00oooooooo
oooo01?ooooo00?oo`00o`00ooooool0@_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooo
oooo04;ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`12ooooo`03o`00oooooooo
oooo02Kooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool04oooool00ol0
0?ooooooooooo`13ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool0@_ooool00ol0
0?ooooooooooo`0Cooooo`03o`00oooooooooooo04;ooooo00?o003oooooooooool09_ooool0027o
oooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo04?o
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo01?o
oooo00?o003oooooooooool0@oooool00ol00?ooooooooooo`0Uooooo`008Oooool00ol0003ooooo
ooooo`09ooooo`03o`00oooooooooooo01;ooooo00?oo`00o`00ooooool0A?ooool00ol00?oooooo
ooooo`0Booooo`03o`00oooooooooooo04?ooooo00?o003oool00?ooool04_ooool00ol00?oooooo
ooooo`14ooooo`03o`00oooooooooooo02Gooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o
003oooooooooool04Oooool00ooo003o003oooooo`14ooooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool0A?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo04Cooooo00?o
003oooooooooool09Oooool0027ooooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`0A
ooooo`03ool00?l00?oooooo04Gooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`14
ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0AOooool00ol00?ooooooooooo`0T
ooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo017ooooo00?o003ooooo
ooooool0AOooool00ol00?ooooooooooo`0@ooooo`03ool00?l00?oooooo04Gooooo00?o003ooooo
ooooool04Oooool00ol00?ooooooooooo`15ooooo`03o`00oooooooooooo02Cooooo000Qooooo`?o
00002oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo04Gooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`15ooooo`03o`00oooooooooooo017ooooo00?o003ooooooooo
ool0AOooool00ol00?ooooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`0;ooooo`03o`00
oooooooooooo00oooooo00?oo`00o`00ooooool0A_ooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo04Kooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`16ooooo`03o`00
oooo003ooooo02Cooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool03ooo
ool00ooo003o003oooooo`17ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0A_oo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo04Oooooo00?o003oooooooooool08ooo
ool0027ooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`0>ooooo`03ool00?l00?oo
oooo04Oooooo00?o003oooooooooool03_ooool00ooo003o003oooooo`17ooooo`03o`00oooooooo
oooo00oooooo00?o003oooooooooool0Aoooool00ol00?ooooooooooo`0Sooooo`008Oooool00ol0
003oooooooooo`0<ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0Aoooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo04Sooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`18ooooo`03o`00oooo003ooooo02?ooooo000Qooooo`03o`000?oooooooooo00co
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`18ooooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool0B?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo04Wo
oooo00?o003oooooooooool08_ooool0027ooooo00?o0000ooooooooool03Oooool00ol00?oooooo
ooooo`0=ooooo`03o`00oooooooooooo04Sooooo00?o003oooooooooool03?ooool00ooo003o003o
ooooo`19ooooo`03ool00?l00?oooooo00gooooo00?o003oooooooooool0BOooool00ol00?oooooo
ooooo`0Rooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0BOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo04[ooooo00?o
003oooooooooool02oooool00ol00?ooo`00ooooo`1:ooooo`03o`00oooooooooooo02;ooooo000Q
ooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1:
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0B_ooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo04[ooooo00?o003oooooooooool08_ooool0027ooooo00?o0000oooo
ooooool03Oooool00ol00?ooo`00ooooo`0;ooooo`03o`00oooooooooooo04_ooooo00?o003ooooo
ooooool02_ooool00ooo003o003oooooo`1<ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool0Boooool00ol00?ooooooooooo`0Qooooo`008Oooool3o`0000kooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`1;ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool0C?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo04_ooooo00?o003ooooooooo
ool08Oooool0027ooooo00?o0000ooooooooool03_ooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo04cooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`1<ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool0C?ooool00ol00?ooooooooooo`0Qooooo`008Ooo
ool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0COoo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo04gooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`1=ooooo`03o`00oooooooooooo023ooooo000Qooooo`03o`000?oooooo
oooo00oooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`1=ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool0C_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo04gooooo00?o003oooooooooool08?ooool0027ooooo00?o0000ooooooooool04?ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo04kooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`1>ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0Coooool00ol0
0?ooooooooooo`0Oooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool0D?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo053o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo01oo
oooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool0DOooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo05;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Aooooo`03o`00
oooooooooooo01kooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05?ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`1Cooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0Dooo
ool00ol00?ooooooooooo`0Mooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01;ooooo0_l00?l2ooooo`;o003oE_ooool00ol00?ooooooooooo`02o`00oeKooooo0_l00?l2
ooooo`03o`00oooooooooooo05Gooooo00?o003oooooooooool07?ooool001[ooooo00?o0000oooo
ooooool01?ooool3o`0001?ooooo0ol00?mIooooo`?o003oF?ooool3o`00oeWooooo0_l00?lLoooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006
ooooo`03o`000?oooooooooo0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00:Sooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0@ooooo`03o`00
0?o^k^kooooo0:Cooooo002Yooooo`05o`000?ooooooooooooooool000000_ooool6o`0000_ooooo
00?oEEEEojVYZOooool0Y?ooool0023ooooo00?o^[Zjoc8b<_ooool0Q_ooool01Ol0003ooooooooo
oooooooo000001?ooooo00?oZJVYoeEEEOooool0Y?ooool0027ooooo00?o0000ooooooooool0QOoo
ool01Ol0003ooooooooooooooooo000000;ooooo1_l0000<ooooo`03ob4Q8Ooooooooooo0:?ooooo
000Oooooo`05oiRHV?l@413o0000o`000?nYZJT0QOooool01Ol0003oQhN7oooooonYZJWo000001Co
oooo00?oEEEEolc<c?ooool0Xoooool001oooooo00Ko0000ojVYZOmEEEGoV9RHoeEEEOnj^[Z3oooo
o`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool04_ooool00onYZJWoMgMgooooo`2Soooo
o`007oooool01_lb<S;ok^k^oiRHV?mEEEGogMgMoa0@49[ooooo00Go410@oooooooooooooooooc8b
<P2Tooooo`007oooool01onj^[[oA4A4olc<c?lQ8B7ooooooa0@4?o<c<`0VOooool5o`000:Cooooo
000Oooooo`07onk^k_l0003oooooo`000?ooooooIVIVohN7Q`3ooooood?ooooo000Oooooo`04ofIV
I_nHV9Sooooooc8b<P;o^[Zj00?o0000ooooooooool0oooooom1ooooo`008_ooool00omVIVKoQhN7
ooooo`3oooooodCooooo000Rooooo`03ojVYZOm4A4Cooooo0?ooooooA?ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.179101, -1.0861, \
0.0066032, 0.0136034}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0.309017 0.294302 [
[.17539 .29652 -12 -9 ]
[.17539 .29652 12 0 ]
[.32696 .29652 -9 -9 ]
[.32696 .29652 9 0 ]
[.47854 .29652 -12 -9 ]
[.47854 .29652 12 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -12 -9 ]
[.78169 .29652 12 0 ]
[.93327 .29652 -9 -9 ]
[.93327 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .01472 -12 -4.5 ]
[.01131 .01472 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(0.25)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(0.5)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(0.75)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(1)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(1.25)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(1.5)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01472 m
.03006 .01472 L
s
[(-1)] .01131 .01472 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ .05 .05 ] 0 setdash
.02381 .30902 m
.03279 .4154 L
.04262 .51486 L
.04758 .55308 L
.0503 .56996 L
.05288 .58292 L
.05528 .59204 L
.05664 .59599 L
.05789 .59888 L
.05894 .60072 L
.0601 .60214 L
.06131 .60292 L
.06244 .60296 L
.0631 .60265 L
.06379 .60208 L
.06504 .60046 L
.06581 .5991 L
.06653 .59756 L
.06788 .59403 L
.07036 .58529 L
.07305 .57251 L
.0781 .53981 L
.08274 .50098 L
.10458 .25385 L
.11366 .15205 L
.11867 .10442 L
.1234 .06743 L
.12608 .05044 L
.12899 .03544 L
.13028 .03019 L
.13164 .02545 L
.13282 .02206 L
.13409 .01914 L
.13537 .01698 L
.13654 .01569 L
.13766 .01508 L
.13883 .01512 L
.14013 .01609 L
.14133 .01772 L
.14265 .02031 L
.14407 .024 L
.14666 .03319 L
.1494 .04638 L
.15431 .07841 L
.1596 .12322 L
.16541 .18266 L
.18557 .41985 L
.19034 .47089 L
.19554 .5195 L
.20013 .55423 L
Mistroke
.20265 .56971 L
.20501 .58179 L
.20644 .58777 L
.20799 .59308 L
.20927 .59664 L
.21 .59831 L
.21068 .59965 L
.21137 .60079 L
.21201 .60162 L
.21269 .6023 L
.21341 .60277 L
.21471 .60298 L
.21593 .60234 L
.21714 .60093 L
.21841 .59867 L
.21951 .59611 L
.22071 .59264 L
.22339 .5825 L
.2259 .5699 L
.23062 .53875 L
.23576 .49506 L
.24613 .38398 L
.26464 .16664 L
.26995 .11426 L
.27495 .07333 L
.27943 .04505 L
.28196 .03292 L
.28429 .02458 L
.2855 .02128 L
.2868 .0185 L
.28803 .01663 L
.28915 .01554 L
.29046 .01505 L
.2912 .01514 L
.29189 .01548 L
.29315 .01683 L
.29378 .0178 L
.29448 .01911 L
.29588 .02239 L
.29716 .02621 L
.30004 .03761 L
.30258 .0509 L
.30526 .06805 L
.31479 .15082 L
.32497 .26559 L
.34333 .47706 L
.3483 .52265 L
.35356 .56101 L
.35631 .57652 L
.35776 .58341 L
Mistroke
.35933 .58968 L
.36077 .5943 L
.36208 .59767 L
.3634 .60023 L
.36465 .60189 L
.36592 .6028 L
.36707 .60294 L
.36771 .60275 L
.3684 .60231 L
.36965 .60076 L
.37083 .59862 L
.37207 .59565 L
.37429 .58851 L
.37688 .5773 L
.3793 .56399 L
.3848 .52453 L
.39526 .42124 L
.40517 .3041 L
.41399 .19983 L
.41901 .14607 L
.42373 .10187 L
.42877 .06332 L
.43339 .03718 L
.4358 .02737 L
.43701 .02357 L
.43833 .02022 L
.43966 .01768 L
.44041 .01663 L
.44109 .01592 L
.44241 .01515 L
.44365 .01521 L
.44472 .01586 L
.44589 .01732 L
.44711 .01959 L
.44825 .02237 L
.4503 .02887 L
.4525 .038 L
.4575 .0671 L
.46208 .10266 L
.48272 .33048 L
.49277 .44667 L
.50186 .53222 L
.50645 .56414 L
.50887 .5774 L
.51141 .58858 L
.51365 .59571 L
.51491 .59866 L
.5161 .60072 L
.51718 .60203 L
.51817 .60272 L
Mistroke
.51932 .60293 L
.5204 .60254 L
.52153 .60152 L
.52278 .59951 L
.52409 .59661 L
.52531 .59315 L
.5275 .58523 L
.52985 .57428 L
.53522 .53997 L
.54012 .49882 L
.56071 .266 L
.57073 .15283 L
.57982 .07247 L
.58439 .04406 L
.58696 .03201 L
.58819 .02733 L
.58933 .0237 L
.59042 .02086 L
.59141 .01877 L
.59251 .01699 L
.59369 .01574 L
.59482 .01517 L
.59606 .01525 L
.59722 .01601 L
.5983 .01732 L
.59942 .01941 L
.60064 .02235 L
.60284 .02945 L
.60545 .04077 L
.60785 .05385 L
.61279 .08883 L
.618 .13527 L
.63796 .36471 L
.64666 .46255 L
.65124 .50684 L
.6561 .5462 L
.65859 .5627 L
.66134 .57784 L
.66384 .58871 L
.66618 .59613 L
.66741 .59891 L
.66857 .60087 L
.66962 .60208 L
.67077 .60279 L
.67201 .60284 L
.67332 .60208 L
.67457 .60059 L
.6757 .59846 L
.67701 .59519 L
.6784 .59084 L
Mistroke
.68088 .58085 L
.68356 .56701 L
.68649 .54807 L
.69664 .45787 L
.71782 .21043 L
.72268 .15719 L
.72784 .10753 L
.73263 .06943 L
.73711 .04231 L
.7393 .0322 L
.74167 .02378 L
.74295 .02048 L
.74365 .01902 L
.74429 .01786 L
.74544 .01632 L
.7467 .01535 L
.74735 .01515 L
.74806 .01517 L
.74934 .01582 L
.75059 .01722 L
.75174 .01924 L
.75299 .02223 L
.75435 .02638 L
.75712 .0374 L
.75959 .05013 L
.76184 .06415 L
.76691 .10329 L
.77606 .19507 L
.78607 .31334 L
.79672 .43787 L
.80581 .52564 L
.8083 .54495 L
.81099 .56282 L
.81351 .57679 L
.81586 .58728 L
.8181 .59494 L
.81935 .59805 L
.8205 .6002 L
.82175 .60185 L
.82246 .60244 L
.82311 .60277 L
.82431 .60284 L
.82558 .60216 L
.82679 .60078 L
.82809 .59847 L
.82933 .59541 L
.83045 .59198 L
.8332 .58112 L
.83582 .56765 L
.84036 .53707 L
Mistroke
.84458 .50156 L
.85414 .40148 L
.87295 .17978 L
.8781 .12705 L
.88354 .08023 L
.88818 .04932 L
.89082 .03594 L
.89328 .02627 L
.89461 .02222 L
.89531 .02048 L
.89606 .01892 L
.89671 .01778 L
.89742 .01676 L
.89869 .01556 L
.89991 .01514 L
.90123 .0155 L
.90248 .01661 L
.90362 .01829 L
.90426 .01952 L
.90495 .02112 L
.9062 .02461 L
.90902 .03521 L
.91199 .0503 L
.9147 .06737 L
.92508 .15867 L
.93487 .27003 L
.95356 .48402 L
.9581 .52489 L
.96298 .56046 L
.96578 .57623 L
.96834 .58764 L
.96957 .59206 L
.97091 .59608 L
.97217 .59907 L
.97334 .60115 L
.97407 .60209 L
.97472 .60272 L
.97548 .60317 L
.97619 .60332 L
Mfstroke
0 0 1 r
[ ] 0 setdash
.02381 .30902 m
.03279 .41547 L
.04262 .51505 L
.04758 .55343 L
.0503 .57029 L
.05288 .58319 L
.05528 .59242 L
.05664 .59641 L
.05789 .59929 L
.05894 .60112 L
.0601 .6025 L
.06131 .60323 L
.06244 .60325 L
.0631 .60296 L
.06379 .60243 L
.06504 .60086 L
.06581 .59951 L
.06653 .59798 L
.06788 .59443 L
.07036 .58561 L
.07305 .57281 L
.0781 .54013 L
.08274 .50119 L
.10458 .25377 L
.11366 .15183 L
.11867 .10421 L
.1234 .06708 L
.12608 .05009 L
.12899 .0352 L
.13028 .02987 L
.13164 .02507 L
.13282 .02165 L
.13409 .01872 L
.13537 .01658 L
.13654 .01532 L
.13766 .01476 L
.13883 .01485 L
.14013 .01575 L
.14133 .01733 L
.14265 .0199 L
.14407 .02359 L
.14666 .03286 L
.1494 .04609 L
.15431 .07808 L
.1596 .123 L
.16541 .1825 L
.18557 .41997 L
.19034 .47113 L
.19554 .51971 L
.20013 .55458 L
Mistroke
.20265 .57006 L
.20501 .58207 L
.20644 .58806 L
.20799 .59344 L
.20927 .59705 L
.21 .59873 L
.21068 .60007 L
.21137 .6012 L
.21201 .60202 L
.21269 .60268 L
.21341 .60313 L
.21471 .60327 L
.21593 .60264 L
.21714 .60129 L
.21841 .59906 L
.21951 .59653 L
.22071 .59305 L
.22339 .58282 L
.2259 .57018 L
.23062 .53908 L
.23576 .49527 L
.24613 .38407 L
.26464 .16646 L
.26995 .11401 L
.27495 .07302 L
.27943 .04469 L
.28196 .03266 L
.28429 .02423 L
.2855 .02088 L
.2868 .01808 L
.28803 .01621 L
.28915 .01516 L
.29046 .01472 L
.2912 .01485 L
.29189 .01521 L
.29315 .0165 L
.29378 .01744 L
.29448 .01872 L
.29588 .02198 L
.29716 .02581 L
.30004 .0373 L
.30258 .05061 L
.30526 .06771 L
.31479 .1506 L
.32497 .26553 L
.34333 .4773 L
.3483 .52287 L
.35356 .56138 L
.35631 .57687 L
.35776 .58371 L
Mistroke
.35933 .58996 L
.36077 .59465 L
.36208 .59807 L
.3634 .60065 L
.36465 .60231 L
.36592 .60318 L
.36707 .60328 L
.36771 .60305 L
.3684 .60257 L
.36965 .60109 L
.37083 .599 L
.37207 .59605 L
.37429 .5889 L
.37688 .5776 L
.3793 .56428 L
.3848 .52482 L
.39526 .42138 L
.40517 .30411 L
.41399 .1997 L
.41901 .14585 L
.42373 .10162 L
.42877 .06298 L
.43339 .03685 L
.4358 .02709 L
.43702 .02319 L
.43833 .01983 L
.43965 .01729 L
.44087 .0157 L
.44162 .0151 L
.44233 .01478 L
.44296 .01472 L
.44365 .01487 L
.4448 .01566 L
.44587 .01699 L
.44705 .0191 L
.44831 .02213 L
.45089 .0307 L
.45324 .04128 L
.45778 .06866 L
.46208 .1024 L
.48216 .32371 L
.4909 .42642 L
.50034 .52004 L
.50564 .55949 L
.50796 .57312 L
.51051 .58527 L
.51167 .58981 L
.51292 .59397 L
.51399 .59695 L
.51516 .59955 L
Mistroke
.51648 .60167 L
.51773 .60289 L
.51895 .60332 L
.52007 .60306 L
.52127 .60208 L
.52257 .60022 L
.5238 .5977 L
.52492 .59475 L
.52765 .58498 L
.53026 .57244 L
.53542 .53876 L
.54106 .49019 L
.56237 .24611 L
.57243 .13554 L
.57685 .09537 L
.58169 .05944 L
.58396 .04596 L
.5864 .03406 L
.58774 .02867 L
.58897 .0245 L
.59013 .02122 L
.59137 .01846 L
.592 .01733 L
.5927 .01632 L
.59394 .01514 L
.59463 .01481 L
.59538 .01472 L
.59609 .0149 L
.59674 .01528 L
.59792 .01652 L
.59922 .01867 L
.60057 .02181 L
.60183 .02553 L
.6043 .03504 L
.60664 .04663 L
.61101 .07476 L
.62081 .16371 L
.63912 .37856 L
.64953 .49123 L
.65461 .53537 L
.65926 .56707 L
.66161 .57955 L
.66418 .59026 L
.66535 .59412 L
.6666 .5975 L
.66777 .59998 L
.66884 .60164 L
.66949 .60238 L
.67017 .60292 L
.67139 .60332 L
Mistroke
.6727 .60291 L
.67345 .6023 L
.67414 .60148 L
.6754 .59938 L
.67655 .59678 L
.67913 .5886 L
.68182 .5767 L
.68431 .56276 L
.68994 .52166 L
.70017 .41973 L
.70994 .30401 L
.72045 .18082 L
.72529 .13086 L
.73038 .08597 L
.73473 .05532 L
.73701 .04244 L
.73948 .03115 L
.74081 .02625 L
.74203 .02249 L
.74318 .01963 L
.74444 .01723 L
.74558 .01576 L
.74663 .01496 L
.74775 .01472 L
.74895 .01516 L
.75025 .01645 L
.75098 .01754 L
.75166 .0188 L
.75291 .0217 L
.75424 .02561 L
.75653 .03436 L
.75906 .04688 L
.76358 .07616 L
.76845 .11674 L
.77727 .20857 L
.79688 .4398 L
.80226 .49455 L
.808 .543 L
.81079 .56194 L
.81343 .57677 L
.81579 .58739 L
.81703 .5919 L
.81836 .59593 L
.81965 .59899 L
.82082 .60108 L
.822 .6025 L
.82312 .6032 L
.82442 .60323 L
.82562 .6025 L
.82694 .60086 L
Mistroke
.82768 .59957 L
.82835 .59817 L
.83097 .59057 L
.83245 .58484 L
.83381 .57866 L
.83894 .54785 L
.84335 .51285 L
.84818 .46678 L
.85794 .35689 L
.8688 .22641 L
.87909 .11746 L
.88357 .07969 L
.88833 .04814 L
.89081 .03559 L
.89213 .03009 L
.89355 .02507 L
.89485 .02133 L
.89604 .01864 L
.89718 .01671 L
.89837 .01538 L
.89963 .01475 L
.90081 .01488 L
.90188 .0156 L
.90303 .01701 L
.90429 .0193 L
.90562 .02258 L
.908 .0306 L
.91021 .0404 L
.91227 .05158 L
.91696 .08381 L
.92676 .17645 L
.93729 .29925 L
.94684 .41285 L
.95188 .46745 L
.95725 .51802 L
.96241 .55705 L
.96708 .58279 L
.96934 .59164 L
.97052 .59532 L
.97177 .59845 L
.97287 .60057 L
.97408 .6022 L
.97517 .60306 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool000oooooo
1_l00005ooooo`03o`000?oooooooooo00Cooooo0ol0000Qooooo`;o003o;Oooool2o`00obkooooo
0_l00?l]ooooo`;o003o;_ooool2o`00obgooooo0ol00?lcooooo`006_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo023ooooo00?o003oooooool00?l0;Oooool00ol00?ooooooo`00
o`0/ooooo`04o`00oooooooo003oo`00obcooooo00?o003oooooool00?l0;?ooool01?l00?ooo`00
o`00ool00?l/ooooo`03o`00oooooooo003o03?ooooo000Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool07oooool01Ol00?oooooooooooooooooo003o02_ooooo00Co003ooooooooo
oooo003o;?ooool01?l00?ooooooooooool00?l[ooooo`04o`00ooooooooooooo`00obcooooo00Co
003ooooooooooooo003o:oooool01Ol00?oooooooooooooooooo003o03;ooooo000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool07oooool01Ol00?oooooooooooooooooo003o02_o
oooo00Go003oooooooooooooo`00o`00o`0Zooooo`05o`00ooooooooooooooooool00?l0:oooool0
1Ol00?oooooooooooooooooo003o02_ooooo00Co003ooooooooooooo003o:oooool01Ol00?oooooo
oooooooooooo003o03;ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
7oooool01Ol00?oooooooooooooooooo003o02_ooooo00Go003oooooooooooooooooo`00o`0Zoooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo02Sooooo00Go003oooooooooooooooooo`00o`0[ooooo`05o`00oooooooo
ooooooooool00?l0<_ooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`0O
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0W
ooooo`03o`00oooooooooooo00;ooooo00?oo`00o`00ooooool0:?ooool01_l00?oooooooooooooo
ooooo`00o`00ob[ooooo00Go003oooooooooooooooooo`00o`0booooo`008Oooool00ol0003ooooo
ooooo`0Nooooo`03o`00oooo003ooooo00?ooooo00?o003oooooooooool09oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`0Wooooo`03o`00oooooooooooo00;ooooo00?oo`00o`00ooooool0:?ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo02Oooooo00?oo`00o`00ooooool00_ooool00ol00?oooooo
ooooo`0`ooooo`008Oooool00ol0003oooooooooo`0Nooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool09oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02Kooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool09oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02Oooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0_ooooo`008Oooool00ol0003oooooooooo`0N
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0W
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0_
ooooo`008Oooool3o`0001gooooo00?o003oool00?ooool01Oooool00ol00?ooooooooooo`0Uoooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo02Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Voooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool09Oooool00ol00?ooo`00ooooo`04oooo
o`03o`00oooooooooooo02oooooo000Qooooo`03o`000?oooooooooo01gooooo00?o003oool00?oo
ool01Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool09_ooool00ol00?ooooooooooo`03ooooo`03o`00oooo003ooooo02Kooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool09Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02oooooo000Qooooo`03o`00
0?oooooooooo01gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Uooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo02Gooooo00?o003oooooooooool01?ooool00ol00?ooo`00ooooo`0Vooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo02kooooo000Qooooo`03o`000?oooooooooo01gooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool09Ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool01?oo
ool00ol00?ooo`00ooooo`0Uooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09Ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02kooooo000Qooooo`03o`000?oooooo
oooo01gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo02Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo02kooooo000Qooooo`03o`000?oooooooooo01gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0Tooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0Tooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooo003ooooo02kooooo000Qooooo`03o`000?oooooooooo01go
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo003ooooo02Co
oooo00?oo`00o`00ooooool01_ooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool08oooool00ooo003o003oooooo`06ooooo`03o`00oooo003ooooo02ko
oooo000Qooooo`03o`000?oooooooooo01gooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Sooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool09?ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo02?ooooo00?oo`00o`00ooooool01_ooool00ol00?oooooo
ooooo`0Tooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooo003ooooo02kooooo000Qooooo`03o`000?oooooooooo01gooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool09?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02?ooooo00?o
o`00o`00ooooool01_ooool00ol00?ooo`00ooooo`0Tooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool08oooool00ol00?ooooooooooo`06ooooo`03o`00oooo003ooooo02kooooo000Q
ooooo`?o00007Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02?ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool08oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02;ooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool0;Oooool0027ooooo00?o0000ooooooooool07Oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo02?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Soooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo02;ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Soooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool0;Oooool0027ooooo00?o0000oooooooo
ool07?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02?ooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool08oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02;ooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool0;Oooool0027ooooo00?o0000ooooooooool07?ooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo02?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Sooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo02;ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Sooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool0;Oooool0027ooooo00?o0000ooooooooool07?oo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool08_oo
ool00ooo003o003oooooo`08ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Oooooo00?o003oool00?ooool0;Ooo
ool0027ooooo00?o0000ooooooooool07?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo02;ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo02;ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooo
oooo00Oooooo00?o003oool00?ooool0;Oooool0027ooooo00?o0000ooooooooool07?ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0Rooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool08Oooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0Qooooo`03o`00oooooooooooo00Sooooo00?o003oool00?ooool0;Oooool0027o
oooo00?o0000ooooooooool07?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo027o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo023o
oooo00?oo`00o`00ooooool02Oooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00So
oooo00?o003oool00?ooool0;Oooool0027ooooo00?o0000ooooooooool06oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0Qooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool08Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0Qooooo`03o`00oooooooooooo00Sooooo00?o003oool00?ooool0;Oooool0027ooooo00?o
0000ooooooooool06oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo027ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool08Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo023ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Sooooo00?o
003oool00?ooool0;Oooool0027ooooo0ol0000Kooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool08Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo027ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool08?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo027ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0/ooooo`008Oooool00ol0003oooooooooo`0Koooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo027ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Qoooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo027ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0/oooo
o`008Oooool00ol0003oooooooooo`0Kooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool08?ooool00ol00?ooooooooooo`09ooooo`03ool00?l00?oooooo027ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool08?ooool00ol00?ooooooooooo`09ooooo`03ool00?l00?oooooo023ooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`0/ooooo`008Oooool00ol0003oooooooooo`0Kooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`09ooooo`03ool0
0?l00?oooooo027ooooo00?o003oooooooooool02Oooool00ol00?ooo`00ooooo`0Qooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`09ooooo`03ool0
0?l00?oooooo023ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0/ooooo`008Ooo
ool00ol0003oooooooooo`0Kooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool07ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool02Ooo
ool00ol00?ooo`00ooooo`0Pooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool08?oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`0/ooooo`008Oooool00ol0003oooooooooo`0Jooooo`03o`00oooo003o
oooo00_ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo023ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool07oooool00ol00?ooo`00ooooo`0;ooooo`03o`00oooooooo
oooo01oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0/ooooo`008Oooool00ol0
003oooooooooo`0Jooooo`03o`00oooo003ooooo00_ooooo00?o003oooooooooool07oooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`0Oooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool07_ooool00ol0
0?ooo`00ooooo`0;ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`0/ooooo`008Oooool00ol0003oooooooooo`0Jooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01oo
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool07_ooool00ol00?ooo`00ooooo`0;ooooo`03o`00oooooooooooo01oo
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0/ooooo`008Oooool00ol0003ooooo
ooooo`0Jooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool07oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`0Oooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool07_ooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`0/ooooo`008Oooool3o`0001[ooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`0Oooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool07oooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`0Nooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool07oooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo02_ooooo000Qooooo`03o`000?oooooooooo01[ooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool07oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01oooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00_ooooo00?oo`00
o`00ooooool07oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo02_ooooo000Qoooo
o`03o`000?oooooooooo01[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Noooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo01oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0Noooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool07Oooool00ol00?ooo`00ooooo`0<oooo
o`03o`00oooooooooooo02_ooooo000Qooooo`03o`000?oooooooooo01Wooooo00?o003oool00?oo
ool03Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool07_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooo003ooooo01oooooo00?o003ooooooooo
ool02oooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool07Oooool00ol00?ooo`00ooooo`0<ooooo`03o`00oooooooooooo02_ooooo000Qooooo`03o`00
0?oooooooooo01Wooooo00?o003oool00?ooool03Oooool00ol00?ooooooooooo`0Mooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0;ooooo`03o`00
oooo003ooooo01kooooo00?oo`00o`00ooooool03?ooool00ol00?ooooooooooo`0Nooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool07Oooool00ol00?ooo`00ooooo`0<ooooo`03o`00
oooooooooooo02_ooooo000Qooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool07_oo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooo003ooooo01kooooo00?oo`00o`00ooooool03?oo
ool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool07Ooo
ool00ol00?ooo`00ooooo`0<ooooo`03o`00oooooooooooo02_ooooo0007ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`00
0?oooooooooo01Wooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Mooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo01gooooo00?oo`00o`00ooooool03?ooool00ooo003o003oooooo`0Nooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo02_ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool07Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01kooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Mooooo`03ool00?l00?oooooo00cooooo
00?oo`00o`00ooooool07_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01gooooo
00?o003oooooooooool03?ooool00ol00?ooo`00ooooo`0[ooooo`001Ol00002ooooo`05oa0@4?oo
ooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool07Oooool00ooo003o003oooooo`0=ooooo`03o`00oooooooooooo01gooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool07Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo003ooooo02_ooooo
0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`?o0000
6Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
7Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00cooooo00?o003oool00?ooool0
:oooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01?ooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool07Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01gooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool07?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01cooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`0Zooooo`001oooool01Ol@413ooooooooooooooooo410@00co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01go
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01co
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Zooooo`001oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool06oooool00ooo003o003oooooo`0>ooooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Mooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Zooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01Wo
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Kooooo`03ool00?l00?oooooo00ko
oooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01co
oooo00?oo`00o`00ooooool03_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo02[o
oooo000Qooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool03Oooool00ooo003o003o
ooooo`0Looooo`03ool00?l00?oooooo00kooooo00?o003oooooooooool07?ooool00ol00?oooooo
ooooo`0=ooooo`03o`00oooooooooooo01cooooo00?oo`00o`00ooooool03_ooool00ol00?oooooo
ooooo`0Looooo`03o`00oooooooooooo00kooooo00?o003oooooooooool06oooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo02[ooooo000Qooooo`03o`000?oooooooooo01Sooooo00?o
003oooooooooool03oooool00ol00?ooooooooooo`0Kooooo`03ool00?l00?oooooo00kooooo00?o
003oooooooooool06oooool00ooo003o003oooooo`0>ooooo`03o`00oooooooooooo01cooooo00?o
o`00o`00ooooool03_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool06oooool00ol00?ooooooooooo`0>ooooo`03o`00oooo003ooooo02[ooooo000Q
ooooo`03o`000?oooooooooo01Sooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0K
ooooo`03ool00?l00?oooooo00kooooo00?o003oooooooooool06oooool00ooo003o003oooooo`0?
ooooo`03o`00oooooooooooo01_ooooo00?oo`00o`00ooooool03_ooool00ol00?ooooooooooo`0L
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0>
ooooo`03o`00oooo003ooooo02[ooooo000Qooooo`03o`000?oooooooooo01Sooooo00?o003ooooo
ooooool03oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool06oooool00ooo003o003oooooo`0?ooooo`03o`00oooooooooooo01_ooooo00?oo`00o`00
ooooool03oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool06oooool00ol00?ooooooooooo`0>ooooo`03o`00oooo003ooooo02[ooooo000Qooooo`?o
00006?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01_ooooo00?o003ooooooooo
ool03_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00oooooo00?o003ooooooooo
ool06oooool00ooo003o003oooooo`0?ooooo`03o`00oooooooooooo01_ooooo00?o003ooooooooo
ool03_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00kooooo00?o003oool00?oo
ool0:_ooool0027ooooo00?o0000ooooooooool06?ooool00ol00?ooooooooooo`0?ooooo`03o`00
oooooooooooo01_ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Kooooo`03o`00
oooooooooooo00oooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0?ooooo`03o`00
oooooooooooo01_ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Kooooo`03o`00
oooooooooooo00kooooo00?o003oool00?ooool0:_ooool0027ooooo00?o0000ooooooooool06?oo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool06ooo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01[ooooo00?oo`00o`00ooooool03ooo
ool00ooo003o003oooooo`0Kooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0:Ooo
ool0027ooooo00?o0000ooooooooool06?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo
oooo01[ooooo00?oo`00o`00ooooool03oooool00ol00?ooo`00ooooo`0Kooooo`03o`00oooooooo
oooo00oooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo
oooo01[ooooo00?oo`00o`00ooooool03oooool00ooo003o003oooooo`0Kooooo`03o`00oooooooo
oooo00oooooo00?o003oooooooooool0:Oooool0027ooooo00?o0000ooooooooool06?ooool00ol0
0?ooooooooooo`0?ooooo`03ool00?l00?oooooo01[ooooo00?oo`00o`00ooooool03oooool00ol0
0?ooo`00ooooo`0Kooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool06oooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool03oooool00ooo
003o003oooooo`0Kooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0:Oooool0027o
oooo00?o0000ooooooooool06?ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01Wo
oooo00?oo`00o`00ooooool03oooool00ol00?ooo`00ooooo`0Kooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01[o
oooo00?o003oooooooooool03oooool00ooo003o003oooooo`0Kooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool0:Oooool0027ooooo00?o0000ooooooooool06?ooool00ol00?oooooo
ooooo`0@ooooo`03o`00oooooooooooo01Wooooo00?oo`00o`00ooooool04?ooool00ol00?oooooo
ooooo`0Jooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool06oooool00ol00?oooooo
ooooo`0?ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool03oooool00ooo003o003o
ooooo`0Jooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0:Oooool0027ooooo00?o
0000ooooooooool06?ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01Wooooo00?o
o`00o`00ooooool04?ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00oooooo00?o
003oooooooooool06oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01[ooooo00?o
003oooooooooool04?ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo013ooooo00?o
003oooooooooool0:Oooool0027ooooo00?o0000ooooooooool06?ooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo01Wooooo00?oo`00o`00ooooool04?ooool00ol00?ooooooooooo`0J
ooooo`03o`00oooooooooooo00oooooo00?oo`00o`00ooooool06oooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0I
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0:Oooool0027ooooo0ol0000Hoooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool06Oooool00ooo003o003oooooo`0@oooo
o`03o`00oooooooooooo01Wooooo00?o003oooooooooool04?ooool00ooo003o003oooooo`0Koooo
o`03o`00oooooooooooo00oooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo01Wooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Yoooo
o`008Oooool00ol0003oooooooooo`0Gooooo`03ool00?l00?oooooo017ooooo00?o003ooooooooo
ool06Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01Wooooo00?o003ooooooooo
ool04?ooool00ooo003o003oooooo`0Kooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool06Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01Wooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`0Yooooo`008Oooool00ol0003oooooooooo`0Gooooo`03ool0
0?l00?oooooo017ooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0@ooooo`03o`00
oooo003ooooo01Wooooo00?o003oooooooooool04?ooool00ooo003o003oooooo`0Kooooo`03o`00
oooooooooooo00oooooo00?oo`00o`00ooooool06_ooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo01Wooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Xooooo`008Ooo
ool00ol0003oooooooooo`0Gooooo`03ool00?l00?oooooo017ooooo00?o003oooooooooool06Ooo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooo003ooooo01Wooooo00?o003oooooooooool04?oo
ool00ooo003o003oooooo`0Jooooo`03o`00oooooooooooo013ooooo00?oo`00o`00ooooool06_oo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool04Ooo
ool00ol00?ooooooooooo`0Xooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`00oooooooo
oooo017ooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooo003o
oooo01Wooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooo
oooo013ooooo00?oo`00o`00ooooool06_ooool00ol00?ooooooooooo`0@ooooo`03ool00?l00?oo
oooo01Wooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Xooooo`008Oooool00ol0
003oooooooooo`0Gooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool06Oooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooo003ooooo01Wooooo00?o003oooooooooool04Oooool00ol0
0?ooooooooooo`0Iooooo`03o`00oooooooooooo013ooooo00?oo`00o`00ooooool06_ooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool04Oooool00ol0
0?ooooooooooo`0Xooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`00oooooooooooo017o
oooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooo003ooooo01Wo
oooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo013o
oooo00?oo`00o`00ooooool06_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01So
oooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Xooooo`008Oooool00ol0003ooooo
ooooo`0Gooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool06Oooool00ol00?oooooo
ooooo`0@ooooo`03o`00oooo003ooooo01Wooooo00?o003oooooooooool04Oooool00ol00?oooooo
ooooo`0Iooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool06Oooool00ol00?oooooo
ooooo`0Aooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool04Oooool00ol00?oooooo
ooooo`0Xooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool06?ooool00ol00?ooooooooooo`0@ooooo`03o`00oooo003ooooo01Wooooo00?o
003oooooooooool04Oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo017ooooo00?o
003oooooooooool06?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01Sooooo00?o
003oooooooooool04Oooool00ol00?ooooooooooo`0Xooooo`008Oooool00ol0003oooooooooo`0G
ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0A
ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool04Oooool00ooo003o003oooooo`0I
ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0B
ooooo`03o`00oooooooooooo01Oooooo00?oo`00o`00ooooool04_ooool00ol00?ooooooooooo`0X
ooooo`008Oooool3o`0001Oooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Hoooo
o`03o`00oooooooooooo017ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0Aoooo
o`03ool00?l00?oooooo01Wooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Hoooo
o`03o`00oooooooooooo01;ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0Boooo
o`03o`00oooooooooooo02Sooooo000Qooooo`03o`000?oooooooooo01Oooooo00?o003ooooooooo
ool04_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo017ooooo00?o003ooooooooo
ool05oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01Sooooo00?o003ooooooooo
ool04Oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo01;ooooo00?o003ooooooooo
ool05oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo02Sooooo000Qooooo`03o`00
0?oooooooooo01Oooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Gooooo`03o`00
oooooooooooo01;ooooo00?o003oooooooooool05oooool00ol00?ooo`00ooooo`0Cooooo`03o`00
oooooooooooo01Oooooo00?oo`00o`00ooooool04_ooool00ooo003o003oooooo`0Hooooo`03o`00
oooooooooooo01;ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0Booooo`03ool0
0?l00?oooooo02Sooooo000Qooooo`03o`000?oooooooooo01Oooooo00?o003oooooooooool04_oo
ool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool05ooo
ool00ol00?ooo`00ooooo`0Cooooo`03o`00oooooooooooo01Oooooo00?oo`00o`00ooooool04_oo
ool00ooo003o003oooooo`0Hooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool05ooo
ool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo02Oooooo000Qooooo`03o`000?oooooo
oooo01Oooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooo
oooo01;ooooo00?o003oooooooooool05oooool00ol00?ooo`00ooooo`0Cooooo`03o`00oooooooo
oooo01Oooooo00?o003oooooooooool04_ooool00ooo003o003oooooo`0Hooooo`03o`00oooooooo
oooo01;ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooo
oooo02Oooooo000Qooooo`03o`000?oooooooooo01Oooooo00?o003oooooooooool01?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B42ooooo`03o`00oooooooo000000Co00001?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00[ooooo00?o003oooooooooool02?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo00?o003oob4Q8Oooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00ko
oooo00?o003oool00?ooool01?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B43oooo
o`05o`00ooooooooooooo`000?o^k^h01Oooool01Om4A4Co0000o`000?lb<S;ogMgM00_ooooo00?o
003oooooooooool04Oooool2o`000003o`00ool0003o410@01Oooooo00?o003oooooooooool01?oo
ool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B43ooooo`03o`00ool0003o000000?o00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00_ooooo00?o003oooooooooool02?ooool4o`000003oa0@
4?oooooooooo00;ooooo0_lQ8B400ol00?ooooooooooo`02ooooo`05odA4A?l0003o0000oc8b<_oM
gMd08?ooool0027ooooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`04ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@;ooooo00Oo003ooooooonHV9So8B4Qonk^k_oooooo
A4A400Oooooo00?oMgMgoc8b<_ooool02Oooool00ol00?ooooooooooo`08ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool00ol00?oo8B4Qooooo`07ooooo`03ogMgMolb<S;ooooo00gooooo00?o
003oooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B43ooooo`05o`00
oooooooooooooeEEEOnYZJT02?ooool00omgMgOo<S8booooo`0:ooooo`03o`00oooooooooooo01?o
oooo00?o003oooooooooool05oooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00Co
oooo0_lQ8B44ooooo`05o`00oolQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0:oooo
o`03o`00oooooooooooo00[ooooo00?o0000ooooooooool01?ooool2ob4Q8@03o`00oooooooooooo
00Gooooo00?oMgMgoc8b<_ooool07oooool0027ooooo00?o0000ooooooooool05_ooool00ol00?oo
ooooooooo`05ooooo`05oa0@4?ooooooooooooooool@41002Oooool01_l00?oooooooooooonHV9So
8B4Qonk^kPWooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`08ooooo`05oa0@4?oo
ooooooooooooool@41001Oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00cooooo
00?o003oooooooooool01?ooool01Ol@413ooooooooooooooooo410@00[ooooo00Go003ooooooooo
ooooZJVYoeEEE@09ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool04oooool00ol0
0?ooooooooooo`0Gooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool02_ooool01?l0
0?ooV9RHob4Q8Oo^k^h9ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool02_ooool0
0ol0003oooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool07_ooool0
027ooooo00?o0000ooooooooool05_ooool00ol00?ooooooooooo`05ooooo`05o`000?oooooooooo
ooooool000002Oooool01ol00?ooooooooooooooooooV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`09ooooo`03o`00oooooooooooo00Sooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`00oooooooooooo00Oooooo00?oMgMgoc8b<_ooool03Oooool00ol00?ooooooooooo`04ooooo`05
o`000?ooooooooooooooool000002_ooool01Ol00?oooooooooooooooooo8B4Q00Sooooo00?oMgMg
oc8b<_ooool02_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01Kooooo00?oo`00
o`00ooooool01oooool00ol0003oooooooooo`0:ooooo`05o`00ooooooooV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`0:ooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool01_oo
ool00ol00?ooooooooooo`05ooooo`03ogMgMolb<S;ooooo01oooooo000Qooooo`?o00005_ooool0
0ol00?ooooooooooo`05ooooo`05o`000?ooooooooooooooool000002Oooool00ol00?oooooooooo
o`02ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00:ooooo`03o`00
oooooooooooo00Sooooo00Go0000ooooooooooooooooo`000005ooooo`03o`00oooooooooooo00Co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00>ooooo`03o`00oooooooooooo00Cooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`00oooooooooooooeEEEOo<c<`01?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00[ooooo00?oo`00o`00ooooool05?ooool00ol00?ooooooooooo`0Fooooo`03ool0
0?l00?oooooo00Oooooo00?o0000ooooooooool02_ooool01Ol00?oooooooooooomgMgOoIVIV00Co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00;ooooo`03o`00oooooooooooo00[ooooo00?o0000oooo
ooooool01_ooool00ol00?ooooooooooo`02ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`08?ooool0
027ooooo00?o0000ooooooooool05_ooool00ol00?ooooooooooo`05ooooo`05oa0@4?oooooooooo
ooooool@41002Oooool00ooo003o003oooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool03?ooool00ol00?ooooooooooo`08ooooo`05oa0@4?ooooooooooooooool@41001_oo
ool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool01?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go003oooooooooooooZJVYogMgM`04ooooo`03
o`000?oooooooooo00cooooo00?oo`00o`00ooooool05?ooool00ol00?ooooooooooo`0Fooooo`03
ool00?l00?oooooo00Oooooo00?o0000ooooooooool02_ooool01Ol00?oooooooooooooooooo0000
00Cooooo00?o0000ooooooooool03Oooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo
00Kooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`0Rooooo`008Oooool00ol0003o
ooooooooo`0Fooooo`03o`00oooooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09oooo
o`07ool00?l00?oo0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00cooooo00?o
003oooooooooool02?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o003oooooooooool0
0oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`00oooooooooooooooooolb<S801?ooool00ol0003oooooooooo`0<oooo
o`03ool00?l00?oooooo01Cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`07oooo
o`03o`000?oooooooooo00[ooooo00Go003ookZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooo
oooo00gooooo00?o003oooooooooool02_ooool00ol0003oooooooooo`07ooooo`05o`00oooooooo
ooooooooool000009?ooool0027ooooo00?o0000ooooooooool05_ooool00ol00?ooooooooooo`05
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02Oooool01ooo003o003ooiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`0000[ooooo00?oo`00o`00ooooool02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Kooooo00?o003oooooooooool00oooool4o`0000kooooo00?o003oool00?ooool01Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00?o003oo`000?l000000_l00004ooooo`Co00002oooool0
0ooo003o003oooooo`0Booooo`03oeEEEOmVIVKo003o01Sooooo00?o003oooooooooool01Oooool0
0omEEEGoIVIVo`00000<ooooo`05o`00ool@413o0000ob4Q8Oo<c<`01?ooool4o`0000cooooo00?o
003oooooooooool02?ooool00omEEEGoIVIVo`000009ooooo`04o`00ooooooooooooooooo`Co0000
8Oooool0027ooooo00?o0000ooooooooool05_ooool00ol00?ooooooooooo`0Cooooo`03ool00?l0
0?oooooo01Kooooo00?oo`00o`00ooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool05Oooool00ooo003o003oooooo`0Eooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool09_ooool0027ooooo00?o0000ooooooooool05Oooool0
0ooo003o003oooooo`0Dooooo`03ool00?l00?oooooo01Kooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05_ooool0
0ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool09_ooool0
027ooooo00?o0000ooooooooool05Oooool00ooo003o003oooooo`0Dooooo`03ool00?l00?oooooo
01Kooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool07?ooool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003o
ooooooooo`0Eooooo`03ool00?l00?oooooo01Gooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ooo003o
003oooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`0Looooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool0027ooooo00?o0000oooo
ooooool05Oooool00ooo003o003oooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?oo`00o`00
ooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool07Oooool01?oMgMgo0000oa0@4?o<c<`5ooooo`006_ooool7o`000003o`00ool0003o0000
01Go000000?o003oo`000?l000005Ol000000ol00?oo0000o`00000Eo`000003o`00ool0003o0000
01Co000000?o003oo`000?l000005Ol000000ol00?oo0000o`00000Eo`000003o`00ool0003o0000
01Go000000?o003oo`000?l000005Ol000000ol00?oo0000o`00000Do`000003ool00?l00?oo0000
01Go000000?oo`00o`00ool000005Ol000000ol00?oo0000o`00000Eo`000003o`00ool0003o0000
017o00003?ooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool00ol00?ooooooooooo`07oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00Ko0000ooooooooooooooooool00?l00?l3ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool01Ol00?oooooooooooooooooo000000Wooooo
00?o0000ooooooooool01_ooool00ol0003oooooo`00o`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00oooool01Ol00?oooooooooooooooooo000000Sooooo00?o0000oooooooo
ool01oooool00ol0003o003oooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool00_ooool01Ooo003o003ooooooooooooo000000Wooooo00?o0000ooooooooool01_ooool00ol0
003oo`00o`00o`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool01?l0
0?ooooooooooool00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool00?l01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo00Co8B4QogMgMomgMgOo<S8b1Ooo
ool0027ooooo00?o003oool00?ooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooo
oooo01Cooooo00?oo`00o`00ooooool05Oooool00ol00?ooo`00ooooo`0Eooooo`03o`00oooooooo
oooo01Cooooo00?o0000ool00?l00?l05_ooool00ol00?ooooooooooo`0Dooooo`03o`000?l00?oo
oooo01Gooooo00?oo`00o`00ooooool05?ooool00ol0003oo`00o`00o`0Fooooo`03o`00oooooooo
oooo01?ooooo00?o0000ooooool00?l07_ooool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0
0?ooo`00ooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ooo
003o003oooooo`0Fooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05Oooool00ooo
003o003oooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ooo
003o003oooooo`0Eooooo`03ool00?l00?oooooo01Gooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`0Vooooo`008Oooool00ol00?ooooooooooo`0Dooooo`03ool00?l00?oooooo01Ko
oooo00?o003oooooooooool05?ooool00ooo003o003oooooo`0Fooooo`03o`00oooooooooooo01Co
oooo00?o003oooooooooool05Oooool00ooo003o003oooooo`0Eooooo`03o`00oooooooooooo01Go
oooo00?o003oooooooooool05?ooool00ooo003o003oooooo`0Eooooo`03ool00?l00?oooooo01Go
oooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0Uooooo`008Oooool00ol00?oooooo
ooooo`0Dooooo`03ool00?l00?oooooo01Kooooo00?oo`00o`00ooooool05Oooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool05oooool00ol00?oooooo
ooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?oooooo
ooooo`0Eooooo`03ool00?l00?oooooo01Gooooo00?o003oooooooooool05_ooool00ol00?oooooo
ooooo`0Uooooo`008Oooool00ol0003o003oooooo`0Dooooo`03ool00?l00?oooooo01Oooooo00?o
003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01?ooooo00?o
003oooooooooool05oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o
o`00o`00ooooool05?ooool00ol00?ooooooooooo`0Eooooo`03ool00?l00?oooooo01Gooooo00?o
003oooooooooool05_ooool00ol00?ooooooooooo`0Uooooo`008Oooool00ol0003o003oooooo`0D
ooooo`03ool00?l00?oooooo01Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0F
ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0D
ooooo`03o`00oooooooooooo01Gooooo00?oo`00o`00ooooool05?ooool00ol00?ooooooooooo`0F
ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0U
ooooo`008Oooool00ol0003o003oooooo`0Dooooo`03ool00?l00?oooooo01Oooooo00?o003ooooo
ooooool04oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo01?ooooo00?o003ooooo
ooooool05oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01Kooooo00?oo`00o`00
ooooool05?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo01Cooooo00?o003ooooo
ooooool05_ooool00ol00?ooooooooooo`0Uooooo`008Oooool00ol0003o003oo`00000Dooooo`03
ool00?l00?oooooo01Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Fooooo`03
o`00oooo003ooooo01?ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0Cooooo`03
o`00oooooooooooo01Kooooo00?oo`00o`00ooooool05?ooool00ol00?ooooooooooo`0Fooooo`03
o`00oooooooooooo01?ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0Uooooo`00
8Oooool00ol0003o003oooooo`0Dooooo`03ool00?l00?oooooo01Oooooo00?o003oooooooooool0
4oooool00ol00?ooooooooooo`0Fooooo`03o`00oooo003ooooo01?ooooo00?o003oooooooooool0
5oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01Kooooo00?oo`00o`00ooooool0
5?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool0
5oooool00ol00?ooooooooooo`0Uooooo`008Oooool00ol0003o003oooooo`0Dooooo`03o`00oooo
oooooooo01Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Fooooo`03o`00oooo
003ooooo01?ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0Cooooo`03o`00oooo
oooooooo01Kooooo00?oo`00o`00ooooool05?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooo
oooooooo01?ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0Uooooo`008Oooool0
0ol0003o003oooooo`0Dooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool04oooool0
0ol00?ooooooooooo`0Fooooo`03o`00oooo003ooooo01?ooooo00?o003oooooooooool05oooool0
0ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool04oooool0
0ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool05oooool0
0ol00?ooooooooooo`0Uooooo`008Oooool00ol0003o003oooooo`0Dooooo`03o`00oooooooooooo
01Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo
01?ooooo00?o003oooooooooool05oooool00ol00?ooo`00ooooo`0Cooooo`03o`00oooooooooooo
01Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo
01;ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0Uooooo`008Oooool00ol0003o
003oooooo`0Dooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool04oooool00ol00?oo
ooooooooo`0Gooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool06?ooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool04oooool00ol00?oo
ooooooooo`0Gooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool05oooool00ol00?oo
ooooooooo`0Uooooo`008Oooool00ol0003o003oooooo`0Dooooo`03o`00oooooooooooo01Oooooo
00?o003oooooooooool04oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo01;ooooo
00?o003oooooooooool06?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01Oooooo
00?o003oooooooooool04oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo01;ooooo
00?o003oooooooooool05oooool00ooo003o003oooooo`0Uooooo`008Oooool00ol0003o003ooooo
o`0Dooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool04oooool00ol00?oooooooooo
o`0Gooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool06?ooool00ol00?oooooooooo
o`0Aooooo`03ool00?l00?oooooo01Sooooo00?o003oooooooooool04oooool00ol00?oooooooooo
o`0Gooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool05oooool00ooo003o003ooooo
o`0Uooooo`008Oooool00ol0003oooooo`00o`0Dooooo`03o`00oooooooooooo01Sooooo00?o003o
ooooooooool04_ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo017ooooo00?o003o
ool00?ooool06Oooool00ol00?ooooooooooo`0Aooooo`03ool00?l00?oooooo01Sooooo00?oo`00
o`00ooooool04_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo017ooooo00?oo`00
o`00ooooool06?ooool00ooo003o003oooooo`0Uooooo`008Oooool2o`000003o`00oooooooooooo
01;ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo
01Sooooo00?o003oooooooooool04Oooool00ol00?ooo`00ooooo`0Iooooo`03o`00oooooooooooo
017ooooo00?oo`00o`00ooooool06?ooool00ooo003o003oooooo`0Booooo`03o`00oooooooooooo
01Sooooo00?o003oooooooooool04Oooool00ooo003o003oooooo`0Hooooo`03ool00?l00?oooooo
02Gooooo000Qooooo`03o`000?oooooo003o01Cooooo00?o003oooooooooool06?ooool00ol00?oo
ooooooooo`0Aooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool04Oooool00ol00?oo
o`00ooooo`0Iooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool06?ooool00ooo003o
003oooooo`0Booooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool04Oooool00ooo003o
003oooooo`0Hooooo`03ool00?l00?oooooo02Gooooo000Qooooo`03o`000?oooooo003o01Cooooo
00?o003oooooooooool06?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01Sooooo
00?o003oooooooooool04Oooool00ol00?ooo`00ooooo`0Iooooo`03o`00oooooooooooo017ooooo
00?o003oooooooooool06?ooool00ooo003o003oooooo`0Booooo`03o`00oooooooooooo01Sooooo
00?o003oooooooooool04Oooool00ooo003o003oooooo`0Hooooo`03ool00?l00?oooooo02Gooooo
000Qooooo`03o`000?oooooo003o01Cooooo00?o003oooooooooool06?ooool00ol00?oooooooooo
o`0Aooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool04Oooool00ol00?ooo`00oooo
o`0Iooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool06?ooool00ooo003o003ooooo
o`0Booooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`0Hooooo`03o`00oooooooooooo02Cooooo000Qooooo`03o`000?oooooo003o01?ooooo00?o003o
ooooooooool06Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01Sooooo00?o003o
ooooooooool04Oooool00ol00?ooo`00ooooo`0Iooooo`03o`00oooooooooooo017ooooo00?o003o
ooooooooool06Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01Sooooo00?o003o
ooooooooool04Oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo02Cooooo000Qoooo
o`03o`000?oooooo003o01?ooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0Aoooo
o`03o`00oooooooooooo01Sooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Ioooo
o`03o`00oooooooooooo013ooooo00?oo`00o`00ooooool06_ooool00ol00?ooooooooooo`0Aoooo
o`03o`00oooooooooooo01Sooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Ioooo
o`03o`00oooooooooooo02Cooooo000Qooooo`03o`000?oooooo003o01?ooooo00?o003ooooooooo
ool06Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01Sooooo00?o003ooooooooo
ool04Oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo013ooooo00?oo`00o`00oooo
ool06_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01Wooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo02Cooooo000Qooooo`03o`00
0?oooooo003o01?ooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0Aooooo`03o`00
oooooooooooo01Wooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Iooooo`03o`00
oooooooooooo013ooooo00?oo`00o`00ooooool06_ooool00ol00?ooooooooooo`0Aooooo`03o`00
oooooooooooo01Wooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Iooooo`03o`00
oooooooooooo02Cooooo000Qooooo`03o`000?oooooo003o01?ooooo00?o003oooooooooool06Ooo
ool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo013ooooo00?oo`00o`00ooooool06_oo
ool00ol00?ooooooooooo`0@ooooo`03ool00?l00?oooooo01[ooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo02Cooooo000Qooooo`;o000000?o003o
ool00?ooool04Oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo017ooooo00?o003o
ooooooooool06Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01Wooooo00?o003o
ooooooooool04Oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo013ooooo00?oo`00
o`00ooooool06_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01Wooooo00?oo`00
o`00ooooool09?ooool0027ooooo00Co0000oooooooooooo003o4_ooool00ol00?ooooooooooo`0I
ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0I
ooooo`03o`00oooooooooooo013ooooo00?oo`00o`00ooooool06_ooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo01Wooooo00?oo`00o`00ooooool09?ooool0027ooooo00Co0000oooo
oooooooo003o4_ooool00ol00?ooooooooooo`0Iooooo`03o`00oooo003ooooo017ooooo00?o003o
ooooooooool06Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01Wooooo00?o003o
ooooooooool04Oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool06_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01[ooooo00?o003o
ooooooooool08oooool0027ooooo00Co0000oooooooooooo003o4_ooool00ol00?ooooooooooo`0J
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0?
ooooo`03o`00oooo003ooooo01_ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0K
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool08oooool0027ooooo00Co0000oooo
oooooooo003o4_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool06_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01_ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool06_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01[ooooo00?o003o
ooooooooool08oooool0027ooooo00Co0000oooooooooooo003o4Oooool00ooo003o003oooooo`0K
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0K
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool08oooool0027ooooo00Co0000oooo
oooooooo003o4Oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool06_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01_ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00kooooo00?oo`00
o`00ooooool06oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01_ooooo00?o003o
ooooooooool08oooool0027ooooo00Co0000oooooooooooo003o4Oooool00ol00?ooooooooooo`0K
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0K
ooooo`03o`00oooooooooooo00kooooo00?oo`00o`00ooooool06oooool00ol00?ooo`00ooooo`0?
ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool08oooool0027ooooo00Co0000oooo
oooooooo003o4Oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool06_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01_ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00kooooo00?oo`00
o`00ooooool06oooool00ol00?ooo`00ooooo`0?ooooo`03o`00oooooooooooo01_ooooo00?o003o
ooooooooool08oooool0027ooooo00Co0000oooooooooooo003o4Oooool00ol00?ooooooooooo`0K
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool06_ooool00ooo003o003oooooo`0?
ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0K
ooooo`03o`00oooooooooooo00kooooo00?oo`00o`00ooooool07?ooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool08oooool0027ooooo0ol000000ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`0Kooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool06oooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`0Kooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool06oooool00ol0
0?ooooooooooo`0Sooooo`008Oooool01?l0003oooooooooool00?lAooooo`03o`00oooooooooooo
01_ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
01_ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Sooooo`008Oooool01Ol0003o
oooooooooooooooo003o00oooooo00?oo`00o`00ooooool07?ooool00ol00?ooooooooooo`0?oooo
o`03o`00oooooooooooo01_ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Koooo
o`03o`00oooo003ooooo00oooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0>oooo
o`03o`00oooooooooooo01cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Koooo
o`03o`00oooooooooooo02?ooooo000Qooooo`05o`000?ooooooooooooooool00?l03oooool00ooo
003o003oooooo`0Looooo`03o`00oooooooooooo00oooooo00?o003oooooooooool06oooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo01_ooooo00?o003oool00?ooool03oooool00ol0
0?ooooooooooo`0Kooooo`03ool00?l00?oooooo00kooooo00?o003oooooooooool07?ooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool08oooool0027o
oooo00Go0000ooooooooooooooooo`00o`0?ooooo`03ool00?l00?oooooo01cooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool07?ooool00ol00?ooo`00ooooo`0>ooooo`03o`00oooooooooooo01cooooo00?oo`00o`00
ooooool03_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool07?ooool00ol00?ooooooooooo`0Rooooo`008Oooool01Ol0003ooooooooooooooooo003o
00oooooo00?oo`00o`00ooooool07?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo
01cooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Looooo`03o`00oooo003ooooo
00kooooo00?o003oooooooooool07?ooool00ooo003o003oooooo`0>ooooo`03o`00oooooooooooo
01cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo
02;ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@04ooooo`05o`000?ooooooooooooooool00?l04?ooool00ol00?oooooooooo
o`0Kooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool07?ooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`0Mooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool07?ooool00ol00?oooooooooo
o`0>ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool08_ooool000Oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`05o`000?oo
ooooooooooooool00?l03oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool07?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01gooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool07?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01gooooo
00?o003oooooooooool08_ooool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00o`0?ooooo`03o`00oooooooooooo01go
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01go
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0Rooooo`001oooool01Ol0003ooooo
oooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool3o`000003ooooool00?oooooo00ko
oooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01co
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01co
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo02;o
oooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Cooooo00Go0000ooooooooooooooooo`00o`0?ooooo`03o`00oooooooooooo01gooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool07Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01gooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool07Oooool00ol00?ooooooooooo`0Rooooo`001oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo003o00oooooo00?o
003oooooooooool07Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01gooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00gooooo00?o
003oooooooooool07Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01gooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo02;ooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooo
oooooooo00gooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo01gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooo
oooooooo01gooooo00?o003oooooooooool08_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001Oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool07Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01gooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00gooooo00?o
003oooooooooool07Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01kooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooo003ooooo02;ooooo000Q
ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0M
ooooo`03o`00oooooooooooo00cooooo00?oo`00o`00ooooool07_ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool03?ooool00ooo003o003oooooo`0N
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo01gooooo00?o003oool00?ooool08_ooool0027ooooo00?o0000oooo
ooooool00_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01gooooo00?o003oool0
0?ooool03?ooool00ooo003o003oooooo`0Nooooo`03o`00oooooooooooo00_ooooo00?o003oool0
0?ooool07oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01kooooo00?oo`00o`00
ooooool03?ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool07Oooool00ol00?ooo`00ooooo`0Rooooo`008Oooool00ol0003oooooooooo`02ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool07Oooool00ol00?ooo`00ooooo`0<ooooo`03
o`00oooooooooooo01kooooo00?o003oooooooooool02oooool00ol00?ooo`00ooooo`0Oooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo01kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Mooooo`03
o`00oooo003ooooo02;ooooo000Qooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooo003ooooo00cooooo00?o003oooooooooool0
7_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooo003ooooo01oooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
7_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool0
8Oooool0027ooooo0ol00002ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool07_oo
ool00ol00?ooo`00ooooo`0<ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool07ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooo003ooooo01oooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo027ooooo000Qooooo`03o`000?oooooo
oooo00;ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo01oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooo
oooo00[ooooo00?o003oool00?ooool07oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo01oooooo00?o003oooooooooool08Oooool0027ooooo00?o0000ooooooooool00_ooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`0Oooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool07oooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`0Oooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool07oooool00ol0
0?ooooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`00oooo003ooooo00_o
oooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01oo
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01oo
oooo00?o003oool00?ooool02oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo027o
oooo000Qooooo`03o`000?oooooooooo00;ooooo00?o003oool00?ooool02oooool00ol00?oooooo
ooooo`0Oooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool07oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`0Oooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool07oooool00ol00?ooo`00
ooooo`0;ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool08Oooool0027ooooo00?o
0000ooooooooool00oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01oooooo00?o
003oool00?ooool02oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool07oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01oooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooo003ooooo00_ooooo00?o
003oooooooooool07oooool00ol00?ooooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`03
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool07oooool00ol00?ooo`00ooooo`0;
ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0O
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo01oooooo00?o003oool00?ooool02_ooool00ol00?ooooooooooo`0P
ooooo`03o`00oooooooooooo027ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooo003ooooo00[ooooo00?o003oool0
0?ooool08?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo023ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool07oooool00ol00?ooo`00ooooo`0:ooooo`03o`00oooooooooooo027ooooo00?o003ooooo
ooooool08?ooool0027ooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo023ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Pooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo023ooooo00?o003oooooooooool02Oooool00ol00?ooo`00ooooo`0Qooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`0Pooooo`00
8Oooool3o`0000?ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Qooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo027ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Pooooo`03o`00
oooooooooooo00Wooooo00?o003oool00?ooool08Oooool00ol00?ooo`00ooooo`09ooooo`03o`00
oooooooooooo027ooooo00?o003oooooooooool08?ooool0027ooooo00?o0000ooooooooool00ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool08Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0Qooooo`03o`00oooo003ooooo00Wooooo00?o003oooooooooool08Ooo
ool00ol00?ooooooooooo`0Pooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo027ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo027ooooo00?o003oool00?ooool02Oooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooo
oooo023ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`0Qooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool08Oooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`0Qooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool08Oooool00ol0
0?ooo`00ooooo`09ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool08?ooool0027o
oooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo027o
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool08Oooool00ol00?ooo`00ooooo`09ooooo`03o`00oooooooooooo027o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooo003ooooo00Wo
oooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`0Pooooo`008Oooool00ol0003ooooo
ooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool08Oooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0Qooooo`03o`00oooo003ooooo00Sooooo00?o003oooooooooool08_ooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo027ooooo00?o003oool00?ooool02?ooool00ooo003o003o
ooooo`0Rooooo`03o`00oooooooooooo023ooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool08_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo02;ooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool08_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02;ooooo00?o
003oooooooooool08?ooool0027ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0R
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0R
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0P
ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool08oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02;ooooo00?o003oool0
0?ooool01oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool08_ooool00ol00?ooo`00ooooo`08ooooo`03o`00oooooooooooo02;ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo01oooooo000Qooooo`?o
00001?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02?ooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`0Rooooo`03o`00oooo003ooooo00Oooooo00?o003ooooooooo
ool08oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02;ooooo00?o003oool00?oo
ool01oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool08oooool00ol00?ooooooooooo`0Oooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo02?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Sooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo02?ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Sooooo`03o`00
oooooooooooo01oooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool08ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02?ooooo00?o003oool00?ooool01ooo
ool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08ooo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool07ooo
ool0027ooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo02?ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`05ooooo`03ool00?l00?oo
oooo02Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`0Oooooo`008Oooool00ol0
003oooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0Tooooo`03o`00oooooooooooo00Gooooo00?oo`00o`00ooooool09?ooool00ol0
0?ooo`00ooooo`06ooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0Tooooo`03o`00oooo003ooooo01oooooo000Qooooo`03o`000?oooooooooo00Go
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo003ooooo02Go
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooo003ooooo00Ko
oooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02Co
oooo00?o003oool00?ooool07oooool0027ooooo00?o0000ooooooooool01_ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Tooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09Oooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0Tooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09?ooool00ol00?ooo`00
ooooo`0Oooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool09Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool09Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo01kooooo000Q
ooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0U
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool00oooool00ooo003o003oooooo`0V
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo02Gooooo00?o003oool00?ooool07_ooool0027ooooo00?o0000oooo
ooooool01_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02Gooooo00?o003ooooo
ooooool01?ooool00ooo003o003oooooo`0Vooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool09_ooool00ol00?ooooooooooo`03ooooo`03ool00?l00?oooooo02Kooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00?ooooo00?o003oool0
0?ooool09_ooool00ol00?ooo`00ooooo`0Nooooo`008Oooool3o`0000Kooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Cooooo00?oo`00o`00oooo
ool09_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02Kooooo00?o003ooooooooo
ool00oooool00ooo003o003oooooo`0Vooooo`03ool00?l00?oooooo00Cooooo00?o003ooooooooo
ool09_ooool00ol00?ooooooooooo`03ooooo`03o`00oooo003ooooo02Kooooo00?o003oool00?oo
ool07_ooool0027ooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo02Kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Vooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`03ooooo`03ool0
0?l00?oooooo02Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Vooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`0Mooooo`008Ooo
ool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool09ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool09ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo01gooooo000Qooooo`03o`000?oooooo
oooo00Kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo02Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooo
oooo00;ooooo00?o003oool00?ooool0:?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo02Oooooo00?o003oooooooooool07Oooool0027ooooo00?o0000ooooooooool01_ooool00ol0
0?ooo`00ooooo`03ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool00_ooool00ooo
003o003oooooo`0Xooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool09oooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Xooooo`06o`00oooooooooooooooooooo003o003o:Oooool00ooo003o003ooooo
o`0Mooooo`008Oooool00ol0003oooooooooo`07ooooo`05o`00ooooooooooooooooool00?l0:_oo
ool00ol00?ooo`00ooooo`02ooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0Xooooo`05o`00ooooooooooooooooool00?l0:_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo02Sooooo00Go003oooooooooooooooooo`00o`0[ooooo`03
o`00oooooooooooo01cooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`05o`00ooooooooooooooooool00?l0:oooool01Ol00?oooooooooooooooooo003o
02_ooooo00Co003ooooooooooooo003o:oooool01Ol00?oooooooooooooooooo003o02_ooooo00Co
003ooooooooooooo003o:oooool01Ol00?oooooooooooooooooo003o02_ooooo00?o003ooooooooo
ool07?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`04o`00
ooooooooooooo`00ob_ooooo0_l00?l00ooooooo003oo`00o`0[ooooo`04o`00ooooooooooooo`00
ob_ooooo00Go003oooooooooooooooooo`00o`0[ooooo`04o`00ooooooooooooo`00ob_ooooo0_l0
0?l2ooooo`03o`00oooooooooooo02Wooooo00?o003oooooooooool07?ooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`08ooooo`04o`00oooo003o003oo`00obcooooo00?o
003oooooool00?l0;?ooool3o`00obgooooo00?o003oooooool00?l0;?ooool4o`00obcooooo00?o
003oool00?l00?l0;Oooool00ol00?ooooooooooo`0Kooooo`006_ooool00ol0003oooooooooo`04
ooooo`?o00002Oooool2o`00obgooooo0_l00?l^ooooo`;o003o;_ooool00ol00?ooooooooooo`0/
ooooo`;o003o;_ooool2o`00obgooooo0_l00?lLooooo`006_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo0?ooooooAOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Cooooo00Co410@o`000?l0003o
oooo0_l000000ol@413oooooooooo`0?ooooo`Co000000So410@ooooooooooooV9RHoa0@4?l0003o
<S8bolc<c:3ooooo002Uooooo`05o`000?ooooooooooooooool000000_ooool6o`0000cooooo00?o
0000ooooooooool00_ooool01Ol@413o^[ZjoooooomgMgOo<S8b0:3ooooo000Pooooo`03okZj^_lb
<S;ooooo08;ooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0W_ooool0027ooooo00?o0000ooooooooool0POooool01Ol0003ooooooooo
oooooooo000000;ooooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo00?oZJVYoa0@4?ooool0
Woooool001oooooo00GoV9RHoa0@4?l0003o0000ojVYZ@21ooooo`05o`000?n7QhOoooooojVYZOl0
00005?ooool00ol0003oooooooooo`04ooooo`03oa0@4?l0003o^[Zj0:3ooooo000Oooooo`06o`00
0?nYZJWoEEEEoiRHV?mEEEGo^[ZjOoooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo
01;ooooo00?o0000ooooooooool01Oooool00onj^[[o8B4Qooooo`2Oooooo`007oooool01_lb<S;o
k^k^oiRHV?mEEEGogMgMoa0@49Wooooo00?o0000ooooooooool00_ooool01Ol@413oV9RHoooooonj
^[[o00000:3ooooo000Oooooo`07okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c02Fooooo`03oeEE
EOmVIVKo000000Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2Pooooo`007oooool01oo^k^ko0000
ooooool0003oooooofIVI_n7QhL0oooooom3ooooo`007oooool01?mVIVKoV9RHoooooolb<S82okZj
^P03o`000?oooooooooo0?oooooo@Oooool002;ooooo00?oIVIVohN7Qoooool0oooooom4ooooo`00
8_ooool00onYZJWoA4A4ooooo`3oooooodCooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.179101, -1.08611, \
0.0066032, 0.0136036}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0.309017 0.294302 [
[.17539 .29652 -12 -9 ]
[.17539 .29652 12 0 ]
[.32696 .29652 -9 -9 ]
[.32696 .29652 9 0 ]
[.47854 .29652 -12 -9 ]
[.47854 .29652 12 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -12 -9 ]
[.78169 .29652 12 0 ]
[.93327 .29652 -9 -9 ]
[.93327 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(0.25)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(0.5)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(0.75)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(1)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(1.25)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(1.5)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(19) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ .05 .05 ] 0 setdash
.02381 .30902 m
.02846 .39194 L
.03279 .46181 L
.03793 .53095 L
.04037 .55688 L
.04262 .57625 L
.04376 .58386 L
.04498 .59034 L
.0462 .59538 L
.04689 .59758 L
.04754 .5992 L
.04871 .60105 L
.04978 .60152 L
.05102 .6006 L
.0522 .59826 L
.05343 .59378 L
.05474 .58711 L
.0571 .57093 L
.0599 .54513 L
.06244 .51593 L
.08269 .18138 L
.08823 .10121 L
.09102 .0689 L
.09263 .054 L
.09409 .04243 L
.09534 .03408 L
.09671 .0267 L
.09746 .02343 L
.09815 .0209 L
.09885 .01883 L
.09951 .01735 L
.10068 .01602 L
.10197 .01675 L
.10323 .01912 L
.10393 .02115 L
.10458 .02346 L
.10691 .03521 L
.10822 .04407 L
.10941 .05351 L
.1139 .10226 L
.11915 .17757 L
.1241 .26154 L
.13408 .43515 L
.13954 .51482 L
.14221 .54551 L
.14465 .56844 L
.14577 .57725 L
.147 .58548 L
.14818 .59197 L
.14924 .59608 L
Mistroke
.15048 .59938 L
.1518 .60117 L
.15303 .60124 L
.15418 .59992 L
.15545 .59689 L
.1561 .59473 L
.1568 .59189 L
.15805 .5855 L
.15922 .57765 L
.16185 .55525 L
.16466 .52471 L
.17432 .37847 L
.18311 .22345 L
.18794 .14591 L
.19058 .10926 L
.19305 .07927 L
.19533 .056 L
.19742 .03945 L
.19853 .03256 L
.19974 .02639 L
.20096 .02164 L
.20224 .01824 L
.20291 .01712 L
.20364 .01643 L
.20433 .01628 L
.20497 .01658 L
.20617 .01859 L
.20745 .02278 L
.20882 .02911 L
.21009 .03669 L
.213 .05961 L
.21553 .08564 L
.21783 .11472 L
.22301 .19238 L
.23225 .35389 L
.23731 .43955 L
.24207 .50924 L
.24474 .54136 L
.24719 .56492 L
.24991 .58479 L
.25134 .59242 L
.25213 .59575 L
.25285 .59824 L
.25404 .60091 L
.25531 .60171 L
.25649 .60095 L
.25761 .59892 L
.25891 .59498 L
.26011 .58985 L
.26143 .58259 L
Mistroke
.26282 .57307 L
.26535 .55011 L
.26774 .52314 L
.27224 .46145 L
.28237 .28824 L
.28732 .20252 L
.29198 .13001 L
.29616 .0778 L
.29831 .0562 L
.30068 .03724 L
.30194 .02963 L
.30311 .02432 L
.30435 .0202 L
.30504 .01858 L
.30568 .01752 L
.30681 .01664 L
.30804 .01716 L
.3092 .01907 L
.31027 .02207 L
.31149 .02718 L
.31263 .03369 L
.31523 .05319 L
.31777 .07799 L
.3205 .1105 L
.33889 .41728 L
.34352 .48854 L
.34847 .54953 L
.34994 .56347 L
.35132 .57449 L
.35266 .58351 L
.3539 .59029 L
.35508 .59534 L
.35632 .59918 L
.35757 .60144 L
.35828 .60201 L
.35895 .60199 L
.36025 .59999 L
.36099 .59809 L
.36168 .59582 L
.36293 .59045 L
.36427 .58305 L
.36682 .56423 L
.36912 .5418 L
.37476 .46791 L
.38005 .38187 L
.38985 .20967 L
.3952 .12651 L
.39781 .0924 L
.40018 .06659 L
.40223 .04818 L
Mistroke
.40445 .03249 L
.40566 .0259 L
.40679 .0212 L
.40787 .01846 L
.40901 .01687 L
.41015 .01661 L
.41138 .01782 L
.41254 .02037 L
.41361 .0239 L
.41485 .02944 L
.4162 .03724 L
.41867 .05726 L
.42398 .11783 L
.42899 .19327 L
.43834 .35672 L
.44323 .43977 L
.44841 .51437 L
.45111 .54585 L
.45255 .56012 L
.45408 .57341 L
.4555 .58315 L
.45678 .59013 L
.45808 .59549 L
.45931 .59903 L
.46044 .60095 L
.46167 .60155 L
.46283 .6007 L
.46389 .5987 L
.46507 .59457 L
.46636 .58831 L
.46895 .57079 L
.47152 .54744 L
.47426 .51616 L
.47921 .44492 L
.48879 .27946 L
.49762 .13432 L
.5026 .07168 L
.5051 .04877 L
.50652 .03834 L
.50786 .03018 L
.5093 .02336 L
.51062 .01895 L
.51136 .01727 L
.51204 .01626 L
.5128 .01609 L
.51359 .01656 L
.51429 .01751 L
.51504 .0191 L
.51576 .02112 L
.51641 .02343 L
Mistroke
.51765 .02898 L
.51896 .03646 L
.52136 .0544 L
.52393 .08057 L
.52857 .14084 L
.53911 .318 L
.5493 .4869 L
.5521 .52356 L
.55506 .55565 L
.55759 .57711 L
.55903 .58666 L
.55973 .59057 L
.56038 .59345 L
.56156 .59748 L
.56285 .60027 L
.5641 .60137 L
.5648 .60128 L
.56544 .60077 L
.56658 .59882 L
.56782 .5952 L
.56899 .59036 L
.57007 .58431 L
.57249 .56618 L
.57515 .54021 L
.58051 .47063 L
.59135 .2867 L
.59668 .19437 L
.60162 .11984 L
.60609 .06644 L
.60835 .04607 L
.60965 .03694 L
.61084 .02999 L
.61206 .02436 L
.61334 .01999 L
.61462 .01726 L
.61535 .01646 L
.61602 .01621 L
.61725 .01697 L
.61837 .01968 L
.61967 .02441 L
.62089 .03041 L
.62313 .04515 L
.62559 .06669 L
.63058 .12727 L
.63953 .2726 L
.64494 .36893 L
.65009 .45428 L
.6551 .52444 L
.65754 .55117 L
.65975 .57085 L
Mistroke
.66087 .57909 L
.66207 .58668 L
.66311 .59212 L
.66425 .59684 L
.66546 .6002 L
.66674 .60158 L
.66793 .60133 L
.66904 .5998 L
.67035 .59637 L
.6716 .59154 L
.67271 .5859 L
.67393 .57838 L
.67665 .55545 L
.67917 .52813 L
.68929 .37544 L
.70005 .18782 L
.70462 .11912 L
.70942 .06305 L
.71194 .04134 L
.71337 .03189 L
.71469 .02541 L
.71592 .02101 L
.71703 .01831 L
.71831 .01675 L
.71953 .01682 L
.72058 .0181 L
.72174 .02083 L
.72296 .02539 L
.72409 .03143 L
.72612 .04534 L
.7283 .06449 L
.73327 .12318 L
.73781 .19242 L
.74702 .35338 L
.75208 .43923 L
.75684 .50856 L
.75955 .54143 L
.76249 .5693 L
.76378 .57887 L
.76515 .58724 L
.76632 .59295 L
.7676 .59767 L
.7689 .60077 L
.77009 .60207 L
.77075 .60194 L
.77146 .60111 L
.77276 .59824 L
.77398 .59401 L
.77526 .58791 L
.77758 .57298 L
Mistroke
.78009 .55106 L
.78248 .52407 L
.78698 .46222 L
.79709 .28964 L
.80203 .20403 L
.80668 .13153 L
.81086 .07868 L
.81302 .05718 L
.81539 .03827 L
.81656 .03086 L
.81781 .02442 L
.8185 .02168 L
.81913 .01983 L
.82037 .01742 L
.8215 .01659 L
.82273 .01716 L
.82389 .0191 L
.82496 .02211 L
.82617 .0269 L
.82731 .03274 L
.82856 .041 L
.82991 .05188 L
.83517 .10925 L
.83984 .1773 L
.84476 .26054 L
.85355 .41486 L
.85846 .49053 L
.86309 .54727 L
.86565 .57123 L
.86709 .58158 L
.86842 .58911 L
.86955 .59409 L
.87078 .59813 L
.87207 .60071 L
.87328 .6016 L
.87441 .60107 L
.87565 .59897 L
.87682 .5949 L
.8779 .58985 L
.87995 .57719 L
.88213 .55942 L
.88712 .5028 L
.89164 .43551 L
.90101 .27265 L
.90613 .18522 L
.91091 .11429 L
.91361 .08063 L
.91608 .05607 L
.91882 .03533 L
.92033 .02693 L
Mistroke
.92101 .02388 L
.92176 .02105 L
.92296 .01769 L
.92424 .01618 L
.92542 .01661 L
.92654 .01833 L
.92784 .02195 L
.92904 .02677 L
.93035 .03367 L
.93173 .04272 L
.93431 .06498 L
.93674 .09191 L
.94129 .1538 L
.95149 .32771 L
.95614 .40851 L
.96106 .4857 L
.96525 .53869 L
.96748 .56109 L
.96987 .58028 L
.97158 .59067 L
.97314 .59755 L
.97389 .59994 L
.9747 .60183 L
.97548 .60292 L
.97619 .60332 L
Mfstroke
0 0 1 r
[ ] 0 setdash
.02381 .30902 m
.02846 .39136 L
.03279 .46229 L
.03793 .53242 L
.04037 .55833 L
.04262 .57737 L
.04374 .58502 L
.04498 .59194 L
.04622 .59727 L
.04754 .60111 L
.0487 .60292 L
.04995 .60323 L
.05112 .60197 L
.0522 .59949 L
.0535 .59481 L
.05471 .58885 L
.05745 .56977 L
.05987 .54688 L
.06244 .5168 L
.07287 .35237 L
.07835 .25439 L
.08414 .15767 L
.08922 .08794 L
.0921 .05737 L
.09348 .04542 L
.09479 .03582 L
.09597 .02863 L
.09726 .02247 L
.09843 .01841 L
.09951 .01597 L
.10068 .01478 L
.10197 .0152 L
.10262 .0161 L
.10332 .01757 L
.10458 .02159 L
.10584 .02732 L
.10719 .0353 L
.10963 .0543 L
.11252 .08414 L
.11515 .11734 L
.12627 .30009 L
.1313 .38933 L
.13662 .47548 L
.14116 .53555 L
.14375 .56223 L
.14616 .58151 L
.14735 .58884 L
.14864 .59516 L
.14986 .59949 L
.15099 .60206 L
Mistroke
.15212 .60323 L
.15313 .60311 L
.15431 .60155 L
.15541 .59872 L
.15662 .5941 L
.1579 .58754 L
.16019 .5716 L
.16265 .54876 L
.16535 .51754 L
.17611 .34735 L
.18614 .17266 L
.19117 .10032 L
.19381 .06966 L
.19662 .04396 L
.1978 .03544 L
.19907 .02786 L
.1998 .02428 L
.20047 .02149 L
.20178 .0174 L
.20288 .01538 L
.2041 .01472 L
.20536 .01574 L
.20654 .01826 L
.2077 .02223 L
.20896 .02815 L
.21125 .0431 L
.21347 .06262 L
.21552 .08461 L
.2251 .22705 L
.23417 .38787 L
.23917 .46934 L
.24391 .53303 L
.24658 .56105 L
.24799 .57318 L
.24949 .58393 L
.25075 .59117 L
.25141 .59435 L
.25213 .59724 L
.2534 .60097 L
.25458 .60289 L
.25579 .60326 L
.25648 .60276 L
.25712 .60183 L
.25841 .5986 L
.25913 .59601 L
.25979 .59317 L
.26224 .57855 L
.26456 .55919 L
.26918 .50619 L
.27427 .43004 L
Mistroke
.28455 .24946 L
.28914 .1721 L
.29407 .10098 L
.29646 .07294 L
.29873 .05094 L
.30077 .03539 L
.30185 .02884 L
.30299 .02325 L
.30363 .02074 L
.30433 .01848 L
.30555 .01579 L
.30624 .01499 L
.30698 .01472 L
.30768 .015 L
.30831 .01573 L
.30955 .0184 L
.31024 .02064 L
.31089 .02316 L
.31332 .03669 L
.31548 .0537 L
.31786 .07759 L
.32268 .14024 L
.33363 .32586 L
.33842 .40985 L
.34366 .49164 L
.34602 .52292 L
.34855 .5514 L
.35073 .57142 L
.35309 .58785 L
.35449 .59484 L
.35577 .59945 L
.357 .6022 L
.3583 .60331 L
.35946 .60274 L
.36055 .60087 L
.36174 .59734 L
.36302 .59184 L
.36441 .58393 L
.3657 .57484 L
.36862 .54827 L
.37392 .48127 L
.38388 .31418 L
.38898 .22383 L
.39449 .13571 L
.39702 .10119 L
.39969 .07016 L
.40199 .0484 L
.40326 .03861 L
.40446 .03084 L
.40561 .02477 L
Mistroke
.40687 .01977 L
.40801 .01669 L
.40906 .01511 L
.41005 .01473 L
.41114 .01554 L
.41228 .01779 L
.41335 .02117 L
.4146 .0267 L
.4158 .0335 L
.41804 .05018 L
.42045 .07352 L
.42308 .10481 L
.43405 .2804 L
.43944 .37644 L
.44439 .45868 L
.44882 .52085 L
.45116 .54781 L
.45367 .57129 L
.45499 .58119 L
.4562 .58867 L
.45741 .59468 L
.45856 .59893 L
.45984 .602 L
.46103 .60325 L
.46233 .60283 L
.46299 .60192 L
.46372 .60036 L
.46489 .59661 L
.46618 .59082 L
.46753 .58291 L
.46878 .57389 L
.47342 .52747 L
.47848 .4572 L
.48389 .36682 L
.49375 .19341 L
.49807 .12677 L
.50283 .0682 L
.5054 .04475 L
.50781 .02866 L
.50913 .02234 L
.51034 .0182 L
.51101 .0166 L
.51174 .01541 L
.51243 .01482 L
.51307 .01474 L
.51377 .01516 L
.51452 .01621 L
.51524 .01778 L
.51589 .0197 L
.51713 .02462 L
Mistroke
.51845 .03159 L
.52118 .05173 L
.52417 .08197 L
.52921 .14923 L
.5346 .23765 L
.54432 .40951 L
.54927 .48718 L
.55451 .55187 L
.55725 .57613 L
.55881 .58665 L
.56027 .59424 L
.56092 .5969 L
.56161 .59921 L
.56283 .60206 L
.56415 .6033 L
.5649 .60315 L
.56559 .60248 L
.56685 .5999 L
.56756 .59768 L
.56822 .59516 L
.56942 .58933 L
.5707 .58153 L
.5729 .56413 L
.57533 .5397 L
.5807 .46858 L
.58572 .38656 L
.59615 .20266 L
.60128 .12326 L
.60354 .09365 L
.60604 .06571 L
.60811 .04679 L
.61034 .03107 L
.61157 .0246 L
.6127 .02007 L
.61378 .01702 L
.61492 .01517 L
.61607 .01475 L
.61731 .01591 L
.61847 .01853 L
.61953 .02219 L
.62078 .02803 L
.62213 .03619 L
.62458 .05573 L
.62946 .1108 L
.63403 .1783 L
.64443 .36008 L
.64962 .4479 L
.65456 .51865 L
.65728 .54991 L
.65872 .5638 L
Mistroke
.66025 .57644 L
.66167 .58605 L
.66295 .59298 L
.66424 .59818 L
.66546 .60144 L
.66662 .60306 L
.66787 .60315 L
.66904 .60167 L
.67012 .59902 L
.67137 .59432 L
.67274 .58731 L
.67523 .56964 L
.67783 .54478 L
.68059 .51191 L
.68554 .43918 L
.69518 .27084 L
.70402 .12642 L
.70858 .06998 L
.71088 .04834 L
.71339 .03054 L
.71472 .02376 L
.71592 .01921 L
.71659 .01736 L
.71731 .01591 L
.71863 .01473 L
.71986 .01534 L
.72116 .01778 L
.72227 .02133 L
.72349 .02676 L
.72472 .03374 L
.72587 .04179 L
.72805 .06045 L
.73294 .11778 L
.74178 .25978 L
.75139 .42867 L
.75667 .50758 L
.75925 .53925 L
.76163 .56332 L
.76389 .58127 L
.76502 .58836 L
.76627 .59459 L
.76752 .59919 L
.76823 .60103 L
.76887 .60224 L
.77011 .6033 L
.77128 .60276 L
.77234 .60097 L
.77346 .59775 L
.77442 .59393 L
.77548 .58859 L
Mistroke
.77783 .57259 L
.78003 .55266 L
.78498 .49245 L
.7904 .40789 L
.80026 .2336 L
.8049 .15704 L
.80986 .08889 L
.81226 .06267 L
.81453 .0428 L
.81657 .0293 L
.81772 .02358 L
.81878 .01955 L
.82004 .01633 L
.82123 .01486 L
.8223 .01488 L
.82347 .01633 L
.82473 .01958 L
.82537 .02188 L
.82608 .02493 L
.8285 .03932 L
.83075 .05802 L
.83318 .08348 L
.83758 .14172 L
.84744 .30819 L
.85266 .40035 L
.85824 .48851 L
.86103 .52546 L
.86367 .55463 L
.86604 .57542 L
.86726 .58401 L
.86861 .59169 L
.86987 .59714 L
.87105 .60071 L
.87229 .60283 L
.87299 .60329 L
.87363 .60323 L
.87476 .60203 L
.876 .59911 L
.87717 .59483 L
.87826 .58956 L
.88102 .57068 L
.88362 .54613 L
.88847 .48491 L
.89935 .30213 L
.90913 .13801 L
.91405 .07479 L
.91685 .04796 L
.9181 .03837 L
.91945 .02973 L
.9207 .02349 L
Mistroke
.92185 .01918 L
.92295 .01641 L
.92412 .0149 L
.92516 .01483 L
.92614 .01584 L
.92722 .01815 L
.92837 .02204 L
.92954 .02738 L
.93081 .03484 L
.93336 .05479 L
.93793 .10543 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool000oooooo
1_l00005ooooo`03o`000?oooooooooo00Cooooo0ol0000Eooooo`;o003o7_ooool2o`00oakooooo
0_l00?lOooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool07Oooool2o`00oakooooo
0_l00?lNooooo`;o003o7oooool00ol00?ooooooooooo`0Zooooo`006_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01Gooooo0_l00?lNooooo`;o003o7_ooool00ol00?ooooooo`00
o`0Mooooo`03o`00oooo003o003o01gooooo0ol00?lNooooo`;o003o7Oooool3o`00oakooooo0_l0
0?lNooooo`;o003o;?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0D
ooooo`04o`00oooo003oooooo`00oagooooo00?o003oooooool00?l07Oooool00ol00?ooooooo`00
o`0Mooooo`03o`00oooooooo003o01gooooo00?o003oooooool00?l07Oooool00ol00?ooooooo`00
o`0Mooooo`03o`00oooooooo003o01kooooo0ol00?lMooooo`03o`00oooooooo003o02_ooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05?ooool01?l00?ooooooooooool0
0?lLooooo`04o`00ooooooooooooo`00oagooooo00?o003oooooool00?l07Oooool00ol00?oooooo
o`00o`0Mooooo`03o`00oooooooo003o01gooooo00?o003oooooool00?l07Oooool01?l00?oooooo
o`00oooo000Looooo`04o`00ooooooooooooo`00oacooooo00Co003oool00?oooooo003o:oooool0
01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Dooooo`04o`00oooooooooooo
o`00oacooooo00Co003ooooooooooooo003o7?ooool01?l00?ooo`00ooooool00?lMooooo`03o`00
oooooooo003o01gooooo00Co003oooooool00?ooo`007?ooool01?l00?ooooooool00?l00?lLoooo
o`04o`00ooooooooooooo`00oacooooo00Co003ooooooooooooo003o7?ooool01?l00?oooooooooo
ool00?l[ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo01Cooooo00Co
003ooooooooooooo003o7?ooool01?l00?ooooooooooool00?lLooooo`04o`00ooooooooooooo`00
oacooooo00Co003oool00?oooooo003o7Oooool01?l00?ooooooooooool00?lLooooo`04o`00oooo
ooooooooo`00oacooooo00Co003ooooooooooooo003o7?ooool01?l00?ooooooooooool00?lLoooo
o`04o`00ooooooooooooo`00ob_ooooo000Qooooo`03o`000?oooooooooo01Cooooo00Co003ooooo
oooooooo003o7?ooool01?l00?ooooooooooool00?lLooooo`05o`00ooooooooooooooooool00?l0
6oooool01Ol00?oooooooooooooooooo003o01cooooo00Co003ooooooooooooo003o7?ooool01?l0
0?ooooooooooool00?lLooooo`04o`00ooooooooooooo`00oacooooo00Go003ooooooooooooooooo
o`00o`0Kooooo`05o`00ooooooooooooool00?l00?l0:_ooool0027ooooo00?o0000ooooooooool0
5?ooool01?l00?ooooooooooool00?lLooooo`05o`00ooooooooooooooooool00?l06oooool01Ol0
0?oooooooooooooooooo003o01_ooooo00Go003oooooooooooooooooo`00o`0Kooooo`05o`00oooo
ooooooooooooool00?l07?ooool01?l00?ooooooooooool00?lLooooo`04o`00ooooooooooooo`00
oacooooo00Go003oooooooooooooooooo`00o`0Kooooo`05o`00ooooooooooooool00?l00?l0:_oo
ool0027ooooo00?o0000ooooooooool04oooool01Ooo003o003ooooooooooooo003o01cooooo00Go
003oooooooooooooooooo`00o`0Kooooo`05o`00ooooooooooooooooool00?l06oooool01Ol00?oo
oooooooooooooooo003o01_ooooo00Go003oooooooooooooooooo`00o`0Kooooo`06o`00oooooooo
ooooooooool00?ooo`006oooool01Ol00?oooooooooooooooooo003o01[ooooo00?o003oool00?oo
ool00_ooool00ol00?ooooooooooo`0Iooooo`05o`00ooooooooooooooooool00?l0:_ooool0027o
oooo0ol0000Cooooo`05o`00ooooooooooooooooool00?l06oooool00ol00?ooo`00ooooo`02oooo
o`03o`00oooooooooooo01Sooooo00?o003oool00?ooool00_ooool00ol00?ooooooooooo`0Ioooo
o`05o`00ooooooooooooooooool00?l06oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo01Sooooo00Ko003oooooooooooooooooo`00oooo000Jooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool06?ooool00ol00?ooo`00ooooo`02ooooo`03o`00oooooooooooo01Sooooo
00?o003oool00?ooool00_ooool00ol00?ooooooooooo`0Xooooo`008Oooool00ol0003ooooooooo
o`0Cooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06?ooool00ol00?ooo`00oooo
o`02ooooo`03o`00oooooooooooo01Sooooo00?o003oool00?ooool00_ooool00ol00?oooooooooo
o`0Hooooo`03o`00oooo003ooooo00;ooooo00?o003oooooooooool06Oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo01Sooooo00Ko003oooooooooooooooooo`00oooo000Jooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool06?ooool00ol00?ooo`00ooooo`02ooooo`03
o`00oooooooooooo01Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Xooooo`00
8Oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
6?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooo003ooooo00;ooooo00?o003oooooooooool0
6Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
6?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0Xooooo`008Oooool00ol0003oooooooooo`0Cooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo01Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo01Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo01Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Xooooo`008Oooool0
0ol0003oooooooooo`0Cooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06?ooool0
0ol00?ooooooooooo`02ooooo`03ool00?l00?oooooo01Sooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06Oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06?ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Xooooo`008Oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool05oooool00ol00?ooo`00ooooo`03ooooo`03ool00?l00?oooooo
01Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
01Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
01Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Xooooo`008Oooool00ol0003o
ooooooooo`0Booooo`03ool00?l00?oooooo00?ooooo00?o003oooooooooool05oooool00ol00?oo
o`00ooooo`03ooooo`03ool00?l00?oooooo01Sooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0Hooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool05oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0Gooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool06?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0Xooooo`008Oooool00ol0003oooooooooo`0Booooo`03ool00?l00?oooooo00?ooooo
00?o003oooooooooool05oooool00ol00?ooo`00ooooo`03ooooo`03ool00?l00?oooooo01Sooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool05oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01Oooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool06?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Oooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0Xooooo`008Oooool00ol0003ooooooooo
o`0Cooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool05oooool00ol00?oooooooooo
o`03ooooo`03ool00?l00?oooooo01Sooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0Gooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool05oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0Gooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool05oooool00ooo003o003ooooo
o`03ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0Xooooo`008Oooool3o`0001?ooooo00?o003oooooooooool00_ooool00ooo003o003oooooo`0G
ooooo`03o`00oooooooooooo00?ooooo00?oo`00o`00ooooool06?ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0G
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0G
ooooo`03ool00?l00?oooooo00?ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo02Oooooo000Qooooo`03o`000?oooooooooo01;ooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool05oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01Oooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool05_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01Kooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0Fooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00
ooooool05oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02Oooooo000Qooooo`03
o`000?oooooooooo01;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Fooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo01Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Gooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo01Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Fooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo02Oooooo000Qooooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
5oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
5Oooool00ol00?ooo`00ooooo`05ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
5_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02Oooooo000Qooooo`03o`000?oo
oooooooo01;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo01Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Fooooo`03o`00oooo
003ooooo00Gooooo00?o003oooooooooool05Oooool00ol00?ooo`00ooooo`05ooooo`03o`00oooo
oooooooo01Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo02Oooooo000Qooooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0Fooooo`03o`00oooo003ooooo00Gooooo00?o003oooooooooool05Oooool0
0ol00?ooo`00ooooo`05ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02Oooooo000Qooooo`03o`000?oooooooooo
01;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
01Kooooo00?o003oooooooooool01?ooool00ooo003o003oooooo`0Fooooo`03o`00oooo003ooooo
00Gooooo00?o003oooooooooool05Oooool00ol00?ooo`00ooooo`05ooooo`03o`00oooooooooooo
01Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
02Oooooo000Qooooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool01?ooool00ol00?oo
o`00ooooo`0Fooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooo003ooooo01Kooooo00?o003oooooooooool01?ooool00ooo003o
003oooooo`0Fooooo`03o`00oooo003ooooo00Gooooo00?o003oooooooooool05Oooool00ol00?oo
o`00ooooo`05ooooo`03o`00oooooooooooo01Gooooo00?oo`00o`00ooooool01Oooool00ol00?oo
ooooooooo`0Fooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo02Kooooo000Qooooo`03o`000?oooooooooo01;ooooo
00?o003oooooooooool01?ooool00ol00?ooo`00ooooo`0Fooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool05_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooo003ooooo00Gooooo
00?o003oooooooooool05Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Gooooo
00?oo`00o`00ooooool01Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool05_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02Kooooo
000Qooooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool01?ooool00ol00?ooo`00oooo
o`0Fooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`0Eooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool05Oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`0Fooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo02Kooooo000Qooooo`?o00004_ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0F
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0E
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0F
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09_ooool0027ooooo00?o0000oooo
ooooool04Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00Gooooo00?oo`00o`00
ooooool05Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool09_ooool0027ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo01Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Eooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo01Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Eooooo`03
o`00oooooooooooo00Gooooo00?oo`00o`00ooooool05Oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo01Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Eooooo`03
o`00oooo003ooooo00Kooooo00?o003oooooooooool09_ooool0027ooooo00?o0000ooooooooool0
4Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
5Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Cooooo00?o003oool00?ooool0
1_ooool00ol00?ooo`00ooooo`0Eooooo`03o`00oooooooooooo00Gooooo00?oo`00o`00ooooool0
5Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
9_ooool0027ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool05?ooool00ooo003o003oooooo`06ooooo`03o`00oooo
oooooooo01Cooooo00?o003oool00?ooool01oooool00ol00?ooooooooooo`0Dooooo`03o`00oooo
oooooooo00Gooooo00?oo`00o`00ooooool05Oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo01Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool09_ooool0027ooooo00?o0000ooooooooool04Oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o003oool00?ooool01oooool0
0ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool09_ooool0
027ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo
00Kooooo00?o003oool00?ooool09_ooool0027ooooo00?o0000ooooooooool04Oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0Dooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool04oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0Dooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0Dooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool09Oooool0027ooooo
00?o0000ooooooooool04Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool04oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool05?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool09Oooool0027ooooo0ol0000Aooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool05?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool05?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01Cooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool05?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`0Uooooo`008Oooool00ol0003oooooooooo`0A
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0C
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0D
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0U
ooooo`008Oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool04oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01Cooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01?ooooo00?oo`00o`00
ooooool02?ooool00ol00?ooooooooooo`0Uooooo`008Oooool00ol0003oooooooooo`0@ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo01Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Cooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo01Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Dooooo`03
o`00oooooooooooo00Kooooo00?oo`00o`00ooooool04oooool00ol00?ooo`00ooooo`07ooooo`03
o`00oooooooooooo01?ooooo00?oo`00o`00ooooool02?ooool00ol00?ooooooooooo`0Uooooo`00
8Oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
5?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo003ooooo01Cooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
4oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool0
1oooool00ooo003o003oooooo`0Dooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
4_ooool00ol00?ooo`00ooooo`07ooooo`03o`00oooooooooooo01?ooooo00?oo`00o`00ooooool0
2?ooool00ol00?ooooooooooo`0Uooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
003ooooo01Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Cooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo01?ooooo00?o003oooooooooool01oooool00ooo003o003oooooo`0Dooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool04_ooool00ol00?ooo`00ooooo`07ooooo`03o`00oooo
003ooooo01?ooooo00?oo`00o`00ooooool02?ooool00ol00?ooooooooooo`0Uooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1?ooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
4oooool00ol00?ooooooooooo`06ooooo`03o`00oooo003ooooo01?ooooo00?oo`00o`00ooooool0
2?ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
4oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool0
1oooool00ooo003o003oooooo`0Cooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
4_ooool00ol00?ooo`00ooooo`07ooooo`03o`00oooo003ooooo01?ooooo00?oo`00o`00ooooool0
2?ooool00ol00?ooooooooooo`0Uooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool04?ooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o003oool00?ooool01oooool00ol00?ooo`00
ooooo`0Cooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04oooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?oo`00o`00ooooool04oooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o003oool00?ooool01oooool00ol00?ooo`00
ooooo`0Cooooo`03ool00?l00?oooooo00Sooooo00?o003oooooooooool09Oooool000Go00000_oo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0@ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?ooo`00
ooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool04oooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0Booooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oooooo
ooooo`07ooooo`03o`00oooo003ooooo01?ooooo00?oo`00o`00ooooool02?ooool00ol00?oooooo
ooooo`0Uooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0
0oooool3o`00013ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Booooo`03o`00
oooo003ooooo00Sooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo01;ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Booooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo01;ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Booooo`03o`00
oooooooooooo00Oooooo00?o003oool00?ooool05?ooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo02Gooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo01;ooooo00?o003oool00?ooool02?ooool00ol00?ooooooooooo`0Booooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo01;ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Cooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo01;ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Cooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool09Oooool000Oooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04?ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0Cooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool09?ooool000Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool04?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o003ooooooooo
ool02?ooool00ol00?ooo`00ooooo`0Booooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool04_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool04_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool09?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003o
ooooooooo`0@ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooo003ooooo01;ooooo00?o003oooooooooool02?ooool00ooo003o
003oooooo`0Booooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool04_ooool00ol00?ooooooooooo`08ooooo`03o`00oooo003ooooo01;ooooo
00?o003oooooooooool02?ooool00ooo003o003oooooo`0Booooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool04_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01;ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool04_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01;ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Tooooo`008Oooool00ol0003ooooooooo
o`0@ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`08ooooo`03o`00oooo003ooooo01;ooooo00?o003oooooooooool02?ooool00ooo003o003ooooo
o`0Booooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`0Tooooo`008Oooool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool04_ooool00ol00?ooooooooooo`08ooooo`03o`00oooo003ooooo01;ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Sooooo00?o003o
ool00?ooool04_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?oo`00
o`00ooooool02Oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool04_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`0?oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`08oooo
o`03o`00oooo003ooooo01;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Aoooo
o`03o`00oooooooooooo00Sooooo00?o003oool00?ooool04_ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo017ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Boooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo01;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Toooo
o`008Oooool3o`0000oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Booooo`03
o`00oooooooooooo00Sooooo00?o003oool00?ooool04_ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo017ooooo00?o003oooooooooool02?ooool00ol00?ooo`00ooooo`0Booooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo01;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Aooooo`03
o`00oooooooooooo00Sooooo00?o003oool00?ooool04_ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo02Cooooo000Qooooo`03o`000?oooooooooo00oooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00Sooooo00?o003oool00?ooool0
4_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
4Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Sooooo00?o003oool00?ooool0
4_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02Cooooo000Qooooo`03o`000?oo
oooooooo00oooooo00?o003oooooooooool02Oooool00ol00?ooo`00ooooo`0Booooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo017ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo01;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooo
oooooooo00Wooooo00?o003oool00?ooool04_ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo02Cooooo000Qooooo`03o`000?oooooooooo00oooooo00?o003oooooooooool02Oooool0
0ol00?ooo`00ooooo`0Booooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool04Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o003oool00?ooool02_ooool0
0ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Wooooo00?o003oool00?ooool04_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02Cooooo000Qooooo`03o`000?oooooooooo
00oooooo00?o003oooooooooool02Oooool00ol00?ooo`00ooooo`0Aooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
013ooooo00?o003oool00?ooool02_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
017ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
02Cooooo000Qooooo`03o`000?oooooooooo00oooooo00?o003oooooooooool02Oooool00ol00?oo
o`00ooooo`0Aooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool04Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo013ooooo00?o003oool00?ooool02_ooool00ol00?oo
ooooooooo`0Aooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool04Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`0@ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool04Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo02Cooooo000Qooooo`03o`000?oooooooooo00oooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool04Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo013ooooo
00?o003oool00?ooool02_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool04Oooool00ol00?ooooooooooo`09ooooo`03ool00?l00?oooooo017ooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool04?ooool00ooo003o003oooooo`0:ooooo`03ool00?l00?oooooo02Cooooo
000Qooooo`03o`000?oooooooooo00oooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`0@ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool04?ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo013ooooo00?o003oool00?ooool02_ooool00ol00?oooooooooo
o`0@ooooo`03ool00?l00?oooooo00[ooooo00?o003oool00?ooool04Oooool00ol00?oooooooooo
o`09ooooo`03ool00?l00?oooooo017ooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`0@ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool04?ooool00ooo003o003ooooo
o`0:ooooo`03ool00?l00?oooooo02Cooooo000Qooooo`03o`000?oooooooooo00oooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003o
ool00?ooool02_ooool00ol00?ooooooooooo`0@ooooo`03ool00?l00?oooooo00[ooooo00?o003o
ool00?ooool04Oooool00ol00?ooooooooooo`09ooooo`03ool00?l00?oooooo017ooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool04?ooool00ooo003o003oooooo`0:ooooo`03ool00?l00?oooooo02Cooooo000Qoooo
o`?o00003oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool04?ooool00ol00?ooo`00ooooo`0:ooooo`03o`00oooooooooooo013ooooo00?oo`00o`00
ooooool02oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Wooooo00?oo`00o`00
ooooool04Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0@ooooo`03ool00?l00?oooooo00[ooooo00?oo`00o`00
ooooool09?ooool0027ooooo00?o0000ooooooooool03oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool04?ooool00ol00?ooo`00ooooo`0:ooooo`03
o`00oooooooooooo013ooooo00?oo`00o`00ooooool02oooool00ol00?ooooooooooo`0@ooooo`03
o`00oooooooooooo00Wooooo00?oo`00o`00ooooool04Oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool08oooool0027ooooo00?o0000ooooooooool0
3oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
4?ooool00ol00?ooo`00ooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Wooooo00?oo`00o`00ooooool0
4Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
8oooool0027ooooo00?o0000ooooooooool03oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo013ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool04?ooool00ol00?ooo`00ooooo`0:ooooo`03o`00oooo
oooooooo013ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0@ooooo`03o`00oooo
oooooooo00Wooooo00?oo`00o`00ooooool04Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo013ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool08oooool0027ooooo00?o0000ooooooooool03_ooool0
0ol00?ooo`00ooooo`0;ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool04?ooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02oooool0
0ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool04?ooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool08oooool0
027ooooo00?o0000ooooooooool03_ooool00ol00?ooo`00ooooo`0;ooooo`03o`00oooooooooooo
013ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
013ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
013ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool08oooool0027ooooo00?o0000ooooooooool03_ooool00ol00?oo
o`00ooooo`0;ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`0@ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03oooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`0?ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool04?ooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`0@ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool08oooool0027ooooo
00?o0000ooooooooool03_ooool00ol00?ooo`00ooooo`0;ooooo`03o`00oooooooooooo013ooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo013ooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool04?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool08oooool0027ooooo00?o0000ooooooooool03_ooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`0@ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`0?ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool04?ooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`0@ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool08oooool0027ooooo00?o0000
ooooooooool03_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo013ooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool02_ooool00ooo003o003oooooo`0@ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool08oooool0027ooooo0ol0000>ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool04?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00oooooo00?oo`00o`00
ooooool03?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool04?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00oooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool03oooool00ol00?ooooooooooo`0:ooooo`03ool00?l00?oooooo013ooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0Rooooo`008Oooool00ol0003oooooooooo`0>ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0:ooooo`03
ool00?l00?oooooo00oooooo00?oo`00o`00ooooool03?ooool00ol00?ooooooooooo`0?ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0?ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0:ooooo`03
ool00?l00?oooooo013ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Rooooo`00
8Oooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
4?ooool00ol00?ooooooooooo`0:ooooo`03ool00?l00?oooooo00oooooo00?oo`00o`00ooooool0
3?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
3_ooool00ooo003o003oooooo`0<ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0Rooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`00oooo
oooooooo00_ooooo00?o003oool00?ooool03oooool00ol00?ooooooooooo`0;ooooo`03ool00?l0
0?oooooo00oooooo00?oo`00o`00ooooool03?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool03_ooool00ooo003o003oooooo`0<ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Rooooo`008Oooool0
0ol0003oooooooooo`0>ooooo`03o`00oooooooooooo00_ooooo00?o003oool00?ooool03oooool0
0ol00?ooooooooooo`0;ooooo`03ool00?l00?oooooo00oooooo00?oo`00o`00ooooool03?ooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool02oooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0Rooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo
00_ooooo00Oo003oool00?o^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`03o`00ool0
003o000000;o00001?ooool01om4A4Co0000o`000?lb<S;ogMgMool00?l00?l04?ooool02?oo003o
003oooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@03o`00oooooooooooo00;ooooo00Go
A4A4o`000?l0003o<S8bomgMg@08ooooo`03o`00oooooooooooo00[ooooo00Gok^k^o`00ool0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003o003oooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Oooooo1?l000000ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo00[ooooo0_l000000ol00?oo0000oa0@4004oooo
o`;o8B4Q1?ooool4o`000003o`00oooooooooooo00;ooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`00oooooooooooo00kooooo00Go0000o`00ool0003o0000oa0@4004ooooo`;o8B4Q1Ooo
ool01Ol00?oo0000o`000?lb<S;ogMgM023ooooo000Qooooo`03o`000?oooooooooo00kooooo00?o
003oooooooooool03?ooool01_l00?ooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05
o`00oolQ8B7ok^k^oooooom4A4@01oooool01?mgMgOo<S8booooool00?l@ooooo`08ool00?l00?oo
ooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q00?o003oooooooooool01Oooool00omgMgOo
<S8booooo`06ooooo`03o`00oooooooooooo00_ooooo00GoMgMgo`00ooooooooV9RHogMgM`05oooo
o`;o8B4Q1_ooool00omEEEGo003oooooo`07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`09ooooo`04o`000?ooooooooooo`00oa3ooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
oooo003o00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00ool0
003ooooo00Gooooo0_lQ8B45ooooo`05o`00ooooooooooooogMgMolb<S808?ooool0027ooooo00?o
0000ooooooooool03_ooool00ol00?ooooooooooo`0<ooooo`03o`00ool@413ooooo00;ooooo00?o
410@ooooooooool02Oooool01?l00?ooV9RHob4Q8Oo^k^h9ooooo`03o`000?oooooo003o013ooooo
00Coo`00o`00oooooooo410@0oooool00ol@413oooooooooo`05ooooo`03o`00oooooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`0;ooooo`05oa0@4?l00?oooooooooo
ool@41003Oooool00onYZJWo003oooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`09ooooo`04o`000?ooooooooooo`00oa3ooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`04oiRHV?lQ8B7ok^k^o`00o`Sooooo00?o
0000ooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00ool0003ooooo00cooooo00Go
003oooooooooooooooooo`00000Pooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`00oooo
oooooooo00cooooo00?o003oo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`00oooo
ooooV9RHob4Q8Oo^k^h01oooool01?mgMgOo<S8booooool00?lAooooo`03o`00oooooooo000000?o
oooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03ogMgMolb<S;ooooo00Ko
oooo00?o003oooooooooool02oooool01Ol0003o003ooooooooooooo000000kooooo00?o003ooooo
ooooool01_ooool00omgMgOo<S8booooo`03ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool02Oooool01?l0003oooooooooool00?l@ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool03?ooool00onHV9So8B4Qo`00o`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o003o
ooooooooool03_ooool00ol00?ooooooo`00000=ooooo`05o`00ooooooooooooogMgMolb<S808?oo
ool0027ooooo0ol0000>ooooo`03o`00oooooooooooo00cooooo00?o003oo`000?ooool00_ooool0
0ol0003oooooooooo`09ooooo`05o`00ooooooooooooogMgMomVIVH01?ooool01ol0003o8B4Qo`00
0?lb<S;oc<c<ooooool00?l04?ooool01?l00?ooooooooooool00003ooooo`03o`000?oooooooooo
00Gooooo00?o003oooooooooool00_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Oooooo00?o003o
ooooooooool02oooool01Ol0003o003ooooooooooooo000000kooooo00?o003oolc<c?ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`09ooooo`04o`000?ooooooooooo`00oa3ooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0=ooooo`03ogMgMol00?oooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`00oooooooooooo00kooooo00?o003oooooool000003Oooool01Ol00?oo8B4Qo`000?lb<S;o
c<c<023ooooo000Qooooo`03o`000?oooooooooo00kooooo00?o003oooooooooool03?ooool00ol0
0?oo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go003oooooooooooooooooo`000004
ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool03_ooool01?l00?ooooooooooool@
4103ooooo`03oa0@4?oooooooooo00Gooooo00?o003oool00?ooool00_ooool00ol0003ooooooooo
o`09ooooo`03o`00oooooooooooo00_ooooo00Go410@o`00oooooooooooooa0@400=ooooo`03o`00
oonYZJWoMgMg00Cooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`03o`00
oooooooooooo00Wooooo00Co0000oooooooooooo003o4?ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`07ooooo`03
o`00oooooooooooo00kooooo00?o003oooooool000003Oooool00ol00?ooooooooooo`0Rooooo`00
8Oooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00Ko003oogMgMonHV9So
oooooiRHV?mgMgL;ooooo`05o`00oonj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`03
ooooo`03o`00oooooooooooo00kooooo00So003oooooooooooooMgMgoiRHV?ooooooV9RHogMgM`Oo
oooo00?o003oool00?ooool00_ooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00_o
oooo00GoMgMgo`00ooooooooV9RHogMgM`0;ooooo`05oa0@4?oooooo003ooooooolb<S801?ooool0
0ol0003oooooooooo`06ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool02Oooool0
1?l0003oooooooooool00?l@ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02_oo
ool01Ol0003o^[ZjoooooonHV9So003o00Cooooo00?o0000ooooooooool01oooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooo000000gooooo00?o003oooooooooool08_ooool0027ooooo00?o
0000ooooooooool03_ooool00ol00?ooooooooooo`0<ooooo`06o`00oooo003o<S8bo`000?lb<S;o
k^k^2oooool01Ol00?oo410@o`000?lQ8B7oc<c<00Cooooo1?l00002ooooo`03o`00oooooooooooo
00kooooo00So003oooooooooooook^k^oc8b<_l0003o<S8bonk^kPOooooo00?o003oool00?ooool0
0_ooool4o`0000Sooooo00?o003oooooooooool02oooool01Oo^k^ko003oo`000?lb<S;ok^k^00_o
oooo0_l000000ol00?oo0000o`000004ooooo`Co00001Oooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Oooooo00?oEEEEofIVI_l000000_ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00[ooooo00?oEEEEofIVI_l00?l03?ooool01OnHV9So410@o`000?lQ8B7o003o
00Cooooo1?l00006ooooo`03ool00?l00?oooooo00kooooo00?o003oofIVI_l000003Oooool01?l0
0?oo0000o`000?l0000Qooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo
00cooooo00?o003oool00?ooool03_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool03?ooool00ol00?ooo`00ooooo`0>ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0=ooooo`03ool00?l00?oooooo
00kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0<ooooo`03ool00?l00?oooooo
00kooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Qooooo`008Oooool00ol0003o
ooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00?o003oool00?ooool03_ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00?o003oool00?ooool03Oooool00ol00?oo
ooooooooo`0=ooooo`03ool00?l00?oooooo00kooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`0<ooooo`03ool00?l00?oooooo00kooooo00?o003oooooooooool03?ooool00ooo003o
ooooo`00o`0Sooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo00cooooo
00?o003oool00?ooool03_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00kooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00cooooo
00?o003oool00?ooool03_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00gooooo
00?o003oool00?ooool03Oooool00ol00?ooooooooooo`0=ooooo`03ool00?l00?oooooo00kooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`0<ooooo`03ool00?l00?oooooo00kooooo
00?o003oooooooooool03?ooool00ooo003oooooo`00o`0Iooooo`;o00000_ooool2o`0000Cooooo
000Qooooo`03o`000?oooooooooo00kooooo00?o003oooooooooool03?ooool00ol00?ooo`00oooo
o`0>ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03_ooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03?ooool00ol00?ooo`00oooo
o`0>ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03Oooool00ol00?ooo`00oooo
o`0=ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03_ooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`0<ooooo`03ool00?oooooo003o01Wooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`00
8Oooool00ol0003oooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00?o003oool00?ooool0
3_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
3?ooool00ooo003oooooo`00o`0Jooooo`04omgMgOl0003o410@olc<c0Gooooo000Jooooo`Oo0000
00?o003oo`000?l000003Ol000000ol00?oo0000o`00000=o`000003o`00oooo003o000000ko0000
00?o003oo`000?l000003Ol000000ol00?oo0000o`00000=o`000003o`00ool0003o000000go0000
00?o003oo`000?l000003Ol000000ol00?oo0000o`00000=o`000003o`00ool0003o000000go0000
00?o003oo`000?l000003Ol000000ol00?oo0000o`00000=o`000003o`00ool0003o000000go0000
00?o003oo`000?l000003Ol000000ol00?oo0000o`00000>o`000003o`00ool0003o000000go0000
00?o003oo`000?l000003Ol000000ol00?oo0000o`00000=o`000003o`00ool0003o000000co0000
00?oo`00o`000?l00?l03_l0000<ooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`03o`00
oooooooooooo00Oooooo00?o0000ooooooooool00oooool01?l00?ooooooooooool00009ooooo`05
o`000?ooooooooooo`00oooo00001?ooool00ol0003oooooooooo`07ooooo`03o`000?l00?oooooo
00Kooooo00?o0000ooooooooool01Oooool00ol00?ooooooo`000008ooooo`03o`000?oooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo003o
00Oooooo00?o0000ooooooooool01Oooool00ol00?oo0000ooooo`07ooooo`03o`000?oooooooooo
00?ooooo00Go003oooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`00o`Kooooo00?o
0000ooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00Co
003ooooooooooooo00002Oooool01?l0003oooooooooool00?l5ooooo`03o`000?oooooooooo00Oo
oooo00?o003oooooooooool01_ooool00ol0003oooooooooo`04ooooo`04ool00?l00?ooooooo`00
00Sooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooool00?l01_ooool00ol0003oooooooooo`06ooooo`03o`00ool0003ooooo
00Oooooo00?o0000ooooooooool00_ooool00ooo003oooooo`00o`02ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool03?ooool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03Oooool00ol0
003o003oooooo`0>ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool02oooool00ol0
003oooooo`00o`0?ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool02_ooool01?l0
003oooooooooool00?l?ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool02_ooool0
1?l0003oooooooooool00?l?ooooo`03o`00oooooooooooo00gooooo00?oo`00o`00ooooool02Ooo
ool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?oo`00o`00ooooool06?oo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00gooooo00?oo`00o`00ooooool03_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool03Oooool00ooo003o003oooooo`0Rooooo`008Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00?oo`00o`00ooooool03_ooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00?oo`00o`00ooooool03Oooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03Oooool00ooo
003o003oooooo`0Rooooo`008Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00co
oooo00?oo`00o`00ooooool03_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0=ooooo`03ool00?l00?oooooo00go
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00go
oooo00?oo`00o`00ooooool03Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool03Oooool00ooo003o003oooooo`0Rooooo`008Oooool00ol00?oooooo
ooooo`0=ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00cooooo00?oo`00o`00ooooool03_ooool00ol00?oooooo
ooooo`0<ooooo`03ool00?l00?oooooo00kooooo00?o003oooooooooool03Oooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03Oooool00ol00?oooooo
ooooo`0=ooooo`03o`00oooooooooooo00gooooo00?oo`00o`00ooooool03Oooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00cooooo00?o003oool00?ooool03_ooool00ooo003o003o
ooooo`0Rooooo`008Oooool00ol0003o003oooooo`0=ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00?o
o`00o`00ooooool03_ooool00ol00?ooooooooooo`0<ooooo`03ool00?l00?oooooo00kooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00gooooo00?o
o`00o`00ooooool03Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00?o
003oool00?ooool03_ooool00ooo003o003oooooo`0Rooooo`008Oooool00ol0003o003oooooo`0=
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00cooooo00?oo`00o`00ooooool03_ooool00ol00?ooooooooooo`0<
ooooo`03ool00?l00?oooooo00kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03_ooool00ooo003oooooo`00o`0R
ooooo`008Oooool00ol0003o003oo`00000=ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00?oo`00o`00
ooooool03_ooool00ol00?ooooooooooo`0<ooooo`03ool00?l00?oooooo00kooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool03_ooool00ooo003oooooo`00o`0Rooooo`008Oooool00ol0003o003oooooo`0=ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0<ooooo`03
ool00?l00?oooooo00kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0?ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool03_ooool00ooo003oooooo`00o`0Rooooo`00
8Oooool00ol0003o003oooooo`0<ooooo`03ool00?l00?oooooo00oooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
3_ooool00ol00?ooooooooooo`0<ooooo`03ool00?l00?oooooo00kooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
3_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
3_ooool00ooo003oooooo`00o`0Rooooo`008Oooool00ol0003o003oooooo`0<ooooo`03ool00?l0
0?oooooo00oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00kooooo00?oo`00o`00ooooool03?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Pooooo`008Oooool0
0ol0003o003oooooo`0<ooooo`03ool00?l00?oooooo00oooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00kooooo00?oo`00o`00ooooool03?ooool0
0ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool04?ooool0
0ol00?ooooooooooo`0Pooooo`008Oooool00ol0003o003oooooo`0<ooooo`03ool00?l00?oooooo
00oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00kooooo00?oo`00o`00ooooool03?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Pooooo`008Oooool00ol0003o
003oooooo`0<ooooo`03ool00?l00?oooooo00oooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03oooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`0?ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03oooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00oooooo00?oo`00o`00ooooool02oooool00ooo003o
003oooooo`0?ooooo`03ool00?l00?oooooo00cooooo00?o003oooooooooool04?ooool00ol00?oo
ooooooooo`0Pooooo`008Oooool00ol0003o003oooooo`0<ooooo`03ool00?l00?oooooo00oooooo
00?o003oooooooooool02oooool00ooo003o003oooooo`0?ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00oooooo
00?oo`00o`00ooooool02oooool00ooo003o003oooooo`0?ooooo`03ool00?l00?oooooo00cooooo
00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Pooooo`008Oooool00ol0003o003ooooo
o`0<ooooo`03ool00?l00?oooooo00oooooo00?o003oooooooooool02oooool00ooo003o003ooooo
o`0?ooooo`03ool00?l00?oooooo00cooooo00?o003oooooooooool03oooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`0?ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03oooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00oooooo00?oo`00o`00ooooool02oooool00ooo003o003ooooo
o`0?ooooo`03ool00?l00?oooooo00cooooo00?o003oooooooooool04?ooool00ol00?oooooooooo
o`0Pooooo`008Oooool00ol0003o003oo`00000<ooooo`03ool00?l00?oooooo00oooooo00?o003o
ooooooooool02oooool00ooo003o003oooooo`0?ooooo`03ool00?l00?oooooo00cooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo013ooooo00?o003o
ooooooooool02_ooool00ooo003o003oooooo`0?ooooo`03ool00?l00?oooooo00cooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`0Pooooo`008Oooool00ol0003o003oool0000=oooo
o`03o`00oooooooooooo00kooooo00?oo`00o`00ooooool02oooool00ooo003o003oooooo`0?oooo
o`03ool00?l00?oooooo00cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo00oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0?oooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool00ooo003o003oooooo`0?oooo
o`03ool00?l00?oooooo00cooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Poooo
o`008Oooool00ol0003oooooo`00o`0<ooooo`03o`00oooooooooooo00oooooo00?oo`00o`00oooo
ool02oooool00ooo003o003oooooo`0?ooooo`03ool00?l00?oooooo00cooooo00?o003ooooooooo
ool03oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00oooooo00?o003ooooooooo
ool02oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00_ooooo00?o003ooooooooo
ool03oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool02_ooool00ooo003o003oooooo`0?ooooo`03ool00?l00?oooooo00_ooooo00?o003ooooooooo
ool04Oooool00ol00?ooooooooooo`0Pooooo`008Oooool00ol0003oooooo`00o`0<ooooo`03o`00
oooooooooooo00oooooo00?oo`00o`00ooooool02oooool00ooo003o003oooooo`0@ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0?ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo013ooooo00?o003oooooooooool02_ooool00ooo003o003oooooo`0@ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Oooooo`008Ooo
ool00ol0003oooooo`00o`0<ooooo`03o`00oooooooooooo00oooooo00?oo`00o`00ooooool02ooo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03ooo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03ooo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02_oo
ool00ooo003o003oooooo`0@ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool04_oo
ool00ol00?ooooooooooo`0Oooooo`008Oooool00ol0003oooooo`00o`0<ooooo`03o`00oooooooo
oooo00oooooo00?oo`00o`00ooooool02oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool03oooool00ol00?ooo`00ooooo`0;ooooo`03o`00oooooooo
oooo00oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo013ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Oooooo`008Oooool00ol0
003oooooo`00o`0<ooooo`03o`00oooooooooooo00oooooo00?oo`00o`00ooooool02oooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03oooool00ol0
0?ooo`00ooooo`0;ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool04?ooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool04_ooool00ol0
0?ooooooooooo`0Oooooo`008Oooool00ol0003oooooo`00o`0<ooooo`03o`00oooooooooooo013o
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo013o
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Oooooo`008Oooool00ol0003ooooo
o`00o`0<ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`0@ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool04?ooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool02_ooool00ol00?ooo`00
ooooo`0Aooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool04?ooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`0@ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool04_ooool00ol00?oooooo
ooooo`0Oooooo`008Oooool2o`000003o`00oooooooooooo00[ooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool03ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooo003ooooo017ooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`0@ooooo`03ool00?oooooo003o027ooooo000Qooooo`03o`000?oooooo
003o00cooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo013ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`09ooooo`03o`00oooo003o
oooo017ooooo00?o003oooooooooool02Oooool00ooo003o003oooooo`0Aooooo`03o`00oooooooo
oooo00Wooooo00?oo`00o`00ooooool04Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo013ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03ool00?oooooo
003o027ooooo000Qooooo`03o`000?oooooo003o00cooooo00?o003oooooooooool04?ooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool04Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooo003ooooo017ooooo00?o003oooooooooool02Oooool00ooo
003o003oooooo`0Aooooo`03o`00oooooooooooo00Wooooo00?oo`00o`00ooooool04_ooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`0@ooooo`03ool00?oooooo003o027ooooo000Qooooo`03o`000?oooooo003o00co
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo013o
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo003ooooo017o
oooo00?o003oooooooooool02Oooool00ooo003o003oooooo`0Aooooo`03o`00oooooooooooo00Wo
oooo00?oo`00o`00ooooool04_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo013o
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Aooooo`03ool00?l00?oooooo023o
oooo000Qooooo`03o`000?oooooo003o00cooooo00?o003oooooooooool04?ooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`0Aooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool04Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooo003ooooo017ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0Aooooo`03o`00oooooooooooo00Wooooo00?oo`00o`00ooooool04_ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`0Aooooo`03ool00?l00?oooooo023ooooo000Qooooo`03o`000?oooooo003o00cooooo00?o
003oooooooooool04?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo017ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool04Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Wooooo00?o
o`00o`00ooooool04Oooool00ooo003o003oooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`0Aooooo`03ool00?l00?oooooo023ooooo000Q
ooooo`03o`000?oooooo003o00_ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0A
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0A
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool04Oooool00ooo003o003oooooo`0:
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0A
ooooo`03ool00?l00?oooooo023ooooo000Qooooo`03o`000?oooooo003o00_ooooo00?o003ooooo
ooooool04_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool04Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool04Oooool00ooo003o003oooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0Aooooo`03ool00?oooooo003o023ooooo000Qooooo`03
o`000?oooooo003o00_ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo017ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Aooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo017ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Aooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool04Oooool00ooo003o003oooooo`0:ooooo`03
o`00oooooooooooo013ooooo00?o003oooooooooool02Oooool00ol00?ooo`00ooooo`0Booooo`03
ool00?oooooo003o023ooooo000Qooooo`03o`000?oooooo003o00_ooooo00?o003oooooooooool0
4_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
4Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
4Oooool00ooo003o003oooooo`0:ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`0Booooo`03ool00?oooooo003o023ooooo000Qooooo`;o000000?o
003oooooooooool02Oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool04Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o
003oooooooooool02?ooool00ooo003o003oooooo`0Booooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool04Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o
o`00o`00ooooool02Oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool04Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o
o`00ooooool00?l08?ooool0027ooooo00Co0000oooooooooooo003o2_ooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool04Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool02?ooool00ooo003o003ooooo
o`0Booooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool04Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo01;ooooo00?oo`00ooooool00?l08?ooool0027ooooo00Co0000
oooooooooooo003o2_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool04_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o
003oooooooooool02?ooool00ooo003o003oooooo`0Booooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool04Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool04_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o
o`00ooooool00?l08?ooool0027ooooo00Co0000oooooooooooo003o2_ooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool02?ooool00ooo003o003ooooo
o`0Booooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo01;ooooo00?oo`00ooooool00?l08?ooool0027ooooo00Co0000
oooooooooooo003o2_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool04_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o
003oooooooooool02?ooool00ooo003o003oooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool04_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool04_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o
o`00ooooool00?l08?ooool0027ooooo00Co0000oooooooooooo003o2Oooool00ooo003o003ooooo
o`0Cooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`08ooooo`03ool00?l00?oooooo01;ooooo00?o003oooooooooool02?ooool00ooo003o003ooooo
o`0Cooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo01;ooooo00?oo`00ooooool00?l08?ooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo
00Co0000oooooooooooo003o2Oooool00ooo003o003oooooo`0Cooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`08ooooo`03ool00?l00?oooooo01;o
oooo00?o003oooooooooool02?ooool00ooo003o003oooooo`0Cooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01;o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01;o
oooo00?oo`00ooooool00?l08?ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`04o`000?ooooooooooo`00o`Wooooo00?oo`00o`00
ooooool04oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o003ooooo
ooooool02?ooool00ooo003o003oooooo`0Booooo`03o`00oooooooooooo00Sooooo00?oo`00o`00
ooooool04oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool04_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01kooooo0007ooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`00o`Wooooo00?oo`00o`00ooooool04oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo01;ooooo00?oo`00o`00ooooool02?ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo01?ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo01;ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooo
oooo01kooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03
ooooo`?o000000?o003oooooooooool01oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool04_ooool00ooo003o003oooooo`08ooooo`03o`00oooooooo
oooo01?ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo01?ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo01Cooooo00?o003oooooooooool07_ooool000Oooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool01?l0003oooooooooool00?l9ooooo`03o`00
oooooooooooo01Cooooo00?o003oooooooooool01_ooool00ooo003o003oooooo`0Cooooo`03ool0
0?l00?oooooo00Sooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo01?ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Cooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo01?ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Booooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Mooooo`001ooo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool01?l0003ooooo
ooooool00?l9ooooo`03o`00oooooooooooo01?ooooo00?oo`00o`00ooooool01oooool00ooo003o
003oooooo`0Cooooo`03ool00?l00?oooooo00Sooooo00?o003oooooooooool04oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool04oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`0Mooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool01_ooool01?l0003oooooooooool00?l9ooooo`03o`00oooooooooooo01?ooooo00?oo`00o`00
ooooool01oooool00ooo003o003oooooo`0Cooooo`03ool00?l00?oooooo00Sooooo00?o003ooooo
ooooool04oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool04oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool05_ooool00ol00?ooooooooooo`0Mooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l00005ooooo`04o`000?ooooooooooo`00o`Wooooo00?o003oooooooooool04oooool0
0ooo003o003oooooo`07ooooo`03ool00?l00?oooooo01?ooooo00?oo`00o`00ooooool02?ooool0
0ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool04oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01;ooooo00?oo`00o`00ooooool01oooool0
0ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo01gooooo000Qooooo`04o`000?oooooooooo
o`00o`Wooooo00?o003oooooooooool04oooool00ooo003o003oooooo`07ooooo`03ool00?l00?oo
oooo01Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo01?ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo01Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooo
oooo01gooooo000Qooooo`04o`000?ooooooooooo`00o`Wooooo00?o003oooooooooool04oooool0
0ooo003o003oooooo`07ooooo`03ool00?l00?oooooo01Cooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool04oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo01gooooo000Qooooo`05o`000?oooooooooo
o`00oooo00002?ooool00ol00?ooooooooooo`0Cooooo`03ool00?l00?oooooo00Oooooo00?oo`00
o`00ooooool05?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool04oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool05?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Kooooo00?o003o
ooooooooool07Oooool0027ooooo00Go0000ooooooooooooooooo`00o`08ooooo`03o`00oooooooo
oooo01?ooooo00?oo`00o`00ooooool01oooool00ooo003o003oooooo`0Dooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo01?ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo01Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0Mooooo`008Oooool3o`00
0003ooooool00?oooooo00Oooooo00?o003oooooooooool04oooool00ooo003o003oooooo`08oooo
o`03o`00oooooooooooo01?ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Coooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo01?ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Doooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo01Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Foooo
o`03o`00oooooooooooo01gooooo000Qooooo`05o`000?ooooooooooooooool00?l02?ooool00ol0
0?ooooooooooo`0Dooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool04oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool04oooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0Dooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool07Oooool0027o
oooo00Go0000ooooooooooooooooo`00o`08ooooo`03o`00oooooooooooo01Cooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?oo`00o`00
ooooool01oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool05_ooool00ol00?ooooooooooo`0Mooooo`008Oooool01Ol0003ooooooooooooooooo003o
00Sooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo003ooooo
01Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Dooooo`03ool00?oooooo003o
01oooooo000Qooooo`05o`000?ooooooooooooooool00?l01oooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo01Cooooo00?o003oool00?ooool01oooool00ol00?ooooooooooo`0Doooo
o`03o`00oooooooooooo00Gooooo00?o003oool00?ooool05?ooool00ol00?ooooooooooo`06oooo
o`03ool00?l00?oooooo01Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo01Cooooo00?oo`00ooooool00?l07oooool0027ooooo00Go0000oooooooo
ooooooooo`00o`07ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0Dooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool00ol0
0?ooo`00ooooo`06ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool01Oooool00ol0
0?ooo`00ooooo`0Dooooo`03o`00oooooooooooo00Kooooo00?oo`00o`00ooooool05Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0Dooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool01?oo
003oooooooooool00?lNooooo`008Oooool01Ol0003ooooooooooooooooo003o00Oooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Gooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooo003ooooo00Kooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Cooooo00?o003o
ooooooooool01_ooool00ooo003o003oooooo`0Eooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0Dooooo`04ool00?ooooooooooo`00oakooooo000Q
ooooo`05o`000?ooooooooooooooool00?l01oooool00ol00?ooooooooooo`0Eooooo`03ool00?l0
0?oooooo00Kooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo01Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo01Cooooo00Coo`00oooooooooooo003o7_ooool0027ooooo00Go0000oooooooooooooooo
o`00o`07ooooo`03o`00oooooooooooo01Gooooo00?oo`00o`00ooooool01_ooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool05Oooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool05Oooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool05?ooool01?oo003ooooo
ooooool00?lNooooo`008Oooool3o`000003ooooool00?oooooo00Kooooo00?o003oool00?ooool0
5_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
5Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
5Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0Dooooo`04ool00?ooooooooooo`00oakooooo000Qooooo`03o`00
0?oooooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Fooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo01Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Eooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo01Gooooo00?o003oool00?ooool01Oooool00ol00?ooooooooooo`0Eooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`04ooooo`03o`00
oooo003ooooo01Gooooo00Coo`00oooooooooooo003o7_ooool0027ooooo00?o0000ooooooooool0
0_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
5Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
5Oooool00ol00?ooo`00ooooo`05ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00Cooooo00?o003oool00?ooool0
5_ooool00ooo003oooooo`00o`0Nooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
oooooooo00Cooooo00?oo`00o`00ooooool05_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
003ooooo00Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo01Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Fooooo`03ool00?oo
oooo003o01kooooo000Qooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool05Oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool01?ooool0
0ooo003o003oooooo`0Fooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool05Oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Gooooo00?o003oool00?ooool01Oooool0
0ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01Kooooo00?oo`00ooooool00?l07_ooool0
027ooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
01Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`04ooooo`03ool00?l00?oooooo
01Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooo003ooooo
00Gooooo00?o003oooooooooool05Oooool00ol00?ooo`00ooooo`05ooooo`03o`00oooooooooooo
01Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool05_ooool00ooo003oooooo`00o`0Nooooo`008Oooool00ol0003o
ooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool00ol00?oo
ooooooooo`04ooooo`03ool00?l00?oooooo01Kooooo00?o003oooooooooool01?ooool00ol00?oo
o`00ooooo`0Fooooo`03o`00oooooooooooo00Cooooo00?oo`00o`00ooooool05_ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo01Gooooo00?o003oool00?ooool01Oooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooo003ooooo00Gooooo00?o003oooooooooool05_ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`0Fooooo`03ool00?oooooo003o01kooooo000Qooooo`03o`000?oooooooooo00;ooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool05_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo003ooooo01Kooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool05Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Kooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool05_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01Kooooo
00?oo`00ooooool00?l07_ooool0027ooooo00?o0000ooooooooool00_ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0Fooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0Fooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0Fooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool00ooo003oooooo`00
o`0Nooooo`008Oooool3o`0000;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0F
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0G
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0F
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo01Kooooo00Coo`00oooooooooooo003o7Oooool0027ooooo00?o0000
ooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01Kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool05oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01Oooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool05_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01Kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool05oooool00ooo003oooooo`00o`0Mooooo`008Oooool00ol0003oooooooooo`03oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo01Kooooo00?oo`00o`00ooooool01?ooool00ol00?ooooooooooo`0Goooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo01Oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Foooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo01Kooooo00?oo`00o`00ooooool00oooool00ooo003o003oooooo`0Joooo
o`03o`00oooooooooooo01_ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool05_ooool00ooo003o003oooooo`04ooooo`03o`00oooooooooooo01Oooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool05oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01Kooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool05_ooool00ooo003o003oooooo`03ooooo`03ool00?l00?oooooo01[ooooo00?o003ooooooooo
ool06oooool0027ooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo01Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Gooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo01Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Gooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo01Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Fooooo`03ool0
0?l00?oooooo00?ooooo00?oo`00o`00ooooool06_ooool00ol00?ooooooooooo`0Kooooo`008Ooo
ool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06?oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool05ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06?oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01Kooooo00?oo`00o`00ooooool00ooo
ool00ooo003o003oooooo`0Jooooo`03o`00oooooooooooo01_ooooo000Qooooo`03o`000?oooooo
oooo00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooo
oooo00;ooooo00?o003oool00?ooool06?ooool00ol00?ooooooooooo`02ooooo`03ool00?l00?oo
oooo01Sooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo01Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooo
oooo00;ooooo00?oo`00o`00ooooool06?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo01[ooooo00?o003oooooooooool06oooool0027ooooo00?o0000ooooooooool00oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool00_ooool00ol0
0?ooo`00ooooo`0Hooooo`03o`00oooooooooooo00;ooooo00?oo`00o`00ooooool06?ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo01Wooooo00Go003oooooooooooooooooo`00o`0K
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0H
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0K
ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool06?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Sooooo00?o003ooooo
ooooool00_ooool00ooo003o003oooooo`0Hooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool06Oooool01Ol00?oooooooooooooooooo003o01_ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06?ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo01_ooooo000Qooooo`03o`000?oooooooooo
00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
01Sooooo00?o003oool00?ooool00_ooool00ol00?ooooooooooo`0Iooooo`05o`00oooooooooooo
ooooool00?l06oooool01_l00?ooooooooooooooooooo`00o`00oa[ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
6?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool0
6oooool0027ooooo0ol00003ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06?oo
ool00ooo003o003oooooo`02ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0Hooooo`03o`00oooo003ooooo00;ooooo00?o003oooooooooool06Ooo
ool01Ol00?oooooooooooooooooo003o01_ooooo00Go003oooooooooooooooooo`00o`0Kooooo`06
o`00oooooooooooooooooooo003o003o6_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo01Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooo
oooo01_ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Hooooo`03ool00?l00?oooooo00;ooooo00?o003oooooooooool06?ooool00ol0
0?ooo`00ooooo`02ooooo`03o`00oooooooooooo01Sooooo00?o003oool00?ooool00_ooool00ol0
0?ooooooooooo`0Iooooo`05o`00ooooooooooooooooool00?l06oooool01Ol00?oooooooooooooo
oooo003o01_ooooo00Ko003oooooooooooooooooool00?l00?lJooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool06?ooool00ol00?ooo`00ooooo`02ooooo`03o`00oooooooooooo01[o
oooo00?o003oooooooooool06oooool0027ooooo00?o0000ooooooooool00oooool01Ol00?ooo`00
oooooooooooo003o01_ooooo00Koo`00o`00ooooooooooooo`00oooo000Kooooo`05o`00oooooooo
ooooooooool00?l06oooool01Ol00?oooooooooooooooooo003o01_ooooo00Go003ooooooooooooo
ooooo`00o`0Kooooo`05o`00ooooooooooooooooool00?l07?ooool01?l00?ooooooooooool00?lK
ooooo`05o`00ooooooooooooooooool00?l07?ooool01Ol00?oooooooooooooooooo003o01cooooo
00?o003oooooooooool06oooool0027ooooo00?o0000ooooooooool01?ooool01?l00?oooooooooo
ool00?lLooooo`04o`00ooooooooooooo`00oacooooo00Go003oooooooooooooooooo`00o`0Koooo
o`05o`00ooooooooooooooooool00?l06oooool01Ol00?oooooooooooooooooo003o01_ooooo00Go
003oooooooooooooooooo`00o`0Looooo`04o`00ooooooooooooo`00oa_ooooo00Go003ooooooooo
ooooooooo`00o`0Looooo`04o`00ooooooooooooo`00oakooooo00?o003oooooooooool06_ooool0
027ooooo00?o0000ooooooooool01?ooool01?l00?ooooooooooool00?lLooooo`04o`00oooooooo
ooooo`00oacooooo00Co003ooooooooooooo003o7?ooool01Ol00?oooooooooooooooooo003o01_o
oooo00Go003oooooooooooooooooo`00o`0Kooooo`05o`00oooo003oooooooooool00?l07?ooool0
1?l00?ooooooooooool00?lLooooo`04o`00ooooooooooooo`00oacooooo00Co003ooooooooooooo
003o7_ooool00ol00?ooooooooooo`0Jooooo`008Oooool00ol0003oooooooooo`04ooooo`04o`00
ooooooooooooo`00oacooooo00Co003ooooooooooooo003o7?ooool01?l00?ooooooooooool00?lL
ooooo`04o`00ooooooooooooo`00oacooooo00Go003oool00?ooooooooooo`00o`0Kooooo`05o`00
oooo003oooooooooool00?l07?ooool01?l00?ooooooooooool00?lLooooo`04o`00oooooooooooo
o`00oacooooo00Co003ooooooooooooo003o7_ooool00ol00?ooooooooooo`0Jooooo`006?ooool4
o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l00?ooooooooooool0
0?lLooooo`04o`00ooooooooooooo`00oacooooo00Co003oool00?oooooo003o7Oooool00ol00?oo
ooooo`00o`0Mooooo`04o`00ooooooooo`00o`00oacooooo00?o003oooooool00?l07Oooool01?l0
0?ooooooooooool00?lLooooo`04o`00ooooooooooooo`00oacooooo00Co003ooooooooooooo003o
7Oooool00ooo003o003oooooo`0Kooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00Co003ooooooooooooo003o7?ooool00ol00?ooo`00o`00o`0Nooooo`03o`00
oooooooo003o01gooooo00?o003oooooool00?l07Oooool00ol00?ooooooo`00o`0Mooooo`03o`00
oooooooo003o01gooooo00?o003oooooool00?l07Oooool00ol00?ooooooo`00o`0Nooooo`;o003o
7_ooool00ooo003o003oooooo`0Kooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo0_l00?lNooooo`;o003o7_ooool2o`00oakooooo00?o003oool00?l00?l07_oo
ool2o`00oagooooo0ol00?lNooooo`;o003o7_ooool2o`00oakooooo0_l00?lNooooo`03ool00?l0
0?oooooo01_ooooo000Jooooo`03o`000?oooooooooo00Cooooo0ol00005ooooo`;o003o7_ooool2
o`00oakooooo0_l00?lOooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool07Oooool2
o`00oakooooo00?o003oooooooooool07Oooool2o`00oakooooo0_l00?lOooooo`03o`00oooooooo
oooo01[ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmV
IVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00Y?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00oo
oooo1?l000001ol@413oooooooooool@413o0000odA4A?o<c<`0XOooool00:Gooooo00Go0000oooo
ooooooooooooo`000002ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`03oiRHV?l@413o
gMgM0:3ooooo000Pooooo`03okZj^_lb<S;ooooo08;ooooo00Go0000ooooooooooooooooo`00000D
ooooo`03o`000?oooooooooo00Gooooo00?oQhN7oeEEEOooool0Woooool0027ooooo00?o0000oooo
ooooool0POooool01Ol0003ooooooooooooooooo000000;ooooo1_l0000<ooooo`03o`000?oooooo
oooo00;ooooo00Goc<c<ob4Q8Ol0003oEEEEo`00002Pooooo`007oooool01OnHV9So410@o`000?l0
003oZJVY087ooooo00Go0000ohN7QoooooooZJVYo`00000Dooooo`03o`000?oooooooooo00;ooooo
00Go8B4QohN7QoooooooV9RHo`00002Pooooo`007oooool01_l0003oZJVYoeEEEOnHV9SoEEEEokZj
^Woooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Booooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00002Pooooo`007oooool01_lb<S;ok^k^oiRHV?mEEEGo
gMgMoa0@49Wooooo00?o0000ooooooooool00_ooool01OlQ8B7oV9RHoooooomgMgOoEEEE0:3ooooo
000Oooooo`07okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c02Fooooo`03oeEEEOmVIVKo000000Co
oooo00Goc<c<oa0@4?l0003o<S8bonk^kP2Pooooo`007oooool01oo^k^ko0000ooooool0003ooooo
ofIVI_n7QhL0oooooom3ooooo`007oooool01?mVIVKoV9RHoooooolb<S82okZj^P03o`000?oooooo
oooo0?oooooo@Oooool002;ooooo00?oIVIVohN7Qoooool0oooooom4ooooo`008_ooool00onYZJWo
A4A4ooooo`3oooooodCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.179101, -1.08612, \
0.0066032, 0.0136036}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0.309017 0.294302 [
[.17539 .29652 -12 -9 ]
[.17539 .29652 12 0 ]
[.32696 .29652 -9 -9 ]
[.32696 .29652 9 0 ]
[.47854 .29652 -12 -9 ]
[.47854 .29652 12 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -12 -9 ]
[.78169 .29652 12 0 ]
[.93327 .29652 -9 -9 ]
[.93327 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(0.25)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(0.5)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(0.75)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(1)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(1.25)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(1.5)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ .05 .05 ] 0 setdash
.02381 .30902 m
.02846 .4191 L
.03279 .50266 L
.03523 .53992 L
.03754 .56765 L
.03881 .57959 L
.03948 .58486 L
.0402 .58965 L
.04146 .59605 L
.04262 .59954 L
.04384 .59915 L
.04496 .59597 L
.04626 .58964 L
.04749 .58106 L
.04967 .56004 L
.05205 .52914 L
.05466 .48411 L
.05744 .42771 L
.06244 .31468 L
.06791 .19038 L
.07079 .13195 L
.07382 .08224 L
.07649 .04959 L
.078 .03573 L
.07872 .03036 L
.07941 .02608 L
.0807 .02017 L
.08189 .01842 L
.08316 .02026 L
.08388 .02253 L
.08454 .02541 L
.08569 .03209 L
.08693 .04165 L
.08916 .06493 L
.09182 .10328 L
.09426 .14813 L
.10458 .37885 L
.10932 .47979 L
.11192 .5242 L
.11438 .55762 L
.11668 .58096 L
.11797 .59046 L
.11916 .59673 L
.12017 .59902 L
.12127 .59882 L
.12242 .59636 L
.1235 .59202 L
.12478 .5844 L
.12618 .57312 L
.12741 .56067 L
Mistroke
.12872 .54493 L
.13119 .50591 L
.13348 .46281 L
.1442 .2221 L
.14922 .11971 L
.15175 .08008 L
.15452 .04642 L
.15597 .03338 L
.15677 .02768 L
.15752 .02328 L
.15822 .02075 L
.15899 .0195 L
.15968 .01926 L
.16032 .01977 L
.16155 .02271 L
.16225 .02552 L
.16291 .02888 L
.16423 .03777 L
.16566 .05044 L
.16811 .08051 L
.17079 .1254 L
.17619 .23694 L
.18584 .45566 L
.18838 .50298 L
.19114 .54511 L
.19241 .56107 L
.19374 .57538 L
.1949 .58548 L
.19614 .59376 L
.19734 .59736 L
.19844 .59845 L
.19955 .59746 L
.20059 .59463 L
.20181 .58906 L
.20294 .58175 L
.20417 .5714 L
.20549 .55776 L
.20796 .52199 L
.21062 .47451 L
.21545 .37263 L
.22115 .24009 L
.22645 .12938 L
.22883 .08996 L
.23107 .05927 L
.23231 .0454 L
.23296 .03906 L
.23366 .03309 L
.23488 .02532 L
.23601 .02153 L
.23725 .01988 L
Mistroke
.23794 .0201 L
.23858 .02101 L
.23981 .02471 L
.24099 .03056 L
.24235 .04014 L
.24361 .05169 L
.24499 .06872 L
.24647 .09048 L
.25746 .31846 L
.26227 .42829 L
.26501 .48266 L
.26756 .52593 L
.26998 .55941 L
.27122 .57332 L
.27187 .57968 L
.27257 .58566 L
.27331 .59012 L
.27399 .59325 L
.27463 .59547 L
.27533 .59711 L
.27663 .59792 L
.27785 .5961 L
.27851 .59411 L
.27922 .59113 L
.27996 .58713 L
.28065 .5826 L
.28189 .57252 L
.28321 .5576 L
.28624 .51276 L
.28899 .46254 L
.29949 .22638 L
.30409 .13164 L
.30654 .09041 L
.30788 .07084 L
.30916 .05461 L
.31037 .04157 L
.31168 .03118 L
.31288 .0251 L
.31398 .02162 L
.31513 .02018 L
.31617 .02078 L
.31736 .02371 L
.31849 .02864 L
.31969 .03625 L
.32096 .04753 L
.32205 .06028 L
.32324 .07626 L
.32836 .16529 L
.33925 .41169 L
.34175 .4633 L
Mistroke
.3444 .51152 L
.34686 .54886 L
.34797 .56299 L
.34916 .57608 L
.35036 .58519 L
.35146 .59132 L
.35275 .59598 L
.35398 .5978 L
.35528 .59698 L
.35649 .59368 L
.35781 .58726 L
.35855 .58239 L
.35922 .57656 L
.36157 .54902 L
.36411 .51044 L
.36873 .42211 L
.3787 .19404 L
.38144 .13928 L
.38437 .08878 L
.38579 .06814 L
.38714 .05126 L
.38834 .03975 L
.38966 .03057 L
.39089 .02457 L
.39204 .02122 L
.39331 .0201 L
.39402 .02066 L
.39468 .02192 L
.39592 .02631 L
.39662 .02996 L
.39727 .03438 L
.3986 .04703 L
.40001 .06359 L
.40503 .14389 L
.40959 .24054 L
.41491 .36457 L
.42055 .48315 L
.42286 .52352 L
.42536 .55928 L
.42679 .5742 L
.42809 .58436 L
.4294 .59179 L
.43065 .59621 L
.43186 .59803 L
.43296 .59756 L
.43422 .59446 L
.43541 .58901 L
.43652 .58004 L
.43753 .57003 L
.43982 .54169 L
Mistroke
.44469 .45929 L
.44983 .34585 L
.45499 .22624 L
.45987 .12651 L
.46256 .08143 L
.46399 .06153 L
.46549 .04572 L
.46676 .03535 L
.46743 .0309 L
.46816 .02692 L
.46943 .02202 L
.47062 .01987 L
.47186 .02019 L
.47301 .02285 L
.47427 .02938 L
.47498 .03484 L
.47562 .04051 L
.47833 .07143 L
.48089 .10989 L
.49029 .30943 L
.4945 .40579 L
.49903 .4969 L
.50162 .53968 L
.50399 .56837 L
.50513 .57861 L
.50637 .58741 L
.50755 .59345 L
.50863 .59701 L
.50979 .59862 L
.51087 .59805 L
.51207 .59488 L
.51335 .58677 L
.51463 .576 L
.51597 .56188 L
.51837 .53013 L
.52329 .44153 L
.52868 .31995 L
.53323 .21564 L
.53563 .16478 L
.53817 .11616 L
.54039 .07967 L
.54157 .06422 L
.54283 .05032 L
.54399 .03972 L
.54506 .03188 L
.54612 .02583 L
.54714 .02182 L
.54837 .01927 L
.54968 .01945 L
.55092 .02348 L
Mistroke
.55204 .03029 L
.55336 .04101 L
.5548 .05571 L
.55739 .08987 L
.56225 .17843 L
.56672 .27865 L
.57198 .39972 L
.5769 .49956 L
.57937 .53982 L
.58203 .57064 L
.58354 .58344 L
.58428 .58842 L
.58497 .59222 L
.58626 .59722 L
.58693 .59872 L
.58765 .59945 L
.58879 .59831 L
.59004 .59285 L
.59134 .58433 L
.59254 .57395 L
.59471 .54977 L
.59703 .5167 L
.60232 .41355 L
.60713 .30346 L
.61164 .20104 L
.61402 .1515 L
.61654 .1048 L
.61874 .07214 L
.6199 .05803 L
.62115 .0451 L
.6223 .03535 L
.62335 .02828 L
.62441 .02299 L
.62541 .01972 L
.62666 .01808 L
.62737 .01928 L
.62801 .0214 L
.6292 .02719 L
.63046 .03586 L
.63264 .05681 L
.63503 .08773 L
.63759 .13054 L
.64033 .18578 L
.64526 .29722 L
.64991 .40362 L
.65245 .45772 L
.65483 .50334 L
.65702 .53772 L
.65903 .5627 L
.66126 .58344 L
Mistroke
.66249 .59152 L
.66367 .59686 L
.66489 .59991 L
.66619 .59844 L
.66743 .59397 L
.66854 .5877 L
.66986 .5777 L
.67128 .56385 L
.67387 .53113 L
.67667 .48322 L
.67964 .42269 L
.68495 .30197 L
.68958 .19674 L
.69455 .10062 L
.6974 .06125 L
.69875 .0466 L
.7 .03551 L
.70125 .0269 L
.70191 .0234 L
.70261 .02051 L
.70379 .01825 L
.70509 .02005 L
.7063 .02436 L
.70743 .03059 L
.70867 .03981 L
.71 .05231 L
.7127 .08593 L
.71517 .12786 L
.72442 .32975 L
.72956 .44497 L
.73227 .49805 L
.73514 .54226 L
.73764 .57177 L
.73907 .58433 L
.73975 .5892 L
.7404 .59311 L
.74163 .59847 L
.74275 .59931 L
.74395 .59766 L
.74526 .59304 L
.74591 .5897 L
.7466 .58543 L
.74782 .57592 L
.74925 .56187 L
.75059 .54601 L
.75298 .5091 L
.7556 .45983 L
.76496 .24959 L
.77016 .13801 L
.77272 .09459 L
Mistroke
.77509 .06198 L
.77638 .04748 L
.77781 .03446 L
.7785 .02934 L
.77924 .02472 L
.78003 .02097 L
.78076 .01956 L
.78208 .01942 L
.78274 .02048 L
.78346 .02248 L
.78475 .02817 L
.78594 .03587 L
.78722 .04663 L
.78857 .06078 L
.791 .09485 L
.79648 .20004 L
.80642 .42638 L
.81069 .50876 L
.81309 .54485 L
.81527 .57097 L
.81651 .58251 L
.81716 .5876 L
.81786 .59223 L
.81913 .59713 L
.82031 .59855 L
.82158 .59739 L
.82278 .59382 L
.82385 .58859 L
.82501 .58084 L
.8274 .55821 L
.82873 .54047 L
.82995 .52159 L
.83455 .43492 L
.84501 .19761 L
.85021 .099 L
.85314 .05806 L
.85454 .04287 L
.85585 .03144 L
.85699 .02455 L
.85821 .02087 L
.85891 .01994 L
.85957 .01982 L
.86082 .0216 L
.86213 .02626 L
.86334 .0331 L
.86467 .04335 L
.86609 .05738 L
.8758 .23445 L
.88606 .46572 L
.88865 .51207 L
Mistroke
.89143 .55294 L
.89302 .57156 L
.89447 .58507 L
.89517 .58977 L
.89593 .59332 L
.89665 .59576 L
.89732 .59724 L
.89855 .59798 L
.8997 .59637 L
.90097 .59204 L
.90168 .58843 L
.90234 .5844 L
.90358 .57482 L
.90494 .56073 L
.90767 .52156 L
.91763 .31498 L
.92253 .20237 L
.92704 .11423 L
.92952 .07548 L
.93083 .05824 L
.93224 .04258 L
.93298 .03565 L
.93366 .03096 L
.93434 .0272 L
.93498 .02443 L
.93569 .02214 L
.93647 .02063 L
.93715 .02014 L
.93788 .02047 L
.93916 .02322 L
.93988 .02596 L
.94054 .02925 L
.94176 .03719 L
.94305 .04877 L
.94421 .06266 L
.94528 .07741 L
.94773 .11662 L
.97619 .60332 L
Mfstroke
0 0 1 r
[ ] 0 setdash
.02381 .30902 m
.02846 .41696 L
.03279 .50427 L
.03523 .54366 L
.03754 .57253 L
.03881 .58462 L
.03948 .58982 L
.0402 .59443 L
.04146 .60024 L
.04262 .60294 L
.04384 .60298 L
.04496 .60049 L
.04626 .59464 L
.04749 .58619 L
.04862 .57599 L
.04967 .56453 L
.05205 .53187 L
.05708 .43771 L
.06244 .31466 L
.06791 .18832 L
.07079 .12976 L
.07382 .0784 L
.07649 .04469 L
.078 .0309 L
.07872 .02574 L
.07941 .02176 L
.0807 .01664 L
.08189 .01477 L
.08316 .01575 L
.08388 .01768 L
.08454 .02035 L
.08569 .02689 L
.08693 .03664 L
.08916 .06111 L
.09182 .10064 L
.09426 .14536 L
.10458 .38025 L
.10932 .48181 L
.11192 .52778 L
.11438 .56234 L
.1155 .57478 L
.11668 .5856 L
.11797 .59458 L
.11916 .60011 L
.12023 .60276 L
.12123 .60326 L
.12233 .60161 L
.1235 .59727 L
.12417 .59366 L
.12488 .58889 L
Mistroke
.12616 .57803 L
.12905 .54304 L
.13182 .49768 L
.13432 .44845 L
.1442 .22058 L
.14909 .11932 L
.15156 .0786 L
.15297 .05924 L
.15425 .04444 L
.15536 .03399 L
.15656 .02513 L
.15783 .01867 L
.15903 .01538 L
.16016 .0148 L
.16135 .01683 L
.16237 .02072 L
.16349 .02725 L
.16481 .03788 L
.16619 .05237 L
.16867 .0861 L
.17424 .19202 L
.17953 .3144 L
.18432 .42522 L
.18892 .51542 L
.19151 .55451 L
.19389 .58106 L
.19511 .59077 L
.19581 .59512 L
.19645 .5983 L
.19712 .60081 L
.19784 .60255 L
.19915 .60316 L
.20037 .60077 L
.20105 .59817 L
.20169 .59496 L
.20286 .58712 L
.2041 .57607 L
.20627 .55045 L
.20861 .51456 L
.21284 .43205 L
.22248 .20856 L
.2271 .11461 L
.22969 .073 L
.23204 .04404 L
.23337 .03178 L
.23408 .02662 L
.23482 .02214 L
.23548 .01908 L
.23619 .01664 L
.23746 .01474 L
Mistroke
.23871 .01588 L
.23942 .01785 L
.24006 .02047 L
.24131 .02779 L
.2425 .0374 L
.24503 .06611 L
.24773 .10782 L
.25259 .20524 L
.25832 .33925 L
.26359 .45754 L
.26618 .5071 L
.2686 .54558 L
.27112 .57612 L
.27246 .58787 L
.27315 .59271 L
.27389 .59687 L
.27463 .60003 L
.27532 .60202 L
.27606 .60315 L
.27688 .60317 L
.27758 .60216 L
.27834 .60001 L
.27905 .59698 L
.27971 .59336 L
.28095 .58437 L
.2823 .57142 L
.28502 .53602 L
.29007 .44292 L
.29547 .31963 L
.3002 .20931 L
.30519 .1085 L
.30773 .06878 L
.30908 .05173 L
.31053 .03682 L
.31121 .03107 L
.31186 .0264 L
.31307 .01972 L
.31421 .01598 L
.31545 .01472 L
.3162 .0154 L
.31691 .01704 L
.31755 .01933 L
.31824 .02267 L
.31899 .02735 L
.31979 .03341 L
.32121 .04707 L
.32376 .08006 L
.32655 .12726 L
.33711 .36378 L
.3421 .47292 L
Mistroke
.34429 .51346 L
.34671 .55067 L
.34905 .57793 L
.35033 .58885 L
.35153 .59636 L
.35285 .60149 L
.35405 .60329 L
.35472 .60309 L
.35544 .6019 L
.35677 .59715 L
.35802 .58963 L
.35915 .58032 L
.3617 .55132 L
.36405 .51531 L
.36627 .47452 L
.37645 .24327 L
.38201 .12516 L
.38473 .07953 L
.38592 .06294 L
.38721 .04746 L
.38844 .03536 L
.38958 .02656 L
.39067 .02039 L
.39182 .01628 L
.39304 .01472 L
.39418 .01583 L
.39543 .01989 L
.39613 .02348 L
.39677 .02758 L
.39804 .03784 L
.39922 .04993 L
.40189 .08588 L
.40728 .18763 L
.41614 .39345 L
.4208 .49134 L
.42336 .5348 L
.42575 .56683 L
.427 .57988 L
.42835 .5908 L
.42912 .59552 L
.42985 .59899 L
.4305 .60124 L
.43122 .60277 L
.43248 .60307 L
.43319 .60189 L
.43383 .6 L
.43508 .59406 L
.43626 .58581 L
.43747 .57473 L
.43875 .56028 L
Mistroke
.44104 .52785 L
.44619 .42943 L
.45592 .2041 L
.46016 .11771 L
.4624 .0806 L
.46478 .04939 L
.46598 .03714 L
.46731 .02662 L
.46852 .01988 L
.46966 .01607 L
.47082 .01472 L
.47188 .01575 L
.47305 .01937 L
.47428 .02595 L
.47549 .03524 L
.47679 .04808 L
.47914 .07834 L
.48445 .17531 L
.494 .39602 L
.49819 .48448 L
.50041 .52384 L
.50279 .55838 L
.50414 .57389 L
.50537 .58532 L
.5066 .59405 L
.50778 .59971 L
.50909 .60294 L
.5103 .60299 L
.51094 .60189 L
.51164 .59979 L
.51237 .59661 L
.51305 .5927 L
.51441 .58242 L
.51584 .56803 L
.5184 .53383 L
.52417 .42446 L
.53391 .1987 L
.53671 .1402 L
.53936 .09281 L
.54174 .05862 L
.54308 .04344 L
.54433 .03201 L
.54547 .02404 L
.5467 .01816 L
.54739 .01609 L
.54806 .01499 L
.5493 .0152 L
.55061 .01863 L
.55182 .02471 L
.55252 .02945 L
Mistroke
.55316 .03452 L
.55458 .04848 L
.55692 .07885 L
.55945 .12091 L
.56404 .21571 L
.56862 .32306 L
.57353 .43562 L
.57571 .48023 L
.57808 .52268 L
.58017 .55367 L
.58239 .57894 L
.58362 .58923 L
.58427 .59359 L
.58498 .59739 L
.58621 .60181 L
.58737 .60331 L
.58852 .60225 L
.58973 .59839 L
.59077 .59289 L
.5919 .5846 L
.59327 .5715 L
.59451 .55681 L
.59731 .515 L
.60234 .41513 L
.60766 .29093 L
.6133 .16354 L
.61562 .1184 L
.61811 .0774 L
.61954 .05802 L
.62084 .04323 L
.62216 .03134 L
.6234 .02295 L
.62461 .01756 L
.62571 .01509 L
.62698 .01511 L
.62817 .01793 L
.62927 .02297 L
.63029 .02962 L
.63141 .03909 L
.63258 .05145 L
.63506 .08482 L
.63736 .12398 L
.64259 .23422 L
.64772 .35506 L
.65328 .47685 L
.65583 .52278 L
.65854 .56156 L
.65965 .57411 L
.66085 .58522 L
.66216 .59443 L
Mistroke
.66339 .60015 L
.66405 .60202 L
.66474 .60311 L
.666 .60272 L
.66677 .60098 L
.66749 .59831 L
.66815 .59507 L
.66885 .59067 L
.67016 .58004 L
.67155 .56548 L
.67404 .53148 L
.67869 .44532 L
.68379 .32934 L
.68835 .2221 L
.69332 .11912 L
.6956 .08122 L
.69802 .04937 L
.69901 .0391 L
.70008 .02997 L
.70126 .02236 L
.70236 .01756 L
.7036 .01494 L
.7043 .01476 L
.70495 .01544 L
.70627 .01929 L
.70701 .02289 L
.70768 .02704 L
.70888 .03656 L
.71018 .04978 L
.71255 .08103 L
.71739 .16914 L
.72185 .26951 L
.72706 .39203 L
.72993 .45469 L
.73265 .50704 L
.73518 .54707 L
.73651 .5643 L
.73793 .5794 L
.73925 .5902 L
.74044 .59725 L
.74163 .60164 L
.74276 .60328 L
.74385 .60255 L
.74504 .59914 L
.74629 .59269 L
.74745 .58408 L
.74954 .56265 L
.75177 .53176 L
.75686 .43616 L
.76151 .33005 L
Mistroke
.76658 .21118 L
.76926 .15386 L
.7721 .10099 L
.77458 .06372 L
.7759 .04784 L
.77732 .03404 L
.77862 .02457 L
.77981 .01863 L
.78094 .01547 L
.78214 .01481 L
.78338 .01702 L
.78407 .01955 L
.78472 .0227 L
.7859 .0305 L
.78715 .04151 L
.78931 .06698 L
.7917 .10348 L
.8019 .32417 L
.80648 .42945 L
.809 .48133 L
.8114 .52398 L
.81362 .55641 L
.81479 .57038 L
.81604 .58267 L
.81719 .59157 L
.81824 .59751 L
.81929 .6014 L
.82027 .60315 L
.82144 .60279 L
.8227 .5995 L
.82388 .59367 L
.82495 .58611 L
.82622 .57456 L
.82759 .55889 L
.83008 .52277 L
.83545 .4178 L
.84041 .30242 L
.84505 .19525 L
.84939 .10889 L
.85175 .07155 L
.85392 .04493 L
.85515 .03332 L
.85632 .02482 L
.85756 .01862 L
.85826 .01638 L
.8589 .01514 L
.86019 .01508 L
.86084 .01625 L
.86155 .01846 L
.86281 .0247 L
Mistroke
.86398 .03319 L
.86537 .04638 L
.86663 .06129 L
.86947 .10395 L
.87458 .20594 L
.87942 .31888 L
.88374 .41892 L
.88833 .51042 L
.89073 .54792 L
.892 .56429 L
.89337 .57891 L
.89462 .5894 L
.89577 .59649 L
.89687 .60095 L
.89803 .60315 L
.89926 .60268 L
.89996 .60112 L
.9006 .59886 L
.90178 .59269 L
.90303 .58335 L
.90519 .56064 L
.90757 .52682 L
.91284 .42565 L
.91777 .31172 L
.92231 .20594 L
.92662 .118 L
.929 .07876 L
.93025 .06137 L
.93159 .04567 L
.93283 .03388 L
.93395 .02556 L
.93507 .01954 L
.93613 .01606 L
.9373 .01472 L
.93855 .01617 L
.93973 .02028 L
.9408 .02631 L
.94206 .03609 L
.94343 .04992 L
.94592 .08303 L
.95129 .18319 L
.95625 .29698 L
.96048 .39633 L
.96504 .49168 L
.96765 .53596 L
.96879 .55227 L
.97004 .56772 L
.97115 .57921 L
.97233 .58909 L
.97357 .59676 L
Mistroke
.97473 .60128 L
.9755 .60286 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool000oooooo
1_l00005ooooo`03o`000?oooooooooo00Cooooo0ol0000@ooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool05Oooool2o`00oaKooooo0_l00?lGooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`;o003o5oooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooooooo01Gooooo0_l00?lFooooo`;o003o:?ooool001[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`;o003o5_ooool2o`00oaKooooo0ol0
0?lFooooo`;o003o5_ooool2o`00oaOooooo0_l00?lFooooo`;o003o5_ooool2o`00oaKooooo0_l0
0?lFooooo`03o`00oooooooo003o01Kooooo0_l00?lFooooo`;o003o:?ooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`;o003o5_ooool00ol00?ooo`00o`00o`0E
ooooo`03o`00oooo003o003o01Kooooo0_l00?lFooooo`;o003o5_ooool00ol00?ooooooo`00o`0F
ooooo`;o003o5_ooool2o`00oaKooooo0_l00?lFooooo`03o`00oooooooo003o01Kooooo0_l00?lF
ooooo`;o003o:?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?oooo
o`;o003o5_ooool00ol00?ooooooo`00o`0Eooooo`03o`00oooooooo003o01Kooooo0_l00?lFoooo
o`03o`00oooooooo003o01Gooooo00?o003oooooool00?l05Oooool00ol00?ooo`00o`00o`0Foooo
o`;o003o5_ooool00ol00?ooooooo`00o`0Eooooo`03o`00oooooooo003o01Gooooo00?o003oool0
0?l00?l05_ooool2o`00obSooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool03oooool00ol00?ooooooo`00o`0Eooooo`03o`00oooooooo003o01Gooooo00?o003oooooool0
0?l05Oooool01?l00?ooooooooooool00?lEooooo`03o`00oooooooo003o01Gooooo00?o003ooooo
ool00?l05Oooool00ol00?ooooooo`00o`0Fooooo`;o003o5_ooool00ol00?ooooooo`00o`0Eoooo
o`03o`00oooooooo003o01Gooooo00?o003oool00?l00?l05_ooool00ol00?ooooooo`00o`0Woooo
o`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo00kooooo00Co003ooooooooo
oooo003o5?ooool01?l00?ooo`00ooooool00?lEooooo`03o`00oooooooo003o01Gooooo00Co003o
oooooooooooo003o5Oooool00ol00?ooooooo`00o`0Eooooo`03o`00oooooooo003o01Gooooo00?o
003oooooool00?l05Oooool01?l00?ooo`00ooooool00?lEooooo`03o`00oooooooo003o01Gooooo
00?o003oooooool00?l05Oooool01?l00?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00
obOooooo000Qooooo`03o`000?oooooooooo00kooooo00Co003ooooooooooooo003o5?ooool01?l0
0?ooo`00ooooool00?lEooooo`04o`00ooooooooo`00o`00oaCooooo00Co003ooooooooooooo003o
5?ooool01?l00?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00oaGooooo00Co003ooooo
oooooooo003o5?ooool01?l00?ooooooooooool00?lEooooo`03o`00oooooooo003o01Gooooo00?o
003oooooool00?l05Oooool01?l00?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00obOo
oooo000Qooooo`03o`000?oooooooooo00kooooo00Co003ooooooooooooo003o5?ooool01?l00?oo
o`00ooooool00?lEooooo`04o`00ooooooooooooo`00oaCooooo00Co003ooooooooooooo003o5?oo
ool01?l00?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00oaGooooo00Co003ooooooooo
oooo003o5?ooool01?l00?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00oaGooooo00Co
003ooooooooo003o003o5?ooool01?l00?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00
obOooooo000Qooooo`03o`000?oooooooooo00kooooo00Co003ooooooooooooo003o5?ooool01?l0
0?ooo`00ooooool00?lDooooo`05o`00ooooooooooooooooool00?l05?ooool01?l00?oooooooooo
ool00?lDooooo`04o`00ooooooooooooo`00oaCooooo00Co003ooooooooooooo003o5Oooool01?l0
0?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00oaCooooo00Co003ooooooooooooo003o
5Oooool01?l00?ooooooool00?l00?lDooooo`04o`00ooooooooooooo`00oaCooooo00Co003ooooo
oooooooo003o9oooool0027ooooo0ol0000>ooooo`04o`00ooooooooooooo`00oaCooooo00Co003o
oooooooooooo003o5?ooool01Ol00?oooooooooooooooooo003o01Cooooo00Co003ooooooooooooo
003o5?ooool01?l00?ooooooooooool00?lDooooo`05o`00ooooooooooooool00?l00?l05?ooool0
1?l00?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00oaCooooo00Co003ooooooooooooo
003o5?ooool01Ol00?oooooooooooooooooo003o01Cooooo00Co003ooooooooooooo003o5?ooool0
1?l00?ooooooooooool00?lWooooo`008Oooool00ol0003oooooooooo`0>ooooo`04o`00oooooooo
ooooo`00oaCooooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool0
0?l04oooool01Ol00?ooo`00oooooooooooo003o01Cooooo00Go003oooooooooooooo`00o`00o`0C
ooooo`05o`00ooooooooooooool00?l00?l04oooool01Ooo003o003ooooooooooooo003o01Cooooo
00Co003ooooooooooooo003o5?ooool01Ol00?oooooooooooooo003o003o01?ooooo00Go003ooooo
ooooooooooooo`00o`0Dooooo`04o`00ooooooooooooo`00oaCooooo00Go003oooooooooooooo`00
o`00o`0Vooooo`008Oooool00ol0003oooooooooo`0>ooooo`04o`00ooooooooooooo`00oaCooooo
00Go003oooooooooooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l04oooool01Ol0
0?oooooooooooooooooo003o01Cooooo00Go003oooooooooooooo`00o`00o`0Cooooo`05o`00oooo
ooooooooool00?l00?l04oooool01Ooo003o003ooooooooooooo003o01Cooooo00Co003ooooooooo
oooo003o5?ooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00
o`0Dooooo`04o`00ooooooooooooo`00oaCooooo00Go003oooooooooooooo`00o`00o`0Vooooo`00
8Oooool00ol0003oooooooooo`0>ooooo`05o`00ooooooooooooool00?l00?l04oooool01Ol00?oo
oooooooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00oooooooo
ooooooooool00?l05?ooool01Ol00?oooooooooooooo003o003o01?ooooo00Go003ooooooooooooo
o`00o`00o`0Cooooo`05o`00ooooooooooooooooool00?l04oooool01Ol00?ooo`00oooooooooooo
003o01Cooooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l0
4oooool01Ooo003o003ooooooooooooo003o01Cooooo00Go003oooooooooooooo`00o`00o`0Voooo
o`008Oooool00ol0003oooooooooo`0>ooooo`05o`00ooooooooooooooooool00?l04oooool01Ol0
0?oooooooooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00o`0Cooooo`06o`00oooo
ooooooooooooool00?ooo`004_ooool00ol00?ooo`00ooooo`02ooooo`03o`00oooooooooooo017o
oooo00Go003oooooooooooooo`00o`00o`0Cooooo`05o`00ooooooooooooooooool00?l04oooool0
1Ol00?ooo`00oooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00
ooooooooooooooooool00?l04oooool00ooo003o003oooooo`02ooooo`03o`00oooooooooooo013o
oooo00Ko003oool00?ooooooooooool00?l00?lVooooo`008Oooool00ol0003oooooooooo`0>oooo
o`05o`00ooooooooooooooooool00?l04oooool01Ol00?oooooooooooooooooo003o01?ooooo00Go
003oooooooooooooooooo`00o`0Cooooo`06o`00ooooooooooooooooool00?ooo`004_ooool00ol0
0?ooo`00ooooo`02ooooo`03o`00oooooooooooo017ooooo00Go003oooooooooooooooooo`00o`0C
ooooo`05o`00ooooooooooooooooool00?l04oooool01Ol00?ooo`00oooooooooooo003o01Cooooo
00Go003oooooooooooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l04oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003oool00?ooool00_ooool00ol0
0?ooooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`00oooo003ooooo00;o
oooo00?o003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003ooooo
ooooooooooooo`00o`0Cooooo`06o`00ooooooooooooooooool00?ooo`004_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo017ooooo00Go003oooooooooooooooooo`00o`0Cooooo`05
o`00ooooooooooooooooool00?l04oooool01Ol00?oooooooooooooooooo003o01Cooooo00Go003o
ooooooooooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l04oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003oool00?ooool00_ooool00ol00?oooooo
ooooo`0Tooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`00oooo003ooooo00;ooooo00?o
003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003ooooooooooooo
ooooo`00o`0Cooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo017ooooo00Ko003oooooooooooooooooool00?l00?lB
ooooo`06o`00oooooooooooooooooooo003o003o4_ooool01Ol00?oooooooooooooooooo003o01Co
oooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l04oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003oool00?ooool00_ooool0
0ol00?ooooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003o
ooooooooooooooooo`00o`0Cooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003oool00?ooool00_oo
ool00ooo003o003oooooo`0Aooooo`06o`00oooooooooooooooooooo003o003o4_ooool01Ol00?oo
oooooooooooooooo003o01?ooooo00?o003oool00?ooool00_ooool00ol00?ooooooooooo`0Aoooo
o`05o`00ooooooooooooooooool00?l04oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Tooooo`008Oooool3o`00
00gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00;ooooo00?oo`00o`00ooooool04Oooool01Ol00?oooooooooooooooooo003o01?ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool04?ooool00ol00?ooo`00ooooo`02ooooo`03ool00?l00?oooooo017ooooo00Ko003o
ooooooooooooooooool00?l00?lBooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
4?ooool00ol00?ooo`00ooooo`02ooooo`03o`00oooooooooooo017ooooo00Ko003ooooooooooooo
ooooo`00oooo000Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo02Cooooo000Qooooo`03o`000?oooooooooo00go
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;o
oooo00?oo`00o`00ooooool04Oooool01Ol00?oooooooooooooooooo003o01?ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool04?ooool00ol00?ooooooooooo`02ooooo`03ool00?l00?oooooo017ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool04?ooool00ol00?ooo`00ooooo`02ooooo`03o`00oooooooooooo017ooooo00Ko003ooooo
ooooooooooooo`00oooo000Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02Cooooo000Qooooo`03o`000?oooooo
oooo00gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo
oooo00;ooooo00?oo`00o`00ooooool04Oooool01Ol00?oooooooooooooooooo003o01?ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03ool00?l00?oooooo013ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool04?ooool00ol00?ooo`00ooooo`02ooooo`03o`00oooooooooooo017ooooo00Ko
003oooooooooooooooooo`00oooo000Booooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02Cooooo000Qooooo`03o`00
0?oooooooooo00gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo00;ooooo00?oo`00o`00ooooool04Oooool01Ol00?oooooooooooooooooo003o01?o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013o
oooo00?oo`00o`00ooooool00_ooool00ol00?ooo`00ooooo`0Aooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02Co
oooo000Qooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool00_ooool00ooo003o003o
ooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?oo`00o`00ooooool04Oooool01Ol00?oooooo
oooooooooooo003o01?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo02Cooooo000Qooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool0
0_ooool00ooo003o003oooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?oo`00o`00ooooool0
4?ooool00ooo003o003oooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
4?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
4?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
4?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02Cooooo000Qooooo`03o`000?oo
oooooooo00gooooo00?o003oooooooooool00_ooool00ooo003o003oooooo`0@ooooo`03o`00oooo
oooooooo00;ooooo00?oo`00o`00ooooool04?ooool00ooo003o003oooooo`03ooooo`03o`00oooo
oooooooo00oooooo00?o003oool00?ooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
003ooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo02Cooooo000Qooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool00_ooool0
0ooo003o003oooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?oo`00o`00ooooool04?ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02Cooooo000Qooooo`03o`000?oooooooooo
00gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00;ooooo00?oo`00o`00ooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
02Cooooo000Qooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0?ooooo`03o`00oooooooooooo00;ooooo00?oo`00o`00ooooool04?ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo02Cooooo000Qooooo`?o00003Oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool09?ooool0027ooooo00?o
0000ooooooooool03?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool09?ooool0027ooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool08oooool0027ooooo00?o0000oooo
ooooool03?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool08oooool0027ooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool08oooool0027ooooo00?o0000ooooooooool0
3?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
8oooool0027ooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool08oooool0027ooooo00?o0000ooooooooool03?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool0
0ooo003o003oooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool08oooool0
027ooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool08oooool0027ooooo0ol0000<ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Co
oooo00?o003oool00?ooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Sooooo`008Oooool00ol0003ooooo
ooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oool00?ooool03oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0Sooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00gooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o
003oooooooooool00oooool00ooo003o003oooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o
003oool00?ooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0Sooooo`008Oooool00ol0003oooooooooo`0<
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ooo003o003oooooo`0>
ooooo`03ool00?l00?oooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooo`00ooooo`05
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0S
ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03_ooool00ooo003o003oooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01?ooool00ooo003o003oooooo`0>ooooo`03ool00?l00?oooooo00Gooooo00?o003ooooo
ooooool03Oooool00ol00?ooo`00ooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool03Oooool00ooo003o003oooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0Sooooo`008Oooool00ol0003oooooooooo`0<ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ooo003o003oooooo`0>ooooo`03
ool00?l00?oooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooo`00ooooo`05ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ooo003o003oooooo`0>ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ooo003o003oooooo`05ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Sooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01?ooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01?ooool00ooo003o003oooooo`0>ooooo`03ool00?l00?oooooo00Gooooo00?o003ooooo
ooooool03Oooool00ol00?ooo`00ooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01?ooool00ooo003o003oooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0Sooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool03?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?oo`00o`00ooooool03_ooool00ooo
003o003oooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oool00?ooool01_ooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Cooooo00?oo`00o`00ooooool03_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool08oooool000Go
00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ooo
003o003oooooo`0>ooooo`03ool00?l00?oooooo00Gooooo00?o003oooooooooool03Oooool00ol0
0?ooo`00ooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01?ooool00ooo
003o003oooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`0Sooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b
<_ooool00oooool3o`0000_ooooo00?o003oool00?ooool01Oooool00ol00?ooooooooooo`0>oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00gooooo00?o003oool00?ooool01Oooool00ol00?ooooooooooo`0>oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04oooo
o`03ool00?l00?oooooo00kooooo00?oo`00o`00ooooool01Oooool00ol00?ooo`00ooooo`0=oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`04oooo
o`03ool00?l00?oooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04oooo
o`03ool00?l00?oooooo02?ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool02oooool00ol00?ooo`00ooooo`05
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooo`00ooooo`05
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ooo003o003oooooo`0>
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04
ooooo`03o`00oooo003ooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo00Cooooo00?oo`00o`00ooooool03_ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=
ooooo`03o`00oooo003ooooo00Gooooo00?oo`00o`00ooooool08oooool000Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`05ooooo`03ool00?l00?oooooo00kooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooo003ooooo00gooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooo003ooooo00Kooooo00?o003oooooooooool08_ooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03ool00?l00?oooooo00kooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03ool00?l00?oooooo00Kooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooo003ooooo00Kooooo00?o003o
ooooooooool08_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool0
0ol0003oooooooooo`0;ooooo`03o`00oooooooooooo00Gooooo00?o003oool00?ooool03_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?oo`00o`00ooooool03Oooool0
0ooo003o003oooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0Rooooo`008Oooool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
00Gooooo00?oo`00o`00ooooool03Oooool00ooo003o003oooooo`06ooooo`03o`00oooooooooooo
00cooooo00?oo`00o`00ooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Rooooo`008Oooool00ol0003o
ooooooooo`0;ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?oo`00o`00ooooool03Oooool00ooo003o
003oooooo`06ooooo`03o`00oooooooooooo00cooooo00?oo`00o`00ooooool01_ooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0Rooooo`008Oooool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool03?ooool00ooo003o003oooooo`06ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03ool00?l00?oooooo00gooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Rooooo`008Oooool00ol0003ooooooooo
o`0;ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00cooooo00?o003oool00?ooool01oooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`05ooooo`03ool00?l00?oooooo00gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0Rooooo`008Oooool3o`0000_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03?ooool00ol00?ooo`00ooooo`07
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo00Gooooo00?oo`00o`00ooooool03Oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo02;ooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool03?ooool00ol00?ooo`00ooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?oo`00o`00
ooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02;ooooo000Qooooo`03
o`000?oooooooooo00_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00Kooooo00?o003oool00?ooool03?ooool00ol00?ooo`00ooooo`07ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo02;ooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oool00?ooool0
3?ooool00ol00?ooo`00ooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02;ooooo000Qooooo`03o`000?oo
oooooooo00_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00Kooooo00?o003oool00?ooool03?ooool00ol00?ooo`00ooooo`07ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo02;ooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oool00?ooool03?ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02;ooooo000Qooooo`03o`000?oooooooooo
00_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00Kooooo00?o003oool00?ooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00Kooooo00?oo`00o`00ooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
02;ooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oool00?ooool03?ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?oo`00o`00ooooool01oooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?oo`00o`00ooooool03?ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo02;ooooo000Qooooo`03o`000?oooooooooo00_ooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo
00?o003oool00?ooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo
00?oo`00o`00ooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo
00?oo`00o`00ooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03ool00?l00?oooooo00Oooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo027ooooo
000Qooooo`?o00002oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool01_ooool00ol00?ooo`00ooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool02oooool00ooo003o003oooooo`07ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool01_ooool00ooo003o003oooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o
o`00o`00ooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool08Oooool0027ooooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ooo003o003oooooo`07
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool08Oooool0027ooooo00?o0000oooo
ooooool02_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02oooool00ooo003o003oooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool08Oooool0027ooooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ooo003o003oooooo`07ooooo`03
o`00oooooooooooo00_ooooo00?o003oool00?ooool02?ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool08Oooool0027ooooo00?o0000ooooooooool0
2_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
2oooool00ooo003o003oooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oool00?ooool0
2?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
8Oooool0027ooooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool02oooool00ooo003o003oooooo`07ooooo`03o`00oooo
oooooooo00_ooooo00?o003oool00?ooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool08Oooool0027ooooo00?o0000ooooooooool02_ooool0
0ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oool00?ooool02?ooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool08Oooool0
027ooooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Oooooo00?oo`00o`00ooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool08Oooool0027ooooo00?o0000ooooooooool02_ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?oo`00o`00ooooool02?ooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?oo`00o`00ooooool02oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`07ooooo`03ool00?l00?oooooo00_ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0:ooooo`03ool00?l00?oooooo00Sooooo00?o003oooooooooool08Oooool0027ooooo
00?o0000ooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo
00?oo`00o`00ooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo
00?oo`00o`00ooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo
00?oo`00o`00ooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooo003ooooo00Sooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03ool00?l00?oooooo00_ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03ool00?l00?oooooo00Sooooo
00?o003oooooooooool08Oooool0027ooooo0ol0000:ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool02_ooool00ooo003o003oooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02?ooool00ooo003o003oooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool02_ooool00ooo003o003oooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o
003oool00?ooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o
o`00o`00ooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o
003oool00?ooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o
o`00o`00ooooool02?ooool00ol00?ooooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`0:
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ooo003o003oooooo`08
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ooo003o003oooooo`0;
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ooo003o003oooooo`08
ooooo`03o`00oooooooooooo00[ooooo00?o003oool00?ooool02?ooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo00Oooooo00?oo`00o`00ooooool02oooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00[ooooo00?o003oool00?ooool02?ooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00[ooooo00?oo`00o`00ooooool02?ooool00ol00?ooooooooooo`0Q
ooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool02_ooool00ooo003o003oooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02?ooool00ooo003o003oooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool02_ooool00ooo003o003oooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oool0
0?ooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?oo`00o`00
ooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oool0
0?ooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?oo`00o`00
ooooool02?ooool00ol00?ooooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`0:ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ooo003o003oooooo`08ooooo`03
o`00oooooooooooo00[ooooo00?o003oool00?ooool02?ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00[ooooo00?o003oool00?ooool02?ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Oooooo00?o003oool00?ooool02oooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Qooooo`00
8Oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
2_ooool00ooo003o003oooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oool00?ooool0
2?ooool00ol00?ooo`00ooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oool00?ooool0
2?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oool00?ooool0
2oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool01_ooool01Oo^k^ko<S8bo`000?lb<S;o003o00Gooooo
0_lQ8B43ooooo`03o`00ool0003o000000?o00001?ooool01Om4A4Co0000o`000?l00?oogMgM00[o
oooo00?o003oooooooooool02?ooool01Oo^k^ko<S8bo`00oolb<S;ok^k^00Gooooo0_lQ8B400ooo
oooo003oooooo`02ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ooo003o003oooooo`08
ooooo`03o`00oooooooooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`00oooo
003ooooo00;o8B4Q1_ooool00ol00?ooo`00ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
0_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
0_ooool4o`000003oa0@4?oooooo003o00cooooo00?o003oool00?ooool02?ooool00ol00?ooo`00
ooooo`02ooooo`Co000000?o410@ooooooooool00_ooool00ol00?oo8B4Qooooo`03ooooo`Co0000
00?o003oool00?ooool00_ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`04ooooo`Co000000?o410@ooooool00?l00_ooool2ob4Q8@Go
oooo00GoA4A4o`00ool0003o<S8bomgMg@0Pooooo`008Oooool00ol0003oooooooooo`0:ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool01_ooool01OmgMgOoV9RHoooooonHV9So003o
00Gooooo0_lQ8B43ooooo`06o`00oonHV9So8B4Qonk^k_ooooooA4A41oooool00ol00?oo<S8boooo
o`09ooooo`03o`00oooooooooooo00Sooooo00GoMgMgoiRHV?l00?ooV9RHogMgM`05ooooo`;o8B4Q
00?oooooo`00ooooool01Oooool00omgMgOo<S8booooo`03ooooo`03ool00?l00?oooooo00Sooooo
00?o003oooooooooool00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o003oool00?oo
ool00_lQ8B46ooooo`03o`00oooo003ooooo00Oooooo00GoMgMgoc8b<_ooooooooooo`00o`0:oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool01?ooool01Ol0003ooooooooooooooooo
003o00cooooo00?o003oooooooooool02?ooool00ol00?ooo`00ooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o003oob4Q8OlQ8B401?ooool01_nHV9So8B4Qonk^k_oooooo003oool000Kooooo
00?oMgMgoc8b<_ooool00oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Kooooo
00Go0000ooooooooooooooooo`00o`02ooooo`;o8B4Q1oooool00ol00?ooMgMgoc8b<P0Pooooo`00
8Oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
1_ooool01Ol@413ooooooooooooooooo003o00[ooooo00Go003ooooooonHV9So8B4Qonk^kP08oooo
o`03o`00ool0003ooooo00Wooooo00?o003oooooooooool02?ooool01Ol@413oooooo`00oooooooo
410@00Sooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool00oooool01Ol@413ooooooooooooooooo410@00;ooooo00?o
003oool00?ooool02?ooool00ol00?ooo`00ooooo`08ooooo`04o`000?ooooooooooo`00o`[ooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`04ooooo`05o`000?ooooooooooooooool0
0?l03?ooool00ol00?ooooooooooo`08ooooo`03o`00oooo003ooooo00Cooooo00?o0000oooooooo
ool00oooool00ol00?ooooooooooo`05ooooo`05oiRHV?lQ8B7ok^k^o`00oooo00001oooool00ol0
003oooooooooo`02ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01_ooool01Ol0
003ooooooooooooooooo003o00_ooooo00?o003oooooool000008?ooool0027ooooo00?o0000oooo
ooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Kooooo00Go0000oooo
ooooooooooooo`00o`0:ooooo`06o`00oooooooooooooiRHV?lQ8B7ok^k^1oooool00ol00?oo<S8b
ooooo`09ooooo`03o`00oooooooooooo00Sooooo00Go0000ooooool00?ooooooo`000008ooooo`03
o`00oooooooooooo00Cooooo00?oMgMgoc8b<_ooool00oooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00oooooooooooo
00Sooooo00?o003oool00?ooool01oooool01OmgMgOo<S8boooooooooooo003o00[ooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`04ooooo`05o`000?ooooooooooooooool00?l03?oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooo003ooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol00?ooooooooooo`06ooooo`04oiRHV?lQ8B7o003oool000Kooooo00?oMgMgoc8b<_ooool0
0_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Kooooo00Go0000oooooooooooo
ooooo`00o`0;ooooo`03o`00oomgMgOo<S8b023ooooo000Qooooo`?o00002_ooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00Kooooo00Go0000ooooooooooooooooo`00o`0:ooooo`06
o`00oooooooooooooooooomgMgOoIVIV1?ooool01Ol0003o8B4Qo`000?l00?ooc<c<00[ooooo00?o
003oooooooooool02?ooool01Ol0003oooooo`00oooooooo000000Sooooo00Wo003ooooooooooooo
ooooo`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00oooooooooooo00Sooooo00?o
003oool00?o<c<`01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Cooooo00Go0000oooooooooooo
ooooo`00o`0<ooooo`03o`00oooooooooooo00Sooooo00?o003oool00?ooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`00oooooooooooo00Oooooo00?oMgMgo`00oooo00000oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00?ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`06oooo
o`05o`000?ooooooooooooooool00?l02Oooool01Ol0003o8B4Qo`00oolb<S;oc<c<023ooooo000Q
ooooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`06
ooooo`05oa0@4?ooooooooooooooool00?l02_ooool00ol00?ooooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo003o2oooool00ol00?ooooooooooo`08ooooo`05oa0@
4?oooooo003oooooool@41002?ooool01Ol00?oooooooooooooooooo000000Sooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`03ooooo`05oa0@4?ooooooooooooooool@41000_ooool0
0ol00?ooooooooooo`08ooooo`03o`00oooo003oMgMg00Cooooo00?o0000ooooooooool01?ooool0
0ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01?ooool0
1Ol0003ooooooooooooooooo003o00cooooo00?o003oooooooooool02?ooool00ol00?ooo`00oooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool02?ooool00ol00?ooo`00oooo
o`02ooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`06ooooo`05o`000?ooooooooooooooool00?l02Oooool00ol0003oooooo`00o`0Rooooo`008Ooo
ool00ol0003oooooooooo`09ooooo`03o`00oooo003ooooo00Wooooo00?o003oooooooooool01_oo
ool01OmgMgOoV9RHoooooonHV9So003o00[ooooo00Koo`00o`00oonj^[[ooooooiRHV?l@4104oooo
o`04o`000?ooooooooooo`00o`_ooooo00?o003oooooooooool02?ooool01OmgMgOoV9RHo`00oonH
V9SoMgMg00Sooooo00Go003oooooooooooooooooo`000008ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o003ooooooooo
ool01_ooool01Ol@413oooooooooool00?oo<S8b00Cooooo00?o0000ooooooooool01?ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01?ooool01Ol0
003ooooooooooooooooo003o00cooooo00?o003oooooooooool02?ooool00ol00?ooo`00ooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool01?ooool01Ol0003o^[ZjoooooonH
V9So003o00Cooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Kooooo00Go0000ooooooooooooooooo`00o`09ooooo`03o`000?oooooo003o02;ooooo
000Qooooo`03o`000?oooooooooo00Wooooo00?o003oool00?ooool02Oooool00ol00?oooooooooo
o`06ooooo`05onk^k_lb<S;o0000oc8b<_l00?l02_ooool01_oo003o003ooa0@4?l0003o8B4Qolc<
c0Cooooo0ol000000ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Sooooo00Gok^k^oc8b
<_l00?oo<S8bonk^kP08ooooo`04o`00ooooooooooooooooo`Co00001Oooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`00
oooooooooooo00Kooooo0ol000000ol00?oo0000ooooo`03ooooo`Co00000oooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool00_ooool00omEEEGoIVIV
o`000003ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooo`00
ooooo`02ooooo`03oeEEEOmVIVKo000000Gooooo00?o003oooooooooool01?ooool01_nHV9So410@
o`000?lQ8B7oc<c<o`00o`?ooooo1?l00004ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool01?ooool00omEEEGoIVIVo`000003ooooo`03o`00oooooooooooo00Oooooo0_l000000ol0
0?oo0000ooooo`0Pooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03ool00?l00?oooooo00[o
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03ool00?l00?oooooo00[o
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Pooooo`008Oooool00ol0003ooooo
ooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`08ooooo`03ool00?l00?oooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`08ooooo`03ool00?l00?oooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0Pooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03ool00?l00?oooooo00[ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0Fooooo`;o00000_ooool2o`0000Cooooo000Q
ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Sooooo00?oo`00o`00ooooool02_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo01Kooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`008Ooo
ool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`08ooooo`03ool00?l00?oooooo00Wooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0Gooooo`04omgMgOl0003o410@olc<c0Gooooo000Jooooo`Oo000000?o
003oo`000?l000002Ol000000ol00?oo0000o`00000:o`000003o`00ool0003o000000Wo000000?o
003oo`000?l000002Ol000000ol00?oo0000o`000009o`000003o`00ool0003o000000Wo000000?o
o`00o`00ool000002Ol000000ol00?oo0000o`000009o`000003o`00ool0003o000000[o000000?o
003oo`000?l000002Ol000000ol00?oo0000o`000009o`000003o`00ool0003o000000Wo000000?o
003oo`000?l000002_l000000ol00?oo0000o`000009o`000003o`00ool0003o000000Wo000000?o
003oo`000?l000002?l000000ooo003o003oo`000009o`000003o`00ool0003o000000[o000000?o
003oo`000?l000002Ol000000ol00?oo0000o`000009o`000003o`00ool0003o000000Wo000000?o
003oo`000?l000002_l000000ol00?oo0000o`000009o`000003o`00ool0003o000000Wo000000?o
003oo`000?l000002ol0000<ooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`03o`00oooo
oooooooo00Oooooo00?o0000ooooool00?l01_ooool00ol0003oooooooooo`03ooooo`05o`00oooo
ooooooooooooool000001oooool00ol00?oo0000ooooo`08ooooo`03o`000?l00?oooooo00Kooooo
00Go0000ooooooooooooooooo`00o`05ooooo`03o`000?oooooooooo00?ooooo00Coo`00o`00oooo
oooo00002?ooool00ol00?oo0000ooooo`07ooooo`03o`000?oooooo003o00Oooooo00?o0000oooo
ooooool00_ooool01Ol00?oooooooooooooooooo000000Oooooo00?o003oo`000?ooool02?ooool0
0ol0003o003oooooo`06ooooo`05o`000?ooooooooooooooool00?l01Oooool00ol0003ooooooooo
o`03ooooo`04o`00ooooooooooooo`0000Wooooo00?o003oooooooooool01_ooool01?l0003ooooo
ool00?l00?l6ooooo`03o`000?oooooooooo00;ooooo00Go003oooooooooooooooooo`000006oooo
o`04o`00ooooooooooooo`0000Sooooo00?o0000o`00ooooool01oooool01?l0003oooooooooool0
0?l5ooooo`03o`000?oooooooooo00?ooooo00Go003oooooooooooooooooo`000007ooooo`03o`00
ool0003ooooo00Oooooo00Co0000oooooooooooo003o1_ooool00ol0003oooooooooo`02ooooo`05
o`00ooooooooooooooooool000001oooool00ol00?ooooooo`000008ooooo`03o`000?oooooooooo
00cooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol0
003o003oooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?oo`00o`00ooooool02Oooool00ol0
0?ooooooooooo`07ooooo`03o`000?oooooo003o00cooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Gooooo00Go0000ooooooooooooooooo`00o`0;
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ooo003o003oooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09
ooooo`05o`00ooooooooooooooooool000001oooool00ol00?ooooooooooo`0Fooooo`;o00000_oo
ool2o`0000Cooooo000Qooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03ool00?l00?oooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`08ooooo`03ool00?l00?oooooo00[ooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo023ooooo000Qooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02?ooool00ol00?ooo`00ooooo`0:ooooo`03ool00?l00?oooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03ool00?l00?oooooo
00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
023ooooo000Qooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?oo
o`00ooooo`0:ooooo`03ool00?l00?oooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo023ooooo000Qooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02?ooool00ol00?ooo`00ooooo`0:ooooo`03ool00?l00?oooooo00Wooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo023ooooo
000Qooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0:ooooo`03ool00?l00?oooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo023ooooo000Qooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooo003ooooo00[ooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03ool00?l00?oooooo00Wooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo023ooooo000Qoooo
o`03o`000?l00?oo000000Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08oooo
o`03o`00oooo003ooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:oooo
o`03ool00?l00?oooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00Sooooo00?oo`00o`00ooooool02_ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo023ooooo000Qooooo`03o`000?l00?oooooo00Wooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?oo`00o`00oooo
ool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?oo`00o`00oooo
ool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo003ooooo023ooooo000Qooooo`03o`00
0?l00?oooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo00Sooooo00?oo`00o`00ooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo00Sooooo00?oo`00o`00ooooool02_ooool00ol00?ooooooooooo`08ooooo`03ool0
0?l00?oooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00
oooo003ooooo023ooooo000Qooooo`03o`000?l00?oooooo00Wooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?oo`00o`00ooooool02ooo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?oo`00o`00ooooool02_oo
ool00ol00?ooooooooooo`08ooooo`03ool00?l00?oooooo00_ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01oooooo000Qooooo`03o`000?l00?oo
oooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Sooooo00?oo`00o`00ooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Sooooo00?oo`00o`00ooooool02_ooool00ol00?ooooooooooo`08ooooo`03ool00?l00?oo
oooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo01oooooo000Qooooo`03o`000?l00?oooooo00Wooooo00?o003oooooooooool02_ooool00ooo
003o003oooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oool00?ooool02?ooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?oo`00o`00ooooool02oooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?oo`00o`00ooooool02_ooool00ooo
003o003oooooo`08ooooo`03ool00?l00?oooooo00_ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo01oooooo000Qooooo`03o`000?l00?oooooo00Wo
oooo00?o003oooooooooool02_ooool00ooo003o003oooooo`08ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[o
oooo00?o003oool00?ooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00So
oooo00?oo`00o`00ooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool02_ooool00ooo003o003oooooo`08ooooo`03ool00?l00?oooooo00_o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01oo
oooo000Qooooo`03o`000?l00?oooooo00Wooooo00?o003oooooooooool02_ooool00ooo003o003o
ooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`0:ooooo`03ool00?l00?oooooo00Sooooo00?oo`00o`00ooooool02oooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`07ooooo`03ool00?l00?oooooo00_ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo01oooooo000Qooooo`03o`000?l00?oooooo00Wooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`0:ooooo`03ool00?l00?oooooo00Wooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03ool00?l00?oooooo00Sooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01oooooo000Q
ooooo`03o`000?l00?oo000000Wooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo00Oooooo00?oo`00o`00ooooool02oooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:
ooooo`03ool00?l00?oooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo01oooooo000Qooooo`03o`000?l00?oooooo00Sooooo00?oo`00o`00
ooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?oo`00o`00
ooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?oo`00o`00
ooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooo003ooooo01oooooo000Qooooo`03
o`000?l00?oooooo00Sooooo00?oo`00o`00ooooool03?ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Oooooo00?oo`00o`00ooooool02oooool00ol00?ooo`00ooooo`08ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00_ooooo00?oo`00o`00ooooool01oooool00ooo003o003oooooo`0<ooooo`03
o`00oooo003ooooo01oooooo000Qooooo`03o`000?l00?oooooo00Sooooo00?oo`00o`00ooooool0
3?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?oo`00o`00ooooool0
2oooool00ol00?ooo`00ooooo`07ooooo`03ool00?l00?oooooo00cooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?oo`00o`00ooooool0
1oooool00ooo003o003oooooo`0<ooooo`03o`00oooo003ooooo01oooooo000Qooooo`03o`000?l0
0?oooooo00Sooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Oooooo00?oo`00o`00ooooool02oooool00ol00?ooo`00ooooo`07ooooo`03ool00?l0
0?oooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool02_ooool00ooo003o003oooooo`08ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo00_ooooo00?oo`00o`00ooooool01oooool00ooo003o003oooooo`0<ooooo`03o`00oooo
003ooooo01oooooo000Qooooo`03o`000?l00?oooooo00Sooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool0
0ol00?ooo`00ooooo`07ooooo`03ool00?l00?oooooo00cooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool0
0ooo003o003oooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?oo`00o`00ooooool01oooool0
0ooo003o003oooooo`0<ooooo`03o`00oooo003ooooo01oooooo000Qooooo`03o`000?l00?oooooo
00Sooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool02oooool00ol00?ooo`00ooooo`07ooooo`03ool00?l00?oooooo
00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool02_ooool00ooo003o003oooooo`07ooooo`03o`00oooooooooooo
00_ooooo00?oo`00o`00ooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00_ooooo00?oo`00o`00ooooool01oooool00ooo003o003oooooo`0<ooooo`03o`00oooo003ooooo
01oooooo000Qooooo`03o`000?l00?oooooo00Sooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?oo
o`00ooooo`07ooooo`03ool00?l00?oooooo00cooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ooo003o
003oooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oo
o`00ooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?oo`00o`00ooooool01oooool00ooo003o
003oooooo`0<ooooo`03o`00oooo003ooooo01oooooo000Qooooo`03o`000?oooooo003o00Sooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool01_ooool00ol00?ooo`00ooooo`0<ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo
00?oo`00o`00ooooool01oooool00ooo003o003oooooo`0<ooooo`03o`00oooo003ooooo01oooooo
000Qooooo`;o000000?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
003ooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
003ooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03ool00?l0
0?oooooo00cooooo00?o003oooooooooool07oooool0027ooooo00?o0000ooooool00?l02?ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool0
0ooo003o003oooooo`06ooooo`03o`00oooo003ooooo00gooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooo003ooooo00cooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool07oooool0
027ooooo00?o0000ooooool00?l02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool02oooool00ooo003o003oooooo`06ooooo`03o`00oooo003ooooo
00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool07oooool0027ooooo00?o0000ooooool00?l02?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ooo003o
003oooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool07oooool0027ooooo
00?o0000ooooool00?l02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool02oooool00ooo003o003oooooo`06ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool07oooool0027ooooo00?o0000ooooool00?l02?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ooo003o003ooooo
o`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooo`00oooo
o`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool07oooool0027ooooo00?o0000
ooooool00?l02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool03?ooool00ooo003o003oooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool01_ooool00ol00?ooo`00ooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool07oooool0027ooooo00?o0000ooooool00?l02?ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ooo003o003oooooo`06oooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooo`00ooooo`0=oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool07oooool0027ooooo00?o0000ooooool0
0?l02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool03?ooool00ooo003o003oooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool01_ooool00ol00?ooo`00ooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool07oooool0027ooooo00?o0000ooooool00?l02?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooo`00ooooo`0=ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool07oooool0027ooooo0_l000000ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`05ooooo`03ool00?l00?oooooo00gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`05ooooo`03o`00oooo003ooooo00gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0Oooooo`008Oooool00ol0003oooooo`00o`08ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03ool00?l00?oooooo00gooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo003ooooo00gooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0Oooooo`008Oooool00ol0003oooooo`00o`08oooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05oooo
o`03ool00?l00?oooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05oooo
o`03o`00oooo003ooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Ooooo
o`008Oooool00ol0003oooooo`00o`08ooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo003ooooo00Kooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`05ooooo`03ool00?l00?oooooo00gooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0Oooooo`008Oooool00ol0003oooooo`00o`08ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03ool0
0?l00?oooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooo003ooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03ool0
0?l00?oooooo00gooooo00?o003oooooooooool01Oooool00ooo003o003oooooo`0=ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooool0000Oooooo`008Ooo
ool00ol0003oooooo`00o`08ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`05ooooo`03ool00?l00?oooooo00gooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`05ooooo`03ool00?l00?oooooo00gooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Gooooo00?oo`00o`00ooooool03Ooo
ool00ol00?ooooooool0000Oooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooo`00o`08ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03ool0
0?l00?oooooo00gooooo00?oo`00o`00ooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03ool0
0?l00?oooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooo`00ooooo`0=ooooo`03o`00
oooooooooooo00Gooooo00?oo`00o`00ooooool03_ooool00ol00?ooo`00ooooo`0Nooooo`001ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo
00?o0000ooooool00?l02?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool01Oooool00ooo003o003oooooo`0=ooooo`03ool00?l00?oooooo00Gooooo
00?o003oool00?ooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool01Oooool00ooo003o003oooooo`0=ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo
00?o003oool00?ooool03Oooool00ol00?ooooooooooo`05ooooo`03ool00?l00?oooooo00kooooo
00?o003oool00?ooool07_ooool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooool00?l02?ooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01Oooool00ooo003o003oooooo`0=ooooo`03ool0
0?l00?oooooo00Gooooo00?o003oool00?ooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00kooooo00?o003oool00?ooool07_ooool000Oooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo0_l000000ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03ool0
0?l00?oooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooo`00ooooo`0>ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooo`00ooooo`0Nooooo`001ooo
ool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03
o`000?oooooo003o00Sooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooooooo00Gooooo00?oo`00o`00ooooool03_ooool00ol00?ooooooooooo`04ooooo`03
o`00oooo003ooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ooo003o003oooooo`05ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03
o`00oooo003ooooo01kooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`06ooooo`04o`000?ooooooooooo`00o`Kooooo00?o003oool00?ooool03_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?oo`00o`00ooooool03_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooo003ooooo00kooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ooo
003o003oooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooo003ooooo01kooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`00o`Kooooo00?o003o
ooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?oo`00
o`00ooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo003ooooo00kooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01?ooool00ooo003o003oooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo003ooooo01kooooo0007oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00Co0000oooooooooooo003o1_oo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oool00?ooool03_oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo00007_oo
ool0027ooooo00Co0000oooooooooooo003o1_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool03Oooool00ooo003o003oooooo`05ooooo`03o`00oooo
oooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Cooooo00?o003oool00?ooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00kooooo00?o003ooooooooo00007_ooool0027ooooo00Co0000oooooooooooo003o1_oo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_oo
ool00ooo003o003oooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo00007_oo
ool0027ooooo00Co0000oooooooooooo003o1_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03_ooool00ooo003o003oooooo`04ooooo`03o`00oooo
003ooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00kooooo00?o003ooooooooo00007_ooool0027ooooo00Co0000oooooooooooo003o1_oo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_oo
ool00ooo003o003oooooo`04ooooo`03o`00oooo003ooooo00kooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?oo`00o`00ooooool01Ooo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo00007_oo
ool0027ooooo0ol000000ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03ool00?l00?oooooo00Cooooo00?o003o
ool00?ooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03_ooool00ooo003o003oooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03_ooool00ol00?ooooooool0000Nooooo`008Oooool01?l0003oooooooooool00?l6
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00?ooooo00?o003oool00?ooool03oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ooo003o003oooooo`04
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooool0000N
ooooo`008Oooool01?l0003oooooooooool00?l6ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003o
ool00?ooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03_ooool00ooo003o003oooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03_ooool00ol00?ooooooool0000Nooooo`008Oooool01?l0003oooooooooool00?l6
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00?ooooo00?o003oool00?ooool03oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0N
ooooo`008Oooool01?l0003oooooooooool00?l6ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003o
ool00?ooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03_ooool00ol00?ooooooooooo`0Nooooo`008Oooool01?l0003oooooooooool00?l6
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?
ooooo`03ool00?l00?oooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0N
ooooo`008Oooool01?l0003oooooooooool00?l6ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03ool00?l00?oooooo00Cooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`0Nooooo`008Oooool01?l0003oooooooooool00?l6
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00kooooo00?o003oool00?ooool01?ooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?
ooooo`03ool00?l00?oooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0N
ooooo`008Oooool01?l0003oooooooooool00?l5ooooo`03o`00oooooooooooo013ooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ool00?ooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03ool00?l00?oooooo00?ooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`0Nooooo`008Oooool3o`000003o`00oooooooooooo
00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool03_ooool00ol00?ooo`00ooooo`04ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
01kooooo000Qooooo`04o`000?ooooooooooo`00o`Gooooo00?o003oooooooooool04?ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol0
0?ooo`00ooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo01gooooo000Qooooo`04o`000?ooooooooooo`00
o`Gooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooo003ooooo
00?ooooo00?o003oooooooooool03oooool00ol00?ooo`00ooooo`04ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
01gooooo000Qooooo`04o`000?ooooooooooo`00o`Gooooo00?o003oooooooooool04?ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooo003ooooo013ooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooo003ooooo00?ooooo00?o003oooooooooool03oooool00ol0
0?ooo`00ooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo01gooooo000Qooooo`05o`000?oooooooooooooo
ool00?l01?ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003oool0
0?ooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oool0
0?ooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooo003ooooo00Cooooo00?o003ooooo
ooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003ooooo
ooooool07Oooool0027ooooo00Go0000ooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo
013ooooo00?o003oooooooooool00_ooool00ol00?ooo`00ooooo`0@ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00oooooo00?o003oool00?ooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool04Oooool01_l00?ooooooooooooooooooo`00o`00oa7ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool04?ooool00ol00?ooooooooooo`0Mooooo`008Oooool01Ol0003ooooooooooooo
oooo003o00Cooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`06o`00oooo
oooooooooooooooo003o003o4Oooool00ol00?ooo`00ooooo`03ooooo`03o`00oooooooooooo013o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01go
oooo000Qooooo`05o`000?ooooooooooooooool00?l01?ooool00ol00?ooooooooooo`0@ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o
01?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00oooooo00?o003oool00?ooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooo003ooooo
00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
017ooooo00Ko003oooooooooooooooooool00?l00?lAooooo`03o`00oooo003ooooo00?ooooo00?o
003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o
003oooooooooool07Oooool0027ooooo00Go0000ooooooooooooooooo`00o`04ooooo`03o`00oooo
oooooooo013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`05o`00oooo
ooooooooooooool00?l04oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool03oooool00ol00?ooo`00ooooo`03ooooo`03o`00oooooooooooo013ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool04?ooool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo013ooooo
00?o003oool00?ooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Mooooo`008Oooool3o`000003ooooool0
0?oooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo017ooooo00Go003oooooooooooooooooo`00o`0Cooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo
00?o003oooooooooool00_ooool00ooo003o003oooooo`0Aooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03ool00?l00?oooooo00;ooooo
00?oo`00o`00ooooool04Oooool01_l00?oooooooooooooooooo003oool001;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00ooooooooo`0001gooooo000Qooooo`05
o`000?ooooooooooooooool00?l01?ooool00ol00?ooooooooooo`0@ooooo`03ool00?l00?oooooo
00;ooooo00?o003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o01?ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool04Oooool01Ol00?oooooooooooooooooo003o01;ooooo00?oo`00o`00ooooool00_oo
ool00ooo003o003oooooo`0Aooooo`06o`00ooooooooooooooooool00?ooo`004_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo00007Oooool0027ooooo
00Go0000ooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo013ooooo00?oo`00o`00oooo
ool00_ooool00ol00?ooooooooooo`0Aooooo`05o`00ooooooooooooooooool00?l04oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooo003ooooo00;ooooo00?o003oooooooooool04Oooool01_l0
0?ooooooooooooooooooo`00o`00oa;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0Aooooo`05o`00ooooooooooooooooool00?l04_ooool00ooo003o003oooooo`02ooooo`03o`00
oooooooooooo017ooooo00Ko003oooooooooooooooooo`00oooo000Booooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooool0000Mooooo`008Oooool01Ol0003o
oooooooooooooooo003o00?ooooo00?o003oooooooooool04_ooool01Ol00?oooooooooooooooooo
003o01?ooooo00Go003oooooooooooooooooo`00o`0Cooooo`06o`00oooooooooooooooooooo003o
003o4_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00Go003ooooooooo
ooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l04oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo017ooooo00Go003oooooooooooooooooo`00o`0Booooo`03ool00?l0
0?oooooo00;ooooo00?o003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o01?ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00ooooooooo`0001gooooo
000Qooooo`05o`000?ooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Booooo`05o`00
ooooooooooooooooool00?l04oooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003ooooo
ooooooooooooo`00o`0Cooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool0
1Ol00?oooooooooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00o`0Cooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o01;o
oooo00?oo`00o`00ooooool00_ooool00ol00?ooooooooooo`0Aooooo`05o`00oooooooooooooooo
ool00?l04oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003ooooo
oooo00007Oooool0027ooooo00Ko0000ooooooooooooooooool00?l00?l2ooooo`03o`00oooooooo
oooo01;ooooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l0
4oooool01Ol00?oooooooooooooooooo003o01?ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0Aooooo`05o`00ooooooooooooooooool00?l04oooool01Ol00?oooooooooooooooooo
003o01?ooooo00Ko003oool00?ooooooooooool00?l00?lCooooo`05o`00ooooooooooooooooool0
0?l04oooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00o`0C
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooool0000M
ooooo`008Oooool00ol0003oooooooooo`02ooooo`04o`00ooooooooooooo`00oaCooooo00Co003o
oooooooooooo003o5?ooool01Ol00?oooooooooooooooooo003o01Cooooo00Co003ooooooooooooo
003o4oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00Go003ooooooooo
ooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l04oooool01_l00?ooo`00oooooooo
ooooo`00o`00oa?ooooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00oooooooooooooooo
ool00?l04oooool01Ol00?ooo`00oooooooooooo003o01?ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Aooooo`03o`00oooo003ooooo01cooooo000Qooooo`03o`000?oooooooooo
00;ooooo00Co003ooooooooooooo003o5?ooool01?l00?ooooooooooool00?lDooooo`05o`00oooo
ooooooooooooool00?l05?ooool01?l00?ooooooooooool00?lDooooo`05o`00ooooooooooooool0
0?l00?l04oooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00
o`0Cooooo`05o`00oooo003oooooooooool00?l05?ooool01Ol00?oooooooooooooooooo003o01?o
oooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00oooo003oooooooooool00?l04oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003oool00?ooool07?ooool0
027ooooo00?o0000ooooooooool00_ooool01?l00?ooooooooooool00?lDooooo`04o`00oooooooo
ooooo`00oaCooooo00Go003oooooooooooooooooo`00o`0Dooooo`04o`00ooooooooooooo`00oaCo
oooo00Co003ooooooooooooo003o5?ooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003o
ooooooooooooooooo`00o`0Dooooo`04o`00ooooooooooooo`00oaCooooo00Go003ooooooooooooo
ooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l04oooool01Ol00?ooo`00oooooooooooo
003o01?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooo
o`0001cooooo000Qooooo`03o`000?oooooooooo00;ooooo00Co003ooooooooooooo003o5?ooool0
1?l00?ooooooooooool00?lDooooo`05ool00?l00?ooooooooooool00?l05?ooool01?l00?oooooo
ooooool00?lDooooo`04o`00ooooooooooooo`00oaCooooo00Go003oooooooooooooooooo`00o`0C
ooooo`05o`00ooooooooooooooooool00?l05?ooool01?l00?ooooooooooool00?lDooooo`05o`00
ooooooooooooool00?l00?l04oooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003oool0
0?ooooooooooo`00o`0Cooooo`06o`00oooooooooooooooooooo003o003o4oooool00ol00?oooooo
ool0000Looooo`008Oooool3o`0000;ooooo00Co003ooooooooooooo003o5?ooool01?l00?oooooo
ooooool00?lDooooo`05ool00?l00?ooooooooooool00?l05?ooool01?l00?ooooooooooool00?lD
ooooo`04o`00ooooooooooooo`00oaCooooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00
oooo003oooooooooool00?l05?ooool01?l00?ooooooooooool00?lDooooo`04o`00oooooooooooo
o`00oaCooooo00Co003ooooooooooooo003o5?ooool01Ol00?ooo`00oooooooooooo003o01Cooooo
00Co003ooooooooooooo003o5?ooool00ol00?ooooooool0000Looooo`008Oooool00ol0003ooooo
ooooo`02ooooo`04o`00ooooooooooooo`00oaCooooo00Co003ooooooooooooo003o5?ooool01Ooo
003o003ooooooooo003o003o01Cooooo00Co003ooooooooooooo003o5?ooool01?l00?oooooooooo
ool00?lDooooo`05o`00ooooooooooooooooool00?l04oooool01Ol00?ooo`00oooooooooooo003o
01Cooooo00Co003ooooooooooooo003o5?ooool01?l00?ooooooooooool00?lDooooo`04o`00oooo
ooooooooo`00oaGooooo00Co003ooooooooooooo003o5?ooool01?l00?ooooooooooool00?lDoooo
o`03o`00ooooooooo`0001cooooo000Qooooo`03o`000?oooooooooo00;ooooo00Co003ooooooooo
oooo003o5?ooool01?l00?ooooooooooool00?lEooooo`04o`00ooooooooo`00o`00oaCooooo00Co
003ooooooooooooo003o5?ooool01?l00?ooooooooooool00?lDooooo`04o`00oooo003oooooo`00
oaGooooo00Co003ooooooooooooo003o5?ooool01?l00?ooooooooooool00?lDooooo`04o`00oooo
ooooooooo`00oaCooooo00Co003oool00?oooooo003o5Oooool01?l00?ooooooooooool00?lDoooo
o`04o`00ooooooooooooo`00oaCooooo00?o003ooooooooo00007?ooool0027ooooo00?o0000oooo
ooooool00_ooool01?l00?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00oaGooooo00?o
003oooooool00?l05Oooool01?l00?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00oaCo
oooo00Co003oool00?oooooo003o5Oooool01?l00?ooooooooooool00?lDooooo`04o`00oooooooo
ooooo`00oaCooooo00Co003ooooooooooooo003o5?ooool01?l00?ooo`00ooooool00?lEooooo`04
o`00ooooooooooooo`00oaCooooo00Co003ooooooooooooo003o5Oooool00ol00?ooo`00ooooo`0K
ooooo`008Oooool00ol0003oooooooooo`02ooooo`04o`00ooooooooo`00o`00oaCooooo00Co003o
ool00?oooooo003o5Oooool00ol00?ooooooo`00o`0Eooooo`04o`00ooooooooo`00o`00oaCooooo
00Co003ooooooooooooo003o5Oooool00ol00?ooooooo`00o`0Eooooo`03o`00oooooooo003o01Go
oooo00Co003ooooooooooooo003o5?ooool01?l00?ooooooooooool00?lEooooo`03o`00oooooooo
003o01Gooooo00Co003ooooooooooooo003o5?ooool01?l00?ooooooool00?l00?lEooooo`03o`00
oooo003ooooo01_ooooo000Qooooo`03o`000?oooooooooo00;ooooo00?o003oooooool00?l05_oo
ool00ol00?ooooooo`00o`0Eooooo`03o`00oooooooo003o01Gooooo00?o003oooooool00?l05Ooo
ool01?l00?ooooooooooool00?lEooooo`03o`00oooooooo003o01Gooooo00?o003oooooool00?l0
5Oooool00ol00?ooooooo`00o`0Fooooo`03o`00oooooooo003o01Gooooo00?o003oooooool00?l0
5Oooool00ol00?ooooooo`00o`0Eooooo`04o`00ooooooooo`00o`00oaGooooo00?o003oool00?oo
ool06oooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
0_l00?lFooooo`03o`00oooooooo003o01Gooooo00?o003oooooool00?l05Oooool00ol00?oooooo
o`00o`0Fooooo`03o`00oooo003o003o01Gooooo00?o003oooooool00?l05Oooool00ol00?oooooo
o`00o`0Eooooo`03o`00oooooooo003o01Kooooo00?o003oool00?l00?l05Oooool00ol00?oooooo
o`00o`0Eooooo`03o`00oooooooo003o01Kooooo00?o003oool00?l00?l05Oooool00ol00?oooooo
ooooo`0Kooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0_l0
0?lFooooo`03o`00oooooooo003o01Gooooo00?o003oool00?l00?l05Oooool00ol00?ooooooo`00
o`0Fooooo`;o003o5_ooool00ol00?ooooooo`00o`0Eooooo`03o`00oooooooo003o01Kooooo0_l0
0?lFooooo`;o003o5_ooool00ol00?ooooooo`00o`0Eooooo`03o`00oooooooo003o01Kooooo0_l0
0?lFooooo`03o`00oooooooooooo01_ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool2o`00oaKooooo0_l00?lGooooo`;o003o5_ooool2o`00oaKooooo0_l00?lF
ooooo`;o003o5oooool2o`00oaKooooo0_l00?lFooooo`;o003o5oooool2o`00oaKooooo0_l00?lF
ooooo`;o003o5_ooool00ol00?ooooooooooo`0Kooooo`006_ooool00ol0003oooooooooo`04oooo
o`?o00000oooool2o`00oaOooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo01Kooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool2o`00oaOooooo00?o003ooooo
ooooool06_ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGo
oooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEE
ofIVI_l000001_ooool00ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo002Tooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool0
3_ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@2Oooooo`00YOooool01Ol0003ooooo
oooooooooooo000000;ooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omg
MgOo<S8booooo`2Nooooo`008?ooool00onj^[[o<S8booooo`22ooooo`05o`000?oooooooooooooo
ool000004_ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo09gooooo000Qooooo`03
o`000?oooooooooo087ooooo00Go0000ooooooooooooooooo`000002ooooo`Ko00002oooool00onH
V9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo09kooooo000Oooooo`05oiRHV?l@413o0000o`00
0?nYZJT0POooool01Ol0003oQhN7oooooonYZJWo000001Cooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<09oooooo000Oooooo`06o`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj
Ooooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`2Qooooo`007oooool01_lb<S;ok^k^oiRHV?mEEEGogMgMoa0@49Ko
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo0:7ooooo000Oooooo`07
okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c02Eooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?oo
ool4o`000:3ooooo000Oooooo`07onk^k_l0003oooooo`000?ooooooIVIVohN7Q`3ooooood?ooooo
000Oooooo`04ofIVI_nHV9Sooooooc8b<P;o^[Zj00?o0000ooooooooool0oooooom1ooooo`008_oo
ool00omVIVKoQhN7ooooo`3oooooodCooooo000Rooooo`03ojVYZOm4A4Cooooo0?ooooooA?ooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.179101, -1.08612, \
0.0066032, 0.0136036}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The match between the approximate (dashed) and exact (solid) eigenmodes is \
very accurate for the lowest modes, but begins to break down for the \
higher-order modes with variation approaching the scale of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "\tWe can now use these eigenvalues and eigenvectors to solve any \
initial-value problem that has the above boundary conditions, using the \
general solution of the heat equation. For instance, if we choose ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, 0)\  = \ x\^3\ \((\[Pi] - x)\)\^3\)]],
  ",  we can determine the subsequent temperature evolution as shown in Cell \
",
  ButtonBox["6.141",
    ButtonData:>"Cell 6.141",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox[\( (*\ define\ the\ initial\ condition\ *) \),
        FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
      RowBox[{\(T0[x_]\  = \ x^3 \((Pi - x)\)^3;\), "\[IndentingNewLine]", 
        StyleBox[\( (*\ 
            determine\ the\ Fourier\ coefficients\ as\ inner\ products\ over\ \
the\ initial\ condition*) \),
          FontColor->RGBColor[1, 0, 0]], 
        "\[IndentingNewLine]", \(A[n_]\  := \ \(A[n]\  = \ 
              NIntegrate[T0[x]\ \(\[Psi][n]\)[x], {x, 0, Pi/2}, 
                  MaxRecursion \[Rule] 20]/
                NIntegrate[\((\(\[Psi][n]\)[x])\)^2, {x, 0, Pi/2}, 
                  MaxRecursion \[Rule] 20]\);\), "\n", 
        "\[IndentingNewLine]", \(T[x_, t_]\  = \ 
            Sum[A[n]\ Exp[\[Lambda]1[\([n]\)]\ t]\ \(\[Psi][n]\)[x], {n, 1, 
                8}];\), "\n", 
        "\[IndentingNewLine]", \(Table[
            Plot[T[x, t], {x, 0, Pi/2}, PlotRange \[Rule] {0, 15}, 
              AxesLabel \[Rule] {"\<x\>", "\<\>"}, 
              PlotLabel -> "\<T[x,\>" <> ToString[t] <> "\<]\>"], {t, 0, 
              1,  .05}];\)}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.141"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0 0.0412023 [
[.17539 -0.0125 -12 -9 ]
[.17539 -0.0125 12 0 ]
[.32696 -0.0125 -9 -9 ]
[.32696 -0.0125 9 0 ]
[.47854 -0.0125 -12 -9 ]
[.47854 -0.0125 12 0 ]
[.63011 -0.0125 -3 -9 ]
[.63011 -0.0125 3 0 ]
[.78169 -0.0125 -12 -9 ]
[.78169 -0.0125 12 0 ]
[.93327 -0.0125 -9 -9 ]
[.93327 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .0824 -6 -4.5 ]
[.01131 .0824 0 4.5 ]
[.01131 .16481 -6 -4.5 ]
[.01131 .16481 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .32962 -6 -4.5 ]
[.01131 .32962 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .49443 -12 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .57683 -12 -4.5 ]
[.01131 .57683 0 4.5 ]
[.5 .63053 -20 0 ]
[.5 .63053 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .00625 L
s
[(0.25)] .17539 -0.0125 0 1 Mshowa
.32696 0 m
.32696 .00625 L
s
[(0.5)] .32696 -0.0125 0 1 Mshowa
.47854 0 m
.47854 .00625 L
s
[(0.75)] .47854 -0.0125 0 1 Mshowa
.63011 0 m
.63011 .00625 L
s
[(1)] .63011 -0.0125 0 1 Mshowa
.78169 0 m
.78169 .00625 L
s
[(1.25)] .78169 -0.0125 0 1 Mshowa
.93327 0 m
.93327 .00625 L
s
[(1.5)] .93327 -0.0125 0 1 Mshowa
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75138 0 m
.75138 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0824 m
.03006 .0824 L
s
[(2)] .01131 .0824 1 0 Mshowa
.02381 .16481 m
.03006 .16481 L
s
[(4)] .01131 .16481 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(6)] .01131 .24721 1 0 Mshowa
.02381 .32962 m
.03006 .32962 L
s
[(8)] .01131 .32962 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(12)] .01131 .49443 1 0 Mshowa
.02381 .57683 m
.03006 .57683 L
s
[(14)] .01131 .57683 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02846 1e-05 L
.03279 3e-05 L
.03754 5e-05 L
.0402 6e-05 L
.04262 8e-05 L
.0475 .00012 L
.05281 .00019 L
.05782 .00027 L
.06244 .00037 L
.07218 .00066 L
.07771 .00088 L
.0829 .00113 L
.09334 .00177 L
.10458 .00268 L
.11468 .00372 L
.12571 .00513 L
.1458 .0085 L
.16548 .01288 L
.18645 .01883 L
.22803 .03474 L
.2681 .05539 L
.30665 .0801 L
.34765 .1113 L
.38714 .14567 L
.42511 .18215 L
.46554 .22388 L
.50444 .26601 L
.54581 .31192 L
.58565 .35625 L
.62398 .39811 L
.66476 .44085 L
.70403 .47935 L
.74178 .51314 L
.78198 .54489 L
.82067 .57071 L
.86181 .59251 L
.88234 .60106 L
.90143 .60755 L
.91986 .61246 L
.9293 .61444 L
.93954 .61619 L
.94431 .61686 L
.94935 .61747 L
.95402 .61794 L
s
.95402 .61794 m
.95519 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd07Oooool4o`000003oa0@4?oooooooooo01_ooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Eooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0[ooooo`00?Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool04oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46oooo
o`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool07_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`0Fooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo02[ooooo000mooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09
ooooo`03o`000?oooooooooo01;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo01;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00_ooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0:Oooool003gooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool04oooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool04oooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`0Nooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo01Kooooo00?o0000oooo
ooooool03_ooool00omgMgOo<S8booooo`0Zooooo`00?Oooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05?ooool01Ol0003ooooo
oooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
01oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Gooooo`03o`000?oooooooooo00_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00[ooooo`00?Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00ol0003oooooooooo`0Fooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWo
MgMgooooo`03ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo02gooooo000mooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool05_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool05_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0;Oooool003gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0001Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00005Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00007_ooool00omEEEGoIVIVo`00
000Oooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000
5_ooool00omEEEGoIVIVo`00000=ooooo`Co0000;?ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooDoooool2o`0000;ooooo0_l0000@ooooo`00oooooomCooooo`06onk^k_lQ8B7oQhN7okZj
^_l0003ogMgM4?ooool00?ooooooE?ooool01?oMgMgo0000oa0@4?o<c<`Aooooo`005oooooooo`00
037o00003?ooool01?o^k^ko8B4Qoa0@4?o^k^hAooooo`007_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo3Ol00006ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02oooool01?lQ8B7oMgMgogMgMolb<S8Aooooo`007_ooool00ol0003oooooooooo`0Loooo
o`Co00002oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool07Oooool2o`0000;ooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`0Pooooo`Ko
0000oooooolRooooo`007_ooool00ol0003oooooooooo`0Vooooo`Go0000oooooolMooooo`007_oo
ool00ol0003oooooooooo`0[ooooo`?o0000oooooolJooooo`007_ooool2o`0002oooooo0ol0003o
oooooaOooooo000Nooooo`03o`000?oooooooooo037ooooo0ol0003ooooooaCooooo000Nooooo`03
o`000?oooooooooo03Cooooo0_l0003ooooooa;ooooo000Nooooo`03o`000?oooooooooo03Kooooo
0_l0003ooooooa3ooooo000Nooooo`03o`000?oooooooooo03Sooooo0ol0003oooooo`gooooo000N
ooooo`03o`000?oooooooooo03_ooooo0_l0003oooooo`_ooooo000Nooooo`03o`000?oooooooooo
03gooooo0_l0003oooooo`Wooooo000Nooooo`;o0000@?ooool2o`000?oooooo1oooool001kooooo
00?o0000ooooooooool0@Oooool2o`000?oooooo1Oooool001kooooo00?o0000ooooooooool0@ooo
ool2o`000?oooooo0oooool001kooooo00?o0000ooooooooool0AOooool2o`000?oooooo0Oooool0
01kooooo00?o0000ooooooooool0Aoooool2o`000?kooooo000Nooooo`03o`000?oooooooooo04Wo
oooo0_l0003looooo`007_ooool2o`0004cooooo00?o0000ooooooooool0nOooool001kooooo00?o
0000ooooooooool0C?ooool2o`000?Wooooo000Nooooo`03o`000?oooooooooo04kooooo0_l0003g
ooooo`007_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo0?Cooooo000Cooooo`Go
00001_ooool00ol0003oooooooooo`1Aooooo`;o0000m?ooool001?ooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A006ooooo`03o`000?oooooooooo05?ooooo0_l0003booooo`005?ooool00onHV9So8B4Q
onk^kP07ooooo`?o0000EOooool00ol0003oooooooooo`3_ooooo`005Oooool00onHV9So8B4Qonk^
kP06ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0k_ooool001Kooooo00?oMgMg
ofIVI_ooool01Oooool00ol0003oooooooooo`1Gooooo`;o0000k_ooool001Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo0>_ooooo000Cooooo`05
o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo
0>[ooooo000Cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Koooo
o`03o`000?oooooooooo0>Wooooo000Nooooo`;o0000GOooool2o`000>Wooooo000Nooooo`03o`00
0?oooooooooo05kooooo00?o0000ooooooooool0i_ooool001kooooo00?o0000ooooooooool0Gooo
ool00ol0003oooooooooo`3Uooooo`007_ooool00ol0003oooooooooo`1Pooooo`;o0000iOooool0
01kooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`3Rooooo`007_ooool00ol0003o
ooooooooo`1Sooooo`03o`000?oooooooooo0>7ooooo000Nooooo`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool0h?ooool001kooooo0_l0001Vooooo`03o`000?oooooooooo0=oooooo000N
ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0g_ooool001kooooo00?o0000oooo
ooooool0Ioooool00ol0003oooooooooo`3Mooooo`007_ooool00ol0003oooooooooo`1Xooooo`03
o`000?oooooooooo0=cooooo000Nooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0
foooool001kooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`3Jooooo`007_ooool2
o`0006cooooo0_l0003Jooooo`007_ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
0=Oooooo000Nooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0e_ooool001kooooo
00?o0000ooooooooool0Koooool00ol0003oooooooooo`3Eooooo`005Oooool2o`000003oa0@4?oo
oooooooo00Cooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`3Dooooo`005_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0doooool0
01?ooooo1Ol00006ooooo`?o0000L_ooool00ol0003oooooooooo`3Booooo`004oooool01?m4A4Co
gMgMooooool00007ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0dOooool001?o
oooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo
0=3ooooo000Dooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0MOooool00ol0003o
ooooooooo`3?ooooo`005?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo07Kooooo
00?o0000ooooooooool0c_ooool001Gooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooooooo
o`1gooooo`03o`000?oooooooooo0<gooooo000Nooooo`;o0000N?ooool00ol0003oooooooooo`3=
ooooo`007_ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo0<cooooo000Nooooo`03
o`000?oooooooooo07Wooooo00?o0000ooooooooool0boooool001kooooo00?o0000ooooooooool0
N_ooool00ol0003oooooooooo`3:ooooo`007_ooool00ol0003oooooooooo`1kooooo`03o`000?oo
oooooooo0<Wooooo000Nooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0b?ooool0
01kooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`37ooooo`007_ooool2o`0007oo
oooo00?o0000ooooooooool0a_ooool001kooooo00?o0000ooooooooool0Ooooool00ol0003ooooo
ooooo`35ooooo`007_ooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo0<Cooooo000N
ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0`oooool001kooooo00?o0000oooo
ooooool0P_ooool00ol0003oooooooooo`32ooooo`007_ooool00ol0003oooooooooo`23ooooo`03
o`000?oooooooooo0<7ooooo000Nooooo`;o0000Q?ooool00ol0003oooooooooo`31ooooo`007_oo
ool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo0<3ooooo000Nooooo`03o`000?oooooo
oooo08Gooooo00?o0000ooooooooool0_oooool001kooooo00?o0000ooooooooool0Q_ooool00ol0
003oooooooooo`2nooooo`004oooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool0Qoooool00ol0003oooooooooo`2mooooo`004oooool01OmEEEGoMgMgoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`2looooo`004oooool01Ol0003o
oooooooooooooooo000000Kooooo0ol00029ooooo`03o`000?oooooooooo0;_ooooo000Cooooo`05
o`000?nHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo
0;[ooooo000Cooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2;oooo
o`03o`000?oooooooooo0;Wooooo000Cooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000oooooooo
ool0S?ooool00ol0003oooooooooo`2hooooo`004oooool00ooMgMgo410@oiRHV008ooooo`03o`00
0?oooooooooo08gooooo00?o0000ooooooooool0]oooool001Cooooo00Coc<c<odA4A?l0003o410@
1_ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo0;Kooooo000Nooooo`;o0000T?oo
ool00ol0003oooooooooo`2eooooo`007_ooool00ol0003oooooooooo`2?ooooo`03o`000?oooooo
oooo0;Gooooo000Nooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0]?ooool001ko
oooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`2cooooo`007_ooool00ol0003ooooo
ooooo`2Booooo`03o`000?oooooooooo0;;ooooo000Nooooo`03o`000?oooooooooo09?ooooo00?o
0000ooooooooool0/Oooool001kooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`2`
ooooo`007_ooool2o`0009Kooooo00?o0000ooooooooool0[oooool001kooooo00?o0000oooooooo
ool0U_ooool00ol0003oooooooooo`2^ooooo`007_ooool00ol0003oooooooooo`2Gooooo`03o`00
0?oooooooooo0:gooooo000Nooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool0[?oo
ool001kooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`2[ooooo`007_ooool00ol0
003oooooooooo`2Jooooo`03o`000?oooooooooo0:[ooooo000Nooooo`;o0000W?ooool00ol0003o
ooooooooo`2Yooooo`007_ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo0:Sooooo
000Nooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool0Z?ooool001kooooo00?o0000
ooooooooool0WOooool00ol0003oooooooooo`2Wooooo`004oooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`2Vooooo`004oooool01OlQ
8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`2U
ooooo`004oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0002Pooooo`03o`000?oooooo
oooo0:Cooooo000Cooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`2Q
ooooo`03o`000?oooooooooo0:?ooooo000Cooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool0
0ol0003oooooooooo`2Rooooo`03o`000?oooooooooo0:;ooooo000Cooooo`05oa0@4?nj^[[ooooo
okZj^_l@41001_ooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo0:7ooooo000Coooo
o`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`2Tooooo`03o`000?oooooo
oooo0:3ooooo000Cooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`2U
ooooo`03o`000?oooooooooo09oooooo000Nooooo`;o0000Yoooool00ol0003oooooooooo`2Noooo
o`007_ooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo09gooooo000Nooooo`03o`00
0?oooooooooo0:Sooooo00?o0000ooooooooool0W?ooool001kooooo00?o0000ooooooooool0Z?oo
ool00ol0003oooooooooo`2Looooo`007_ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo
oooo09_ooooo000Nooooo`03o`000?oooooooooo0:[ooooo00?o0000ooooooooool0V_ooool001ko
oooo00?o0000ooooooooool0Zoooool00ol0003oooooooooo`2Iooooo`007_ooool2o`000:gooooo
00?o0000ooooooooool0V?ooool001kooooo00?o0000ooooooooool0[Oooool00ol0003ooooooooo
o`2Gooooo`007_ooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo09Kooooo000Noooo
o`03o`000?oooooooooo0:kooooo00?o0000ooooooooool0U_ooool001kooooo00?o0000oooooooo
ool0[oooool00ol0003oooooooooo`2Eooooo`007_ooool00ol0003oooooooooo`2`ooooo`03o`00
0?oooooooooo09Cooooo000Nooooo`;o0000/_ooool00ol0003oooooooooo`2Cooooo`007_ooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo09;ooooo000Nooooo`03o`000?oooooooooo
0;?ooooo00?o0000ooooooooool0TOooool001kooooo00?o0000ooooooooool0]?ooool00ol0003o
ooooooooo`2@ooooo`003?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6
ooooo`03o`000?oooooooooo0;Gooooo00?o0000ooooooooool0Soooool000kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0]_ooool0
0ol0003oooooooooo`2>ooooo`003_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41001_ooool3o`000;Oooooo00?o0000ooooooooool0SOooool000kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0^?ooool0
0ol0003oooooooooo`2<ooooo`003_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`2iooooo`03o`000?oooooooooo08_ooooo000>oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool0R_ooool000kooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`29
ooooo`003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool0
0ol0003oooooooooo`2looooo`03o`000?oooooooooo08Sooooo000Nooooo`;o0000__ooool00ol0
003oooooooooo`27ooooo`007_ooool00ol0003oooooooooo`2nooooo`03o`000?oooooooooo08Ko
oooo000Nooooo`03o`000?oooooooooo0;oooooo00?o0000ooooooooool0QOooool001kooooo00?o
0000ooooooooool0`?ooool00ol0003oooooooooo`24ooooo`007_ooool00ol0003oooooooooo`31
ooooo`03o`000?oooooooooo08?ooooo000Nooooo`03o`000?oooooooooo0<;ooooo00?o0000oooo
ooooool0P_ooool001kooooo00?o0000ooooooooool0`oooool00ol0003oooooooooo`21ooooo`00
7_ooool2o`000<Gooooo00?o0000ooooooooool0P?ooool001kooooo00?o0000ooooooooool0aOoo
ool00ol0003oooooooooo`1oooooo`007_ooool00ol0003oooooooooo`36ooooo`03o`000?oooooo
oooo07kooooo000Nooooo`03o`000?oooooooooo0<Oooooo00?o0000ooooooooool0OOooool001ko
oooo00?o0000ooooooooool0b?ooool00ol0003oooooooooo`1looooo`007_ooool00ol0003ooooo
ooooo`39ooooo`03o`000?oooooooooo07_ooooo000Nooooo`;o0000boooool00ol0003ooooooooo
o`1jooooo`007_ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo07Wooooo000Noooo
o`03o`000?oooooooooo0<cooooo0_l0001iooooo`007_ooool00ol0003oooooooooo`3>ooooo`03
o`000?oooooooooo07Kooooo000<ooooo`Co000000?o410@ooooooooool01Ol00006ooooo`03o`00
0?oooooooooo0<oooooo00?o0000ooooooooool0MOooool000kooooo00?o0000ooooooooool00_oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0d?ooool00ol0003ooooo
ooooo`1dooooo`003_ooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0
003Aooooo`03o`000?oooooooooo07?ooooo000>ooooo`03o`000?oooooooooo00Cooooo00?oV9RH
ob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3Booooo`03o`000?oooooooooo07;ooooo000>oooo
o`03o`000?oooooooooo00Gooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3Coooo
o`03o`000?oooooooooo077ooooo000>ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3Dooooo`03o`000?oooooooooo073ooooo000>ooooo`03o`00
0?oooooooooo00;ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0=Go
oooo00?o0000ooooooooool0Koooool000cooooo00?oEEEEofIVI_l000001?ooool01OnHV9So410@
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0e_ooool00ol0003oooooooooo`1^ooooo`00
7_ooool2o`000=Sooooo0_l0001^ooooo`007_ooool00ol0003oooooooooo`3Iooooo`03o`000?oo
oooooooo06_ooooo000Nooooo`03o`000?oooooooooo0=[ooooo00?o0000ooooooooool0J_ooool0
01kooooo00?o0000ooooooooool0foooool00ol0003oooooooooo`1Yooooo`007_ooool00ol0003o
ooooooooo`3Looooo`03o`000?oooooooooo06Sooooo000Nooooo`03o`000?oooooooooo0=gooooo
0_l0001Xooooo`007_ooool00ol0003oooooooooo`3Oooooo`03o`000?oooooooooo06Gooooo000N
ooooo`;o0000hOooool00ol0003oooooooooo`1Tooooo`007_ooool00ol0003oooooooooo`3Qoooo
o`03o`000?oooooooooo06?ooooo000Nooooo`03o`000?oooooooooo0>;ooooo00?o0000oooooooo
ool0H_ooool001kooooo00?o0000ooooooooool0hoooool2o`0006;ooooo000Nooooo`03o`000?oo
oooooooo0>Gooooo0_l0001Pooooo`007_ooool00ol0003oooooooooo`3Wooooo`03o`000?oooooo
oooo05gooooo000Nooooo`;o0000jOooool2o`0005gooooo000Nooooo`03o`000?oooooooooo0>[o
oooo0_l0001Kooooo`007_ooool00ol0003oooooooooo`3/ooooo`03o`000?oooooooooo05Sooooo
000Nooooo`03o`000?oooooooooo0>gooooo0_l0001Hooooo`003?ooool4o`000003oa0@4?oooooo
oooo00;ooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0>oooooo0_l0001F
ooooo`003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0lOooool2o`0005Cooooo000>ooooo`03o`000?oooooooooo00;ooooo1Ol00006ooooo`?o
0000loooool2o`0005;ooooo000>ooooo`03o`000?oooooooooo00;ooooo00CoA4A4omgMgOoooooo
00001oooool00ol0003oooooooooo`3eooooo`;o0000D?ooool000kooooo00?o0000ooooooooool0
0_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0?Oooooo00?o0000oooooooo
ool0COooool000kooooo00?o0000ooooooooool00oooool00omgMgOoc<c<o`000007ooooo`03o`00
0?oooooooooo0?Sooooo0_l0001=ooooo`003_ooool00ol0003oooooooooo`03ooooo`03onk^k_m4
A4Co000000Oooooo00?o0000ooooooooool0n_ooool2o`0004_ooooo000<ooooo`03oeEEEOmVIVKo
000000Kooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3looooo`;o0000BOooool0
01kooooo0_l0003oooooo`;o0000Aoooool001kooooo00?o0000ooooooooool0ooooool1ooooo`;o
0000AOooool001kooooo00?o0000ooooooooool0ooooool3ooooo`?o0000@_ooool001kooooo00?o
0000ooooooooool0ooooool6ooooo`?o0000?oooool001kooooo00?o0000ooooooooool0ooooool9
ooooo`Co0000>oooool001kooooo00?o0000ooooooooool0ooooool=ooooo`Co0000=oooool001ko
oooo00?o0000ooooooooool0oooooolAooooo`Ko0000<Oooool001kooooo00?o0000ooooooooool0
oooooolGooooo`?o0000;_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00:Cooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0
002Vooooo`00Y?ooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`2T
ooooo`00VOooool01Ol@413o0000o`000?l0003o410@00Kooooo00Co0000oooooooooooooooo0_l0
0002ooooo`;o00000oooool00on7QhOo0000okZj^P03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool00ol0003oooooooooo`2Tooooo`00Voooool00ol0003oooooooooo`06ooooo`0:o`000?oo
ooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0Y?ooool009_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0[ooooo00Go
410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0:Cooooo002Kooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h:ooooo`05o`00
0?ooooooooooooooool000001Oooool00ol0003oooooooooo`2Tooooo`00Voooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2_ooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooooooool0Y?ooool009Sooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2
o`0000Wooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0:Cooooo002H
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2Tooooo`00V?oo
ool7o`0000Gooooo0_l0000Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool2o`000:Kooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.167107, -1.20328, \
0.00679425, 0.0999796}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0 0.0412023 [
[.17539 -0.0125 -12 -9 ]
[.17539 -0.0125 12 0 ]
[.32696 -0.0125 -9 -9 ]
[.32696 -0.0125 9 0 ]
[.47854 -0.0125 -12 -9 ]
[.47854 -0.0125 12 0 ]
[.63011 -0.0125 -3 -9 ]
[.63011 -0.0125 3 0 ]
[.78169 -0.0125 -12 -9 ]
[.78169 -0.0125 12 0 ]
[.93327 -0.0125 -9 -9 ]
[.93327 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .0824 -6 -4.5 ]
[.01131 .0824 0 4.5 ]
[.01131 .16481 -6 -4.5 ]
[.01131 .16481 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .32962 -6 -4.5 ]
[.01131 .32962 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .49443 -12 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .57683 -12 -4.5 ]
[.01131 .57683 0 4.5 ]
[.5 .63053 -29 0 ]
[.5 .63053 29 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .00625 L
s
[(0.25)] .17539 -0.0125 0 1 Mshowa
.32696 0 m
.32696 .00625 L
s
[(0.5)] .32696 -0.0125 0 1 Mshowa
.47854 0 m
.47854 .00625 L
s
[(0.75)] .47854 -0.0125 0 1 Mshowa
.63011 0 m
.63011 .00625 L
s
[(1)] .63011 -0.0125 0 1 Mshowa
.78169 0 m
.78169 .00625 L
s
[(1.25)] .78169 -0.0125 0 1 Mshowa
.93327 0 m
.93327 .00625 L
s
[(1.5)] .93327 -0.0125 0 1 Mshowa
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75138 0 m
.75138 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0824 m
.03006 .0824 L
s
[(2)] .01131 .0824 1 0 Mshowa
.02381 .16481 m
.03006 .16481 L
s
[(4)] .01131 .16481 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(6)] .01131 .24721 1 0 Mshowa
.02381 .32962 m
.03006 .32962 L
s
[(8)] .01131 .32962 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(12)] .01131 .49443 1 0 Mshowa
.02381 .57683 m
.03006 .57683 L
s
[(14)] .01131 .57683 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.000 13.000 moveto
(D) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .01222 L
.10458 .02626 L
.14415 .04074 L
.18221 .05637 L
.22272 .07524 L
.26171 .09587 L
.30316 .12061 L
.34309 .14717 L
.3815 .17508 L
.42237 .20701 L
.46172 .23953 L
.49955 .27195 L
.53984 .30714 L
.57861 .34103 L
.61984 .37638 L
.65954 .40907 L
.69774 .4386 L
.73838 .46735 L
.77751 .49182 L
.81909 .51382 L
.85916 .53064 L
.89771 .54243 L
.91765 .54675 L
.92782 .54848 L
.93871 .54997 L
.94392 .55055 L
.94885 .55102 L
.95365 .5514 L
.9581 .55169 L
.9623 .5519 L
.96676 .55207 L
.96907 .55213 L
.97124 .55217 L
.97249 .55219 L
.97362 .5522 L
.97487 .55221 L
.97619 .55221 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0 0.0412023 [
[.17539 -0.0125 -12 -9 ]
[.17539 -0.0125 12 0 ]
[.32696 -0.0125 -9 -9 ]
[.32696 -0.0125 9 0 ]
[.47854 -0.0125 -12 -9 ]
[.47854 -0.0125 12 0 ]
[.63011 -0.0125 -3 -9 ]
[.63011 -0.0125 3 0 ]
[.78169 -0.0125 -12 -9 ]
[.78169 -0.0125 12 0 ]
[.93327 -0.0125 -9 -9 ]
[.93327 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .0824 -6 -4.5 ]
[.01131 .0824 0 4.5 ]
[.01131 .16481 -6 -4.5 ]
[.01131 .16481 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .32962 -6 -4.5 ]
[.01131 .32962 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .49443 -12 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .57683 -12 -4.5 ]
[.01131 .57683 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .00625 L
s
[(0.25)] .17539 -0.0125 0 1 Mshowa
.32696 0 m
.32696 .00625 L
s
[(0.5)] .32696 -0.0125 0 1 Mshowa
.47854 0 m
.47854 .00625 L
s
[(0.75)] .47854 -0.0125 0 1 Mshowa
.63011 0 m
.63011 .00625 L
s
[(1)] .63011 -0.0125 0 1 Mshowa
.78169 0 m
.78169 .00625 L
s
[(1.25)] .78169 -0.0125 0 1 Mshowa
.93327 0 m
.93327 .00625 L
s
[(1.5)] .93327 -0.0125 0 1 Mshowa
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75138 0 m
.75138 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0824 m
.03006 .0824 L
s
[(2)] .01131 .0824 1 0 Mshowa
.02381 .16481 m
.03006 .16481 L
s
[(4)] .01131 .16481 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(6)] .01131 .24721 1 0 Mshowa
.02381 .32962 m
.03006 .32962 L
s
[(8)] .01131 .32962 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(12)] .01131 .49443 1 0 Mshowa
.02381 .57683 m
.03006 .57683 L
s
[(14)] .01131 .57683 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .01756 L
.10458 .03706 L
.14415 .05602 L
.18221 .0751 L
.22272 .09654 L
.26171 .11841 L
.30316 .14306 L
.34309 .16817 L
.3815 .19349 L
.42237 .2215 L
.46172 .24924 L
.49955 .27633 L
.53984 .30527 L
.57861 .33278 L
.61984 .36119 L
.65954 .38727 L
.69774 .4107 L
.73838 .43341 L
.77751 .45269 L
.81909 .46998 L
.85916 .48318 L
.89771 .49242 L
.91765 .49581 L
.92782 .49716 L
.93871 .49833 L
.94392 .49879 L
.94885 .49915 L
.95365 .49945 L
.9581 .49968 L
.9623 .49985 L
.96676 .49998 L
.96907 .50003 L
.97124 .50006 L
.97249 .50007 L
.97362 .50008 L
.97487 .50009 L
.97619 .50009 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0 0.0412023 [
[.17539 -0.0125 -12 -9 ]
[.17539 -0.0125 12 0 ]
[.32696 -0.0125 -9 -9 ]
[.32696 -0.0125 9 0 ]
[.47854 -0.0125 -12 -9 ]
[.47854 -0.0125 12 0 ]
[.63011 -0.0125 -3 -9 ]
[.63011 -0.0125 3 0 ]
[.78169 -0.0125 -12 -9 ]
[.78169 -0.0125 12 0 ]
[.93327 -0.0125 -9 -9 ]
[.93327 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .0824 -6 -4.5 ]
[.01131 .0824 0 4.5 ]
[.01131 .16481 -6 -4.5 ]
[.01131 .16481 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .32962 -6 -4.5 ]
[.01131 .32962 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .49443 -12 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .57683 -12 -4.5 ]
[.01131 .57683 0 4.5 ]
[.5 .63053 -29 0 ]
[.5 .63053 29 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .00625 L
s
[(0.25)] .17539 -0.0125 0 1 Mshowa
.32696 0 m
.32696 .00625 L
s
[(0.5)] .32696 -0.0125 0 1 Mshowa
.47854 0 m
.47854 .00625 L
s
[(0.75)] .47854 -0.0125 0 1 Mshowa
.63011 0 m
.63011 .00625 L
s
[(1)] .63011 -0.0125 0 1 Mshowa
.78169 0 m
.78169 .00625 L
s
[(1.25)] .78169 -0.0125 0 1 Mshowa
.93327 0 m
.93327 .00625 L
s
[(1.5)] .93327 -0.0125 0 1 Mshowa
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75138 0 m
.75138 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0824 m
.03006 .0824 L
s
[(2)] .01131 .0824 1 0 Mshowa
.02381 .16481 m
.03006 .16481 L
s
[(4)] .01131 .16481 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(6)] .01131 .24721 1 0 Mshowa
.02381 .32962 m
.03006 .32962 L
s
[(8)] .01131 .32962 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(12)] .01131 .49443 1 0 Mshowa
.02381 .57683 m
.03006 .57683 L
s
[(14)] .01131 .57683 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.000 13.000 moveto
(D) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .0202 L
.10458 .0424 L
.14415 .06356 L
.18221 .08431 L
.22272 .10692 L
.26171 .12925 L
.30316 .1536 L
.34309 .17763 L
.3815 .20118 L
.42237 .22657 L
.46172 .25115 L
.49955 .27471 L
.53984 .29944 L
.57861 .32263 L
.61984 .34629 L
.65954 .36778 L
.69774 .38694 L
.73838 .40538 L
.77751 .42095 L
.81909 .43486 L
.85916 .44544 L
.89771 .45283 L
.91765 .45554 L
.92769 .45661 L
.93871 .45755 L
.94818 .45817 L
.9568 .45858 L
.96157 .45874 L
.96409 .45881 L
.96676 .45886 L
.96909 .4589 L
.97041 .45892 L
.97166 .45893 L
.9728 .45894 L
.97384 .45895 L
.97498 .45895 L
.97619 .45895 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0 0.0412023 [
[.17539 -0.0125 -12 -9 ]
[.17539 -0.0125 12 0 ]
[.32696 -0.0125 -9 -9 ]
[.32696 -0.0125 9 0 ]
[.47854 -0.0125 -12 -9 ]
[.47854 -0.0125 12 0 ]
[.63011 -0.0125 -3 -9 ]
[.63011 -0.0125 3 0 ]
[.78169 -0.0125 -12 -9 ]
[.78169 -0.0125 12 0 ]
[.93327 -0.0125 -9 -9 ]
[.93327 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .0824 -6 -4.5 ]
[.01131 .0824 0 4.5 ]
[.01131 .16481 -6 -4.5 ]
[.01131 .16481 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .32962 -6 -4.5 ]
[.01131 .32962 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .49443 -12 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .57683 -12 -4.5 ]
[.01131 .57683 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .00625 L
s
[(0.25)] .17539 -0.0125 0 1 Mshowa
.32696 0 m
.32696 .00625 L
s
[(0.5)] .32696 -0.0125 0 1 Mshowa
.47854 0 m
.47854 .00625 L
s
[(0.75)] .47854 -0.0125 0 1 Mshowa
.63011 0 m
.63011 .00625 L
s
[(1)] .63011 -0.0125 0 1 Mshowa
.78169 0 m
.78169 .00625 L
s
[(1.25)] .78169 -0.0125 0 1 Mshowa
.93327 0 m
.93327 .00625 L
s
[(1.5)] .93327 -0.0125 0 1 Mshowa
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75138 0 m
.75138 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0824 m
.03006 .0824 L
s
[(2)] .01131 .0824 1 0 Mshowa
.02381 .16481 m
.03006 .16481 L
s
[(4)] .01131 .16481 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(6)] .01131 .24721 1 0 Mshowa
.02381 .32962 m
.03006 .32962 L
s
[(8)] .01131 .32962 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(12)] .01131 .49443 1 0 Mshowa
.02381 .57683 m
.03006 .57683 L
s
[(14)] .01131 .57683 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .02138 L
.10458 .04475 L
.14415 .06682 L
.18221 .08819 L
.22272 .11111 L
.26171 .13333 L
.30316 .15712 L
.34309 .18012 L
.3815 .20225 L
.42237 .22568 L
.46172 .24798 L
.49955 .26903 L
.53984 .29082 L
.57861 .31099 L
.61984 .33135 L
.65954 .34965 L
.69774 .36583 L
.73838 .3813 L
.77751 .39428 L
.81909 .40581 L
.85916 .41455 L
.89771 .42065 L
.91765 .42287 L
.92769 .42375 L
.93871 .42453 L
.94818 .42504 L
.9568 .42537 L
.96157 .4255 L
.96409 .42556 L
.96676 .42561 L
.96909 .42564 L
.97041 .42565 L
.97166 .42566 L
.9728 .42567 L
.97384 .42568 L
.97498 .42568 L
.97619 .42568 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0 0.0412023 [
[.17539 -0.0125 -12 -9 ]
[.17539 -0.0125 12 0 ]
[.32696 -0.0125 -9 -9 ]
[.32696 -0.0125 9 0 ]
[.47854 -0.0125 -12 -9 ]
[.47854 -0.0125 12 0 ]
[.63011 -0.0125 -3 -9 ]
[.63011 -0.0125 3 0 ]
[.78169 -0.0125 -12 -9 ]
[.78169 -0.0125 12 0 ]
[.93327 -0.0125 -9 -9 ]
[.93327 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .0824 -6 -4.5 ]
[.01131 .0824 0 4.5 ]
[.01131 .16481 -6 -4.5 ]
[.01131 .16481 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .32962 -6 -4.5 ]
[.01131 .32962 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .49443 -12 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .57683 -12 -4.5 ]
[.01131 .57683 0 4.5 ]
[.5 .63053 -29 0 ]
[.5 .63053 29 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .00625 L
s
[(0.25)] .17539 -0.0125 0 1 Mshowa
.32696 0 m
.32696 .00625 L
s
[(0.5)] .32696 -0.0125 0 1 Mshowa
.47854 0 m
.47854 .00625 L
s
[(0.75)] .47854 -0.0125 0 1 Mshowa
.63011 0 m
.63011 .00625 L
s
[(1)] .63011 -0.0125 0 1 Mshowa
.78169 0 m
.78169 .00625 L
s
[(1.25)] .78169 -0.0125 0 1 Mshowa
.93327 0 m
.93327 .00625 L
s
[(1.5)] .93327 -0.0125 0 1 Mshowa
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75138 0 m
.75138 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0824 m
.03006 .0824 L
s
[(2)] .01131 .0824 1 0 Mshowa
.02381 .16481 m
.03006 .16481 L
s
[(4)] .01131 .16481 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(6)] .01131 .24721 1 0 Mshowa
.02381 .32962 m
.03006 .32962 L
s
[(8)] .01131 .32962 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(12)] .01131 .49443 1 0 Mshowa
.02381 .57683 m
.03006 .57683 L
s
[(14)] .01131 .57683 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.000 13.000 moveto
(D) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .02169 L
.10458 .04535 L
.14415 .06757 L
.18221 .08892 L
.22272 .11162 L
.26171 .1334 L
.30316 .15642 L
.34309 .17842 L
.3815 .19932 L
.42237 .22116 L
.46172 .24171 L
.49955 .26087 L
.53984 .28051 L
.57861 .2985 L
.61984 .31649 L
.65954 .33252 L
.69774 .3466 L
.73838 .35997 L
.77751 .37113 L
.81909 .381 L
.85916 .38846 L
.89771 .39364 L
.91765 .39553 L
.92769 .39628 L
.93871 .39693 L
.94818 .39737 L
.9568 .39765 L
.96157 .39776 L
.96409 .39781 L
.96676 .39785 L
.96909 .39788 L
.97041 .39789 L
.97166 .3979 L
.9728 .3979 L
.97384 .39791 L
.97498 .39791 L
.97619 .39791 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0 0.0412023 [
[.17539 -0.0125 -12 -9 ]
[.17539 -0.0125 12 0 ]
[.32696 -0.0125 -9 -9 ]
[.32696 -0.0125 9 0 ]
[.47854 -0.0125 -12 -9 ]
[.47854 -0.0125 12 0 ]
[.63011 -0.0125 -3 -9 ]
[.63011 -0.0125 3 0 ]
[.78169 -0.0125 -12 -9 ]
[.78169 -0.0125 12 0 ]
[.93327 -0.0125 -9 -9 ]
[.93327 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .0824 -6 -4.5 ]
[.01131 .0824 0 4.5 ]
[.01131 .16481 -6 -4.5 ]
[.01131 .16481 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .32962 -6 -4.5 ]
[.01131 .32962 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .49443 -12 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .57683 -12 -4.5 ]
[.01131 .57683 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .00625 L
s
[(0.25)] .17539 -0.0125 0 1 Mshowa
.32696 0 m
.32696 .00625 L
s
[(0.5)] .32696 -0.0125 0 1 Mshowa
.47854 0 m
.47854 .00625 L
s
[(0.75)] .47854 -0.0125 0 1 Mshowa
.63011 0 m
.63011 .00625 L
s
[(1)] .63011 -0.0125 0 1 Mshowa
.78169 0 m
.78169 .00625 L
s
[(1.25)] .78169 -0.0125 0 1 Mshowa
.93327 0 m
.93327 .00625 L
s
[(1.5)] .93327 -0.0125 0 1 Mshowa
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75138 0 m
.75138 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0824 m
.03006 .0824 L
s
[(2)] .01131 .0824 1 0 Mshowa
.02381 .16481 m
.03006 .16481 L
s
[(4)] .01131 .16481 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(6)] .01131 .24721 1 0 Mshowa
.02381 .32962 m
.03006 .32962 L
s
[(8)] .01131 .32962 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(12)] .01131 .49443 1 0 Mshowa
.02381 .57683 m
.03006 .57683 L
s
[(14)] .01131 .57683 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .02149 L
.10458 .0449 L
.14415 .06681 L
.18221 .08777 L
.22272 .10994 L
.26171 .13106 L
.30316 .15323 L
.34309 .17422 L
.3815 .19401 L
.42237 .21452 L
.46172 .23364 L
.49955 .25133 L
.53984 .26931 L
.57861 .28567 L
.61984 .3019 L
.65954 .31628 L
.69774 .32882 L
.73838 .34068 L
.77751 .35053 L
.81909 .35922 L
.85916 .36575 L
.89771 .37029 L
.91765 .37194 L
.92769 .37259 L
.93871 .37317 L
.94818 .37354 L
.9568 .37379 L
.96157 .37389 L
.96409 .37393 L
.96676 .37397 L
.96909 .37399 L
.97041 .374 L
.97166 .37401 L
.9728 .37401 L
.97384 .37402 L
.97498 .37402 L
.97619 .37402 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0 0.0412023 [
[.17539 -0.0125 -12 -9 ]
[.17539 -0.0125 12 0 ]
[.32696 -0.0125 -9 -9 ]
[.32696 -0.0125 9 0 ]
[.47854 -0.0125 -12 -9 ]
[.47854 -0.0125 12 0 ]
[.63011 -0.0125 -3 -9 ]
[.63011 -0.0125 3 0 ]
[.78169 -0.0125 -12 -9 ]
[.78169 -0.0125 12 0 ]
[.93327 -0.0125 -9 -9 ]
[.93327 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .0824 -6 -4.5 ]
[.01131 .0824 0 4.5 ]
[.01131 .16481 -6 -4.5 ]
[.01131 .16481 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .32962 -6 -4.5 ]
[.01131 .32962 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .49443 -12 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .57683 -12 -4.5 ]
[.01131 .57683 0 4.5 ]
[.5 .63053 -29 0 ]
[.5 .63053 29 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .00625 L
s
[(0.25)] .17539 -0.0125 0 1 Mshowa
.32696 0 m
.32696 .00625 L
s
[(0.5)] .32696 -0.0125 0 1 Mshowa
.47854 0 m
.47854 .00625 L
s
[(0.75)] .47854 -0.0125 0 1 Mshowa
.63011 0 m
.63011 .00625 L
s
[(1)] .63011 -0.0125 0 1 Mshowa
.78169 0 m
.78169 .00625 L
s
[(1.25)] .78169 -0.0125 0 1 Mshowa
.93327 0 m
.93327 .00625 L
s
[(1.5)] .93327 -0.0125 0 1 Mshowa
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75138 0 m
.75138 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0824 m
.03006 .0824 L
s
[(2)] .01131 .0824 1 0 Mshowa
.02381 .16481 m
.03006 .16481 L
s
[(4)] .01131 .16481 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(6)] .01131 .24721 1 0 Mshowa
.02381 .32962 m
.03006 .32962 L
s
[(8)] .01131 .32962 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(12)] .01131 .49443 1 0 Mshowa
.02381 .57683 m
.03006 .57683 L
s
[(14)] .01131 .57683 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.000 13.000 moveto
(D) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .02099 L
.10458 .04383 L
.14415 .06516 L
.18221 .08552 L
.22272 .10697 L
.26171 .12733 L
.30316 .14858 L
.34309 .1686 L
.3815 .18736 L
.42237 .2067 L
.46172 .22462 L
.49955 .2411 L
.53984 .25777 L
.57861 .27284 L
.61984 .28772 L
.65954 .30084 L
.69774 .31223 L
.73838 .32296 L
.77751 .33185 L
.81909 .33965 L
.85916 .34552 L
.89771 .34958 L
.91765 .35105 L
.92769 .35164 L
.93871 .35215 L
.94818 .35249 L
.9568 .35271 L
.96157 .3528 L
.96409 .35283 L
.96676 .35286 L
.96909 .35289 L
.97041 .3529 L
.97166 .3529 L
.9728 .35291 L
.97384 .35291 L
.97498 .35291 L
.97619 .35291 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0 0.0412023 [
[.17539 -0.0125 -12 -9 ]
[.17539 -0.0125 12 0 ]
[.32696 -0.0125 -9 -9 ]
[.32696 -0.0125 9 0 ]
[.47854 -0.0125 -12 -9 ]
[.47854 -0.0125 12 0 ]
[.63011 -0.0125 -3 -9 ]
[.63011 -0.0125 3 0 ]
[.78169 -0.0125 -12 -9 ]
[.78169 -0.0125 12 0 ]
[.93327 -0.0125 -9 -9 ]
[.93327 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .0824 -6 -4.5 ]
[.01131 .0824 0 4.5 ]
[.01131 .16481 -6 -4.5 ]
[.01131 .16481 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .32962 -6 -4.5 ]
[.01131 .32962 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .49443 -12 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .57683 -12 -4.5 ]
[.01131 .57683 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .00625 L
s
[(0.25)] .17539 -0.0125 0 1 Mshowa
.32696 0 m
.32696 .00625 L
s
[(0.5)] .32696 -0.0125 0 1 Mshowa
.47854 0 m
.47854 .00625 L
s
[(0.75)] .47854 -0.0125 0 1 Mshowa
.63011 0 m
.63011 .00625 L
s
[(1)] .63011 -0.0125 0 1 Mshowa
.78169 0 m
.78169 .00625 L
s
[(1.25)] .78169 -0.0125 0 1 Mshowa
.93327 0 m
.93327 .00625 L
s
[(1.5)] .93327 -0.0125 0 1 Mshowa
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75138 0 m
.75138 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0824 m
.03006 .0824 L
s
[(2)] .01131 .0824 1 0 Mshowa
.02381 .16481 m
.03006 .16481 L
s
[(4)] .01131 .16481 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(6)] .01131 .24721 1 0 Mshowa
.02381 .32962 m
.03006 .32962 L
s
[(8)] .01131 .32962 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(12)] .01131 .49443 1 0 Mshowa
.02381 .57683 m
.03006 .57683 L
s
[(14)] .01131 .57683 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .02032 L
.10458 .0424 L
.14415 .06301 L
.18221 .08265 L
.22272 .10328 L
.26171 .12281 L
.30316 .14313 L
.34309 .16221 L
.3815 .18002 L
.42237 .1983 L
.46172 .21518 L
.49955 .23064 L
.53984 .24621 L
.57861 .26024 L
.61984 .27404 L
.65954 .28616 L
.69774 .29665 L
.73838 .30651 L
.77751 .31465 L
.81909 .32178 L
.85916 .32713 L
.89771 .33083 L
.91765 .33218 L
.92769 .33271 L
.93871 .33318 L
.94818 .33348 L
.9568 .33369 L
.96157 .33377 L
.96409 .3338 L
.96676 .33383 L
.96909 .33385 L
.97041 .33386 L
.97166 .33386 L
.9728 .33387 L
.97384 .33387 L
.97498 .33387 L
.97619 .33387 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0 0.0412023 [
[.17539 -0.0125 -12 -9 ]
[.17539 -0.0125 12 0 ]
[.32696 -0.0125 -9 -9 ]
[.32696 -0.0125 9 0 ]
[.47854 -0.0125 -12 -9 ]
[.47854 -0.0125 12 0 ]
[.63011 -0.0125 -3 -9 ]
[.63011 -0.0125 3 0 ]
[.78169 -0.0125 -12 -9 ]
[.78169 -0.0125 12 0 ]
[.93327 -0.0125 -9 -9 ]
[.93327 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .0824 -6 -4.5 ]
[.01131 .0824 0 4.5 ]
[.01131 .16481 -6 -4.5 ]
[.01131 .16481 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .32962 -6 -4.5 ]
[.01131 .32962 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .49443 -12 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .57683 -12 -4.5 ]
[.01131 .57683 0 4.5 ]
[.5 .63053 -29 0 ]
[.5 .63053 29 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .00625 L
s
[(0.25)] .17539 -0.0125 0 1 Mshowa
.32696 0 m
.32696 .00625 L
s
[(0.5)] .32696 -0.0125 0 1 Mshowa
.47854 0 m
.47854 .00625 L
s
[(0.75)] .47854 -0.0125 0 1 Mshowa
.63011 0 m
.63011 .00625 L
s
[(1)] .63011 -0.0125 0 1 Mshowa
.78169 0 m
.78169 .00625 L
s
[(1.25)] .78169 -0.0125 0 1 Mshowa
.93327 0 m
.93327 .00625 L
s
[(1.5)] .93327 -0.0125 0 1 Mshowa
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75138 0 m
.75138 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0824 m
.03006 .0824 L
s
[(2)] .01131 .0824 1 0 Mshowa
.02381 .16481 m
.03006 .16481 L
s
[(4)] .01131 .16481 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(6)] .01131 .24721 1 0 Mshowa
.02381 .32962 m
.03006 .32962 L
s
[(8)] .01131 .32962 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(12)] .01131 .49443 1 0 Mshowa
.02381 .57683 m
.03006 .57683 L
s
[(14)] .01131 .57683 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.000 13.000 moveto
(D) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .01955 L
.10458 .04079 L
.14415 .06059 L
.18221 .07944 L
.22272 .09921 L
.26171 .1179 L
.30316 .1373 L
.34309 .15546 L
.3815 .17239 L
.42237 .18971 L
.46172 .20565 L
.49955 .22022 L
.53984 .23485 L
.57861 .248 L
.61984 .2609 L
.65954 .2722 L
.69774 .28196 L
.73838 .29111 L
.77751 .29865 L
.81909 .30526 L
.85916 .3102 L
.87754 .312 L
.89771 .31362 L
.91765 .31486 L
.92854 .31539 L
.93871 .31578 L
.94354 .31594 L
.94878 .31608 L
.95341 .31619 L
.95832 .31628 L
.96273 .31634 L
.96524 .31637 L
.9676 .31639 L
.96976 .3164 L
.97173 .31641 L
.97277 .31642 L
.97391 .31642 L
.97509 .31642 L
.97619 .31642 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0 0.0412023 [
[.17539 -0.0125 -12 -9 ]
[.17539 -0.0125 12 0 ]
[.32696 -0.0125 -9 -9 ]
[.32696 -0.0125 9 0 ]
[.47854 -0.0125 -12 -9 ]
[.47854 -0.0125 12 0 ]
[.63011 -0.0125 -3 -9 ]
[.63011 -0.0125 3 0 ]
[.78169 -0.0125 -12 -9 ]
[.78169 -0.0125 12 0 ]
[.93327 -0.0125 -9 -9 ]
[.93327 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .0824 -6 -4.5 ]
[.01131 .0824 0 4.5 ]
[.01131 .16481 -6 -4.5 ]
[.01131 .16481 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .32962 -6 -4.5 ]
[.01131 .32962 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .49443 -12 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .57683 -12 -4.5 ]
[.01131 .57683 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .00625 L
s
[(0.25)] .17539 -0.0125 0 1 Mshowa
.32696 0 m
.32696 .00625 L
s
[(0.5)] .32696 -0.0125 0 1 Mshowa
.47854 0 m
.47854 .00625 L
s
[(0.75)] .47854 -0.0125 0 1 Mshowa
.63011 0 m
.63011 .00625 L
s
[(1)] .63011 -0.0125 0 1 Mshowa
.78169 0 m
.78169 .00625 L
s
[(1.25)] .78169 -0.0125 0 1 Mshowa
.93327 0 m
.93327 .00625 L
s
[(1.5)] .93327 -0.0125 0 1 Mshowa
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75138 0 m
.75138 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0824 m
.03006 .0824 L
s
[(2)] .01131 .0824 1 0 Mshowa
.02381 .16481 m
.03006 .16481 L
s
[(4)] .01131 .16481 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(6)] .01131 .24721 1 0 Mshowa
.02381 .32962 m
.03006 .32962 L
s
[(8)] .01131 .32962 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(12)] .01131 .49443 1 0 Mshowa
.02381 .57683 m
.03006 .57683 L
s
[(14)] .01131 .57683 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .01874 L
.10458 .03909 L
.14415 .05806 L
.18221 .07609 L
.22272 .09499 L
.26171 .11283 L
.30316 .13133 L
.34309 .14863 L
.3815 .16471 L
.42237 .18114 L
.46172 .19623 L
.49955 .21001 L
.53984 .22381 L
.57861 .23619 L
.61984 .24831 L
.65954 .25892 L
.69774 .26807 L
.73838 .27663 L
.77751 .28368 L
.81909 .28984 L
.85916 .29445 L
.87754 .29612 L
.89771 .29764 L
.91765 .29879 L
.92854 .29928 L
.93871 .29965 L
.94354 .29979 L
.94878 .29993 L
.95341 .30003 L
.95832 .30011 L
.96273 .30017 L
.96524 .3002 L
.9676 .30022 L
.96976 .30023 L
.97173 .30024 L
.97277 .30024 L
.97391 .30024 L
.97509 .30025 L
.97619 .30025 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0 0.0412023 [
[.17539 -0.0125 -12 -9 ]
[.17539 -0.0125 12 0 ]
[.32696 -0.0125 -9 -9 ]
[.32696 -0.0125 9 0 ]
[.47854 -0.0125 -12 -9 ]
[.47854 -0.0125 12 0 ]
[.63011 -0.0125 -3 -9 ]
[.63011 -0.0125 3 0 ]
[.78169 -0.0125 -12 -9 ]
[.78169 -0.0125 12 0 ]
[.93327 -0.0125 -9 -9 ]
[.93327 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .0824 -6 -4.5 ]
[.01131 .0824 0 4.5 ]
[.01131 .16481 -6 -4.5 ]
[.01131 .16481 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .32962 -6 -4.5 ]
[.01131 .32962 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .49443 -12 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .57683 -12 -4.5 ]
[.01131 .57683 0 4.5 ]
[.5 .63053 -29 0 ]
[.5 .63053 29 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .00625 L
s
[(0.25)] .17539 -0.0125 0 1 Mshowa
.32696 0 m
.32696 .00625 L
s
[(0.5)] .32696 -0.0125 0 1 Mshowa
.47854 0 m
.47854 .00625 L
s
[(0.75)] .47854 -0.0125 0 1 Mshowa
.63011 0 m
.63011 .00625 L
s
[(1)] .63011 -0.0125 0 1 Mshowa
.78169 0 m
.78169 .00625 L
s
[(1.25)] .78169 -0.0125 0 1 Mshowa
.93327 0 m
.93327 .00625 L
s
[(1.5)] .93327 -0.0125 0 1 Mshowa
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75138 0 m
.75138 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0824 m
.03006 .0824 L
s
[(2)] .01131 .0824 1 0 Mshowa
.02381 .16481 m
.03006 .16481 L
s
[(4)] .01131 .16481 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(6)] .01131 .24721 1 0 Mshowa
.02381 .32962 m
.03006 .32962 L
s
[(8)] .01131 .32962 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(12)] .01131 .49443 1 0 Mshowa
.02381 .57683 m
.03006 .57683 L
s
[(14)] .01131 .57683 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.000 13.000 moveto
(D) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .01791 L
.10458 .03737 L
.14415 .05549 L
.18221 .07272 L
.22272 .09076 L
.26171 .10777 L
.30316 .12539 L
.34309 .14185 L
.3815 .15714 L
.42237 .17274 L
.46172 .18706 L
.49955 .2001 L
.53984 .21316 L
.57861 .22485 L
.61984 .23629 L
.65954 .24629 L
.69774 .2549 L
.73838 .26296 L
.77751 .26958 L
.81909 .27537 L
.85916 .2797 L
.87754 .28126 L
.89771 .28268 L
.91765 .28377 L
.92854 .28423 L
.93871 .28457 L
.94354 .2847 L
.94878 .28483 L
.95341 .28492 L
.95832 .285 L
.96273 .28506 L
.96524 .28508 L
.9676 .2851 L
.96976 .28511 L
.97173 .28512 L
.97277 .28512 L
.97391 .28513 L
.97509 .28513 L
.97619 .28513 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0 0.0412023 [
[.17539 -0.0125 -12 -9 ]
[.17539 -0.0125 12 0 ]
[.32696 -0.0125 -9 -9 ]
[.32696 -0.0125 9 0 ]
[.47854 -0.0125 -12 -9 ]
[.47854 -0.0125 12 0 ]
[.63011 -0.0125 -3 -9 ]
[.63011 -0.0125 3 0 ]
[.78169 -0.0125 -12 -9 ]
[.78169 -0.0125 12 0 ]
[.93327 -0.0125 -9 -9 ]
[.93327 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .0824 -6 -4.5 ]
[.01131 .0824 0 4.5 ]
[.01131 .16481 -6 -4.5 ]
[.01131 .16481 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .32962 -6 -4.5 ]
[.01131 .32962 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .49443 -12 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .57683 -12 -4.5 ]
[.01131 .57683 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .00625 L
s
[(0.25)] .17539 -0.0125 0 1 Mshowa
.32696 0 m
.32696 .00625 L
s
[(0.5)] .32696 -0.0125 0 1 Mshowa
.47854 0 m
.47854 .00625 L
s
[(0.75)] .47854 -0.0125 0 1 Mshowa
.63011 0 m
.63011 .00625 L
s
[(1)] .63011 -0.0125 0 1 Mshowa
.78169 0 m
.78169 .00625 L
s
[(1.25)] .78169 -0.0125 0 1 Mshowa
.93327 0 m
.93327 .00625 L
s
[(1.5)] .93327 -0.0125 0 1 Mshowa
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75138 0 m
.75138 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0824 m
.03006 .0824 L
s
[(2)] .01131 .0824 1 0 Mshowa
.02381 .16481 m
.03006 .16481 L
s
[(4)] .01131 .16481 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(6)] .01131 .24721 1 0 Mshowa
.02381 .32962 m
.03006 .32962 L
s
[(8)] .01131 .32962 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(12)] .01131 .49443 1 0 Mshowa
.02381 .57683 m
.03006 .57683 L
s
[(14)] .01131 .57683 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .0171 L
.10458 .03566 L
.14415 .05295 L
.18221 .06938 L
.22272 .08658 L
.26171 .10279 L
.30316 .11958 L
.34309 .13524 L
.3815 .14977 L
.42237 .1646 L
.46172 .17818 L
.49955 .19056 L
.53984 .20293 L
.57861 .21401 L
.61984 .22483 L
.65954 .23428 L
.69774 .24241 L
.73838 .25002 L
.77751 .25626 L
.81909 .26172 L
.85916 .2658 L
.87754 .26728 L
.89771 .26861 L
.91765 .26964 L
.92854 .27007 L
.93871 .27039 L
.94354 .27052 L
.94878 .27064 L
.95341 .27073 L
.95832 .2708 L
.96273 .27085 L
.96524 .27088 L
.9676 .27089 L
.96976 .27091 L
.97173 .27091 L
.97277 .27092 L
.97391 .27092 L
.97509 .27092 L
.97619 .27092 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0 0.0412023 [
[.17539 -0.0125 -12 -9 ]
[.17539 -0.0125 12 0 ]
[.32696 -0.0125 -9 -9 ]
[.32696 -0.0125 9 0 ]
[.47854 -0.0125 -12 -9 ]
[.47854 -0.0125 12 0 ]
[.63011 -0.0125 -3 -9 ]
[.63011 -0.0125 3 0 ]
[.78169 -0.0125 -12 -9 ]
[.78169 -0.0125 12 0 ]
[.93327 -0.0125 -9 -9 ]
[.93327 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .0824 -6 -4.5 ]
[.01131 .0824 0 4.5 ]
[.01131 .16481 -6 -4.5 ]
[.01131 .16481 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .32962 -6 -4.5 ]
[.01131 .32962 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .49443 -12 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .57683 -12 -4.5 ]
[.01131 .57683 0 4.5 ]
[.5 .63053 -29 0 ]
[.5 .63053 29 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .00625 L
s
[(0.25)] .17539 -0.0125 0 1 Mshowa
.32696 0 m
.32696 .00625 L
s
[(0.5)] .32696 -0.0125 0 1 Mshowa
.47854 0 m
.47854 .00625 L
s
[(0.75)] .47854 -0.0125 0 1 Mshowa
.63011 0 m
.63011 .00625 L
s
[(1)] .63011 -0.0125 0 1 Mshowa
.78169 0 m
.78169 .00625 L
s
[(1.25)] .78169 -0.0125 0 1 Mshowa
.93327 0 m
.93327 .00625 L
s
[(1.5)] .93327 -0.0125 0 1 Mshowa
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75138 0 m
.75138 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0824 m
.03006 .0824 L
s
[(2)] .01131 .0824 1 0 Mshowa
.02381 .16481 m
.03006 .16481 L
s
[(4)] .01131 .16481 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(6)] .01131 .24721 1 0 Mshowa
.02381 .32962 m
.03006 .32962 L
s
[(8)] .01131 .32962 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(12)] .01131 .49443 1 0 Mshowa
.02381 .57683 m
.03006 .57683 L
s
[(14)] .01131 .57683 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.000 13.000 moveto
(D) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .0163 L
.10458 .034 L
.14415 .05048 L
.18221 .06614 L
.22272 .08252 L
.26171 .09796 L
.30316 .11393 L
.34309 .12884 L
.3815 .14266 L
.42237 .15675 L
.46172 .16965 L
.49955 .1814 L
.53984 .19314 L
.57861 .20364 L
.61984 .2139 L
.65954 .22285 L
.69774 .23056 L
.73838 .23775 L
.77751 .24366 L
.81909 .24882 L
.85916 .25268 L
.87754 .25407 L
.89771 .25534 L
.91765 .2563 L
.92854 .25671 L
.93871 .25702 L
.94354 .25714 L
.94878 .25725 L
.95341 .25733 L
.95832 .2574 L
.96273 .25745 L
.96524 .25747 L
.9676 .25749 L
.96976 .2575 L
.97173 .25751 L
.97277 .25751 L
.97391 .25751 L
.97509 .25752 L
.97619 .25752 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0 0.0412023 [
[.17539 -0.0125 -12 -9 ]
[.17539 -0.0125 12 0 ]
[.32696 -0.0125 -9 -9 ]
[.32696 -0.0125 9 0 ]
[.47854 -0.0125 -12 -9 ]
[.47854 -0.0125 12 0 ]
[.63011 -0.0125 -3 -9 ]
[.63011 -0.0125 3 0 ]
[.78169 -0.0125 -12 -9 ]
[.78169 -0.0125 12 0 ]
[.93327 -0.0125 -9 -9 ]
[.93327 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .0824 -6 -4.5 ]
[.01131 .0824 0 4.5 ]
[.01131 .16481 -6 -4.5 ]
[.01131 .16481 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .32962 -6 -4.5 ]
[.01131 .32962 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .49443 -12 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .57683 -12 -4.5 ]
[.01131 .57683 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .00625 L
s
[(0.25)] .17539 -0.0125 0 1 Mshowa
.32696 0 m
.32696 .00625 L
s
[(0.5)] .32696 -0.0125 0 1 Mshowa
.47854 0 m
.47854 .00625 L
s
[(0.75)] .47854 -0.0125 0 1 Mshowa
.63011 0 m
.63011 .00625 L
s
[(1)] .63011 -0.0125 0 1 Mshowa
.78169 0 m
.78169 .00625 L
s
[(1.25)] .78169 -0.0125 0 1 Mshowa
.93327 0 m
.93327 .00625 L
s
[(1.5)] .93327 -0.0125 0 1 Mshowa
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75138 0 m
.75138 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0824 m
.03006 .0824 L
s
[(2)] .01131 .0824 1 0 Mshowa
.02381 .16481 m
.03006 .16481 L
s
[(4)] .01131 .16481 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(6)] .01131 .24721 1 0 Mshowa
.02381 .32962 m
.03006 .32962 L
s
[(8)] .01131 .32962 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(12)] .01131 .49443 1 0 Mshowa
.02381 .57683 m
.03006 .57683 L
s
[(14)] .01131 .57683 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .01553 L
.10458 .03239 L
.14415 .04809 L
.18221 .063 L
.22272 .0786 L
.26171 .09329 L
.30316 .1085 L
.34309 .12267 L
.3815 .13582 L
.42237 .14922 L
.46172 .16148 L
.49955 .17264 L
.53984 .18379 L
.57861 .19376 L
.61984 .20349 L
.65954 .21198 L
.69774 .21929 L
.73838 .22611 L
.77751 .23171 L
.81909 .2366 L
.85916 .24025 L
.87754 .24157 L
.89771 .24277 L
.91765 .24368 L
.92854 .24407 L
.93871 .24436 L
.94354 .24448 L
.94878 .24458 L
.95341 .24466 L
.95832 .24473 L
.96273 .24477 L
.96524 .24479 L
.9676 .24481 L
.96976 .24482 L
.97173 .24483 L
.97277 .24483 L
.97391 .24483 L
.97509 .24483 L
.97619 .24483 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0 0.0412023 [
[.17539 -0.0125 -12 -9 ]
[.17539 -0.0125 12 0 ]
[.32696 -0.0125 -9 -9 ]
[.32696 -0.0125 9 0 ]
[.47854 -0.0125 -12 -9 ]
[.47854 -0.0125 12 0 ]
[.63011 -0.0125 -3 -9 ]
[.63011 -0.0125 3 0 ]
[.78169 -0.0125 -12 -9 ]
[.78169 -0.0125 12 0 ]
[.93327 -0.0125 -9 -9 ]
[.93327 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .0824 -6 -4.5 ]
[.01131 .0824 0 4.5 ]
[.01131 .16481 -6 -4.5 ]
[.01131 .16481 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .32962 -6 -4.5 ]
[.01131 .32962 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .49443 -12 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .57683 -12 -4.5 ]
[.01131 .57683 0 4.5 ]
[.5 .63053 -29 0 ]
[.5 .63053 29 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .00625 L
s
[(0.25)] .17539 -0.0125 0 1 Mshowa
.32696 0 m
.32696 .00625 L
s
[(0.5)] .32696 -0.0125 0 1 Mshowa
.47854 0 m
.47854 .00625 L
s
[(0.75)] .47854 -0.0125 0 1 Mshowa
.63011 0 m
.63011 .00625 L
s
[(1)] .63011 -0.0125 0 1 Mshowa
.78169 0 m
.78169 .00625 L
s
[(1.25)] .78169 -0.0125 0 1 Mshowa
.93327 0 m
.93327 .00625 L
s
[(1.5)] .93327 -0.0125 0 1 Mshowa
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75138 0 m
.75138 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0824 m
.03006 .0824 L
s
[(2)] .01131 .0824 1 0 Mshowa
.02381 .16481 m
.03006 .16481 L
s
[(4)] .01131 .16481 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(6)] .01131 .24721 1 0 Mshowa
.02381 .32962 m
.03006 .32962 L
s
[(8)] .01131 .32962 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(12)] .01131 .49443 1 0 Mshowa
.02381 .57683 m
.03006 .57683 L
s
[(14)] .01131 .57683 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.000 13.000 moveto
(D) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .01479 L
.10458 .03084 L
.14415 .04579 L
.18221 .05998 L
.22272 .07483 L
.26171 .08882 L
.30316 .10328 L
.34309 .11677 L
.3815 .12927 L
.42237 .14201 L
.46172 .15367 L
.49955 .16428 L
.53984 .17487 L
.57861 .18434 L
.61984 .19358 L
.65954 .20164 L
.69774 .20858 L
.73838 .21505 L
.77751 .22036 L
.81909 .225 L
.85916 .22847 L
.87754 .22972 L
.89771 .23086 L
.91765 .23172 L
.92854 .23209 L
.93871 .23237 L
.94354 .23248 L
.94878 .23258 L
.95341 .23265 L
.95832 .23271 L
.96273 .23276 L
.96524 .23278 L
.9676 .23279 L
.96976 .2328 L
.97173 .23281 L
.97277 .23281 L
.97391 .23281 L
.97509 .23281 L
.97619 .23281 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0 0.0412023 [
[.17539 -0.0125 -12 -9 ]
[.17539 -0.0125 12 0 ]
[.32696 -0.0125 -9 -9 ]
[.32696 -0.0125 9 0 ]
[.47854 -0.0125 -12 -9 ]
[.47854 -0.0125 12 0 ]
[.63011 -0.0125 -3 -9 ]
[.63011 -0.0125 3 0 ]
[.78169 -0.0125 -12 -9 ]
[.78169 -0.0125 12 0 ]
[.93327 -0.0125 -9 -9 ]
[.93327 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .0824 -6 -4.5 ]
[.01131 .0824 0 4.5 ]
[.01131 .16481 -6 -4.5 ]
[.01131 .16481 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .32962 -6 -4.5 ]
[.01131 .32962 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .49443 -12 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .57683 -12 -4.5 ]
[.01131 .57683 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .00625 L
s
[(0.25)] .17539 -0.0125 0 1 Mshowa
.32696 0 m
.32696 .00625 L
s
[(0.5)] .32696 -0.0125 0 1 Mshowa
.47854 0 m
.47854 .00625 L
s
[(0.75)] .47854 -0.0125 0 1 Mshowa
.63011 0 m
.63011 .00625 L
s
[(1)] .63011 -0.0125 0 1 Mshowa
.78169 0 m
.78169 .00625 L
s
[(1.25)] .78169 -0.0125 0 1 Mshowa
.93327 0 m
.93327 .00625 L
s
[(1.5)] .93327 -0.0125 0 1 Mshowa
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75138 0 m
.75138 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0824 m
.03006 .0824 L
s
[(2)] .01131 .0824 1 0 Mshowa
.02381 .16481 m
.03006 .16481 L
s
[(4)] .01131 .16481 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(6)] .01131 .24721 1 0 Mshowa
.02381 .32962 m
.03006 .32962 L
s
[(8)] .01131 .32962 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(12)] .01131 .49443 1 0 Mshowa
.02381 .57683 m
.03006 .57683 L
s
[(14)] .01131 .57683 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .01407 L
.10458 .02936 L
.14415 .04358 L
.18221 .05709 L
.22272 .07122 L
.26171 .08453 L
.30316 .0983 L
.34309 .11113 L
.3815 .12302 L
.42237 .13513 L
.46172 .14622 L
.49955 .1563 L
.53984 .16637 L
.57861 .17537 L
.61984 .18415 L
.65954 .19181 L
.69774 .1984 L
.73838 .20454 L
.77751 .20959 L
.81909 .21399 L
.85916 .21728 L
.87754 .21848 L
.89771 .21955 L
.91765 .22038 L
.92854 .22072 L
.93871 .22099 L
.94354 .22109 L
.94878 .22118 L
.95341 .22125 L
.95832 .22131 L
.96273 .22136 L
.96524 .22137 L
.9676 .22139 L
.96976 .2214 L
.97173 .2214 L
.97277 .22141 L
.97391 .22141 L
.97509 .22141 L
.97619 .22141 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0 0.0412023 [
[.17539 -0.0125 -12 -9 ]
[.17539 -0.0125 12 0 ]
[.32696 -0.0125 -9 -9 ]
[.32696 -0.0125 9 0 ]
[.47854 -0.0125 -12 -9 ]
[.47854 -0.0125 12 0 ]
[.63011 -0.0125 -3 -9 ]
[.63011 -0.0125 3 0 ]
[.78169 -0.0125 -12 -9 ]
[.78169 -0.0125 12 0 ]
[.93327 -0.0125 -9 -9 ]
[.93327 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .0824 -6 -4.5 ]
[.01131 .0824 0 4.5 ]
[.01131 .16481 -6 -4.5 ]
[.01131 .16481 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .32962 -6 -4.5 ]
[.01131 .32962 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .49443 -12 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .57683 -12 -4.5 ]
[.01131 .57683 0 4.5 ]
[.5 .63053 -29 0 ]
[.5 .63053 29 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .00625 L
s
[(0.25)] .17539 -0.0125 0 1 Mshowa
.32696 0 m
.32696 .00625 L
s
[(0.5)] .32696 -0.0125 0 1 Mshowa
.47854 0 m
.47854 .00625 L
s
[(0.75)] .47854 -0.0125 0 1 Mshowa
.63011 0 m
.63011 .00625 L
s
[(1)] .63011 -0.0125 0 1 Mshowa
.78169 0 m
.78169 .00625 L
s
[(1.25)] .78169 -0.0125 0 1 Mshowa
.93327 0 m
.93327 .00625 L
s
[(1.5)] .93327 -0.0125 0 1 Mshowa
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75138 0 m
.75138 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0824 m
.03006 .0824 L
s
[(2)] .01131 .0824 1 0 Mshowa
.02381 .16481 m
.03006 .16481 L
s
[(4)] .01131 .16481 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(6)] .01131 .24721 1 0 Mshowa
.02381 .32962 m
.03006 .32962 L
s
[(8)] .01131 .32962 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(12)] .01131 .49443 1 0 Mshowa
.02381 .57683 m
.03006 .57683 L
s
[(14)] .01131 .57683 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.000 13.000 moveto
(D) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .01339 L
.10458 .02794 L
.14415 .04147 L
.18221 .05433 L
.22272 .06778 L
.26171 .08044 L
.30316 .09353 L
.34309 .10574 L
.3815 .11705 L
.42237 .12857 L
.46172 .13911 L
.49955 .1487 L
.53984 .15827 L
.57861 .16683 L
.61984 .17518 L
.65954 .18245 L
.69774 .18871 L
.73838 .19455 L
.77751 .19935 L
.81909 .20353 L
.85916 .20666 L
.87754 .20779 L
.89771 .20881 L
.91765 .2096 L
.92854 .20993 L
.93871 .21018 L
.94354 .21027 L
.94878 .21036 L
.95341 .21043 L
.95832 .21049 L
.96273 .21053 L
.96524 .21055 L
.9676 .21056 L
.96976 .21057 L
.97173 .21057 L
.97277 .21058 L
.97391 .21058 L
.97509 .21058 L
.97619 .21058 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0 0.0412023 [
[.17539 -0.0125 -12 -9 ]
[.17539 -0.0125 12 0 ]
[.32696 -0.0125 -9 -9 ]
[.32696 -0.0125 9 0 ]
[.47854 -0.0125 -12 -9 ]
[.47854 -0.0125 12 0 ]
[.63011 -0.0125 -3 -9 ]
[.63011 -0.0125 3 0 ]
[.78169 -0.0125 -12 -9 ]
[.78169 -0.0125 12 0 ]
[.93327 -0.0125 -9 -9 ]
[.93327 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .0824 -6 -4.5 ]
[.01131 .0824 0 4.5 ]
[.01131 .16481 -6 -4.5 ]
[.01131 .16481 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .32962 -6 -4.5 ]
[.01131 .32962 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .49443 -12 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .57683 -12 -4.5 ]
[.01131 .57683 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .00625 L
s
[(0.25)] .17539 -0.0125 0 1 Mshowa
.32696 0 m
.32696 .00625 L
s
[(0.5)] .32696 -0.0125 0 1 Mshowa
.47854 0 m
.47854 .00625 L
s
[(0.75)] .47854 -0.0125 0 1 Mshowa
.63011 0 m
.63011 .00625 L
s
[(1)] .63011 -0.0125 0 1 Mshowa
.78169 0 m
.78169 .00625 L
s
[(1.25)] .78169 -0.0125 0 1 Mshowa
.93327 0 m
.93327 .00625 L
s
[(1.5)] .93327 -0.0125 0 1 Mshowa
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75138 0 m
.75138 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0824 m
.03006 .0824 L
s
[(2)] .01131 .0824 1 0 Mshowa
.02381 .16481 m
.03006 .16481 L
s
[(4)] .01131 .16481 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(6)] .01131 .24721 1 0 Mshowa
.02381 .32962 m
.03006 .32962 L
s
[(8)] .01131 .32962 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(12)] .01131 .49443 1 0 Mshowa
.02381 .57683 m
.03006 .57683 L
s
[(14)] .01131 .57683 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .01274 L
.10458 .02658 L
.14415 .03946 L
.18221 .05169 L
.22272 .06449 L
.26171 .07653 L
.30316 .08899 L
.34309 .1006 L
.3815 .11136 L
.42237 .12232 L
.46172 .13235 L
.49955 .14146 L
.53984 .15057 L
.57861 .1587 L
.61984 .16664 L
.65954 .17355 L
.69774 .17951 L
.73838 .18506 L
.77751 .18962 L
.81909 .19359 L
.85916 .19656 L
.87754 .19764 L
.89771 .19861 L
.91765 .19936 L
.92854 .19967 L
.93871 .19991 L
.94354 .2 L
.94878 .20009 L
.95341 .20015 L
.95832 .2002 L
.96273 .20024 L
.96524 .20026 L
.9676 .20027 L
.96976 .20028 L
.97173 .20028 L
.97277 .20029 L
.97391 .20029 L
.97509 .20029 L
.97619 .20029 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0 0.0412023 [
[.17539 -0.0125 -12 -9 ]
[.17539 -0.0125 12 0 ]
[.32696 -0.0125 -9 -9 ]
[.32696 -0.0125 9 0 ]
[.47854 -0.0125 -12 -9 ]
[.47854 -0.0125 12 0 ]
[.63011 -0.0125 -3 -9 ]
[.63011 -0.0125 3 0 ]
[.78169 -0.0125 -12 -9 ]
[.78169 -0.0125 12 0 ]
[.93327 -0.0125 -9 -9 ]
[.93327 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .0824 -6 -4.5 ]
[.01131 .0824 0 4.5 ]
[.01131 .16481 -6 -4.5 ]
[.01131 .16481 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .32962 -6 -4.5 ]
[.01131 .32962 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .49443 -12 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .57683 -12 -4.5 ]
[.01131 .57683 0 4.5 ]
[.5 .63053 -29 0 ]
[.5 .63053 29 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .00625 L
s
[(0.25)] .17539 -0.0125 0 1 Mshowa
.32696 0 m
.32696 .00625 L
s
[(0.5)] .32696 -0.0125 0 1 Mshowa
.47854 0 m
.47854 .00625 L
s
[(0.75)] .47854 -0.0125 0 1 Mshowa
.63011 0 m
.63011 .00625 L
s
[(1)] .63011 -0.0125 0 1 Mshowa
.78169 0 m
.78169 .00625 L
s
[(1.25)] .78169 -0.0125 0 1 Mshowa
.93327 0 m
.93327 .00625 L
s
[(1.5)] .93327 -0.0125 0 1 Mshowa
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75138 0 m
.75138 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0824 m
.03006 .0824 L
s
[(2)] .01131 .0824 1 0 Mshowa
.02381 .16481 m
.03006 .16481 L
s
[(4)] .01131 .16481 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(6)] .01131 .24721 1 0 Mshowa
.02381 .32962 m
.03006 .32962 L
s
[(8)] .01131 .32962 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(12)] .01131 .49443 1 0 Mshowa
.02381 .57683 m
.03006 .57683 L
s
[(14)] .01131 .57683 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.000 13.000 moveto
(D) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .01212 L
.10458 .02529 L
.14415 .03755 L
.18221 .04918 L
.22272 .06135 L
.26171 .07281 L
.30316 .08466 L
.34309 .09571 L
.3815 .10594 L
.42237 .11637 L
.46172 .1259 L
.49955 .13457 L
.53984 .14323 L
.57861 .15097 L
.61984 .15851 L
.65954 .16509 L
.69774 .17075 L
.73838 .17603 L
.77751 .18036 L
.81909 .18414 L
.85916 .18697 L
.87754 .18799 L
.89771 .18891 L
.91765 .18962 L
.92854 .18992 L
.93871 .19014 L
.94354 .19023 L
.94878 .19031 L
.95341 .19037 L
.95832 .19043 L
.96273 .19046 L
.96524 .19048 L
.9676 .19049 L
.96976 .1905 L
.97173 .1905 L
.97277 .19051 L
.97391 .19051 L
.97509 .19051 L
.97619 .19051 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0 0.0412023 [
[.17539 -0.0125 -12 -9 ]
[.17539 -0.0125 12 0 ]
[.32696 -0.0125 -9 -9 ]
[.32696 -0.0125 9 0 ]
[.47854 -0.0125 -12 -9 ]
[.47854 -0.0125 12 0 ]
[.63011 -0.0125 -3 -9 ]
[.63011 -0.0125 3 0 ]
[.78169 -0.0125 -12 -9 ]
[.78169 -0.0125 12 0 ]
[.93327 -0.0125 -9 -9 ]
[.93327 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .0824 -6 -4.5 ]
[.01131 .0824 0 4.5 ]
[.01131 .16481 -6 -4.5 ]
[.01131 .16481 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .32962 -6 -4.5 ]
[.01131 .32962 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .49443 -12 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .57683 -12 -4.5 ]
[.01131 .57683 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .00625 L
s
[(0.25)] .17539 -0.0125 0 1 Mshowa
.32696 0 m
.32696 .00625 L
s
[(0.5)] .32696 -0.0125 0 1 Mshowa
.47854 0 m
.47854 .00625 L
s
[(0.75)] .47854 -0.0125 0 1 Mshowa
.63011 0 m
.63011 .00625 L
s
[(1)] .63011 -0.0125 0 1 Mshowa
.78169 0 m
.78169 .00625 L
s
[(1.25)] .78169 -0.0125 0 1 Mshowa
.93327 0 m
.93327 .00625 L
s
[(1.5)] .93327 -0.0125 0 1 Mshowa
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75138 0 m
.75138 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0824 m
.03006 .0824 L
s
[(2)] .01131 .0824 1 0 Mshowa
.02381 .16481 m
.03006 .16481 L
s
[(4)] .01131 .16481 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(6)] .01131 .24721 1 0 Mshowa
.02381 .32962 m
.03006 .32962 L
s
[(8)] .01131 .32962 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(12)] .01131 .49443 1 0 Mshowa
.02381 .57683 m
.03006 .57683 L
s
[(14)] .01131 .57683 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 13.000 moveto
(D) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .01154 L
.10458 .02406 L
.14415 .03572 L
.18221 .04679 L
.22272 .05837 L
.26171 .06927 L
.30316 .08054 L
.34309 .09105 L
.3815 .10078 L
.42237 .1107 L
.46172 .11977 L
.49955 .12802 L
.53984 .13625 L
.57861 .14361 L
.61984 .15078 L
.65954 .15704 L
.69774 .16242 L
.73838 .16744 L
.77751 .17156 L
.81909 .17516 L
.85916 .17784 L
.87754 .17881 L
.89771 .17969 L
.91765 .18037 L
.92854 .18065 L
.93871 .18086 L
.94354 .18095 L
.94878 .18102 L
.95341 .18108 L
.95832 .18113 L
.96273 .18117 L
.96524 .18118 L
.9676 .18119 L
.96976 .1812 L
.97173 .1812 L
.97277 .18121 L
.97391 .18121 L
.97509 .18121 L
.97619 .18121 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "As expected, the solution rapidly relaxes to the form of the lowest \
eigenmode, which decays away at rate ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_1\)]],
  ". Since the decay rate and the eigenfunction are both well approximated by \
our numerics, the solution is very accurate. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 2: 2D Drumhead Eigenmodes", "Section",
  CellTags->{"i:47", "c:33"}],

Cell[TextData[{
  "It is also possible to determine eigenmodes for 2D or 3D problems using \
the grid method. However, difficulties arise in taking proper account of the \
boundary conditions. Fortunately, with help from ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " these difficulties can be overcome."
}], "Text"],

Cell["\<\
\tAs an example, consider the eigenmodes of a 2D drumhead, which \
satisfy \
\>", "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`c\^\(\(2\)\(\ \)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\(\( \[Psi]\_\(m\ n\)\)(x, 
            y)\)\  = \(\[Lambda]\_\(m\ n\)\) \(\(\[Psi]\_\(m\ n\)\)(x, 
            y)\)\)]],
  ","
}], "Text"],

Cell[TextData[{
  "subject to the boundary conditions that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_\(m\ n\) = 0\)]],
  "  on some given boundary.  In this example, we will take the boundary to \
be a triangular box given by the equations ",
  Cell[BoxData[
      \(TraditionalForm\`y = x\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x = 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y = 1\)]],
  "(see Cell ",
  ButtonBox["6.144",
    ButtonData:>"Cell 6.144",
    ButtonStyle->"Hyperlink"],
  ").  Eigenmodes and eigenvalues for this problem can be determined \
analytically, and are of the form "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\[Psi]\_\(m\ n\)\)(x, 
          y) = \(sin(m\ \[VeryThinSpace]\[Pi]\ x)\) \(sin(
              n\ \[Pi]\ y)\) - \(sin(n\ \[Pi]\ x)\) \(sin(
              m\ \[Pi]\ y)\)\)\(,\)\)\)]],
  "\n\n",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_\(m\ n\) = \ \(\(\[Pi]\^2\)(
            m\^2 + n\^2)\)\ c\^2\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(n = 1, 2,  ... , \ \ \ \ m = 1, 2,  ... , 
      n - 1\)\)\)]],
  ". "
}], "NE3",
  CellTags->"(6.3.7)"],

Cell[TextData[{
  "\tWe first centered-difference the Laplacian operator on a rectangular \
grid, chosen so that grid points lie on the boundary, just as in Eq. ",
  ButtonBox["(6.2.35)",
    ButtonData:>"(6.2.35)",
    ButtonStyle->"Hyperlink"],
  ". In this example we take ",
  Cell[BoxData[
      \(TraditionalForm\`M\_x = \(M\_y = 20\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`L\_x = \(L\_y = \(c = 1\)\)\)]],
  ": "
}], "Text"],

Cell[BoxData[{
    \(\(\(Clear["\<Global`*\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(M\_x = 20; \ M\_y = 20;\), "\n", 
    \(L\_x = \ 1. ; L\_y = \ 1. ;\), "\n", 
    \(\(c = 1;\)\), "\n", 
    \(\[CapitalDelta]x = L\_x/M\_x; \[CapitalDelta]y = L\_y/M\_y;\), "\n", 
    \(x0\  = \ 0; \ y0 = 0;\), "\n", 
    \(\(x[j_]\  = \ x0\  + \ j\ \[CapitalDelta]x;\)\), "\n", 
    \(\(y[k_]\  = y0\  + \ k\ \[CapitalDelta]y;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.142"],

Cell["\<\
The homogeneous boundary conditions are specified by the following \
statements: \
\>", "Text"],

Cell[BoxData[{
    \(\[Psi][j_, k_]\  := \ \ 0 /; \ 
        j \[LessEqual] \ f[k]\), "\[IndentingNewLine]", 
    \(\[Psi][j_, k_]\  := 
      0\  /; \ j \[GreaterEqual] \ g[k]\), "\[IndentingNewLine]", 
    \(\(\[Psi][j_, 0]\  := 0;\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi][j_, M\_y]\  := \ 0;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(g[k_]\  = \ M\_x;\)\), "\n", 
    \(\(f[k_]\  = \ \ k;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.143"],

Cell[TextData[{
  "The triangular shape of this boundary is shown in Cell ",
  ButtonBox["6.144",
    ButtonData:>"Cell 6.144",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[
        Join[Table[{x[f[k]], \ y[k]}, {k, 0, M\_y}], 
          Table[{x[g[k]], \ y[k]}, {k, 0, M\_y}], 
          Table[{x[j], \ y[0]}, {j, 0, M\_x}]], AspectRatio \[Rule] 1, 
        AxesOrigin \[Rule] {\(- .2\), \(- .2\)}, 
        PlotRange \[Rule] {{\(- .2\), 1.2}, {\(- .2\), 1.2}}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.144"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.714286 0.142857 0.714286 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -9 -9 ]
[.28571 -0.0125 9 0 ]
[.42857 -0.0125 -9 -9 ]
[.42857 -0.0125 9 0 ]
[.57143 -0.0125 -9 -9 ]
[.57143 -0.0125 9 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[-0.0125 .14286 -6 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -18 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -18 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -18 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[-0.0125 .71429 -18 -4.5 ]
[-0.0125 .71429 0 4.5 ]
[-0.0125 .85714 -6 -4.5 ]
[-0.0125 .85714 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14286 0 m
.14286 .00625 L
s
[(0)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(0.2)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(0.4)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(0.6)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(0.8)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(1)] .85714 -0.0125 0 1 Mshowa
.125 Mabswid
.03571 0 m
.03571 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.10714 0 m
.10714 .00375 L
s
.17857 0 m
.17857 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.25 0 m
.25 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.39286 0 m
.39286 .00375 L
s
.46429 0 m
.46429 .00375 L
s
.5 0 m
.5 .00375 L
s
.53571 0 m
.53571 .00375 L
s
.60714 0 m
.60714 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.75 0 m
.75 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.82143 0 m
.82143 .00375 L
s
.89286 0 m
.89286 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.96429 0 m
.96429 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(0)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(0.2)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(0.4)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(0.6)] -0.0125 .57143 1 0 Mshowa
0 .71429 m
.00625 .71429 L
s
[(0.8)] -0.0125 .71429 1 0 Mshowa
0 .85714 m
.00625 .85714 L
s
[(1)] -0.0125 .85714 1 0 Mshowa
.125 Mabswid
0 .03571 m
.00375 .03571 L
s
0 .07143 m
.00375 .07143 L
s
0 .10714 m
.00375 .10714 L
s
0 .17857 m
.00375 .17857 L
s
0 .21429 m
.00375 .21429 L
s
0 .25 m
.00375 .25 L
s
0 .32143 m
.00375 .32143 L
s
0 .35714 m
.00375 .35714 L
s
0 .39286 m
.00375 .39286 L
s
0 .46429 m
.00375 .46429 L
s
0 .5 m
.00375 .5 L
s
0 .53571 m
.00375 .53571 L
s
0 .60714 m
.00375 .60714 L
s
0 .64286 m
.00375 .64286 L
s
0 .67857 m
.00375 .67857 L
s
0 .75 m
.00375 .75 L
s
0 .78571 m
.00375 .78571 L
s
0 .82143 m
.00375 .82143 L
s
0 .89286 m
.00375 .89286 L
s
0 .92857 m
.00375 .92857 L
s
0 .96429 m
.00375 .96429 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.14286 .14286 Mdot
.17857 .17857 Mdot
.21429 .21429 Mdot
.25 .25 Mdot
.28571 .28571 Mdot
.32143 .32143 Mdot
.35714 .35714 Mdot
.39286 .39286 Mdot
.42857 .42857 Mdot
.46429 .46429 Mdot
.5 .5 Mdot
.53571 .53571 Mdot
.57143 .57143 Mdot
.60714 .60714 Mdot
.64286 .64286 Mdot
.67857 .67857 Mdot
.71429 .71429 Mdot
.75 .75 Mdot
.78571 .78571 Mdot
.82143 .82143 Mdot
.85714 .85714 Mdot
.85714 .14286 Mdot
.85714 .17857 Mdot
.85714 .21429 Mdot
.85714 .25 Mdot
.85714 .28571 Mdot
.85714 .32143 Mdot
.85714 .35714 Mdot
.85714 .39286 Mdot
.85714 .42857 Mdot
.85714 .46429 Mdot
.85714 .5 Mdot
.85714 .53571 Mdot
.85714 .57143 Mdot
.85714 .60714 Mdot
.85714 .64286 Mdot
.85714 .67857 Mdot
.85714 .71429 Mdot
.85714 .75 Mdot
.85714 .78571 Mdot
.85714 .82143 Mdot
.85714 .85714 Mdot
.14286 .14286 Mdot
.17857 .14286 Mdot
.21429 .14286 Mdot
.25 .14286 Mdot
.28571 .14286 Mdot
.32143 .14286 Mdot
.35714 .14286 Mdot
.39286 .14286 Mdot
.42857 .14286 Mdot
.46429 .14286 Mdot
.5 .14286 Mdot
.53571 .14286 Mdot
.57143 .14286 Mdot
.60714 .14286 Mdot
.64286 .14286 Mdot
.67857 .14286 Mdot
.71429 .14286 Mdot
.75 .14286 Mdot
.78571 .14286 Mdot
.82143 .14286 Mdot
.85714 .14286 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Aoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02;o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0001_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo01Sooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<01_ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
02?ooooo1?l000000ol@413oooooooooo`0/ooooo`00Aoooool01OmgMgOoV9RHoooooonHV9SoMgMg
02;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A401_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooo
ooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@0Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@0Uooooo`03o`000?oooooooooo02kooooo0017ooooo`05oa0@4?oooooo
ooooooooool@41008_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0
7?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Jooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`05o`000?ooooooooooooooool000009Oooool00ol0003oooooooooo`0^ooooo`00Aooo
ool01Ol0003ooooooooooooooooo000002;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^01_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgooooo
o`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40
6oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Uoooo
o`03o`000?oooooooooo02kooooo0017ooooo`05o`000?ooooooooooooooool000008_ooool01Ol0
003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool06_ooool01Ol0003ooooooooooooo
oooo000000_ooooo00CogMgMoeEEEOoooooo00006oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000oeEEEOl0003o410@olc<c00Kooooo`05o`000?ooooooooooooooool000002oooool0
1Oo<c<co0000o`000?l0003oc<c<02Gooooo00?o0000ooooooooool0;_ooool004Oooooo00Go410@
oooooooooooooooooa0@400Rooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Iooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Kooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Mooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@02Gooooo00?o0000ooooooooool0;_oo
ool004Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Rooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000001_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413o
V9RH01gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000
9Oooool00ol0003oooooooooo`0^ooooo`00Aoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`06oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool06_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@6oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Sooooo`03oeEEEOmVIVKo0000033ooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo000Joooooooo0000Col0000001[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool001[ooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0;_ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000oooooom=ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003ooooo
odgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool2o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool000oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oo
ooooC?ooool000oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oo
ooooC?ooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`?o0000;?ooool2o`0000[o
oooo0_l0000:ooooo`;o00002Oooool2o`0000[ooooo0_l0000:ooooo`;o00002_ooool2o`0000[o
oooo0_l0000:ooooo`;o00002_ooool2o`0000[ooooo0_l00009ooooo`;o00002_ooool2o`0000[o
oooo0_l0000:ooooo`;o00002_ooool2o`0000[ooooo0_l0000:ooooo`;o00002Oooool2o`0000[o
oooo0_l0000:ooooo`;o0000<?ooool000oooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo02cooooo0_l0000:ooooo`;o00002_ooool2o`0000Wooooo0_l0000:ooooo`;o
00002_ooool2o`0000[ooooo0_l0000:ooooo`;o00002_ooool2o`0000[ooooo0_l0000:ooooo`;o
00002Oooool2o`0000[ooooo0_l0000:ooooo`;o00002_ooool2o`0000[ooooo0_l0000:ooooo`;o
00002_ooool2o`0000Wooooo0_l0000:ooooo`;o00002_ooool2o`00033ooooo000?ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`3oooooodcooooo000?ooooo`05oa0@
4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3oooooodcooooo000?ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3oooooodcooooo000?ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`;o0000>Oooool2o`000=oooooo0_l0000`ooooo`006_ooool00ol0003oooooooooo`0h
ooooo`;o0000goooool2o`00033ooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l00015oooo
o`;o0000doooool2o`00033ooooo000Jooooo`03o`000?oooooooooo04Cooooo0_l0003Cooooo`;o
0000<?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0Coooool2o`000<Sooooo0_l0000`ooooo`006_ooool2o`00053ooooo
0_l00038ooooo`;o0000<?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h5oooo
o`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonH
V9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo0?ooooooC?ooool000?ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07oooo
o`?o0000Foooool2o`000;cooooo0_l0000`ooooo`000oooool00ol0003oooooooooo`0;ooooo`03
oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0Foooool2o`000;cooooo0_l0000`ooooo`00
0oooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0
oooooom<ooooo`000oooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooo
oonHV9So410@00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool2o`0006Sooooo0_l0002`ooooo`;o0000<?ooool001[ooooo00?o0000
ooooooooool0Ioooool2o`000;3ooooo0_l0000`ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`;o0000M?ooool2o`000:Cooooo0_l0000`ooooo`006_ooool00ol0003oooooooooo`1cooooo`;o
0000Y?ooool2o`00033ooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l00020ooooo`;o0000
V?ooool2o`00033ooooo000Jooooo`03o`000?oooooooooo07oooooo0_l0002Hooooo`;o0000<?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb
<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo
0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413oooooooooo`09ooooo`Go
00001_ooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo
00CoA4A4omgMgOoooooo00001oooool3o`0008_ooooo0_l0002<ooooo`;o0000<?ooool000?ooooo
00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo08_o
oooo0_l0002<ooooo`;o0000<?ooool000?ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<
o`000007ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`cooooo
00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b
<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000V?ooool2o`00
083ooooo0_l0000`ooooo`006_ooool00ol0003oooooooooo`2Gooooo`;o0000P?ooool2o`00033o
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0002Tooooo`;o0000M?ooool2o`00033ooooo
000Jooooo`03o`000?oooooooooo0:?ooooo0_l0001dooooo`;o0000<?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0[_oo
ool2o`0006Wooooo0_l0000`ooooo`006_ooool2o`000:oooooo0_l0001Yooooo`;o0000<?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo0000
00Kooooo0ol0002jooooo`;o0000GOooool2o`00033ooooo0003ooooo`03o`000?oooooooooo00Wo
oooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;[ooooo0_l0001Moooo
o`;o0000<?ooool000?ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<
00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413oooooooooo`09ooooo`03
oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9So
MgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oc8b
<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`;o0000aoooool2o`00057ooooo0_l0000`ooooo`006_oo
ool00ol0003oooooooooo`36ooooo`;o0000DOooool2o`00033ooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003Cooooo`;o0000AOooool2o`00033ooooo000Jooooo`03o`000?oooooooooo
0=;ooooo0_l00015ooooo`;o0000<?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000=oo
oooo0_l0000iooooo`;o0000<?ooool001[ooooo00?o0000ooooooooool0g_ooool2o`0003Wooooo
0_l0000`ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb
<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o
0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go
8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o
410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80
1_ooool3o`000>[ooooo0_l0000]ooooo`;o0000<?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0j_ooool2o`0002gooooo
0_l0000`ooooo`000oooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`00
0?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000
oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003gooooo`;o00008Oooool2o`00033ooooo000Jooooo`03o`000?oooooooooo0?Kooooo0_l0000Q
ooooo`;o0000<?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0ooooool2ooooo`;o00005_ooool2o`00033ooooo000Joooo
o`;o0000ooooool3ooooo`;o00005_ooool2o`00033ooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0ooooool>ooooo`;o00002_ooool2o`00033ooooo000Jooooo`;o0000
ooooool?ooooo`;o00002_ooool2o`00033ooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`004?ooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom<ooooo`004_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Ooo
ool3o`000?oooooo6_ooool2o`00033ooooo000Booooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0oooooolJooooo`;o0000<?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooodcooooo000Booooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooom<ooooo`004_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
C?ooool0013ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`;o0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.312289, -0.288593, \
0.00526565, 0.00526565}}]
}, Open  ]],

Cell[TextData[{
  "\tNext, we create the equations for the interior points, using the same \
finite difference procedure as in Sec. ",
  ButtonBox["6.2",
    ButtonData:>"c:22",
    ButtonStyle->"Hyperlink"],
  ". Here however, we finite-difference the equation ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\^2\) \[Del]\^2\(\( \[Psi]\_\(m\ n\)\)(x, 
              y)\)\  = 0\)]],
  " in order to obtain linear equations that can eventually be put into the \
matrix form ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["L",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[" ",
              FontWeight->"Bold"], 
            StyleBox["\[CenterDot]",
              FontWeight->"Bold"], 
            StyleBox["\[Psi]",
              FontWeight->"Bold"]}], "=", "0"}], TraditionalForm]]],
  ". All we care about is  the matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["L",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  "; the ",
  "right-hand",
  " side of this matrix equation is not important. After we determine ",
  Cell[BoxData[
      FormBox[
        StyleBox["L",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", we can evaluate the eigenvalues and eigenvectors of this matrix using \
the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions ",
  StyleBox["Eigenvalues",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Eigenvectors",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Text"],

Cell["\tThe equations for the interior points are", "Text"],

Cell[BoxData[
    \(eqns\  = \ 
      Flatten[Table[
          Table[c^2\ \((\(\[Psi][j + 1, k] - 2  \[Psi][j, k]\  + \ \[Psi][j - \
1, k]\)\/\[CapitalDelta]x\^2 + \(\[Psi][j, k + 1] - 2  \[Psi][j, k]\  + \ \
\[Psi][j, k - 1]\)\/\[CapitalDelta]y\^2)\) \[Equal] 0, {j, f[k] + 1, 
              g[k] - 1}], {k, 1, M\_y - 1}]]; \)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.145"],

Cell[TextData[{
  "Since we have already defined the values of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  " on the boundaries, these ",
  "boundary-value",
  "s are used whenever they are encountered in the above equations. The \
variables in these equations are"
}], "Text"],

Cell[BoxData[
    \(\(vars\  = \ 
        Flatten[Table[
            Table[\[Psi][j, k], {j, f[k] + 1, g[k] - 1}], {k, 1, 
              M\_y - 1}]];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.146"],

Cell[TextData[{
  "Now we must turn these algebraic equations into a matrix equation of the \
form ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["L",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[" ",
              FontWeight->"Bold"], 
            StyleBox["\[CenterDot]",
              FontWeight->"Bold"], 
            StyleBox["\[Psi]",
              FontWeight->"Bold"]}], "=", "0"}], TraditionalForm]]],
  ". To do so, we use a function ",
  StyleBox["LinearEquationstoMatrices",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", available in the  add-on  package",
  StyleBox[" LinearAlgebra`",
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "Text"],

Cell[BoxData[{
    \(\(\(<< LinearAlgebra`;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(matrixsystem\  = \ 
        LinearEquationsToMatrices[eqns, vars];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.147"],

Cell[TextData[{
  "The result is a list of the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{
            StyleBox["L",
              FontWeight->"Bold",
              FontSlant->"Plain"], ",", \({0, 0, 0, \(\(...\)\(.\)\)}\)}], 
          "}"}], TraditionalForm]]],
  ". The first element is the matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["L",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", whose rows and columns correspond to the variables in the list ",
  Cell[BoxData[
      \(TraditionalForm\`vars\)],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The second element of ",
  Cell[BoxData[
      \(TraditionalForm\`matrixsystem\)],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the vector on the ",
  "right-hand",
  " side of the matrix equation (in this case the zero vector). Thus, we \
define"
}], "Text"],

Cell[BoxData[
    \(\(lmat\  = \ matrixsystem[\([1]\)];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.148"],

Cell["The eigenvalues follow immediately:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Lambda] = Eigenvalues[lmat]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.149"],

Cell[BoxData[
    \({\(-3150.995885512237`\), \(-3102.955891826802`\), \
\(-3073.650432386822`\), \(-3037.364267976061`\), \(-3008.058808536083`\), \
\(-2960.0188148506477`\), \(-2955.836097425349`\), \(-2926.5306379853637`\), \
\(-2878.4906442999322`\), \(-2860.3788743100877`\), \(-2831.0734148701004`\), \
\(-2812.8990204491965`\), \(-2783.033421184671`\), \(-2753.3430722677426`\), \
\(-2724.037612827754`\), \(-2717.4417973339287`\), \(-2675.9976191423325`\), \
\(-2637.3642679760706`\), \(-2635.9136267832173`\), \(-2610.405995291594`\), \
\(-2608.0588085360787`\), \(-2560.018814850652`\), \(-2528.8778247408754`\), \
\(-2515.2982445082916`\), \(-2494.4271909999106`\), \(-2485.9927850682984`\), \
\(-2437.9527913828724`\), \(-2433.420601625616`\), \(-2412.899020449196`\), \
\(-2390.1506724761107`\), \(-2372.3611675321463`\), \(-2360.8452130361247`\), \
\(-2317.441797333936`\), \(-2312.805219350694`\), \(-2290.832996981424`\), \
\(-2265.003100443925`\), \(-2247.2135954999553`\), \(-2235.6976410039383`\), \
\(-2210.405995291591`\), \(-2195.375773866164`\), \(-2187.65764731851`\), \
\(-2165.6854249492394`\), \(-2142.9370769761526`\), \(-2122.066023467776`\), \
\(-2113.6316175361612`\), \(-2088.339971823824`\), \(-2070.2282018339743`\), \
\(-2065.591623850736`\), \(-2040.53785291705`\), \(-2026.9582726844753`\), \
\(-2000.000000000001`\), \(-1997.6528132444844`\), \(-1972.3611675321424`\), \
\(-1963.1923997916367`\), \(-1949.6128195590575`\), \(-1945.0806298017924`\), \
\(-1919.9224706421328`\), \(-1918.471829449278`\), \(-1890.6170112021423`\), \
\(-1884.0211957083209`\), \(-1847.2135954999576`\), \(-1842.5770175167136`\), \
\(-1838.044827759451`\), \(-1824.4652475268688`\), \(-1823.0146063340178`\), \
\(-1802.4930251575988`\), \(-1795.1597880868817`\), \(-1776.9853936659797`\), \
\(-1747.1197944014584`\), \(-1742.9370769761485`\), \(-1725.1475720321835`\), \
\(-1722.0660234677728`\), \(-1715.978804291681`\), \(-1713.6316175361649`\), \
\(-1707.0358020423414`\), \(-1695.4572231152586`\), \(-1681.528170550721`\), \
\(-1677.3454531254176`\), \(-1665.5916238507368`\), \(-1648.0399936854283`\), \
\(-1629.305459439987`\), \(-1600.0000000000025`\), \(-1600.0000000000005`\), \
\(-1600.`\), \(-1600.`\), \(-1599.9999999999995`\), \(-1599.9999999999993`\), \
\(-1599.999999999999`\), \(-1599.9999999999989`\), \(-1599.9999999999968`\), \
\(-1570.6945405600125`\), \(-1551.960006314571`\), \(-1534.4083761492634`\), \
\(-1522.6545468745853`\), \(-1518.4718294492804`\), \(-1504.5427768847396`\), \
\(-1492.9641979576593`\), \(-1486.368382463835`\), \(-1484.0211957083222`\), \
\(-1477.9339765322263`\), \(-1474.8524279678145`\), \(-1457.0629230238449`\), \
\(-1452.8802055985457`\), \(-1423.0146063340205`\), \(-1404.8402119131106`\), \
\(-1397.506974842398`\), \(-1376.9853936659777`\), \(-1375.5347524731249`\), \
\(-1361.9551722405474`\), \(-1357.4229824832823`\), \(-1352.7864045000415`\), \
\(-1315.9788042916787`\), \(-1309.3829887978534`\), \(-1281.5281705507173`\), \
\(-1280.0775293578693`\), \(-1254.9193701982053`\), \(-1250.3871804409432`\), \
\(-1236.8076002083624`\), \(-1227.6388324678574`\), \(-1202.3471867555143`\), \
\(-1199.9999999999998`\), \(-1173.0417273155301`\), \(-1159.4621470829447`\), \
\(-1134.4083761492634`\), \(-1129.771798166018`\), \(-1111.6600281761782`\), \
\(-1086.3683824638329`\), \(-1077.9339765322288`\), \(-1057.0629230238483`\), \
\(-1034.3145750507633`\), \(-1012.3423526814927`\), \(-1004.624226133837`\), \
\(-989.5940047084016`\), \(-964.3023589960624`\), \(-952.786404500042`\), \
\(-934.9968995560774`\), \(-909.1670030185775`\), \(-887.1947806493048`\), \
\(-882.558202666063`\), \(-839.1547869638765`\), \(-827.6388324678577`\), \
\(-809.8493275238912`\), \(-787.100979550806`\), \(-766.5793983743852`\), \
\(-762.0472086171186`\), \(-714.0072149316888`\), \(-705.5728090000819`\), \
\(-684.7017554917005`\), \(-671.1221752591231`\), \(-639.9811851493481`\), \
\(-591.94119146392`\), \(-589.5940047084054`\), \(-564.0863732167835`\), \
\(-562.635732023935`\), \(-524.0023808576668`\), \(-482.5582026660586`\), \
\(-475.96238717223355`\), \(-446.6569277322501`\), \(-416.9665788153239`\), \
\(-387.10097955080437`\), \(-368.9265851298974`\), \(-339.6211256899086`\), \
\(-321.5093557000698`\), \(-273.46936201464405`\), \(-244.1639025746556`\), \
\(-239.98118514935072`\), \(-191.94119146392322`\), \(-162.63573202392985`\), \
\(-126.34956761318972`\), \(-97.04410817319877`\), \
\(-49.0041144877689`\)}\)], "Output"]
}, Open  ]],

Cell["\<\
There are 171 eigenvalues, one for each interior grid point. This \
number can be found using\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nvalues\  = \ Length[\[Lambda]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.150"],

Cell[BoxData[
    \(171\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The lowest eigenvalue is not far off from the exact value ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_\(1, 2\) = \(\(-5\) \[Pi]\^2 = \(-49.3\) ... \
\)\)]],
  ", given by Eq. ",
  ButtonBox["(6.3.7)",
    ButtonData:>"(6.3.7)",
    ButtonStyle->"Hyperlink"],
  ". This is reasonable agreement, considering the coarseness of our 20-by-20 \
grid.  The next eigenvalue is not too different from the next eigenvalue, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_\(1, 3\) = \(\(-10\)\ \[Pi]\^2 = \
\(-98.7\) ... \)\)]],
  ". Higher precision can be achieved by using a finer grid, but it must be \
remembered that the rank of the matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["L",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " (and the number of eigenvalues) is of order  ",
  Cell[BoxData[
      \(TraditionalForm\`\(M\_x\) M\_y\)]],
  ", so calculating the large number of eigenvectors and eigenvalues \
associated with a fine grid can be quite time-consuming. "
}], "Text"],

Cell["\<\
\tNext, we determine the eigenvectors associated with these \
eigenvalues: \
\>", "Text"],

Cell[BoxData[
    \(\(\[Psi]vec\  = \ Eigenvectors[lmat];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.151"],

Cell[TextData[{
  "Each element of ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Psi]vec",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  " is itself a vector whose elements correspond to the values ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[\(\((\[Psi]\_\(m\ n\))\)\_\(j\ k\)\),
            "TraditionalForm"]}], TraditionalForm]]],
  " of the ",
  Cell[BoxData[
      \(TraditionalForm\`\((m, \ n)\)\)]],
  "'th eigenmode at the ",
  Cell[BoxData[
      \(TraditionalForm\`\((j, k)\)\)]],
  "'th grid point, with the  order of the elements specified by the order of \
the variables in the vector ",
  Cell[BoxData[
      FormBox[
        StyleBox["vars",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  ",",
  " defined above.  For example, the lowest eigenmode is "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Psi]vec[\([nvalues]\)]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.152"],

Cell[BoxData[
    \({\(-0.0003541631311616608`\), \(-0.0013732638980802566`\), \
\(-0.003285761465169663`\), \(-0.006207354718420297`\), \
\(-0.010122198265037236`\), \(-0.01487780173496886`\), \
\(-0.020194275464535758`\), \(-0.025687157418653198`\), \
\(-0.030901699437497137`\), \(-0.03535533905932906`\), \
\(-0.03858424976471559`\), \(-0.04018942987966648`\), \(-0.03987780173496598`\
\), \(-0.037494247726464154`\), \(-0.03304136493510003`\), \
\(-0.026684892042779528`\), \(-0.01874413743134372`\), \
\(-0.00966818164067706`\), \(-0.0016848920427803761`\), \
\(-0.005159887666630935`\), \(-0.0106609943402542`\), \
\(-0.018163563200138996`\), \(-0.02737204946143541`\), \(-0.0377381362373661`\
\), \(-0.04850571376505711`\), \(-0.05877852522925138`\), \
\(-0.06760401432756018`\), \(-0.07406526263763046`\), \(-0.07737204946143048`\
\), \(-0.07694208842938145`\), \(-0.07246439321524`\), \
\(-0.06393841289587622`\), \(-0.05168489204277945`\), \(-0.03632712640026811`\
\), \(-0.018744137431343677`\), \(-0.004375763503420244`\), \
\(-0.01180709030781743`\), \(-0.022273787407413755`\), \
\(-0.035355339059333364`\), \(-0.05025719638660801`\), \(-0.0658765872983221`\
\), \(-0.08090169943749935`\), \(-0.09393474323917834`\), \
\(-0.1036269804721625`\), \(-0.10881254497414149`\), \
\(-0.10862791203008611`\), \(-0.10260519025572301`\), \(-0.09072988812609663`\
\), \(-0.07345720591481346`\), \(-0.051684892042779505`\), \
\(-0.026684892042779466`\), \(-0.008471325967150632`\), \
\(-0.02104038899189054`\), \(-0.03718693027433204`\), \(-0.05590169943750073`\
\), \(-0.07577118003904702`\), \(-0.0951056516295204`\), \
\(-0.11209830643931216`\), \(-0.1250000000000011`\), \
\(-0.13229258190384194`\), \(-0.13284378786687578`\), \
\(-0.1260283764256422`\), \(-0.11180339887498873`\), \
\(-0.09072988812609618`\), \(-0.06393841289587594`\), \(-0.03304136493509972`\
\), \(-0.013651848241101076`\), \(-0.03189451213707201`\), \
\(-0.05354295785177455`\), \(-0.07691803283707734`\), \
\(-0.1000000000000034`\), \(-0.12061963528195672`\), \
\(-0.13666834540726075`\), \(-0.14630679270060443`\), \(-0.14815155063388954`\
\), \(-0.14142135623730817`\), \(-0.12602837642564244`\), \
\(-0.10260519025572264`\), \(-0.07246439321523955`\), \(-0.03749424772646393`\
\), \(-0.019288906370338692`\), \(-0.042898023903992555`\), \
\(-0.0689347432391786`\), \(-0.09510565162951787`\), \(-0.118934743239176`\), \
\(-0.13800367553350462`\), \(-0.1501906058078307`\), \
\(-0.15388417685876132`\), \(-0.14815155063388927`\), \
\(-0.1328437878668747`\), \(-0.10862791203008516`\), \
\(-0.07694208842938068`\), \(-0.03987780173496539`\), \(-0.02457003896795254`\
\), \(-0.05237204946143125`\), \(-0.08090169943749553`\), \
\(-0.10743928107606156`\), \(-0.12931413789080992`\), \(-0.14416788403346692`\
\), \(-0.15019060580782995`\), \(-0.14630679270060348`\), \
\(-0.13229258190384055`\), \(-0.10881254497413946`\), \
\(-0.077372049461429`\), \(-0.04018942987966546`\), \
\(-0.02866560143168147`\), \(-0.05877852522924715`\), \(-0.08744412666092753`\
\), \(-0.11180339887498818`\), \(-0.12931413789080964`\), \
\(-0.1380036755335031`\), \(-0.1366683454072588`\), \
\(-0.12499999999999808`\), \(-0.10362698047215946`\), \
\(-0.0740652626376277`\), \(-0.038584249764714126`\), \
\(-0.030901699437494552`\), \(-0.061042496477976896`\), \
\(-0.08744412666092721`\), \(-0.10743928107605974`\), \(-0.11893474323917363`\
\), \(-0.12061963528195288`\), \(-0.11209830643930753`\), \
\(-0.09393474323917371`\), \(-0.06760401432755628`\), \(-0.03535533905932667`\
\), \(-0.03090169943749431`\), \(-0.05877852522924621`\), \
\(-0.08090169943749342`\), \(-0.09510565162951379`\), \(-0.09999999999999813`\
\), \(-0.09510565162951358`\), \(-0.08090169943749308`\), \
\(-0.058778525229246176`\), \(-0.030901699437494084`\), \
\(-0.02866560143168055`\), \(-0.052372049461428954`\), \
\(-0.06893474323917402`\), \(-0.07691803283707113`\), \
\(-0.0757711800390395`\), \(-0.06587658729831468`\), \
\(-0.04850571376505092`\), \(-0.025687157418649794`\), \
\(-0.02457003896795093`\), \(-0.042898023903988905`\), \
\(-0.05354295785176887`\), \(-0.05590169943749319`\), \(-0.05025719638660039`\
\), \(-0.0377381362373597`\), \(-0.020194275464532032`\), \
\(-0.01928890637033646`\), \(-0.03189451213706751`\), \
\(-0.0371869302743255`\), \(-0.03535533905932623`\), \(-0.027372049461429074`\
\), \(-0.014877801734965307`\), \(-0.013651848241098627`\), \
\(-0.021040388991885917`\), \(-0.02227378740740774`\), \
\(-0.018163563200133362`\), \(-0.010122198265033822`\), \
\(-0.008471325967148145`\), \(-0.011807090307813331`\), \
\(-0.010660994340250238`\), \(-0.006207354718417717`\), \
\(-0.004375763503418604`\), \(-0.0051598876666287714`\), \
\(-0.0032857614651681144`\), \(-0.0016848920427794851`\), \
\(-0.0013732638980794188`\), \(-0.00035416313116159813`\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In order to create a plottable eigenmode, we must associate the elements \
in ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Psi]vec",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  " with their correct grid locations. This can be done as follows. Let ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " be a parameter denoting a given eigenfunction. We usually think of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Alpha]\)\(\ \)\)\)]],
  "as the pair ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((m, n)\)\(,\)\)\)]],
  " but here it is simply a counter, with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\  = \ 1\)]],
  " corresponding to the lowest frequency eigenmode, \[Alpha]=2 being the \
next mode, etc.  Then we equate the function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_\[Alpha]\)(j, k)\)]],
  " (the value of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_\[Alpha]\)]],
  " at grid point ",
  Cell[BoxData[
      \(TraditionalForm\`\((j, k)\)\)]],
  " ) with the corresponding value in the vector ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Psi]vec",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  " using nested ",
  StyleBox["Do",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " statements to run over the interior grid points in the correct order:"
}], "Text"],

Cell[BoxData[
    \(\(\[Psi]val[\[Alpha]_] := \(\[Psi]val[\[Alpha]]\  = \ \ \((n0 = 
              0; \[IndentingNewLine]Do[
              Do[n0 = n0 + 1; \[Psi][j, 
                    k] = \[Psi]vec[\([nvalues - \[Alpha] + 1, n0]\)], {j, 
                  f[k] + 1, g[k] - 1}], {k, 1, 
                M\_y - 1}]; \[IndentingNewLine]a = 
              Table[Table[{x[j], y[k], \[Psi][j, k]}, {j, 0, M\_x}], {k, 0, 
                  M\_y}]; \[IndentingNewLine]Interpolation[
              Flatten[a, 1]])\)\);\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.153"],

Cell[TextData[{
  "The counter ",
  Cell[BoxData[
      \(TraditionalForm\`n0\)],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " keeps track of the position that the ",
  Cell[BoxData[
      \(TraditionalForm\`\((j, k)\)\)]],
  "th grid point occupies in the list ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Psi]vec[\([\[Alpha]]\)]\),
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  ".  We then form a table of position-function values called ",
  StyleBox["a",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", on the entire rectangle containing the domain of interest, and \
interpolate this to create the eigenfunction ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Psi]val[\[Alpha]]\),
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  ". We use double equal signs so that this procedure is performed only once \
for each eigenmode. In Cell ",
  ButtonBox["6.154",
    ButtonData:>"Cell 6.154",
    ButtonStyle->"Hyperlink"],
  ", we plot the eigenfunctions for the lowest three modes."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
      ParametricPlot3D[
        Evaluate[{Min[x + y, 1], 
            y, \(\[Psi]val[\[Alpha]]\)[Min[x + y, 1], y]}], {x, 0, 1}, {y, 0, 
          1}, BoxRatios \[Rule] {1, 1, 1/2}, PlotRange \[Rule] All, 
        PlotPoints \[Rule] 30, AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
        PlotLabel \[Rule] \ "\<triangular drumhead eigenmodes \[Alpha]=\>" <> 
            ToString[\[Alpha]]], {\[Alpha], 1, 3}]; \)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.154"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.05023 -0.0446497 1.05023 [
[.5 .87208 -104 0 ]
[.5 .87208 104 12 ]
[.05011 .23931 -6 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -16.6517 -9 ]
[.33812 .12455 1.34831 0 ]
[.495 .06208 -21.0373 -9 ]
[.495 .06208 2.96266 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.2956 .07454 -9.25094 -12 ]
[.2956 .07454 .74906 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 6 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 18 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 24 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.91306 .21061 0 -8.07062 ]
[.91306 .21061 10 3.92938 ]
[.03186 .27111 -30 -2.72586 ]
[.03186 .27111 0 6.27414 ]
[.01831 .35604 -24 -2.79832 ]
[.01831 .35604 0 6.20168 ]
[.00398 .44587 -30 -2.87539 ]
[.00398 .44587 0 6.12461 ]
[-0.01121 .54103 -6 -2.95752 ]
[-0.01121 .54103 0 6.04248 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .87208 -165 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(triangular) show
129.000 13.000 moveto
(drumhead) show
183.000 13.000 moveto
(eigenmodes) show
249.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
255.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
261.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
267.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(0)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(0.25)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0.5)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.75)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
gsave
.2956 .07454 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(0)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(0.25)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0.5)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.75)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
gsave
.91306 .21061 -61 -12.0706 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04408 .26629 m
.05018 .26389 L
s
[(-0.15)] .03186 .27111 1 -0.39425 Mshowa
.03059 .3514 m
.03673 .34908 L
s
[(-0.1)] .01831 .35604 1 -0.37815 Mshowa
.01632 .44141 m
.0225 .43918 L
s
[(-0.05)] .00398 .44587 1 -0.36103 Mshowa
.00121 .53677 m
.00742 .53464 L
s
[(0)] -0.01121 .54103 1 -0.34277 Mshowa
.125 Mabswid
.04144 .28294 m
.04511 .28151 L
s
.03877 .29977 m
.04244 .29835 L
s
.03607 .31679 m
.03975 .31537 L
s
.03335 .334 m
.03703 .33259 L
s
.0278 .36899 m
.03149 .36761 L
s
.02498 .38679 m
.02867 .38542 L
s
.02213 .40479 m
.02582 .40343 L
s
.01924 .42299 m
.02294 .42165 L
s
.01337 .46004 m
.01708 .45871 L
s
.01039 .47889 m
.0141 .47757 L
s
.00736 .49795 m
.01108 .49665 L
s
.00431 .51725 m
.00803 .51596 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.94761 .68972 m .96955 .6839 L .97747 .69446 L closepath p .645 .766 .937 r
F P
0 g
s
.96955 .6839 m .94761 .68972 L .91754 .68476 L p .648 .76 .931 r
F P
0 g
s
.91754 .68476 m .93943 .67881 L .96955 .6839 L p .648 .76 .931 r
F P
0 g
s
.93943 .67881 m .91754 .68476 L .88728 .67981 L p .655 .753 .922 r
F P
0 g
s
.93943 .67881 m .96153 .67318 L .96955 .6839 L closepath p .639 .764 .938 r
F P
0 g
s
.88728 .67981 m .9091 .67351 L .93943 .67881 L p .655 .753 .922 r
F P
0 g
s
.9091 .67351 m .88728 .67981 L .85684 .67487 L p .678 .721 .882 r
F P
0 g
s
.96153 .67318 m .93943 .67881 L .9091 .67351 L p .649 .749 .923 r
F P
0 g
s
.64189 .33991 m .62119 .35312 L .58954 .33492 L p .684 .539 .683 r
F P
0 g
s
.58954 .33492 m .61002 .31618 L .64189 .33991 L p .684 .539 .683 r
F P
0 g
s
.56916 .36095 m .58954 .33492 L .62119 .35312 L p .716 .554 .669 r
F P
0 g
s
.61002 .31618 m .58954 .33492 L .55803 .32473 L p .721 .57 .684 r
F P
0 g
s
.58954 .33492 m .56916 .36095 L .53756 .35499 L p .745 .581 .671 r
F P
0 g
s
.53756 .35499 m .55803 .32473 L .58954 .33492 L p .745 .581 .671 r
F P
0 g
s
.66303 .33485 m .64189 .33991 L .61002 .31618 L p .64 .519 .7 r
F P
0 g
s
.61002 .31618 m .63077 .3053 L .66303 .33485 L p .64 .519 .7 r
F P
0 g
s
.63077 .3053 m .61002 .31618 L .57846 .30091 L p .684 .554 .701 r
F P
0 g
s
.55803 .32473 m .57846 .30091 L .61002 .31618 L p .721 .57 .684 r
F P
0 g
s
.57846 .30091 m .599 .28435 L .63077 .3053 L p .684 .554 .701 r
F P
0 g
s
.599 .28435 m .57846 .30091 L .54695 .29477 L p .731 .597 .708 r
F P
0 g
s
.57846 .30091 m .55803 .32473 L .5264 .32282 L p .758 .608 .691 r
F P
0 g
s
.5264 .32282 m .54695 .29477 L .57846 .30091 L p .758 .608 .691 r
F P
0 g
s
.85684 .67487 m .87847 .66718 L .9091 .67351 L p .678 .721 .882 r
F P
0 g
s
.87847 .66718 m .85684 .67487 L .82614 .66912 L p .689 .706 .86 r
F P
0 g
s
.67426 .37082 m .65317 .37846 L .62119 .35312 L p .649 .514 .685 r
F P
0 g
s
.62119 .35312 m .64189 .33991 L .67426 .37082 L p .649 .514 .685 r
F P
0 g
s
.60075 .37415 m .62119 .35312 L .65317 .37846 L p .687 .532 .67 r
F P
0 g
s
.62119 .35312 m .60075 .37415 L .56916 .36095 L p .716 .554 .669 r
F P
0 g
s
.65197 .30259 m .63077 .3053 L .599 .28435 L p .632 .531 .722 r
F P
0 g
s
.599 .28435 m .61981 .27559 L .65197 .30259 L p .632 .531 .722 r
F P
0 g
s
.61981 .27559 m .599 .28435 L .56746 .27308 L p .688 .581 .729 r
F P
0 g
s
.54695 .29477 m .56746 .27308 L .599 .28435 L p .731 .597 .708 r
F P
0 g
s
.9091 .67351 m .9311 .66747 L .96153 .67318 L p .649 .749 .923 r
F P
0 g
s
.9311 .66747 m .9091 .67351 L .87847 .66718 L p .654 .734 .908 r
F P
0 g
s
.65317 .37846 m .6325 .39412 L .60075 .37415 L p .687 .532 .67 r
F P
0 g
s
.5804 .40243 m .60075 .37415 L .6325 .39412 L p .715 .545 .659 r
F P
0 g
s
.60075 .37415 m .5804 .40243 L .54874 .39342 L p .738 .565 .659 r
F P
0 g
s
.54874 .39342 m .56916 .36095 L .60075 .37415 L p .738 .565 .659 r
F P
0 g
s
.9311 .66747 m .95339 .66232 L .96153 .67318 L closepath p .627 .758 .941 r
F P
0 g
s
.55803 .32473 m .53756 .35499 L .5057 .3563 L p .776 .613 .678 r
F P
0 g
s
.5057 .3563 m .5264 .32282 L .55803 .32473 L p .776 .613 .678 r
F P
0 g
s
.56916 .36095 m .54874 .39342 L .51692 .39071 L p .762 .588 .662 r
F P
0 g
s
.51692 .39071 m .53756 .35499 L .56916 .36095 L p .762 .588 .662 r
F P
0 g
s
.56746 .27308 m .58808 .25852 L .61981 .27559 L p .688 .581 .729 r
F P
0 g
s
.58808 .25852 m .56746 .27308 L .53586 .27192 L p .748 .642 .743 r
F P
0 g
s
.56746 .27308 m .54695 .29477 L .51521 .29779 L p .779 .65 .72 r
F P
0 g
s
.51521 .29779 m .53586 .27192 L .56746 .27308 L p .779 .65 .72 r
F P
0 g
s
.69595 .37136 m .67426 .37082 L .64189 .33991 L p .596 .489 .703 r
F P
0 g
s
.64189 .33991 m .66303 .33485 L .69595 .37136 L p .596 .489 .703 r
F P
0 g
s
.6848 .33808 m .66303 .33485 L .63077 .3053 L p .576 .489 .719 r
F P
0 g
s
.63077 .3053 m .65197 .30259 L .6848 .33808 L p .576 .489 .719 r
F P
0 g
s
.68562 .40946 m .66459 .41978 L .6325 .39412 L p .659 .514 .676 r
F P
0 g
s
.6325 .39412 m .65317 .37846 L .68562 .40946 L p .659 .514 .676 r
F P
0 g
s
.61209 .41749 m .6325 .39412 L .66459 .41978 L p .692 .53 .663 r
F P
0 g
s
.6325 .39412 m .61209 .41749 L .5804 .40243 L p .715 .545 .659 r
F P
0 g
s
.54695 .29477 m .5264 .32282 L .49441 .32898 L p .798 .653 .702 r
F P
0 g
s
.49441 .32898 m .51521 .29779 L .54695 .29477 L p .798 .653 .702 r
F P
0 g
s
.82614 .66912 m .84764 .66041 L .87847 .66718 L p .689 .706 .86 r
F P
0 g
s
.84764 .66041 m .82614 .66912 L .79531 .66418 L p .708 .676 .817 r
F P
0 g
s
.70723 .4071 m .68562 .40946 L .65317 .37846 L p .614 .494 .693 r
F P
0 g
s
.65317 .37846 m .67426 .37082 L .70723 .4071 L p .614 .494 .693 r
F P
0 g
s
.87847 .66718 m .90041 .66093 L .9311 .66747 L p .654 .734 .908 r
F P
0 g
s
.90041 .66093 m .87847 .66718 L .84764 .66041 L p .674 .693 .859 r
F P
0 g
s
.64107 .27493 m .61981 .27559 L .58808 .25852 L p .624 .554 .755 r
F P
0 g
s
.58808 .25852 m .60897 .2516 L .64107 .27493 L p .624 .554 .755 r
F P
0 g
s
.60897 .2516 m .58808 .25852 L .55648 .25222 L p .697 .626 .773 r
F P
0 g
s
.53586 .27192 m .55648 .25222 L .58808 .25852 L p .748 .642 .743 r
F P
0 g
s
.66459 .41978 m .64396 .43792 L .61209 .41749 L p .692 .53 .663 r
F P
0 g
s
.59177 .44796 m .61209 .41749 L .64396 .43792 L p .716 .542 .653 r
F P
0 g
s
.61209 .41749 m .59177 .44796 L .56 .43705 L p .734 .556 .65 r
F P
0 g
s
.56 .43705 m .5804 .40243 L .61209 .41749 L p .734 .556 .65 r
F P
0 g
s
.6738 .30821 m .65197 .30259 L .61981 .27559 L p .554 .494 .743 r
F P
0 g
s
.61981 .27559 m .64107 .27493 L .6738 .30821 L p .554 .494 .743 r
F P
0 g
s
.5804 .40243 m .56 .43705 L .52814 .43129 L p .753 .572 .651 r
F P
0 g
s
.52814 .43129 m .54874 .39342 L .5804 .40243 L p .753 .572 .651 r
F P
0 g
s
.95339 .66232 m .9311 .66747 L .90041 .66093 L p .63 .744 .93 r
F P
0 g
s
.53756 .35499 m .51692 .39071 L .48475 .3941 L p .787 .617 .669 r
F P
0 g
s
.48475 .3941 m .5057 .3563 L .53756 .35499 L p .787 .617 .669 r
F P
0 g
s
.69709 .44965 m .67612 .46264 L .64396 .43792 L p .67 .519 .671 r
F P
0 g
s
.64396 .43792 m .66459 .41978 L .69709 .44965 L p .67 .519 .671 r
F P
0 g
s
.62357 .46355 m .64396 .43792 L .67612 .46264 L p .699 .533 .659 r
F P
0 g
s
.64396 .43792 m .62357 .46355 L .59177 .44796 L p .716 .542 .653 r
F P
0 g
s
.7186 .44433 m .69709 .44965 L .66459 .41978 L p .631 .501 .687 r
F P
0 g
s
.66459 .41978 m .68562 .40946 L .7186 .44433 L p .631 .501 .687 r
F P
0 g
s
.5264 .32282 m .5057 .3563 L .47338 .36445 L p .809 .653 .689 r
F P
0 g
s
.47338 .36445 m .49441 .32898 L .5264 .32282 L p .809 .653 .689 r
F P
0 g
s
.84764 .66041 m .86937 .65263 L .90041 .66093 L p .674 .693 .859 r
F P
0 g
s
.86937 .65263 m .84764 .66041 L .81659 .65296 L p .693 .651 .804 r
F P
0 g
s
.79531 .66418 m .81659 .65296 L .84764 .66041 L p .708 .676 .817 r
F P
0 g
s
.54874 .39342 m .52814 .43129 L .49602 .4307 L p .772 .593 .656 r
F P
0 g
s
.49602 .4307 m .51692 .39071 L .54874 .39342 L p .772 .593 .656 r
F P
0 g
s
.81659 .65296 m .79531 .66418 L .7643 .65927 L p .721 .631 .757 r
F P
0 g
s
.7184 .37994 m .69595 .37136 L .66303 .33485 L p .519 .454 .723 r
F P
0 g
s
.66303 .33485 m .6848 .33808 L .7184 .37994 L p .519 .454 .723 r
F P
0 g
s
.55648 .25222 m .57721 .23943 L .60897 .2516 L p .697 .626 .773 r
F P
0 g
s
.57721 .23943 m .55648 .25222 L .52468 .25673 L p .774 .716 .798 r
F P
0 g
s
.55648 .25222 m .53586 .27192 L .50388 .2805 L p .81 .718 .763 r
F P
0 g
s
.50388 .2805 m .52468 .25673 L .55648 .25222 L p .81 .718 .763 r
F P
0 g
s
.53586 .27192 m .51521 .29779 L .48295 .30937 L p .83 .714 .737 r
F P
0 g
s
.48295 .30937 m .50388 .2805 L .53586 .27192 L p .83 .714 .737 r
F P
0 g
s
.72956 .41256 m .70723 .4071 L .67426 .37082 L p .55 .465 .713 r
F P
0 g
s
.67426 .37082 m .69595 .37136 L .72956 .41256 L p .55 .465 .713 r
F P
0 g
s
.90041 .66093 m .92264 .65575 L .95339 .66232 L p .63 .744 .93 r
F P
0 g
s
.92264 .65575 m .90041 .66093 L .86937 .65263 L p .638 .709 .898 r
F P
0 g
s
.67612 .46264 m .65553 .48316 L .62357 .46355 L p .699 .533 .659 r
F P
0 g
s
.60326 .4959 m .62357 .46355 L .65553 .48316 L p .721 .544 .65 r
F P
0 g
s
.62357 .46355 m .60326 .4959 L .57137 .48445 L p .734 .552 .646 r
F P
0 g
s
.57137 .48445 m .59177 .44796 L .62357 .46355 L p .734 .552 .646 r
F P
0 g
s
.59177 .44796 m .57137 .48445 L .53942 .47693 L p .749 .563 .645 r
F P
0 g
s
.53942 .47693 m .56 .43705 L .59177 .44796 L p .749 .563 .645 r
F P
0 g
s
.66296 .28255 m .64107 .27493 L .60897 .2516 L p .526 .508 .779 r
F P
0 g
s
.60897 .2516 m .6303 .25263 L .66296 .28255 L p .526 .508 .779 r
F P
0 g
s
.6303 .25263 m .60897 .2516 L .57721 .23943 L p .615 .595 .806 r
F P
0 g
s
.70735 .3495 m .6848 .33808 L .65197 .30259 L p .483 .445 .739 r
F P
0 g
s
.65197 .30259 m .6738 .30821 L .70735 .3495 L p .483 .445 .739 r
F P
0 g
s
.73001 .48197 m .70861 .49019 L .67612 .46264 L p .647 .512 .684 r
F P
0 g
s
.67612 .46264 m .69709 .44965 L .73001 .48197 L p .647 .512 .684 r
F P
0 g
s
.65553 .48316 m .67612 .46264 L .70861 .49019 L p .681 .527 .669 r
F P
0 g
s
.7408 .44652 m .7186 .44433 L .68562 .40946 L p .577 .479 .706 r
F P
0 g
s
.68562 .40946 m .70723 .4071 L .7408 .44652 L p .577 .479 .706 r
F P
0 g
s
.70861 .49019 m .68771 .50572 L .65553 .48316 L p .681 .527 .669 r
F P
0 g
s
.63517 .51089 m .65553 .48316 L .68771 .50572 L p .707 .539 .658 r
F P
0 g
s
.65553 .48316 m .63517 .51089 L .60326 .4959 L p .721 .544 .65 r
F P
0 g
s
.92264 .65575 m .94514 .6513 L .95339 .66232 L closepath p .61 .751 .945 r
F P
0 g
s
.81659 .65296 m .83803 .64245 L .86937 .65263 L p .693 .651 .804 r
F P
0 g
s
.83803 .64245 m .81659 .65296 L .78523 .64359 L p .7 .626 .77 r
F P
0 g
s
.7643 .65927 m .78523 .64359 L .81659 .65296 L p .721 .631 .757 r
F P
0 g
s
.57721 .23943 m .59821 .23404 L .6303 .25263 L p .615 .595 .806 r
F P
0 g
s
.59821 .23404 m .57721 .23943 L .54546 .23887 L p .71 .703 .842 r
F P
0 g
s
.52468 .25673 m .54546 .23887 L .57721 .23943 L p .774 .716 .798 r
F P
0 g
s
.56 .43705 m .53942 .47693 L .50727 .47315 L p .763 .578 .647 r
F P
0 g
s
.50727 .47315 m .52814 .43129 L .56 .43705 L p .763 .578 .647 r
F P
0 g
s
.51521 .29779 m .49441 .32898 L .4618 .3424 L p .839 .708 .718 r
F P
0 g
s
.4618 .3424 m .48295 .30937 L .51521 .29779 L p .839 .708 .718 r
F P
0 g
s
.86937 .65263 m .8915 .6472 L .92264 .65575 L p .638 .709 .898 r
F P
0 g
s
.8915 .6472 m .86937 .65263 L .83803 .64245 L p .651 .666 .851 r
F P
0 g
s
.78523 .64359 m .7643 .65927 L .73294 .65194 L p .728 .63 .749 r
F P
0 g
s
.75206 .4809 m .73001 .48197 L .69709 .44965 L p .602 .494 .703 r
F P
0 g
s
.69709 .44965 m .7186 .44433 L .75206 .4809 L p .602 .494 .703 r
F P
0 g
s
.69643 .32207 m .6738 .30821 L .64107 .27493 L p .438 .438 .761 r
F P
0 g
s
.64107 .27493 m .66296 .28255 L .69643 .32207 L p .438 .438 .761 r
F P
0 g
s
.74139 .519 m .72011 .52991 L .68771 .50572 L p .664 .525 .684 r
F P
0 g
s
.68771 .50572 m .70861 .49019 L .74139 .519 L p .664 .525 .684 r
F P
0 g
s
.66717 .52833 m .68771 .50572 L .72011 .52991 L p .694 .538 .67 r
F P
0 g
s
.68771 .50572 m .66717 .52833 L .63517 .51089 L p .707 .539 .658 r
F P
0 g
s
.51692 .39071 m .49602 .4307 L .4635 .43487 L p .793 .618 .664 r
F P
0 g
s
.4635 .43487 m .48475 .3941 L .51692 .39071 L p .793 .618 .664 r
F P
0 g
s
.78523 .64359 m .80646 .63082 L .83803 .64245 L p .7 .626 .77 r
F P
0 g
s
.80646 .63082 m .78523 .64359 L .7538 .6348 L p .711 .597 .727 r
F P
0 g
s
.73294 .65194 m .7538 .6348 L .78523 .64359 L p .728 .63 .749 r
F P
0 g
s
.5057 .3563 m .48475 .3941 L .45206 .40296 L p .814 .651 .681 r
F P
0 g
s
.45206 .40296 m .47338 .36445 L .5057 .3563 L p .814 .651 .681 r
F P
0 g
s
.61487 .54545 m .63517 .51089 L .66717 .52833 L p .728 .549 .649 r
F P
0 g
s
.63517 .51089 m .61487 .54545 L .5829 .53599 L p .738 .551 .64 r
F P
0 g
s
.5829 .53599 m .60326 .4959 L .63517 .51089 L p .738 .551 .64 r
F P
0 g
s
.83803 .64245 m .85998 .63605 L .8915 .6472 L p .651 .666 .851 r
F P
0 g
s
.85998 .63605 m .83803 .64245 L .80646 .63082 L p .667 .625 .798 r
F P
0 g
s
.94514 .6513 m .92264 .65575 L .8915 .6472 L p .601 .731 .936 r
F P
0 g
s
.60326 .4959 m .5829 .53599 L .5508 .52622 L p .748 .56 .641 r
F P
0 g
s
.5508 .52622 m .57137 .48445 L .60326 .4959 L p .748 .56 .641 r
F P
0 g
s
.76328 .5148 m .74139 .519 L .70861 .49019 L p .625 .51 .703 r
F P
0 g
s
.70861 .49019 m .73001 .48197 L .76328 .5148 L p .625 .51 .703 r
F P
0 g
s
.72011 .52991 m .69928 .54756 L .66717 .52833 L p .694 .538 .67 r
F P
0 g
s
.64683 .55786 m .66717 .52833 L .69928 .54756 L p .718 .549 .66 r
F P
0 g
s
.66717 .52833 m .64683 .55786 L .61487 .54545 L p .728 .549 .649 r
F P
0 g
s
.7538 .6348 m .73294 .65194 L .70155 .64713 L p .736 .613 .72 r
F P
0 g
s
.52814 .43129 m .50727 .47315 L .47482 .47335 L p .778 .596 .653 r
F P
0 g
s
.47482 .47335 m .49602 .4307 L .52814 .43129 L p .778 .596 .653 r
F P
0 g
s
.80646 .63082 m .82813 .62219 L .85998 .63605 L p .667 .625 .798 r
F P
0 g
s
.82813 .62219 m .80646 .63082 L .77468 .61747 L p .679 .593 .752 r
F P
0 g
s
.7538 .6348 m .77468 .61747 L .80646 .63082 L p .711 .597 .727 r
F P
0 g
s
.75268 .55443 m .73151 .56766 L .69928 .54756 L p .681 .541 .688 r
F P
0 g
s
.69928 .54756 m .72011 .52991 L .75268 .55443 L p .681 .541 .688 r
F P
0 g
s
.67884 .57319 m .69928 .54756 L .73151 .56766 L p .71 .55 .67 r
F P
0 g
s
.69928 .54756 m .67884 .57319 L .64683 .55786 L p .718 .549 .66 r
F P
0 g
s
.77468 .61747 m .7538 .6348 L .72223 .62587 L p .72 .574 .69 r
F P
0 g
s
.70155 .64713 m .72223 .62587 L .7538 .6348 L p .736 .613 .72 r
F P
0 g
s
.57137 .48445 m .5508 .52622 L .51856 .52069 L p .758 .57 .642 r
F P
0 g
s
.51856 .52069 m .53942 .47693 L .57137 .48445 L p .758 .57 .642 r
F P
0 g
s
.77439 .54741 m .75268 .55443 L .72011 .52991 L p .646 .529 .706 r
F P
0 g
s
.72011 .52991 m .74139 .519 L .77439 .54741 L p .646 .529 .706 r
F P
0 g
s
.75276 .42535 m .72956 .41256 L .69595 .37136 L p .457 .425 .734 r
F P
0 g
s
.69595 .37136 m .7184 .37994 L .75276 .42535 L p .457 .425 .734 r
F P
0 g
s
.49441 .32898 m .47338 .36445 L .44039 .37843 L p .843 .701 .706 r
F P
0 g
s
.44039 .37843 m .4618 .3424 L .49441 .32898 L p .843 .701 .706 r
F P
0 g
s
.77468 .61747 m .79602 .60574 L .82813 .62219 L p .679 .593 .752 r
F P
0 g
s
.79602 .60574 m .77468 .61747 L .74274 .6024 L p .688 .573 .721 r
F P
0 g
s
.72223 .62587 m .74274 .6024 L .77468 .61747 L p .72 .574 .69 r
F P
0 g
s
.65226 .26177 m .6303 .25263 L .59821 .23404 L p .486 .535 .833 r
F P
0 g
s
.59821 .23404 m .61964 .23632 L .65226 .26177 L p .486 .535 .833 r
F P
0 g
s
.61964 .23632 m .59821 .23404 L .56634 .2276 L p .599 .666 .886 r
F P
0 g
s
.54546 .23887 m .56634 .2276 L .59821 .23404 L p .71 .703 .842 r
F P
0 g
s
.76381 .45573 m .7408 .44652 L .70723 .4071 L p .5 .447 .73 r
F P
0 g
s
.70723 .4071 m .72956 .41256 L .76381 .45573 L p .5 .447 .73 r
F P
0 g
s
.8915 .6472 m .91399 .6433 L .94514 .6513 L p .601 .731 .936 r
F P
0 g
s
.91399 .6433 m .8915 .6472 L .85998 .63605 L p .611 .683 .894 r
F P
0 g
s
.54546 .23887 m .52468 .25673 L .49234 .27128 L p .849 .825 .824 r
F P
0 g
s
.52468 .25673 m .50388 .2805 L .47123 .29781 L p .871 .808 .785 r
F P
0 g
s
.47123 .29781 m .49234 .27128 L .52468 .25673 L p .871 .808 .785 r
F P
0 g
s
.74274 .6024 m .76379 .58734 L .79602 .60574 L p .688 .573 .721 r
F P
0 g
s
.76379 .58734 m .74274 .6024 L .7108 .58772 L p .7 .559 .692 r
F P
0 g
s
.74274 .6024 m .72223 .62587 L .6904 .6145 L p .726 .57 .678 r
F P
0 g
s
.6904 .6145 m .7108 .58772 L .74274 .6024 L p .726 .57 .678 r
F P
0 g
s
.78533 .57795 m .76379 .58734 L .73151 .56766 L p .668 .55 .712 r
F P
0 g
s
.73151 .56766 m .75268 .55443 L .78533 .57795 L p .668 .55 .712 r
F P
0 g
s
.7108 .58772 m .73151 .56766 L .76379 .58734 L p .7 .559 .692 r
F P
0 g
s
.73151 .56766 m .7108 .58772 L .67884 .57319 L p .71 .55 .67 r
F P
0 g
s
.74176 .3961 m .7184 .37994 L .6848 .33808 L p .406 .402 .741 r
F P
0 g
s
.6848 .33808 m .70735 .3495 L .74176 .3961 L p .406 .402 .741 r
F P
0 g
s
.56634 .2276 m .54546 .23887 L .51332 .24955 L p .803 .836 .876 r
F P
0 g
s
.49234 .27128 m .51332 .24955 L .54546 .23887 L p .849 .825 .824 r
F P
0 g
s
.7108 .58772 m .6904 .6145 L .65858 .60549 L p .733 .562 .661 r
F P
0 g
s
.65858 .60549 m .67884 .57319 L .7108 .58772 L p .733 .562 .661 r
F P
0 g
s
.77486 .48646 m .75206 .4809 L .7186 .44433 L p .537 .47 .728 r
F P
0 g
s
.7186 .44433 m .7408 .44652 L .77486 .48646 L p .537 .47 .728 r
F P
0 g
s
.68566 .29836 m .66296 .28255 L .6303 .25263 L p .379 .434 .792 r
F P
0 g
s
.6303 .25263 m .65226 .26177 L .68566 .29836 L p .379 .434 .792 r
F P
0 g
s
.67884 .57319 m .65858 .60549 L .62666 .59775 L p .737 .551 .641 r
F P
0 g
s
.62666 .59775 m .64683 .55786 L .67884 .57319 L p .737 .551 .641 r
F P
0 g
s
.64683 .55786 m .62666 .59775 L .59453 .58741 L p .745 .557 .641 r
F P
0 g
s
.59453 .58741 m .61487 .54545 L .64683 .55786 L p .745 .557 .641 r
F P
0 g
s
.81792 .59923 m .79602 .60574 L .76379 .58734 L p .654 .567 .745 r
F P
0 g
s
.76379 .58734 m .78533 .57795 L .81792 .59923 L p .654 .567 .745 r
F P
0 g
s
.78586 .51682 m .76328 .5148 L .73001 .48197 L p .571 .493 .728 r
F P
0 g
s
.73001 .48197 m .75206 .4809 L .78586 .51682 L p .571 .493 .728 r
F P
0 g
s
.85998 .63605 m .88237 .63217 L .91399 .6433 L p .611 .683 .894 r
F P
0 g
s
.88237 .63217 m .85998 .63605 L .82813 .62219 L p .625 .634 .839 r
F P
0 g
s
.72223 .62587 m .70155 .64713 L .67 .6436 L p .738 .58 .677 r
F P
0 g
s
.67 .6436 m .6904 .6145 L .72223 .62587 L p .738 .58 .677 r
F P
0 g
s
.50388 .2805 m .48295 .30937 L .44993 .32829 L p .879 .79 .758 r
F P
0 g
s
.44993 .32829 m .47123 .29781 L .50388 .2805 L p .879 .79 .758 r
F P
0 g
s
.79674 .54613 m .77439 .54741 L .74139 .519 L p .601 .516 .731 r
F P
0 g
s
.74139 .519 m .76328 .5148 L .79674 .54613 L p .601 .516 .731 r
F P
0 g
s
.85031 .61746 m .82813 .62219 L .79602 .60574 L p .639 .595 .788 r
F P
0 g
s
.79602 .60574 m .81792 .59923 L .85031 .61746 L p .639 .595 .788 r
F P
0 g
s
.80744 .57376 m .78533 .57795 L .75268 .55443 L p .628 .541 .736 r
F P
0 g
s
.75268 .55443 m .77439 .54741 L .80744 .57376 L p .628 .541 .736 r
F P
0 g
s
.91399 .6433 m .93677 .64013 L .94514 .6513 L closepath p .578 .736 .95 r
F P
0 g
s
.73084 .36867 m .70735 .3495 L .6738 .30821 L p .346 .378 .751 r
F P
0 g
s
.6738 .30821 m .69643 .32207 L .73084 .36867 L p .346 .378 .751 r
F P
0 g
s
.53942 .47693 m .51856 .52069 L .48606 .51942 L p .769 .578 .641 r
F P
0 g
s
.48606 .51942 m .50727 .47315 L .53942 .47693 L p .769 .578 .641 r
F P
0 g
s
.82813 .62219 m .85031 .61746 L .88237 .63217 L p .625 .634 .839 r
F P
0 g
s
.61487 .54545 m .59453 .58741 L .56233 .58048 L p .753 .563 .639 r
F P
0 g
s
.56233 .58048 m .5829 .53599 L .61487 .54545 L p .753 .563 .639 r
F P
0 g
s
.6904 .6145 m .67 .6436 L .63803 .63424 L p .746 .591 .684 r
F P
0 g
s
.63803 .63424 m .65858 .60549 L .6904 .6145 L p .746 .591 .684 r
F P
0 g
s
.56634 .2276 m .58747 .22337 L .61964 .23632 L p .599 .666 .886 r
F P
0 g
s
.58747 .22337 m .56634 .2276 L .53429 .23335 L p .711 .829 .938 r
F P
0 g
s
.51332 .24955 m .53429 .23335 L .56634 .2276 L p .803 .836 .876 r
F P
0 g
s
.48475 .3941 m .4635 .43487 L .43045 .44315 L p .814 .648 .677 r
F P
0 g
s
.43045 .44315 m .45206 .40296 L .48475 .3941 L p .814 .648 .677 r
F P
0 g
s
.49602 .4307 m .47482 .47335 L .44194 .47716 L p .794 .617 .662 r
F P
0 g
s
.44194 .47716 m .4635 .43487 L .49602 .4307 L p .794 .617 .662 r
F P
0 g
s
.84037 .5968 m .81792 .59923 L .78533 .57795 L p .61 .563 .777 r
F P
0 g
s
.78533 .57795 m .80744 .57376 L .84037 .5968 L p .61 .563 .777 r
F P
0 g
s
.93677 .64013 m .91399 .6433 L .88237 .63217 L p .561 .709 .94 r
F P
0 g
s
.5829 .53599 m .56233 .58048 L .52995 .57637 L p .754 .556 .629 r
F P
0 g
s
.52995 .57637 m .5508 .52622 L .5829 .53599 L p .754 .556 .629 r
F P
0 g
s
.48295 .30937 m .4618 .3424 L .42839 .36165 L p .88 .774 .74 r
F P
0 g
s
.42839 .36165 m .44993 .32829 L .48295 .30937 L p .88 .774 .74 r
F P
0 g
s
.65858 .60549 m .63803 .63424 L .60604 .62935 L p .752 .591 .676 r
F P
0 g
s
.60604 .62935 m .62666 .59775 L .65858 .60549 L p .752 .591 .676 r
F P
0 g
s
.47338 .36445 m .45206 .40296 L .4187 .41624 L p .841 .693 .699 r
F P
0 g
s
.4187 .41624 m .44039 .37843 L .47338 .36445 L p .841 .693 .699 r
F P
0 g
s
.72003 .34376 m .69643 .32207 L .66296 .28255 L p .27 .351 .763 r
F P
0 g
s
.66296 .28255 m .68566 .29836 L .72003 .34376 L p .27 .351 .763 r
F P
0 g
s
.83018 .57421 m .80744 .57376 L .77439 .54741 L p .576 .532 .769 r
F P
0 g
s
.77439 .54741 m .79674 .54613 L .83018 .57421 L p .576 .532 .769 r
F P
0 g
s
.87299 .61568 m .85031 .61746 L .81792 .59923 L p .591 .6 .829 r
F P
0 g
s
.81792 .59923 m .84037 .5968 L .87299 .61568 L p .591 .6 .829 r
F P
0 g
s
.88237 .63217 m .90516 .63002 L .93677 .64013 L p .561 .709 .94 r
F P
0 g
s
.90516 .63002 m .88237 .63217 L .85031 .61746 L p .573 .651 .889 r
F P
0 g
s
.50727 .47315 m .48606 .51942 L .45327 .51786 L p .78 .596 .65 r
F P
0 g
s
.45327 .51786 m .47482 .47335 L .50727 .47315 L p .78 .596 .65 r
F P
0 g
s
.85031 .61746 m .87299 .61568 L .90516 .63002 L p .573 .651 .889 r
F P
0 g
s
.5508 .52622 m .52995 .57637 L .49735 .56968 L p .764 .569 .635 r
F P
0 g
s
.49735 .56968 m .51856 .52069 L .5508 .52622 L p .764 .569 .635 r
F P
0 g
s
.81978 .54995 m .79674 .54613 L .76328 .5148 L p .537 .501 .763 r
F P
0 g
s
.76328 .5148 m .78586 .51682 L .81978 .54995 L p .537 .501 .763 r
F P
0 g
s
.80921 .52438 m .78586 .51682 L .75206 .4809 L p .493 .469 .759 r
F P
0 g
s
.75206 .4809 m .77486 .48646 L .80921 .52438 L p .493 .469 .759 r
F P
0 g
s
.61964 .23632 m .64168 .24645 L .67503 .27894 L p .294 .434 .832 r
F P
0 g
s
.65226 .26177 m .61964 .23632 L p .63948 .25159 L .294 .434 .832 r
F P
0 g
s
.61964 .23632 m .58747 .22337 L p .60508 .23087 L .417 .58 .906 r
F P
0 g
s
.64168 .24645 m .61964 .23632 L p .60929 .23244 L .417 .58 .906 r
F P
0 g
s
.61513 .23515 m .64168 .24645 L .60929 .23244 L .417 .58 .906 r
F
.60903 .22645 m .64168 .24645 L p .6228 .23841 L F P
0 g
s
.67503 .27894 m .64168 .24645 L p .66309 .26796 L .047 .287 .778 r
F P
0 g
s
.67503 .27894 m .65449 .26345 L p .64417 .2553 L .294 .434 .832 r
F P
0 g
s
.63948 .25159 m .64961 .25939 L .64417 .2553 L .294 .434 .832 r
F
.64961 .25939 m .67503 .27894 L .64417 .2553 L F
.64168 .24645 m .66451 .26435 L .6801 .28231 L p .047 .287 .778 r
F P
0 g
s
.65226 .26177 m .67503 .27894 L .70933 .32197 L p .173 .322 .775 r
F P
0 g
s
.70933 .32197 m .67503 .27894 L p .69972 .30983 L 0 .176 .707 r
F P
0 g
s
.69876 .3038 m .7236 .33583 L .73912 .3589 L p 0 .023 .594 r
F P
0 g
s
.73413 .35285 m .71512 .32918 L p .70587 .31756 L 0 .176 .707 r
F P
0 g
s
.71117 .32414 m .73413 .35285 L .70587 .31756 L 0 .176 .707 r
F
.67503 .27894 m .69876 .3038 L .73413 .35285 L p F P
0 g
s
.70933 .32197 m .73413 .35285 L .77063 .40801 L p 0 .078 .639 r
F P
0 g
s
.73413 .35285 m .69876 .3038 L p .72618 .34238 L 0 .023 .594 r
F P
0 g
s
.77063 .40801 m .73413 .35285 L p .77294 .41112 L 0 0 .507 r
F P
0 g
s
.77294 .41112 m .78936 .43576 L .78547 .43009 L 0 0 .507 r
F
.78547 .43009 m .77063 .40801 L p .77294 .41112 L F P
0 g
s
.8183 .48204 m .79166 .44828 L .75541 .39497 L p 0 .046 .614 r
F P
0 g
s
.75541 .39497 m .78114 .4275 L .8183 .48204 L p 0 .046 .614 r
F P
0 g
s
.80808 .46495 m .78114 .4275 L .74473 .3727 L p 0 0 .557 r
F P
0 g
s
.74473 .3727 m .77063 .40801 L .80808 .46495 L p 0 0 .557 r
F P
0 g
s
.73413 .35285 m .76015 .39016 L .7978 .44843 L p 0 0 .507 r
F P
0 g
s
.76015 .39016 m .74135 .36322 L p .73383 .35289 L 0 .023 .594 r
F P
0 g
s
.72618 .34238 m .73986 .36162 L .73383 .35289 L 0 .023 .594 r
F
.73986 .36162 m .76015 .39016 L .73383 .35289 L F
.73912 .3589 m .75603 .38404 L p .74041 .36107 L F P
0 g
s
.75603 .38404 m .76015 .39016 L p .74041 .36107 L 0 .023 .594 r
F P
0 g
s
.74535 .36935 m .74041 .36107 L .76015 .39016 L 0 .023 .594 r
F
.74135 .36322 m .73413 .35285 L p .72618 .34238 L F P
0 g
s
.73537 .35424 m .73912 .3589 L .74535 .36935 L 0 .023 .594 r
F
.69876 .3038 m .73912 .3589 L .72881 .34607 L F
.76015 .39016 m .7236 .33583 L p .75549 .38419 L 0 0 .466 r
F P
0 g
s
.75549 .38419 m .77427 .41266 L .7669 .40093 L 0 0 .466 r
F
.75549 .38419 m .7669 .40093 L .76015 .39016 L F
.76403 .39621 m .76015 .39016 L p .77427 .41266 L F P
0 g
s
.7236 .33583 m .74968 .37421 L .76639 .40006 L p 0 0 .466 r
F P
0 g
s
.7236 .33583 m .76639 .40006 L .75679 .38615 L 0 0 .466 r
F
.72881 .34607 m .73537 .35424 L .74535 .36935 L 0 .023 .594 r
F
.66743 .27207 m .69876 .3038 L .67816 .28222 L .047 .287 .778 r
F
.6727 .27762 m .69876 .3038 L .66743 .27207 L F
.6801 .28231 m .69876 .3038 L p .67966 .28462 L F P
0 g
s
.67816 .28222 m .67503 .27894 L p .66309 .26796 L .047 .287 .778 r
F P
0 g
s
.67444 .27806 m .6801 .28231 L .67966 .28462 L .047 .287 .778 r
F
.66309 .26796 m .6727 .27762 L .66743 .27207 L F
.64168 .24645 m .6801 .28231 L .66925 .27415 L F
.7236 .33583 m .69876 .3038 L .68407 .28689 L p 0 .122 .672 r
F P
0 g
s
.68407 .28689 m .66451 .26435 L p .68658 .29105 L 0 .122 .672 r
F P
0 g
s
.68658 .29105 m .68754 .2922 L .68713 .29159 L 0 .122 .672 r
F
.68658 .29105 m .68713 .29159 L .68407 .28689 L F
.66451 .26435 m .64168 .24645 L .62567 .23665 L p .161 .43 .866 r
F P
0 g
s
.63717 .24567 m .66451 .26435 L .62567 .23665 L .161 .43 .866 r
F
.63117 .23699 m .64674 .24976 L p .63845 .24464 L F P
0 g
s
.62567 .23665 m .60903 .22645 L p .62798 .2394 L .161 .43 .866 r
F P
0 g
s
.62798 .2394 m .63717 .24567 L .63171 .24139 L .161 .43 .866 r
F
.62798 .2394 m .63171 .24139 L .62567 .23665 L F
.60903 .22645 m .63794 .24416 L .63845 .24464 L F
.60903 .22645 m .62955 .23622 L p .63794 .24416 L F P
0 g
s
.62955 .23622 m .63117 .23699 L p .63845 .24464 L .161 .43 .866 r
F P
0 g
s
.60903 .22645 m .64674 .24976 L .63565 .24464 L .161 .43 .866 r
F
.60508 .23087 m .61513 .23515 L .60929 .23244 L .417 .58 .906 r
F
.58747 .22337 m .60736 .22621 L p .6228 .23841 L F P
0 g
s
.60736 .22621 m .60903 .22645 L p .6228 .23841 L .417 .58 .906 r
F P
0 g
s
.53429 .23335 m .55537 .22333 L .58747 .22337 L p .711 .829 .938 r
F P
0 g
s
.60903 .22645 m .58747 .22337 L .55537 .22333 L p .538 .771 .984 r
F P
0 g
s
.57669 .21989 m .60903 .22645 L p .5904 .22537 L .538 .771 .984 r
F P
0 g
s
.63117 .23699 m .60903 .22645 L .57669 .21989 L p .267 .622 .96 r
F P
0 g
s
.5984 .22327 m .63117 .23699 L p .61246 .23112 L .267 .622 .96 r
F P
0 g
s
.57669 .21989 m .59749 .22313 L p .61246 .23112 L .267 .622 .96 r
F P
0 g
s
.59749 .22313 m .5984 .22327 L p .61246 .23112 L .267 .622 .96 r
F P
0 g
s
.64674 .24976 m .66451 .26435 L p .63565 .24464 L .161 .43 .866 r
F P
0 g
s
.68754 .2922 m .69179 .29689 L .68407 .28689 L 0 .122 .672 r
F
.69723 .30393 m .7236 .33583 L .68407 .28689 L F
.66451 .26435 m .68618 .28745 L p .69981 .30617 L F P
0 g
s
.68754 .2922 m .69723 .30393 L .69179 .29689 L 0 .122 .672 r
F
.66451 .26435 m .69981 .30617 L .69418 .30023 L F
.68618 .28745 m .68828 .28969 L p .7052 .31356 L F P
0 g
s
.66451 .26435 m .63117 .23699 L p .65155 .2558 L 0 .242 .756 r
F P
0 g
s
.68828 .28969 m .66637 .26634 L p .65475 .25807 L 0 .242 .756 r
F P
0 g
s
.65978 .26339 m .68828 .28969 L .65475 .25807 L 0 .242 .756 r
F
.66637 .26634 m .66451 .26435 L p .65155 .2558 L F P
0 g
s
.65407 .25492 m .68828 .28969 L p .66949 .27235 L 0 .242 .756 r
F P
0 g
s
.66012 .2637 m .6654 .26785 L .66949 .27235 L 0 .242 .756 r
F
.6526 .25377 m .65407 .25492 L p .66949 .27235 L F P
0 g
s
.68828 .28969 m .71059 .32009 L p .7052 .31356 L 0 .122 .672 r
F P
0 g
s
.71374 .32294 m .7236 .33583 L p .71745 .32838 L 0 .122 .672 r
F P
0 g
s
.7236 .33583 m .68828 .28969 L p .71346 .32435 L 0 0 .548 r
F P
0 g
s
.74968 .37421 m .72858 .34315 L p .7179 .32988 L 0 0 .548 r
F P
0 g
s
.72392 .33875 m .74968 .37421 L .7179 .32988 L 0 0 .548 r
F
.72858 .34315 m .7236 .33583 L p .71346 .32435 L F P
0 g
s
.71346 .32435 m .72392 .33875 L .7179 .32988 L 0 0 .548 r
F
.68828 .28969 m .71249 .32112 L p .72752 .34316 L F P
0 g
s
.72078 .33443 m .72752 .34316 L .73362 .3521 L 0 0 .548 r
F
.68828 .28969 m .72752 .34316 L .72078 .33443 L F
.71249 .32112 m .71315 .32197 L p .73362 .3521 L F P
0 g
s
.71315 .32197 m .74968 .37421 L p .73362 .3521 L 0 0 .548 r
F P
0 g
s
.78746 .43266 m .76403 .39621 L p .77427 .41266 L 0 0 .466 r
F P
0 g
s
.76639 .40006 m .78746 .43266 L p .75679 .38615 L 0 0 .466 r
F P
0 g
s
.77063 .40801 m .74473 .3727 L .70933 .32197 L p 0 .078 .639 r
F P
0 g
s
.74968 .37421 m .71315 .32197 L p .7414 .36432 L 0 0 .435 r
F P
0 g
s
.8183 .48204 m .8138 .47544 L p .83304 .50143 L 0 0 .449 r
F P
0 g
s
.84605 .51902 m .83453 .50366 L p .83304 .50143 L 0 0 .449 r
F P
0 g
s
.83453 .50366 m .8183 .48204 L p .83304 .50143 L 0 0 .449 r
F P
0 g
s
.80203 .45694 m .84605 .51902 L .8138 .47544 L 0 0 .449 r
F
.77533 .41502 m .79171 .43937 L .79576 .44551 L 0 0 .402 r
F
.7731 .41168 m .7978 .44843 L p .77533 .41502 L F P
0 g
s
.80808 .46495 m .77796 .41916 L p .80333 .45693 L 0 0 .402 r
F P
0 g
s
.80333 .45693 m .81111 .46896 L .80808 .46495 L 0 0 .402 r
F
.80808 .46495 m .81394 .47329 L p .80203 .45694 L 0 0 .449 r
F P
0 g
s
.7978 .44843 m .76435 .39667 L p .79459 .44353 L .607 .181 0 r
F P
0 g
s
.79576 .44551 m .7978 .44843 L .80048 .45252 L 0 0 .402 r
F
.80117 .45358 m .8109 .46803 L .81424 .47309 L F
.79576 .44551 m .80048 .45252 L .80117 .45358 L F
.80048 .45252 m .8109 .46803 L .80117 .45358 L F
.76217 .39328 m .7944 .44323 L .76435 .39667 L .607 .181 0 r
F
.80203 .45694 m .81394 .47329 L .81759 .47888 L 0 0 .449 r
F
.81394 .47329 m .82102 .48338 L p .81759 .47888 L F P
0 g
s
.82102 .48338 m .84605 .51902 L p .82432 .48837 L 0 0 .449 r
F P
0 g
s
.81759 .47888 m .82102 .48338 L .82432 .48837 L 0 0 .449 r
F
.80808 .46495 m .83621 .50588 L .84605 .51902 L closepath p .618 .169 0 r
F P
0 g
s
.83621 .50588 m .81556 .47583 L p .81378 .47247 L 0 0 .402 r
F P
0 g
s
.81556 .47583 m .80808 .46495 L p .81111 .46896 L 0 0 .402 r
F P
0 g
s
.81378 .47247 m .81556 .47583 L .81111 .46896 L 0 0 .402 r
F
.79171 .43937 m .7978 .44843 L .79576 .44551 L F
.77533 .41502 m .80506 .45939 L .77796 .41916 L F
.80506 .45939 m .83621 .50588 L .80717 .46263 L F
.80506 .45939 m .80717 .46263 L .77796 .41916 L F
.7978 .44843 m .79149 .43905 L p .78936 .43576 L 0 0 .507 r
F P
0 g
s
.78746 .43266 m .82622 .49254 L p .76217 .39328 L .607 .181 0 r
F P
0 g
s
.76015 .39016 m .76127 .39191 L p .76217 .39328 L .607 .181 0 r
F P
0 g
s
.76127 .39191 m .78746 .43266 L p .76217 .39328 L .607 .181 0 r
F P
0 g
s
.7944 .44323 m .82622 .49254 L .79459 .44353 L .607 .181 0 r
F
.7944 .44323 m .79459 .44353 L .76435 .39667 L F
.79459 .44353 m .80031 .45239 L .7978 .44843 L F
.7978 .44843 m .8109 .46803 L p .80048 .45252 L 0 0 .402 r
F P
0 g
s
.8109 .46803 m .83621 .50588 L p .81424 .47309 L 0 0 .402 r
F P
0 g
s
.82622 .49254 m .80361 .45745 L p .80031 .45239 L .607 .181 0 r
F P
0 g
s
.80361 .45745 m .7978 .44843 L p .80031 .45239 L .607 .181 0 r
F P
0 g
s
.76435 .39667 m .76015 .39016 L p .76217 .39328 L .607 .181 0 r
F P
0 g
s
.80333 .45693 m .81378 .47247 L .81111 .46896 L 0 0 .402 r
F
.78114 .4275 m .80808 .46495 L p .80203 .45694 L 0 0 .449 r
F P
0 g
s
.77706 .41779 m .79365 .44381 L p .77227 .40994 L .622 .195 0 r
F P
0 g
s
.76125 .39247 m .77017 .40675 L .77227 .40994 L .622 .195 0 r
F
.77017 .40675 m .77706 .41779 L .77227 .40994 L F
.77063 .40801 m .7731 .41168 L p .77533 .41502 L 0 0 .402 r
F P
0 g
s
.77796 .41916 m .77063 .40801 L p .77533 .41502 L 0 0 .402 r
F P
0 g
s
.8138 .47544 m .78114 .4275 L p .80203 .45694 L 0 0 .449 r
F P
0 g
s
.7414 .36432 m .75289 .38155 L .74604 .37067 L 0 0 .435 r
F
.75606 .38437 m .74968 .37421 L p .7414 .36432 L F P
0 g
s
.75289 .38155 m .77706 .41779 L .74604 .37067 L 0 0 .435 r
F
.71315 .32197 m .73923 .36043 L .76108 .39356 L p F P
0 g
s
.71315 .32197 m .76108 .39356 L .7499 .37706 L 0 0 .435 r
F
.73923 .36043 m .7666 .40394 L .79223 .44405 L p .623 .195 0 r
F P
0 g
s
.79223 .44405 m .80576 .46523 L p .78198 .42776 L .623 .195 0 r
F P
0 g
s
.73923 .36043 m .79223 .44405 L .78198 .42776 L .623 .195 0 r
F
.77706 .41779 m .75606 .38437 L p .74604 .37067 L 0 0 .435 r
F P
0 g
s
.69418 .30023 m .69981 .30617 L .7052 .31356 L 0 .122 .672 r
F
.71315 .32197 m .68828 .28969 L .67013 .27125 L p 0 .072 .621 r
F P
0 g
s
.68352 .28834 m .71315 .32197 L .67013 .27125 L 0 .072 .621 r
F
.68553 .29063 m .69093 .29634 L .69477 .30111 L F
.67013 .27125 m .65407 .25492 L p .68352 .28834 L F P
0 g
s
.65407 .25492 m .67788 .27991 L .69731 .30308 L p 0 .072 .621 r
F P
0 g
s
.65407 .25492 m .69731 .30308 L .68553 .29063 L 0 .072 .621 r
F
.69731 .30308 m .71315 .32197 L p .69477 .30111 L F P
0 g
s
.69093 .29634 m .69731 .30308 L .69477 .30111 L 0 .072 .621 r
F
.71315 .32197 m .67788 .27991 L p .7015 .31091 L 0 0 .504 r
F P
0 g
s
.73923 .36043 m .71651 .32692 L p .70397 .31354 L 0 0 .504 r
F P
0 g
s
.70868 .32034 m .73923 .36043 L .70397 .31354 L 0 0 .504 r
F
.71651 .32692 m .71315 .32197 L p .7015 .31091 L F P
0 g
s
.7015 .31091 m .70868 .32034 L .70397 .31354 L 0 0 .504 r
F
.67788 .27991 m .70377 .31288 L .71855 .33308 L F
.67788 .27991 m .71855 .33308 L .71273 .32564 L F
.67788 .27991 m .70275 .3115 L .70377 .31288 L p F P
0 g
s
.71512 .32918 m .70933 .32197 L p .69972 .30983 L 0 .176 .707 r
F P
0 g
s
.71273 .32564 m .71855 .33308 L .72227 .33816 L 0 0 .504 r
F
.70377 .31288 m .73923 .36043 L p .72227 .33816 L F P
0 g
s
.73923 .36043 m .70275 .3115 L p .72873 .34912 L 0 0 .419 r
F P
0 g
s
.72873 .34912 m .73441 .35734 L .73046 .35124 L 0 0 .419 r
F
.74354 .36728 m .73923 .36043 L p .72873 .34912 L F P
0 g
s
.73441 .35734 m .7666 .40394 L .73046 .35124 L 0 0 .419 r
F
.70275 .3115 m .72879 .34895 L .75409 .38575 L p F P
0 g
s
.70275 .3115 m .75409 .38575 L .74262 .36922 L 0 0 .419 r
F
.74473 .3727 m .72003 .34376 L .68566 .29836 L p .047 .229 .728 r
F P
0 g
s
.68566 .29836 m .70933 .32197 L .74473 .3727 L p .047 .229 .728 r
F P
0 g
s
.78114 .4275 m .75541 .39497 L .72003 .34376 L p 0 .14 .68 r
F P
0 g
s
.72003 .34376 m .74473 .3727 L .78114 .4275 L p 0 .14 .68 r
F P
0 g
s
.72879 .34895 m .75608 .39119 L .78597 .43698 L p .611 .181 0 r
F P
0 g
s
.78597 .43698 m .79529 .45125 L p .77588 .42139 L .611 .181 0 r
F P
0 g
s
.72879 .34895 m .78597 .43698 L .77588 .42139 L .611 .181 0 r
F
.7666 .40394 m .74354 .36728 L p .73046 .35124 L 0 0 .419 r
F P
0 g
s
.65155 .2558 m .65978 .26339 L .65475 .25807 L 0 .242 .756 r
F
.63117 .23699 m .6526 .25377 L p .6654 .26785 L F P
0 g
s
.63117 .23699 m .6654 .26785 L .66012 .2637 L 0 .242 .756 r
F
.63117 .23699 m .61307 .22941 L p .62176 .23482 L 0 .4 .84 r
F P
0 g
s
.61307 .22941 m .5984 .22327 L p .62467 .23821 L 0 .4 .84 r
F P
0 g
s
.62467 .23821 m .65407 .25492 L .61307 .22941 L 0 .4 .84 r
F
.5984 .22327 m .61979 .23321 L p .62037 .23362 L F P
0 g
s
.65407 .25492 m .63117 .23699 L p .62176 .23482 L 0 .4 .84 r
F P
0 g
s
.61664 .23364 m .62037 .23362 L .63539 .2443 L 0 .4 .84 r
F
.5984 .22327 m .62037 .23362 L .61664 .23364 L F
.61979 .23321 m .62067 .23361 L p .63539 .2443 L F P
0 g
s
.55537 .22333 m .57605 .21999 L p .5904 .22537 L .538 .771 .984 r
F P
0 g
s
.57605 .21999 m .57669 .21989 L p .5904 .22537 L .538 .771 .984 r
F P
0 g
s
.53429 .23335 m .51332 .24955 L .50144 .25706 L p .853 .966 .873 r
F P
0 g
s
.50144 .25706 m .48047 .27032 L p .50883 .25084 L .853 .966 .873 r
F P
0 g
s
.50883 .25084 m .53429 .23335 L .50144 .25706 L .853 .966 .873 r
F
.50169 .25055 m .5229 .23586 L .5298 .23319 L p .761 .975 .921 r
F P
0 g
s
.48047 .27032 m .50169 .25055 L .53429 .23335 L p .853 .966 .873 r
F P
0 g
s
.55537 .22333 m .53429 .23335 L .52174 .23997 L p .761 .975 .921 r
F P
0 g
s
.52174 .23997 m .5199 .24095 L p .55537 .22333 L .761 .975 .921 r
F P
0 g
s
.52876 .23682 m .55537 .22333 L .5199 .24095 L .761 .975 .921 r
F
.5199 .24095 m .50169 .25055 L p .52876 .23682 L F P
0 g
s
.5298 .23319 m .55537 .22333 L p .52052 .241 L .761 .975 .921 r
F P
0 g
s
.50169 .25055 m .5298 .23319 L .52052 .241 L .761 .975 .921 r
F
.57669 .21989 m .55537 .22333 L .5229 .23586 L p .584 .93 .951 r
F P
0 g
s
.5229 .23586 m .54422 .2268 L .55542 .22441 L p .584 .93 .951 r
F P
0 g
s
.55542 .22441 m .57669 .21989 L p .54481 .22935 L .584 .93 .951 r
F P
0 g
s
.5229 .23586 m .55542 .22441 L .54481 .22935 L .584 .93 .951 r
F
.5984 .22327 m .57669 .21989 L .54422 .2268 L p .303 .783 .916 r
F P
0 g
s
.54422 .2268 m .56576 .22375 L .5984 .22327 L p .303 .783 .916 r
F P
0 g
s
.62067 .23361 m .5984 .22327 L .56576 .22375 L p 0 .549 .802 r
F P
0 g
s
.58768 .22693 m .62067 .23361 L p .60197 .23025 L 0 .549 .802 r
F P
0 g
s
.56576 .22375 m .58737 .22689 L p .60197 .23025 L 0 .549 .802 r
F P
0 g
s
.58737 .22689 m .58768 .22693 L p .60197 .23025 L 0 .549 .802 r
F P
0 g
s
.62067 .23361 m .65407 .25492 L p .63539 .2443 L 0 .4 .84 r
F P
0 g
s
.64688 .25483 m .67788 .27991 L .64503 .25151 L 0 .186 .682 r
F
.64249 .25042 m .64503 .25151 L .63461 .24251 L F
.64688 .25483 m .64503 .25151 L .64249 .25042 L F
.63461 .24251 m .62067 .23361 L p .64688 .25483 L F P
0 g
s
.62067 .23361 m .65598 .26131 L .65894 .26418 L 0 .186 .682 r
F
.62067 .23361 m .65894 .26418 L .65109 .25824 L F
.64366 .25084 m .65598 .26131 L p .64153 .24997 L F P
0 g
s
.62067 .23361 m .64366 .25084 L p .64153 .24997 L 0 .186 .682 r
F P
0 g
s
.64366 .25084 m .62067 .23361 L .61847 .23317 L p 0 .311 .659 r
F P
0 g
s
.61847 .23317 m .58768 .22693 L p .60538 .23449 L 0 .311 .659 r
F P
0 g
s
.60538 .23449 m .64366 .25084 L .61847 .23317 L 0 .311 .659 r
F
.58768 .22693 m .6098 .23631 L p .62496 .24285 L F P
0 g
s
.6098 .23631 m .61012 .23645 L p .62496 .24285 L 0 .311 .659 r
F P
0 g
s
.57679 .23738 m .61012 .23645 L p .59118 .23593 L .25 0 0 r
F P
0 g
s
.55462 .23492 m .57679 .23738 L p .59118 .23593 L .25 0 0 r
F P
0 g
s
.61012 .23645 m .64366 .25084 L p .62496 .24285 L 0 .311 .659 r
F P
0 g
s
.65109 .25824 m .65894 .26418 L .66141 .26658 L 0 .186 .682 r
F
.65598 .26131 m .67788 .27991 L p .66141 .26658 L F P
0 g
s
.66925 .27415 m .67444 .27806 L .67966 .28462 L .047 .287 .778 r
F
.70275 .3115 m .67788 .27991 L .65691 .2621 L p 0 .033 .553 r
F P
0 g
s
.66452 .27226 m .66998 .27787 L .66626 .27337 L 0 .033 .553 r
F
.66998 .27787 m .70275 .3115 L .65691 .2621 L F
.65691 .2621 m .64366 .25084 L p .66452 .27226 L F P
0 g
s
.66452 .27226 m .66626 .27337 L .65691 .2621 L 0 .033 .553 r
F
.64366 .25084 m .6672 .27432 L p .68161 .2897 L F P
0 g
s
.64366 .25084 m .68161 .2897 L .67695 .28502 L 0 .033 .553 r
F
.6672 .27432 m .66751 .27463 L p .68424 .2925 L F P
0 g
s
.70933 .32197 m .68566 .29836 L .65226 .26177 L p .173 .322 .775 r
F P
0 g
s
.63322 .25221 m .66751 .27463 L p .64873 .26214 L .432 0 0 r
F P
0 g
s
.61012 .23645 m .633 .25206 L p .64873 .26214 L .432 0 0 r
F P
0 g
s
.633 .25206 m .63322 .25221 L p .64873 .26214 L .432 0 0 r
F P
0 g
s
.67695 .28502 m .68161 .2897 L .68424 .2925 L 0 .033 .553 r
F
.66751 .27463 m .70275 .3115 L p .68424 .2925 L F P
0 g
s
.69972 .30983 m .71117 .32414 L .70587 .31756 L 0 .176 .707 r
F
.70275 .3115 m .66751 .27463 L p .68996 .30186 L 0 0 .468 r
F P
0 g
s
.68996 .30186 m .69401 .30677 L .69113 .30286 L 0 0 .468 r
F
.69401 .30677 m .72879 .34895 L .69113 .30286 L F
.70486 .31454 m .70275 .3115 L p .68996 .30186 L F P
0 g
s
.66751 .27463 m .69471 .3074 L .70897 .32489 L 0 0 .468 r
F
.66751 .27463 m .70897 .32489 L .70461 .31963 L F
.66751 .27463 m .69236 .30453 L .69471 .3074 L p F P
0 g
s
.69236 .30453 m .71832 .33985 L .74608 .37761 L p .57 .124 0 r
F P
0 g
s
.74608 .37761 m .75608 .39119 L p .73498 .3625 L .57 .124 0 r
F P
0 g
s
.69236 .30453 m .74608 .37761 L .73498 .3625 L .57 .124 0 r
F
.72879 .34895 m .70486 .31454 L p .69113 .30286 L 0 0 .468 r
F P
0 g
s
.63322 .25221 m .65712 .27391 L .65752 .27426 L p .518 0 0 r
F P
0 g
s
.65752 .27426 m .69236 .30453 L p .67367 .288 L .518 0 0 r
F P
0 g
s
.63322 .25221 m .65752 .27426 L .67367 .288 L .518 0 0 r
F
.70461 .31963 m .70897 .32489 L .71113 .32754 L 0 0 .468 r
F
.67788 .27991 m .65407 .25492 L .63461 .24251 L p 0 .186 .682 r
F P
0 g
s
.69471 .3074 m .72879 .34895 L p .71113 .32754 L 0 0 .468 r
F P
0 g
s
.75409 .38575 m .7666 .40394 L p .74262 .36922 L 0 0 .419 r
F P
0 g
s
.76108 .39356 m .77706 .41779 L p .7499 .37706 L 0 0 .435 r
F P
0 g
s
.79365 .44381 m .81607 .47899 L p .78651 .43234 L .622 .195 0 r
F P
0 g
s
.76125 .39247 m .79365 .44381 L .78651 .43234 L .622 .195 0 r
F
.74968 .37421 m .75826 .38786 L p .76125 .39247 L F P
0 g
s
.75826 .38786 m .77706 .41779 L p .76125 .39247 L .622 .195 0 r
F P
0 g
s
.79149 .43905 m .78547 .43009 L p .78936 .43576 L 0 0 .507 r
F P
0 g
s
.65449 .26345 m .65226 .26177 L p .63948 .25159 L .294 .434 .832 r
F P
0 g
s
.79851 .49798 m .77486 .48646 L .7408 .44652 L p .443 .436 .756 r
F P
0 g
s
.7408 .44652 m .76381 .45573 L .79851 .49798 L p .443 .436 .756 r
F P
0 g
s
.62666 .59775 m .60604 .62935 L .57389 .62863 L p .75 .565 .646 r
F P
0 g
s
.57389 .62863 m .59453 .58741 L .62666 .59775 L p .75 .565 .646 r
F P
0 g
s
.78774 .47127 m .76381 .45573 L .72956 .41256 L p .386 .401 .753 r
F P
0 g
s
.72956 .41256 m .75276 .42535 L .78774 .47127 L p .386 .401 .753 r
F P
0 g
s
.77694 .44481 m .75276 .42535 L .7184 .37994 L p .319 .363 .75 r
F P
0 g
s
.7184 .37994 m .74176 .3961 L .77694 .44481 L p .319 .363 .75 r
F P
0 g
s
.86338 .59774 m .84037 .5968 L .80744 .57376 L p .55 .563 .82 r
F P
0 g
s
.80744 .57376 m .83018 .57421 L .86338 .59774 L p .55 .563 .82 r
F P
0 g
s
.90516 .63002 m .92829 .6288 L .93677 .64013 L closepath p .528 .711 .956 r
F P
0 g
s
.59453 .58741 m .57389 .62863 L .5414 .61767 L p .757 .583 .661 r
F P
0 g
s
.5414 .61767 m .56233 .58048 L .59453 .58741 L p .757 .583 .661 r
F P
0 g
s
.4618 .3424 m .44039 .37843 L .40661 .39679 L p .875 .758 .729 r
F P
0 g
s
.40661 .39679 m .42839 .36165 L .4618 .3424 L p .875 .758 .729 r
F P
0 g
s
.51332 .24955 m .49234 .27128 L .45915 .29449 L p .897 .938 .832 r
F P
0 g
s
.45915 .29449 m .48047 .27032 L .51332 .24955 L p .897 .938 .832 r
F P
0 g
s
.51856 .52069 m .49735 .56968 L .46451 .56581 L p .775 .587 .645 r
F P
0 g
s
.46451 .56581 m .48606 .51942 L .51856 .52069 L p .775 .587 .645 r
F P
0 g
s
.4635 .43487 m .44194 .47716 L .40856 .48349 L p .81 .645 .677 r
F P
0 g
s
.40856 .48349 m .43045 .44315 L .4635 .43487 L p .81 .645 .677 r
F P
0 g
s
.76615 .41919 m .74176 .3961 L .70735 .3495 L p .242 .322 .747 r
F P
0 g
s
.70735 .3495 m .73084 .36867 L .76615 .41919 L p .242 .322 .747 r
F P
0 g
s
.49234 .27128 m .47123 .29781 L .43766 .32229 L p .914 .907 .801 r
F P
0 g
s
.43766 .32229 m .45915 .29449 L .49234 .27128 L p .914 .907 .801 r
F P
0 g
s
.89613 .61593 m .87299 .61568 L .84037 .5968 L p .522 .612 .883 r
F P
0 g
s
.84037 .5968 m .86338 .59774 L .89613 .61593 L p .522 .612 .883 r
F P
0 g
s
.92829 .6288 m .90516 .63002 L .87299 .61568 L p .501 .675 .943 r
F P
0 g
s
.47482 .47335 m .45327 .51786 L .42009 .51931 L p .792 .617 .663 r
F P
0 g
s
.42009 .51931 m .44194 .47716 L .47482 .47335 L p .792 .617 .663 r
F P
0 g
s
.85356 .57845 m .83018 .57421 L .79674 .54613 L p .5 .523 .812 r
F P
0 g
s
.79674 .54613 m .81978 .54995 L .85356 .57845 L p .5 .523 .812 r
F P
0 g
s
.45206 .40296 m .43045 .44315 L .39676 .45449 L p .835 .685 .696 r
F P
0 g
s
.39676 .45449 m .4187 .41624 L .45206 .40296 L p .835 .685 .696 r
F P
0 g
s
.87299 .61568 m .89613 .61593 L .92829 .6288 L p .501 .675 .943 r
F P
0 g
s
.56233 .58048 m .5414 .61767 L .50877 .61238 L p .766 .597 .669 r
F P
0 g
s
.50877 .61238 m .52995 .57637 L .56233 .58048 L p .766 .597 .669 r
F P
0 g
s
.47123 .29781 m .44993 .32829 L .41597 .35278 L p .918 .878 .78 r
F P
0 g
s
.41597 .35278 m .43766 .32229 L .47123 .29781 L p .918 .878 .78 r
F P
0 g
s
.75541 .39497 m .73084 .36867 L .69643 .32207 L p .151 .277 .74 r
F P
0 g
s
.69643 .32207 m .72003 .34376 L .75541 .39497 L p .151 .277 .74 r
F P
0 g
s
.84354 .55797 m .81978 .54995 L .78586 .51682 L p .442 .48 .803 r
F P
0 g
s
.78586 .51682 m .80921 .52438 L .84354 .55797 L p .442 .48 .803 r
F P
0 g
s
.48606 .51942 m .46451 .56581 L .43132 .5654 L p .774 .585 .643 r
F P
0 g
s
.43132 .5654 m .45327 .51786 L .48606 .51942 L p .774 .585 .643 r
F P
0 g
s
.83336 .53655 m .80921 .52438 L .77486 .48646 L p .374 .433 .794 r
F P
0 g
s
.77486 .48646 m .79851 .49798 L .83336 .53655 L p .374 .433 .794 r
F P
0 g
s
.88693 .60103 m .86338 .59774 L .83018 .57421 L p .457 .564 .875 r
F P
0 g
s
.83018 .57421 m .85356 .57845 L .88693 .60103 L p .457 .564 .875 r
F P
0 g
s
.44039 .37843 m .4187 .41624 L .38459 .43251 L p .867 .744 .724 r
F P
0 g
s
.38459 .43251 m .40661 .39679 L .44039 .37843 L p .867 .744 .724 r
F P
0 g
s
.52995 .57637 m .50877 .61238 L .47585 .61279 L p .76 .575 .647 r
F P
0 g
s
.47585 .61279 m .49735 .56968 L .52995 .57637 L p .76 .575 .647 r
F P
0 g
s
.82305 .5145 m .79851 .49798 L .76381 .45573 L p .297 .382 .781 r
F P
0 g
s
.76381 .45573 m .78774 .47127 L .82305 .5145 L p .297 .382 .781 r
F P
0 g
s
.89613 .61593 m .91967 .6173 L .92829 .6288 L closepath p .454 .672 .957 r
F P
0 g
s
.44993 .32829 m .42839 .36165 L .39406 .38496 L p .914 .85 .767 r
F P
0 g
s
.39406 .38496 m .41597 .35278 L .44993 .32829 L p .914 .85 .767 r
F P
0 g
s
.91967 .6173 m .89613 .61593 L .86338 .59774 L p .417 .626 .939 r
F P
0 g
s
.86338 .59774 m .88693 .60103 L .91967 .6173 L p .417 .626 .939 r
F P
0 g
s
.44194 .47716 m .42009 .51931 L .38641 .52377 L p .802 .635 .675 r
F P
0 g
s
.38641 .52377 m .40856 .48349 L .44194 .47716 L p .802 .635 .675 r
F P
0 g
s
.43045 .44315 m .40856 .48349 L .37462 .49172 L p .827 .678 .698 r
F P
0 g
s
.37462 .49172 m .39676 .45449 L .43045 .44315 L p .827 .678 .698 r
F P
0 g
s
.81264 .49218 m .78774 .47127 L .75276 .42535 L p .209 .326 .765 r
F P
0 g
s
.75276 .42535 m .77694 .44481 L .81264 .49218 L p .209 .326 .765 r
F P
0 g
s
.87755 .58536 m .85356 .57845 L .81978 .54995 L p .377 .508 .863 r
F P
0 g
s
.81978 .54995 m .84354 .55797 L .87755 .58536 L p .377 .508 .863 r
F P
0 g
s
.49735 .56968 m .47585 .61279 L .44285 .6029 L p .767 .597 .667 r
F P
0 g
s
.44285 .6029 m .46451 .56581 L .49735 .56968 L p .767 .597 .667 r
F P
0 g
s
.45327 .51786 m .43132 .5654 L .39792 .56239 L p .784 .605 .658 r
F P
0 g
s
.39792 .56239 m .42009 .51931 L .45327 .51786 L p .784 .605 .658 r
F P
0 g
s
.80217 .46997 m .77694 .44481 L .74176 .3961 L p .113 .266 .743 r
F P
0 g
s
.74176 .3961 m .76615 .41919 L .80217 .46997 L p .113 .266 .743 r
F P
0 g
s
.4187 .41624 m .39676 .45449 L .3624 .46761 L p .856 .73 .723 r
F P
0 g
s
.3624 .46761 m .38459 .43251 L .4187 .41624 L p .856 .73 .723 r
F P
0 g
s
.42839 .36165 m .40661 .39679 L .37196 .41779 L p .903 .826 .76 r
F P
0 g
s
.37196 .41779 m .39406 .38496 L .42839 .36165 L p .903 .826 .76 r
F P
0 g
s
.868 .569 m .84354 .55797 L .80921 .52438 L p .283 .442 .843 r
F P
0 g
s
.80921 .52438 m .83336 .53655 L .868 .569 L p .283 .442 .843 r
F P
0 g
s
.50169 .25055 m .48047 .27032 L .47482 .27515 L p .763 .986 .752 r
F P
0 g
s
.47482 .27515 m .44659 .29932 L p .47796 .27155 L .763 .986 .752 r
F P
0 g
s
.47796 .27155 m .50169 .25055 L .47482 .27515 L .763 .986 .752 r
F
.44659 .29932 m .46817 .27755 L .50169 .25055 L p F P
0 g
s
.5229 .23586 m .50169 .25055 L .48922 .26059 L p .619 .936 .713 r
F P
0 g
s
.48922 .26059 m .46817 .27755 L p .49653 .25595 L .619 .936 .713 r
F P
0 g
s
.49653 .25595 m .5229 .23586 L .48922 .26059 L .619 .936 .713 r
F
.48967 .2597 m .5229 .23586 L p .48177 .26719 L F P
0 g
s
.54422 .2268 m .5229 .23586 L .50721 .24711 L p .422 .835 .653 r
F P
0 g
s
.50721 .24711 m .48967 .2597 L p .51623 .24368 L .422 .835 .653 r
F P
0 g
s
.51623 .24368 m .54422 .2268 L .50721 .24711 L .422 .835 .653 r
F
.48967 .2597 m .51118 .24633 L .51779 .24242 L p F P
0 g
s
.51779 .24242 m .54422 .2268 L p .50829 .24846 L .422 .835 .653 r
F P
0 g
s
.48967 .2597 m .51779 .24242 L .50829 .24846 L .422 .835 .653 r
F
.51118 .24633 m .53279 .23797 L .54471 .23283 L p 0 0 0 r
F P
0 g
s
.54471 .23283 m .56576 .22375 L p .53354 .23708 L 0 0 0 r
F P
0 g
s
.51118 .24633 m .54471 .23283 L .53354 .23708 L 0 0 0 r
F
.46817 .27755 m .48473 .26379 L p .48177 .26719 L .619 .936 .713 r
F P
0 g
s
.48473 .26379 m .48967 .2597 L p .48177 .26719 L .619 .936 .713 r
F P
0 g
s
.91094 .60564 m .88693 .60103 L .85356 .57845 L p .307 .557 .924 r
F P
0 g
s
.85356 .57845 m .87755 .58536 L .91094 .60564 L p .307 .557 .924 r
F P
0 g
s
.48047 .27032 m .45915 .29449 L .42488 .32431 L p .853 .997 .774 r
F P
0 g
s
.42488 .32431 m .44659 .29932 L .48047 .27032 L p .853 .997 .774 r
F P
0 g
s
.46451 .56581 m .44285 .6029 L .40957 .59721 L p .778 .629 .695 r
F P
0 g
s
.40957 .59721 m .43132 .5654 L .46451 .56581 L p .778 .629 .695 r
F P
0 g
s
.79166 .44828 m .76615 .41919 L .73084 .36867 L p .009 .203 .715 r
F P
0 g
s
.73084 .36867 m .75541 .39497 L .79166 .44828 L p .009 .203 .715 r
F P
0 g
s
.45915 .29449 m .43766 .32229 L .40301 .3517 L p .901 .984 .784 r
F P
0 g
s
.40301 .3517 m .42488 .32431 L .45915 .29449 L p .901 .984 .784 r
F P
0 g
s
.88693 .60103 m .91094 .60564 L .91967 .6173 L closepath p .351 .613 .948 r
F P
0 g
s
.8583 .55207 m .83336 .53655 L .79851 .49798 L p .176 .367 .815 r
F P
0 g
s
.79851 .49798 m .82305 .5145 L .8583 .55207 L p .176 .367 .815 r
F P
0 g
s
.42009 .51931 m .39792 .56239 L .36417 .56068 L p .796 .638 .685 r
F P
0 g
s
.36417 .56068 m .38641 .52377 L .42009 .51931 L p .796 .638 .685 r
F P
0 g
s
.40856 .48349 m .38641 .52377 L .35234 .52748 L p .813 .665 .699 r
F P
0 g
s
.35234 .52748 m .37462 .49172 L .40856 .48349 L p .813 .665 .699 r
F P
0 g
s
.40661 .39679 m .38459 .43251 L .34971 .4502 L p .889 .803 .758 r
F P
0 g
s
.34971 .4502 m .37196 .41779 L .40661 .39679 L p .889 .803 .758 r
F P
0 g
s
.43766 .32229 m .41597 .35278 L .38097 .38063 L p .921 .959 .789 r
F P
0 g
s
.38097 .38063 m .40301 .3517 L .43766 .32229 L p .921 .959 .789 r
F P
0 g
s
.90208 .59381 m .87755 .58536 L .84354 .55797 L p .173 .468 .889 r
F P
0 g
s
.84354 .55797 m .868 .569 L .90208 .59381 L p .173 .468 .889 r
F P
0 g
s
.39676 .45449 m .37462 .49172 L .34012 .50093 L p .841 .716 .726 r
F P
0 g
s
.34012 .50093 m .3624 .46761 L .39676 .45449 L p .841 .716 .726 r
F P
0 g
s
.56576 .22375 m .54422 .2268 L .51118 .24633 L p 0 0 0 r
F P
0 g
s
.84846 .53472 m .82305 .5145 L .78774 .47127 L p .06 .286 .775 r
F P
0 g
s
.78774 .47127 m .81264 .49218 L .84846 .53472 L p .06 .286 .775 r
F P
0 g
s
.43132 .5654 m .40957 .59721 L .37587 .59605 L p .769 .61 .682 r
F P
0 g
s
.37587 .59605 m .39792 .56239 L .43132 .5654 L p .769 .61 .682 r
F P
0 g
s
.41597 .35278 m .39406 .38496 L .35877 .41019 L p .924 .93 .793 r
F P
0 g
s
.35877 .41019 m .38097 .38063 L .41597 .35278 L p .924 .93 .793 r
F P
0 g
s
.87755 .58536 m .90208 .59381 L .91094 .60564 L closepath p .219 .529 .921 r
F P
0 g
s
.8385 .51713 m .81264 .49218 L .77694 .44481 L p 0 .202 .727 r
F P
0 g
s
.77694 .44481 m .80217 .46997 L .8385 .51713 L p 0 .202 .727 r
F P
0 g
s
.38641 .52377 m .36417 .56068 L .32997 .56141 L p .795 .646 .697 r
F P
0 g
s
.32997 .56141 m .35234 .52748 L .38641 .52377 L p .795 .646 .697 r
F P
0 g
s
.89308 .5818 m .868 .569 L .83336 .53655 L p .023 .36 .832 r
F P
0 g
s
.83336 .53655 m .8583 .55207 L .89308 .5818 L p .023 .36 .832 r
F P
0 g
s
.38459 .43251 m .3624 .46761 L .32739 .48119 L p .871 .782 .76 r
F P
0 g
s
.32739 .48119 m .34971 .4502 L .38459 .43251 L p .871 .782 .76 r
F P
0 g
s
.39792 .56239 m .37587 .59605 L .34218 .58898 L p .773 .636 .71 r
F P
0 g
s
.34218 .58898 m .36417 .56068 L .39792 .56239 L p .773 .636 .71 r
F P
0 g
s
.37462 .49172 m .35234 .52748 L .31784 .5314 L p .823 .704 .733 r
F P
0 g
s
.31784 .5314 m .34012 .50093 L .37462 .49172 L p .823 .704 .733 r
F P
0 g
s
.58768 .22693 m .56576 .22375 L .53279 .23797 L p .052 0 0 r
F P
0 g
s
.82845 .4995 m .80217 .46997 L .76615 .41919 L p 0 .121 .672 r
F P
0 g
s
.76615 .41919 m .79166 .44828 L .82845 .4995 L p 0 .121 .672 r
F P
0 g
s
.39406 .38496 m .37196 .41779 L .33647 .43948 L p .915 .899 .797 r
F P
0 g
s
.33647 .43948 m .35877 .41019 L .39406 .38496 L p .915 .899 .797 r
F P
0 g
s
.88396 .56962 m .8583 .55207 L .82305 .5145 L p 0 .244 .756 r
F P
0 g
s
.82305 .5145 m .84846 .53472 L .88396 .56962 L p 0 .244 .756 r
F P
0 g
s
.868 .569 m .89308 .5818 L .90208 .59381 L closepath p .062 .421 .867 r
F P
0 g
s
.3624 .46761 m .34012 .50093 L .30509 .50981 L p .85 .763 .765 r
F P
0 g
s
.30509 .50981 m .32739 .48119 L .3624 .46761 L p .85 .763 .765 r
F P
0 g
s
.36417 .56068 m .34218 .58898 L .30821 .5832 L p .781 .692 .766 r
F P
0 g
s
.30821 .5832 m .32997 .56141 L .36417 .56068 L p .781 .692 .766 r
F P
0 g
s
.46817 .27755 m .44659 .29932 L .41151 .3339 L p .52 .832 .518 r
F P
0 g
s
.41151 .3339 m .43347 .31189 L .46817 .27755 L p .52 .832 .518 r
F P
0 g
s
.44659 .29932 m .42488 .32431 L .38944 .35795 L p .665 .921 .617 r
F P
0 g
s
.38944 .35795 m .41151 .3339 L .44659 .29932 L p .665 .921 .617 r
F P
0 g
s
.48967 .2597 m .46817 .27755 L .43347 .31189 L p 0 0 0 r
F P
0 g
s
.51118 .24633 m .48967 .2597 L .45534 .2926 L p 0 0 0 r
F P
0 g
s
.43347 .31189 m .45534 .2926 L .48967 .2597 L p 0 0 0 r
F P
0 g
s
.35234 .52748 m .32997 .56141 L .29558 .55967 L p .798 .677 .73 r
F P
0 g
s
.29558 .55967 m .31784 .5314 L .35234 .52748 L p .798 .677 .73 r
F P
0 g
s
.37196 .41779 m .34971 .4502 L .31411 .46763 L p .898 .869 .801 r
F P
0 g
s
.31411 .46763 m .33647 .43948 L .37196 .41779 L p .898 .869 .801 r
F P
0 g
s
.42488 .32431 m .40301 .3517 L .36725 .38332 L p .777 .977 .701 r
F P
0 g
s
.36725 .38332 m .38944 .35795 L .42488 .32431 L p .777 .977 .701 r
F P
0 g
s
.53279 .23797 m .51118 .24633 L .47716 .27663 L p 0 0 0 r
F P
0 g
s
.45534 .2926 m .47716 .27663 L .51118 .24633 L p 0 0 0 r
F P
0 g
s
.87469 .55725 m .84846 .53472 L .81264 .49218 L p 0 .132 .67 r
F P
0 g
s
.81264 .49218 m .8385 .51713 L .87469 .55725 L p 0 .132 .67 r
F P
0 g
s
.34012 .50093 m .31784 .5314 L .28287 .53578 L p .825 .739 .769 r
F P
0 g
s
.28287 .53578 m .30509 .50981 L .34012 .50093 L p .825 .739 .769 r
F P
0 g
s
.61012 .23645 m .58768 .22693 L .55462 .23492 L p .25 0 0 r
F P
0 g
s
.53279 .23797 m .55462 .23492 L .58768 .22693 L p .052 0 0 r
F P
0 g
s
.40301 .3517 m .38097 .38063 L .34495 .40924 L p .848 .996 .764 r
F P
0 g
s
.34495 .40924 m .36725 .38332 L .40301 .3517 L p .848 .996 .764 r
F P
0 g
s
.32997 .56141 m .30821 .5832 L .27382 .58001 L p .767 .681 .768 r
F P
0 g
s
.27382 .58001 m .29558 .55967 L .32997 .56141 L p .767 .681 .768 r
F P
0 g
s
.8583 .55207 m .88396 .56962 L .89308 .5818 L closepath p 0 .296 .787 r
F P
0 g
s
.34971 .4502 m .32739 .48119 L .2918 .49386 L p .876 .84 .807 r
F P
0 g
s
.2918 .49386 m .31411 .46763 L .34971 .4502 L p .876 .84 .807 r
F P
0 g
s
.55462 .23492 m .53279 .23797 L .49902 .26446 L p .111 0 0 r
F P
0 g
s
.47716 .27663 m .49902 .26446 L .53279 .23797 L p 0 0 0 r
F P
0 g
s
.31784 .5314 m .29558 .55967 L .26089 .55782 L p .8 .729 .785 r
F P
0 g
s
.26089 .55782 m .28287 .53578 L .31784 .5314 L p .8 .729 .785 r
F P
0 g
s
.38097 .38063 m .35877 .41019 L .3226 .43497 L p .884 .988 .806 r
F P
0 g
s
.3226 .43497 m .34495 .40924 L .38097 .38063 L p .884 .988 .806 r
F P
0 g
s
.86529 .5447 m .8385 .51713 L .80217 .46997 L p 0 .033 .585 r
F P
0 g
s
.80217 .46997 m .82845 .4995 L .86529 .5447 L p 0 .033 .585 r
F P
0 g
s
.32739 .48119 m .30509 .50981 L .26961 .51748 L p .849 .813 .815 r
F P
0 g
s
.26961 .51748 m .2918 .49386 L .32739 .48119 L p .849 .813 .815 r
F P
0 g
s
.29558 .55967 m .27382 .58001 L .23936 .57433 L p .757 .711 .809 r
F P
0 g
s
.23936 .57433 m .26089 .55782 L .29558 .55967 L p .757 .711 .809 r
F P
0 g
s
.35877 .41019 m .33647 .43948 L .30023 .45981 L p .892 .963 .833 r
F P
0 g
s
.30023 .45981 m .3226 .43497 L .35877 .41019 L p .892 .963 .833 r
F P
0 g
s
.84846 .53472 m .87469 .55725 L .88396 .56962 L closepath p 0 .169 .69 r
F P
0 g
s
.30509 .50981 m .28287 .53578 L .24759 .53847 L p .818 .781 .818 r
F P
0 g
s
.24759 .53847 m .26961 .51748 L .30509 .50981 L p .818 .781 .818 r
F P
0 g
s
.57679 .23738 m .55462 .23492 L .52098 .25653 L p .235 0 0 r
F P
0 g
s
.49902 .26446 m .52098 .25653 L .55462 .23492 L p .111 0 0 r
F P
0 g
s
.85574 .53196 m .82845 .4995 L .79166 .44828 L p 0 0 .51 r
F P
0 g
s
.79166 .44828 m .8183 .48204 L .85574 .53196 L p 0 0 .51 r
F P
0 g
s
.66751 .27463 m .64366 .25084 L .61012 .23645 L p .432 0 0 r
F P
0 g
s
.26089 .55782 m .23936 .57433 L .20466 .56868 L p .734 .77 .881 r
F P
0 g
s
.28287 .53578 m .26089 .55782 L .22583 .55659 L p .785 .751 .822 r
F P
0 g
s
.22583 .55659 m .24759 .53847 L .28287 .53578 L p .785 .751 .822 r
F P
0 g
s
.33647 .43948 m .31411 .46763 L .27793 .48312 L p .88 .93 .85 r
F P
0 g
s
.27793 .48312 m .30023 .45981 L .33647 .43948 L p .88 .93 .85 r
F P
0 g
s
.63322 .25221 m .61012 .23645 L .57679 .23738 L p .4 0 0 r
F P
0 g
s
.20466 .56868 m .22583 .55659 L .26089 .55782 L p .734 .77 .881 r
F P
0 g
s
.31411 .46763 m .2918 .49386 L .25575 .50437 L p .857 .893 .861 r
F P
0 g
s
.25575 .50437 m .27793 .48312 L .31411 .46763 L p .857 .893 .861 r
F P
0 g
s
.22583 .55659 m .20466 .56868 L .16964 .56386 L p .71 .761 .892 r
F P
0 g
s
.45534 .2926 m .43347 .31189 L .39745 .35046 L p 0 0 0 r
F P
0 g
s
.38944 .35795 m .35283 .39236 L p .39086 .35447 L 0 0 0 r
F P
0 g
s
.41151 .3339 m .40443 .34162 L p .39086 .35447 L 0 0 0 r
F P
0 g
s
.40443 .34162 m .38944 .35795 L p .39086 .35447 L 0 0 0 r
F P
0 g
s
.37517 .37089 m .41151 .3339 L p .37098 .37428 L 0 0 0 r
F P
0 g
s
.35283 .39236 m .37517 .37089 L p .37098 .37428 L 0 0 0 r
F P
0 g
s
.33045 .41426 m .35283 .39236 L .38944 .35795 L p .553 .862 .562 r
F P
0 g
s
.35283 .39236 m .33045 .41426 L .29284 .44168 L p 0 0 0 r
F P
0 g
s
.29284 .44168 m .31523 .42431 L .35283 .39236 L p 0 0 0 r
F P
0 g
s
.37517 .37089 m .35283 .39236 L .31523 .42431 L p 0 0 0 r
F P
0 g
s
.37517 .37089 m .33768 .40681 L p .3794 .36748 L 0 0 0 r
F P
0 g
s
.38944 .35795 m .36725 .38332 L .33045 .41426 L p .553 .862 .562 r
F P
0 g
s
.39745 .35046 m .37517 .37089 L p .3794 .36748 L 0 0 0 r
F P
0 g
s
.33768 .40681 m .37517 .37089 L p .3476 .39546 L 0 0 0 r
F P
0 g
s
.31523 .42431 m .32609 .41585 L p .3476 .39546 L 0 0 0 r
F P
0 g
s
.32609 .41585 m .33768 .40681 L p .3476 .39546 L 0 0 0 r
F P
0 g
s
.43347 .31189 m .41151 .3339 L .37517 .37089 L p 0 0 0 r
F P
0 g
s
.37517 .37089 m .39745 .35046 L .43347 .31189 L p 0 0 0 r
F P
0 g
s
.47716 .27663 m .45534 .2926 L .41968 .33162 L p 0 0 0 r
F P
0 g
s
.39745 .35046 m .41968 .33162 L .45534 .2926 L p 0 0 0 r
F P
0 g
s
.8385 .51713 m .86529 .5447 L .87469 .55725 L closepath p 0 .054 .591 r
F P
0 g
s
.2918 .49386 m .26961 .51748 L .23377 .52321 L p .827 .856 .868 r
F P
0 g
s
.23377 .52321 m .25575 .50437 L .2918 .49386 L p .827 .856 .868 r
F P
0 g
s
.49902 .26446 m .47716 .27663 L .44188 .31492 L p .088 0 0 r
F P
0 g
s
.41968 .33162 m .44188 .31492 L .47716 .27663 L p 0 0 0 r
F P
0 g
s
.24759 .53847 m .22583 .55659 L .19062 .55339 L p .758 .78 .872 r
F P
0 g
s
.16964 .56386 m .19062 .55339 L .22583 .55659 L p .71 .761 .892 r
F P
0 g
s
.26961 .51748 m .24759 .53847 L .21206 .53942 L p .793 .822 .875 r
F P
0 g
s
.21206 .53942 m .23377 .52321 L .26961 .51748 L p .793 .822 .875 r
F P
0 g
s
.19062 .55339 m .21206 .53942 L .24759 .53847 L p .758 .78 .872 r
F P
0 g
s
.57679 .23738 m .59943 .24542 L .63322 .25221 L p .4 0 0 r
F P
0 g
s
.59943 .24542 m .57679 .23738 L .54314 .25311 L p .341 0 0 r
F P
0 g
s
.52098 .25653 m .54314 .25311 L .57679 .23738 L p .235 0 0 r
F P
0 g
s
.19062 .55339 m .16964 .56386 L .13445 .5582 L p .682 .773 .92 r
F P
0 g
s
.36725 .38332 m .34495 .40924 L .30806 .43601 L p .681 .951 .692 r
F P
0 g
s
.30806 .43601 m .33045 .41426 L .36725 .38332 L p .681 .951 .692 r
F P
0 g
s
.52098 .25653 m .49902 .26446 L .46407 .30083 L p .17 0 0 r
F P
0 g
s
.44188 .31492 m .46407 .30083 L .49902 .26446 L p .088 0 0 r
F P
0 g
s
.34495 .40924 m .3226 .43497 L .28571 .45708 L p .771 .994 .794 r
F P
0 g
s
.28571 .45708 m .30806 .43601 L .34495 .40924 L p .771 .994 .794 r
F P
0 g
s
.21206 .53942 m .19062 .55339 L .1552 .5495 L p .716 .805 .92 r
F P
0 g
s
.13445 .5582 m .1552 .5495 L .19062 .55339 L p .682 .773 .92 r
F P
0 g
s
.82845 .4995 m .85574 .53196 L .86529 .5447 L closepath p 0 0 .5 r
F P
0 g
s
.1552 .5495 m .13445 .5582 L .09901 .55254 L p .655 .782 .942 r
F P
0 g
s
.3226 .43497 m .30023 .45981 L .26344 .47699 L p .815 .995 .86 r
F P
0 g
s
.26344 .47699 m .28571 .45708 L .3226 .43497 L p .815 .995 .86 r
F P
0 g
s
.23377 .52321 m .21206 .53942 L .17629 .53891 L p .75 .839 .919 r
F P
0 g
s
.1552 .5495 m .17629 .53891 L .21206 .53942 L p .716 .805 .92 r
F P
0 g
s
.54314 .25311 m .52098 .25653 L .48632 .28975 L p .242 0 .004 r
F P
0 g
s
.46407 .30083 m .48632 .28975 L .52098 .25653 L p .17 0 0 r
F P
0 g
s
.30023 .45981 m .27793 .48312 L .24131 .49533 L p .823 .967 .897 r
F P
0 g
s
.24131 .49533 m .26344 .47699 L .30023 .45981 L p .823 .967 .897 r
F P
0 g
s
.69236 .30453 m .66751 .27463 L .63322 .25221 L p .518 0 0 r
F P
0 g
s
.65712 .27391 m .63322 .25221 L .59943 .24542 L p .5 0 0 r
F P
0 g
s
.25575 .50437 m .23377 .52321 L .1977 .52636 L p .781 .881 .919 r
F P
0 g
s
.17629 .53891 m .1977 .52636 L .23377 .52321 L p .75 .839 .919 r
F P
0 g
s
.27793 .48312 m .25575 .50437 L .21938 .51184 L p .808 .925 .913 r
F P
0 g
s
.21938 .51184 m .24131 .49533 L .27793 .48312 L p .808 .925 .913 r
F P
0 g
s
.1977 .52636 m .21938 .51184 L .25575 .50437 L p .781 .881 .919 r
F P
0 g
s
.09901 .55254 m .11955 .54515 L .1552 .5495 L p .655 .782 .942 r
F P
0 g
s
.11955 .54515 m .09901 .55254 L .06332 .54689 L p .649 .769 .936 r
F P
0 g
s
.17629 .53891 m .1552 .5495 L .11955 .54515 L p .68 .8 .939 r
F P
0 g
s
.59943 .24542 m .62268 .25894 L .65712 .27391 L p .5 0 0 r
F P
0 g
s
.62268 .25894 m .59943 .24542 L .56562 .25433 L p .43 0 0 r
F P
0 g
s
.54314 .25311 m .56562 .25433 L .59943 .24542 L p .341 0 0 r
F P
0 g
s
.8183 .48204 m .84605 .51902 L .85574 .53196 L closepath p 0 0 .425 r
F P
0 g
s
.1977 .52636 m .17629 .53891 L .14038 .53649 L p .7 .834 .947 r
F P
0 g
s
.11955 .54515 m .14038 .53649 L .17629 .53891 L p .68 .8 .939 r
F P
0 g
s
.06332 .54689 m .08375 .53974 L .11955 .54515 L p .649 .769 .936 r
F P
0 g
s
.08375 .53974 m .06332 .54689 L .02741 .541 L p .643 .768 .939 r
F P
0 g
s
.56562 .25433 m .54314 .25311 L .50869 .28202 L p .306 0 .005 r
F P
0 g
s
.48632 .28975 m .50869 .28202 L .54314 .25311 L p .242 0 .004 r
F P
0 g
s
.14038 .53649 m .11955 .54515 L .08375 .53974 L p .655 .785 .943 r
F P
0 g
s
.21938 .51184 m .1977 .52636 L .16148 .52673 L p .719 .878 .955 r
F P
0 g
s
.14038 .53649 m .16148 .52673 L .1977 .52636 L p .7 .834 .947 r
F P
0 g
s
.02741 .541 m .04773 .53409 L .08375 .53974 L p .643 .768 .939 r
F P
0 g
s
.24131 .49533 m .21938 .51184 L .18284 .51575 L p .735 .925 .955 r
F P
0 g
s
.16148 .52673 m .18284 .51575 L .21938 .51184 L p .719 .878 .955 r
F P
0 g
s
.16148 .52673 m .14038 .53649 L .10438 .53224 L p .657 .815 .96 r
F P
0 g
s
.08375 .53974 m .10438 .53224 L .14038 .53649 L p .655 .785 .943 r
F P
0 g
s
.10438 .53224 m .08375 .53974 L .04773 .53409 L p .642 .778 .946 r
F P
0 g
s
.41968 .33162 m .39745 .35046 L .36016 .38959 L p .041 0 0 r
F P
0 g
s
.33768 .40681 m .36016 .38959 L .39745 .35046 L p 0 0 0 r
F P
0 g
s
.44188 .31492 m .41968 .33162 L .38265 .37307 L p .116 0 .005 r
F P
0 g
s
.36016 .38959 m .38265 .37307 L .41968 .33162 L p .041 0 0 r
F P
0 g
s
.26344 .47699 m .24131 .49533 L .20446 .50337 L p .733 .966 .936 r
F P
0 g
s
.18284 .51575 m .20446 .50337 L .24131 .49533 L p .735 .925 .955 r
F P
0 g
s
.33045 .41426 m .30806 .43601 L .27053 .45857 L p .472 .845 .611 r
F P
0 g
s
.27053 .45857 m .29284 .44168 L .33045 .41426 L p .472 .845 .611 r
F P
0 g
s
.30806 .43601 m .28571 .45708 L .24833 .47464 L p .607 .944 .769 r
F P
0 g
s
.24833 .47464 m .27053 .45857 L .30806 .43601 L p .607 .944 .769 r
F P
0 g
s
.28571 .45708 m .26344 .47699 L .2263 .48963 L p .695 .982 .88 r
F P
0 g
s
.20446 .50337 m .2263 .48963 L .26344 .47699 L p .733 .966 .936 r
F P
0 g
s
.2263 .48963 m .24833 .47464 L .28571 .45708 L p .695 .982 .88 r
F P
0 g
s
.81607 .47899 m .78746 .43266 L .74968 .37421 L p .622 .195 0 r
F P
0 g
s
.46407 .30083 m .44188 .31492 L .40516 .35763 L p .177 0 .052 r
F P
0 g
s
.38265 .37307 m .40516 .35763 L .44188 .31492 L p .116 0 .005 r
F P
0 g
s
.18284 .51575 m .16148 .52673 L .1252 .52445 L p .664 .851 .971 r
F P
0 g
s
.10438 .53224 m .1252 .52445 L .16148 .52673 L p .657 .815 .96 r
F P
0 g
s
.56562 .25433 m .58853 .26025 L .62268 .25894 L p .43 0 0 r
F P
0 g
s
.58853 .26025 m .56562 .25433 L .53125 .27784 L p .362 0 0 r
F P
0 g
s
.50869 .28202 m .53125 .27784 L .56562 .25433 L p .306 0 .005 r
F P
0 g
s
.04773 .53409 m .06821 .52713 L .10438 .53224 L p .642 .778 .946 r
F P
0 g
s
.1252 .52445 m .10438 .53224 L .06821 .52713 L p .64 .791 .954 r
F P
0 g
s
.48632 .28975 m .46407 .30083 L .4277 .34366 L p .226 0 .083 r
F P
0 g
s
.40516 .35763 m .4277 .34366 L .46407 .30083 L p .177 0 .052 r
F P
0 g
s
.71832 .33985 m .69236 .30453 L .65712 .27391 L p .554 .056 0 r
F P
0 g
s
.65712 .27391 m .68195 .3011 L .71832 .33985 L p .554 .056 0 r
F P
0 g
s
.68195 .3011 m .65712 .27391 L .62268 .25894 L p .549 0 0 r
F P
0 g
s
.62268 .25894 m .64665 .27764 L .68195 .3011 L p .549 0 0 r
F P
0 g
s
.64665 .27764 m .62268 .25894 L .58853 .26025 L p .497 0 0 r
F P
0 g
s
.20446 .50337 m .18284 .51575 L .14626 .516 L p .665 .893 .979 r
F P
0 g
s
.1252 .52445 m .14626 .516 L .18284 .51575 L p .664 .851 .971 r
F P
0 g
s
.50869 .28202 m .48632 .28975 L .4503 .3315 L p .267 0 .099 r
F P
0 g
s
.4277 .34366 m .4503 .3315 L .48632 .28975 L p .226 0 .083 r
F P
0 g
s
.06821 .52713 m .08886 .5201 L .1252 .52445 L p .64 .791 .954 r
F P
0 g
s
.7978 .44843 m .82622 .49254 L .83621 .50588 L closepath p .653 .207 0 r
F P
0 g
s
.14626 .516 m .1252 .52445 L .08886 .5201 L p .636 .814 .968 r
F P
0 g
s
.2263 .48963 m .20446 .50337 L .16754 .5068 L p .645 .932 .97 r
F P
0 g
s
.14626 .516 m .16754 .5068 L .20446 .50337 L p .665 .893 .979 r
F P
0 g
s
.75608 .39119 m .72879 .34895 L .69236 .30453 L p .57 .124 0 r
F P
0 g
s
.80576 .46523 m .77706 .41779 L .73923 .36043 L p .623 .195 0 r
F P
0 g
s
.24833 .47464 m .2263 .48963 L .18904 .49688 L p .584 .942 .913 r
F P
0 g
s
.16754 .5068 m .18904 .49688 L .2263 .48963 L p .645 .932 .97 r
F P
0 g
s
.53125 .27784 m .50869 .28202 L .47299 .32144 L p .302 0 .102 r
F P
0 g
s
.4503 .3315 m .47299 .32144 L .50869 .28202 L p .267 0 .099 r
F P
0 g
s
.16754 .5068 m .14626 .516 L .10968 .51302 L p .623 .846 .985 r
F P
0 g
s
.08886 .5201 m .10968 .51302 L .14626 .516 L p .636 .814 .968 r
F P
0 g
s
.58853 .26025 m .61196 .27076 L .64665 .27764 L p .497 0 0 r
F P
0 g
s
.61196 .27076 m .58853 .26025 L .5541 .27733 L p .411 0 0 r
F P
0 g
s
.53125 .27784 m .5541 .27733 L .58853 .26025 L p .362 0 0 r
F P
0 g
s
.27053 .45857 m .24833 .47464 L .21075 .48624 L p .463 .883 .779 r
F P
0 g
s
.18904 .49688 m .21075 .48624 L .24833 .47464 L p .584 .942 .913 r
F P
0 g
s
.29284 .44168 m .27053 .45857 L .23469 .47405 L p 0 0 0 r
F P
0 g
s
.23469 .47405 m .23407 .47432 L p .23551 .47352 L 0 0 0 r
F P
0 g
s
.23551 .47352 m .29284 .44168 L .23469 .47405 L 0 0 0 r
F
.23684 .47262 m .29284 .44168 L .23407 .47432 L F
.23407 .47432 m .23265 .47493 L p .23684 .47262 L F P
0 g
s
.23265 .47493 m .25472 .46305 L .29284 .44168 L p 0 0 0 r
F P
0 g
s
.31523 .42431 m .29284 .44168 L .25472 .46305 L p 0 0 0 r
F P
0 g
s
.25472 .46305 m .27694 .4507 L .31358 .42545 L p 0 0 0 r
F P
0 g
s
.31358 .42545 m .31523 .42431 L p .31038 .42741 L 0 0 0 r
F P
0 g
s
.25472 .46305 m .31358 .42545 L .31038 .42741 L 0 0 0 r
F
.33768 .40681 m .31523 .42431 L .27694 .4507 L p F P
0 g
s
.27694 .4507 m .2993 .43808 L .33525 .40879 L p 0 0 0 r
F P
0 g
s
.33525 .40879 m .33768 .40681 L p .33221 .41077 L 0 0 0 r
F P
0 g
s
.27694 .4507 m .33525 .40879 L .33221 .41077 L 0 0 0 r
F
.21075 .48624 m .23265 .47493 L .27053 .45857 L p .463 .883 .779 r
F P
0 g
s
.78746 .43266 m .81607 .47899 L .82622 .49254 L closepath p .675 .231 0 r
F P
0 g
s
.18904 .49688 m .16754 .5068 L .13068 .50588 L p .592 .881 .992 r
F P
0 g
s
.10968 .51302 m .13068 .50588 L .16754 .5068 L p .623 .846 .985 r
F P
0 g
s
.5541 .27733 m .53125 .27784 L .49582 .3137 L p .331 0 .091 r
F P
0 g
s
.47299 .32144 m .49582 .3137 L .53125 .27784 L p .302 0 .102 r
F P
0 g
s
.36016 .38959 m .33768 .40681 L .2993 .43808 L p .091 0 0 r
F P
0 g
s
.79529 .45125 m .7666 .40394 L .72879 .34895 L p .611 .181 0 r
F P
0 g
s
.38265 .37307 m .36016 .38959 L .32178 .42534 L p .161 0 .005 r
F P
0 g
s
.2993 .43808 m .32178 .42534 L .36016 .38959 L p .091 0 0 r
F P
0 g
s
.21075 .48624 m .18904 .49688 L .15185 .49868 L p .521 .897 .962 r
F P
0 g
s
.13068 .50588 m .15185 .49868 L .18904 .49688 L p .592 .881 .992 r
F P
0 g
s
.7078 .33315 m .68195 .3011 L .64665 .27764 L p .552 .018 0 r
F P
0 g
s
.64665 .27764 m .67146 .30111 L .7078 .33315 L p .552 .018 0 r
F P
0 g
s
.67146 .30111 m .64665 .27764 L .61196 .27076 L p .53 0 0 r
F P
0 g
s
.40516 .35763 m .38265 .37307 L .34437 .41272 L p .213 0 .067 r
F P
0 g
s
.32178 .42534 m .34437 .41272 L .38265 .37307 L p .161 0 .005 r
F P
0 g
s
.75608 .39119 m .71832 .33985 L p .74484 .37871 L 0 0 .402 r
F P
0 g
s
.78465 .43704 m .75964 .39691 L p .74484 .37871 L 0 0 .402 r
F P
0 g
s
.75964 .39691 m .75608 .39119 L p .74484 .37871 L 0 0 .402 r
F P
0 g
s
.68195 .3011 m .7078 .33315 L .71364 .34035 L p .557 .09 0 r
F P
0 g
s
.71832 .33985 m .74547 .37958 L .78465 .43704 L p 0 0 .402 r
F P
0 g
s
.71364 .34035 m .74547 .37958 L p .72791 .35789 L .557 .09 0 r
F P
0 g
s
.68195 .3011 m .71364 .34035 L .72791 .35789 L .557 .09 0 r
F
.74547 .37958 m .71832 .33985 L .68195 .3011 L p F P
0 g
s
.4277 .34366 m .40516 .35763 L .36707 .40041 L p .251 0 .11 r
F P
0 g
s
.34437 .41272 m .36707 .40041 L .40516 .35763 L p .213 0 .067 r
F P
0 g
s
.23265 .47493 m .21075 .48624 L .1732 .49142 L p .386 .848 .847 r
F P
0 g
s
.15185 .49868 m .1732 .49142 L .21075 .48624 L p .521 .897 .962 r
F P
0 g
s
.77706 .41779 m .80576 .46523 L .81607 .47899 L closepath p .684 .241 0 r
F P
0 g
s
.61196 .27076 m .63604 .28558 L .67146 .30111 L p .53 0 0 r
F P
0 g
s
.63604 .28558 m .61196 .27076 L .57731 .2805 L p .451 0 0 r
F P
0 g
s
.5541 .27733 m .57731 .2805 L .61196 .27076 L p .411 0 0 r
F P
0 g
s
.57731 .2805 m .5541 .27733 L .51884 .30845 L p .355 0 .06 r
F P
0 g
s
.49582 .3137 m .51884 .30845 L .5541 .27733 L p .331 0 .091 r
F P
0 g
s
.4503 .3315 m .4277 .34366 L .38986 .38863 L p .28 0 .138 r
F P
0 g
s
.36707 .40041 m .38986 .38863 L .4277 .34366 L p .251 0 .11 r
F P
0 g
s
.25472 .46305 m .23265 .47493 L .19473 .4841 L p 0 0 0 r
F P
0 g
s
.1732 .49142 m .19473 .4841 L .23265 .47493 L p .386 .848 .847 r
F P
0 g
s
.47299 .32144 m .4503 .3315 L .41276 .37758 L p .302 0 .154 r
F P
0 g
s
.38986 .38863 m .41276 .37758 L .4503 .3315 L p .28 0 .138 r
F P
0 g
s
.19473 .4841 m .21644 .47671 L .25472 .46305 L p 0 0 0 r
F P
0 g
s
.27694 .4507 m .25472 .46305 L .21644 .47671 L p 0 0 0 r
F P
0 g
s
.21644 .47671 m .23834 .46926 L .27694 .4507 L p 0 0 0 r
F P
0 g
s
.2993 .43808 m .27694 .4507 L .23834 .46926 L p .11 0 0 r
F P
0 g
s
.7666 .40394 m .79529 .45125 L .80576 .46523 L closepath p .682 .239 0 r
F P
0 g
s
.49582 .3137 m .47299 .32144 L .43579 .36745 L p .318 0 .159 r
F P
0 g
s
.41276 .37758 m .43579 .36745 L .47299 .32144 L p .302 0 .154 r
F P
0 g
s
.57731 .2805 m .60099 .28725 L .63604 .28558 L p .451 0 0 r
F P
0 g
s
.60099 .28725 m .57731 .2805 L .54211 .30573 L p .373 0 .002 r
F P
0 g
s
.51884 .30845 m .54211 .30573 L .57731 .2805 L p .355 0 .06 r
F P
0 g
s
.32178 .42534 m .2993 .43808 L .26043 .46175 L p .198 0 0 r
F P
0 g
s
.23834 .46926 m .26043 .46175 L .2993 .43808 L p .11 0 0 r
F P
0 g
s
.63604 .28558 m .66085 .30433 L .66314 .30587 L p .513 0 0 r
F P
0 g
s
.74547 .37958 m .7078 .33315 L p .7328 .36701 L 0 0 .457 r
F P
0 g
s
.77384 .42261 m .74783 .38317 L p .7328 .36701 L 0 0 .457 r
F P
0 g
s
.74783 .38317 m .74547 .37958 L p .7328 .36701 L 0 0 .457 r
F P
0 g
s
.7078 .33315 m .73476 .3691 L .77384 .42261 L p 0 0 .457 r
F P
0 g
s
.73476 .3691 m .70888 .33458 L p .69381 .32512 L 0 0 .483 r
F P
0 g
s
.7078 .33315 m .67146 .30111 L p .69381 .32512 L 0 0 .483 r
F P
0 g
s
.70888 .33458 m .7078 .33315 L p .69381 .32512 L 0 0 .483 r
F P
0 g
s
.67146 .30111 m .69384 .32514 L p .69384 .32514 L 0 0 .483 r
F P
0 g
s
.69384 .32514 m .6972 .32874 L p .69384 .32514 L 0 0 .483 r
F P
0 g
s
.6972 .32874 m .70201 .33391 L p .69384 .32514 L 0 0 .483 r
F P
0 g
s
.70201 .33391 m .73476 .3691 L p .71635 .34933 L 0 0 .483 r
F P
0 g
s
.67146 .30111 m .70201 .33391 L .71635 .34933 L 0 0 .483 r
F
.66314 .30587 m .6972 .32874 L p .67802 .31521 L .513 0 0 r
F P
0 g
s
.63604 .28558 m .66314 .30587 L .67802 .31521 L .513 0 0 r
F
.6972 .32874 m .67146 .30111 L .63604 .28558 L p F P
0 g
s
.66085 .30433 m .63604 .28558 L .60099 .28725 L p .465 0 0 r
F P
0 g
s
.51884 .30845 m .49582 .3137 L .45895 .35837 L p .33 0 .153 r
F P
0 g
s
.43579 .36745 m .45895 .35837 L .49582 .3137 L p .318 0 .159 r
F P
0 g
s
.34437 .41272 m .32178 .42534 L .2827 .45418 L p .256 0 .03 r
F P
0 g
s
.26043 .46175 m .2827 .45418 L .32178 .42534 L p .198 0 0 r
F P
0 g
s
.36707 .40041 m .34437 .41272 L .30517 .44654 L p .294 0 .095 r
F P
0 g
s
.2827 .45418 m .30517 .44654 L .34437 .41272 L p .256 0 .03 r
F P
0 g
s
.75608 .39119 m .78465 .43704 L .79529 .45125 L closepath p .668 .223 0 r
F P
0 g
s
.54211 .30573 m .51884 .30845 L .48229 .35049 L p .336 0 .135 r
F P
0 g
s
.45895 .35837 m .48229 .35049 L .51884 .30845 L p .33 0 .153 r
F P
0 g
s
.60099 .28725 m .62521 .29734 L .66085 .30433 L p .465 0 0 r
F P
0 g
s
.62521 .29734 m .60099 .28725 L .56571 .30556 L p .379 0 0 r
F P
0 g
s
.54211 .30573 m .56571 .30556 L .60099 .28725 L p .373 0 .002 r
F P
0 g
s
.38986 .38863 m .36707 .40041 L .32783 .43883 L p .319 0 .139 r
F P
0 g
s
.30517 .44654 m .32783 .43883 L .36707 .40041 L p .294 0 .095 r
F P
0 g
s
.41276 .37758 m .38986 .38863 L .35069 .43105 L p .335 0 .168 r
F P
0 g
s
.32783 .43883 m .35069 .43105 L .38986 .38863 L p .319 0 .139 r
F P
0 g
s
.56571 .30556 m .54211 .30573 L .50582 .34387 L p .334 0 .098 r
F P
0 g
s
.48229 .35049 m .50582 .34387 L .54211 .30573 L p .336 0 .135 r
F P
0 g
s
.43579 .36745 m .41276 .37758 L .37375 .42321 L p .345 0 .185 r
F P
0 g
s
.35069 .43105 m .37375 .42321 L .41276 .37758 L p .335 0 .168 r
F P
0 g
s
.74547 .37958 m .77384 .42261 L .78465 .43704 L closepath p .638 .191 0 r
F P
0 g
s
.73476 .3691 m .6972 .32874 L p .72105 .35752 L 0 0 .538 r
F P
0 g
s
.76285 .40794 m .7363 .37123 L p .72105 .35752 L 0 0 .538 r
F P
0 g
s
.7363 .37123 m .73476 .3691 L p .72105 .35752 L 0 0 .538 r
F P
0 g
s
.6972 .32874 m .72393 .35969 L .76285 .40794 L p 0 0 .538 r
F P
0 g
s
.6972 .32874 m .66085 .30433 L p .68245 .32329 L 0 .074 .562 r
F P
0 g
s
.72393 .35969 m .69768 .3293 L p .68245 .32329 L 0 .074 .562 r
F P
0 g
s
.69768 .3293 m .6972 .32874 L p .68245 .32329 L 0 .074 .562 r
F P
0 g
s
.62521 .29734 m .65005 .31042 L .6518 .31119 L p .422 0 0 r
F P
0 g
s
.66085 .30433 m .68647 .32646 L .69025 .32981 L p 0 .074 .562 r
F P
0 g
s
.66085 .30433 m .69025 .32981 L .70485 .34294 L 0 .074 .562 r
F
.6518 .31119 m .68647 .32646 L p .66681 .31712 L .422 0 0 r
F P
0 g
s
.62521 .29734 m .6518 .31119 L .66681 .31712 L .422 0 0 r
F
.69025 .32981 m .72393 .35969 L p .70485 .34294 L 0 .074 .562 r
F P
0 g
s
.68647 .32646 m .66085 .30433 L .62521 .29734 L p .422 0 0 r
F P
0 g
s
.45895 .35837 m .43579 .36745 L .39701 .4153 L p .349 0 .193 r
F P
0 g
s
.37375 .42321 m .39701 .4153 L .43579 .36745 L p .345 0 .185 r
F P
0 g
s
.65005 .31042 m .62521 .29734 L .58968 .30785 L p .357 0 0 r
F P
0 g
s
.56571 .30556 m .58968 .30785 L .62521 .29734 L p .379 0 0 r
F P
0 g
s
.58968 .30785 m .56571 .30556 L .52959 .33854 L p .323 0 .034 r
F P
0 g
s
.50582 .34387 m .52959 .33854 L .56571 .30556 L p .334 0 .098 r
F P
0 g
s
.48229 .35049 m .45895 .35837 L .42048 .40732 L p .349 0 .191 r
F P
0 g
s
.39701 .4153 m .42048 .40732 L .45895 .35837 L p .349 0 .193 r
F P
0 g
s
.73476 .3691 m .76285 .40794 L .77384 .42261 L closepath p .586 .137 0 r
F P
0 g
s
.50582 .34387 m .48229 .35049 L .44415 .39927 L p .342 0 .18 r
F P
0 g
s
.42048 .40732 m .44415 .39927 L .48229 .35049 L p .349 0 .191 r
F P
0 g
s
.58968 .30785 m .61409 .31239 L .65005 .31042 L p .357 0 0 r
F P
0 g
s
.61409 .31239 m .58968 .30785 L .55362 .33451 L p .29 0 0 r
F P
0 g
s
.52959 .33854 m .55362 .33451 L .58968 .30785 L p .323 0 .034 r
F P
0 g
s
.72393 .35969 m .68647 .32646 L p .70939 .34986 L 0 .112 .649 r
F P
0 g
s
.72393 .35969 m .75168 .39302 L .76285 .40794 L closepath p 0 0 .489 r
F P
0 g
s
.75168 .39302 m .72483 .36078 L p .70939 .34986 L 0 .112 .649 r
F P
0 g
s
.72483 .36078 m .72393 .35969 L p .70939 .34986 L 0 .112 .649 r
F P
0 g
s
.68647 .32646 m .71295 .35124 L .75168 .39302 L p 0 .112 .649 r
F P
0 g
s
.68647 .32646 m .65005 .31042 L p .67101 .32402 L 0 .234 .681 r
F P
0 g
s
.71295 .35124 m .68647 .32646 L p .67101 .32402 L 0 .234 .681 r
F P
0 g
s
.61409 .31239 m .639 .31894 L .64003 .31914 L p .262 0 0 r
F P
0 g
s
.65005 .31042 m .67557 .32604 L .67844 .32798 L p 0 .234 .681 r
F P
0 g
s
.65005 .31042 m .67844 .32798 L .69334 .33851 L 0 .234 .681 r
F
.64003 .31914 m .67557 .32604 L p .65539 .32156 L .262 0 0 r
F P
0 g
s
.61409 .31239 m .64003 .31914 L .65539 .32156 L .262 0 0 r
F
.67844 .32798 m .71295 .35124 L p .69334 .33851 L 0 .234 .681 r
F P
0 g
s
.67557 .32604 m .65005 .31042 L .61409 .31239 L p .262 0 0 r
F P
0 g
s
.52959 .33854 m .50582 .34387 L .46804 .39114 L p .329 0 .155 r
F P
0 g
s
.44415 .39927 m .46804 .39114 L .50582 .34387 L p .342 0 .18 r
F P
0 g
s
.639 .31894 m .61409 .31239 L .57795 .3317 L p .21 0 0 r
F P
0 g
s
.55362 .33451 m .57795 .3317 L .61409 .31239 L p .29 0 0 r
F P
0 g
s
.55362 .33451 m .52959 .33854 L .49214 .38295 L p .304 0 .113 r
F P
0 g
s
.46804 .39114 m .49214 .38295 L .52959 .33854 L p .329 0 .155 r
F P
0 g
s
.71295 .35124 m .74032 .37787 L .75168 .39302 L closepath p 0 .075 .609 r
F P
0 g
s
.71295 .35124 m .67557 .32604 L p .69771 .34376 L 0 .281 .779 r
F P
0 g
s
.74032 .37787 m .71336 .35163 L p .69771 .34376 L 0 .281 .779 r
F P
0 g
s
.71336 .35163 m .71295 .35124 L p .69771 .34376 L 0 .281 .779 r
F P
0 g
s
.67557 .32604 m .7018 .3436 L .74032 .37787 L p 0 .281 .779 r
F P
0 g
s
.7018 .3436 m .67557 .32604 L .639 .31894 L p 0 .46 .832 r
F P
0 g
s
.639 .31894 m .66445 .32715 L .66641 .32802 L p 0 .46 .832 r
F P
0 g
s
.66641 .32802 m .7018 .3436 L p .68169 .3357 L 0 .46 .832 r
F P
0 g
s
.639 .31894 m .66641 .32802 L .68169 .3357 L 0 .46 .832 r
F
.57795 .3317 m .55362 .33451 L .51645 .37468 L p .262 0 .041 r
F P
0 g
s
.49214 .38295 m .51645 .37468 L .55362 .33451 L p .304 0 .113 r
F P
0 g
s
.66445 .32715 m .639 .31894 L .60262 .33001 L p .02 0 0 r
F P
0 g
s
.57795 .3317 m .60262 .33001 L .639 .31894 L p .21 0 0 r
F P
0 g
s
.60262 .33001 m .57795 .3317 L .54098 .36633 L p .184 0 0 r
F P
0 g
s
.51645 .37468 m .54098 .36633 L .57795 .3317 L p .262 0 .041 r
F P
0 g
s
.7018 .3436 m .72878 .36246 L .74032 .37787 L closepath p 0 .253 .755 r
F P
0 g
s
.7018 .3436 m .66445 .32715 L p .68589 .33892 L .156 .477 .897 r
F P
0 g
s
.72878 .36246 m .7018 .3436 L p .68589 .33892 L .156 .477 .897 r
F P
0 g
s
.66445 .32715 m .69046 .33659 L .72878 .36246 L p .156 .477 .897 r
F P
0 g
s
.69046 .33659 m .66445 .32715 L .62765 .32929 L p .264 .712 .959 r
F P
0 g
s
.62765 .32929 m .65306 .32935 L .65399 .32953 L p .264 .712 .959 r
F P
0 g
s
.65399 .32953 m .69046 .33659 L p .66982 .33419 L .264 .712 .959 r
F P
0 g
s
.62765 .32929 m .65399 .32953 L .66982 .33419 L .264 .712 .959 r
F
.60262 .33001 m .62765 .32929 L .66445 .32715 L p .02 0 0 r
F P
0 g
s
.62765 .32929 m .60262 .33001 L .56574 .35791 L p .028 0 0 r
F P
0 g
s
.54098 .36633 m .56574 .35791 L .60262 .33001 L p .184 0 0 r
F P
0 g
s
.65306 .32935 m .62765 .32929 L .59072 .34942 L p .273 .77 .724 r
F P
0 g
s
.56574 .35791 m .59072 .34942 L .62765 .32929 L p .028 0 0 r
F P
0 g
s
.69046 .33659 m .71704 .34679 L .72878 .36246 L closepath p .123 .464 .89 r
F P
0 g
s
.71704 .34679 m .69046 .33659 L .65306 .32935 L p .428 .653 .953 r
F P
0 g
s
.65306 .32935 m .67888 .32995 L .71704 .34679 L p .428 .653 .953 r
F P
0 g
s
.59072 .34942 m .61593 .34084 L .65306 .32935 L p .273 .77 .724 r
F P
0 g
s
.67888 .32995 m .65306 .32935 L .61593 .34084 L p .57 .892 .987 r
F P
0 g
s
.67888 .32995 m .70511 .33085 L .71704 .34679 L closepath p .416 .651 .955 r
F P
0 g
s
.61593 .34084 m .64138 .33219 L .67888 .32995 L p .57 .892 .987 r
F P
0 g
s
.70511 .33085 m .67888 .32995 L .64138 .33219 L p .643 .765 .937 r
F P
0 g
s
.64138 .33219 m .66705 .32346 L .70511 .33085 L p .643 .765 .937 r
F P
0 g
s
.66705 .32346 m .69297 .31464 L .70511 .33085 L closepath p .643 .765 .937 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(0)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(0.25)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0.5)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.75)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
gsave
.2956 .07454 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00loooool4o`000003oa0@4?oooooooooo06kooooo
003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo003eoooo
o`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`00
0?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo003cooooo`03oeEEEOmVIVKo
000007;ooooo003oooooo`Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Looooo`00ooooool8oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0G?ooool00?oooooo0_l00006ooooo`05oa0@4?oooooooooo
ooooool@4100G?ooool00?cooooo0ol000000ooooooo0000ooooo`05ooooo`05o`000?oooooooooo
ooooool00000G?ooool00?[ooooo0_l00004ooooo`;o00001Oooool01Ol0003ooooooooooooooooo
000005cooooo003gooooo`Co00001Oooool00ol0003oooooo`000004ooooo`05oa0@4?oooooooooo
ooooool@4100G?ooool00?Gooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00004oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0G?ooool00?;ooooo0ol0000;ooooo`04o`000?oooooooooo
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Looooo`00l?ooool2o`0000kooooo00Go0000
ooooooooooooooooo`00001Sooooo`00kOooool3o`00013ooooo00Go0000ooooooooooooooooo`00
001Sooooo`00joooool2o`0000?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo063ooooo003Xooooo`?o00005Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo063ooooo003Vooooo`;o00006?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo05oooooo002Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo0ol0000Koooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0G_ooool00:Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
01_ooooo0_l00002ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Nooooo`00Yoooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`0Gooooo`?o00008?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooo000005oooooo001jooooo`;o00000_ooool2o`0002Oooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool05_ooool2o`00
02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Looooo`00N_ooool01_o^k^ko
8B4QohN7Qonj^[[o0000omgMgBOooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Dooooo`?o00009Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo05cooooo001kooooo`04omgMgOl0003o410@olc<c2Sooooo
00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000oooooooo
ool05?ooool2o`0000;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo05_ooooo001kooooo`04onk^k_lQ8B7o410@onk^kRSooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0A
ooooo`?o0000:_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05[ooooo001koooo
o`04ob4Q8OmgMgOoMgMgoc8b<RSooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?oo
ool4o`0000kooooo0_l0000]ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_oo
ool007[ooooo0_l00002ooooo`;o0000Coooool3o`0002oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1Iooooo`00c?ooool3o`000003ooooool0003ooooo02oooooo00?o0000oooo
ooooool01oooool3o`0005[ooooo003:ooooo`;o0000=Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo05Sooooo0037ooooo`?o0000=oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo05Oooooo0035ooooo`;o0000>_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo05Oooooo0032ooooo`Co0000>oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo05Kooooo0030ooooo`;o00001?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0EOooool00;gooooo0ol00011ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0EOooool00;_ooooo0_l00014ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0E?ooool00;Sooooo1?l00015ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooool00000EOooool00;Kooooo0_l00004ooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`1Cooooo`00/oooool3o`0004cooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`1Booooo`00Noooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd08?ooool2o`0004oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Aooooo`00Noooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01cooooo1?l0001@ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0DOooool007_ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo01Wooooo0_l00003ooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`1@ooooo`00Noooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool05oooool3o`0005Kooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`1?ooooo`00Noooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000FOooool00ol0003oooooooooo`0@ooooo`;o0000DOoo
ool007_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01Gooooo1?l0
001Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo001kooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Cooooo`;o
00000oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01oooool00omgMgOo<S8booooo`0Yooooo`00Noooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l0000?ooooo`?o0000H?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00Gooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o
0000ooooooooool0:?ooool009gooooo0_l0001Sooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`0Yooooo`00V_ooool4o`0006Cooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0:_ooool009Sooooo0_l00003ooooo`03o`000?oo
oooooooo06;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02cooooo
002Eooooo`?o0000J_ooool00ol0003oooooooooo`0Eooooo`;o00001?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo02co
oooo002Cooooo`;o0000KOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
02_ooooo002@ooooo`Co0000K_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Wo
oooo002>ooooo`;o00001?ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0B?ooool008_ooooo0ol0001dooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0B?ooool008Wooooo0_l0001gooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0Aoooool008Kooooo0ol000000ooooooo0000ooooo`1fooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0A_ooool008Cooooo0_l0001looooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0A_ooool004;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Qooooo`?o0000Ooooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooo000004Oooooo0012ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;o
oooo01kooooo0_l00022ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0AOooool0
04;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000
ooooooooool06_ooool3o`000003ooooool0003ooooo087ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`14ooooo`00@_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`0Iooooo`;o0000Qoooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo04?ooooo0012ooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05oooool3o`0008Wooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`13ooooo`00@_ooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`;o0000S?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo0012ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0
5?ooool3o`0000;ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo047ooooo0012ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l0000Aooooo`;o0000TOooool00ol0003oooooooooo`0Mooooo`;o
0000@oooool006gooooo0ol0002Cooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
@?ooool006_ooooo1?l0002Dooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_oo
ool3o`000003oa0@4?oooooooooo01Oooooo001Xooooo`?o0000V?ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo02Cooooo00?o410@okZj^_ooool06?ooool006Gooooo0ol0002Koooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool08oooool00onHV9So<S8booooo`0Hoooo
o`00Hoooool2o`0009kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Rooooo`03
omgMgOl0003o^[Zj01Sooooo001Pooooo`?o000000?oooooo`000?ooool0WOooool00ol0003ooooo
ooooo`0Qooooo`;o00009?ooool00omEEEGoMgMgodA4A00Hooooo`00G_ooool2o`0000Gooooo00?o
0000ooooooooool0Voooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo023ooooo00Go
gMgMoa0@4?oooooo8B4QomgMg@0Gooooo`00Foooool3o`000:Gooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0Pooooo`05ofIVI_n7QhOooooooiRHV?mEEED05oooool005Wooooo0_l0
002Xooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07_ooool00oo^k^ko0000onk^
kP02ooooo`03o`000?oMgMgooooo01Gooooo001Fooooo`?o00000_ooool00ol0003oooooooooo`2U
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Oooool01?l@413o0000o`000?oo
ool2o`000003oa0@4?oooooooooo01Cooooo000]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_oo
ool2o`000:gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0jooooo`00;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0002_ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0>Oooool002gooooo00Go410@oooooooooooooooooa0@400Mooooo`;o000000?o
ooooo`000?ooool0/?ooool00ol0003oooooooooo`0Tooooo`?o00002?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd07?ooool002gooooo
00Go0000ooooooooooooooooo`00000Jooooo`?o0000R_ooool9o`0002;ooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`06ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool06oooool002gooooo00Go0000ooooooooooooooooo`00000Hoooo
o`;o0000R?oooolBo`0001kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`05oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Jooooo`00;Oooool01Ol@
413ooooooooooooooooo410@01Gooooo0ol00027ooooo`Oo00001_l=0006o`0000;o08c=0ol0000K
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool06oooool002gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Cooooo`;o00000_ooool00ol0003oooooooooo`22ooooo`So00001Ol=0003o`0000Co?`002_l0
000Hooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Looooo`00;Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^013ooooo0ol00027ooooo`So00001?l=0003o`0000[o?`000_l00002o`1?Z0Go
00005_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03o`000?oooooooooo01kooooo0010ooooo`;o0000R?ooool8o`000003
o`d00?l0003o000001Co00001?l0CjP3o`0001Cooooo00?o0000ooooooooool0:Oooool2o`0000Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo01kooooo000mooooo`Co
0000R?ooool:o`000003oa`00?l0003o?00000Co?0000_l00003oeL000?o00001omV0002o`0000?o
04nX0ol0000Cooooo`03o`000?oooooooooo02Sooooo00?o0000ooooool000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo1?l0000Mooooo`00>oooool2o`0008_ooooo1_l00004oa`000;o
00000oll0003o`0000SoE`000_l00006ofH000Co000000Co04nXo`000?l0003o00004_ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo03?ooooo000hooooo`?o0000S?ooool6o`0000?o
70000_l00003oc`000;o00002omG0006o`0000CoIP002?l0000@ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool0<oooool003Kooooo0_l0002=ooooo`Oo00000olL00001?l0003o?000
oc`00?ll0002o`0000WoE`001?l00004ofh000Oo000000?oIP00o`000?m^00001Ol0000?ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0<_ooool003?ooooo0ol00002ooooo`03o`00
0?oooooooooo08Wooooo1_l00003oa`000;o000000?o?000o`000?l000001Ol00004oeL000?o0000
2_m^00000ol0003oO`00ogl00002ogl000Co000000?oKP00o`000?l000000_l0000>ooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool0<Oooool003;ooooo0_l0002?ooooo`Ko00000olL
0005o`0000KoCP011Ol0000=ofh000;o00001Omo0002o`0000;oKP000ol0000=ooooo`03o`000?oo
oooooooo02gooooo0_l0000booooo`00<_ooool00ol0003oooooo`00002=ooooo`Go00000_lL0004
o`0000;o?@0100?o0000odh00Om>00401Om>00400ol0003oG000oe`00002oe`000?o00001om^0007
o`0000CoO`000ol000001?m^003o0000o`000?l0000<ooooo`03o`000?oooooooooo02gooooo0_l0
000booooo`00<_ooool01?l0003oooooooooool0002:ooooo`[o00001?lm00400ol0003oCP01odh0
0@04odh00@;o00002?mL0007o`0000OoO`000_l00003ogl00003o`000?n4003o000000Co00002ooo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02oooooo000booooo`?o000000?ooooo
o`000?ooool0Q_ooool8o`0000;o:`0000?o0000ocd00Olm00400_lm00400ol0003oCP01odh00@03
odh00@;o00002?mL0002o`0000?oJ@000ol00009ogl000Co000000CoO`00o`000?n4003oQ0001?l0
000:ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;oooool0037ooooo0_l00004
ooooo`03o`000?oooooooooo08?ooooo1_l000001OlF003o0000ob/00?l[003o000000Co?@0100?o
0000odh00Om>00400om>00400ol0003oG000oe`00005oe`000?o00002?mY0003o`0000OoO`000_l0
00001?n<003o0000o`000?l00002oh@000Co00002Oooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo02kooooo000?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
1?l000001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo087ooooo1Ol00002oaH00004o`000?l[003o:`00o`00
00Co?@0100?o0000odh00Om>00400_m>0042o`0000KoG0000_l0000<ofT000Ko00001Omo00000ol0
003oS000oh`00002o`0000?oQ0000ol00008ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0;Oooool000oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0
003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1oooooo`Go00000_lF00001?l0003o:`00ob/00?l00004ocd00@03o`000?m>007o
CP0100;oCP0100?o0000oe`00?mL00001?mL0002o`0000[oJ@001?l00004og<00003o`000?n7003o
000000Co000000?oO`00o`000?n<00000_n<0002o`0000;oQ0000ol00007ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0;Oooool000Oooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41003_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`1mooooo`Co00000olF00001?l0003o:`00ob/00?l0
0004ocd00@03o`000?m>007oCP0100ko00001OmY0003o`0000WoL`000_l00004ohL000Co000000Oo
S000o`000?n=3P3o0000oh@00?l0003o00R=00;o00001oooool00ol0003oooooooooo`0`ooooo`;o
0000;_ooool000oooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Ko
oooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07_o
oooo1?l00003oaH00004o`000?l[003o:`00o`0000Co?@011?l00002odd06P03o`000?mD01OoE00G
00;oE00G00?o0000oeX03omJ00l01?mJ00l6o`0000goL`000_l00005ohL000;o000000OoS000o`00
0?n=3P3o0000oh@00?l0003o00R=00;o00001_ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo02cooooo000?ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooooooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool2o`0000Wooooo00?o0000ooooooooool0
NOooool4o`0000?o5P0000Co0000ob/00?l[003o00000_lm0044o`0000CoC@0J00?o0000oe@05omD
01L00_mD01L00ol0003oFP0?oeX03`06oeX03`03o`000?mO003oG`0000;oG`000ol0000<og<00003
o`000?n7003oQ`0000?oQ`000_l000001On<003o0000ohd>0?l0003oQ00000Co00001Oooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo000?ooooo`05oa0@4?oooooooooooooo
ool@41003_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`1gooooo`Co00000olF00000ol0003o:`00ob/00004o`00
0003od@06Ol0003oC@0J00CoC@0J00?o0000oe@05omD01L00_mD01L00ol0003oFP0?oeX03`06oeX0
3`03o`000?mO003oG`0000KoG`003ol00004ohL000Co000000?oS@h0o`000?n400001?l00004oooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:_ooool000oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo07Gooooo1?l00003oaH00003o`000?l[003o0000
00;o00000om401T00ol0003oC@0Jodd06P03odd06P03o`000?mD01OoE00G00;oE00G00?o0000oeX0
3omJ00l01OmJ00l2o`0000OoG`000_l00003of4000;o00002_mg0002o`0000?oQ`0000Go0000ohd4
0?l0003o0000ohd>0005o`0000Cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Z
ooooo`003oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4
o`0000Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1cooooo`Co00000olF0003
o`000003ocT05Ol0003oA00I00;oA00I00?o0000odd06_m=01X00om=01X00ol0003oE00Goe@05`02
oe@05`03o`000?mJ00ooFP0?00GoFP0?00?o0000oel00?mO00001OmO0002o`0000OoH@000_l00009
ogL000Co000000?oQ`00o`000?n=10000_l00002ohd>00?o00001?ooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo02Wooooo000`ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0LOooool4o`0000?o5P000_l00002ocT05@05o`000?m401WoA00Iod@06Ol000001Om=01X0
0ol0003oE00Goe@05`02oe@05`03o`000?mJ00ooFP0?00CoFP0?0_l00007oel00003o`000?mQ003o
H@0000WoH@000_l00008ogL000;o000000CoP`00o`000?l0003o00000_n=10000ol0003oS@h0ohd>
0003o`0000?ooooo00?o0000ooooooooool0=?ooool2o`0002[ooooo000`ooooo`;o00003oooool0
0ol0003oooooooooo`1_ooooo`Co00000olF0002o`0000;o>@0E00Go0000od@06Om401WoA00Io`00
0005odd06P03o`000?mD01OoE00G00;oE00G00?o0000oeX03omJ00l01?mJ00l00ol0003oG`00oel0
0005oel000;o00003?mQ0006o`0000KoM`0000?o0000oh<00?n300000_l00002ohd40003o`000?n=
3P3oS@h000?o00000_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Sooooo000`
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0KOooool4o`0000;o5P000_l00003
ocT05@05o`000?m401WoA00Iod@06Ol000001Om=01X00ol0003oE00Goe@05`02oe@05`03o`000?mJ
00ooFP0?00CoFP0?00?o0000oel00?mO00001?mO0002o`0000[oH@001?l00004oe/000So000000?o
M`00o`000?n300000_n30002o`000004ohd40?l0003oS@h0ohd>00?o000000?oooooo`000?ooool0
=oooool00ol0003oooooooooo`0Wooooo`00<?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo06_ooooo1?l000001OlF003o0000o`000?l]00go000000;o>@0E00Go0000od@06Om401Wo
A00Io`000005odd06P03o`000?mD01OoE00G00;oE00G00?o0000oeX03omJ00l04?l00005of4000?o
00002_mK0002o`0000CoK0001?l000001_n3003o0000o`00Nol0003oSQL0o`0000;oS@h01?l0000i
ooooo`03o`000?oooooooooo02Kooooo000`ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0JOooool6o`0000;o;@0=00Co0000ocT05Oli01Go00000om401T00ol0003oC@0Jodd06P03
odd06P03o`000?mD01OoE00G00Ko00001?mF02800ol0003oE@0IoeD06@03oeD06@03o`000?mB00So
DP0800?oDP082?l0000<oe/000;o00001_m/00001_l0003oP`00o`000?l007_o0000ohhG00Ko0000
>Oooool00ol0003oooooooooo`0Vooooo`00;oooool00ol0003oooooooooo`0Cooooo`;o0000J?oo
ool5o`0000?o;@0=00Co0000ocT05Oli01Go00000om401T00ol0003oC@0Jodd06P03odd06PCo0000
0_mD02L00ol0003oEP0RoeH08P04oeH08P03o`000?mE01WoE@0I00?oE@0I00?o0000oe802?mB00P0
1OmB00P00ol0003oBP00odX00004odX0013o00001Om/00000ol0003oP`00o`000004o`000003ohd>
0?l0003o001g00;o0000>Oooool00ol0003oooooooooo`0Uooooo`00;oooool2o`0001Kooooo00?o
0000ooooooooool0I?ooool4o`0000Co;@0=00Go0000ocT05Oli01Go>@0Eo`000002od@06@04o`00
0?m=01[oC@0Jodd06PCo00001?mD02L00ol0003oEP0RoeH08P04oeH08P03o`000?mE01WoE@0I00?o
E@0I00?o0000oe802?mB00P01OmB00P00ol0003oBP00odX00005odX000;o00000ole0003o`0000So
@`000ol00002of`000Co000000Oo001ko`000?l0003o0000ohd>0?l0003o001g00;o0000=oooool3
o`0000Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^oooo
o`04ooooo`04odA4A?l0003o0000oc8b<P7ogMgM000_ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0H_ooool3o`000003oad00Ol0003o;@0=00;o;@0=00Go0000ocT05Oli01Go>@0E
o`000002od@06@Go00000_mA02P00ol0003oE00Woe@09`02oe@09`03o`000?mF02;oEP0R00CoEP0R
00?o0000oeD06OmE01T00omE01T00ol0003oDP08oe802004oe8020;o00001om:00000ol0003o=@00
ocD00006ocD000?o00001_m30004o`0000;oK0001?l000001?nT`noo0000o`000?n=3P04o`0003So
oooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46oooo
o`03oeEEEOnYZJWooooo00Oooooo0OmgMgL1oc8b<P00;oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo063ooooo0ol000000olM007o0000obd03@02obd03@06o`000?li01Go>@0EocT0
5Ol0003oA00I0ol00005oe40:003o`000?mD02OoE00W00;oE00W00?o0000oeH08_mF02801?mF0280
0ol0003oE@0IoeD06@03oeD06@03o`000?mB00SoDP0800CoDP0800?o0000odX00?m:00001Om:0002
o`0000[o=@002Ol000000om3003o0000o`000003o`0000GoY<?_0_l000001?nA7`3o0000o`000?l0
000iooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVY
ZOmEEEGooooo00Sooooo0Ol0000002oooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`1Nooooo`?o000000?o7@01o`000?l]00d00_l]00d01?l0003o>@0EocT05Oli01D3o`000003odd0
9ol0003oD@0X00CoD@0X00?o0000oe@09omD02L00_mD02L00ol0003oEP0RoeH08P04oeH08P03o`00
0?mE01WoE@0I00?oE@0I00?o0000oe802?mB00P01?mB00P00ol0003oBP00odX00004odX000;o0000
2?le0004o`0000?o1@003?l00006ojC3k`?o000000?o001go`000?l00000>?ooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`7o
MgMg0Olb<S8002oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Looooo`?o0000
00?o7@01o`000?l]00d00_l]00d01?l0003o>@0EocT05Oli01D2o`0000;oC@0W00?o0000oe40:?mA
02P00omA02P00ol0003oE00Woe@09`02oe@09`03o`000?mF02;oEP0R00CoEP0R00?o0000oeD06OmE
01T00omE01T00ol0003oDP08oe802003oe8020;o00001_m:00000ol0003o=@00ocD00004ocD000Co
00001?l50003o`000003o`D00?l0003o000000Co00001OnT`nl6o`000003ojC3kol0003o000000;o
000000?o0021o`000?ooool0=oooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`04o`000?lQ8B7o0000oc8b<P7oc<c<000^oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0F_ooool3o`000003oad00Ol0003o;@0=
00;o;@0=00Co0000ocT05Oli01Go>@0E0_l00002odd09`03o`000?mA02SoD@0X00?oD@0X00?o0000
oe@09omD02L00_mD02L00ol0003oEP0RoeH08P04oeH08P03o`000?mE01WoE@0I00?oE@0I00?o0000
oe802?mB00P00omB00P00ol0003oBP00odX00004odX000;o000000?o=@00o`000?l000004ol0000>
ojC3k`So0000>?ooool00ol0003oooooooooo`03ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00;ooooo000^ooooo`?o00007?ooool0
0ol0003oooooooooo`1Hooooo`?o00000_lM00401?l0003o;@0=obd03Ol00002ocT05@;o00000om=
02L00ol0003oD@0Xoe40:003oe40:003o`000?mD02OoE00W00?oE00W00?o0000oeH08_mF02800omF
02800ol0003oE@0IoeD06@03oeD06@03o`000?mB00SoDP0800?oDP0800?o0000odX00?m:00002?l0
0002obl00003o`000?l7003o1`0000?o1`000ol00004odG5^@?o00002OnT`nl3offWl`?o00001?mZ
Y_@6o`0003Kooooo0ol00005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooo
oooooooooooo<S8b00Cooooo00?o0000ooooooooool00_ooool002kooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`1Fooooo`;o000000Co2P00o`000?lM007o00000_l]00d4o`000005
odL08ol0003oC@0Wodd09ol000001OmA02P00ol0003oE00Woe@09`03oe@09`03o`000?mF02;oEP0R
00?oEP0R00?o0000oeD06OmE01T00omE01T00ol0003oDP08oe802007o`0000;o@`0:00?o0000obl0
0?l_00001?l_00001?l0003o1`00o`L00?l70004o`0000?oALFi0ol00006oi7To0Ko00001_m]Yo<3
o`0000;oJZKd00?o0000ohhG0?l000000ol0000hooooo`03o`000?oooooooooo00;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00007ooooo000^ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool0E?ooool2o`000004o`X00?l0003o7@01o`0000;o;@0=0_l0
0003odL08`05o`000?m=02OoC@0Wodd09ol000001OmA02P00ol0003oE00Woe@09`02oe@09`03o`00
0?mF02;oEP0R00?oEP0R00Co0000oeD06OmE01WoE@0I1_l00002odd07003o`000?m300[o@`0:00?o
@`0:00?o0000obl00?l_00000ol_0002o`000003o`L00?l0003o000000?o00000_m5aKT3o`0000Co
TNCl1?l00004oiQm/`04o`000?n4M;WoQ7BiohAd^@?o000000?o9g[UoffWlom]Yo<00_m]Yo<2o`00
0003ofZVm?l0003oSQL000Co0000>?ooool00ol0003oooooooooo`0Oooooo`00;_ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo05;ooooo0_l000001Ol:003o0000oad00Ol0003o;@0=
00;o00001?m702<01Ol0003oC@0Wodd09om=02Oo000000GoD@0X00?o0000oe@09omD02L00_mD02L0
0ol0003oEP0RoeH08P03oeH08PGo00000_mD02L00ol0003oC@0Lodd07002odd07003o`000?m300[o
@`0:00?o@`0:00?o0000obl00?l_00000ol_0004o`000004o`L00?l0003o0000odG5^@?o00000_nA
i?`4ojn9[P04o`000?nVPjooYX>_o`0000KoV7fc00?o0000ohAd^On4M;T00_n4M;T00ol0003oIfJm
o`000002obMji@03o`000?m]Yo?oKJOc00So0000=oooool00ol0003oooooooooo`0Oooooo`00;_oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo053ooooo0_l000001?l:003o0000oad0
0OlM0042o`000003od007?l0003oA`0S00;oA`0S00Go0000odd09om=02OoC@0Wo`000005oe40:003
o`000?mD02OoE00W00;oE00W00Co0000oeH08_mF02;oEP0R1?l00005oe@09`03o`000?m=01coC@0L
00;oC@0L00?o0000od<02_m300X00om300X00ol0003o;`00obl00003obl000;o00000_l70006o`00
00Ko[hV^0_l00004ojJ3[`03o`000?nHOK?oV7fc00CoV7fc00?o0000ohAd^On4M;T00_n4M;T00ol0
003oIfJmofMV_@02obMji@;o00000_lOM^<00om]Yo?o0000o`000003o`0003Sooooo00?o0000oooo
ooooool07_ooool002kooooo0ol0000Qooooo`03o`000?oooooooooo04kooooo0_l000001?l:003o
0000oad00OlM0042o`000003od007?l0003oA`0S00;oA`0S00Go0000odd09om=02OoC@0Wo`000005
oe40:003o`000?mD02OoE00W00;oE00W1Ol00002oeL0;P03o`000?mD02OoE00W00?oE00W00?o0000
odd07?m=01`00_m=01`00ol0003o@`0:od<02P03od<02P04o`000?l_003o;`00obl000?o00000_l7
0003o`0000Go]hf[0_l00003ojn9[P03o`000?nVPjooYX>_00GoYX>_00?o0000oiQm/onHOK<01?nH
OK<00ol0003oQ7BiohAd^@02ohAd^@04o`000?mWI[goIfJmofMV_@;o9g[U00?o0000oamfholOM^<0
1_l0000hooooo`03o`000?oooooooooo01gooooo000]ooooo`;o00009?ooool00ol0003ooooooooo
o`1<ooooo`;o000000Go2P00o`000?lM007o7@01o`000002od007005o`000?m702?oA`0SodL08ol0
00000om=02L00ol0003oD@0Xoe40:003oe40:003o`000?mD02OoE00W00Co00001OmG02h00ol0003o
E00Woe@09`03oe@09`03o`000?m=01coC@0L00;oC@0L00?o0000od<02_m300X00om300X00ol0003o
;`00o`000003o`000004o`L00?l0003o0000o`0000[o]hf[00?o0000ojn9[_l000002OnVPjl00ol0
003oV7fcoiQm/`04oiQm/`03o`000?n4M;WoQ7Bi00;oQ7Bi00Oo0000ofMV_OmWI[goIfJmo`17aolW
N^Go000000;o7gKS1_l0000fooooo`;o00007oooool001?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1:ooooo`;o000000Go2P00o`000?lM007o7@01o`000002od007005o`00
0?m702?oA`0SodL08ol000001?m=02L00ol0003oD@0Xoe40:002oe40:0Co00000_mI03000ol0003o
E`0^oeL0;P03oeL0;P03o`000?mD02OoE00W00?oE00W00?o0000odd07?m=01`00_m=01`00ol0003o
@`0:od<02P03od<02P?o00000_l_0003o`0000go]hf[0ol0000:ojJ3[`03o`000?nHOK?oV7fc00Co
V7fc00?o0000ohAd^On4M;T00_n4M;T00ol0003oIfJmofMV_@02ofMV_@03obMjiOl0003o000000Oo
0000=oooool00ol0003oooooooooo`0Looooo`004oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`18ooooo`;o000000?o2P00o`000?lM00400_l00002od007003o`000?m702?oA`0S00;o
A`0S00Go0000odd09om=02OoC@0Wo`000003oe40:0?o00001?mI03000ol0003oE`0^oeL0;P03oeL0
;P03o`000?mD02OoE00W00?oE00W00?o0000odd07?m=01`00_m=01`01?l0003o@`0:od<02_m300X3
o`0000?o;`000_l000000onnU:_o0000okN=Z`0<okN=Z`05o`000?n_R:_o[hR[ojn8Zol000002_nV
Pjl00ol0003oV7fcoiQm/`04oiQm/`03o`000?n4M;WoQ7Bi00;oQ7Bi00?o0000ofMV_OmWI[d00_mW
I[d00ol0AlOo9g[Uo`000006o`0003Sooooo00?o0000ooooooooool06oooool000_ooooo1_l00002
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0A_ooool2o`000006o`X00?l0003o7@01o`000?lf017o
00000_m001`01Ol0003oA`0SodL08om702?o000000?oC@0W00?o0000oe40:?l000000_l000000omI
037o0000oeT0<003oeT0<003o`000?mG02koE`0^00?oE`0^00?o0000oe@09omD02L00omD02L00ol0
003oC@0Lodd07002odd07003o`000?m300[o000000;o000000?o@`0:o`000?l_00000ol000001?o3
UZWo0000o`000?l0000<okN=Z`03o`000?n_R:_o[hR[00?o[hR[00?o0000ojJ3[onVPjl02?nVPjl0
0ol0003oV7fcoiQm/`04oiQm/`03o`000?n4M;WoQ7Bi00;oQ7Bi00?o0000ofMV_OmWI[d00_mWI[d2
o`17a`Oo0000=oooool00ol0003oooooooooo`0Kooooo`004oooool01Ol0003ooooooooooooooooo
000000kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo04Cooooo0_l000001_l:003o0000o`000?l0003o=P0Ao`0000;o@00L00Go0000odL08om702?o
A`0So`000003odd09`?o00000omI03400ol0003oF@0`oeT0<002oeT0<003o`000?mG02koE`0^00Co
E`0^00?o0000oe@09omD02L00omD02L01?l0003oC@0Lodd07?m=01`3o`0000?o@`0:0ol00005ol>F
Z@03o`000?nlT:So000000;o00002?ngSJ/00ol0003o[hR[ojn8Z`05ojn8Z`03o`000?nVPjooYX>_
00SoYX>_00?o0000oiQm/onHOK<01?nHOK<01Ol0003oQ7BiohAd^On4M;Wo000000CoIfJm00Go0000
oceB_ol0AlOo0000o`00M005o`0003Oooooo00?o0000ooooooooool06_ooool001?ooooo00Go0000
ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Cooooo0_l0000Yooooo`03o`000?oo
oooooooo04;ooooo0_l000000ol:003o0000o`000002ocH04@04o`000?m001co@00Lo`0000?oA`0S
00?o0000odd09om=02L00_l00005oeT0<@03o`000?mI033oF@0`00;oF@0`00?o0000oeL0;_mG02h0
1?mG02h00ol0003oE00Woe@09`03oe@09`03o`000?m=01co000000;o00000om300X3o`0000Oo`iJY
00?o0000okb@Z?nlT:P00onlT:P2o`0000Go]hf[00?o0000ojn8Zon_R:/01on_R:/2o`0000WoYX>_
00?o0000oiQm/onHOK<01?nHOK<01Ol0003oQ7BiohAd^On4M;Wo000000CoIfJm0_lmD[l00ol0AlOo
0000o`000004o`0003Oooooo0_l0000Kooooo`004oooool01Ol@413ooooooooooooooooo410@00ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Yooooo`;o0000@Oooool2o`000003
o`X00?l0003o=P0A00;o=P0A00Co0000od007?m001co00000om702<4o`000003oeP0;ol0003oF@0a
00?oF@0a00?o0000oeT0<?mI03000omI03000ol0003oE`0^oeL0;P03oeL0;P03o`000?mD02OoE00W
00?oE00W0ol000000om=01co0000o`000003o`0000Wo`iJY00?o0000okb@Z?nlT:P01_nlT:P3o`00
0003okN=Zol0003o[hR[00_o[hR[00?o0000ojJ3[onVPjl01_nVPjl:o`0000;oQ7Bi00?o0000ofMV
_OmWI[d00_mWI[d2oceB_`Oo0000=_ooool2o`0001_ooooo000Cooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool0?Oooool4o`0000?o=P0A00Co0000od007?m001co00000om702<2o`0000?oF00_00?o0000
oeT0<OmI03400omI03400ol0003oF@0`oeT0<002oeT0<003o`000?mG02koE`0^00?oE`0^00Co0000
oe@09omD02OoE00W0ol00002odd070?o00000_o9WJ/00ol0003o`iJYol>FZ@08ol>FZ@03o`000?nl
T:So_92X00Wo_92X0_l0000=ojn8Z`03o`000?nVPjooYX>_00;oYX>_0ol000000onMO[7o0000ohag
]P05ohag]P03o`000?mdK;_o000000?o00001?mWI[d00olmD[oo0029o`000006o`0003Oooooo00?o
0000ooooooooool06?ooool001?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmV
IVKo000000Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0kooooo`?o000000Go
:@01o`000?lf017o=P0Ao`000003od007004o`000?m702?o0000o`0000CoF00_00?o0000oeT0<OmI
03400omI03400ol0003oF@0`oeT0<002oeT0<003o`000?mG02koE`0^00?oE`0^00?o0000oe@09ol0
00000_l000000omD02Oo0000o`000002o`0000CobIf[00?o0000ol>FZOo3UZT02?o3UZT00ol0003o
_92Xokb@Z00:okb@Z003o`000?ngRjSo000000go[hR[00Co0000ojJ3[ol0003o00001OnMO[400ol0
003oS7Nfohag]P04ohag]P04o`000?mdK;_oM6bkogA/^`;o00000omWI[d00ol0003o?E:oo`00R@05
o`000003ooooool0003ooooo03Gooooo00?o0000ooooooooool06?ooool002cooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0iooooo`?o000000Go:@01o`000?lf017o=P0Ao`000003
od0070?o000000?oE@0[o`000?mH02l00_mH02l00ol0003oF@0aoeT0<@03oeT0<@03o`000?mI033o
F@0`00;oF@0`00?o0000oeL0;_mG02h00omG02h3o`0000?oE00W0_l00007olVMZ`03o`000?o3UZWo
`iJY00So`iJY00?o0000okb@Z?nlT:P02OnlT:P01?l0003o]h^XokN;Z?ngRjP2o`0000_o[hR[0_l0
0008oien/@03o`000?n<MkKoS7Nf00CoS7Nf00?o0000ogA/^omdK;/00_mdK;/2o`0000;oIfJm0_lm
D[l7o`0003Oooooo00?o0000ooooooooool05oooool002cooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0gooooo`;o00000_lY00401?l0003o=P0AocH04Ol00003od0070;o00000_mE
02/01Ol0003oF00_oeP0;omH02oo000000GoF@0a00?o0000oeT0<?mI03000_mI03001?l0003oE`0^
oeL0;_mG02h4o`0000?oE00W0_l00008olVMZ`03o`000?o3UZWo`iJY00So`iJY00?o0000okb@Z?nl
T:P02OnlT:P00ol0003o]h^XokN;Z004okN;Z0;o00002?n_R:/01?l0003oZ8>]ojR3[OnXPjd8oien
/@03o`000?n<MkKoS7Nf00CoS7Nf00Co0000ogA/^omdK;_oM6bk0_mAG;l01?l0003oIfJmofMV_Olm
D[l8o`0003Oooooo00?o0000ooooooooool05_ooool002cooooo0_l0000aooooo`03o`000?oooooo
oooo03Gooooo0_l00002obT00@04o`000?lf017o=P0Ao`0000?o@00L0_l00002oeD0:`03o`000?mH
02ooF00_00;oF00_00?o0000oeT0<OmI03400omI03400ol0003oF@0`oeT0<002oeT0<004o`000?mG
02ko0000o`0000;oE`0^00?o0000oe@09ol000000ol00008olVMZ`03o`000?o3UZWo`iJY00So`iJY
00?o0000okb@Z?nlT:P02_nlT:P00ol0003o]h^XokN;Z006okN;Z003o`000?n_R:_o[hR[00Co[hR[
00?o0000ojR3[OnXPjd00onXPjd00ol0003oWGjaoien/@05oien/@03o`000?n<MkKoS7Nf00CoS7Nf
00Co0000ogA/^omdK;_oM6bk0_mAG;l3o`000003oceB_ol0003o000000Co000000?oooooo`000?oo
ool0=?ooool3o`0001Oooooo000/ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
<oooool2o`0000;o:@0100Co0000ocH04Olf017o00000_m001`2o`0000?oE@0[00?o0000oeP0;omH
02l00_mH02l00ol0003oF@0aoeT0<@03oeT0<@03o`000?mI033oF@0`00;oF@0`0ol00003oeL0;P?o
00000_o@YZh00ol0003obIf[olVMZ`07olVMZ`03o`000?o3UZWo`iJY00So`iJY00?o0000okb@Z?nl
T:P02OnlT:P00ol0003o]h^XokN;Z008okN;Z0;o00000on_R:/00ol0003oZ8>]ojR3[@05ojR3[@03
o`000?nMO[7oWGja00GoWGja00?o0000ohag]_n<MkH00on<MkH00ol0003oM6bkogA/^`02ogA/^`?o
DEbo0_l000000olmD[oo0S>go`000004o`000003ooooool0003ooooo03Gooooo00?o0000oooooooo
ool05Oooool002_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0`ooooo`?o0000
0_lY00401Ol0003o=P0AocH04Ol0003o@00L00;o000000GoD@0So`000?mE02_oE@0[o`000004oeP0
;`03o`000?mI037oF@0a00?oF@0a00?o0000oeT0<?mI03000ol00003oeL0;P?o00001Oo@YZh01?l0
003obIf[olVMZoo9WJ/Co`0000Wo_92X00?o0000okN;Z?ngRjP02ongRjP00ol0003o[hR[o`000009
ojR3[@03o`000?nMO[7oWGja00GoWGja00?o0000ohag]_n<MkH00on<MkH00ol0003oM6bkogA/^`02
ogA/^`CoDEbo0_l000000ol008Wo0000o`000004o`0003Oooooo00?o0000ooooooooool05?ooool0
02_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0^ooooo`?o00000_lY00400ol0
003o=P0AocH04@03o`0000;oD@0S00Go0000oeD0:omE02_oE@0[o`000003oeP0;`03o`000?mI037o
F@0a00?oF@0a1?l000000omI033o0000o`000003o`0000God:J^1ol00005ol^NZ@03o`000?o5UjOo
aINW00SoaINW00?o0000ol2BY_o0TZH00ol00006okb@Z003o`000?ngRjSo]h^X00co]h^X0_l0000:
ojR3[@03o`000?nMO[7oWGja00GoWGja00?o0000ohag]_n<MkH00on<MkH01Ol0003oM6bkogA/^omd
K;_o000000CoDEbo2Ol0000fooooo`03o`000?oooooooooo01Cooooo000[ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool0;?ooool3o`0000;o:@0100?o0000ocH04Olf01400_l00003
oe408`05o`000?mE02_oE@0[oeD0:ol000000omH02l00ol0003oF@0aoeT0<@02oeT0<@?o00000_mI
0303o`0000;oek6b00?o0000om2V[_l000001?l00002om2U[@03o`000?o;WZWobijY00KobijY00?o
0000olFGYoo5UjL02?o5UjL00ol0003o`9:Vol2BYP04ol2BYP?o00000_nlT:P00ol0003o]h^XokN;
Z00<okN;Z004o`000?naQjWo/HNYo`0000[oZ8>]00?o0000oien/OnMO[401OnMO[400ol0003oS7Nf
ohag]P03ohag]P05o`000?mdK;_oM6bkogA/^ol000000omAG;l00ol0003o?E:oo`000005o`000003
ooooool0003ooooo03Gooooo00?o0000ooooooooool04oooool002_ooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0Zooooo`?o00000_lY00401?l0003o=P0Ao`000?l00004oe408`05
o`000?mE02_oE@0[oeD0:ol000001?mH02l00ol0003oF@0ao`000002o`000003oeT0<Ol0003o0000
00;o00000ooG/K84o`0000Kod:F]00?o0000ol^NZOo;WZT01oo;WZT00ol0003oaINWolFGY`08olFG
Y`03o`000?o0TZKo`9:V00Oo`9:V0ol0000=okN;Z003o`000?naQjWo/HNY00;o/HNY00?o0000ojR3
[OnXPjd02?nXPjd00ol0003oWGjaoien/@05oien/@03o`000?n<MkKoS7Nf00;oS7Nf00?o0000ogA/
^omdK;/00_mdK;/01_l0003oDEbooe5L_omAG;oo0000oceB_`Ko000000?oooooo`000?ooool0=Ooo
ool00ol0003oooooooooo`07ooooo`Co000000?o410@ooooooooool01?ooool002_ooooo0_l0000h
ooooo`03o`000?oooooooooo02Sooooo0ol00002obT00@Co00001?mA02<01Ol0003oE@0[oeD0:omE
02_o000000CoF00_0ol00003oeT0<@;o00001?oG/K82o`000003omF_/_l0003od:F]00Ood:F]00?o
0000ol^NZOo;WZT01_o;WZT00ol0003oaINWolFGY`08olFGY`03o`000?o0TZKo`9:V00Wo`9:V00Co
0000ok^>Y_l0003o00002_ngRjP00ol0003o/HNYok67Z@04ok67Z@03o`000?nXPjgoZ8>]00SoZ8>]
00?o0000oien/OnMO[401OnMO[400ol0003oS7Nfohag]P02ohag]P03o`000?mdK;_oM6bk00;oM6bk
00Co0000oe5L_omAG;ooDEbo0_l000001?l2<kOo0000o`000?nL;P03o`0003Gooooo0_l0000;oooo
o`03o`000?oooooooooo00Kooooo000[ooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool09Oooool2o`000004oaL00?l0003o:@01obT00@;o000000?oB`0Ho`000?mA02<00omA02<01Ol0
003oE@0[oeD0:omE02_o000000;oF00_0ol00003oeT0<@Co00000_oG/K83o`0000;oeJnb00?o0000
om2U[Oo@YJd01_o@YJd00ol0003obijYol^NZ@07ol^NZ@03o`000?o5UjOoaINW00SoaINW00?o0000
ol2BY_o0TZH02?o0TZH00ol0003o^hjVok^>YP02ok^>YP;o00001ongRjP00ol0003o/HNYok67Z@06
ok67Z@;o00002OnXPjd00ol0003oWGjaoien/@02oien/@Ko00000_n<MkH01Ol0003oM6bkogA/^omd
K;_o000000?oDEbo0ol000000ol2<kOo0000o`000002o`000003ooooool0003ooooo03Gooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`00:oooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo02?ooooo0_l000001?lG003o0000obT00OlY0042o`000003od/06?l0
003oD@0S00?oD@0S00?o0000oeD0:omE02/00_mE02/3o`000003oeP0;ol0003o000000?o00000_oM
_[T01?l0003oek6bo`000?l00005omF_/P03o`000?o@YJgod:F]00Kod:F]00?o0000ol^NZOo;WZT0
1_o;WZT00ol0003oaINWolFGY`08olFGY`03o`000?o0TZKo`9:V00So`9:V00?o0000ok^>Y_nkSZH0
1OnkSZH2o`0000Co]h^X00?o0000ok67ZOnaQjT02OnaQjT00ol0003oZ8>]ojR3[@06ojR3[@Go0000
0onCN[@00ol0003oOg:jogmb^P04o`0000?oM6bk00Co0000oe5L_omAG;ooDEbo2?l000000ooooooo
0000ooooo`0dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool002[ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Qooooo`;o000000?o5`00o`000?lY0040
0_l00002od/06003o`000?mA02?oD@0S00;oD@0S00?o0000oeD0:omE02/00ol00002oeP0;`?o0000
1_oM_[T2o`0000KoeJnb00?o0000om2U[Oo@YJd01_o@YJd00ol0003obijYol^NZ@07ol^NZ@03o`00
0?o5UjOoaINW00OoaINW00?o0000ol2BY_o0TZH02Oo0TZH00ol0003o^hjVok^>YP07ok^>YP;o0000
00?o]h^Xo`000?naQjT03?naQjT00ol0003oZ8>]ojR3[@02ojR3[@?o000000?oXH2_o`000?nCN[@0
1_nCN[@00ol0003oOg:jogmb^P02ogmb^P?o00000_mdK;/01ol0003oDEbooe5L_omAG;oo74Bno`00
0?l2<kL00_l000001OnL;P3o0000o`000?oooooo000003Gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`00:_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
01oooooo0_l000001?lG003o0000o`000?l00003od/06003o`000?mA02?oD@0S00;oD@0S1?l00000
0omE02_o0000o`000003o`0000KogKji0_l00008omF_/P03o`000?o@YJgod:F]00God:F]00?o0000
ol^NZOo;WZT01oo;WZT00ol0003oaINWolFGY`08olFGY`03o`000?o0TZKo`9:V00So`9:V00?o0000
ok^>Y_nkSZH02_nkSZH2o`0000ko/HNY00Co0000ojR3[Ol0003o00001OnQP:l00ol0003oTgZdoi=j
]005oi=j]003o`000?moL[[oOg:j00;oOg:j00?o0000of9V`?l000000_l00003oe5L_`04o`000?lL
A;ko0000o`8c]`Co000000?oooooo`000?ooool0=Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo000Zooooo`;o0000?_ooool00ol0003oooooooooo`0Mooooo`;o000000Co
5`00o`000?l0003o00000om;01P01?l0003oD@0Soe408omA02<3o`0000?oE@0[0_l00003on?=`P03
o`000?oM_[WogKji00;ogKji0_l000000ooK^[Wo0000omF_/P06omF_/P03o`000?o@YJgod:F]00Ko
d:F]00?o0000ol^NZOo;WZT01oo;WZT00ol0003oaINWolFGY`07olFGY`03o`000?o0TZKo`9:V00So
`9:V00?o0000ok^>Y_nkSZH02onkSZH00ol0003o]hZWo`00000=ok67Z@;o00002?nQP:l00ol0003o
TgZdoi=j]005oi=j]003o`000?moL[[oOg:j00;oOg:j00?o0000of9V`?mRI/000_l00003oe5L_`04
o`000?lLA;ko0000o`8c]`Co000000?oooooo`000?ooool0<oooool3o`0000Oooooo00?o0000oooo
ooooool01_ooool002[ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Jooooo`?o
000000Co5`00o`000?l0003o00000om;01P00ol0003oD@0So`000003o`0000?oE@0[0_l00004on?=
`P03o`000?oM_[WogKji00?o00000_oK^[T00ol0003oeJnbomF_/P05omF_/P03o`000?o@YJgod:F]
00Kod:F]00?o0000ol^NZOo;WZT01oo;WZT00ol0003oaINWolFGY`08olFGY`03o`000?o0TZKo`9:V
00So`9:V00?o0000ok^>Y_nkSZH02_nkSZH01?l0003o]hZWokN:YongRZL2o`0000[o/HNY00Co0000
oj^4Zon[Q:_oZhB[2?nQP:l00ol0003oTgZdoi=j]005oi=j]003o`000?moL[[oOg:j00;oOg:j00?o
0000of9V`?mRI/000_l00003oe5L_`04o`000?l07Zco0000o`8c]`Co000000?oooooo`000?ooool0
=?ooool00ol0003oooooooooo`03ooooo`03oeEEEOmVIVKo000000Sooooo000Zooooo`03o`000?oo
oooooooo03oooooo0_l0000Iooooo`;o000000Go5`00o`000?l0003o@@07o`000003od/060?o0000
0_mA02<00ol0003oE@0[o`000002o`0000Kohlg20ol00005om^j^@03o`000?oE[k;oeJnb00GoeJnb
00?o0000om2U[Oo@YJd01_o@YJd00ol0003obijYol^NZ@07ol^NZ@03o`000?o5UjOoaINW00OoaINW
00?o0000ol2BY_o0TZH02?o0TZH00ol0003o^hjVok^>YP0:ok^>YP03o`000?ngRZOo]hZW00Co]hZW
00?o0000ok67ZOnaQjT01_naQjT00ol0003oZhB[oj^4Z`03oj^4Z`03o`000?nQP:ooXH2_00GoXH2_
00?o0000oi=j]?nCN[@01OnCN[@00ol0003oOg:jogmb^P02ogmb^P04o`000?mRI/3oHVK0of9V`0;o
00000_mAG;l00ol0003o01j/o`000004o`0000;ooooo00?o0000ooooooooool0<Oooool3o`0000oo
oooo000Zooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool05Oooool4o`000003od40
1ol0003o000000;oB`0H0ol00003oe408`?o000000?oiMk=o`000?oScL801OoScL82o`0000KofkZi
00?o0000omF_/_oE[k801OoE[k800ol0003od:F]om2U[@06om2U[@03o`000?o;WZWobijY00CobijY
2Ol00005olFGY`03o`000?o0TZKo`9:V00So`9:V00?o0000ok^>Y_nkSZH02_nkSZH00ol0003o]hZW
okN:Y`05okN:Y`03o`000?naQjWo/HNY00Co/HNY00?o0000oj^4Zon[Q:/01On[Q:/00ol0003oXH2_
oj60[`05oj60[`03o`000?nCN[CoTgZd00CoTgZd00?o0000ogmb^_moL[X00omoL[X00ol0003oHVK0
of9V`002ocEC``05o`000?mAG;oo0000oaa4__l07Z`01Ol000000ooooooo0000ooooo`0_ooooo`?o
00000_ooool00ol0003oooooooooo`0=ooooo`00:Oooool00ol0003oooooooooo`13ooooo`03o`00
0?oooooooooo01;ooooo1Ol000000om100Oo0000od/06004o`0000;oD@0S0ol00003onGNc@03o`00
0?oScL;ohlg200?ohlg20_l00007om^j^@03o`000?oE[k;oeJnb00KoeJnb00?o0000om2U[Oo@YJd0
1_o@YJd00ol0003obijYo`000004o`0000?obifY00?o0000olNHYoo7V:L00oo7V:L:o`0000Go`9:V
00?o0000ok^>Y_nkSZH02_nkSZH00ol0003o]hZWokN:Y`07okN:Y`;o00000onaQjT00ol0003oZhB[
oj^4Z`07oj^4Z`03o`000?nQP:ooXH2_00GoXH2_00?o0000oi=j]?nCN[@01?nCN[@00ol0003oOg:j
ogmb^P03ogmb^P03o`000?mRI/3oHVK000;o=E?300Go0000oe5L_ol0003o74Bno`0N[004o`0000;o
oooo00?o0000ooooooooool0:_ooool3o`0000Gooooo00?o0000ooooooooool03Oooool002Wooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0@ooooo`Co00000_m100L3o`0000;oB`0H
1?l00005onGNc@03o`000?oScL;ohlg200;ohlg20_l000000ooNb<;o0000om^j^@06om^j^@03o`00
0?oE[k;oeJnb00GoeJnb00?o0000om2U[Oo@YJd01?o@YJd5o`0000OobifY00?o0000olNHYoo7V:L0
2?o7V:L00ol0003o`i>Uol>CY@03ol>CY@Ko00002onkSZH00ol0003o]hZWokN:Y`0:okN:Y`03o`00
0?naQjWo000000_oZhB[00?o0000oj60[onQP:l01OnQP:l00ol0003oTgZdoi=j]004oi=j]003o`00
0?moL[[oOg:j00?oOg:j00?o0000of9V`?mRI/000_leDl<4o`000003o`0N[?l0003o000000;o0000
0_ooool00ol0003oooooooooo`0Vooooo`?o00002?ooool00ol0003oooooooooo`0=ooooo`00:Ooo
ool3o`0004Gooooo00?o0000ooooooooool03_ooool7o`0000;oB`0H1_l00006onGNc@03o`000?oS
cL;ohlg200;o00000_oNb<800ol0003ofkZiom^j^@05om^j^@03o`000?oE[k;oeJnb00KoeJnb00?o
0000om2U[Ol000001?l00002olnU[@03o`000?o;WJWobifY00OobifY00?o0000olNHYoo7V:L01oo7
V:L00ol0003o`i>Uol>CY@08ol>CY@03o`000?noT:Go000000;o00001onkSZH00ol0003o]hZWokN:
Y`0<okN:Y`;o00003?n[Q:/00ol0003oXH2_oj60[`05oj60[`03o`000?nCN[CoTgZd00CoTgZd00?o
0000ogmb^_moL[X00_moL[X01?l0003oHVK0of9V`?mRI/03ocEC``04o`000?lLA;ko01j/o`0N[0Co
00000_ooool00ol0003oooooooooo`0Qooooo`Co00002oooool00ol0003oooooooooo`0=ooooo`00
:Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00_ooooo1_l000000om100Oo0000
o`000002o`0000;oi?KE0_l000000ooQk]Wo0000onGNc@04onGNc@04o`000?oScL;ohlg2o`0000?o
g/S200?o0000om^j^OoK^[T01_oK^[T00ol0003oeJnbomF_/P04omF_/PCo00001_o?YJd00ol0003o
bifYol^MZ@07ol^MZ@03o`000?o7V:OoaiRW00SoaiRW00?o0000ol>CYOo3TjD01oo3TjD00ol0003o
_i2Uokn@Y@03okn@Y@;o00001OnkSZH00ol0003o]hZWokN:Y`0<okN:Y`03o`000?nbR:So000000co
ZhB[00?o0000oj60[onQP:l01OnQP:l00ol0003oTgZdoi=j]004oi=j]003o`000?moL[[oOg:j00;o
Og:j00Co0000of9V`?mRI/3oHVK00oleDl<01?l0003o74Bno`0N[?l07Z`3o`0000;ooooo00?o0000
ooooooooool07_ooool3o`00013ooooo00?o0000ooooooooool03?ooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
2Oooool4o`0000;o@@070ol000001Oo@o]co0000onCfeOoTm]Go000000;ohNkI00?o0000onGNcOoU
g/d01?oUg/d3o`0000Cog/S200?o0000om^j^OoK^[T01OoK^[T00ol0003oeJnbomF_/P02omF_/P?o
000000?odjfbo`000?o?YJd01oo?YJd00ol0003obifYol^MZ@07ol^MZ@03o`000?o7V:OoaiRW00Oo
aiRW00?o0000ol>CYOo3TjD02?o3TjD00ol0003o_i2Uokn@Y@05okn@Y@?o000000?o^hjVo`000?ng
RZL03OngRZL01Ol0003o/XRXok:8Z?nbR:So000000coZhB[00?o0000oj60[onQP:l00_nQP:l<o`00
00?oOg:j00Co0000of9V`?mRI/3o00000oleDl<01?l0003o74Bno`0N[?l07Z`3o`0000;ooooo00?o
0000ooooooooool06_ooool3o`0001?ooooo00?o0000ooooooooool03?ooool000Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Kooooo
2?l00003om3ng004o`000?oTm]Go0000o`0000;ohNkI00?o0000onGNcOoUg/d01?oUg/d2o`0000Go
g/S200?o0000om^j^OoK^[T01OoK^[T00ol0003oeJnbomF_/P03o`0000?odjfb00?o0000olnU[Oo?
YJd01_o?YJd00ol0003obifYol^MZ@07ol^MZ@03o`000?o7V:OoaiRW00SoaiRW00?o0000ol>CYOo3
TjD01oo3TjD00ol0003o_i2Uokn@Y@09okn@Y@;o00003OngRZL00ol0003o/XRXok:8Z003ok:8Z0;o
00002_n[Q:/5o`0000CoVWjc00?o0000ohUh^_n9N;X00on9N;X00ol0003oLFo1o`000002o`000005
ogmb^_l0003oHVK0of9V`?l000000_leDl<00ol0<k[o0000o`000002o`0N[0?o00000_ooool00ol0
003oooooooooo`0Fooooo`?o00005_ooool00ol0003oooooooooo`0<ooooo`001?l00002ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00;ooooo0ol00002
oc8000Co00001?o@o]`3o`0000?ohNkI00?o0000onGNcOoUg/d00ooUg/d2o`0000Kog/S200?o0000
om^j^OoK^[T01_oK^[T3o`0000Kodjfb00?o0000olnU[Oo?YJd01_o?YJd00ol0003obifYol^MZ@07
ol^MZ@03o`000?o7V:OoaiRW00OoaiRW00?o0000ol>CYOo3TjD02?o3TjD00ol0003o_i2Uokn@Y@09
okn@Y@04o`000?nkSJGo0000o`0000[o]hZW00?o0000ok:8Z?nbR:P01_nbR:P00ol0003oZhB[oj^4
Z`06oj^4Z`04o`000?nUPjooYH>_o`0000OoVWjc00?o0000ohUh^_n9N;X00on9N;X01?l0003oLFo1
og5_`OmaKl43o`0000;oHVK000Co0000ocEC`oleDl?o03>j0_l000001?l07Zco0000o`000?l00003
ooooo`03o`000?oooooooooo017ooooo1?l0000Iooooo`03o`000?oooooooooo00cooooo0006oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000Oooooo00?o
MgMgoc8b<_ooool00oooool00ol0003oooooooooo`1;ooooo`Wo000000?oVo74o`000?l000001?o@
o]`2o`0000CohNkI00Co0000onGNcOoUg/goiMk=0ol000000ooPelko0000omk8`P05omk8`P03o`00
0?oK^[WofkZi00CofkZi0_l00008om>]/P03o`000?o?YJgocjF]00KocjF]00?o0000ol^MZOo;WJT0
1oo;WJT00ol0003oaiRWolNHY`07olNHY`03o`000?o3TjGo`i>U00So`i>U00?o0000okn@YOnoT:D0
2OnoT:D00ol0003o^hfUok^=Y@02ok^=Y@?o00001ongRZL00ol0003o/XRXok:8Z007ok:8Z0;o0000
1On[Q:/00ol0003oYH>_ojF3[`02ojF3[`03o`000?nJO[?oVWjc00GoVWjc00?o0000ohUh^_n9N;X0
0on9N;X00ol0003oLFo1og5_`@03og5_`@;o000000KoHVK0o`000?leDl?o=E?3o`0c^_l00002o`0N
[0?o00000_ooool00ol0003oooooooooo`0>ooooo`?o00007Oooool00ol0003oooooooooo`0<oooo
o`001_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool2o`0004[ooooo2?l00002oi_aa0;o00001Oo@
o]`2o`0000CohNkI00?o0000onGNcOoUg/d00_l00003on3GcP03o`000?oNb<;og/S200Cog/S200?o
0000om^j^OoK^[T00_oK^[T3o`000003omNg^Ol0003odjfb00Oodjfb00?o0000olnU[Oo?YJd01Oo?
YJd00ol0003obifYol^MZ@08ol^MZ@03o`000?o7V:OoaiRW00OoaiRW00?o0000ol>CYOo3TjD02?o3
TjD00ol0003o_i2Uokn@Y@09okn@Y@03o`000?nkSJGo^hfU00Go^hfU0_l00004okN:Y`03o`000?nb
R:So/XRX00[o/XRX00Go0000oj^4Zon[Q:_oZhB[o`000006ojF3[`03o`000?nJO[?oVWjc00GoVWjc
00?o0000ohUh^_n9N;X00on9N;X00ol0003oLFo1og5_`@02og5_`@04o`000?m<HLOo0000o`0000?o
=E?300Co03>jo`000?l07Zco01j/0ol00002ooooo`03o`000?oooooooooo00[ooooo0ol0000Poooo
o`03o`000?oooooooooo00cooooo0006ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@
413ooooooooooooooooo410@00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`16
ooooo`?o000000?oooooo`000?l000000_l00002oi_aa0?o00001Oo@o]`2o`0000GohNkI00Co0000
onGNcOl0003o00001?oPelh00ol0003og/S2omk8`P05omk8`P03o`000?oK^[Wo000000;o00000ooG
]kT00ol0003odjfbom>]/P06om>]/P03o`000?o?YJgocjF]00KocjF]00?o0000ol^MZOo;WJT01oo;
WJT00ol0003oaiRWolNHY`07olNHY`03o`000?o3TjGo`i>U00Wo`i>U00?o0000okn@YOnoT:D02?no
T:D00ol0003o^hfUok^=Y@08ok^=Y@;o000000?o]hZWo`000?nbR:P03OnbR:P00ol0003oZhB[o`00
0008ojF3[`03o`000?nJO[?oVWjc00GoVWjc00?o0000ohUh^_n9N;X00on9N;X00ol0003oLFo1og5_
`@02og5_`@04o`000?m<HLOo0000o`0000;o=E?300Co0000o`0c^_l0003o01j/0ol00003ooooo`03
o`000?oooooooooo00Kooooo0ol0000Sooooo`03o`000?oooooooooo00cooooo0006ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`14ooooo`;o00000_ooool5o`000005oi_aa?l0003o0000
ok7khOl000000oo@o]`4o`0000GohNkI0ol00006on3GcP03o`000?oNb<;og/S200Cog/S20ol00006
omNg^@03o`000?oC[K;odjfb00Godjfb00?o0000olnU[Oo?YJd01_o?YJd00ol0003obifYol^MZ@08
ol^MZ@03o`000?o7V:OoaiRW00OoaiRW00?o0000ol>CYOo3TjD02?o3TjD00ol0003o_i2Uokn@Y@09
okn@Y@03o`000?nkSJGo^hfU00[o^hfU0_l0000>ok:8Z0?o00002OnUPjl00ol0003oVWjcoiYn/`05
oiYn/`03o`000?n9N;[oRGRj00?oRGRj00?o0000og5_`OmaKl400_maKl401?l0003oC677odaQaol0
0002ocEC``04o`000?l0<k[o0000o`0N[0?o00000_ooool00ol0003oooooooooo`03ooooo`?o0000
9oooool00ol0003oooooooooo`0;ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co00001Oooool00ol0003oooooooooo`11ooooo`?o
00000_ooool5o`000003oi_aa?l0003o000000;o/O_Q00?o0000om3ng?o@o]`00_l00002om;gi@03
o`000?oQk]WohNkI00;ohNkI0_l00008on3GcP03o`000?oNb<;og/S200?og/S20_l00008omNg^@03
o`000?oC[K;odjfb00Kodjfb00?o0000olnU[Oo?YJd01_o?YJd00ol0003obifYol^MZ@07ol^MZ@03
o`000?o7V:OoaiRW00OoaiRW00?o0000ol>CYOo3TjD02Oo3TjD00ol0003o_i2Uokn@Y@08okn@Y@03
o`000?nkSJGo^hfU00_o^hfU00Co0000okR;Y_l0003o00002onbR:P01Ol0003o[XJ[ojj6Zon^QZ_o
000000WoYH>_00?o0000oiYn/onJO[<01OnJO[<00ol0003oRGRjohUh^P03ohUh^P03o`000?maKl7o
LFo100;oLFo100Co0000odaQaom<HLOo00000_leDl<01?l0003o03>jo`000?l07Z`3o`0000;ooooo
1Ol0000Zooooo`03o`000?oooooooooo00_ooooo000Xooooo`03o`000?oooooooooo03kooooo0ol0
0002ooooo`Go000000CoM^;7o`000?l0003o00000onann401?l0003od?kLo`000?l00003om;gi@04
o`000?oQk]WohNkIon7^f@;o000000?ofnCLo`000?oPelh01_oPelh00ol0003og/S2omk8`P02omk8
`P;o000000?ofL?3o`000?oG]kT01_oG]kT00ol0003odjfbom>]/P06om>]/P03o`000?o?YJgocjF]
00KocjF]00?o0000ol^MZOo;WJT02?o;WJT00ol0003oaiRWolNHY`07olNHY`03o`000?o3TjGo`i>U
00So`i>U00?o0000okn@YOnoT:D02OnoT:D00ol0003o^hfUok^=Y@0:ok^=Y@03o`000?nhRjKo^8^V
00;o^8^V00?o0000ok:8Z?nbR:P01onbR:P00ol0003o[XJ[ojj6Z`03ojj6Z`03o`000?nUPjooYH>_
00OoYH>_00?o0000oiYn/onJO[<01OnJO[<00ol0003oRGRjohUh^P02ohUh^P03o`000?maKl7oLFo1
00?oLFo100?o0000odaQaom<HLL00_l000000oleDl?o0000o`0c^P08o`0002gooooo00?o0000oooo
ooooool02oooool002Sooooo00?o0000ooooooooool0>oooool3o`0000;ooooo1_l000000omfh/Oo
0000o`000005ok7kh@?o00001?oBmnD00ol0003ohNkIo`000002o`0000;ofnCL00?o0000on3Gc_oP
elh01OoPelh00ol0003og/S2omk8`P03o`0000;ofL?300?o0000omNg^OoG]kT01_oG]kT00ol0003o
djfbom>]/P06om>]/P03o`000?o?YJgocjF]00KocjF]00?o0000ol^MZOo;WJT00_o;WJTFo`0000Go
`i>U00?o0000okn@YOnoT:D02?noT:D00ol0003o^hfUok^=Y@0:ok^=Y@03o`000?nhRjKo^8^V00Co
^8^V0_l00006ok:8Z003o`000?n^QZ_o[XJ[00Go[XJ[00?o0000ojF3[onUPjl01onUPjl00ol0003o
VWjcoiYn/`05oiYn/`03o`000?n9N;[oRGRj00;oRGRj00?o0000og5_`OmaKl400_maKl400ol0003o
C677odaQa`02o`m9aP;o000000Co03>jo`000?l07ZcoWc400_l00003ooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool02oooool002Oooooo0_l0000jooooo`?o00000_ooool:o`0000Go
/O_Q0_l00006om;gi@?o00001?oKi=`00ol0003oh=O>on3GcP06on3GcP?o00001?oI`l<00ol0003o
ekNiomNg^@06omNg^@03o`000?oC[K;odjfb00Kodjfb00?o0000olnU[Oo?YJd01?o?YJd8o`0000Go
bYfY00?o0000olNHY_o7V:H01oo7V:H00ol0003oa9>TolBCY004olBCY0Oo00002OnoT:D00ol0003o
^hfUok^=Y@0:ok^=Y@03o`000?nhRjKo^8^V00Ko^8^V0_l00003ok:8Z003o`000?n^QZ_o[XJ[00Oo
[XJ[0_l00008ojF3[`03o`000?nJO[?oVWjc00GoVWjc00?o0000ohUh^_n9N;X00_n9N;X00ol0003o
LFo1og5_`@02og5_`@03o`000?m<HLOoC67700;o3dW60_l000000ol0<k[o0000o`0N[003o`0000;o
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0;ooooo`009oooool00ol0003ooooo
ooooo`0fooooo`?o00000_ooool<o`0000?o/O_Q0ol00007om;gi@;o00001OoKi=`00ol0003oh=O>
on3GcP06on3GcP;o00001_oI`l<00ol0003oekNiomNg^@06omNg^@03o`000?oC[K;odjfb00Kodjfb
00?o0000olnU[Ol000001?l00002olfR[003o`000?o:WJWobYfY00OobYfY00?o0000olNHY_o7V:H0
1oo7V:H00ol0003oa9>TolBCY009olBCY003o`000?o2TJCo`Y6T00?o00001OnoT:D00ol0003o^hfU
ok^=Y@0:ok^=Y@03o`000?nhRjKo^8^V00Wo^8^V00?o0000ok:8Z?l000003?n^QZ/00ol0003oYH>_
ojF3[`06ojF3[`03o`000?nJO[?oVWjc00;oVWjc1_l00002ohUh^P03o`000?maKl7oLFo100;oLFo1
00?o0000odaQaom<HLL00_l?BLH2o`000003o`0c^_l0003o01j/00;o00000oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00_ooooo000Wooooo`03o`000?oooooooooo03?ooooo0ol0
0003ooooo`Wo00000_nElNT00ol0003o/O_Qok7kh@03o`000003ok_gkol0003od_OU00God_OU0_l0
0006om_Tg003o`000?oPelkoh=O>00Goh=O>0_l00007omW3``03o`000?oG]kWoekNi00KoekNi00?o
0000om>]/_oC[K801?oC[K85o`0000KocJ:/00?o0000olZMZOo:WJT02?o:WJT00ol0003oaiRVolNH
YP07olNHYP03o`000?o4TjCoa9>T00Soa9>T00?o0000ol:AY?o2TJ@01?o2TJ@3o`0000;o_i2U00?o
0000ok^=YOnkSJD02OnkSJD00ol0003o^8^VokR;YP0;okR;YP;o00003On^QZ/00ol0003oYH>_ojF3
[`04ojF3[`Ko00000onBO[X00ol0003oOWS2ogih`P04o`0000CoLFo100?o0000odaQaom<HLL00_l?
BLH00ol0003o03>jo`0c^P04o`0000?ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0;ooooo`009oooool00ol0003oooooooooo`0`ooooo`?o00000oooool9o`0000CoUO7Y00Co0000
ok7khOl0003o00000onkmnl00ol0003od_OUom;gi@02om;gi@Co00001ooKi=`00ol0003oh=O>on3G
cP02on3GcP?o000000?ofM3@o`000?oI`l<01OoI`l<00ol0003oekNiomNg^@06omNg^@04o`000?oC
[K;odjfbom>]/PCo00000_o@Z[800ol0003ocJ:/olfR[006olfR[003o`000?o:WJWobYfY00OobYfY
00?o0000olNHY_o7V:H02?o7V:H00ol0003oa9>TolBCY008olBCY003o`000?o2TJCo`Y6T00Oo`Y6T
1?l00009ok^=Y@03o`000?nhRjKo^8^V00co^8^V00?o0000okB9Z?l000003On^QZ/00ol0003oYH>_
ojF3[`03o`0000CoWh:c1_nBO[X00ol0003oOWS2ogih`P02ogih`P?o00000_maKl401?l0003oC677
odaQaom<HLL2o`m9aP03o`000?l0<k[o03>j00?o00001?ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00_ooooo000Wooooo`03o`000?oooooooooo02gooooo0ol00003ooooo`?o0000
00KoH]WHo`000?l0003o0000ohGUm_l00004oiGaj@Co00001Onkmnl00ol0003od_OUom;gi@03o`00
00;oc^cY00?o0000om_Tg?oKi=`01OoKi=`00ol0003oh=O>on3GcP03o`0000?ofM3@00?o0000omW3
`ooI`l<01OoI`l<00ol0003oekNiomNg^@06omNg^@Co00001Oo@Z[800ol0003ocJ:/olfR[006olfR
[003o`000?o:WJWobYfY00SobYfY00?o0000olNHY_o7V:H01oo7V:H00ol0003oa9>TolBCY008olBC
Y003o`000?o2TJCo`Y6T00Wo`Y6T00?o0000okn?Y?noSj@00ol00006ok^=Y@03o`000?nhRjKo^8^V
00_o^8^V00Co0000okB9Z?ndRJSo]8VX0_l0000;ojj6Z`?o00002?nOP[<6oi9n^P03o`000?mnN<;o
OWS200;oOWS200Ko0000oem^bol0003o0000og5_`Ol00003odaQa`;o3dW600?o0000o`0c^_l00000
0ol00003ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02_ooool002Oooooo00?o
0000ooooooooool0:_ooool3o`0000;ooooo1Ol00005ohGUmP03o`000?nElNWoUO7Y00Go00001onk
mnl4o`0000Coc^cY00?o0000om_Tg?oKi=`01OoKi=`4o`0000GofM3@00?o0000omW3`ooI`l<01OoI
`l<00ol0003oekNiomNg^@04omNg^@Co00002?o@Z[800ol0003ocJ:/olfR[006olfR[003o`000?o:
WJWobYfY00OobYfY00?o0000olNHY_o7V:H02?o7V:H00ol0003oa9>TolBCY008olBCY003o`000?o2
TJCo`Y6T00So`Y6T00?o0000okn?Y?noSj@01?noSj@3o`0000;o^hfU00?o0000okR;Y_nhRjH02onh
RjH00ol0003o]8VXokB9Z004okB9Z003o`000?n^QZ_o[XJ[00Oo[XJ[00Co0000ojV6[onYQZoo0000
2OnOP[<00ol0003oTWjjoi9n^P03oi9n^P03o`000?mnN<;oOWS200;oOWS200?o0000oem^bomOK//0
0ol00003odaQa`;o3dW60_l000001?l029Go0000o`000?l00003ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool02_ooool002Kooooo00?o0000ooooooooool0:?ooool3o`0000;ooooo
0ol00008ohGUmP;o000000?oUO7Yo`000?l000000_nUk_P2o`0000Go^oO_1?l00006olk/j@03o`00
0?oKi=cofnCL00?ofnCL1?l00007omW@d003o`000?oI`l?ofL?300KofL?300?o0000omNg^OoG]kT0
1?l00002om:d^`03o`000?o@Z[;od:Zb00Kod:Zb00?o0000olfR[?o=XZ`01_o=XZ`00ol0003obYfY
olZMZ@08olZMZ@03o`000?o7V:KoaiRV00OoaiRV00?o0000olBCY?o4Tj@02?o4Tj@00ol0003o`Y6T
ol:AY009ol:AY003o`000?noSjCo_hnT00Oo_hnT0ol0000<okR;YP03o`000?ndRJSo]8VX00Ko]8VX
00?o0000ojj6Zon^QZ/01?n^QZ/2o`0000CoZHJ_00?o0000oin2/onOP[<01onOP[<00ol0003oTWjj
oi9n^P03oi9n^P03o`000?mnN<;oOWS200;oOWS200Co0000oem^bomOK/_oGfk;0_l00002odaQa`06
o`000?l?BLKo026[o`0QZol0003o00RE0_l00004ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool02_ooool002Kooooo0_l0000Vooooo`?o00000_ooool?o`0000GoYNkh00Co0000ok_g
konkmnoo^oO_1?l000000onlk?Coc^cYolk/j@06olk/j@03o`000?oKi=cofnCL00Co000000?odm_N
o`000?oId=001ooId=000ol0003ofL?3omW3``06omW3``Co00001OoB];/00ol0003od:Zbom2Z/P07
om2Z/P03o`000?o=XZcocJ:/00KocJ:/00?o0000olZMZOo:WJT01oo:WJT00ol0003oaiRVolNHYP08
olNHYP03o`000?o4TjCoa9>T00Soa9>T00?o0000ol:AY?o2TJ@02?o2TJ@00ol0003o_hnTokn?Y009
okn?Y004o`000?nlSJ?o0000o`0000Wo^8^V00?o0000okB9Z?ndRJP02?ndRJP2o`0000?o[XJ[00?o
0000ojV6[onYQZl01OnYQZl00ol0003oWh:coin2/`07oin2/`03o`000?nBO[[oTWjj00?oTWjj00?o
0000ogih`_mnN<800_mnN<800ol0003oGfk;oem^b`02oem^b`;o000000?oC677o`000?l?BLH00_l0
8J/01?l0003o00REo`000?l00004ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
2_ooool002Kooooo00?o0000ooooooooool08_ooool3o`0000?ooooo0_l0000:oiOQo@;o00001onU
k_P00ol0003o^oO_o`000002o`0000;o_>cd0_l00008olk/j@Co00001?oCfmh00ol0003ofM3@omW@
d007omW@d003o`000?oI`l?ofL?300?ofL?31?l00007om:d^`03o`000?o@Z[;od:Zb00Ood:Zb00?o
0000olfR[?o=XZ`01_o=XZ`00ol0003obYfYolZMZ@08olZMZ@03o`000?o7V:KoaiRV00SoaiRV00?o
0000olBCY?o4Tj@01oo4Tj@00ol0003o`Y6Tol:AY009ol:AY003o`000?noSjCo_hnT00So_hnT00?o
0000okb=XonlSJ<00_nlSJ<2o`0000Oo^8^V00?o0000okB9Z?ndRJP02_ndRJP00ol0003o[XJ[o`00
0009ojV6[`03o`000?nOP[?oWh:c00OoWh:c00?o0000oi9n^_nBO[X00onBO[X00ol0003oOWS2ogih
`P02ogih`P0:o`000?mOK/_oGfk;oem^bol0003o;Eg@o`000?m<HLOo0000o`m9aP;o026[1?l00003
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02_ooool002Kooooo00?o0000oooo
ooooool08?ooool2o`0000Cooooo0_l00009oiOQo@;o00000onUk_P8o`0000Go_>cd00?o0000olk/
jOo>k>T01?o>k>T5o`0000Kodm_N00?o0000omW@d?oId=001ooId=000ol0003ofL?3omW3``04o`00
00;odkg400?o0000om:d^ooB];/01_oB];/00ol0003od:Zbom2Z/P06om2Z/P03o`000?o=XZcocJ:/
00OocJ:/00?o0000olZMZOo:WJT01oo:WJT00ol0003oaiRVolNHYP08olNHYP03o`000?o4TjCoa9>T
00Soa9>T00?o0000ol:AY?o2TJ@02?o2TJ@00ol0003o_hnTokn?Y009okn?Y003o`000?nlSJ?o_8fS
00Co_8fS0_l00004okR;YP03o`000?ndRJSo]8VX00co]8VX0_l0000:ojV6[`03o`000?nOP[?oWh:c
00OoWh:c00?o0000oi9n^_nBO[X00onBO[X00ol0003oOWS2ogih`P02ogih`P06o`000?mOK/_oGfk;
oem^bol0003o;Eg@0ol000000ol?BLKo026[o`0QZ`03o`0000Cooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0:ooooo`009_ooool00ol0003oooooooooo`0Mooooo`?o00000oooool3
o`0000;oUn7m2Ol000000onUk_So0000o`000002o`0000CoZ^Cj00?o0000okc/m?nlk?@01Onlk?@0
0ol0003oc^cYo`000005o`0000;oan7[2?oCfmh00ol0003ofM3@omW@d007omW@d0Co00001OoC_L@0
0ol0003od[Bkom:d^`06om:d^`03o`000?o@Z[;od:Zb00Ood:Zb00?o0000olfR[?o=XZ`01_o=XZ`0
0ol0003obYfYolZMZ@08olZMZ@03o`000?o7V:KoaiRV00SoaiRV00?o0000olBCY?o4Tj@01oo4Tj@0
0ol0003o`Y6Tol:AY008ol:AY003o`000?noSjCo_hnT00Wo_hnT00?o0000okb=XonlSJ<01onlSJ<2
o`000003okR;Y_l0003o]8VX00ko]8VX00?o0000ok69Zol000002_nYQZl00ol0003oWh:coin2/`07
oin2/`03o`000?nBO[[oTWjj00?oTWjj00?o0000ogih`_mnN<800_mnN<801Ol0003oGfk;oem^bomO
K/_o000000;o;Eg@0_l000000ol?BLKo026[o`0QZ`03o`0000Cooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0:ooooo`009_ooool00ol0003oooooooooo`0Jooooo`?o00000oooool3
o`0000[oWmSl0_l00009oj[TnP03o`000?nlk?Co_>cd00?o_>cd1_l00006olOQj`03o`000?oCfmko
dm_N00Kodm_N00?o0000omW@d?oId=001?oId=05o`0000Oodkg400?o0000om:d^ooB];/01_oB];/0
0ol0003od:Zbom2Z/P07om2Z/P03o`000?o=XZcocJ:/00OocJ:/00?o0000olZMZOo:WJT01oo:WJT0
0ol0003oaiRVolNHYP08olNHYP03o`000?o4TjCoa9>T00Soa9>T00?o0000ol:AY?o2TJ@02?o2TJ@0
0ol0003o_hnTokn?Y009okn?Y003o`000?nlSJ?o_8fS00Wo_8fS0_l0000>okB9Z005o`000?naRJ_o
/HV[ok69Zol000002_nYQZl00ol0003oWh:coin2/`07oin2/`03o`000?nBO[[oTWjj00?oTWjj00?o
0000ogih`_mnN<800_mnN<801Ol0003oGfk;oem^bomOK/_o000000?o;Eg@00Go0000o`m9a_l08J_o
026[o`08U@02o`0000Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`09ooooo`00
9_ooool00ol0003oooooooooo`0Gooooo`?o00000_ooool4o`0000?oWmSl0_l00006oioHo0;o0000
2OnZi?X2o`000003okc/m?l0003o000000?o000000?o^>3do`000?o7hN/02?o7hN/00ol0003odm_N
om?KgP06om?KgP03o`000?oId=3o000000Go00000_oAam400ol0003odkg4om>ma007om>ma003o`00
0?oB];_od[Bk00Kod[Bk00?o0000om2Z/_o@Z[801oo@Z[800ol0003ocJ:/olfR[006olfR[003o`00
0?o:WJWobYfY00SobYfY00?o0000olNHY_o7V:H02?o7V:H00ol0003oa9>TolBCY007olBCY003o`00
0?o2TJCo`Y6T00So`Y6T00?o0000okn?Y?noSj@02OnoSj@00ol0003o_8fSokb=X`0:okb=X`04o`00
0?njS:Ko0000o`0000_o]8VX00?o0000ok69ZonaRJ/00onaRJ/2o`0000WoZHJ_00?o0000oin2/onO
P[<01OnOP[<7o`000003oi9n^_l0003oOWS200?oOWS200Go0000oem^bomOK/_oGfk;o`000003obeM
d0;o00000_l08J/00ol029Go0000ooooo`03ooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool02Oooool002Gooooo0_l0000Fooooo`?o00000_ooool3o`0000WoX]3g1_l000000onZi?[o
0000o`00000:o`0000Go^>3d0_l00009olOQj`03o`000?oCfmkodm_N00?odm_N1_l00007om77d@03
o`000?oC_LCodkg400Oodkg400?o0000om:d^ooB];/01_oB];/00ol0003od:Zbom2Z/P07om2Z/P03
o`000?o=XZcocJ:/00OocJ:/00?o0000olZMZOo:WJT00_o:WJT<o`0000GoaiRV00?o0000olBCY?o4
Tj@01oo4Tj@00ol0003o`Y6Tol:AY008ol:AY003o`000?noSjCo_hnT00Wo_hnT00?o0000okb=Xonl
SJ<02OnlSJ<00ol0003o^XbVokZ<YP02okZ<YP;o00002?ndRJP00ol0003o/HV[ok69Z`06ok69Z`03
o`000?nYQZooZHJ_00OoZHJ_00?o0000oin2/onOP[<01?l00003oiV4^`04o`000?n9P<?oRH33ohV0
``Go00000_mnN<801Ol0003oGfk;oem^bomOK/_o000000;o;Eg@00?o0000o`0n`Ol000000_l08J/2
o`0000Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0
003oooooooooo`0Booooo`?o00000_ooool3o`0000coX]3g0ol0000:ojWIn0;o00002?nhh?@00ol0
003oan7[olOQj`08olOQj`03o`000?oCfmko000000Co00000_o;d]l00ol0003odLOAom77d@07om77
d@03o`000?oC_LCodkg400Oodkg400?o0000om:d^ooB];/01ooB];/00ol0003od:Zbom2Z/P07om2Z
/P04o`000?o=XZcocJ:/olfR[0_o00001Oo8VZP00ol0003oaYFTolJEY004olJEY1;o00001oo2TJ@0
0ol0003o_hnTokn?Y00:okn?Y003o`000?nlSJ?o_8fS00Wo_8fS00?o0000okZ<Y_njS:H01?njS:H0
0ol0003o]8VXokB9Z005okB9Z003o`000?naRJ_o/HV[00Oo/HV[0_l00007ojV6[`?o00002?nIQ;/0
0ol0003oRH33ohV0``03ohV0``03o`000?maN/go000000?o00000omOK//01ol0003o;Eg@obeMd?l0
003o03k1o`000?l08J/00ol00004ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
2Oooool002Gooooo00?o0000ooooooooool03oooool3o`0000;ooooo0ol00008oj?:m0Oo00000onY
fOP2o`0000KoZMWh0_l00009okSPm003o`000?o7hN_oan7[00;oan7[2Ol00006ol_Bg`03o`000?oA
am7odLOA00OodLOA00?o0000om>ma?oC_L@01ooC_L@00ol0003od[Bkom:d^`07om:d^`03o`000?o@
Z[;od:Zb00;od:Zb2_l00005ol^S[`03o`000?o8VZSob9ZX00Oob9ZX00?o0000olJEY?o6UJ@02Oo6
UJ@00ol0003oaYJUolJFY@07olJFY@04o`000?o3TJ;o`i6Rol>AXPGo00000_o2TJ@00ol0003o_hnT
okn?Y009okn?Y003o`000?nlSJ?o_8fS00Wo_8fS00?o0000okZ<Y_njS:H01_njS:H2o`0000Co]8VX
00?o0000ok69ZonaRJ/02_naRJ/00ol0003oZHJ_ojV6[`02ojV6[`;o00000onUQk@9oiV4^`03o`00
0?n9P<?oRH3300?oRH3300Co0000og5jcOmaN/goLG[=0ol00002oem^b`07o`000?l]GM3o;Eg@o`00
0?l0?/7o0000o`0QZ`02o`0000Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`09
ooooo`009Oooool00ol0003oooooooooo`0<ooooo`?o00000_ooool3o`0000coXl[d0ol00008ojS@
m@Ko000000?o^>3do`000?l000003Ol00004okoFj`03o`000?o;d]oobm;O00Oobm;O00?o0000om77
dOoAam401ooAam400ol0003odkg4om>ma008om>ma003o`000?oB];_od[Bk00?od[Bk2Ol00005ol^U
/P03o`000?o;Xjoobj>_00Kobj>_00?o0000olRJZ?o8VZP02?o8VZP00ol0003oaYFTolJEY008olJE
Y003o`000?o6UZGoaYJU00OoaYJU00?o0000ol>AX_o3TJ801oo3TJ84o`0000[o_hnT00?o0000okb=
XonlSJ<02OnlSJ<00ol0003o^XbVokZ<YP08okZ<YP;o000000?o]8VXo`000?naRJ/03OnaRJ/01?l0
003oZHJ_o`000?l00006ojF7]003o`000?nIQ;_oVHBk00KoVHBk00?o0000ohV0`on9P<<00on9P<<0
0ol0003oLG[=og5jc@02og5jc@?o000000SoGfk;o`000?l]GM3o;Eg@o`000?l0?/7o0000o`0QZ`;o
00001?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`00
0?oooooooooo00Wooooo0ol00002ooooo`?o00001OnTao85o`0000?oXl[d0_l0000<ojS@m@?o0000
2OnceO82o`0000Wo_mK[0_l00009ol_Bg`03o`000?oAam7odLOA00OodLOA00?o0000om>ma?oC_L@0
2?oC_L@00ol0003od[Bko`000004o`0000?oc:fj00?o0000ol^U/_o;YK801oo;YK800ol0003obj>_
ol^S[`07ol^S[`03o`000?o8VZSob9ZX00Oob9ZX00?o0000olJEY?o6UJ@02Oo6UJ@00ol0003oaYJU
olJFY@07olJFY@03o`000?o3TJ;o`i6R00So`i6R00?o0000ol6>XOo1SZ401?l00005okn?Y003o`00
0?nlSJ?o_8fS00Wo_8fS00?o0000okZ<Y_njS:H02onjS:H2o`0000ko/HV[0_l00009ojF7]003o`00
0?nIQ;_oVHBk00KoVHBk00?o0000ohV0`on9P<<00on9P<<00ol0003oLG[=og5jc@02og5jc@03o`00
0?m8LMOo000000;o00000_l]GM001?l0003o03k1o`000?l08J/2o`0000Cooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`06ooooo`?o0000
0oooool2o`0000goY<Ob0ol00004ojS@m@;o00001_nXd?D2o`0000_o/mGb00?o0000okoFjonoe^/0
2?noe^/00ol0003obm;Ool_Bg`08ol_Bg`03o`000?oAam7odLOA00OodLOA00?o0000om>ma?oC_L@0
0_oC_L@9o`0000Ooc:fj00?o0000ol^U/_o;YK802?o;YK800ol0003obj>_ol^S[`06ol^S[`03o`00
0?o8VZSob9ZX00Sob9ZX00?o0000olJEY?o6UJ@02?o6UJ@00ol0003oaYJUolJFY@07olJFY@03o`00
0?o3TJ;o`i6R00So`i6R00?o0000ol6>XOo1SZ401Oo1SZ43o`0000;o_hnT00?o0000okb=XonlSJ<0
2?nlSJ<00ol0003o^XbVokZ<YP0<okZ<YP04o`000?ngS:So0000o`0000_o/HV[00Co0000ojj:/?n^
R[3o[XZ`2OnUQk@2o`0000OoVHBk00?o0000ohV0`on9P<<00on9P<<00ol0003oLG[=og5jc@02og5j
c@03o`000?m8LMOoB77G00;o00000_l]GM001?l0003o03k1o`000?l08J/2o`0000Cooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`08ooooo`009?ooool3o`0000Cooooo0ol00004oooo
o`;o00003OnTao83o`0000SoYlSa1_l00002ok?ElPCo00001OnceO82o`0000[o_mK[00?o0000ol_B
goo;d]l02?o;d]l00ol0003odLOAom77d@02om77d@_o00001_o<^/P00ol0003oc:fjolb]^P06olb]
^P03o`000?o;YK;objFb00SobjFb00?o0000ol^S[oo;Xjl01oo;Xjl00ol0003ob9ZXolRJZ008olRJ
Z003o`000?o6UJCoaYFT00SoaYFT00?o0000olJFYOo6UZD01oo6UZD00ol0003o`i6Rol>AXP08ol>A
XP03o`000?o1SZ7o`HjQ00So`HjQ1?l00009okb=X`03o`000?njS:Ko^XbV00_o^XbV00?o0000okN<
Z?ngS:P00_ngS:P00ol0003o/HV[ok69Z`07ok69Z`03o`000?n^R[3o[XZ`00?o[XZ`00?o0000ojF7
]?nUQk@01onUQk@00ol0003oVHBkoiV4^`05oiV4^`03o`000?n9P<?oRH3300?oRH3300?o0000og5j
cOmaN/d00_maN/d01?l0003oB77GodQaeom8LML2o`000003obeMd?l0003o03k100?o00001Oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo000Tooooo`04o`000?oooooooooo
ooooo`?o00001?ooool3o`0000SoY<C`1ol0000<ojO8l@?o00002?n^c?05o`000003okoFjol0003o
000001Wo00001?o8`=800ol0003oc;[8olbjb009olbjb003o`000?o<[K[oc:fj00Ooc:fj00?o0000
ol^U/_o;YK801oo;YK800ol0003obj>_ol^S[`07ol^S[`03o`000?o8VZSob9ZX00Sob9ZX00?o0000
olJEY?o6UJ@02?o6UJ@00ol0003oaYJUolJFY@08olJFY@03o`000?o3TJ;o`i6R00So`i6R00?o0000
ol6>XOo1SZ402Oo1SZ400ol0003o`92Sol2@X`03o`0000Go_8fS00?o0000okZ<Y_njS:H02onjS:H0
0ol0003o]hbXokN<Z004okN<Z0;o00001_naRJ/00ol0003o[XZ`ojj:/005ojj:/003o`000?nUQkCo
YHNd00OoYHNd00?o0000oiV4^onIQ;/01OnIQ;/00ol0003oRH33ohV0``03ohV0``03o`000?maN/go
LG[=00;oLG[=00Co0000odQaeom8LMOoB77G0_l000000ol]GM3o0000o`0n`@03o`0000Cooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`08ooooo`006Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Kooooo1?l00005ooooo`;o00003?nTa?03o`0000GoY/C_1Ol00003ojO8l@;o00002on^
c?03o`0000_o]lk[00?o0000ol;7goo2aml02?o2aml00ol0003ob<3BolS0dP08olS0dP03o`000?o<
^/Soc;[800Woc;[800?o0000olb]^_o<[KX01oo<[KX00ol0003objFbol^U/P08ol^U/P03o`000?o;
Xjoobj>_00Oobj>_00?o0000olRJZ?o8VZP02?o8VZP00ol0003oaYFTolJEY008olJEY003o`000?o6
UZGoaYJU00OoaYJU00?o0000ol>AX_o3TJ802?o3TJ800ol0003o`HjQol6>X@09ol6>X@03o`000?o0
T:?o`92S00Co`92S0ol00002okb=X`03o`000?njS:Ko^XbV00[o^XbV00?o0000okN<Z?ngS:P01ong
S:P2o`0000?o/HV[00?o0000ojj:/?n^R[001on^R[02o`0000SoYHNd00?o0000oiV4^onIQ;/01OnI
Q;/00ol0003oRH33ohV0``03ohV0``03o`000?maN/goLG[=00;oLG[=00Co0000odQaeom8LMOoB77G
1?l000001?l0?/7o0000o`000?l00004ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool02?ooool001Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`;o00002oooool5o`0000?o
Y<C`0_l0000=ojK4k`?o00001?n^c?02o`0000Go[/c`0_l0000<okO>j`;o00002_o2aml00ol0003o
b<3BolS0dP08olS0dP03o`000?o<^/Soc;[800Woc;[800?o0000olb]^_o<[KX01oo<[KX00ol0003o
bjFbol^U/P08ol^U/P03o`000?o;Xjoobj>_00Oobj>_00?o0000olRJZ?o8VZP02?o8VZP00ol0003o
aYFTolJEY008olJEY003o`000?o6UZGoaYJU00SoaYJU00?o0000ol>AX_o3TJ802?o3TJ800ol0003o
`HjQol6>X@09ol6>X@03o`000?o0T:?o`92S00Oo`92S0ol0000;okZ<YP03o`000?ngS:So]hbX00[o
]hbX00?o0000ok69Zol000003?n^R[000ol0003oYHNdojF7]006ojF7]003o`000?nIQ;_oVHBk00;o
VHBk1_l00003ohV0``03o`000?maN/goLG[=00;oLG[=00Ko0000odQaeom8LMOoB77Go`000?l5G=@2
o`000004o`0n`Ol0003o0000o`0000Cooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`08ooooo`006Oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool03Ooo
ool3o`0000coY/C_0ol00009ojO8l@Go00000_ngc^/00ol0003o]lk[okO>j`08okO>j`03o`000?o2
amoo`/OO00Wo`/OO00?o0000olS0d_o8`=802?o8`=800ol0003oc;[8olbjb009olbjb003o`000?o<
[K[oc:fj00Soc:fj00?o0000ol^U/_o;YK802?o;YK800ol0003obj>_ol^S[`07ol^S[`03o`000?o8
VZSob9ZX00Sob9ZX00?o0000olJEY?o6UJ@02?o6UJ@00ol0003oaYJUolJFY@07olJFY@03o`000?o3
TJ;o`i6R00Wo`i6R00?o0000ol6>XOo1SZ402?o1SZ400ol0003o`92Sol2@X`09ol2@X`03o`000?nn
SZCo000000;o00002?njS:H00ol0003o]hbXokN<Z00;okN<Z0;o00003On^R[000ol0003oYHNdojF7
]004ojF7]0Ko00001OnCR<@00omoQLoo0000o`000003o`0000CoLG[=00Go0000odQaeom8LMOoB77G
o`000002o`ELe004o`000?l0?/7o0000o`0000Gooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`08ooooo`006Oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000oooooooo
ool05Oooool6o`0000goYlSa0_l00005ojk5j`Ko00000ongc^/00ol0003o`/OOol;7g`09ol;7g`03
o`000?o8`=;ob<3B00Sob<3B00?o0000olbjb?o<^/P02_o<^/P00ol0003oc:fjolb]^P07olb]^P03
o`000?o;YK;objFb00SobjFb00?o0000ol^S[oo;Xjl01oo;Xjl00ol0003ob9ZXolRJZ008olRJZ003
o`000?o6UJCoaYFT00WoaYFT00?o0000olJFYOo6UZD01oo6UZD00ol0003o`i6Rol>AXP08ol>AXP03
o`000?o1SZ7o`HjQ00Wo`HjQ00?o0000ol2@Xoo0T:<02?o0T:<00ol0003o_XjTokj>Y003okj>Y0;o
00001OnjS:H00ol0003o]hbXokN<Z00<okN<Z004o`000?neS:_o0000o`0000co[XZ`00?o0000ojF7
]?nUQk@00ol00004oj2:_0SoThS41?moQLl4o`0000;oLG[=00Go0000odQaeom8LMOoB77Go`000002
o`ELe0Co00001?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo000Ioooo
o`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`0Looooo`Ko00000onWb?42
o`0000go[/G[0ol000000oo2amoo0000o`000003o`0000Go`/OO00?o0000olS0d_o8`=802?o8`=80
0ol0003oc;[8olbjb00:olbjb003o`000?o<[K[oc:fj00Soc:fj00?o0000ol^U/_o;YK801oo;YK80
0ol0003obj>_ol^S[`08ol^S[`03o`000?o8VZSob9ZX00Sob9ZX00?o0000olJEY?o6UJ@02?o6UJ@0
0ol0003oaYJUolJFY@07olJFY@03o`000?o3TJ;o`i6R00Wo`i6R00?o0000ol6>XOo1SZ402?o1SZ40
0ol0003o`92Sol2@X`09ol2@X`03o`000?nnSZCo_XjT00Go_XjT0ol000000onjS:Ko0000okN<Z00=
okN<Z003o`000?neS:_o]Hb[00;o]Hb[00?o0000ojj:/?n^R[002On^R[03o`0000SoX8Zl00?o0000
oi>8a?nCR<@01OnCR<@00ol0003oOhG?ogn5c`03ogn5c`03of22g?l0003o000000;o00000om8LML0
1?l0003o1EcDo`ELe?l5G=@3o`0000Cooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`08ooooo`006Oooool01Ol@413ooooooooooooooooo410@00_ooooo0_l0000Rooooo`?o00003On^
aN/3o`0000So]L;T5_l00006olbjb003o`000?o<[K[oc:fj00Soc:fj00?o0000ol^U/_o;YK802?o;
YK800ol0003obj>_ol^S[`07ol^S[`03o`000?o8VZSob9ZX00Wob9ZX00?o0000olJEY?o6UJ@02?o6
UJ@00ol0003oaYJUolJFY@07olJFY@03o`000?o3TJ;o`i6R00So`i6R00?o0000ol6>XOo1SZ402Oo1
SZ400ol0003o`92Sol2@X`08ol2@X`03o`000?nnSZCo_XjT00Wo_XjT0_l0000=okN<Z003o`000?ne
S:_o]Hb[00Co]Hb[0_l00007ojj:/0;o00000on[S;H00ol0003oX8Zloj2:_006oj2:_0;o00001_nC
R<@2o`0000CoOhG?0omPP]`3o`0000;oB77G00Co0000o`ELe?l5G=Co1EcD0ol00004ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool01oooool001Wooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0=ooooo`03o`000?oooooooooo02Gooooo1Ol00003ojk5j`;o00003?ne`^@2o`0000[o^lGQ
00?o0000ol6fcoo1]/l01_o1]/lQo`0000Gobj>_00?o0000olRJZ?o8VZP02?o8VZP00ol0003oaYFT
olJEY008olJEY003o`000?o6UZGoaYJU00SoaYJU00?o0000ol>AX_o3TJ802?o3TJ800ol0003o`HjQ
ol6>X@08ol6>X@03o`000?o0T:?o`92S00Wo`92S00?o0000okj>Y?nnSZ@02OnnSZ@01?l0003o_8fT
o`000?l0000:okN<Z003o`000?neS:_o]Hb[00Oo]Hb[0_l00004ojj:/003o`000?n[S;KoZhbf00Co
Zhbf00?o0000oj2:_?nPR[`01onPR[`00ol0003oThS4oi>8a005oi>8a003o`000?moQLooOhG?00;o
OhG?00?o0000of22g?mPP]`00_mPP]`2o`000003odQaeol0003o1EcD00;o1EcD0_l00004ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool01oooool001Wooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0>ooooo`03o`000?oooooooooo02Wooooo0ol0000=okG2i003o`000?nkaN7o^lGQ00So
^lGQ0_l0000<ol6fc`03o`000?o4[/Coa:k400Woa:k400?o0000olNaa?o7/L@02Oo7/L@00ol0003o
aJ:eolFR]@03olFR]@_o00001Oo8VZP00ol0003oaYFTolJEY008olJEY003o`000?o6UZGoaYJU00Oo
aYJU00?o0000ol>AX_o3TJ802Oo3TJ800ol0003o`HjQol6>X@08ol6>X@03o`000?o0T:?o`92S00So
`92S00?o0000okj>Y?nnSZ@02OnnSZ@00ol0003o_8fTokb=Y002okb=Y0;o00001ongS:P00ol0003o
]Hb[okF<Z`0:okF<Z`04o`000?n^R[3o0000o`0000SoZhbf0_l00008oj2:_0;o00001_nCR<@00ol0
003oOhG?ogn5c`02ogn5c`03o`000?mPP]coH8;L00;oH8;L00Co;7OSo`000?l0003o00000ol5G=@2
o`0000Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07ooooo`00;Oooool00ol0
003oooooooooo`0^ooooo`Go00000one`^@2o`0000[o^lGQ00?o0000ol6fcoo1]/l02oo1]/l00ol0
003oa:k4olB^a009olB^a003o`000?o7/LCoak7400Woak7400?o0000olFR]Oo5X[D02?o5X[D00ol0
003oa9b^olBL[P04olBL[QGo00001Oo6UZD00ol0003o`i6Rol>AXP08ol>AXP03o`000?o1SZ7o`HjQ
00So`HjQ00?o0000ol2@Xoo0T:<02Oo0T:<00ol0003o_XjTokj>Y009okj>Y003o`000?nlSJCo_8fT
00Co_8fT0_l00004okN<Z003o`000?neS:_o]Hb[00co]Hb[0_l0000;oj^<]P03o`000?nPR[coX8Zl
00OoX8Zl00?o0000oi>8a?nCR<@01?nCR<@00ol0003oOhG?ogn5c`02ogn5c`03o`000?mPP]coH8;L
00;oH8;L00Co0000obaghol0003o00000ol5G=@2o`0000Cooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`07ooooo`00;_ooool2o`0003?ooooo0ol000000onkaN7o0000o`000003o`00
00Go^lGQ00?o0000ol6fcoo1]/l02oo1]/l00ol0003oa:k4olB^a009olB^a003o`000?o7/LCoak74
00Woak7400?o0000olFR]Oo5X[D02?o5X[D00ol0003oa9b^olBL[P09olBL[P03o`000?o7XK7oaj6a
00Soaj6a00?o0000olBHZ_o4V:X00oo4V:X8o`0000So`i6R00?o0000ol6>XOo1SZ402?o1SZ400ol0
003o`92Sol2@X`08ol2@X`03o`000?nnSZCo_XjT00Wo_XjT00?o0000okb=Y?nlSJ@01onlSJ@2o`00
0003okN<Z?l0003o]Hb[00ko]Hb[00?o0000ok>?/Ol000002on[S;H2o`0000SoX8Zl00?o0000oi>8
a?nCR<@01?nCR<@00ol0003oOhG?ogn5c`02ogn5c`03o`000?mPP]coH8;L00;oH8;L0_l000000ol/
Mn?o0000o`000002o`ELe0;o00001?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00Oooooo000`ooooo`03o`000?oooooooooo03Wooooo1Ol000000oo1]/oo0000o`00000:ol6fc`03
o`000?o4[/Coa:k400Woa:k400?o0000olNaa?o7/L@02Oo7/L@00ol0003oaJ:eolFR]@08olFR]@03
o`000?o4W:koa9b^00Woa9b^00?o0000olNQ/Oo7XK402?o7XK400ol0003oa9RZolBHZP08olBHZP04
o`000?o2TjGo`Y>Uol:CY@Go00000oo3TJ800ol0003o`HjQol6>X@07ol6>X@03o`000?o0T:?o`92S
00Wo`92S00?o0000okj>Y?nnSZ@02OnnSZ@00ol0003o_8fTokb=Y009okb=Y0;o00003_neS:/01?l0
003o/hnaok>?/OncSk42o`0000_oZhbf00?o0000oj2:_?nPR[`01?nPR[`<o`0000;oOhG?00?o0000
of22g?mPP]`00omPP]`00ol0003o;7OSobagh`02o`000003o`ELe?l0003ooooo00?ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`07ooooo`00<Oooool00ol0003oooooooooo`10oooo
o`Ko00000oo1]/l00ol0003oa:k4olB^a009olB^a003o`000?o7/LCoak7400Woak7400?o0000olFR
]Oo5X[D02Oo5X[D00ol0003oa9b^olBL[P08olBL[P03o`000?o7XK7oaj6a00Woaj6a00?o0000olBH
Z_o4V:X01oo4V:X00ol0003o`Y>Uol:CY@07ol:CY@So00001Oo1SZ400ol0003o`92Sol2@X`08ol2@
X`03o`000?nnSZCo_XjT00Wo_XjT00?o0000okb=Y?nlSJ@02_nlSJ@01?l0003o^hnYo`000?l0000;
okF<Z`03o`000?ncSk7o/hna00Co/hna0_l0000:oj^<]P03o`000?nPR[coX8Zl00?o00001?nLT<H7
ohb@d@03ogB@gol0003o000000;o00001OmPP]`00ol0003o;7OSobagh`04o`0000Cooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`07ooooo`00<_ooool00ol0003oooooooooo`15oooo
o`?o000000?oa:k4o`000?l000000ol00005olB^a003o`000?o7/LCoak7400Woak7400?o0000olFR
]Oo5X[D02Oo5X[D00ol0003oa9b^olBL[P09olBL[P03o`000?o7XK7oaj6a00Soaj6a00?o0000olBH
Z_o4V:X02?o4V:X00ol0003o`Y>Uol:CY@09ol:CY@03o`000?o4V:_oa9R[00?oa9R[1ol00009ol2@
X`03o`000?nnSZCo_XjT00Wo_XjT00?o0000okb=Y?nlSJ@02OnlSJ@00ol0003o^hnYok^?Z@02ok^?
Z@?o00001oneS:/00ol0003o/hnaok>?/@07ok>?/@03o`000?n[S;KoZhbf00OoZhbf0ol00008oib@
aP03o`000?n<T=7oS93A00CoS93A00?o0000ogB@gomdT=l01?l00003of22g003o`000?l/Mn?o;7OS
00Co00001?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo000cooooo`;o
0000C_ooool8o`0000Soak7400?o0000olFR]Oo5X[D02Oo5X[D00ol0003oa9b^olBL[P09olBL[P03
o`000?o7XK7oaj6a00Soaj6a00?o0000olBHZ_o4V:X02?o4V:X00ol0003o`Y>Uol:CY@09ol:CY@03
o`000?o4V:_oa9R[00Soa9R[00?o0000ol6EZOo1UJT00ol00005ol2@X`03o`000?nnSZCo_XjT00[o
_XjT00?o0000okb=Y?nlSJ@02?nlSJ@00ol0003o^hnYok^?Z@06ok^?Z@;o00001?neS:/00ol0003o
/hnaok>?/@09ok>?/@;o00001?n[S;H3o`0000?oYi6n2OnLT<H00ol0003oS93Aohb@d@04ohb@d@;o
00000omdT=l00om>S^co0000o`000003o`0000?o;7OS00?o0000o`m[gOl000001?ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo000eooooo`03o`000?oooooooooo05?ooooo
1Ol00002olNaa003o`000?o5X[GoaJ:e00WoaJ:e00?o0000olBL[_o4W:h02Oo4W:h00ol0003oaj6a
olNQ/@09olNQ/@03o`000?o4V:[oa9RZ00Soa9RZ00?o0000ol:CYOo2TjD02Oo2TjD00ol0003oa9R[
olBHZ`07olBHZ`03o`000?o1UJWo`IFY00Co`IFY0ol00002ol2@X`03o`000?nnSZCo_XjT00Wo_XjT
00?o0000okb=Y?nlSJ@02OnlSJ@00ol0003o^hnYok^?Z@08ok^?Z@;o000000?o]Hb[o`000?ncSk40
3OncSk401?l0003oZhbfo`000?l00008ojNA_P03o`000?nLT<KoW93600GoW9360_l00006ohb@d@04
o`000?mdT=ooM93OogB@g`;o00000_m>S^`3o`0000;o;7OS0_l00004ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool01_ooool003Kooooo00?o0000ooooooooool0Eoooool5o`0000Wo
aJ:e00?o0000olBL[_o4W:h02?o4W:h00ol0003oaj6aolNQ/@09olNQ/@03o`000?o4V:[oa9RZ00So
a9RZ00?o0000ol:CYOo2TjD02Oo2TjD00ol0003oa9R[olBHZ`08olBHZ`03o`000?o1UJWo`IFY00Oo
`IFY1?l0000:okj>Y003o`000?nlSJCo_8fT00So_8fT00?o0000ok^?ZOnkSjT02onkSjT00ol0003o
/hnaok>?/@0>ok>?/@03o`000?nWTKkoYi6n00WoYi6n0_l00007oib@aP03o`000?n<T=7oS93A00Co
S93A0_l00003ogB@g`;o00000om>S^`3o`000003obaghol0003ooooo00?ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`06ooooo`00=oooool00ol0003oooooooooo`1Kooooo`Go0000
0oo5X[D00ol0003oa9b^olBL[P09olBL[P03o`000?o7XK7oaj6a00Woaj6a00?o0000olBHZ_o4V:X0
2?o4V:X00ol0003o`Y>Uol:CY@08ol:CY@03o`000?o4V:_oa9R[00Soa9R[00?o0000ol6EZOo1UJT0
2Oo1UJT00ol0003o_i2Uokn@Y@04o`0000Go_XjT00?o0000okb=Y?nlSJ@02OnlSJ@00ol0003o^hnY
ok^?Z@0;ok^?Z@03o`000?niTJgo000000;o00002OncSk42o`0000?o/9:h0_l0000:ojNA_P;o0000
1_nLT<H00ol0003oS93Aohb@d@05ohb@d@03o`000?mdT=ooM93O00;oM93O00?o0000odj>k?m>S^`0
0_m>S^`4o`0000Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`06ooooo`00>?oo
ool2o`00063ooooo2Ol00005olBL[P03o`000?o7XK7oaj6a00Woaj6a00?o0000olBHZ_o4V:X02?o4
V:X00ol0003o`Y>Uol:CY@09ol:CY@03o`000?o4V:_oa9R[00Ooa9R[00?o0000ol6EZOo1UJT02Oo1
UJT00ol0003o_i2Uokn@Y@05okn@Y@?o00000_nnSZ@00ol0003o_8fTokb=Y008okb=Y003o`000?nk
SjWo^hnY00_o^hnY00?o0000okVA[OniTJd00oniTJd2o`0000Ko/hna00?o0000ok2B^?n`T[P01On`
T[P00ol0003oYi6nojNA_P09ojNA_P03o`000?nLT<KoW93600CoW93600?o0000ohb@dOn<T=401On<
T=400ol0003oM93OogB@g`02ogB@g`;o00001?m>S^`00ol0003o>8O[o`000004ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool01_ooool003[ooooo00?o0000ooooooooool0I_ooool8
o`0000Soaj6a00?o0000olBHZ_o4V:X02Oo4V:X00ol0003o`Y>Uol:CY@08ol:CY@03o`000?o4V:_o
a9R[00Soa9R[00?o0000ol6EZOo1UJT02Oo1UJT00ol0003o_i2Uokn@Y@08okn@Y@Go00001onlSJ@0
0ol0003o^hnYok^?Z@0;ok^?Z@03o`000?niTJgo^I6]00Ko^I6]0ol000000oncSk7o0000o`000009
ok2B^0;o00002OnWTKhEo`000003ogB@gol0003oCXk/00?oCXk/0ol00003ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool01_ooool003_ooooo00?o0000ooooooooool0J?ooool00ol0
003oooooooooo`02ooooo`Go00000oo7XK400ol0003oa9RZolBHZP08olBHZP03o`000?o2TjGo`Y>U
00Wo`Y>U00?o0000olBHZoo4V:/01oo4V:/00ol0003o`IFYol6EZ@09ol6EZ@03o`000?noT:Go_i2U
00[o_i2U00Co0000ol2G[Oo0Ujgo`9N]1Ol00002okb=Y003o`000?nkSjWo^hnY00[o^hnY00?o0000
okVA[OniTJd02_niTJd00ol0003o/9:hok2B^00;ok2B^0;o00001?nWTKh3o`0000?oXiS900?o0000
oiNIe?nGVM@01?nGVM@00ol0003oQIcRohFLhP05ohFLhP03o`000?mZX?3oJZ3`00Oo000000?oCXk/
o`000?l000000oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo000loooo
o`;o0000J?ooool00ol0003oooooooooo`07ooooo`Go00002Oo4V:X00ol0003o`Y>Uol:CY@08ol:C
Y@03o`000?o4V:_oa9R[00Soa9R[00?o0000ol6EZOo1UJT02Oo1UJT00ol0003o_i2Uokn@Y@09okn@
Y@03o`000?o0Ujgo`9N]00Oo`9N]1?l0000:ok^?Z@03o`000?niTJgo^I6]00_o^I6]00Co0000okRB
/?l0003o00003?n`T[P01?l0003oYi6no`000?l00008oj>Hb@03o`000?nGVMCoUiWD00CoUiWD0_l0
0006ohFLhP03o`000?mZX?3oJZ3`00;oJZ3`0_l000000omIW?;o0000o`000002o`0000?ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`00?_ooool00ol0003oooooooooo`1U
ooooo`03o`000?oooooooooo00cooooo0ol00005olBHZP03o`000?o2TjGo`Y>U00So`Y>U00?o0000
olBHZoo4V:/02?o4V:/00ol0003o`IFYol6EZ@09ol6EZ@03o`000?noT:Go_i2U00Wo_i2U00?o0000
ol2G[Oo0Ujd02Oo0Ujd00ol0003o_YN_okjG[`03o`0000Ko^hnY00?o0000okVA[OniTJd02oniTJd0
0ol0003o^9:`okRB/002okRB/0;o00002on`T[P00ol0003oXiS9oj>Hb@09oj>Hb@;o00001_nGVM@0
0ol0003oQIcRohFLhP04ohFLhP;o00001?mZX?03o`000003oeVLl_l0003ooooo00?ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`05ooooo`00?oooool00ol0003oooooooooo`1Toooo
o`03o`000?oooooooooo00oooooo0ol00002olBHZP03o`000?o2TjGo`Y>U00So`Y>U00?o0000olBH
Zoo4V:/01oo4V:/00ol0003o`IFYol6EZ@0:ol6EZ@03o`000?noT:Go_i2U00Wo_i2U00?o0000ol2G
[Oo0Ujd02?o0Ujd00ol0003o_YN_okjG[`04okjG[`?o00000_nkSjT00ol0003o^I6]okVA[@0;okVA
[@03o`000?nhT[3o^9:`00Go^9:`0_l00005ok2B^0?o00000on]Ul02o`0000[oXiS90_l00005oiNI
e0;o00001_n5W>82o`0000GoJZ3`0ol00003ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool01Oooool0043ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Boooooa;o
00001Oo4V:/00ol0003o`IFYol6EZ@0:ol6EZ@03o`000?noT:Go_i2U00So_i2U00?o0000ol2G[Oo0
Ujd02?o0Ujd00ol0003o_YN_okjG[`08okjG[`?o00003?niTJd00ol0003o^9:`okRB/008okRB/0;o
000000?o/9:ho`000?l000002?n]Ul02o`0000[oXiS900?o0000oiNIe?nGVM@01?nGVM@2o`0000Ko
QIcR00?o0000ofZPl?mZX?001?mZX?02o`0000?ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`05ooooo`00@Oooool2o`0006?ooooo00?o0000ooooooooool09?ooool6o`0000_o`IFY
00?o0000okn@YOnoT:D02?noT:D00ol0003o`9N]ol2G[@09ol2G[@03o`000?nnUjoo_YN_00Wo_YN_
00?o0000okbD[Ol000000_l00008okVA[@03o`000?nhT[3o^9:`00_o^9:`00?o0000ojfG`?n]Ul00
2_n]Ul02o`0000OoXiS96_l00003ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
1Oooool004?ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0Zooooo`?o00002?o1
UJT00ol0003o_i2Uokn@Y@07okn@Y@03o`000?o0Ujgo`9N]00Wo`9N]00?o0000okjG[onnUjl02Onn
Ujl00ol0003o_9B]okbD[@03okbD[@;o00001OniTJd00ol0003o^9:`okRB/00:okRB/004o`000?nf
V;[o]YRjokJH^P;o00002on]Ul02o`0000;oXiS90ol00004oinReP03o`000?nBY^?oTZKS00GoTZKS
00?o0000oh2/lOn0[?401?n0[?43o`0000?oM:cd00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Gooooo0014ooooo`03o`000?oooooooooo05oooooo00?o
0000ooooooooool0;Oooool3o`0000Co`IFY00?o0000okn@YOnoT:D02?noT:D00ol0003o`9N]ol2G
[@08ol2G[@03o`000?nnUjoo_YN_00Wo_YN_00?o0000okbD[OnlU:d01_nlU:d3o`000003okVA[Ol0
003o^9:`00_o^9:`00?o0000okJH^_nfV;X01?nfV;X2o`0000_o[IO00_l00009oinReP?o00001_nB
Y^<2o`0000GoP:ca0_l00002ogB/m005o`000?ooooooooooooooool000003oooool00ol0003ooooo
ooooo`05ooooo`00AOooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo033ooooo0ol0
00000oo1UJWo0000okn@Y@08okn@Y@03o`000?o0Ujgo`9N]00So`9N]00?o0000okjG[onnUjl02_nn
Ujl00ol0003o_9B]okbD[@09okbD[@03o`000?nhT[3o^9:`00[o^9:`00?o0000okJH^_nfV;X01onf
V;X2o`0000Go[IO00ol00003ojZOc0;o00002_nOX]H2o`0000KoTZKS0ol00004oh2/l@?o00001?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo0016ooooo`;o0000G_ooool0
0ol0003oooooooooo`0cooooo`ko00002?o0Ujd00ol0003o_YN_okjG[`09okjG[`03o`000?nlU:go
_9B]00[o_9B]00?o0000okbL^?nlW;P00ol00006okRB/003o`000?nfV;[o]YRj00[o]YRj0_l00000
0on]Ul3o0000o`000009ojZOc0?o00002?nOX]H2o`0000CoTZKS0_l000000onBY^?o0000o`000004
o`000003oh2/lOl0003ooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04
ooooo`00B?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo047ooooo1Ol00002ol2G
[@03o`000?nnUjoo_YN_00[o_YN_00?o0000okbD[OnlU:d02OnlU:d00ol0003o_9bhokbL^004okbL
^0?o00000_nhT[000ol0003o]YRjokJH^P0=okJH^P03o`000?nZWlcoZYo<00coZYo<0ol00004oinR
eP03o`000?nOX]KoWj;F00Co00001On?]O03o`0000;oQkKd00?o0000ooooooooool00oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo0019ooooo`03o`000?oooooooooo05[o
oooo00?o0000ooooooooool0A_ooool4o`0000[o_YN_00?o0000okbD[OnlU:d02OnlU:d00ol0003o
_9bhokbL^008okbL^0;o00003_nfV;X00ol0003o/j35ok>Pa@02ok>Pa@?o00003?nZWl`4o`0000Go
W:kT0_l00008ohnel0;o000000?oQkKdo`000?ooool00oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Cooooo001:ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0
B_ooool4o`0000Go_YN_00?o0000okbD[OnlU:d02OnlU:d00ol0003o_9bhokbL^008okbL^003o`00
0?njXKoo^Z6o00;o^Z6o1?l00006okJH^P;o00002?ncX<D3o`0000?oZYo<1?l00004ojJZf@;o0000
2?nL[^@2o`0000OoSkG`0ol00004ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1?ooool004_ooooo0_l0001Iooooo`03o`000?oooooooooo04kooooo0ol00002okjG[`03o`000?nl
U:go_9B]00So_9B]00?o0000okbL^?nlW;P02?nlW;P00ol0003o^Z6ookZQ_`07okZQ_`?o00000_nf
V;X00ol0003o/j35ok>Pa@0;ok>Pa@?o00002onVZ]T2o`0000OoW:kT0ol00004ohnel004o`000?n?
]O3oSkG`o`0000Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`00COoo
ool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo05;ooooo1ol00005okbD[@03o`000?nl
W;So_9bh00So_9bh00?o0000okZQ_onjXKl02onjXKl2o`0000go/j3500Co0000ok6VcOnaY/go/JK=
0ol0000:ojJZf@?o00001?nL[^@00ol0003oW:kToib^i004o`0000CoTkcc00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo001>ooooo`03o`000?oo
oooooooo05Cooooo00?o0000ooooooooool0FOooool5o`000003okbL^?l0003o000000;o00001Onl
W;P00ol0003o^Z6ookZQ_`0;okZQ_`03o`000?nhXL7o^:7100;o^:710ol00006ok>Pa@;o00001ona
Y/d3o`0000[oYZ[I1?l00007oiVkk`Ko00000oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00?ooooo001?ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0Hoooool5
o`0000co^Z6o0_l00008okRQ`@?o00000_ncX<D00ol0003o/JK=ok6Vc@0:ok6Vc@?o00000_nVZ]T3
o`0000GoXkGU0ol0000:oiVkk`;o00000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00?ooooo001@ooooo`;o0000Doooool00ol0003oooooooooo`1Zooooo`?o00001_njXKl00ol0
003o^:71okRQ`@0;okRQ`@;o00004?naY/d2o`0000_oXkGU0ol00003oiVkk`?o00000_nL`?400ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool005;o
oooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1]ooooo`?o00000_njXKl00ol0003o
^:71okRQ`@09okRQ`@?o00001One[M45o`0000?o/JK=0ol00005ojbaf`Go00002?nS]ND4o`0000Go
W<3a00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00?ooooo001Cooooo`03
o`000?oooooooooo04oooooo00?o0000ooooooooool0L?ooool2o`0000?o^:710_l00005okRQ`@;o
00003One[M43o`0000go[;7K1Ol00007oj6nkPKo00001?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00?ooooo001Dooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
Moooool5o`0000co]JgA0ol00004ok2dg0Go00000on//M/3o`0000KoYk_X1Ol00007oj6nkP;o0000
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo001Eooooo`;o0000C_oo
ool00ol0003oooooooooo`1oooooo`Go00000_ne[M42o`0000co/;CL0ol0000>ojNkj0Go00001?nP
`_000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool005Oooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`24ooooo`;o00003?n`]=`2
o`0000Go[KSQ1Ol00003ojNkj0?o00001_nV_n`6o`0000?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`00F?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo
08Wooooo1Ol00002ok2dg0;o00003?n]^>43o`0000koY[o/0_l00003ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool005Wooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`2>ooooo`;o00002_n]^>43o`0000KoYl3/1Ol00003ojJok0?o00000_nS`o000ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool005[ooooo
0_l00019ooooo`03o`000?oooooooooo09Gooooo1Ol0000>ojO0k0Go00001?nS`o000ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool005cooooo00?o
0000ooooooooool0A_ooool00ol0003oooooooooo`2Looooo`Go00000onW`>`3o`0000KoYL;^1_l0
0003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool005gooooo00?o0000
ooooooooool0AOooool00ol0003oooooooooo`2Qooooo`?o00003_nU`^h2o`0000?ooooo00Go0000
ooooooooooooooooo`000004ooooo`00G_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooo
oooo0:Sooooo2?l00003ojG4k`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?oo
ool005oooooo0_l00014ooooo`03o`000?oooooooooo0:oooooo1_l00004ooooo`03o`000?oooooo
000000Cooooo001Qooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0]?ooool2o`00
00?ooooo00Co0000oooooooooooo00000oooool006;ooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`2jooooo`03o`000?oooooo000000?ooooo001Sooooo`;o0000@?ooool00ol0003o
ooooooooo`2kooooo`;o00000oooool006Gooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`2jooooo`?o00000oooool006Kooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`2fooooo`Co00001_ooool006Oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2b
ooooo`Co00002_ooool006Sooooo0_l0000kooooo`03o`000?oooooooooo0:kooooo1?l0000>oooo
o`00J_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo0:_ooooo0ol0000Booooo`00
Joooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo0:Oooooo1?l0000Eooooo`00K?oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo0:?ooooo1?l0000Iooooo`00KOooool2
o`0003Kooooo00?o0000ooooooooool0Woooool4o`0001gooooo001_ooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0Voooool4o`00027ooooo001`ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool0V?ooool4o`0002Gooooo001aooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0U?ooool4o`0002Wooooo001booooo`;o0000<?ooool00ol0003ooooooooo
o`2Aooooo`?o0000;Oooool007Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2=
ooooo`Co0000<?ooool007Gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`29oooo
o`Co0000=?ooool007Kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`25ooooo`Co
0000>?ooool007Oooooo0_l0000[ooooo`03o`000?oooooooooo087ooooo1?l0000looooo`00NOoo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07gooooo1?l00010ooooo`00N_ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07Wooooo1?l00014ooooo`00Noooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo07Kooooo0ol00018ooooo`00O?ooool2o`0002Ko
oooo00?o0000ooooooooool0L_ooool4o`0004_ooooo001nooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0K_ooool4o`0004oooooo001oooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0J_ooool4o`0005?ooooo0020ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0I_ooool4o`0005Oooooo0021ooooo`;o00008Oooool00ol0003oooooooooo`1Roooo
o`Co0000Foooool008?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Nooooo`Co
0000Goooool008Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Kooooo`?o0000
Hoooool008Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Gooooo`Co0000I_oo
ool008Kooooo0_l0000Looooo`03o`000?oooooooooo05?ooooo1?l0001Zooooo`00R?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo04oooooo1?l0001^ooooo`00ROooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo04_ooooo1?l0001booooo`00R_ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo04Oooooo1?l0001fooooo`00Roooool2o`0001Oooooo00?o
0000ooooooooool0@oooool4o`0007[ooooo002=ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0@?ooool3o`0007kooooo002>ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0??ooool4o`00087ooooo002?ooooo`;o00004oooool00ol0003oooooooooo`0hooooo`Co
0000QOooool0097ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0dooooo`Co0000
ROooool009;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0`ooooo`Co0000SOoo
ool009?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0]ooooo`Co0000TOooool0
09Cooooo0_l0000=ooooo`03o`000?oooooooooo02Wooooo1?l0002Eooooo`00U_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo02Kooooo0ol0002Iooooo`00Uoooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo02;ooooo1?l0002Looooo`00V?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo01kooooo1?l0002Pooooo`00VOooool2o`0000Sooooo00?o0000
ooooooooool06_ooool4o`000:Cooooo002Kooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool05_ooool4o`000:Sooooo002Looooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool04_ooool4o`000:cooooo002Mooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
3_ooool4o`000;3ooooo002Nooooo`;o00000oooool00ol0003oooooooooo`0;ooooo`?o0000]?oo
ool00:3ooooo00Co0000oooooooooooo00002Oooool4o`000;Oooooo002Qooooo`03o`000?oooooo
000000Gooooo1?l0002kooooo`00X_ooool2o`000003ooooool0003o000000;o0000_oooool00:?o
oooo0_l00033ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00Koooool01OlQ8B7o0000o`000?m4A4CogMgM07Wooooo00Go8B4Qo`000?l0
003oA4A4omgMg@1fooooo`00L_ooool00omgMgOo<S8booooo`1kooooo`03ogMgMolb<S;ooooo07Go
oooo001cooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0M?ooool004Oooooo00Oo
V9RHo`000?l0003oA4A4okZj^_oooooo410@00Go00001?ooool5o`0000;ooooo00KoV9RHo`000?l0
003oMgMgoa0@4?l00002ooooo`04oa0@4?l0003o0000ooooo`;o000000So410@ooooooo^k^koEEEE
o`000?l@413oc<c<o`0000?ooooo00OoV9RHo`000?l0003oMgMgo`000?l@413ooooo00Go00000ooo
ool02?nHV9So0000o`000?mgMgOo410@o`000?oooooo410@1Ol00005ooooo`06onk^k_mEEEGo0000
o`000?nHV9So00000_l@4105o`0000Cooooo00KoV9RHo`000?l0003oMgMgo`000?l@4102o`0000;o
oooo00Co0000oooooooooooo00000_l@4102o`000007ooooool0003o0000oa0@4?ooooook^k^oeEE
E@02o`000005odA4A?nj^[[ooooooooooonHV9P00_l000000omgMgOo410@o`000002ooooo`07onk^
k_mEEEGo0000o`000?nHV9So0000oa0@4005ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0ooo
ool5o`0000;ooooo00Kok^k^oeEEEOl0003o410@olc<c?l00002ooooo`06onk^k_mEEEGo0000o`00
0?m4A4Co^[Zj0_ooool01?l@413o0000o`000?ooool2o`000003oa0@4?l0003o000000;ooooo00Oo
0000oooooooooooo0000oa0@4?o^k^koEEEE00;o000000KoEEEEonk^k_ooooooooooonk^k_mEEED2
o`000006oiRHV?l0003o410@ooooooo^k^koEEEE0_l000001_m4A4Co^[Zjoooooooooooo410@oc8b
<P;o000000?o410@ojVYZOooool00oooool01onHV9So0000o`000?mEEEGok^k^ofIVI_l000002Ooo
ool4o`000003oa0@4?oooooooooo02?ooooo0017ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Go0000olc<c?o^k^koQhN7
o`000004ooooo`05o`000?ooooooooooooooool000000_ooool01_mEEEGoMgMgooooooo^k^koEEEE
o`0000?ooooo00Go0000ojVYZOooooooQhN7o`000004ooooo`03o`000?oooooooooo00?ooooo00Go
0000olc<c?o^k^koQhN7o`000004ooooo`03o`000?oooooooooo00Kooooo00KoEEEEogMgMooooooo
k^k^oeEEEOl00003ooooo`03o`000?oooooooooo00Gooooo00Go0000ojVYZOooooooQhN7o`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool02Ol0003ooooo
oooooomEEEGoMgMgooooooo^k^koMgMgoa0@4002ooooo`05o`000?o<c<cok^k^ohN7Qol000000ooo
ool01_mEEEGoMgMgooooooo^k^koEEEEo`0000Kooooo00KoEEEEogMgMoooooook^k^ogMgMol@4105
ooooo`03o`000?oooooooooo00;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00002ooooo`06oeEE
EOmgMgOoooooonk^k_mgMgOo410@0oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003ooooooeEEEOmgMgL2ooooo`0:ogMgMomEEEGooooooooooomE
EEGoMgMgooooooo^k^koEEEEo`0000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06
o`000?nYZJWooooooooooonj^[[o00001?ooool01_l0003oZJVYoooooon7QhOo<S8bofIVIP;ooooo
1_l00004ooooo`03o`000?oooooooooo02Gooooo0017ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`05oa0@4?n7QhOoooooonk^k_l00000
1?ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000ooooooooooooooooonk^k_l00003
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`05oa0@4?n7
QhOoooooonk^k_l000001?ooool00ol0003oooooooooo`06ooooo`06o`000?ooooooooooooooooo^
k^ko00000oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo
00001oooool01Ol@413oQhN7ooooooo^k^ko000000?ooooo00Ko0000ooooooooooooooooonk^k_l0
0006ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01_l0003ooooooooo
ooooooook^k^o`0000;ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000004ooooo`04o`000?oooooo
ooooo`0000?ooooo00Gok^k^o`000?ooooooooooo`000008ooooo`05okZj^_n7QhOoIVIVofIVI_l@
41001?ooool01_l0003oooooooooooooooooQhN7odA4A0cooooo00?o0000ooooooooool09Oooool0
04Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00;ooooo00?o^[Zjoa0@4?l000000_l00004ooooo`05o`000?ooooooooooooooool000000_ooool0
1_l0003oooooooooooooooook^k^o`0000?ooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo00?ooooo00?o^[Zjoa0@4?l000000_l00004ooooo`03o`000?oooooooooo00Ko
oooo00Ko0000ooooooooooooooooonk^k_l00003ooooo`03o`000?oooooooooo00Gooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`06o`0000;ooooo00?o^[Zjoa0@4?l000000_l00003ooooo`06
o`000?ooooooooooooooooo^k^ko00001_ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1_l0003oooooooooooooooook^k^o`0000;ooooo1_l00003ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000Cooooo00Co0000oooo
oooooooo00000oooool01?o^k^ko0000ooooooooool6o`0000;ooooo00Ko<S8bob4Q8OmgMgOoMgMg
ohN7Qoo^k^h4ooooo`06ob4Q8Oo<c<cooooooooooonHV9So<S8b0_ooool6o`0000Cooooo00?o0000
ooooooooool09Oooool004Oooooo00?o0000ooooooooool01Oooool00ol0003o<S8bomgMg@07oooo
o`03o`000?oooooooooo00Gooooo00?oc<c<o`000?ooool00oooool01Ol0003oQhN7oooooonYZJWo
000000;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00003ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`06ooooo`03olc<c?l0003ooooo00?ooooo00?o0000oc8b<_oM
gMd01_ooool01_mVIVKoMgMgooooooo^k^koEEEEo`0000?ooooo00?o0000oc8b<_oMgMd01Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Oo0000olc<c?o<c<co0000ojVYZOoMgMgo8B4Q00;o
oooo00Go0000ogMgMoooooooZJVYo`000002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b1Ooo
ool00oo<c<co0000ooooo`02ooooo`06ofIVI_mgMgOoooooonk^k_mEEEGo00001_ooool01_mEEEGo
QhN7onk^k_ooooooQhN7oc8b<PGooooo00?o0000ooooooooool00_ooool01_mEEEGoMgMgooooooo^
k^koEEEEo`0000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`05o`000?n7QhOooooo
ojVYZOl000000_ooool02_l0003oc<c<olc<c?l0003oZJVYomgMgOlQ8B7ooooooeEEEOmgMgL2oooo
o`0:ogMgMomEEEGooooooooooomVIVKoMgMgooooooo^k^koEEEEo`0000;ooooo00KoEEEEohN7Qoo^
k^koooooohN7Qolb<S82ooooo`06o`000?nj^[[oooooonk^k_mgMgOo00001?ooool01onYZJWo8B4Q
omgMgOo^k^ko<S8boeEEEOnj^[X02oooool00ol0003oooooooooo`0Uooooo`00AOooool00ol@413o
0000o`000003o`0000?ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B43ooooo`03oa0@4?l0003o0000
00Gooooo00Co<S8bo`000?l0003oV9RH0oooool00ol@413o0000ogMgM`02o`00000=oiRHV?oooooo
ooooonk^k_mEEEGo0000ob4Q8OnYZJWo0000oa0@4?oooooo410@o`000002ooooo`;o00001?ooool0
0ol0003oooooooooo`04ooooo`04oc8b<_l0003o0000oiRHV0?ooooo0_l000001?nYZJWo8B4Qo`00
0?lQ8B44ooooo`06onk^k_mEEEGo0000oa0@4?o<c<co00000_ooool2o`000004ojVYZOlQ8B7o0000
ob4Q8@;ooooo00Co410@o`000?oooooooooo0_l000002Ooooooo410@o`000?lQ8B7o0000ogMgMol@
413o0000ojVYZ@02ooooo`05o`000?mgMgOo0000o`000?nHV9P00_ooool01_o^k^koEEEEo`000?l0
003oA4A4onk^kP?ooooo00Co<S8bo`000?l0003oV9RH0oooool01_o^k^koEEEEo`000?l@413oc<c<
o`0000Kooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h3ooooo`03oa0@4?l0003o000000Cooooo
00[ok^k^oeEEEOl0003o8B4QojVYZOl0003o410@ooooooo^k^koEEEE0_l000001om4A4Cok^k^oooo
oooooooo410@o`000?mgMgL00_l000003OnHV9Sooooooa0@4?l0003o8B4Qo`000?mgMgOo410@o`00
0?nYZJWoooooonk^k_mEEED00_l000002_mEEEGok^k^ooooooooooook^k^oeEEEOl0003o410@olc<
c?l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_nYZJWo8B4Qo`000?l0003o
<S8bo`0000Gooooo00KoV9RHo`000?l0003oV9RHokZj^_lb<S8;ooooo`03o`000?oooooooooo02Go
oooo0017ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0@Oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo02Gooooo0017ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool08_ooool00omEEEGoIVIVo`00000Wooooo`00FOooool00ol@413oooooooooo`0R
ooooo`03oa0@4?l0003o000001_ooooo0_l0000Jooooo`03oa0@4?l0003ooooo01Wooooo0_l0000A
ooooo`03oa0@4?oooooooooo02kooooo0_l0001>ooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.107559, 0.00346706, \
0.00371147, 0.00371147}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.66533e-16 1.05023 -0.0446497 1.05023 [
[.5 .87208 -104 0 ]
[.5 .87208 104 12 ]
[.05011 .23931 -6 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -16.6517 -9 ]
[.33812 .12455 1.34831 0 ]
[.495 .06208 -21.0373 -9 ]
[.495 .06208 2.96266 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.2956 .07454 -9.25094 -12 ]
[.2956 .07454 .74906 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 6 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 18 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 24 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.91306 .21061 0 -8.07062 ]
[.91306 .21061 10 3.92938 ]
[.02581 .30904 -24 -2.75818 ]
[.02581 .30904 0 6.24182 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[-0.00308 .49011 -18 -2.91351 ]
[-0.00308 .49011 0 6.08649 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .87208 -165 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(triangular) show
129.000 13.000 moveto
(drumhead) show
183.000 13.000 moveto
(eigenmodes) show
249.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
255.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
261.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
267.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(0)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(0.25)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0.5)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.75)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
gsave
.2956 .07454 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(0)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(0.25)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0.5)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.75)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
gsave
.91306 .21061 -61 -12.0706 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.03805 .30431 m
.04417 .30194 L
s
[(-0.1)] .02581 .30904 1 -0.38707 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.0093 .48575 m
.01549 .48356 L
s
[(0.1)] -0.00308 .49011 1 -0.35255 Mshowa
.125 Mabswid
.03532 .32153 m
.039 .32012 L
s
.03256 .33896 m
.03624 .33756 L
s
.02977 .35658 m
.03345 .35519 L
s
.02694 .3744 m
.03063 .37302 L
s
.0212 .41066 m
.0249 .4093 L
s
.01828 .4291 m
.02198 .42776 L
s
.01532 .44776 m
.01902 .44643 L
s
.01233 .46664 m
.01604 .46532 L
s
.04075 .28727 m
.04442 .28584 L
s
.04342 .27042 m
.04709 .26898 L
s
.00624 .50508 m
.00995 .50378 L
s
.00314 .52464 m
.00686 .52335 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.93078 .5519 m .95177 .54574 L .95949 .55679 L closepath p .659 .753 .919 r
F P
0 g
s
.95177 .54574 m .93078 .5519 L .90184 .5466 L p .662 .742 .909 r
F P
0 g
s
.90184 .5466 m .92278 .54027 L .95177 .54574 L p .662 .742 .909 r
F P
0 g
s
.92278 .54027 m .90184 .5466 L .87275 .5414 L p .672 .729 .892 r
F P
0 g
s
.92278 .54027 m .94395 .53453 L .95177 .54574 L closepath p .649 .748 .922 r
F P
0 g
s
.87275 .5414 m .89359 .53444 L .92278 .54027 L p .672 .729 .892 r
F P
0 g
s
.89359 .53444 m .87275 .5414 L .84348 .53616 L p .695 .682 .833 r
F P
0 g
s
.94395 .53453 m .92278 .54027 L .89359 .53444 L p .663 .723 .894 r
F P
0 g
s
.84348 .53616 m .86405 .52692 L .89359 .53444 L p .695 .682 .833 r
F P
0 g
s
.86405 .52692 m .84348 .53616 L .81393 .52968 L p .704 .666 .81 r
F P
0 g
s
.89359 .53444 m .91463 .52799 L .94395 .53453 L p .663 .723 .894 r
F P
0 g
s
.91463 .52799 m .89359 .53444 L .86405 .52692 L p .666 .699 .871 r
F P
0 g
s
.91463 .52799 m .93603 .52318 L .94395 .53453 L closepath p .628 .739 .927 r
F P
0 g
s
.81393 .52968 m .83434 .51897 L .86405 .52692 L p .704 .666 .81 r
F P
0 g
s
.83434 .51897 m .81393 .52968 L .78434 .52476 L p .72 .636 .764 r
F P
0 g
s
.86405 .52692 m .885 .52012 L .91463 .52799 L p .666 .699 .871 r
F P
0 g
s
.885 .52012 m .86405 .52692 L .83434 .51897 L p .685 .645 .804 r
F P
0 g
s
.93603 .52318 m .91463 .52799 L .885 .52012 L p .633 .715 .906 r
F P
0 g
s
.83434 .51897 m .85498 .50953 L .885 .52012 L p .685 .645 .804 r
F P
0 g
s
.85498 .50953 m .83434 .51897 L .80444 .51031 L p .701 .606 .748 r
F P
0 g
s
.78434 .52476 m .80444 .51031 L .83434 .51897 L p .72 .636 .764 r
F P
0 g
s
.80444 .51031 m .78434 .52476 L .75455 .51953 L p .727 .6 .715 r
F P
0 g
s
.885 .52012 m .90633 .5152 L .93603 .52318 L p .633 .715 .906 r
F P
0 g
s
.90633 .5152 m .885 .52012 L .85498 .50953 L p .642 .664 .856 r
F P
0 g
s
.80444 .51031 m .82466 .49672 L .85498 .50953 L p .701 .606 .748 r
F P
0 g
s
.82466 .49672 m .80444 .51031 L .77427 .49968 L p .708 .591 .722 r
F P
0 g
s
.75455 .51953 m .77427 .49968 L .80444 .51031 L p .727 .6 .715 r
F P
0 g
s
.85498 .50953 m .87616 .50409 L .90633 .5152 L p .642 .664 .856 r
F P
0 g
s
.87616 .50409 m .85498 .50953 L .82466 .49672 L p .656 .615 .796 r
F P
0 g
s
.90633 .5152 m .928 .51167 L .93603 .52318 L closepath p .599 .726 .934 r
F P
0 g
s
.82466 .49672 m .84556 .48943 L .87616 .50409 L p .656 .615 .796 r
F P
0 g
s
.84556 .48943 m .82466 .49672 L .79423 .48305 L p .674 .582 .744 r
F P
0 g
s
.77427 .49968 m .79423 .48305 L .82466 .49672 L p .708 .591 .722 r
F P
0 g
s
.79423 .48305 m .77427 .49968 L .74416 .49127 L p .72 .575 .691 r
F P
0 g
s
.77427 .49968 m .75455 .51953 L .72441 .51154 L p .737 .613 .721 r
F P
0 g
s
.72441 .51154 m .74416 .49127 L .77427 .49968 L p .737 .613 .721 r
F P
0 g
s
.79423 .48305 m .81471 .47204 L .84556 .48943 L p .674 .582 .744 r
F P
0 g
s
.81471 .47204 m .79423 .48305 L .76373 .4689 L p .689 .565 .71 r
F P
0 g
s
.74416 .49127 m .76373 .4689 L .79423 .48305 L p .72 .575 .691 r
F P
0 g
s
.76373 .4689 m .78379 .45339 L .81471 .47204 L p .689 .565 .71 r
F P
0 g
s
.78379 .45339 m .76373 .4689 L .73325 .45543 L p .704 .562 .692 r
F P
0 g
s
.76373 .4689 m .74416 .49127 L .71396 .48352 L p .731 .568 .67 r
F P
0 g
s
.71396 .48352 m .73325 .45543 L .76373 .4689 L p .731 .568 .67 r
F P
0 g
s
.80451 .44502 m .78379 .45339 L .753 .43562 L p .67 .55 .71 r
F P
0 g
s
.753 .43562 m .77325 .42259 L .80451 .44502 L p .67 .55 .71 r
F P
0 g
s
.73325 .45543 m .753 .43562 L .78379 .45339 L p .704 .562 .692 r
F P
0 g
s
.77325 .42259 m .753 .43562 L .72243 .42081 L p .694 .554 .691 r
F P
0 g
s
.753 .43562 m .73325 .45543 L .70295 .44578 L p .723 .567 .678 r
F P
0 g
s
.70295 .44578 m .72243 .42081 L .753 .43562 L p .723 .567 .678 r
F P
0 g
s
.79418 .41668 m .77325 .42259 L .74227 .40246 L p .654 .538 .71 r
F P
0 g
s
.74227 .40246 m .76267 .39148 L .79418 .41668 L p .654 .538 .71 r
F P
0 g
s
.72243 .42081 m .74227 .40246 L .77325 .42259 L p .694 .554 .691 r
F P
0 g
s
.76267 .39148 m .74227 .40246 L .71169 .38753 L p .687 .552 .696 r
F P
0 g
s
.74227 .40246 m .72243 .42081 L .6921 .41081 L p .72 .57 .684 r
F P
0 g
s
.6921 .41081 m .71169 .38753 L .74227 .40246 L p .72 .57 .684 r
F P
0 g
s
.72243 .42081 m .70295 .44578 L .67271 .4398 L p .743 .581 .674 r
F P
0 g
s
.67271 .4398 m .6921 .41081 L .72243 .42081 L p .743 .581 .674 r
F P
0 g
s
.71169 .38753 m .73164 .37069 L .76267 .39148 L p .687 .552 .696 r
F P
0 g
s
.73164 .37069 m .71169 .38753 L .68146 .37985 L p .724 .58 .693 r
F P
0 g
s
.71169 .38753 m .6921 .41081 L .66195 .40716 L p .75 .596 .686 r
F P
0 g
s
.66195 .40716 m .68146 .37985 L .71169 .38753 L p .75 .596 .686 r
F P
0 g
s
.73325 .45543 m .71396 .48352 L .68359 .47511 L p .744 .582 .674 r
F P
0 g
s
.68359 .47511 m .70295 .44578 L .73325 .45543 L p .744 .582 .674 r
F P
0 g
s
.7838 .38823 m .76267 .39148 L .73164 .37069 L p .64 .532 .716 r
F P
0 g
s
.73164 .37069 m .75217 .36169 L .7838 .38823 L p .64 .532 .716 r
F P
0 g
s
.75217 .36169 m .73164 .37069 L .70113 .35743 L p .685 .559 .706 r
F P
0 g
s
.68146 .37985 m .70113 .35743 L .73164 .37069 L p .724 .58 .693 r
F P
0 g
s
.83587 .46706 m .81471 .47204 L .78379 .45339 L p .647 .558 .74 r
F P
0 g
s
.78379 .45339 m .80451 .44502 L .83587 .46706 L p .647 .558 .74 r
F P
0 g
s
.928 .51167 m .90633 .5152 L .87616 .50409 L p .588 .693 .915 r
F P
0 g
s
.74416 .49127 m .72441 .51154 L .69433 .50746 L p .745 .605 .703 r
F P
0 g
s
.69433 .50746 m .71396 .48352 L .74416 .49127 L p .745 .605 .703 r
F P
0 g
s
.70113 .35743 m .72118 .34191 L .75217 .36169 L p .685 .559 .706 r
F P
0 g
s
.72118 .34191 m .70113 .35743 L .67103 .35373 L p .735 .601 .708 r
F P
0 g
s
.70113 .35743 m .68146 .37985 L .65142 .38059 L p .766 .621 .7 r
F P
0 g
s
.65142 .38059 m .67103 .35373 L .70113 .35743 L p .766 .621 .7 r
F P
0 g
s
.82596 .44291 m .80451 .44502 L .77325 .42259 L p .622 .536 .736 r
F P
0 g
s
.77325 .42259 m .79418 .41668 L .82596 .44291 L p .622 .536 .736 r
F P
0 g
s
.86706 .48639 m .84556 .48943 L .81471 .47204 L p .625 .582 .786 r
F P
0 g
s
.81471 .47204 m .83587 .46706 L .86706 .48639 L p .625 .582 .786 r
F P
0 g
s
.6921 .41081 m .67271 .4398 L .64241 .43718 L p .766 .61 .685 r
F P
0 g
s
.64241 .43718 m .66195 .40716 L .6921 .41081 L p .766 .61 .685 r
F P
0 g
s
.87616 .50409 m .89781 .50134 L .928 .51167 L p .588 .693 .915 r
F P
0 g
s
.89781 .50134 m .87616 .50409 L .84556 .48943 L p .603 .63 .85 r
F P
0 g
s
.77349 .36093 m .75217 .36169 L .72118 .34191 L p .629 .534 .728 r
F P
0 g
s
.72118 .34191 m .74184 .33461 L .77349 .36093 L p .629 .534 .728 r
F P
0 g
s
.74184 .33461 m .72118 .34191 L .6908 .33203 L p .689 .576 .723 r
F P
0 g
s
.67103 .35373 m .6908 .33203 L .72118 .34191 L p .735 .601 .708 r
F P
0 g
s
.70295 .44578 m .68359 .47511 L .65329 .47164 L p .758 .593 .673 r
F P
0 g
s
.65329 .47164 m .67271 .4398 L .70295 .44578 L p .758 .593 .673 r
F P
0 g
s
.84556 .48943 m .86706 .48639 L .89781 .50134 L p .603 .63 .85 r
F P
0 g
s
.81591 .41779 m .79418 .41668 L .76267 .39148 L p .596 .518 .738 r
F P
0 g
s
.76267 .39148 m .7838 .38823 L .81591 .41779 L p .596 .518 .738 r
F P
0 g
s
.68146 .37985 m .66195 .40716 L .63179 .41028 L p .785 .638 .698 r
F P
0 g
s
.63179 .41028 m .65142 .38059 L .68146 .37985 L p .785 .638 .698 r
F P
0 g
s
.71396 .48352 m .69433 .50746 L .66405 .50347 L p .747 .59 .681 r
F P
0 g
s
.66405 .50347 m .68359 .47511 L .71396 .48352 L p .747 .59 .681 r
F P
0 g
s
.80581 .39258 m .7838 .38823 L .75217 .36169 L p .57 .505 .744 r
F P
0 g
s
.75217 .36169 m .77349 .36093 L .80581 .39258 L p .57 .505 .744 r
F P
0 g
s
.85772 .46703 m .83587 .46706 L .80451 .44502 L p .589 .55 .779 r
F P
0 g
s
.80451 .44502 m .82596 .44291 L .85772 .46703 L p .589 .55 .779 r
F P
0 g
s
.6908 .33203 m .71096 .31747 L .74184 .33461 L p .689 .576 .723 r
F P
0 g
s
.71096 .31747 m .6908 .33203 L .66083 .33395 L p .756 .638 .73 r
F P
0 g
s
.6908 .33203 m .67103 .35373 L .6411 .36061 L p .793 .664 .721 r
F P
0 g
s
.6411 .36061 m .66083 .33395 L .6908 .33203 L p .793 .664 .721 r
F P
0 g
s
.67103 .35373 m .65142 .38059 L .62134 .39019 L p .817 .686 .719 r
F P
0 g
s
.62134 .39019 m .6411 .36061 L .67103 .35373 L p .817 .686 .719 r
F P
0 g
s
.67271 .4398 m .65329 .47164 L .62279 .46932 L p .77 .609 .679 r
F P
0 g
s
.62279 .46932 m .64241 .43718 L .67271 .4398 L p .77 .609 .679 r
F P
0 g
s
.76332 .33594 m .74184 .33461 L .71096 .31747 L p .621 .544 .746 r
F P
0 g
s
.71096 .31747 m .73174 .31138 L .76332 .33594 L p .621 .544 .746 r
F P
0 g
s
.73174 .31138 m .71096 .31747 L .68073 .31257 L p .702 .607 .748 r
F P
0 g
s
.66083 .33395 m .68073 .31257 L .71096 .31747 L p .756 .638 .73 r
F P
0 g
s
.89781 .50134 m .91985 .50001 L .928 .51167 L closepath p .544 .7 .941 r
F P
0 g
s
.84818 .44643 m .82596 .44291 L .79418 .41668 L p .549 .52 .776 r
F P
0 g
s
.79418 .41668 m .81591 .41779 L .84818 .44643 L p .549 .52 .776 r
F P
0 g
s
.66195 .40716 m .64241 .43718 L .61202 .44013 L p .796 .653 .705 r
F P
0 g
s
.61202 .44013 m .63179 .41028 L .66195 .40716 L p .796 .653 .705 r
F P
0 g
s
.68359 .47511 m .66405 .50347 L .63342 .49527 L p .763 .635 .72 r
F P
0 g
s
.63342 .49527 m .65329 .47164 L .68359 .47511 L p .763 .635 .72 r
F P
0 g
s
.79574 .36829 m .77349 .36093 L .74184 .33461 L p .544 .498 .755 r
F P
0 g
s
.74184 .33461 m .76332 .33594 L .79574 .36829 L p .544 .498 .755 r
F P
0 g
s
.8891 .48639 m .86706 .48639 L .83587 .46706 L p .555 .59 .844 r
F P
0 g
s
.83587 .46706 m .85772 .46703 L .8891 .48639 L p .555 .59 .844 r
F P
0 g
s
.91985 .50001 m .89781 .50134 L .86706 .48639 L p .527 .656 .917 r
F P
0 g
s
.86706 .48639 m .8891 .48639 L .91985 .50001 L p .527 .656 .917 r
F P
0 g
s
.83852 .42512 m .81591 .41779 L .7838 .38823 L p .505 .492 .775 r
F P
0 g
s
.7838 .38823 m .80581 .39258 L .83852 .42512 L p .505 .492 .775 r
F P
0 g
s
.65142 .38059 m .63179 .41028 L .60144 .41979 L p .832 .709 .729 r
F P
0 g
s
.60144 .41979 m .62134 .39019 L .65142 .38059 L p .832 .709 .729 r
F P
0 g
s
.68073 .31257 m .701 .29845 L .73174 .31138 L p .702 .607 .748 r
F P
0 g
s
.701 .29845 m .68073 .31257 L .65083 .32102 L p .788 .694 .76 r
F P
0 g
s
.68073 .31257 m .66083 .33395 L .63093 .34783 L p .832 .726 .747 r
F P
0 g
s
.63093 .34783 m .65083 .32102 L .68073 .31257 L p .832 .726 .747 r
F P
0 g
s
.8802 .47055 m .85772 .46703 L .82596 .44291 L p .494 .546 .838 r
F P
0 g
s
.82596 .44291 m .84818 .44643 L .8802 .47055 L p .494 .546 .838 r
F P
0 g
s
.78578 .34578 m .76332 .33594 L .73174 .31138 L p .519 .497 .772 r
F P
0 g
s
.73174 .31138 m .75334 .3142 L .78578 .34578 L p .519 .497 .772 r
F P
0 g
s
.75334 .3142 m .73174 .31138 L .701 .29845 L p .62 .567 .773 r
F P
0 g
s
.64241 .43718 m .62279 .46932 L .59205 .46732 L p .795 .666 .721 r
F P
0 g
s
.59205 .46732 m .61202 .44013 L .64241 .43718 L p .795 .666 .721 r
F P
0 g
s
.82878 .40373 m .80581 .39258 L .77349 .36093 L p .458 .465 .778 r
F P
0 g
s
.77349 .36093 m .79574 .36829 L .82878 .40373 L p .458 .465 .778 r
F P
0 g
s
.65329 .47164 m .63342 .49527 L .60277 .49196 L p .767 .65 .732 r
F P
0 g
s
.60277 .49196 m .62279 .46932 L .65329 .47164 L p .767 .65 .732 r
F P
0 g
s
.66083 .33395 m .6411 .36061 L .611 .37757 L p .861 .755 .744 r
F P
0 g
s
.611 .37757 m .63093 .34783 L .66083 .33395 L p .861 .755 .744 r
F P
0 g
s
.701 .29845 m .72188 .29295 L .75334 .3142 L p .62 .567 .773 r
F P
0 g
s
.72188 .29295 m .701 .29845 L .67087 .2995 L p .724 .656 .782 r
F P
0 g
s
.65083 .32102 m .67087 .2995 L .701 .29845 L p .788 .694 .76 r
F P
0 g
s
.63179 .41028 m .61202 .44013 L .58135 .44728 L p .833 .725 .746 r
F P
0 g
s
.58135 .44728 m .60144 .41979 L .63179 .41028 L p .833 .725 .746 r
F P
0 g
s
.9116 .48819 m .8891 .48639 L .85772 .46703 L p .439 .603 .915 r
F P
0 g
s
.85772 .46703 m .8802 .47055 L .9116 .48819 L p .439 .603 .915 r
F P
0 g
s
.87114 .454 m .84818 .44643 L .81591 .41779 L p .424 .498 .831 r
F P
0 g
s
.81591 .41779 m .83852 .42512 L .87114 .454 L p .424 .498 .831 r
F P
0 g
s
.8891 .48639 m .9116 .48819 L .91985 .50001 L closepath p .458 .654 .944 r
F P
0 g
s
.81903 .38291 m .79574 .36829 L .76332 .33594 L p .407 .442 .784 r
F P
0 g
s
.76332 .33594 m .78578 .34578 L .81903 .38291 L p .407 .442 .784 r
F P
0 g
s
.6411 .36061 m .62134 .39019 L .59093 .4074 L p .88 .788 .755 r
F P
0 g
s
.59093 .4074 m .611 .37757 L .6411 .36061 L p .88 .788 .755 r
F P
0 g
s
.62279 .46932 m .60277 .49196 L .57188 .4883 L p .767 .662 .747 r
F P
0 g
s
.57188 .4883 m .59205 .46732 L .62279 .46932 L p .767 .662 .747 r
F P
0 g
s
.77595 .32583 m .75334 .3142 L .72188 .29295 L p .496 .507 .797 r
F P
0 g
s
.72188 .29295 m .74358 .29651 L .77595 .32583 L p .496 .507 .797 r
F P
0 g
s
.71225 .27968 m .73403 .28317 L .75043 .29631 L p .48 .529 .831 r
F P
0 g
s
.74358 .29651 m .72188 .29295 L .70686 .28919 L p .627 .606 .81 r
F P
0 g
s
.71783 .29098 m .74358 .29651 L .70686 .28919 L .627 .606 .81 r
F
.69126 .28527 m .71225 .27968 L .74358 .29651 L p F P
0 g
s
.77595 .32583 m .74358 .29651 L p .76957 .31915 L .308 .413 .806 r
F P
0 g
s
.7997 .34541 m .78406 .33251 L p .76957 .31915 L .308 .413 .806 r
F P
0 g
s
.78406 .33251 m .77595 .32583 L p .76957 .31915 L .308 .413 .806 r
F P
0 g
s
.74358 .29651 m .7663 .30903 L .7997 .34541 L p .308 .413 .806 r
F P
0 g
s
.74358 .29651 m .71225 .27968 L p .73423 .29162 L .48 .529 .831 r
F P
0 g
s
.7374 .29331 m .7663 .30903 L .74896 .29948 L .48 .529 .831 r
F
.73423 .29162 m .7411 .29535 L .7374 .29331 L F
.7411 .29535 m .7663 .30903 L .7374 .29331 L F
.73403 .28317 m .75681 .29564 L .77465 .31384 L p .267 .414 .824 r
F P
0 g
s
.73423 .29162 m .74896 .29948 L .74358 .29651 L .48 .529 .831 r
F
.71225 .27968 m .75043 .29631 L .73962 .29454 L F
.75043 .29631 m .7663 .30903 L p .74752 .29884 L F P
0 g
s
.74357 .29519 m .75043 .29631 L .74752 .29884 L .48 .529 .831 r
F
.7663 .30903 m .73403 .28317 L p .75867 .30358 L .267 .414 .824 r
F P
0 g
s
.7997 .34541 m .7663 .30903 L p .79728 .34198 L .033 .269 .767 r
F P
0 g
s
.7663 .30903 m .79017 .32966 L .82457 .37102 L p .033 .269 .767 r
F P
0 g
s
.75681 .29564 m .78072 .31624 L .80092 .33982 L p 0 .256 .763 r
F P
0 g
s
.79017 .32966 m .77332 .3151 L p .76249 .30658 L .267 .414 .824 r
F P
0 g
s
.76682 .31033 m .79017 .32966 L .76249 .30658 L .267 .414 .824 r
F
.76518 .30668 m .77465 .31384 L .7687 .31056 L F
.75867 .30358 m .76682 .31033 L .76249 .30658 L F
.77332 .3151 m .7663 .30903 L p .75867 .30358 L F P
0 g
s
.77465 .31384 m .79017 .32966 L p .76391 .30792 L .267 .414 .824 r
F P
0 g
s
.79017 .32966 m .75681 .29564 L p .78525 .32528 L 0 .256 .763 r
F P
0 g
s
.82457 .37102 m .79017 .32966 L p .82809 .37429 L 0 .108 .659 r
F P
0 g
s
.8505 .40066 m .83928 .38783 L p .82809 .37429 L 0 .108 .659 r
F P
0 g
s
.83928 .38783 m .82457 .37102 L p .82809 .37429 L 0 .108 .659 r
F P
0 g
s
.79017 .32966 m .81517 .35647 L .8505 .40066 L p 0 .108 .659 r
F P
0 g
s
.81517 .35647 m .79917 .33932 L p .78913 .32919 L 0 .256 .763 r
F P
0 g
s
.78525 .32528 m .79354 .33392 L .78913 .32919 L 0 .256 .763 r
F
.79354 .33392 m .81517 .35647 L .78913 .32919 L F
.78072 .31624 m .80577 .34304 L .8282 .37109 L p 0 .106 .658 r
F P
0 g
s
.80092 .33982 m .81517 .35647 L p .8022 .34295 L 0 .256 .763 r
F P
0 g
s
.79637 .33589 m .80092 .33982 L .8022 .34295 L 0 .256 .763 r
F
.79917 .33932 m .79017 .32966 L p .78525 .32528 L F P
0 g
s
.75681 .29564 m .80092 .33982 L .79084 .33111 L 0 .256 .763 r
F
.81517 .35647 m .78072 .31624 L p .81301 .3542 L 0 .106 .658 r
F P
0 g
s
.81517 .35647 m .84127 .38743 L .8505 .40066 L closepath p 0 0 .53 r
F P
0 g
s
.84127 .38743 m .82607 .3694 L p .81301 .3542 L 0 .106 .658 r
F P
0 g
s
.82607 .3694 m .81517 .35647 L p .81301 .3542 L 0 .106 .658 r
F P
0 g
s
.78072 .31624 m .8282 .37109 L .81878 .36098 L 0 .106 .658 r
F
.73403 .28317 m .76518 .30668 L .76391 .30792 L .267 .414 .824 r
F
.71225 .27968 m .69126 .28527 L .66117 .29288 L p .758 .726 .823 r
F P
0 g
s
.66117 .29288 m .68171 .27797 L .71225 .27968 L p .758 .726 .823 r
F P
0 g
s
.73403 .28317 m .71225 .27968 L .68171 .27797 L p .643 .665 .856 r
F P
0 g
s
.70279 .2716 m .73403 .28317 L p .71482 .28126 L .643 .665 .856 r
F P
0 g
s
.75681 .29564 m .73403 .28317 L .71763 .27709 L p .473 .569 .871 r
F P
0 g
s
.71763 .27709 m .70279 .2716 L p .72978 .28361 L .473 .569 .871 r
F P
0 g
s
.72978 .28361 m .75681 .29564 L .71763 .27709 L .473 .569 .871 r
F
.72465 .2742 m .75013 .29267 L p .73784 .2872 L F P
0 g
s
.75399 .29375 m .75681 .29564 L p .7551 .29487 L .473 .569 .871 r
F P
0 g
s
.78072 .31624 m .75681 .29564 L .74065 .28487 L p .242 .431 .848 r
F P
0 g
s
.74065 .28487 m .72465 .2742 L p .74839 .292 L .242 .431 .848 r
F P
0 g
s
.74839 .292 m .75099 .2936 L .74065 .28487 L .242 .431 .848 r
F
.7546 .29666 m .78072 .31624 L .74065 .28487 L F
.72465 .2742 m .74449 .28418 L p .75998 .2998 L F P
0 g
s
.74839 .292 m .7546 .29666 L .75099 .2936 L .242 .431 .848 r
F
.72465 .2742 m .75998 .2998 L .7558 .29756 L F
.74449 .28418 m .74745 .28567 L p .76344 .30328 L F P
0 g
s
.72073 .27374 m .72465 .2742 L p .73784 .2872 L .473 .569 .871 r
F P
0 g
s
.70279 .2716 m .72073 .27374 L p .73784 .2872 L .473 .569 .871 r
F P
0 g
s
.68171 .27797 m .69891 .27278 L p .71482 .28126 L .643 .665 .856 r
F P
0 g
s
.69891 .27278 m .70279 .2716 L p .71482 .28126 L .643 .665 .856 r
F P
0 g
s
.64096 .31499 m .66117 .29288 L .69126 .28527 L p .832 .771 .794 r
F P
0 g
s
.66117 .29288 m .64096 .31499 L .62165 .33328 L p .922 .902 .788 r
F P
0 g
s
.62165 .33328 m .61078 .34359 L p .63001 .32424 L .922 .902 .788 r
F P
0 g
s
.63001 .32424 m .66117 .29288 L .62165 .33328 L .922 .902 .788 r
F
.63112 .31545 m .65155 .29234 L .66572 .28559 L p .877 .864 .823 r
F P
0 g
s
.61078 .34359 m .63112 .31545 L .66117 .29288 L p .922 .902 .788 r
F P
0 g
s
.68171 .27797 m .66117 .29288 L .65401 .29826 L p .877 .864 .823 r
F P
0 g
s
.65155 .29234 m .67225 .27623 L .68787 .27386 L p .8 .816 .864 r
F P
0 g
s
.65401 .29826 m .643 .30653 L p .68171 .27797 L .877 .864 .823 r
F P
0 g
s
.65235 .29973 m .68171 .27797 L .643 .30653 L .877 .864 .823 r
F
.66572 .28559 m .68171 .27797 L p .65333 .299 L F P
0 g
s
.643 .30653 m .63112 .31545 L p .64557 .30475 L .877 .864 .823 r
F P
0 g
s
.64557 .30475 m .65235 .29973 L .64817 .30277 L .877 .864 .823 r
F
.64557 .30475 m .64817 .30277 L .643 .30653 L F
.64557 .30475 m .66572 .28559 L .65333 .299 L F
.63112 .31545 m .64703 .30172 L .64557 .30475 L F
.64703 .30172 m .66572 .28559 L .64557 .30475 L F
.63112 .31545 m .61078 .34359 L .58804 .37176 L p .917 .977 .711 r
F P
0 g
s
.58804 .37176 m .57987 .38189 L p .59452 .36289 L .917 .977 .711 r
F P
0 g
s
.59452 .36289 m .63112 .31545 L .58804 .37176 L .917 .977 .711 r
F
.57987 .38189 m .60059 .35028 L .63112 .31545 L p F P
0 g
s
.65155 .29234 m .63112 .31545 L .61098 .33844 L p .928 .966 .765 r
F P
0 g
s
.61927 .32905 m .65155 .29234 L .61098 .33844 L .928 .966 .765 r
F
.63063 .31613 m .62748 .3178 L .65155 .29234 L F
.62122 .32113 m .63371 .30927 L p .62748 .3178 L F P
0 g
s
.63371 .30927 m .65155 .29234 L p .62748 .3178 L .928 .966 .765 r
F P
0 g
s
.61098 .33844 m .60059 .35028 L p .61927 .32905 L .928 .966 .765 r
F P
0 g
s
.62122 .32113 m .6419 .29672 L .65656 .28682 L p .903 .943 .823 r
F P
0 g
s
.68171 .27797 m .65155 .29234 L p .70279 .2716 L .8 .816 .864 r
F P
0 g
s
.65155 .29234 m .68787 .27386 L .67618 .28238 L .8 .816 .864 r
F
.67225 .27623 m .65155 .29234 L .63255 .31038 L p .903 .943 .823 r
F P
0 g
s
.63255 .31038 m .62122 .32113 L p .63638 .30779 L .903 .943 .823 r
F P
0 g
s
.63638 .30779 m .64187 .30296 L .63865 .30552 L .903 .943 .823 r
F
.63638 .30779 m .63865 .30552 L .63255 .31038 L F
.64187 .30296 m .67225 .27623 L .63255 .31038 L F
.62122 .32113 m .65656 .28682 L .64384 .30122 L F
.60059 .35028 m .6179 .32583 L p .63063 .31613 L .928 .966 .765 r
F P
0 g
s
.6179 .32583 m .62122 .32113 L p .63063 .31613 L .928 .966 .765 r
F P
0 g
s
.62122 .32113 m .60059 .35028 L .57685 .38249 L p .854 .964 .635 r
F P
0 g
s
.57685 .38249 m .56913 .39296 L p .583 .37383 L .854 .964 .635 r
F P
0 g
s
.583 .37383 m .62122 .32113 L .57685 .38249 L .854 .964 .635 r
F
.56913 .39296 m .5902 .3606 L .62122 .32113 L p F P
0 g
s
.6419 .29672 m .62122 .32113 L .61294 .33167 L p .897 .983 .712 r
F P
0 g
s
.61294 .33167 m .60031 .34774 L p .61918 .3246 L .897 .983 .712 r
F P
0 g
s
.61918 .3246 m .6419 .29672 L .61294 .33167 L .897 .983 .712 r
F
.63211 .30456 m .65324 .28503 L .65475 .28426 L p .852 .962 .876 r
F P
0 g
s
.65656 .28682 m .67225 .27623 L p .64384 .30122 L .903 .943 .823 r
F P
0 g
s
.68787 .27386 m .70279 .2716 L p .67618 .28238 L .8 .816 .864 r
F P
0 g
s
.70279 .2716 m .67225 .27623 L p .69188 .27547 L .672 .745 .906 r
F P
0 g
s
.72465 .2742 m .70698 .2721 L p .69188 .27547 L .672 .745 .906 r
F P
0 g
s
.70698 .2721 m .70279 .2716 L p .69188 .27547 L .672 .745 .906 r
F P
0 g
s
.67225 .27623 m .69346 .26843 L .72465 .2742 L p .672 .745 .906 r
F P
0 g
s
.69346 .26843 m .67225 .27623 L .65382 .28867 L p .835 .903 .886 r
F P
0 g
s
.65382 .28867 m .6419 .29672 L p .66409 .28455 L .835 .903 .886 r
F P
0 g
s
.66409 .28455 m .69346 .26843 L .65382 .28867 L .835 .903 .886 r
F
.6628 .27901 m .67899 .27342 L p .66685 .28105 L F P
0 g
s
.67899 .27342 m .69346 .26843 L p .66705 .28292 L .835 .903 .886 r
F P
0 g
s
.6419 .29672 m .67899 .27342 L .66705 .28292 L .835 .903 .886 r
F
.72465 .2742 m .69346 .26843 L p .71479 .27524 L .481 .628 .917 r
F P
0 g
s
.74745 .28567 m .72991 .27685 L p .71644 .27542 L .481 .628 .917 r
F P
0 g
s
.71882 .27653 m .74745 .28567 L .71644 .27542 L .481 .628 .917 r
F
.72991 .27685 m .72465 .2742 L p .71479 .27524 L F P
0 g
s
.71537 .26937 m .74745 .28567 L p .72811 .27949 L .481 .628 .917 r
F P
0 g
s
.74745 .28567 m .77308 .31051 L p .76344 .30328 L .242 .431 .848 r
F P
0 g
s
.7791 .31475 m .78072 .31624 L p .77976 .31552 L .242 .431 .848 r
F P
0 g
s
.78072 .31624 m .74745 .28567 L p .77424 .31202 L 0 .265 .772 r
F P
0 g
s
.80577 .34304 m .78853 .3246 L p .77625 .31379 L 0 .265 .772 r
F P
0 g
s
.77933 .31703 m .80577 .34304 L .77625 .31379 L 0 .265 .772 r
F
.78853 .3246 m .78072 .31624 L p .77424 .31202 L F P
0 g
s
.77134 .30516 m .80577 .34304 L p .79053 .32805 L 0 .265 .772 r
F P
0 g
s
.80577 .34304 m .77134 .30516 L p .8006 .33842 L 0 .13 .677 r
F P
0 g
s
.80577 .34304 m .8319 .374 L .84127 .38743 L closepath p 0 0 .53 r
F P
0 g
s
.8319 .374 m .81448 .35337 L p .8006 .33842 L 0 .13 .677 r
F P
0 g
s
.81448 .35337 m .80577 .34304 L p .8006 .33842 L 0 .13 .677 r
F P
0 g
s
.77134 .30516 m .79634 .33073 L .82162 .3615 L p 0 .13 .677 r
F P
0 g
s
.77134 .30516 m .82162 .3615 L .81202 .3514 L 0 .13 .677 r
F
.74745 .28567 m .7697 .30381 L p .78733 .32433 L 0 .265 .772 r
F P
0 g
s
.77424 .31202 m .77933 .31703 L .77625 .31379 L 0 .265 .772 r
F
.74745 .28567 m .78733 .32433 L .78319 .32082 L F
.7697 .30381 m .77134 .30516 L p .79053 .32805 L F P
0 g
s
.74745 .28567 m .72924 .27642 L p .74432 .28671 L .241 .47 .879 r
F P
0 g
s
.72924 .27642 m .71537 .26937 L p .74293 .28699 L .241 .47 .879 r
F P
0 g
s
.74293 .28699 m .77134 .30516 L .72924 .27642 L .241 .47 .879 r
F
.77134 .30516 m .75372 .29078 L p .74432 .28671 L F P
0 g
s
.75372 .29078 m .74745 .28567 L p .74432 .28671 L .241 .47 .879 r
F P
0 g
s
.71537 .26937 m .73523 .2777 L p .7475 .2885 L .241 .47 .879 r
F P
0 g
s
.73523 .2777 m .73817 .27893 L p .7475 .2885 L .241 .47 .879 r
F P
0 g
s
.71537 .26937 m .7587 .29516 L .74759 .28997 L .241 .47 .879 r
F
.69346 .26843 m .71142 .2692 L p .71516 .2715 L .481 .628 .917 r
F P
0 g
s
.71479 .27524 m .71882 .27653 L .71644 .27542 L .481 .628 .917 r
F
.71479 .27524 m .71516 .2715 L .72811 .27949 L F
.69346 .26843 m .71516 .2715 L .71479 .27524 L F
.71142 .2692 m .71537 .26937 L p .72811 .27949 L F P
0 g
s
.71537 .26937 m .69346 .26843 L .6628 .27901 L p .706 .831 .942 r
F P
0 g
s
.70195 .26933 m .71537 .26937 L p .6949 .27312 L .706 .831 .942 r
F P
0 g
s
.69302 .27292 m .70195 .26933 L .6949 .27312 L .706 .831 .942 r
F
.6628 .27901 m .68414 .26928 L .70195 .26933 L p F P
0 g
s
.6628 .27901 m .70195 .26933 L .69052 .27393 L .706 .831 .942 r
F
.73817 .27893 m .71537 .26937 L .68414 .26928 L p .51 .703 .957 r
F P
0 g
s
.70611 .26794 m .73817 .27893 L p .71807 .27534 L .51 .703 .957 r
F P
0 g
s
.68414 .26928 m .7016 .26821 L p .71807 .27534 L .51 .703 .957 r
F P
0 g
s
.7016 .26821 m .70611 .26794 L p .71807 .27534 L .51 .703 .957 r
F P
0 g
s
.7587 .29516 m .7652 .3003 L p .75416 .29304 L .241 .47 .879 r
F P
0 g
s
.7652 .3003 m .77134 .30516 L p .75416 .29304 L .241 .47 .879 r
F P
0 g
s
.74759 .28997 m .75416 .29304 L .77134 .30516 L .241 .47 .879 r
F
.73817 .27893 m .7587 .29516 L p .7475 .2885 L F P
0 g
s
.77134 .30516 m .73817 .27893 L p .76395 .30189 L 0 .301 .795 r
F P
0 g
s
.79634 .33073 m .77861 .31259 L p .76479 .30251 L 0 .301 .795 r
F P
0 g
s
.76631 .30399 m .79634 .33073 L .76479 .30251 L 0 .301 .795 r
F
.77861 .31259 m .77134 .30516 L p .76395 .30189 L F P
0 g
s
.762 .29627 m .79634 .33073 L p .77971 .31593 L 0 .301 .795 r
F P
0 g
s
.79634 .33073 m .762 .29627 L p .78942 .32538 L 0 .18 .714 r
F P
0 g
s
.79634 .33073 m .82239 .36038 L .8319 .374 L closepath p 0 .006 .554 r
F P
0 g
s
.82239 .36038 m .80386 .33929 L p .78942 .32538 L 0 .18 .714 r
F P
0 g
s
.80386 .33929 m .79634 .33073 L p .78942 .32538 L 0 .18 .714 r
F P
0 g
s
.762 .29627 m .78687 .31948 L .81388 .35059 L p 0 .18 .714 r
F P
0 g
s
.762 .29627 m .81388 .35059 L .80456 .34146 L 0 .18 .714 r
F
.73817 .27893 m .76033 .29506 L p .77799 .31407 L 0 .301 .795 r
F P
0 g
s
.76395 .30189 m .76631 .30399 L .76479 .30251 L 0 .301 .795 r
F
.73817 .27893 m .77799 .31407 L .77526 .31197 L F
.76033 .29506 m .762 .29627 L p .77971 .31593 L F P
0 g
s
.73817 .27893 m .71849 .27218 L p .73434 .28096 L .274 .531 .914 r
F P
0 g
s
.71849 .27218 m .70611 .26794 L p .73179 .28096 L .274 .531 .914 r
F P
0 g
s
.73179 .28096 m .762 .29627 L .71849 .27218 L .274 .531 .914 r
F
.762 .29627 m .74457 .28359 L p .73434 .28096 L F P
0 g
s
.74457 .28359 m .73817 .27893 L p .73434 .28096 L .274 .531 .914 r
F P
0 g
s
.70611 .26794 m .72549 .27382 L p .74319 .28673 L .274 .531 .914 r
F P
0 g
s
.72549 .27382 m .7289 .27485 L p .74319 .28673 L .274 .531 .914 r
F P
0 g
s
.6419 .29672 m .65809 .283 L p .66685 .28105 L .835 .903 .886 r
F P
0 g
s
.65809 .283 m .6628 .27901 L p .66685 .28105 L .835 .903 .886 r
F P
0 g
s
.60851 .33797 m .6419 .29672 L .60031 .34774 L .897 .983 .712 r
F
.6184 .32575 m .61614 .3272 L .6419 .29672 L F
.61115 .33038 m .62342 .31695 L p .61614 .3272 L F P
0 g
s
.62342 .31695 m .6419 .29672 L p .61614 .3272 L .897 .983 .712 r
F P
0 g
s
.6628 .27901 m .6419 .29672 L .63452 .3048 L p .899 .983 .792 r
F P
0 g
s
.64132 .29979 m .6628 .27901 L .63452 .3048 L .899 .983 .792 r
F
.63144 .31021 m .6628 .27901 L .62215 .31834 L F
.63391 .30775 m .65925 .28197 L .66043 .28136 L F
.63452 .3048 m .62215 .31834 L p .64132 .29979 L F P
0 g
s
.647 .29216 m .65925 .28197 L p .63391 .30775 L .899 .983 .792 r
F P
0 g
s
.65925 .28197 m .6628 .27901 L p .66043 .28136 L .899 .983 .792 r
F P
0 g
s
.62215 .31834 m .61115 .33038 L p .62746 .31416 L .899 .983 .792 r
F P
0 g
s
.62746 .31416 m .63144 .31021 L .6293 .31207 L .899 .983 .792 r
F
.62746 .31416 m .6293 .31207 L .62215 .31834 L F
.63211 .30456 m .647 .29216 L p .62863 .31175 L F P
0 g
s
.61115 .33038 m .63211 .30456 L p .62863 .31175 L .899 .983 .792 r
F P
0 g
s
.61115 .33038 m .647 .29216 L .63391 .30775 L .899 .983 .792 r
F
.60031 .34774 m .5902 .3606 L p .60851 .33797 L .897 .983 .712 r
F P
0 g
s
.5902 .3606 m .60525 .3389 L p .6184 .32575 L .897 .983 .712 r
F P
0 g
s
.60525 .3389 m .61115 .33038 L p .6184 .32575 L .897 .983 .712 r
F P
0 g
s
.61115 .33038 m .5902 .3606 L .56554 .39485 L p .812 .945 .592 r
F P
0 g
s
.56554 .39485 m .55807 .40522 L p .57122 .38668 L .812 .945 .592 r
F P
0 g
s
.57122 .38668 m .61115 .33038 L .56554 .39485 L .812 .945 .592 r
F
.55807 .40522 m .57951 .37231 L .61115 .33038 L p F P
0 g
s
.63211 .30456 m .61115 .33038 L .60227 .34216 L p .867 .976 .672 r
F P
0 g
s
.60227 .34216 m .58961 .35894 L p .60844 .33485 L .867 .976 .672 r
F P
0 g
s
.60844 .33485 m .63211 .30456 L .60227 .34216 L .867 .976 .672 r
F
.62209 .31405 m .64347 .29269 L .64463 .29196 L p .857 .986 .848 r
F P
0 g
s
.68414 .26928 m .6628 .27901 L .64359 .29501 L p .852 .962 .876 r
F P
0 g
s
.64359 .29501 m .63211 .30456 L p .65088 .29183 L .852 .962 .876 r
F P
0 g
s
.65088 .29183 m .65221 .29066 L .64359 .29501 L .852 .962 .876 r
F
.6538 .28985 m .68414 .26928 L .64359 .29501 L F
.63211 .30456 m .65475 .28426 L .64388 .29658 L F
.5977 .34889 m .63211 .30456 L .58961 .35894 L .867 .976 .672 r
F
.60441 .34024 m .60333 .34053 L .63211 .30456 L F
.60082 .34119 m .61185 .32828 L p .60333 .34053 L F P
0 g
s
.61185 .32828 m .63211 .30456 L p .60333 .34053 L .867 .976 .672 r
F P
0 g
s
.65324 .28503 m .63211 .30456 L .62396 .3141 L p .884 .991 .757 r
F P
0 g
s
.63073 .30856 m .65324 .28503 L .62396 .3141 L .884 .991 .757 r
F
.62098 .31959 m .65324 .28503 L .61174 .32841 L F
.62396 .3141 m .61174 .32841 L p .63073 .30856 L F P
0 g
s
.63679 .30035 m .65324 .28503 L p .62767 .31243 L .884 .991 .757 r
F P
0 g
s
.65475 .28426 m .66981 .27658 L p .64388 .29658 L .852 .962 .876 r
F P
0 g
s
.66981 .27658 m .68414 .26928 L p .65762 .28727 L .852 .962 .876 r
F P
0 g
s
.65088 .29183 m .6538 .28985 L .65221 .29066 L .852 .962 .876 r
F
.64388 .29658 m .66981 .27658 L .65762 .28727 L F
.70611 .26794 m .68414 .26928 L .65324 .28503 L p .74 .903 .951 r
F P
0 g
s
.65324 .28503 m .67846 .27243 L .66771 .28035 L .74 .903 .951 r
F
.62555 .3143 m .63679 .30035 L .62767 .31243 L .884 .991 .757 r
F
.61174 .32841 m .60082 .34119 L p .61923 .32147 L F P
0 g
s
.61923 .32147 m .62098 .31959 L .62019 .32035 L .884 .991 .757 r
F
.61923 .32147 m .62019 .32035 L .61174 .32841 L F
.62209 .31405 m .63679 .30035 L p .62004 .31937 L F P
0 g
s
.60082 .34119 m .62209 .31405 L p .62004 .31937 L .884 .991 .757 r
F P
0 g
s
.60082 .34119 m .63679 .30035 L .62327 .31714 L .884 .991 .757 r
F
.59135 .35502 m .60082 .34119 L p .60441 .34024 L .867 .976 .672 r
F P
0 g
s
.65324 .28503 m .67474 .27304 L .67846 .27243 L p .74 .903 .951 r
F P
0 g
s
.67474 .27304 m .65324 .28503 L .63337 .30354 L p .857 .986 .848 r
F P
0 g
s
.63337 .30354 m .62209 .31405 L p .6424 .29823 L .857 .986 .848 r
F P
0 g
s
.6424 .29823 m .64297 .29769 L .63337 .30354 L .857 .986 .848 r
F
.64354 .29734 m .67474 .27304 L .63337 .30354 L F
.62209 .31405 m .64463 .29196 L .63349 .30516 L F
.60082 .34119 m .57951 .37231 L .55426 .40577 L p .825 .954 .61 r
F P
0 g
s
.55426 .40577 m .54665 .41586 L p .55923 .39852 L .825 .954 .61 r
F P
0 g
s
.55923 .39852 m .60082 .34119 L .55426 .40577 L .825 .954 .61 r
F
.54665 .41586 m .56847 .38282 L .60082 .34119 L p F P
0 g
s
.60082 .34119 m .59203 .3525 L p .62209 .31405 L .87 .977 .675 r
F P
0 g
s
.59203 .3525 m .57896 .36933 L p .59799 .34494 L .87 .977 .675 r
F P
0 g
s
.59799 .34494 m .62209 .31405 L .59203 .3525 L .87 .977 .675 r
F
.58688 .35921 m .62209 .31405 L .57896 .36933 L F
.58636 .35987 m .58752 .35722 L .62209 .31405 L F
.59014 .35119 m .59753 .3426 L p .58752 .35722 L F P
0 g
s
.59753 .3426 m .62209 .31405 L p .58752 .35722 L .87 .977 .675 r
F P
0 g
s
.64347 .29269 m .62209 .31405 L .6137 .32379 L p .885 .99 .748 r
F P
0 g
s
.62036 .31764 m .64347 .29269 L .6137 .32379 L .885 .99 .748 r
F
.6105 .32886 m .64347 .29269 L .60131 .3382 L F
.6137 .32379 m .60131 .3382 L p .62036 .31764 L F P
0 g
s
.62549 .30989 m .64347 .29269 L p .61338 .3257 L .885 .99 .748 r
F P
0 g
s
.64463 .29196 m .65209 .28727 L p .63349 .30516 L .857 .986 .848 r
F P
0 g
s
.65209 .28727 m .66017 .28219 L p .64522 .29507 L .857 .986 .848 r
F P
0 g
s
.63349 .30516 m .65209 .28727 L .64522 .29507 L .857 .986 .848 r
F
.66017 .28219 m .67474 .27304 L p .64769 .29411 L F P
0 g
s
.6424 .29823 m .64354 .29734 L .64297 .29769 L .857 .986 .848 r
F
.63349 .30516 m .66017 .28219 L .64769 .29411 L F
.67846 .27243 m .69302 .27007 L p .66771 .28035 L .74 .903 .951 r
F P
0 g
s
.69302 .27007 m .70611 .26794 L p .68142 .27592 L .74 .903 .951 r
F P
0 g
s
.66771 .28035 m .69302 .27007 L .68142 .27592 L .74 .903 .951 r
F
.69052 .27393 m .69302 .27292 L .6949 .27312 L .706 .831 .942 r
F
.7289 .27485 m .70611 .26794 L .67474 .27304 L p .559 .78 .981 r
F P
0 g
s
.67474 .27304 m .69155 .26994 L p .70789 .27415 L .559 .78 .981 r
F P
0 g
s
.69155 .26994 m .69679 .26897 L p .70789 .27415 L .559 .78 .981 r
F P
0 g
s
.69679 .26897 m .67474 .27304 L .64347 .29269 L p .771 .946 .935 r
F P
0 g
s
.64347 .29269 m .66515 .27834 L .66901 .2772 L p .771 .946 .935 r
F P
0 g
s
.64347 .29269 m .66901 .2772 L .65797 .28624 L .771 .946 .935 r
F
.61236 .32666 m .62549 .30989 L .61338 .3257 L .885 .99 .748 r
F
.59014 .35119 m .61174 .32305 L .62549 .30989 L p F P
0 g
s
.60131 .3382 m .59014 .35119 L p .6105 .32886 L .885 .99 .748 r
F P
0 g
s
.59014 .35119 m .62549 .30989 L .61152 .32774 L .885 .99 .748 r
F
.66515 .27834 m .64347 .29269 L .62311 .31217 L p .867 .989 .831 r
F P
0 g
s
.62311 .31217 m .61174 .32305 L p .63325 .30504 L .867 .989 .831 r
F P
0 g
s
.63325 .30504 m .66515 .27834 L .62311 .31217 L .867 .989 .831 r
F
.64983 .28885 m .66515 .27834 L p .637 .3019 L F P
0 g
s
.66901 .2772 m .68372 .27284 L p .65797 .28624 L .771 .946 .935 r
F P
0 g
s
.68372 .27284 m .69679 .26897 L p .67193 .28003 L .771 .946 .935 r
F P
0 g
s
.65797 .28624 m .68372 .27284 L .67193 .28003 L .771 .946 .935 r
F
.69679 .26897 m .7289 .27485 L p .70789 .27415 L .559 .78 .981 r
F P
0 g
s
.7289 .27485 m .74681 .28857 L p .74319 .28673 L .274 .531 .914 r
F P
0 g
s
.75349 .29076 m .762 .29627 L p .7561 .29328 L .274 .531 .914 r
F P
0 g
s
.762 .29627 m .7289 .27485 L p .75401 .29418 L .052 .363 .833 r
F P
0 g
s
.78687 .31948 m .76901 .30282 L p .75409 .29423 L .052 .363 .833 r
F P
0 g
s
.75426 .29437 m .78687 .31948 L .75409 .29423 L .052 .363 .833 r
F
.76901 .30282 m .762 .29627 L p .75401 .29418 L F P
0 g
s
.75263 .28918 m .78687 .31948 L p .76906 .30576 L .052 .363 .833 r
F P
0 g
s
.78687 .31948 m .75263 .28918 L p .77882 .31417 L 0 .252 .765 r
F P
0 g
s
.78687 .31948 m .81274 .34656 L .82239 .36038 L closepath p 0 .059 .603 r
F P
0 g
s
.81274 .34656 m .79367 .3266 L p .77882 .31417 L 0 .252 .765 r
F P
0 g
s
.79367 .3266 m .78687 .31948 L p .77882 .31417 L 0 .252 .765 r
F P
0 g
s
.75263 .28918 m .77733 .30905 L .80538 .33876 L p 0 .252 .765 r
F P
0 g
s
.75263 .28918 m .80538 .33876 L .79645 .33101 L 0 .252 .765 r
F
.7289 .27485 m .75052 .2879 L p .76831 .30504 L .052 .363 .833 r
F P
0 g
s
.73297 .28206 m .72043 .2733 L .69679 .26897 L p .342 .61 .949 r
F P
0 g
s
.75401 .29418 m .75426 .29437 L .75409 .29423 L .052 .363 .833 r
F
.7289 .27485 m .76831 .30504 L .76699 .30417 L F
.75052 .2879 m .75263 .28918 L p .76906 .30576 L F P
0 g
s
.75263 .28918 m .7289 .27485 L p .72099 .2734 L .342 .61 .949 r
F P
0 g
s
.71957 .2727 m .75263 .28918 L p .73297 .28206 L .342 .61 .949 r
F P
0 g
s
.75263 .28918 m .71957 .2727 L p .74427 .28824 L .146 .447 .879 r
F P
0 g
s
.77733 .30905 m .75968 .29485 L p .74427 .28824 L .146 .447 .879 r
F P
0 g
s
.75968 .29485 m .75263 .28918 L p .74427 .28824 L .146 .447 .879 r
F P
0 g
s
.71957 .2727 m .74056 .28218 L p .75858 .29725 L .146 .447 .879 r
F P
0 g
s
.74056 .28218 m .74319 .28337 L p .75858 .29725 L .146 .447 .879 r
F P
0 g
s
.69679 .26897 m .71555 .27204 L p .73297 .28206 L .342 .61 .949 r
F P
0 g
s
.71555 .27204 m .71957 .2727 L p .73297 .28206 L .342 .61 .949 r
F P
0 g
s
.71957 .2727 m .69679 .26897 L .67605 .27511 L p .622 .844 .985 r
F P
0 g
s
.67605 .27511 m .66515 .27834 L p .68754 .27602 L .622 .844 .985 r
F P
0 g
s
.68754 .27602 m .71957 .2727 L .67605 .27511 L .622 .844 .985 r
F
.66515 .27834 m .6873 .27135 L .71957 .2727 L p F P
0 g
s
.74319 .28337 m .71957 .2727 L .6873 .27135 L p .435 .692 .973 r
F P
0 g
s
.72254 .27893 m .72224 .27875 L .74319 .28337 L .435 .692 .973 r
F
.71008 .27158 m .73248 .27956 L p .72224 .27875 L F P
0 g
s
.73248 .27956 m .74319 .28337 L p .72224 .27875 L .435 .692 .973 r
F P
0 g
s
.6873 .27135 m .70528 .27153 L p .72254 .27893 L .435 .692 .973 r
F P
0 g
s
.70528 .27153 m .71008 .27158 L p .72254 .27893 L .435 .692 .973 r
F P
0 g
s
.74319 .28337 m .77733 .30905 L p .75858 .29725 L .146 .447 .879 r
F P
0 g
s
.80538 .33876 m .81274 .34656 L p .79645 .33101 L 0 .252 .765 r
F P
0 g
s
.6334 .30014 m .64983 .28885 L p .62193 .31452 L .867 .989 .831 r
F P
0 g
s
.62193 .31452 m .64983 .28885 L .637 .3019 L .867 .989 .831 r
F
.6873 .27135 m .66515 .27834 L .64442 .29257 L p .801 .962 .914 r
F P
0 g
s
.64442 .29257 m .6334 .30014 L p .65511 .28854 L .801 .962 .914 r
F P
0 g
s
.65511 .28854 m .6873 .27135 L .64442 .29257 L .801 .962 .914 r
F
.65852 .28235 m .67389 .27648 L p .64735 .29269 L F P
0 g
s
.67389 .27648 m .6873 .27135 L p .66184 .28495 L .801 .962 .914 r
F P
0 g
s
.64735 .29269 m .67389 .27648 L .66184 .28495 L .801 .962 .914 r
F
.6334 .30014 m .65529 .28359 L .65852 .28235 L p F P
0 g
s
.6334 .30014 m .65852 .28235 L .64735 .29269 L .801 .962 .914 r
F
.71008 .27158 m .6873 .27135 L .65529 .28359 L p .685 .883 .972 r
F P
0 g
s
.65529 .28359 m .67757 .27376 L .69797 .27239 L p .685 .883 .972 r
F P
0 g
s
.69797 .27239 m .71008 .27158 L p .68627 .2768 L .685 .883 .972 r
F P
0 g
s
.65529 .28359 m .69797 .27239 L .68627 .2768 L .685 .883 .972 r
F
.61152 .32774 m .61236 .32666 L .61338 .3257 L .885 .99 .748 r
F
.61174 .32305 m .63253 .30106 L p .62193 .31452 L .867 .989 .831 r
F P
0 g
s
.63253 .30106 m .6334 .30014 L p .62193 .31452 L .867 .989 .831 r
F P
0 g
s
.57896 .36933 m .56847 .38282 L p .58688 .35921 L .87 .977 .675 r
F P
0 g
s
.56847 .38282 m .57549 .37257 L p .58636 .35987 L .87 .977 .675 r
F P
0 g
s
.57549 .37257 m .59014 .35119 L p .58636 .35987 L .87 .977 .675 r
F P
0 g
s
.62327 .31714 m .62555 .3143 L .62767 .31243 L .884 .991 .757 r
F
.58961 .35894 m .57951 .37231 L p .5977 .34889 L .867 .976 .672 r
F P
0 g
s
.57951 .37231 m .59135 .35502 L p .60441 .34024 L .867 .976 .672 r
F P
0 g
s
.76699 .30417 m .76831 .30504 L .76906 .30576 L .052 .363 .833 r
F
.81388 .35059 m .82239 .36038 L p .80456 .34146 L 0 .18 .714 r
F P
0 g
s
.77526 .31197 m .77799 .31407 L .77971 .31593 L 0 .301 .795 r
F
.82162 .3615 m .8319 .374 L p .81202 .3514 L 0 .13 .677 r
F P
0 g
s
.78319 .32082 m .78733 .32433 L .79053 .32805 L 0 .265 .772 r
F
.7558 .29756 m .75998 .2998 L .76344 .30328 L .242 .431 .848 r
F
.8282 .37109 m .84127 .38743 L p .81878 .36098 L 0 .106 .658 r
F P
0 g
s
.79084 .33111 m .79637 .33589 L .8022 .34295 L 0 .256 .763 r
F
.76518 .30668 m .7687 .31056 L .76391 .30792 L .267 .414 .824 r
F
.82457 .37102 m .81058 .35661 L p .79728 .34198 L .033 .269 .767 r
F P
0 g
s
.81058 .35661 m .7997 .34541 L p .79728 .34198 L .033 .269 .767 r
F P
0 g
s
.73962 .29454 m .74357 .29519 L .74752 .29884 L .48 .529 .831 r
F
.70686 .28919 m .69126 .28527 L p .71783 .29098 L .627 .606 .81 r
F P
0 g
s
.67087 .2995 m .69126 .28527 L .72188 .29295 L p .724 .656 .782 r
F P
0 g
s
.86196 .437 m .83852 .42512 L .80581 .39258 L p .344 .446 .822 r
F P
0 g
s
.80581 .39258 m .82878 .40373 L .86196 .437 L p .344 .446 .822 r
F P
0 g
s
.61202 .44013 m .59205 .46732 L .5611 .46986 L p .821 .747 .781 r
F P
0 g
s
.5611 .46986 m .58135 .44728 L .61202 .44013 L p .821 .747 .781 r
F P
0 g
s
.69126 .28527 m .67087 .2995 L .64096 .31499 L p .832 .771 .794 r
F P
0 g
s
.67087 .2995 m .65083 .32102 L .62085 .3423 L p .88 .809 .775 r
F P
0 g
s
.62085 .3423 m .64096 .31499 L .67087 .2995 L p .88 .809 .775 r
F P
0 g
s
.90323 .4762 m .8802 .47055 L .84818 .44643 L p .327 .532 .901 r
F P
0 g
s
.84818 .44643 m .87114 .454 L .90323 .4762 L p .327 .532 .901 r
F P
0 g
s
.62134 .39019 m .60144 .41979 L .57066 .43451 L p .886 .826 .783 r
F P
0 g
s
.57066 .43451 m .59093 .4074 L .62134 .39019 L p .886 .826 .783 r
F P
0 g
s
.80933 .3633 m .78578 .34578 L .75334 .3142 L p .356 .423 .793 r
F P
0 g
s
.75334 .3142 m .77595 .32583 L .80933 .3633 L p .356 .423 .793 r
F P
0 g
s
.65083 .32102 m .63093 .34783 L .6007 .37247 L p .91 .844 .766 r
F P
0 g
s
.6007 .37247 m .62085 .3423 L .65083 .32102 L p .91 .844 .766 r
F P
0 g
s
.85268 .41988 m .82878 .40373 L .79574 .36829 L p .259 .393 .809 r
F P
0 g
s
.79574 .36829 m .81903 .38291 L .85268 .41988 L p .259 .393 .809 r
F P
0 g
s
.59205 .46732 m .57188 .4883 L .54075 .482 L p .757 .822 .903 r
F P
0 g
s
.54075 .482 m .5611 .46986 L .59205 .46732 L p .757 .822 .903 r
F P
0 g
s
.8802 .47055 m .90323 .4762 L .9116 .48819 L closepath p .337 .583 .934 r
F P
0 g
s
.63093 .34783 m .611 .37757 L .5804 .40265 L p .928 .888 .772 r
F P
0 g
s
.5804 .40265 m .6007 .37247 L .63093 .34783 L p .928 .888 .772 r
F P
0 g
s
.60144 .41979 m .58135 .44728 L .55026 .45649 L p .871 .871 .834 r
F P
0 g
s
.55026 .45649 m .57066 .43451 L .60144 .41979 L p .871 .871 .834 r
F P
0 g
s
.89475 .46405 m .87114 .454 L .83852 .42512 L p .196 .444 .87 r
F P
0 g
s
.83852 .42512 m .86196 .437 L .89475 .46405 L p .196 .444 .87 r
F P
0 g
s
.84334 .40297 m .81903 .38291 L .78578 .34578 L p .174 .343 .794 r
F P
0 g
s
.78578 .34578 m .80933 .3633 L .84334 .40297 L p .174 .343 .794 r
F P
0 g
s
.5611 .46986 m .54075 .482 L .50942 .47892 L p .662 .867 .977 r
F P
0 g
s
.58135 .44728 m .5611 .46986 L .5298 .47116 L p .8 .91 .916 r
F P
0 g
s
.5298 .47116 m .55026 .45649 L .58135 .44728 L p .8 .91 .916 r
F P
0 g
s
.611 .37757 m .59093 .4074 L .55992 .43007 L p .923 .938 .794 r
F P
0 g
s
.55992 .43007 m .5804 .40265 L .611 .37757 L p .923 .938 .794 r
F P
0 g
s
.50942 .47892 m .5298 .47116 L .5611 .46986 L p .662 .867 .977 r
F P
0 g
s
.88615 .45172 m .86196 .437 L .82878 .40373 L p .063 .349 .824 r
F P
0 g
s
.82878 .40373 m .85268 .41988 L .88615 .45172 L p .063 .349 .824 r
F P
0 g
s
.87114 .454 m .89475 .46405 L .90323 .4762 L closepath p .184 .485 .899 r
F P
0 g
s
.5298 .47116 m .50942 .47892 L .47789 .47256 L p .062 0 0 r
F P
0 g
s
.64096 .31499 m .62085 .3423 L .59036 .37442 L p .941 .935 .763 r
F P
0 g
s
.59036 .37442 m .61078 .34359 L .64096 .31499 L p .941 .935 .763 r
F P
0 g
s
.83396 .38659 m .80933 .3633 L .77595 .32583 L p .096 .3 .779 r
F P
0 g
s
.77595 .32583 m .7997 .34541 L .83396 .38659 L p .096 .3 .779 r
F P
0 g
s
.59093 .4074 m .57066 .43451 L .53931 .45224 L p .87 .989 .827 r
F P
0 g
s
.53931 .45224 m .55992 .43007 L .59093 .4074 L p .87 .989 .827 r
F P
0 g
s
.87743 .43923 m .85268 .41988 L .81903 .38291 L p 0 .26 .769 r
F P
0 g
s
.81903 .38291 m .84334 .40297 L .87743 .43923 L p 0 .26 .769 r
F P
0 g
s
.47789 .47256 m .49816 .47247 L p .51974 .47143 L .062 0 0 r
F P
0 g
s
.49816 .47247 m .47789 .47256 L .44612 .46877 L p .517 .011 0 r
F P
0 g
s
.44612 .46877 m .46616 .47508 L .49816 .47247 L p .517 .011 0 r
F P
0 g
s
.49816 .47247 m .48197 .47379 L p .48429 .47314 L .41 0 0 r
F P
0 g
s
.49816 .47247 m .5298 .47116 L p .51974 .47143 L .062 0 0 r
F P
0 g
s
.55026 .45649 m .5298 .47116 L .51587 .47174 L p 0 0 0 r
F P
0 g
s
.51587 .47174 m .49816 .47247 L p .52731 .46353 L 0 0 0 r
F P
0 g
s
.52731 .46353 m .55026 .45649 L .51587 .47174 L 0 0 0 r
F
.49816 .47247 m .51867 .46705 L .55026 .45649 L p F P
0 g
s
.51867 .46705 m .53931 .45224 L .5569 .44229 L p .655 .969 .818 r
F P
0 g
s
.5569 .44229 m .57066 .43451 L p .54783 .44881 L .655 .969 .818 r
F P
0 g
s
.51867 .46705 m .5569 .44229 L .54783 .44881 L .655 .969 .818 r
F
.47634 .47353 m .50667 .46889 L .49816 .47247 L .41 0 0 r
F
.51867 .46705 m .50252 .47132 L p .50667 .46889 L F P
0 g
s
.50252 .47132 m .49816 .47247 L p .50667 .46889 L .41 0 0 r
F P
0 g
s
.46616 .47508 m .47634 .47353 L .48429 .47314 L .41 0 0 r
F
.48197 .47379 m .46616 .47508 L p .48429 .47314 L F P
0 g
s
.46616 .47508 m .48657 .47657 L .51867 .46705 L p .41 0 0 r
F P
0 g
s
.53931 .45224 m .51867 .46705 L .50393 .47142 L p .169 0 0 r
F P
0 g
s
.50393 .47142 m .48657 .47657 L p .51507 .46343 L .169 0 0 r
F P
0 g
s
.51507 .46343 m .53931 .45224 L .50393 .47142 L .169 0 0 r
F
.52003 .46314 m .53931 .45224 L p .51507 .46343 L F P
0 g
s
.50899 .46623 m .51326 .46504 L .51507 .46343 L .169 0 0 r
F
.51326 .46504 m .52003 .46314 L .51507 .46343 L F
.48657 .47657 m .50729 .47035 L .52003 .46314 L p F P
0 g
s
.48657 .47657 m .52003 .46314 L .50899 .46623 L .169 0 0 r
F
.55992 .43007 m .53931 .45224 L .52585 .45985 L p 0 0 0 r
F P
0 g
s
.52585 .45985 m .50729 .47035 L p .53781 .44699 L 0 0 0 r
F P
0 g
s
.53781 .44699 m .55992 .43007 L .52585 .45985 L 0 0 0 r
F
.52816 .45535 m .54534 .44167 L p .51738 .46263 L F P
0 g
s
.51738 .46263 m .54534 .44167 L .53576 .44856 L 0 0 0 r
F
.52816 .45535 m .54903 .43291 L .56725 .41534 L p .677 .932 .637 r
F P
0 g
s
.56725 .41534 m .5804 .40265 L p .55851 .42474 L .677 .932 .637 r
F P
0 g
s
.52816 .45535 m .56725 .41534 L .55851 .42474 L .677 .932 .637 r
F
.54534 .44167 m .55992 .43007 L p .53576 .44856 L 0 0 0 r
F P
0 g
s
.50729 .47035 m .52092 .46055 L p .51738 .46263 L 0 0 0 r
F P
0 g
s
.52092 .46055 m .52816 .45535 L p .51738 .46263 L 0 0 0 r
F P
0 g
s
.62085 .3423 m .6007 .37247 L .56978 .40511 L p .931 .969 .743 r
F P
0 g
s
.56978 .40511 m .59036 .37442 L .62085 .3423 L p .931 .969 .743 r
F P
0 g
s
.57066 .43451 m .55026 .45649 L .51867 .46705 L p .655 .969 .818 r
F P
0 g
s
.86196 .437 m .88615 .45172 L .89475 .46405 L closepath p .016 .367 .836 r
F P
0 g
s
.46616 .47508 m .44612 .46877 L .4141 .46529 L p .527 0 0 r
F P
0 g
s
.6007 .37247 m .5804 .40265 L .54903 .43291 L p .866 .987 .715 r
F P
0 g
s
.54903 .43291 m .56978 .40511 L .6007 .37247 L p .866 .987 .715 r
F P
0 g
s
.86858 .42655 m .84334 .40297 L .80933 .3633 L p 0 .186 .719 r
F P
0 g
s
.80933 .3633 m .83396 .38659 L .86858 .42655 L p 0 .186 .719 r
F P
0 g
s
.85268 .41988 m .87743 .43923 L .88615 .45172 L closepath p 0 .245 .755 r
F P
0 g
s
.5804 .40265 m .55992 .43007 L .52816 .45535 L p .677 .932 .637 r
F P
0 g
s
.4141 .46529 m .43392 .47305 L .46616 .47508 L p .527 0 0 r
F P
0 g
s
.43392 .47305 m .4141 .46529 L .38205 .45677 L p .65 .192 .152 r
F P
0 g
s
.38205 .45677 m .40142 .47066 L .43392 .47305 L p .65 .192 .152 r
F P
0 g
s
.40142 .47066 m .38205 .45677 L .34962 .45246 L p .659 .199 .15 r
F P
0 g
s
.85961 .4137 m .83396 .38659 L .7997 .34541 L p 0 .134 .68 r
F P
0 g
s
.7997 .34541 m .82457 .37102 L .85961 .4137 L p 0 .134 .68 r
F P
0 g
s
.48657 .47657 m .46616 .47508 L .43392 .47305 L p .607 .188 .222 r
F P
0 g
s
.61078 .34359 m .59036 .37442 L .55897 .41316 L p .852 .968 .646 r
F P
0 g
s
.55897 .41316 m .57987 .38189 L .61078 .34359 L p .852 .968 .646 r
F P
0 g
s
.84334 .40297 m .86858 .42655 L .87743 .43923 L closepath p 0 .14 .672 r
F P
0 g
s
.34962 .45246 m .3687 .46701 L .40142 .47066 L p .659 .199 .15 r
F P
0 g
s
.3687 .46701 m .34962 .45246 L .31696 .44801 L p .552 0 0 r
F P
0 g
s
.43392 .47305 m .45401 .48421 L .48657 .47657 L p .607 .188 .222 r
F P
0 g
s
.48657 .47657 m .45401 .48421 L p .49481 .47359 L .464 .025 .118 r
F P
0 g
s
.50729 .47035 m .48912 .47581 L p .49481 .47359 L .464 .025 .118 r
F P
0 g
s
.48912 .47581 m .48657 .47657 L p .49481 .47359 L .464 .025 .118 r
F P
0 g
s
.52816 .45535 m .51233 .46672 L p .51656 .4625 L .253 0 0 r
F P
0 g
s
.45401 .48421 m .47462 .48604 L .50729 .47035 L p .464 .025 .118 r
F P
0 g
s
.5025 .47006 m .52816 .45535 L .49158 .47789 L .253 0 0 r
F
.50729 .47035 m .49158 .47789 L p .51656 .4625 L F P
0 g
s
.51233 .46672 m .50729 .47035 L p .51656 .4625 L .253 0 0 r
F P
0 g
s
.49158 .47789 m .47462 .48604 L p .5025 .47006 L .253 0 0 r
F P
0 g
s
.47462 .48604 m .49558 .4792 L .52816 .45535 L p .253 0 0 r
F P
0 g
s
.51673 .46407 m .53379 .44762 L p .50798 .46847 L 0 0 0 r
F P
0 g
s
.53379 .44762 m .54903 .43291 L p .52369 .45486 L 0 0 0 r
F P
0 g
s
.50798 .46847 m .53379 .44762 L .52369 .45486 L 0 0 0 r
F
.53748 .44405 m .51673 .46407 L p .55085 .42615 L F P
0 g
s
.51673 .46407 m .5379 .44137 L .53914 .43996 L p 0 0 0 r
F P
0 g
s
.55085 .42615 m .56978 .40511 L .53748 .44405 L 0 0 0 r
F
.53914 .43996 m .56978 .40511 L p .53214 .44694 L F P
0 g
s
.51673 .46407 m .53914 .43996 L .53214 .44694 L 0 0 0 r
F
.50798 .46847 m .51519 .46484 L .49558 .4792 L p F P
0 g
s
.54903 .43291 m .52816 .45535 L p .51825 .46261 L 0 0 0 r
F P
0 g
s
.49558 .4792 m .51369 .46624 L p .50798 .46847 L 0 0 0 r
F P
0 g
s
.51369 .46624 m .51673 .46407 L p .50798 .46847 L 0 0 0 r
F P
0 g
s
.56978 .40511 m .54903 .43291 L .53748 .44405 L p 0 0 0 r
F P
0 g
s
.5379 .44137 m .55897 .41316 L .57916 .38824 L p .7 .905 .549 r
F P
0 g
s
.57916 .38824 m .59036 .37442 L p .57167 .39827 L .7 .905 .549 r
F P
0 g
s
.5379 .44137 m .57916 .38824 L .57167 .39827 L .7 .905 .549 r
F
.59036 .37442 m .56978 .40511 L .5379 .44137 L p F P
0 g
s
.45401 .48421 m .43392 .47305 L .40142 .47066 L p .661 .256 .268 r
F P
0 g
s
.31696 .44801 m .33602 .45815 L .3687 .46701 L p .552 0 0 r
F P
0 g
s
.33602 .45815 m .31696 .44801 L .28437 .43947 L p .571 .015 0 r
F P
0 g
s
.83396 .38659 m .85961 .4137 L .86858 .42655 L closepath p 0 .059 .603 r
F P
0 g
s
.28437 .43947 m .30315 .44989 L .33602 .45815 L p .571 .015 0 r
F P
0 g
s
.30315 .44989 m .28437 .43947 L .25138 .43369 L p .38 0 0 r
F P
0 g
s
.40142 .47066 m .4211 .48759 L .45401 .48421 L p .661 .256 .268 r
F P
0 g
s
.4211 .48759 m .40142 .47066 L .3687 .46701 L p .682 .256 .229 r
F P
0 g
s
.25138 .43369 m .27018 .44086 L .30315 .44989 L p .38 0 0 r
F P
0 g
s
.27018 .44086 m .25138 .43369 L .21815 .42815 L p .335 .672 .976 r
F P
0 g
s
.3687 .46701 m .38804 .48502 L .4211 .48759 L p .682 .256 .229 r
F P
0 g
s
.38804 .48502 m .3687 .46701 L .33602 .45815 L p .707 .282 .236 r
F P
0 g
s
.82457 .37102 m .8505 .40066 L .85961 .4137 L closepath p 0 .006 .554 r
F P
0 g
s
.47462 .48604 m .45401 .48421 L .4211 .48759 L p .578 .158 .208 r
F P
0 g
s
.4211 .48759 m .44144 .49665 L .47462 .48604 L p .578 .158 .208 r
F P
0 g
s
.49558 .4792 m .47462 .48604 L .45792 .49138 L p .468 .046 .155 r
F P
0 g
s
.45792 .49138 m .44144 .49665 L p .46841 .48796 L .468 .046 .155 r
F P
0 g
s
.46841 .48796 m .49558 .4792 L .45792 .49138 L .468 .046 .155 r
F
.46229 .49823 m .48351 .49143 L .50037 .47754 L p .297 0 .066 r
F P
0 g
s
.44144 .49665 m .46229 .49823 L .49558 .4792 L p .468 .046 .155 r
F P
0 g
s
.49558 .4792 m .46229 .49823 L p .50571 .47099 L .297 0 .066 r
F P
0 g
s
.51673 .46407 m .49976 .47622 L p .50571 .47099 L .297 0 .066 r
F P
0 g
s
.49976 .47622 m .49558 .4792 L p .50571 .47099 L .297 0 .066 r
F P
0 g
s
.50037 .47754 m .51673 .46407 L p .48974 .48101 L .297 0 .066 r
F P
0 g
s
.46229 .49823 m .50037 .47754 L .48974 .48101 L .297 0 .066 r
F
.51673 .46407 m .51495 .46554 L p .52062 .45949 L .049 0 0 r
F P
0 g
s
.51495 .46554 m .50215 .47608 L p .52062 .45949 L .049 0 0 r
F P
0 g
s
.50215 .47608 m .52934 .44925 L .52062 .45949 L .049 0 0 r
F
.5379 .44137 m .52419 .45607 L p .52934 .44925 L F P
0 g
s
.52419 .45607 m .51673 .46407 L p .52934 .44925 L .049 0 0 r
F P
0 g
s
.50215 .47608 m .48351 .49143 L p .5144 .463 L .049 0 0 r
F P
0 g
s
.5144 .463 m .52934 .44925 L .50215 .47608 L .049 0 0 r
F
.48351 .49143 m .50496 .47618 L .5379 .44137 L p F P
0 g
s
.55897 .41316 m .5379 .44137 L .52529 .45469 L p 0 0 0 r
F P
0 g
s
.52529 .45469 m .50496 .47618 L p .53615 .43979 L 0 0 0 r
F P
0 g
s
.53615 .43979 m .53879 .4367 L .53773 .43811 L 0 0 0 r
F
.53615 .43979 m .53773 .43811 L .52529 .45469 L F
.53879 .4367 m .55897 .41316 L .52529 .45469 L F
.50496 .47618 m .52646 .45328 L .52793 .45146 L p F P
0 g
s
.50496 .47618 m .52793 .45146 L .52201 .45666 L 0 0 0 r
F
.50496 .47618 m .54548 .42981 L .53631 .4396 L F
.48351 .49143 m .46229 .49823 L .44527 .50392 L p .463 .04 .15 r
F P
0 g
s
.44527 .50392 m .42849 .50952 L p .45575 .50056 L .463 .04 .15 r
F P
0 g
s
.45575 .50056 m .48351 .49143 L .44527 .50392 L .463 .04 .15 r
F
.44957 .51102 m .47107 .50416 L .48794 .49024 L p .295 0 .063 r
F P
0 g
s
.42849 .50952 m .44957 .51102 L .48351 .49143 L p .463 .04 .15 r
F P
0 g
s
.48351 .49143 m .4668 .50108 L p .49165 .48486 L .295 0 .063 r
F P
0 g
s
.50496 .47618 m .48617 .48954 L p .49165 .48486 L .295 0 .063 r
F P
0 g
s
.48617 .48954 m .48351 .49143 L p .49165 .48486 L .295 0 .063 r
F P
0 g
s
.4668 .50108 m .44957 .51102 L p .47798 .49315 L .295 0 .063 r
F P
0 g
s
.47798 .49315 m .50496 .47618 L .4668 .50108 L .295 0 .063 r
F
.48794 .49024 m .50496 .47618 L p .47708 .49372 L F P
0 g
s
.52646 .45328 m .50975 .47108 L p .51507 .46427 L .057 0 0 r
F P
0 g
s
.50184 .47589 m .52646 .45328 L .48946 .48898 L .057 0 0 r
F
.50496 .47618 m .48946 .48898 L p .51507 .46427 L F P
0 g
s
.50975 .47108 m .50496 .47618 L p .51507 .46427 L .057 0 0 r
F P
0 g
s
.50273 .47508 m .50195 .47617 L .52646 .45328 L .057 0 0 r
F
.51069 .46997 m .52646 .45328 L p .50195 .47617 L F P
0 g
s
.52793 .45146 m .54548 .42981 L p .52201 .45666 L 0 0 0 r
F P
0 g
s
.49282 .48889 m .50653 .47292 L p .50195 .47617 L .057 0 0 r
F P
0 g
s
.54548 .42981 m .55897 .41316 L p .53631 .4396 L 0 0 0 r
F P
0 g
s
.55422 .41902 m .52646 .45328 L p .56155 .40637 L 0 0 0 r
F P
0 g
s
.56155 .40637 m .57209 .39228 L .56803 .39836 L 0 0 0 r
F
.56155 .40637 m .56803 .39836 L .55422 .41902 L F
.54787 .42474 m .55231 .41881 L p .55056 .42113 L F P
0 g
s
.52646 .45328 m .54787 .42474 L p .55056 .42113 L 0 0 0 r
F P
0 g
s
.55231 .41881 m .56853 .39708 L p .54672 .42621 L 0 0 0 r
F P
0 g
s
.52646 .45328 m .55231 .41881 L .54672 .42621 L 0 0 0 r
F
.52646 .45328 m .56853 .39708 L .5607 .40751 L F
.52646 .45328 m .49282 .48889 L p .51815 .45938 L F P
0 g
s
.54787 .42474 m .5335 .4439 L p .51815 .45938 L 0 0 0 r
F P
0 g
s
.5335 .4439 m .52646 .45328 L p .51815 .45938 L 0 0 0 r
F P
0 g
s
.44957 .51102 m .48794 .49024 L .47708 .49372 L .295 0 .063 r
F
.48946 .48898 m .47107 .50416 L p .50184 .47589 L .057 0 0 r
F P
0 g
s
.49282 .48889 m .51466 .46595 L .51649 .46368 L p 0 0 0 r
F P
0 g
s
.49282 .48889 m .51649 .46368 L .5089 .47015 L 0 0 0 r
F
.47107 .50416 m .48336 .49554 L p .50273 .47508 L .057 0 0 r
F P
0 g
s
.48336 .49554 m .49282 .48889 L p .50273 .47508 L .057 0 0 r
F P
0 g
s
.44957 .51102 m .42849 .50952 L .39451 .51105 L p .565 .122 .157 r
F P
0 g
s
.39451 .51105 m .41524 .51975 L .44957 .51102 L p .565 .122 .157 r
F P
0 g
s
.47107 .50416 m .44957 .51102 L .43215 .51545 L p .44 0 .088 r
F P
0 g
s
.43215 .51545 m .41524 .51975 L p .44269 .51209 L .44 0 .088 r
F P
0 g
s
.44269 .51209 m .47107 .50416 L .43215 .51545 L .44 0 .088 r
F
.41524 .51975 m .43655 .52104 L .47107 .50416 L p F P
0 g
s
.47107 .50416 m .45364 .51268 L p .47817 .49779 L .247 0 0 r
F P
0 g
s
.49282 .48889 m .47143 .50391 L p .47817 .49779 L .247 0 0 r
F P
0 g
s
.47143 .50391 m .47107 .50416 L p .47817 .49779 L .247 0 0 r
F P
0 g
s
.45364 .51268 m .43655 .52104 L p .46492 .50483 L .247 0 0 r
F P
0 g
s
.46492 .50483 m .49282 .48889 L .45364 .51268 L .247 0 0 r
F
.47535 .50166 m .49282 .48889 L p .46429 .50519 L F P
0 g
s
.43655 .52104 m .45831 .51412 L .47535 .50166 L p .247 0 0 r
F P
0 g
s
.43655 .52104 m .47535 .50166 L .46429 .50519 L .247 0 0 r
F
.51466 .46595 m .49282 .48889 L .45831 .51412 L p 0 0 0 r
F P
0 g
s
.49481 .48292 m .49214 .48588 L .51466 .46595 L 0 0 0 r
F
.48035 .49895 m .49867 .48133 L p .49214 .48588 L F P
0 g
s
.49867 .48133 m .51466 .46595 L p .49214 .48588 L 0 0 0 r
F P
0 g
s
.53425 .44165 m .54787 .42474 L p .52746 .44853 L 0 0 0 r
F P
0 g
s
.52477 .45167 m .52583 .45054 L .52746 .44853 L 0 0 0 r
F
.52583 .45054 m .53425 .44165 L .52746 .44853 L F
.5089 .47015 m .51619 .46394 L .52657 .45029 L F
.51619 .46394 m .51649 .46368 L .52657 .45029 L F
.51649 .46368 m .53425 .44165 L p .52657 .45029 L F P
0 g
s
.5089 .47015 m .53425 .44165 L .52477 .45167 L 0 0 0 r
F
.51466 .46595 m .54093 .43076 L .5444 .42775 L F
.56913 .39296 m .55469 .41456 L p .54093 .43076 L F P
0 g
s
.55469 .41456 m .54787 .42474 L p .54093 .43076 L 0 0 0 r
F P
0 g
s
.53644 .43729 m .54155 .43037 L p .54033 .43198 L 0 0 0 r
F P
0 g
s
.51466 .46595 m .53644 .43729 L p .54033 .43198 L 0 0 0 r
F P
0 g
s
.54155 .43037 m .56913 .39296 L p .53407 .43995 L 0 0 0 r
F P
0 g
s
.51466 .46595 m .54155 .43037 L .53407 .43995 L 0 0 0 r
F
.53644 .43729 m .55807 .40522 L .58472 .36822 L p .697 .882 .497 r
F P
0 g
s
.58472 .36822 m .5902 .3606 L p .58057 .37435 L .697 .882 .497 r
F P
0 g
s
.53644 .43729 m .58472 .36822 L .58057 .37435 L .697 .882 .497 r
F
.54787 .42474 m .53886 .43592 L p .5444 .42775 L 0 0 0 r
F P
0 g
s
.53886 .43592 m .51466 .46595 L p .5444 .42775 L 0 0 0 r
F P
0 g
s
.53644 .43729 m .51466 .46595 L .49874 .48127 L p 0 0 0 r
F P
0 g
s
.49874 .48127 m .48035 .49895 L p .50197 .4752 L 0 0 0 r
F P
0 g
s
.50197 .4752 m .50612 .47179 L .49874 .48127 L 0 0 0 r
F
.50197 .4752 m .51246 .46366 L .50612 .47179 L F
.51246 .46366 m .53644 .43729 L .49874 .48127 L F
.49681 .48086 m .5036 .4747 L .52025 .45509 L F
.48035 .49895 m .50252 .47624 L .50486 .47355 L p F P
0 g
s
.48035 .49895 m .50486 .47355 L .49681 .48086 L 0 0 0 r
F
.45831 .51412 m .47583 .50207 L p .49481 .48292 L F P
0 g
s
.47583 .50207 m .48035 .49895 L p .49481 .48292 L 0 0 0 r
F P
0 g
s
.41524 .51975 m .39451 .51105 L .36062 .50298 L p .63 .146 .084 r
F P
0 g
s
.36062 .50298 m .38091 .51635 L .41524 .51975 L p .63 .146 .084 r
F P
0 g
s
.43655 .52104 m .41524 .51975 L .40021 .51826 L p .538 .043 .029 r
F P
0 g
s
.40021 .51826 m .38091 .51635 L p .3934 .5174 L .538 .043 .029 r
F P
0 g
s
.3934 .5174 m .43655 .52104 L .40021 .51826 L .538 .043 .029 r
F
.3469 .50178 m .36735 .51369 L .36964 .5144 L p .568 .001 0 r
F P
0 g
s
.38091 .51635 m .36062 .50298 L .32706 .48664 L p .644 .096 0 r
F P
0 g
s
.32706 .48664 m .3469 .50178 L .38091 .51635 L p .644 .096 0 r
F P
0 g
s
.38091 .51635 m .40183 .52434 L .43655 .52104 L p .538 .043 .029 r
F P
0 g
s
.40183 .52434 m .38091 .51635 L .35207 .504 L p .568 .001 0 r
F P
0 g
s
.35207 .504 m .3469 .50178 L p .35183 .50381 L .568 .001 0 r
F P
0 g
s
.35183 .50381 m .40183 .52434 L .35207 .504 L .568 .001 0 r
F
.3469 .50178 m .32706 .48664 L .2939 .46451 L p .449 0 0 r
F P
0 g
s
.2939 .46451 m .3134 .47861 L .3469 .50178 L p .449 0 0 r
F P
0 g
s
.3134 .47861 m .33341 .49141 L .34932 .50185 L p 0 .188 .618 r
F P
0 g
s
.3469 .50178 m .36964 .5144 L .38117 .51585 L .568 .001 0 r
F
.34932 .50185 m .36735 .51369 L p .35019 .50253 L 0 .188 .618 r
F P
0 g
s
.3134 .47861 m .34932 .50185 L .35019 .50253 L 0 .188 .618 r
F
.36964 .5144 m .40183 .52434 L p .38117 .51585 L .568 .001 0 r
F P
0 g
s
.45831 .51412 m .43655 .52104 L .41874 .52273 L p .371 0 0 r
F P
0 g
s
.41874 .52273 m .40183 .52434 L p .42928 .51937 L .371 0 0 r
F P
0 g
s
.42928 .51937 m .45831 .51412 L .41874 .52273 L .371 0 0 r
F
.40183 .52434 m .42334 .52521 L .45831 .51412 L p F P
0 g
s
.48035 .49895 m .45831 .51412 L .44009 .5199 L p .11 0 0 r
F P
0 g
s
.44009 .5199 m .42334 .52521 L p .45143 .51227 L .11 0 0 r
F P
0 g
s
.45143 .51227 m .48035 .49895 L .44009 .5199 L .11 0 0 r
F
.42334 .52521 m .44532 .51822 L .46243 .50881 L p F P
0 g
s
.46243 .50881 m .48035 .49895 L p .45112 .51242 L .11 0 0 r
F P
0 g
s
.42334 .52521 m .46243 .50881 L .45112 .51242 L .11 0 0 r
F
.46242 .50881 m .44532 .51822 L p .47499 .49645 L 0 0 0 r
F P
0 g
s
.47499 .49645 m .50252 .47624 L .46242 .50881 L 0 0 0 r
F
.44532 .51822 m .4675 .50341 L .48082 .49251 L F
.44532 .51822 m .48082 .49251 L .47525 .49626 L F
.4675 .50341 m .46762 .50333 L p .48486 .4892 L F P
0 g
s
.46762 .50333 m .49007 .48119 L .51105 .46094 L p .528 .842 .535 r
F P
0 g
s
.51105 .46094 m .52465 .44781 L p .50081 .47102 L .528 .842 .535 r
F P
0 g
s
.46762 .50333 m .51105 .46094 L .50081 .47102 L .528 .842 .535 r
F
.50252 .47624 m .48035 .49895 L .46242 .50881 L p 0 0 0 r
F P
0 g
s
.47525 .49626 m .48082 .49251 L .48486 .4892 L 0 0 0 r
F
.46762 .50333 m .50252 .47624 L p .48486 .4892 L F P
0 g
s
.5036 .4747 m .50486 .47355 L .52025 .45509 L 0 0 0 r
F
.50252 .47624 m .52465 .44781 L .54681 .41958 L p .571 .82 .446 r
F P
0 g
s
.54681 .41958 m .55807 .40522 L p .5381 .43075 L .571 .82 .446 r
F P
0 g
s
.50252 .47624 m .54681 .41958 L .5381 .43075 L .571 .82 .446 r
F
.50486 .47355 m .53644 .43729 L p .52025 .45509 L 0 0 0 r
F P
0 g
s
.57209 .39228 m .57987 .38189 L .55422 .41902 L 0 0 0 r
F
.56853 .39708 m .57987 .38189 L p .5607 .40751 L F P
0 g
s
.57987 .38189 m .55897 .41316 L .55422 .41902 L p 0 0 0 r
F P
0 g
s
.54787 .42474 m .56913 .39296 L .596 .35651 L p .747 .913 .541 r
F P
0 g
s
.596 .35651 m .60059 .35028 L p .59293 .36111 L .747 .913 .541 r
F P
0 g
s
.54787 .42474 m .596 .35651 L .59293 .36111 L .747 .913 .541 r
F
.60059 .35028 m .57987 .38189 L .54787 .42474 L p F P
0 g
s
.21815 .42815 m .23727 .42946 L .27018 .44086 L p .335 .672 .976 r
F P
0 g
s
.23727 .42946 m .21815 .42815 L .18488 .42094 L p .447 .723 .984 r
F P
0 g
s
.33602 .45815 m .3549 .47878 L .38804 .48502 L p .707 .282 .236 r
F P
0 g
s
.3549 .47878 m .33602 .45815 L .30315 .44989 L p .708 .244 .149 r
F P
0 g
s
.30315 .44989 m .32179 .46851 L .3549 .47878 L p .708 .244 .149 r
F P
0 g
s
.32179 .46851 m .30315 .44989 L .27018 .44086 L p .611 .046 0 r
F P
0 g
s
.18488 .42094 m .20405 .42002 L .23727 .42946 L p .447 .723 .984 r
F P
0 g
s
.20405 .42002 m .18488 .42094 L .15127 .41494 L p .571 .734 .952 r
F P
0 g
s
.27018 .44086 m .28886 .45409 L .32179 .46851 L p .611 .046 0 r
F P
0 g
s
.28886 .45409 m .27018 .44086 L .23727 .42946 L p .373 0 0 r
F P
0 g
s
.44144 .49665 m .4211 .48759 L .38804 .48502 L p .647 .233 .244 r
F P
0 g
s
.15127 .41494 m .17061 .41124 L .20405 .42002 L p .571 .734 .952 r
F P
0 g
s
.17061 .41124 m .15127 .41494 L .11744 .40889 L p .634 .723 .912 r
F P
0 g
s
.23727 .42946 m .25595 .4389 L .28886 .45409 L p .373 0 0 r
F P
0 g
s
.25595 .4389 m .23727 .42946 L .20405 .42002 L p .167 .573 .935 r
F P
0 g
s
.20405 .42002 m .22296 .4242 L .25595 .4389 L p .167 .573 .935 r
F P
0 g
s
.22296 .4242 m .20405 .42002 L .17061 .41124 L p .494 .667 .94 r
F P
0 g
s
.11744 .40889 m .13696 .40282 L .17061 .41124 L p .634 .723 .912 r
F P
0 g
s
.13696 .40282 m .11744 .40889 L .0834 .40269 L p .645 .745 .922 r
F P
0 g
s
.38804 .48502 m .40795 .50053 L .44144 .49665 L p .647 .233 .244 r
F P
0 g
s
.40795 .50053 m .38804 .48502 L .3549 .47878 L p .683 .25 .214 r
F P
0 g
s
.17061 .41124 m .18985 .41036 L .22296 .4242 L p .494 .667 .94 r
F P
0 g
s
.18985 .41036 m .17061 .41124 L .13696 .40282 L p .587 .691 .914 r
F P
0 g
s
.3549 .47878 m .37438 .49696 L .40795 .50053 L p .683 .25 .214 r
F P
0 g
s
.37438 .49696 m .3549 .47878 L .32179 .46851 L p .698 .219 .109 r
F P
0 g
s
.0834 .40269 m .10291 .39608 L .13696 .40282 L p .645 .745 .922 r
F P
0 g
s
.10291 .39608 m .0834 .40269 L .04909 .39682 L p .656 .746 .916 r
F P
0 g
s
.13696 .40282 m .15641 .39878 L .18985 .41036 L p .587 .691 .914 r
F P
0 g
s
.15641 .39878 m .13696 .40282 L .10291 .39608 L p .633 .718 .909 r
F P
0 g
s
.46229 .49823 m .44144 .49665 L .40795 .50053 L p .573 .152 .204 r
F P
0 g
s
.5902 .3606 m .56913 .39296 L .53644 .43729 L p .697 .882 .497 r
F P
0 g
s
.32179 .46851 m .34094 .48629 L .37438 .49696 L p .698 .219 .109 r
F P
0 g
s
.34094 .48629 m .32179 .46851 L .28886 .45409 L p .675 .139 0 r
F P
0 g
s
.28886 .45409 m .30774 .47026 L .34094 .48629 L p .675 .139 0 r
F P
0 g
s
.30774 .47026 m .28886 .45409 L .25595 .4389 L p .448 0 0 r
F P
0 g
s
.25595 .4389 m .27478 .451 L .30774 .47026 L p .448 0 0 r
F P
0 g
s
.27478 .451 m .25595 .4389 L .2313 .42791 L p .119 .488 .901 r
F P
0 g
s
.24188 .43398 m .27478 .451 L .2313 .42791 L .119 .488 .901 r
F
.2313 .42791 m .22296 .4242 L p .24188 .43398 L F P
0 g
s
.22296 .4242 m .24194 .43087 L .27478 .451 L p .119 .488 .901 r
F P
0 g
s
.2939 .46451 m .27478 .451 L .24194 .43087 L p .043 .406 .858 r
F P
0 g
s
.32706 .48664 m .30774 .47026 L .27478 .451 L p .453 0 0 r
F P
0 g
s
.2939 .46451 m .32706 .48664 L p .2803 .45476 L .453 0 0 r
F P
0 g
s
.27478 .451 m .2939 .46451 L p .2803 .45476 L .453 0 0 r
F P
0 g
s
.2939 .46451 m .26104 .44003 L p .30775 .47444 L .033 .369 .838 r
F P
0 g
s
.3134 .47861 m .2939 .46451 L p .30775 .47444 L .033 .369 .838 r
F P
0 g
s
.24194 .43087 m .26104 .44003 L .28986 .4615 L p .043 .406 .858 r
F P
0 g
s
.28986 .4615 m .2939 .46451 L p .28454 .45845 L .043 .406 .858 r
F P
0 g
s
.24194 .43087 m .28986 .4615 L .28454 .45845 L .043 .406 .858 r
F
.04909 .39682 m .0686 .38965 L .10291 .39608 L p .656 .746 .916 r
F P
0 g
s
.24194 .43087 m .22296 .4242 L .18985 .41036 L p .42 .598 .918 r
F P
0 g
s
.10291 .39608 m .12251 .38995 L .15641 .39878 L p .633 .718 .909 r
F P
0 g
s
.12251 .38995 m .10291 .39608 L .0686 .38965 L p .655 .729 .904 r
F P
0 g
s
.18985 .41036 m .20904 .41214 L .24194 .43087 L p .42 .598 .918 r
F P
0 g
s
.20904 .41214 m .18985 .41036 L .15641 .39878 L p .553 .64 .891 r
F P
0 g
s
.15641 .39878 m .17587 .3963 L .20904 .41214 L p .553 .64 .891 r
F P
0 g
s
.17587 .3963 m .15641 .39878 L .12251 .38995 L p .624 .674 .878 r
F P
0 g
s
.0686 .38965 m .08827 .38242 L .12251 .38995 L p .655 .729 .904 r
F P
0 g
s
.40795 .50053 m .42849 .50952 L .46229 .49823 L p .573 .152 .204 r
F P
0 g
s
.42849 .50952 m .40795 .50053 L .37438 .49696 L p .637 .196 .186 r
F P
0 g
s
.12251 .38995 m .14224 .38413 L .17587 .3963 L p .624 .674 .878 r
F P
0 g
s
.14224 .38413 m .12251 .38995 L .08827 .38242 L p .653 .708 .888 r
F P
0 g
s
.26104 .44003 m .24194 .43087 L .20904 .41214 L p .372 .532 .885 r
F P
0 g
s
.20904 .41214 m .22829 .41618 L .26104 .44003 L p .372 .532 .885 r
F P
0 g
s
.22829 .41618 m .20904 .41214 L .17587 .3963 L p .524 .585 .859 r
F P
0 g
s
.08827 .38242 m .10809 .37513 L .14224 .38413 L p .653 .708 .888 r
F P
0 g
s
.17587 .3963 m .19539 .39536 L .22829 .41618 L p .524 .585 .859 r
F P
0 g
s
.19539 .39536 m .17587 .3963 L .14224 .38413 L p .603 .63 .851 r
F P
0 g
s
.37438 .49696 m .39451 .51105 L .42849 .50952 L p .637 .196 .186 r
F P
0 g
s
.39451 .51105 m .37438 .49696 L .34094 .48629 L p .678 .201 .111 r
F P
0 g
s
.14224 .38413 m .16203 .3792 L .19539 .39536 L p .603 .63 .851 r
F P
0 g
s
.16203 .3792 m .14224 .38413 L .10809 .37513 L p .648 .676 .863 r
F P
0 g
s
.34094 .48629 m .36062 .50298 L .39451 .51105 L p .678 .201 .111 r
F P
0 g
s
.36062 .50298 m .34094 .48629 L .30774 .47026 L p .672 .132 0 r
F P
0 g
s
.30774 .47026 m .32706 .48664 L .36062 .50298 L p .672 .132 0 r
F P
0 g
s
.10809 .37513 m .12806 .36779 L .16203 .3792 L p .648 .676 .863 r
F P
0 g
s
.57951 .37231 m .55807 .40522 L .52465 .44781 L p .73 .908 .538 r
F P
0 g
s
.52465 .44781 m .54665 .41586 L .57951 .37231 L p .73 .908 .538 r
F P
0 g
s
.24768 .42203 m .22829 .41618 L .19539 .39536 L p .497 .535 .826 r
F P
0 g
s
.19539 .39536 m .21498 .39599 L .24768 .42203 L p .497 .535 .826 r
F P
0 g
s
.21498 .39599 m .19539 .39536 L .16203 .3792 L p .583 .585 .82 r
F P
0 g
s
.16203 .3792 m .18191 .37518 L .21498 .39599 L p .583 .585 .82 r
F P
0 g
s
.18191 .37518 m .16203 .3792 L .12806 .36779 L p .64 .637 .831 r
F P
0 g
s
.28039 .4507 m .26104 .44003 L .22829 .41618 L p .346 .48 .852 r
F P
0 g
s
.22829 .41618 m .24768 .42203 L .28039 .4507 L p .346 .48 .852 r
F P
0 g
s
.12806 .36779 m .1482 .36038 L .18191 .37518 L p .64 .637 .831 r
F P
0 g
s
.26104 .44003 m .28039 .4507 L .3134 .47861 L p .033 .369 .838 r
F P
0 g
s
.55807 .40522 m .53644 .43729 L .50252 .47624 L p .571 .82 .446 r
F P
0 g
s
.77733 .30905 m .74319 .28337 L p .7685 .30419 L .049 .342 .82 r
F P
0 g
s
.77733 .30905 m .80295 .33253 L .81274 .34656 L closepath p 0 .14 .672 r
F P
0 g
s
.80295 .33253 m .78375 .31494 L p .7685 .30419 L .049 .342 .82 r
F P
0 g
s
.78375 .31494 m .77733 .30905 L p .7685 .30419 L .049 .342 .82 r
F P
0 g
s
.74319 .28337 m .76768 .29919 L .80295 .33253 L p .049 .342 .82 r
F P
0 g
s
.74319 .28337 m .71008 .27158 L p .73464 .28335 L .265 .541 .922 r
F P
0 g
s
.76768 .29919 m .75053 .28811 L p .73464 .28335 L .265 .541 .922 r
F P
0 g
s
.75053 .28811 m .74319 .28337 L p .73464 .28335 L .265 .541 .922 r
F P
0 g
s
.71008 .27158 m .73035 .27731 L p .74803 .28977 L .265 .541 .922 r
F P
0 g
s
.73035 .27731 m .73361 .27823 L p .74803 .28977 L .265 .541 .922 r
F P
0 g
s
.73361 .27823 m .71008 .27158 L .67757 .27376 L p .533 .758 .979 r
F P
0 g
s
.70038 .2705 m .73361 .27823 L p .71172 .27648 L .533 .758 .979 r
F P
0 g
s
.67757 .27376 m .69455 .27134 L p .71172 .27648 L .533 .758 .979 r
F P
0 g
s
.69455 .27134 m .70038 .2705 L p .71172 .27648 L .533 .758 .979 r
F P
0 g
s
.73361 .27823 m .76768 .29919 L p .74803 .28977 L .265 .541 .922 r
F P
0 g
s
.23472 .39776 m .21498 .39599 L .18191 .37518 L p .568 .543 .787 r
F P
0 g
s
.18191 .37518 m .2019 .37187 L .23472 .39776 L p .568 .543 .787 r
F P
0 g
s
.2019 .37187 m .18191 .37518 L .1482 .36038 L p .63 .596 .796 r
F P
0 g
s
.1482 .36038 m .1685 .35292 L .2019 .37187 L p .63 .596 .796 r
F P
0 g
s
.26731 .42889 m .24768 .42203 L .21498 .39599 L p .483 .495 .794 r
F P
0 g
s
.21498 .39599 m .23472 .39776 L .26731 .42889 L p .483 .495 .794 r
F P
0 g
s
.61174 .32305 m .59014 .35119 L .56861 .37622 L p .899 .983 .716 r
F P
0 g
s
.56861 .37622 m .55705 .38966 L p .5762 .36634 L .899 .983 .716 r
F P
0 g
s
.5762 .36634 m .61174 .32305 L .56861 .37622 L .899 .983 .716 r
F
.57907 .35814 m .60101 .32958 L .61231 .31931 L p .902 .986 .767 r
F P
0 g
s
.55705 .38966 m .57907 .35814 L .61174 .32305 L p .899 .983 .716 r
F P
0 g
s
.6334 .30014 m .61174 .32305 L .5986 .33716 L p .902 .986 .767 r
F P
0 g
s
.60101 .32958 m .62296 .30561 L .63846 .29506 L p .881 .98 .83 r
F P
0 g
s
.5986 .33716 m .59093 .3454 L p .6334 .30014 L .902 .986 .767 r
F P
0 g
s
.60003 .33576 m .6334 .30014 L .59093 .3454 L .902 .986 .767 r
F
.59093 .3454 m .57907 .35814 L p .60003 .33576 L F P
0 g
s
.61231 .31931 m .6334 .30014 L p .59806 .33786 L .902 .986 .767 r
F P
0 g
s
.57907 .35814 m .61231 .31931 L .59806 .33786 L .902 .986 .767 r
F
.65529 .28359 m .6334 .30014 L .61281 .31885 L p .881 .98 .83 r
F P
0 g
s
.61281 .31885 m .60101 .32958 L p .62294 .311 L .881 .98 .83 r
F P
0 g
s
.62294 .311 m .65529 .28359 L .61281 .31885 L .881 .98 .83 r
F
.63846 .29506 m .65529 .28359 L p .62528 .30902 L F P
0 g
s
.60101 .32958 m .63846 .29506 L .62528 .30902 L .881 .98 .83 r
F
.67757 .27376 m .65529 .28359 L .6342 .29796 L p .827 .957 .898 r
F P
0 g
s
.6342 .29796 m .62296 .30561 L p .64486 .29284 L .827 .957 .898 r
F P
0 g
s
.64486 .29284 m .67757 .27376 L .6342 .29796 L .827 .957 .898 r
F
.62296 .30561 m .64509 .2873 L .66332 .2797 L p F P
0 g
s
.66332 .2797 m .67757 .27376 L p .65096 .28928 L .827 .957 .898 r
F P
0 g
s
.62296 .30561 m .66332 .2797 L .65096 .28928 L .827 .957 .898 r
F
.70038 .2705 m .67757 .27376 L .64509 .2873 L p .736 .896 .951 r
F P
0 g
s
.64509 .2873 m .66752 .27498 L .68781 .27222 L p .736 .896 .951 r
F P
0 g
s
.68781 .27222 m .70038 .2705 L p .67586 .27795 L .736 .896 .951 r
F P
0 g
s
.64509 .2873 m .68781 .27222 L .67586 .27795 L .736 .896 .951 r
F
.30011 .4616 m .28039 .4507 L .24768 .42203 L p .347 .449 .823 r
F P
0 g
s
.24768 .42203 m .26731 .42889 L .30011 .4616 L p .347 .449 .823 r
F P
0 g
s
.22206 .36908 m .2019 .37187 L .1685 .35292 L p .619 .558 .764 r
F P
0 g
s
.1685 .35292 m .18896 .3454 L .22206 .36908 L p .619 .558 .764 r
F P
0 g
s
.25469 .40013 m .23472 .39776 L .2019 .37187 L p .557 .509 .757 r
F P
0 g
s
.2019 .37187 m .22206 .36908 L .25469 .40013 L p .557 .509 .757 r
F P
0 g
s
.59014 .35119 m .56847 .38282 L .53487 .42222 L p .876 .978 .678 r
F P
0 g
s
.53487 .42222 m .55705 .38966 L .59014 .35119 L p .876 .978 .678 r
F P
0 g
s
.33341 .49141 m .3134 .47861 L .28039 .4507 L p .08 .375 .839 r
F P
0 g
s
.28039 .4507 m .30011 .4616 L .33341 .49141 L p .08 .375 .839 r
F P
0 g
s
.28729 .4358 m .26731 .42889 L .23472 .39776 L p .481 .468 .766 r
F P
0 g
s
.23472 .39776 m .25469 .40013 L .28729 .4358 L p .481 .468 .766 r
F P
0 g
s
.24242 .36654 m .22206 .36908 L .18896 .3454 L p .609 .526 .735 r
F P
0 g
s
.18896 .3454 m .20958 .33782 L .24242 .36654 L p .609 .526 .735 r
F P
0 g
s
.76768 .29919 m .79301 .31829 L .80295 .33253 L closepath p 0 .245 .755 r
F P
0 g
s
.76768 .29919 m .73361 .27823 L p .75831 .29489 L .183 .438 .868 r
F P
0 g
s
.79301 .31829 m .77401 .30396 L p .75831 .29489 L .183 .438 .868 r
F P
0 g
s
.77401 .30396 m .76768 .29919 L p .75831 .29489 L .183 .438 .868 r
F P
0 g
s
.73361 .27823 m .7579 .28957 L .79301 .31829 L p .183 .438 .868 r
F P
0 g
s
.73361 .27823 m .70038 .2705 L p .72498 .27866 L .39 .627 .948 r
F P
0 g
s
.7579 .28957 m .74142 .28188 L p .72498 .27866 L .39 .627 .948 r
F P
0 g
s
.74142 .28188 m .73361 .27823 L p .72498 .27866 L .39 .627 .948 r
F P
0 g
s
.70038 .2705 m .71977 .27262 L p .73725 .28273 L .39 .627 .948 r
F P
0 g
s
.71977 .27262 m .72383 .27307 L p .73725 .28273 L .39 .627 .948 r
F P
0 g
s
.72383 .27307 m .70038 .2705 L .66752 .27498 L p .617 .799 .969 r
F P
0 g
s
.6904 .26853 m .72383 .27307 L p .70049 .27386 L .617 .799 .969 r
F P
0 g
s
.66752 .27498 m .68337 .27051 L p .70049 .27386 L .617 .799 .969 r
F P
0 g
s
.68337 .27051 m .6904 .26853 L p .70049 .27386 L .617 .799 .969 r
F P
0 g
s
.72383 .27307 m .7579 .28957 L p .73725 .28273 L .39 .627 .948 r
F P
0 g
s
.56847 .38282 m .54665 .41586 L .51253 .45348 L p .821 .965 .644 r
F P
0 g
s
.51253 .45348 m .53487 .42222 L .56847 .38282 L p .821 .965 .644 r
F P
0 g
s
.27495 .40245 m .25469 .40013 L .22206 .36908 L p .551 .482 .731 r
F P
0 g
s
.22206 .36908 m .24242 .36654 L .27495 .40245 L p .551 .482 .731 r
F P
0 g
s
.36735 .51369 m .3469 .50178 L .3134 .47861 L p 0 .188 .618 r
F P
0 g
s
.32031 .47126 m .30011 .4616 L .26731 .42889 L p .37 .439 .802 r
F P
0 g
s
.26731 .42889 m .28729 .4358 L .32031 .47126 L p .37 .439 .802 r
F P
0 g
s
.26301 .3639 m .24242 .36654 L .20958 .33782 L p .6 .5 .712 r
F P
0 g
s
.20958 .33782 m .23038 .33017 L .26301 .3639 L p .6 .5 .712 r
F P
0 g
s
.54665 .41586 m .52465 .44781 L .49007 .48119 L p .717 .932 .604 r
F P
0 g
s
.49007 .48119 m .51253 .45348 L .54665 .41586 L p .717 .932 .604 r
F P
0 g
s
.30768 .44165 m .28729 .4358 L .25469 .40013 L p .488 .453 .745 r
F P
0 g
s
.25469 .40013 m .27495 .40245 L .30768 .44165 L p .488 .453 .745 r
F P
0 g
s
.61213 .30747 m .6345 .28808 L .65166 .28127 L p .841 .935 .889 r
F P
0 g
s
.64509 .2873 m .62296 .30561 L .60264 .32167 L p .889 .955 .839 r
F P
0 g
s
.61269 .31338 m .64509 .2873 L .60264 .32167 L .889 .955 .839 r
F
.58987 .33176 m .61213 .30747 L .64509 .2873 L p F P
0 g
s
.66752 .27498 m .64509 .2873 L .62395 .30024 L p .841 .935 .889 r
F P
0 g
s
.62395 .30024 m .61213 .30747 L p .6346 .29429 L .841 .935 .889 r
F P
0 g
s
.6346 .29429 m .66752 .27498 L .62395 .30024 L .841 .935 .889 r
F
.6345 .28808 m .65712 .27388 L .67685 .27071 L p .768 .888 .93 r
F P
0 g
s
.65166 .28127 m .66752 .27498 L p .63897 .29173 L .841 .935 .889 r
F P
0 g
s
.61213 .30747 m .65166 .28127 L .63897 .29173 L .841 .935 .889 r
F
.6904 .26853 m .66752 .27498 L .6345 .28808 L p .768 .888 .93 r
F P
0 g
s
.67685 .27071 m .6904 .26853 L p .66457 .27756 L .768 .888 .93 r
F P
0 g
s
.6345 .28808 m .67685 .27071 L .66457 .27756 L .768 .888 .93 r
F
.60264 .32167 m .58987 .33176 L p .61269 .31338 L .889 .955 .839 r
F P
0 g
s
.62296 .30561 m .60101 .32958 L .56761 .35994 L p .914 .965 .797 r
F P
0 g
s
.56761 .35994 m .58987 .33176 L .62296 .30561 L p .914 .965 .797 r
F P
0 g
s
.29557 .40396 m .27495 .40245 L .24242 .36654 L p .55 .465 .712 r
F P
0 g
s
.24242 .36654 m .26301 .3639 L .29557 .40396 L p .55 .465 .712 r
F P
0 g
s
.28387 .36081 m .26301 .3639 L .23038 .33017 L p .593 .48 .694 r
F P
0 g
s
.23038 .33017 m .25134 .32247 L .28387 .36081 L p .593 .48 .694 r
F P
0 g
s
.52465 .44781 m .50252 .47624 L .46762 .50333 L p .528 .842 .535 r
F P
0 g
s
.60101 .32958 m .57907 .35814 L .54526 .39055 L p .923 .97 .769 r
F P
0 g
s
.54526 .39055 m .56761 .35994 L .60101 .32958 L p .923 .97 .769 r
F P
0 g
s
.35401 .50119 m .33341 .49141 L .30011 .4616 L p .176 .417 .854 r
F P
0 g
s
.30011 .4616 m .32031 .47126 L .35401 .50119 L p .176 .417 .854 r
F P
0 g
s
.7579 .28957 m .78292 .30384 L .79301 .31829 L closepath p .016 .367 .836 r
F P
0 g
s
.7579 .28957 m .72383 .27307 L p .74812 .28571 L .315 .528 .902 r
F P
0 g
s
.78292 .30384 m .7643 .29322 L p .74812 .28571 L .315 .528 .902 r
F P
0 g
s
.7643 .29322 m .7579 .28957 L p .74812 .28571 L .315 .528 .902 r
F P
0 g
s
.72383 .27307 m .74794 .27983 L .78292 .30384 L p .315 .528 .902 r
F P
0 g
s
.74794 .27983 m .72383 .27307 L .6904 .26853 L p .499 .692 .954 r
F P
0 g
s
.71381 .26724 m .74794 .27983 L p .72622 .27556 L .499 .692 .954 r
F P
0 g
s
.6904 .26853 m .70886 .26751 L p .72622 .27556 L .499 .692 .954 r
F P
0 g
s
.70886 .26751 m .71381 .26724 L p .72622 .27556 L .499 .692 .954 r
F P
0 g
s
.57907 .35814 m .55705 .38966 L .52276 .42183 L p .921 .976 .757 r
F P
0 g
s
.52276 .42183 m .54526 .39055 L .57907 .35814 L p .921 .976 .757 r
F P
0 g
s
.30502 .35691 m .28387 .36081 L .25134 .32247 L p .588 .466 .681 r
F P
0 g
s
.25134 .32247 m .27247 .3147 L .30502 .35691 L p .588 .466 .681 r
F P
0 g
s
.33341 .49141 m .35401 .50119 L .36425 .50694 L p 0 .341 .757 r
F P
0 g
s
.42334 .52521 m .40183 .52434 L .38004 .51761 L p .417 0 0 r
F P
0 g
s
.37726 .51573 m .42334 .52521 L .38004 .51761 L .417 0 0 r
F
.38004 .51761 m .36735 .51369 L p .37726 .51573 L F P
0 g
s
.36735 .51369 m .38843 .52053 L .42334 .52521 L p .417 0 0 r
F P
0 g
s
.36425 .50694 m .38843 .52053 L p .36964 .51058 L 0 .341 .757 r
F P
0 g
s
.33341 .49141 m .36425 .50694 L .36964 .51058 L 0 .341 .757 r
F
.34104 .47828 m .32031 .47126 L .28729 .4358 L p .41 .447 .788 r
F P
0 g
s
.28729 .4358 m .30768 .44165 L .34104 .47828 L p .41 .447 .788 r
F P
0 g
s
.38843 .52053 m .36735 .51369 L .33341 .49141 L p 0 .341 .757 r
F P
0 g
s
.31657 .40396 m .29557 .40396 L .26301 .3639 L p .552 .455 .698 r
F P
0 g
s
.26301 .3639 m .28387 .36081 L .31657 .40396 L p .552 .455 .698 r
F P
0 g
s
.32855 .44535 m .30768 .44165 L .27495 .40245 L p .502 .449 .729 r
F P
0 g
s
.27495 .40245 m .29557 .40396 L .32855 .44535 L p .502 .449 .729 r
F P
0 g
s
.55705 .38966 m .53487 .42222 L .50013 .45169 L p .902 .985 .76 r
F P
0 g
s
.50013 .45169 m .52276 .42183 L .55705 .38966 L p .902 .985 .76 r
F P
0 g
s
.71381 .26724 m .6904 .26853 L .65712 .27388 L p .675 .814 .95 r
F P
0 g
s
.32646 .3519 m .30502 .35691 L .27247 .3147 L p .585 .457 .672 r
F P
0 g
s
.27247 .3147 m .29378 .30687 L .32646 .3519 L p .585 .457 .672 r
F P
0 g
s
.37521 .50639 m .35401 .50119 L .32031 .47126 L p .297 .48 .87 r
F P
0 g
s
.32031 .47126 m .34104 .47828 L .37521 .50639 L p .297 .48 .87 r
F P
0 g
s
.53487 .42222 m .51253 .45348 L .47741 .4781 L p .862 .996 .779 r
F P
0 g
s
.47741 .4781 m .50013 .45169 L .53487 .42222 L p .862 .996 .779 r
F P
0 g
s
.35401 .50119 m .37521 .50639 L .38376 .5099 L p .08 .545 .903 r
F P
0 g
s
.40172 .51999 m .44532 .51822 L .40714 .52304 L .126 0 0 r
F
.40714 .52304 m .38843 .52053 L p .40172 .51999 L F P
0 g
s
.38843 .52053 m .4101 .52073 L .44532 .51822 L p .126 0 0 r
F P
0 g
s
.38376 .5099 m .4101 .52073 L p .39152 .51426 L .08 .545 .903 r
F P
0 g
s
.35401 .50119 m .38376 .5099 L .39152 .51426 L .08 .545 .903 r
F
.44532 .51822 m .42334 .52521 L .40714 .52304 L p .126 0 0 r
F P
0 g
s
.33797 .40183 m .31657 .40396 L .28387 .36081 L p .558 .451 .689 r
F P
0 g
s
.28387 .36081 m .30502 .35691 L .33797 .40183 L p .558 .451 .689 r
F P
0 g
s
.74794 .27983 m .77268 .28916 L .78292 .30384 L closepath p .184 .485 .899 r
F P
0 g
s
.74794 .27983 m .71381 .26724 L p .73787 .2762 L .43 .602 .918 r
F P
0 g
s
.77268 .28916 m .75463 .28235 L p .73787 .2762 L .43 .602 .918 r
F P
0 g
s
.75463 .28235 m .74794 .27983 L p .73787 .2762 L .43 .602 .918 r
F P
0 g
s
.71381 .26724 m .73777 .26964 L .77268 .28916 L p .43 .602 .918 r
F P
0 g
s
.65712 .27388 m .68009 .26478 L .71381 .26724 L p .675 .814 .95 r
F P
0 g
s
.73777 .26964 m .71381 .26724 L .68009 .26478 L p .582 .732 .946 r
F P
0 g
s
.7035 .26015 m .73777 .26964 L p .71471 .26769 L .582 .732 .946 r
F P
0 g
s
.68009 .26478 m .69743 .26135 L p .71471 .26769 L .582 .732 .946 r
F P
0 g
s
.69743 .26135 m .7035 .26015 L p .71471 .26769 L .582 .732 .946 r
F P
0 g
s
.6345 .28808 m .61213 .30747 L .57835 .32814 L p .879 .913 .847 r
F P
0 g
s
.61213 .30747 m .58987 .33176 L .5558 .35502 L p .903 .919 .82 r
F P
0 g
s
.5558 .35502 m .57835 .32814 L .61213 .30747 L p .903 .919 .82 r
F P
0 g
s
.34819 .34552 m .32646 .3519 L .29378 .30687 L p .583 .452 .668 r
F P
0 g
s
.29378 .30687 m .31526 .29897 L .34819 .34552 L p .583 .452 .668 r
F P
0 g
s
.65712 .27388 m .6345 .28808 L .60089 .30446 L p .838 .898 .881 r
F P
0 g
s
.57835 .32814 m .60089 .30446 L .6345 .28808 L p .879 .913 .847 r
F P
0 g
s
.36234 .48138 m .34104 .47828 L .30768 .44165 L p .46 .466 .778 r
F P
0 g
s
.30768 .44165 m .32855 .44535 L .36234 .48138 L p .46 .466 .778 r
F P
0 g
s
.34991 .44597 m .32855 .44535 L .29557 .40396 L p .522 .453 .719 r
F P
0 g
s
.29557 .40396 m .31657 .40396 L .34991 .44597 L p .522 .453 .719 r
F P
0 g
s
.58987 .33176 m .56761 .35994 L .53316 .38379 L p .915 .92 .805 r
F P
0 g
s
.53316 .38379 m .5558 .35502 L .58987 .33176 L p .915 .92 .805 r
F P
0 g
s
.51253 .45348 m .49007 .48119 L .45474 .49925 L p .777 .996 .805 r
F P
0 g
s
.45474 .49925 m .47741 .4781 L .51253 .45348 L p .777 .996 .805 r
F P
0 g
s
.4101 .52073 m .38843 .52053 L .35401 .50119 L p .08 .545 .903 r
F P
0 g
s
.68009 .26478 m .65712 .27388 L .62351 .28484 L p .78 .864 .911 r
F P
0 g
s
.60089 .30446 m .62351 .28484 L .65712 .27388 L p .838 .898 .881 r
F P
0 g
s
.46762 .50333 m .44532 .51822 L .4101 .52073 L p .263 .765 .73 r
F P
0 g
s
.56761 .35994 m .54526 .39055 L .51041 .41292 L p .916 .919 .803 r
F P
0 g
s
.51041 .41292 m .53316 .38379 L .56761 .35994 L p .916 .919 .803 r
F P
0 g
s
.49007 .48119 m .46762 .50333 L .43225 .51366 L p .585 .942 .806 r
F P
0 g
s
.43225 .51366 m .45474 .49925 L .49007 .48119 L p .585 .942 .806 r
F P
0 g
s
.35977 .39704 m .33797 .40183 L .30502 .35691 L p .567 .454 .684 r
F P
0 g
s
.30502 .35691 m .32646 .3519 L .35977 .39704 L p .567 .454 .684 r
F P
0 g
s
.37019 .33767 m .34819 .34552 L .31526 .29897 L p .583 .452 .668 r
F P
0 g
s
.31526 .29897 m .33692 .29101 L .37019 .33767 L p .583 .452 .668 r
F P
0 g
s
.4101 .52073 m .43225 .51366 L .46762 .50333 L p .263 .765 .73 r
F P
0 g
s
.7035 .26015 m .68009 .26478 L .64633 .26957 L p .709 .812 .929 r
F P
0 g
s
.62351 .28484 m .64633 .26957 L .68009 .26478 L p .78 .864 .911 r
F P
0 g
s
.39699 .50567 m .37521 .50639 L .34104 .47828 L p .423 .55 .879 r
F P
0 g
s
.34104 .47828 m .36234 .48138 L .39699 .50567 L p .423 .55 .879 r
F P
0 g
s
.54526 .39055 m .52276 .42183 L .48755 .44058 L p .906 .919 .816 r
F P
0 g
s
.48755 .44058 m .51041 .41292 L .54526 .39055 L p .906 .919 .816 r
F P
0 g
s
.37174 .4427 m .34991 .44597 L .31657 .40396 L p .546 .465 .715 r
F P
0 g
s
.31657 .40396 m .33797 .40183 L .37174 .4427 L p .546 .465 .715 r
F P
0 g
s
.38417 .47948 m .36234 .48138 L .32855 .44535 L p .512 .495 .774 r
F P
0 g
s
.32855 .44535 m .34991 .44597 L .38417 .47948 L p .512 .495 .774 r
F P
0 g
s
.39244 .32836 m .37019 .33767 L .33692 .29101 L p .585 .457 .672 r
F P
0 g
s
.33692 .29101 m .35876 .28298 L .39244 .32836 L p .585 .457 .672 r
F P
0 g
s
.73777 .26964 m .76228 .27426 L .77268 .28916 L closepath p .337 .583 .934 r
F P
0 g
s
.76228 .27426 m .73777 .26964 L .7035 .26015 L p .521 .657 .92 r
F P
0 g
s
.43225 .51366 m .4101 .52073 L .37521 .50639 L p .386 .739 .991 r
F P
0 g
s
.38191 .38938 m .35977 .39704 L .32646 .3519 L p .578 .461 .684 r
F P
0 g
s
.32646 .3519 m .34819 .34552 L .38191 .38938 L p .578 .461 .684 r
F P
0 g
s
.37521 .50639 m .39699 .50567 L .43225 .51366 L p .386 .739 .991 r
F P
0 g
s
.52276 .42183 m .50013 .45169 L .46466 .46505 L p .883 .919 .844 r
F P
0 g
s
.46466 .46505 m .48755 .44058 L .52276 .42183 L p .883 .919 .844 r
F P
0 g
s
.62351 .28484 m .60089 .30446 L .56648 .31813 L p .851 .86 .848 r
F P
0 g
s
.60089 .30446 m .57835 .32814 L .54368 .34273 L p .868 .857 .828 r
F P
0 g
s
.54368 .34273 m .56648 .31813 L .60089 .30446 L p .868 .857 .828 r
F P
0 g
s
.7035 .26015 m .72738 .2587 L .76228 .27426 L p .521 .657 .92 r
F P
0 g
s
.72738 .2587 m .7035 .26015 L .66943 .25859 L p .637 .753 .932 r
F P
0 g
s
.64633 .26957 m .66943 .25859 L .7035 .26015 L p .709 .812 .929 r
F P
0 g
s
.64633 .26957 m .62351 .28484 L .58927 .29601 L p .82 .855 .874 r
F P
0 g
s
.56648 .31813 m .58927 .29601 L .62351 .28484 L p .851 .86 .848 r
F P
0 g
s
.57835 .32814 m .5558 .35502 L .52082 .36873 L p .873 .846 .815 r
F P
0 g
s
.52082 .36873 m .54368 .34273 L .57835 .32814 L p .873 .846 .815 r
F P
0 g
s
.4149 .31765 m .39244 .32836 L .35876 .28298 L p .588 .466 .681 r
F P
0 g
s
.35876 .28298 m .38078 .27488 L .4149 .31765 L p .588 .466 .681 r
F P
0 g
s
.39399 .43522 m .37174 .4427 L .33797 .40183 L p .573 .482 .714 r
F P
0 g
s
.33797 .40183 m .35977 .39704 L .39399 .43522 L p .573 .482 .714 r
F P
0 g
s
.45474 .49925 m .43225 .51366 L .39699 .50567 L p .616 .851 .988 r
F P
0 g
s
.50013 .45169 m .47741 .4781 L .44185 .48478 L p .84 .915 .886 r
F P
0 g
s
.44185 .48478 m .46466 .46505 L .50013 .45169 L p .84 .915 .886 r
F P
0 g
s
.66943 .25859 m .64633 .26957 L .61214 .2771 L p .776 .835 .897 r
F P
0 g
s
.58927 .29601 m .61214 .2771 L .64633 .26957 L p .82 .855 .874 r
F P
0 g
s
.40435 .37883 m .38191 .38938 L .34819 .34552 L p .591 .473 .688 r
F P
0 g
s
.34819 .34552 m .37019 .33767 L .40435 .37883 L p .591 .473 .688 r
F P
0 g
s
.41924 .49848 m .39699 .50567 L .36234 .48138 L p .543 .616 .876 r
F P
0 g
s
.36234 .48138 m .38417 .47948 L .41924 .49848 L p .543 .616 .876 r
F P
0 g
s
.5558 .35502 m .53316 .38379 L .49789 .39483 L p .867 .83 .809 r
F P
0 g
s
.49789 .39483 m .52082 .36873 L .5558 .35502 L p .867 .83 .809 r
F P
0 g
s
.40645 .47216 m .38417 .47948 L .34991 .44597 L p .567 .528 .771 r
F P
0 g
s
.34991 .44597 m .37174 .4427 L .40645 .47216 L p .567 .528 .771 r
F P
0 g
s
.47741 .4781 m .45474 .49925 L .41924 .49848 L p .758 .901 .94 r
F P
0 g
s
.41924 .49848 m .44185 .48478 L .47741 .4781 L p .758 .901 .94 r
F P
0 g
s
.39699 .50567 m .41924 .49848 L .45474 .49925 L p .616 .851 .988 r
F P
0 g
s
.66943 .25859 m .6929 .25137 L .72738 .2587 L p .637 .753 .932 r
F P
0 g
s
.6929 .25137 m .66943 .25859 L .63517 .26166 L p .722 .801 .913 r
F P
0 g
s
.61214 .2771 m .63517 .26166 L .66943 .25859 L p .776 .835 .897 r
F P
0 g
s
.43754 .3058 m .4149 .31765 L .38078 .27488 L p .593 .48 .694 r
F P
0 g
s
.38078 .27488 m .40299 .26672 L .43754 .3058 L p .593 .48 .694 r
F P
0 g
s
.53316 .38379 m .51041 .41292 L .47491 .41956 L p .849 .811 .812 r
F P
0 g
s
.47491 .41956 m .49789 .39483 L .53316 .38379 L p .849 .811 .812 r
F P
0 g
s
.72738 .2587 m .75171 .25913 L .76228 .27426 L closepath p .458 .654 .944 r
F P
0 g
s
.75171 .25913 m .72738 .2587 L .6929 .25137 L p .585 .694 .917 r
F P
0 g
s
.42702 .36558 m .40435 .37883 L .37019 .33767 L p .606 .49 .695 r
F P
0 g
s
.37019 .33767 m .39244 .32836 L .42702 .36558 L p .606 .49 .695 r
F P
0 g
s
.41656 .42349 m .39399 .43522 L .35977 .39704 L p .601 .504 .716 r
F P
0 g
s
.35977 .39704 m .38191 .38938 L .41656 .42349 L p .601 .504 .716 r
F P
0 g
s
.51041 .41292 m .48755 .44058 L .45194 .44148 L p .82 .786 .82 r
F P
0 g
s
.45194 .44148 m .47491 .41956 L .51041 .41292 L p .82 .786 .82 r
F P
0 g
s
.44185 .48478 m .41924 .49848 L .38417 .47948 L p .641 .672 .865 r
F P
0 g
s
.38417 .47948 m .40645 .47216 L .44185 .48478 L p .641 .672 .865 r
F P
0 g
s
.42908 .45936 m .40645 .47216 L .37174 .4427 L p .619 .563 .77 r
F P
0 g
s
.37174 .4427 m .39399 .43522 L .42908 .45936 L p .619 .563 .77 r
F P
0 g
s
.46034 .2931 m .43754 .3058 L .40299 .26672 L p .6 .5 .712 r
F P
0 g
s
.40299 .26672 m .42538 .25849 L .46034 .2931 L p .6 .5 .712 r
F P
0 g
s
.61214 .2771 m .58927 .29601 L .55433 .30171 L p .81 .804 .846 r
F P
0 g
s
.58927 .29601 m .56648 .31813 L .53134 .32314 L p .818 .79 .826 r
F P
0 g
s
.53134 .32314 m .55433 .30171 L .58927 .29601 L p .818 .79 .826 r
F P
0 g
s
.6929 .25137 m .71675 .24679 L .75171 .25913 L p .585 .694 .917 r
F P
0 g
s
.71675 .24679 m .6929 .25137 L .65843 .24966 L p .668 .761 .92 r
F P
0 g
s
.63517 .26166 m .65843 .24966 L .6929 .25137 L p .722 .801 .913 r
F P
0 g
s
.56648 .31813 m .54368 .34273 L .50834 .3455 L p .815 .768 .809 r
F P
0 g
s
.50834 .3455 m .53134 .32314 L .56648 .31813 L p .815 .768 .809 r
F P
0 g
s
.48755 .44058 m .46466 .46505 L .42908 .45936 L p .778 .756 .833 r
F P
0 g
s
.42908 .45936 m .45194 .44148 L .48755 .44058 L p .778 .756 .833 r
F P
0 g
s
.44985 .35013 m .42702 .36558 L .39244 .32836 L p .623 .512 .707 r
F P
0 g
s
.39244 .32836 m .4149 .31765 L .44985 .35013 L p .623 .512 .707 r
F P
0 g
s
.63517 .26166 m .61214 .2771 L .57734 .28206 L p .789 .81 .869 r
F P
0 g
s
.55433 .30171 m .57734 .28206 L .61214 .2771 L p .81 .804 .846 r
F P
0 g
s
.43937 .40781 m .41656 .42349 L .38191 .38938 L p .63 .531 .723 r
F P
0 g
s
.38191 .38938 m .40435 .37883 L .43937 .40781 L p .63 .531 .723 r
F P
0 g
s
.46466 .46505 m .44185 .48478 L .40645 .47216 L p .718 .72 .85 r
F P
0 g
s
.40645 .47216 m .42908 .45936 L .46466 .46505 L p .718 .72 .85 r
F P
0 g
s
.54368 .34273 m .52082 .36873 L .48533 .36781 L p .801 .739 .795 r
F P
0 g
s
.48533 .36781 m .50834 .3455 L .54368 .34273 L p .801 .739 .795 r
F P
0 g
s
.65843 .24966 m .63517 .26166 L .60043 .26478 L p .758 .803 .889 r
F P
0 g
s
.57734 .28206 m .60043 .26478 L .63517 .26166 L p .789 .81 .869 r
F P
0 g
s
.52082 .36873 m .49789 .39483 L .46232 .38893 L p .778 .708 .785 r
F P
0 g
s
.46232 .38893 m .48533 .36781 L .52082 .36873 L p .778 .708 .785 r
F P
0 g
s
.45194 .44148 m .42908 .45936 L .39399 .43522 L p .667 .601 .772 r
F P
0 g
s
.39399 .43522 m .41656 .42349 L .45194 .44148 L p .667 .601 .772 r
F P
0 g
s
.71675 .24679 m .74098 .24375 L .75171 .25913 L closepath p .544 .699 .941 r
F P
0 g
s
.47279 .33309 m .44985 .35013 L .4149 .31765 L p .64 .539 .723 r
F P
0 g
s
.4149 .31765 m .43754 .3058 L .47279 .33309 L p .64 .539 .723 r
F P
0 g
s
.48326 .2799 m .46034 .2931 L .42538 .25849 L p .609 .526 .735 r
F P
0 g
s
.42538 .25849 m .44796 .25019 L .48326 .2799 L p .609 .526 .735 r
F P
0 g
s
.46232 .38893 m .43937 .40781 L .40435 .37883 L p .66 .56 .732 r
F P
0 g
s
.40435 .37883 m .42702 .36558 L .46232 .38893 L p .66 .56 .732 r
F P
0 g
s
.49789 .39483 m .47491 .41956 L .43937 .40781 L p .748 .673 .778 r
F P
0 g
s
.43937 .40781 m .46232 .38893 L .49789 .39483 L p .748 .673 .778 r
F P
0 g
s
.65843 .24966 m .682 .24068 L .71675 .24679 L p .668 .761 .92 r
F P
0 g
s
.682 .24068 m .65843 .24966 L .62367 .25007 L p .719 .785 .904 r
F P
0 g
s
.60043 .26478 m .62367 .25007 L .65843 .24966 L p .758 .803 .889 r
F P
0 g
s
.74098 .24375 m .71675 .24679 L .682 .24068 L p .628 .719 .913 r
F P
0 g
s
.47491 .41956 m .45194 .44148 L .41656 .42349 L p .71 .637 .774 r
F P
0 g
s
.41656 .42349 m .43937 .40781 L .47491 .41956 L p .71 .637 .774 r
F P
0 g
s
.48533 .36781 m .46232 .38893 L .42702 .36558 L p .688 .593 .744 r
F P
0 g
s
.42702 .36558 m .44985 .35013 L .48533 .36781 L p .688 .593 .744 r
F P
0 g
s
.4958 .31517 m .47279 .33309 L .43754 .3058 L p .659 .57 .743 r
F P
0 g
s
.43754 .3058 m .46034 .2931 L .4958 .31517 L p .659 .57 .743 r
F P
0 g
s
.57734 .28206 m .55433 .30171 L .51886 .29712 L p .761 .728 .822 r
F P
0 g
s
.55433 .30171 m .53134 .32314 L .4958 .31517 L p .752 .697 .799 r
F P
0 g
s
.4958 .31517 m .51886 .29712 L .55433 .30171 L p .752 .697 .799 r
F P
0 g
s
.53134 .32314 m .50834 .3455 L .47279 .33309 L p .736 .662 .778 r
F P
0 g
s
.47279 .33309 m .4958 .31517 L .53134 .32314 L p .736 .662 .778 r
F P
0 g
s
.60043 .26478 m .57734 .28206 L .54197 .27961 L p .761 .752 .845 r
F P
0 g
s
.51886 .29712 m .54197 .27961 L .57734 .28206 L p .761 .728 .822 r
F P
0 g
s
.50834 .3455 m .48533 .36781 L .44985 .35013 L p .714 .627 .76 r
F P
0 g
s
.44985 .35013 m .47279 .33309 L .50834 .3455 L p .714 .627 .76 r
F P
0 g
s
.5063 .26657 m .48326 .2799 L .44796 .25019 L p .619 .558 .764 r
F P
0 g
s
.44796 .25019 m .47073 .24182 L .5063 .26657 L p .619 .558 .764 r
F P
0 g
s
.62367 .25007 m .60043 .26478 L .56515 .26321 L p .75 .769 .868 r
F P
0 g
s
.54197 .27961 m .56515 .26321 L .60043 .26478 L p .761 .752 .845 r
F P
0 g
s
.682 .24068 m .70588 .2338 L .74098 .24375 L p .628 .719 .913 r
F P
0 g
s
.70588 .2338 m .682 .24068 L .64711 .23793 L p .681 .761 .912 r
F P
0 g
s
.62367 .25007 m .64711 .23793 L .682 .24068 L p .719 .785 .904 r
F P
0 g
s
.51886 .29712 m .4958 .31517 L .46034 .2931 L p .677 .604 .767 r
F P
0 g
s
.46034 .2931 m .48326 .2799 L .51886 .29712 L p .677 .604 .767 r
F P
0 g
s
.64711 .23793 m .62367 .25007 L .58843 .24834 L p .731 .774 .887 r
F P
0 g
s
.56515 .26321 m .58843 .24834 L .62367 .25007 L p .75 .769 .868 r
F P
0 g
s
.70588 .2338 m .73009 .22814 L .74098 .24375 L closepath p .6 .727 .933 r
F P
0 g
s
.54197 .27961 m .51886 .29712 L .48326 .2799 L p .692 .641 .794 r
F P
0 g
s
.48326 .2799 m .5063 .26657 L .54197 .27961 L p .692 .641 .794 r
F P
0 g
s
.52947 .25345 m .5063 .26657 L .47073 .24182 L p .63 .596 .796 r
F P
0 g
s
.47073 .24182 m .4937 .23337 L .52947 .25345 L p .63 .596 .796 r
F P
0 g
s
.56515 .26321 m .54197 .27961 L .5063 .26657 L p .703 .678 .823 r
F P
0 g
s
.73009 .22814 m .70588 .2338 L .6708 .22804 L p .651 .735 .91 r
F P
0 g
s
.64711 .23793 m .6708 .22804 L .70588 .2338 L p .681 .761 .912 r
F P
0 g
s
.6708 .22804 m .64711 .23793 L .61186 .23515 L p .706 .768 .901 r
F P
0 g
s
.58843 .24834 m .61186 .23515 L .64711 .23793 L p .731 .774 .887 r
F P
0 g
s
.58843 .24834 m .56515 .26321 L .52947 .25345 L p .708 .711 .851 r
F P
0 g
s
.5063 .26657 m .52947 .25345 L .56515 .26321 L p .703 .678 .823 r
F P
0 g
s
.55276 .24082 m .52947 .25345 L .4937 .23337 L p .64 .637 .831 r
F P
0 g
s
.4937 .23337 m .51686 .22486 L .55276 .24082 L p .64 .637 .831 r
F P
0 g
s
.61186 .23515 m .58843 .24834 L .55276 .24082 L p .705 .736 .875 r
F P
0 g
s
.52947 .25345 m .55276 .24082 L .58843 .24834 L p .708 .711 .851 r
F P
0 g
s
.6708 .22804 m .69477 .21971 L .73009 .22814 L p .651 .735 .91 r
F P
0 g
s
.69477 .21971 m .6708 .22804 L .63549 .22364 L p .68 .758 .91 r
F P
0 g
s
.61186 .23515 m .63549 .22364 L .6708 .22804 L p .706 .768 .901 r
F P
0 g
s
.69477 .21971 m .71901 .21228 L .73009 .22814 L closepath p .633 .742 .926 r
F P
0 g
s
.63549 .22364 m .61186 .23515 L .5762 .22891 L p .696 .751 .894 r
F P
0 g
s
.55276 .24082 m .5762 .22891 L .61186 .23515 L p .705 .736 .875 r
F P
0 g
s
.5762 .22891 m .55276 .24082 L .51686 .22486 L p .648 .676 .863 r
F P
0 g
s
.51686 .22486 m .54022 .21627 L .5762 .22891 L p .648 .676 .863 r
F P
0 g
s
.71901 .21228 m .69477 .21971 L .65934 .21361 L p .661 .744 .911 r
F P
0 g
s
.63549 .22364 m .65934 .21361 L .69477 .21971 L p .68 .758 .91 r
F P
0 g
s
.65934 .21361 m .63549 .22364 L .59981 .21779 L p .684 .756 .906 r
F P
0 g
s
.5762 .22891 m .59981 .21779 L .63549 .22364 L p .696 .751 .894 r
F P
0 g
s
.59981 .21779 m .5762 .22891 L .54022 .21627 L p .653 .709 .889 r
F P
0 g
s
.54022 .21627 m .56379 .20761 L .59981 .21779 L p .653 .709 .889 r
F P
0 g
s
.65934 .21361 m .68343 .2046 L .71901 .21228 L p .661 .744 .911 r
F P
0 g
s
.68343 .2046 m .65934 .21361 L .62362 .20747 L p .671 .754 .913 r
F P
0 g
s
.59981 .21779 m .62362 .20747 L .65934 .21361 L p .684 .756 .906 r
F P
0 g
s
.62362 .20747 m .59981 .21779 L .56379 .20761 L p .655 .733 .907 r
F P
0 g
s
.68343 .2046 m .70777 .19617 L .71901 .21228 L closepath p .65 .749 .922 r
F P
0 g
s
.56379 .20761 m .58756 .19887 L .62362 .20747 L p .655 .733 .907 r
F P
0 g
s
.62362 .20747 m .64763 .19784 L .68343 .2046 L p .671 .754 .913 r
F P
0 g
s
.64763 .19784 m .62362 .20747 L .58756 .19887 L p .656 .746 .917 r
F P
0 g
s
.70777 .19617 m .68343 .2046 L .64763 .19784 L p .661 .749 .915 r
F P
0 g
s
.58756 .19887 m .61153 .19006 L .64763 .19784 L p .656 .746 .917 r
F P
0 g
s
.64763 .19784 m .67187 .1887 L .70777 .19617 L p .661 .749 .915 r
F P
0 g
s
.67187 .1887 m .64763 .19784 L .61153 .19006 L p .656 .751 .92 r
F P
0 g
s
.67187 .1887 m .69634 .17979 L .70777 .19617 L closepath p .656 .751 .92 r
F P
0 g
s
.61153 .19006 m .63571 .18117 L .67187 .1887 L p .656 .751 .92 r
F P
0 g
s
.69634 .17979 m .67187 .1887 L .63571 .18117 L p .656 .751 .92 r
F P
0 g
s
.63571 .18117 m .66011 .1722 L .69634 .17979 L p .656 .751 .92 r
F P
0 g
s
.66011 .1722 m .68472 .16315 L .69634 .17979 L closepath p .656 .751 .92 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(0)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(0.25)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0.5)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.75)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
gsave
.2956 .07454 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00kOooool4o`000003oa0@4?oooooooooo07Cooooo003_ooooo`03o`00
0?oooooooooo07Kooooo003_ooooo`03o`000?oooooooooo07Kooooo003_ooooo`03o`000?oooooo
oooo07Kooooo003_ooooo`03o`000?oooooooooo07Kooooo003_ooooo`03o`000?oooooooooo07Ko
oooo003_ooooo`03o`000?oooooooooo07Kooooo003]ooooo`03oeEEEOmVIVKo000007Sooooo003o
ooooo`;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Rooooo`00ooooool2ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0H_ooool00?oooooo0_ooool01Ol@413ooooooooooooooooo410@06;ooooo003i
ooooo`;o00001_ooool01Ol0003ooooooooooooooooo000006;ooooo003fooooo`?o000000?ooooo
o`000?ooool01Oooool01Ol0003ooooooooooooooooo000006;ooooo003dooooo`;o00001?ooool2
o`0000Gooooo00Go410@oooooooooooooooooa0@401Rooooo`00lOooool4o`0000Gooooo00?o0000
ooooool000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg06;ooooo003_ooooo`;o00001?ooool0
0ol0003oooooooooo`02ooooo`?o00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^06;ooooo003/
ooooo`?o00002oooool01?l0003oooooooooool0001Zooooo`00jOooool3o`0000kooooo00Go0000
ooooooooooooooooo`00001Yooooo`00ioooool2o`000003ooooool0003ooooo00kooooo00Go0000
ooooooooooooooooo`00001Yooooo`00i?ooool3o`0001?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1Vooooo`00h_ooool2o`0001Kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Uooooo`00goooool3o`0001Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1Uooooo`00XOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Nooooo`;o00007?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo06Cooooo002Qooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0Joooo
o`?o00000_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo0_l0001Voooo
o`00M?ooool2o`0000;ooooo0_l0000Wooooo`05oa0@4?ooooooooooooooool@41003Oooool00onY
ZJWoEEEEooooo`08ooooo`03o`000?oooooooooo01Oooooo0_l0000Qooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0Hoooool007Cooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMdW
ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb
<S;ooooo01Gooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0H_oo
ool007Gooooo00CogMgMo`000?l@413oc<c<:?ooool01Ol0003ooooooooooooooooo000000kooooo
00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo0_l0000Vooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0H_ooool007Gooooo00Cok^k^ob4Q8Ol@413o
k^k^:?ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0
003oooooooooo`0Cooooo`?o000000?oooooo`000?ooool09Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo067ooooo001eooooo`04ob4Q8OmgMgOoMgMgoc8b<RSooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooooooo
o`0@ooooo`?o0000:oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo063ooooo001d
ooooo`;o00000_ooool2o`0002Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?oo
ool4o`0000gooooo0_l0000^ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0H?oo
ool00<Sooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Goooool0
0<Kooooo0_l00002ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool01oooool00ol0
003oooooo`00001Pooooo`00`oooool3o`0003Gooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1Nooooo`00`Oooool2o`0003Sooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1Mooooo`00__ooool3o`0003[ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`1Looooo`00_?ooool2o`000003ooooool0003ooooo03[ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`1Looooo`00^Oooool3o`0000Cooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo05_ooooo002gooooo`;o0000@_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo05[ooooo002dooooo`?o0000A?ooool00ol0003ooooo
ooooo`0<ooooo`;o0000G?ooool00;;ooooo0_l000000ooooooo0000ooooo`14ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0FOooool00:oooooo0ol00019ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0F?ooool00:cooooo0ol0001=ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0F?ooool007Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM023ooooo0_l0001@ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Eoooool007Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Looooo`?o000000?oooooo`000?ooool0Coooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05Oooooo001dooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`0Iooooo`;o0000EOooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo05Kooooo001dooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`0Gooooo`?o0000Eoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo05Gooooo001dooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<01Kooooo0_l0001Jooooo`03o`000?oooooooooo013ooooo0_l00009ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd0<?ooool007Cooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01Go
oooo0ol000000ooooooo0000ooooo`1Iooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01oooool00omgMgOo<S8booooo`0_ooooo`00M?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool04oooool2o`0005oooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP09ooooo`03o`000?oooooooooo02kooooo001dooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0000oooooo0ol0001Qooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`0_ooooo`00U_ooool2o`0006Cooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0<?ooool009?ooooo0ol000000ooooooo0000ooooo`1Sooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool00oooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0booooo`00T?ooool3o`0006Wooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0<_ooool008ko
oooo0_l0001/ooooo`03o`000?oooooooooo01Cooooo0ol00004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000aooooo`00Roooool3o`00
06kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1?ooooo`00ROooool2o`0000;o
oooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04oo
oooo0026ooooo`?o00001Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0C_ooool008Cooooo0_l0001fooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0COooool0087ooooo0ol0001hooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0COooool007oooooo0_l00002ooooo`03o`000?oooooooooo07Kooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`1<ooooo`00O?ooool3o`0007gooooo00?o0000oooooooo
ool06Oooool3o`0004gooooo000looooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd08?ooool2o`00087ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`1;ooooo`00??ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0L
ooooo`?o0000Poooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04[ooooo000loooo
o`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooo
oooo01Sooooo0ol00003ooooo`03o`000?oooooooooo07_ooooo0_l00003ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool0B_ooool003cooooo00Go0000ooooooooooooooooo`00000=
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool05oooool2o`00087ooooo0ol00000
0onW`>_o0000ooooo`02ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0BOooool0
03cooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00Eooooo`?o0000P?ooool3o`0000GoYl3[00Co0000oooooooooooo0000
7oooool00ol0003oooooooooo`18ooooo`00??ooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Eooooo`;o000000?oooooo`000?ooool0
O_ooool4o`0000OoYl3[00?o0000ooooool000007oooool00ol0003oooooooooo`18ooooo`00??oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo01;ooooo0ol00020ooooo`?o00001?nW`>/4o`0000?oYl3[00?o0000ooooool0
00007oooool2o`0004Wooooo000looooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l0000?ooooo`;o0000P?ooool3o`0000_oYl3[1_l0000Qoooo
o`03o`000?oooooooooo04Kooooo001Uooooo`?o0000P?ooool2o`0001;oYl3[0_l0000Qooooo`03
o`000?oooooooooo04Kooooo001Sooooo`;o00000_ooool00ol0003oooooooooo`1kooooo`?o0000
1OnW`>/6o`0000CoYl3[1?l00002ojO0j`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
8_ooool3o`000003oa0@4?oooooooooo01gooooo001Pooooo`?o0000P?ooool2o`0000koYl3[1Ol0
0005ojO0j`;o00008_ooool00ol0003oooooooooo`0Sooooo`03oa0@4?nj^[[ooooo01kooooo001N
ooooo`;o0000POooool2o`0000koYl3[0ol00004ojVojPCo000000CoYl3[o`000?nW`>_o00008Ooo
ool00ol0003oooooooooo`0Sooooo`03oiRHV?lb<S;ooooo01kooooo001Kooooo`?o0000P?ooool3
o`0000GoYkkZ1Ol00003ojO0j`?o00002onY_nX5o`00027ooooo00?o0000ooooooooool08_ooool0
0ooMgMgo0000okZj^P0Nooooo`00FOooool2o`0000?ooooo00?o0000ooooooooool0N_ooool3o`00
00goYkkZ0ol0000?ojVojP03o`000?nY_n[oZKoZ00;o00007oooool3o`0002?ooooo00?oEEEEogMg
Mom4A4@07_ooool005Kooooo0ol00020ooooo`;o00003onW_^X2o`0000CoZl7Y1?l00009ojVojP?o
000000?oY[o/o`000?ooool08?ooool00ol0003oooooooooo`0Pooooo`05omgMgOl@413oooooob4Q
8OoMgMd07Oooool005?ooooo0ol00020ooooo`?o00001?nW^nP4o`0000SoYkkZ00?o0000oj_1jOn[
`NT02?n[`NT4o`0000;oZKoZ1?l00004ojJok003o`000?oooooooooo01oooooo00?o0000oooooooo
ool07oooool01OmVIVKoQhN7oooooonHV9SoEEEE01gooooo001Aooooo`;o000000?oooooo`000?l0
0000OOooool3o`0000_oYk_X1?l00002ojNnjP;o00003on[`NT6o`0000GoY[o/00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Mooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOoo
ool06oooool004kooooo0ol0001oooooo`?o00004_nW^nP2o`0000coZl7Y1?l00006ojVnj@Go0000
00?oY[o/o`000?ooool08?ooool00ol0003oooooooooo`0Mooooo`04oa0@4?l0003o0000ooooo`;o
000000?o410@ooooooooool06_ooool002Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`;o
0000Ooooool3o`0000GoYkGS1?l00009ojNkj0?o00002?n_`NL6o`0000[oZKkY00?o0000ojVnjOnY
_^T00_nY_^T3o`00027ooooo00?o0000ooooooooool0?oooool002Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Nooooo`?o0000O_ooool3o`0000coYkGS1?l00002ojNkj0?o00003?n_`NL2o`0000Go
[/;X1Ol00003ojVnj@Go00000_nR_Nd00ol0003oooooooooo`0Oooooo`;o0000@?ooool002Kooooo
00Go410@oooooooooooooooooa0@400Looooo`;o00000oooool00ol0003oooooooooo`1hooooo`?o
00000onU[M`3o`0000goYkGS0_l0000=ojo1i`;o00003?n^`^P5o`0000KoX[g]00?o0000oooooooo
ool07Oooool00ol0003oooooo`000008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Rooooo`009_ooool01Ol0003ooooooooooooooooo
000001Wooooo0ol0001mooooo`?o00002OnU[M`3o`0000OoYkGS0ol00005ok;0i0Go00000on_`NL2
o`0000co[/;X0ol00003ojJlj0Go00000onR_Nd00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`0Qooooo`009_ooool01Ol0003ooooooooooooooooo000001Oooooo0_l0001nooooo`;o00003onU
[M`3o`000004ojNehol0003o0000o`0000go//3T0ol00004ojk2j0;o00001_n^`^P2o`0000KoY[cX
00?o0000ojJlj?nV_>P00_nV_>P5o`00023ooooo00?o0000ooooooooool01Oooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o0000ooooooooool08?ooool002Kooooo00Go410@oooooooooooo
oooooa0@400Dooooo`Co0000O?ooool3o`0000?oXj?D0ol0000>ojF]g003o`000?nb`>Co//3T00co
//3T0ol00008okC4iPKo00002?nV_>P00ol0003oY[cXojJlj006ojJlj0;o00008?ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Qoooo
o`009_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo0_l00004ooooo`03o`000?oooooooooo
07Oooooo0_l00009oj>Se0;o00002OnU[M`2o`0000Go];cO1_l00003ok;0i0;o00003?nda>H3o`00
00Go[/;Y1_l00003ojJlj0Co00000_nI^^h00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`08_oo
ool002Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0?ooooo`?o0000O_ooool2o`0000goXj?D0_l0
0006ojF]g003o`000?nd_=oo];cO00_o];cO0ol00004okC4iP;o00001Onda>H3o`0000go[/;Y1Ol0
0006oiVjkP03o`000?oooooooooo01kooooo00?o0000ooooooooool00oooool01Ol@413ooooooooo
oooooooo410@00cooooo00?o0000ooooooooool09?ooool003Oooooo0ol0001nooooo`?o00000onQ
V</2o`0000coXj?D0ol000000onU[Mco0000o`00000>okBlg`03o`000?nka^?o^lKS00Ko^lKS1Ol0
000<ojk2j@Go00001?nP^>T4o`0000?oVK[^00?o0000ooooooooool07?ooool3o`0000Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo02Cooooo000eooooo`;o00000ooo
ool00ol0003oooooooooo`1hooooo`?o00002?nQV</2o`0000coXj?D0_l0000>okBlg`;o00002onk
a^<00ol0003o^<SWokS8i`06okS8i`Ko00001?nP^>T00ol0003oX;SYoj2hj@06oj2hj@Co00008Ooo
ool02Ol0003oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00008oooool003;o
oooo0ol0001mooooo`?o00003OnQV</00ol0003oXj?Doj>Se007oj>Se0;o00001?ne]]T4o`0000Ko
];cO0_l0000;ok_6h`03o`000?nhb>Oo^<SW00Wo^<SW0_l00005oj_2j`Ko00002?nP^>T2o`00023o
oooo00?o0000ooooooooool0>Oooool0033ooooo0_l0001mooooo`?o00001?nNS/<00ol0003oXIS;
oj6Hb`0:oj6Hb`;o00001OnSXm@2o`0000[o]KKI0ol00002okBlg`03o`000?nka^?o^lKS00Wo^lKS
0_l00009okS8i`;o00002_n[`^/01?l0003oZl;[oj_2jon[`^/6o`0000?oRk;`00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0hooooo`00;Oooool4o`0007_ooooo0ol00008oij>``;o0000
3?nQV</2o`000003oj>Se?l0003o000000oo]KKI0_l000000onka^?o0000o`000009o`0000;o^<SW
2Ol0000<oj_2j`Co00001?nE/NX3o`0000?oRk;`00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0gooooo`00;?ooool2o`0000?ooooo00?o0000ooooooooool0MOooool3o`0000?oVhJl00?o
0000oij>`onNS/<01onNS/<00ol0003oXIS;oj6Hb`0:oj6Hb`;o00003one]]T2o`0000_o_lCN00?o
0000ol;=hoo2cN<02?o2cN<00ol0003o^<gYokS=j@06okS=j@Oo00002_nE/NX3o`000003oh^bl?l0
003ooooo01oooooo00?o0000ooooooooool0=oooool002cooooo00?o0000ooooool00000N?ooool2
o`0000OoVhJl00?o0000oij>`onNS/<01onNS/<2o`0000WoXIS;00?o0000ok>]d_nc[M800_nc[M84
o`0000So]KKI00?o0000oko4g_noa=h02Onoa=h2o`0000So`/gS0_l0000;okS=j@03o`000?nS`>ko
Xl3^00;oXl3^00Co0000oj?0k_l0003o00002_nE/NX3o`00023ooooo00?o0000ooooooooool0=_oo
ool002cooooo00Co0000oooooooooooo0000MOooool2o`0000[oVhJl00?o0000oij>`onNS/<02?nN
S/<00ol0003oXIS;oj6Hb`04oj6Hb`;o00002Onc[M84o`0000;o]KKI0_l0000:oko4gP;o00002?o2
cN<2o`0000Ko^<gY1?l00008oj?0kP03o`000?nS`>koXl3^00CoXl3^1_l00004oiFajP03o`000?oo
oooooooo01cooooo00?o0000ooooool00000=oooool002cooooo00Go0000ooooooooooooooooo`00
001aooooo`?o00000_nIOkH00ol0003oVhJloi^6_008oi^6_003o`000?nNS/?oWXk300SoWXk30_l0
0003oj6Hb`03o`000?nc[M;o/jgB00go/jgB0_l000000onoa=ko0000o`000003o`0000Go_lCN00?o
0000ol;=hoo2cN<00_o2cN<6o`0000;o^<gY0ol00004olKEi@[o]Lo]0_l00002oiBklP03o`000?n5
Z>_oQJS[00GoQJS[0_l00004ogFWl@03o`000?oooooooooo01kooooo00?o0000ooooooooool0=Ooo
ool002_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1/ooooo`;o00001_nIOkH0
0ol0003oVhJloi^6_008oi^6_003o`000?nNS/?oWXk300WoWXk300?o0000oj6Hbol000003onc[M80
0ol0003o`/3Hol;0f006ol;0f0Go000000?o`/gSo`000?l000000_l00004olW?gPSoa]GU00?o0000
okG?kOnecnd01Onecnd3o`0000?oU;_b00?o0000oiBkl_nD^o800onD^o82o`0000GoQJS[0ol00002
ogFWl@03o`000?oooooooooo01kooooo00?o0000ooooooooool0=?ooool002_ooooo0_l00005oooo
o`03o`000?oooooooooo06Sooooo0ol00009oiUo]P03o`000?nKQ[coVhJl00SoVhJl00?o0000oij>
`onNS/<02?nNS/<2o`0000oo/jgB00?o0000ol;0f?o2`=P02Oo2`=P00ol0003obLoNolW?gP06olW?
gP;o00001oo6eND2o`0000Co]Lo]00?o0000olOMjOo7gNT01on/d?<00ol0003oU;_boiBklP06oiBk
lP?o00001?n5Z>/2o`000003ogFWlOl0003ooooo01oooooo00?o0000ooooooooool0<oooool002_o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Sooooo`Co00000_nGN[400ol0003o
VGnfoiUo]P08oiUo]P03o`000?nKQ[coVhJl00SoVhJl00?o0000oij>`onNS/<01OnNS/<2o`0000?o
/JC;0ol00009ok>]dP;o00002oo2`=P00ol0003obLoNolW?gP06olW?gP03o`000?o6eNGoa]GU00?o
a]GU1?l000000onecngo0000olOMj@03olOMj@[o[=3c00?o0000ognam?mo/O@01?mo/O@2ofjJj`?o
U;_b0ol00003ohFXj`;o00008?ooool00ol0003oooooooooo`0cooooo`00:oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo05oooooo0ol00007oiMj/@03o`000?nIOkKoVGnf00SoVGnf
00?o0000oi^6_?nKQ[`02?nKQ[`00ol0003oWXk3oij>``02oij>``;o00002?naY</3o`0000Go/jgB
00?o0000ol;0f?o2`=P02_o2`=P00ol0003obLoNolW?gP06olW?gP04o`000?o6eNGoa]GUolKEi@?o
00000_oAf]l5olOMj@Co[=3c00?o0000olCSk_nMc?P01_nMc?P00ol0003oWLchoig<n002oig<n003
ognam?l0003oOk7d00;oOk7d1?m^V^/2o`000005oeJEkol0003o0000ohFXjol000008?ooool00ol0
003oooooooooo`0booooo`00:oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05_o
oooo0ol000000onFMjko0000oiMj/@08oiMj/@03o`000?nIOkKoVGnf00SoVGnf00?o0000oi^6_?nK
Q[`02?nKQ[`01?l0003oWXk3o`000?l0000=ok6Tb`?o000000?o/jgBo`000?o2`=P02oo2`=P00ol0
003obLoNolW?gP03olW?gPCo000000?oa]GUo`000?oAf]l01?oAf]l4olOMj@03omKUhOo4hnko0000
00;o000000?oa>?^okcUlonliO<00onliO<3ojoRn0;oWmSl00?oR<;jo`000?n8`_X00on8`_X4of>P
lP03ognam?l0003oKY[[00?oKY[[0_l00002oeJEk`03o`000?oooooooooo01gooooo0_l0000doooo
o`00:oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Sooooo0_l00005oiIg[P03
o`000?nGN[7oUgZa00OoUgZa00?o0000oiUo]_nIOkH02?nIOkH00ol0003oVhJloi^6_007oi^6_0;o
00004_naY</00ol0003o`/3Ho`000004o`0000Ko`/3H00?o0000olW?g_o9cmh01?l00002olo=f0Ko
dM[O0_l00002olOMj@;oe^GQ0ol000000oo4hnkoenoSokcUl`02okcUl`?o[n;h00?oc=3Mol:id_o2
^M800_o2^M800onTZ]_o0000o`000004ojBZf`?oKk7i0omSX?83oe27iP?oKY[[0_l000000omFUNoo
0000ooooo`0Oooooo`03o`000?oooooooooo037ooooo000Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0E?ooool3o`0000SoUWN^00?o0000oiMj/OnGN[401onGN[400ol0003oVGnf
oiUo]P08oiUo]P03o`000?nKQ[coVhJl00CoVhJl0_l00003ojfJa0?o00003?naY</00ol0003o`[[B
ol:jdP06ol:jdPSo00001Oo?cMP00ol0003odM[Oom7Jg`03om7Jg`;o000000CoamgYomKUhOoFiN7o
e^GQ0_l000001?o4hnkoenoSomO_honliO<2om?di@04olgfjOoEin;oc=3Molc@g@So`[WB00?o0000
oj2KconPVll00_nPVll2o`0000;oY:[K00CoNI7Nod>:k?mSX?;oHj3b1?m@QnH2ofjJj`?o00008?oo
ool00ol0003oooooooooo`0`ooooo`00:_ooool2o`0000cooooo00?o0000ooooooooool0D?ooool3
o`0000;oUGB/00?o0000oiIg[_nFMjh01onFMjh00ol0003oUgZaoiMj/@07oiMj/@03o`000?nIOkKo
VGnf00SoVGnf00?o0000oi^6_?nKQ[`00_nKQ[`00ol0003o[I[4ojfJa006ojfJa0;o00002?naY</2
o`0000co`[[B00?o0000olo=f?o?cMP01_o?cMP00ol0003odM[Oom7Jg`02om7Jg`;o00001OoFiN40
0oo4hnko0000o`000002omO_h`;odoCU00CocOKYomGWh_o<d=goc=3M1?o2^M87o`0000KoX9_?00Go
NXODo`000?mjQmCoNXODogVAgP02od>:k007of>Pl_m@QnKoD8OVoe27i_l0003o;gcVofjJj`02o`00
01oooooo00?o0000ooooooooool0<?ooool002[ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`1<ooooo`?o00001_nEM:`00ol0003oUWN^oiIg[P07oiIg[P03o`000?nGN[7oUgZa00Oo
UgZa00?o0000oiUo]_nIOkH02?nIOkH01?l0003oVhJlo`000?l0000;ojfJa0;o00001OnaY</00ol0
003o`[[Bol:jdP0;ol:jdP03o`000?o?cMSoclgH00KoclgH00Oo0000om7JgooAf]oodM[Oo`000?oI
g=Wo000000Coe^GQ00?o0000omO_hol000000_oGkn<2om?di@;ocOKY00?o0000on3Md_l000001_l0
0005okVWb0Go00000onPVll2ogZ7e004o`000?mjQmCoNXODobEbh@;o@h[/00?o;W3Noe27i_m@QnH0
0_l00002obmliP03o`000?oooooooooo01gooooo00?o0000ooooooooool0;oooool002[ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`18ooooo`?o000000?oUG>[o`000?nEM:`01onE
M:`00ol0003oUWN^oiIg[P06oiIg[P03o`000?nGN[7oUgZa00SoUgZa00?o0000oiUo]_nIOkH01onI
OkH2o`0000oo[I[40ol000000onaY<_o0000ol:jdP0;ol:jdP;o00002?o?cMP00ol0003odM[Oo`00
0003omWLf@05o`000?oFiN7oe^GQomKUhOoQjMP00ol00002omO_h`04om?diOo=m^WocOKYonOadP;o
h=gB0_l00003omC5b`;o00001_niYlP00ol0003o^JO8okVWb002okVWb0;o00000onPVll2ogZ7e003
o`000?mjQmCoA6WB00;o9G;Q00Oo;W3Noe27i_m@QnKoD8OVo`000?l_O>Ko0000023ooooo00?o0000
ooooooooool0;_ooool002[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`15oooo
o`;o00001OnELj/00ol0003oUGB/oiEd[006oiEd[003o`000?nFMjkoUWN^00KoUWN^00?o0000oiMj
/OnGN[402?nGN[400ol0003oVGnfoiUo]P04oiUo]P;o00000onXTKh00ol0003o[I[4ojfJa00>ojfJ
a004o`000?o2^];o0000o`0000Wo`[[B00?o0000olo=f?o?cMP01?o?cMP4o`0000GofMcI00?o0000
omKUhOoFiN400_oQjMP2o`0000;oenoS0_oCm>D00ooMoMCofocIonOadP02on3MdP03o`000?oDaL_o
e<G;00;oe<G;00?o0000okVWb?niYlP01_niYlP01?l0003o^JO8o`000?l00004oijAa@?oOX7<00Oo
X9_?ogZ7e?mjQmCoNXODodAYd_lmK]Wo9G;Q00;o;W3N0_m@QnH3o`0001kooooo0_l0000`ooooo`00
:_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04;ooooo0_l00008oiEcZ`03o`00
0?nEM:coUGB/00KoUGB/00?o0000oiIg[_nFMjh01_nFMjh00ol0003oUgZaoiMj/@08oiMj/@03o`00
0?nIOkKoVGnf00;oVGnf00?o0000ojRA__nXTKh01?nXTKh2o`0000co[I[400?o0000ol2bc?o0//`0
0oo0//`5o`0000?o`[[B00?o0000olo=f?o?cMP01Ol00002om7:d`KofMcI00?o0000omKUhOl00000
0_oQjMP2o`000003omO_hooCm>Go000000;ogOgD00Goi__:onOad_o]ml?oh=gBo`000003omC5b`;o
00000oniYlP7o`0000SoWY751OmnPL`3ogZ7e0;o?FkI00?o35OAobi`g_l^L=h00_m@QnH2o`0001oo
oooo00?o0000ooooooooool0;Oooool002[ooooo0_l0000Aooooo`03o`000?oooooooooo03kooooo
0ol000000onELj_o0000oiEcZ`08oiEcZ`03o`000?nEM:coUGB/00GoUGB/00?o0000oiIg[_nFMjh0
1onFMjh00ol0003oUgZaoiMj/@08oiMj/@04o`000?nIOkKo0000o`0000WoZ96n0_l00009ojfJa003
o`000?o0//co`;;<00Wo`;;<1Ol00006om7:d`03o`000?oIg=WofMcI00CofMcI00?o0000omKUhOoQ
jMP00_oQjMP2o`00000:on?de_oCm>GohO[Do`000?oMoMCoi__:onOad_o]ml?oh=gBo`0000;oe<G;
0ol00008olVa`P;o/i^o0_l00009oijAa@GoOX7<0_mjQm@00om4JM;o0473o`aGd@02obi`gP03o`00
0?m@QnKo0000023ooooo00?o0000ooooooooool0;?ooool002Wooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0kooooo`;o00001OnELj/00ol0003oUG>[oiEcZ`06oiEcZ`03o`000?nE
M:coUGB/00KoUGB/00?o0000oiIg[_nFMjh01_nFMjh00ol0003oUgZaoiMj/@08oiMj/@;o00003OnX
TKh00ol0003o[I[4ojfJa004ojfJa0;o00003Oo0//`00ol0003odL[Com7:d`06om7:d`03o`000?oI
g=WofMcI00?ofMcI0_l00004on7Yf0Co000000CohO[Do`000?oMoMCoi__:0_o]ml<00ooPgM;o0000
omC5b`02o`000003on7?a_l0003obK7200KobK7200?o0000ok>K_oncVkl00_l00003ok>K_`03o`00
0?nNTLGoWY7500GoWY7500?o0000ogj1c?mnPL`00_mnPL`01?m>JLkoNXODodAYd_l0@L<2o`aGd@;o
;W3N0_l0000Oooooo`03o`000?oooooooooo02cooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0>?ooool2o`0000SoUG>[00?o0000oiEcZonELj/01_nELj/00ol0003o
UGB/oiEd[006oiEd[003o`000?nFMjkoUWN^00KoUWN^00?o0000oiMj/OnGN[401OnGN[42o`0000?o
XhVi00?o0000ojRA__nXTKh02_nXTKh2o`0000?o[I[400?o0000ol2bc?o0//`03?o0//`00ol0003o
dL[Com7:d`06om7:d`04o`000?oIg=WofMcIomWLf@Co00000ooQjMP3o`000009onWgc?l0003ohO[D
o`000?oRoKooh_g1onOad_o]ml?ok>K900?o00000_oQclH00ol0003obK72olVa`P04olVa`P03o`00
0?ncVkoo000000;o000000?o/i^oo`000?ncVkl01?ncVkl3o`0000CoWY7500?o0000ogj1c?mnPL`0
0_mnPL`2odiYcP07o`000?l0@L?o02jfo`aGdOl0003o;W3No`00000Pooooo`03o`000?oooooooooo
02_ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03Cooooo0ol000000onE
M:co0000oiEcZ`08oiEcZ`03o`000?nELj_oUG>[00KoUG>[00?o0000oiEd[?nEM:`01_nEM:`00ol0
003oUWN^oiIg[P06oiIg[P03o`000?nGN[7oUgZa00;oUgZa0_l00006oj>9^@03o`000?nXTKkoZ96n
00_oZ96n00?o0000ojfJa?l000003_o0//`00ol0003odL[Com7:d`06om7:d`03o`000?oIg=Wo0000
00;o00000_oNfm<00ol0003ohNWHon7Yf002o`000008onO[dOl0003ojOO<onWgc?oQn]Co0000on;m
_ooRoL42ongg``03oncVbOl0003o000000?ohLo600?o0000olVa`_o9/L800_o9/L85o`0000Go/i^o
00?o0000ok>K_oncVkl01OncVkl3o`0000?oWY7500go0000ogj1c?mnPLcoOX7<odiYc_l8A<CoA6WB
o`11`ol0;[Ko35OAo`000?l^L=ko0000023ooooo00?o0000ooooooooool0:_ooool000Kooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0<?ooool3o`0000GoUGB/00?o0000oiEcZonELj/0
1_nELj/00ol0003oUG>[oiEcZ`07oiEcZ`03o`000?nEM:coUGB/00GoUGB/00?o0000oiIg[_nFMjh0
1onFMjh01?l0003oUgZao`000?l00009oj>9^@03o`000?nXTKkoZ96n00[oZ96n1?l0000<ol2bc003
o`000?oAb]?odL[C00KodL[C00?o0000omWLfOl000001?oNfm<01?l0003ohNWHo`000?l00002onO[
d@03o`000?oYmlcojOO<00;o000000Coh_foon;m`Oo]ml?okOO30_l00004on7?aP04o`000?o9/L;o
bK72olVa`PGo00000oo1XkX6o`0000;o/i^o0ol00003oij;_P?oQ7o500Co0000oijAaOl0003o0000
0_mnPL`02Om>JLko24C4o`Q4a?l0@L?o04g;o`aGdOl0003o03k1o`00000Nooooo`;o00002?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@06ooooo`003_ooool01Ol0003ooooooooooooooooo000000kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02cooooo
0ol000000onFMjko0000oiEd[006oiEd[003o`000?nELj_oUG>[00KoUG>[00?o0000oiEcZonELj/0
1_nELj/00ol0003oUGB/oiEd[006oiEd[003o`000?nFMjkoUWN^00KoUWN^0_l0000<oj>9^@;o0000
2OnXTKh00ol0003o_:W7okbYa`02okbYa`Co00001oo0//`00ol0003odL[Com7:d`03om7:d`Co0000
1_oNfm<00ol0003ohNWHo`000003onO[d@03o`000?oYmlcojOO<00;o000000Ooh_foon;m`Oo]ml?o
kOO3o`000?o`kl?o000000?ohLo600?o0000olVa`_l000000ol00002omBi_`03o`000?o1Xk[o`J>j
00Oo`J>j0ol00007oij;_PKoQ7o50_l000002_mnPLcoCVW>o`Q4a?l8A<Co0473o`0^]_l<Em7o0000
o`0n`Ol0000Oooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Gooooo000>ooooo`05
o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`04ooooo`;o00006Oooool2o`00
02[ooooo0_l00005oiIg[P03o`000?nEM:coUGB/00GoUGB/00?o0000oiEcZonELj/01_nELj/00ol0
003oUG>[oiEcZ`06oiEcZ`03o`000?nEM:coUGB/00KoUGB/00?o0000oiIg[_nFMjh00_nFMjh3o`00
00?oWh>d00?o0000oj>9^OnSRKT02_nSRKT00ol0003oZ96nojRA_P05ojRA_P03o`000?nlZLOo_:W7
00Oo_:W71?l00002ol2bc003o`000?oAb]?o000000Co00000oo@a<l00ol0003og]_ComkKd`03omkK
d`?o00000ooWjm400ol0003ojOO<onWgc002o`000005on;m_ooRoL7oooooongg`ol000000_o`kl<2
on7?aPGo00001?oD^Kl00ol0003o`J>jol6S^P07ol6S^P04o`000?n`TkWo0000ok2C^@SoWX^n00?o
0000ohAoaOn4OlD00on4OlD01?mKK<_o0000o`000?m>JLh2o`Q4a003o`000?l0;[Ko000000;o0000
8?ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00Cooooo000>ooooo`05oa0@4?ooooooooooooooool@
41003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool09?ooool3o`0000SoUWN^00?o0000oiEd[?nEM:`01OnEM:`00ol0003oUG>[oiEcZ`06oiEcZ`03
o`000?nELj_oUG>[00KoUG>[00?o0000oiEd[?nEM:`01_nEM:`01?l0003oUWN^o`000?l00007oin3
]003o`000?nSRKWoXhVi00[oXhVi00?o0000ojRA__nXTKh00onXTKh00ol0003o_:W7okbYa`0<okbY
a`Co00001oo@a<l00ol0003og]_ComkKd`03omkKd`;o00001?oWjm402_l0003ojOO<onWgc?oVo<Co
0000on;m_ooRoL7oiO^fongg`ol00002oo3_``;ohLo60ol00006omBi_`03o`000?o1Xk[o`J>j00Ko
`J>j0_l00003ok2C^@04o`000?n`TkWo/9>io`0000OoWX^n00?o0000ohAoaOn4OlD00_n4OlD2oe]/
b`;o00000_l8A<@5o`0001oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`05ooooo`003_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo023ooooo0ol00002oiMj/@03o`000?nFMjkoUWN^00OoUWN^00?o0000
oiEd[?nEM:`01?nEM:`00ol0003oUG>[oiEcZ`06oiEcZ`03o`000?nELj_oUG>[00KoUG>[00?o0000
oiEd[?nEM:`01_nEM:`2o`0000[oWh>d00?o0000oj>9^OnSRKT02_nSRKT01Ol0003oZ96nojRA__nX
TKko000000ko_:W700?o0000om34coo@a<l02?o@a<l00ol0003og]_ComkKd`02omkKd`;o00001OoW
jm400ol0003ojOO<onWgc002onKla005o`000?oRoL7oiO^fongg`ol000000_o`kl<3o`0000;oj=S4
1_oD^Kl00ol0003o`J>jol6S^P06ol6S^P03o`000?n`TkWo/9>i00Co/9>i00Co0000ok2C^On`TkWo
/9>i0_l00005oij;_P03o`000?n4OlGoQ7o500;oQ7o50omKK</2o`000003o`Q4a?l0003o000000?o
00007oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000003_ooool00omE
EEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01_ooool000kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Kooooo`Co00001_nGN[400ol0003oUWN^oiIg[P06oiIg[P03o`000?nEM:co
UGB/00GoUGB/00?o0000oiEcZonELj/01_nELj/00ol0003oUG>[oiEcZ`06oiEcZ`03o`000?nEM:co
UGB/00;oUGB/0ol000000onKOK7o0000oin3]00:oin3]003o`000?nSRKWoXhVi00[oXhVi00?o0000
ojRA__l000003_nlZLL00ol0003od<C?om34c`08om34c`04o`000?oNfm?og]_ComkKd`;o000000?o
gmS@o`000?oWjm400ooWjm400ol0003ojOO<o`000002onKla003onKk]ooRoL7oiO^f00Oo00000_oX
f<@6omBi_`03o`000?o1Xk[o`J>j00Ko`J>j00?o0000ok2C^On`TkT01_n`TkT00ol0003o/9>iok2C
^@02ok2C^@;o00001OnNRkh01?l0003oQ7o5ohAoaOn4OlD2oe]/b`;o64c700?o0000o`Q4a?l00000
0ol0000Pooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03
ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool02?ooool002Sooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Gooooo`?o00000_nIOkH00ol0003oUgZaoiMj/@06oiMj/@03o`00
0?nFMjkoUWN^00KoUWN^00?o0000oiEd[?nEM:`01OnEM:`00ol0003oUG>[oiEcZ`06oiEcZ`03o`00
0?nELj_oUG>[00KoUG>[00Co0000oiEd[?l0003o00001OnKOK400ol0003oWh>doin3]009oin3]0;o
00002_nSRKT3o`0000go_:W700?o0000om34coo@a<l02?o@a<l00ol0003og]_Co`000002o`0000;o
gmS@00Co0000onO[dOoWjm7oin_A0_l000001ooYmlco0000o`000?oVo<Coi_^gon;m_ooMnJ`00ol0
00000oo`kl?o0000o`000003onSHa003o`000?oD^Kooe;Vo00;oe;Vo0_l000000oo1Xk[o0000o`00
0006o`0000Wo/9>i00?o0000ok2C^On`TkT01?n`TkT5o`000003oij;__l0003oQ7o500;oQ7o50_mK
K</2oaQ<a`03o`000?l06jSo026]00?o00007Oooool3o`0000Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`08ooooo`00
:?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01?ooooo0ol00006oiUo]P03o`00
0?nGN[7oUgZa00KoUgZa00?o0000oiIg[_nFMjh01_nFMjh00ol0003oUGB/oiEd[005oiEd[003o`00
0?nELj_oUG>[00GoUG>[00?o0000oiEcZonELj/01_nELj/2o`0000SoVgfa00?o0000oin3]?nOPk@0
2_nOPk@00ol0003oXhVioj>9^@06oj>9^@04o`000?nfX<;o]Z32okJP`P?o00002OnlZLL00ol0003o
d<C?om34c`08om34c`?o00001?oOf=001_l0003oin_AonO[dOoWjm7o0000on[[cP;o000000?ok?S4
onKla?oVnkL01?l00003oo3_``05o`000?oXf<Coj=S4onSHa?l000000ooD^Kl2o`000003omc1__l0
003objVh00OobjVh00?o0000okbI]OnlVKD00ol00005ok2C^@03o`000?n`TkWo000000;o00000onQ
R;X3oh]o`@Co00000_n4OlD2oe]/b`;o64c700?o0000o`0KZ?l08Jd00_l0000Pooooo`09o`000?oo
ooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001oooool002Oo
oooo0_l0000Qooooo`03o`000?oooooooooo013ooooo0_l00003oi^6_0OoVGnf00?o0000oiMj/OnG
N[401_nGN[400ol0003oUWN^oiIg[P05oiIg[P03o`000?nEM:coUGB/00GoUGB/00?o0000oiEcZonE
Lj/01_nELj/00ol0003oUG>[oiEcZ`02oiEcZ`?o000000?oUgV`o`000?nKOK402?nKOK400ol0003o
Wh>doin3]00:oin3]003o`000?nSRKWoXhVi00?oXhVi0_l00007okJP`P?o00001OnlZLL00ol0003o
d<C?om34c`08om34c`;o00001OoOf=000ol0003oin_AonO[d@02o`000004on[[c_l0003o0000onch
a0Co000000?oiO^fo`000?o`kl<00_o`kl<01Ol0003oj=S4onSHa?oXf<Co000000;oe;Vo0_l00002
omc1_P03o`000?o;ZKSobjVh00KobjVh00?o0000okbI]OnlVKD01?nlVKD3o`0000;o/9>i0_l00007
oj68^PGoRgo11?l00002oe]/b`;o64c700?o0000o`0KZ?l08Jd00_l0000Oooooo`03o`000?oooooo
oooo02Gooooo000Wooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03Oooool2o`00
00KoVhJl00?o0000oiUo]_nIOkH01?nIOkH00ol0003oUgZaoiMj/@06oiMj/@03o`000?nFMjkoUWN^
00GoUWN^00?o0000oiEd[?nEM:`01OnEM:`00ol0003oUG>[oiEcZ`06oiEcZ`04o`000?nELj_o0000
o`0000GoUgV`00?o0000oi]m/OnKOK401onKOK400ol0003oWh>doin3]00:oin3]005o`000?nSRKWo
XhVioj>9^Ol000003?nfX<83o`000003okbYaol0003od<C?00?od<C?1ol00006omoHd004o`000?oW
jm7o0000o`0000;oj^_>1?l000001OoVnkOo0000o`000?oMnJco000000?ol>o300?o0000onSHa?oX
f<@00_oXf<@3o`0000?og<6n00?o0000ol^Y^?o;ZKP01_o;ZKP00ol0003o_9VeokbI]@08okbI]@;o
00000_nQR;X00ol0003oXHRjoj68^P05oj68^P03o`000?n;Ol7oRgo100;oRgo100?o0000ofQab?mX
LLP00_l000001_mKK<_o64c7oaQ<aol0003o01^Xo`0Q[@;o00007oooool00ol0003oooooooooo`0T
ooooo`009oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo0ol00009oi^6
_003o`000?nIOkKoVGnf00CoVGnf00?o0000oiMj/OnGN[401OnGN[400ol0003oUWN^oiIg[P06oiIg
[P03o`000?nEM:coUGB/00GoUGB/00?o0000oiEcZonELj/01?nELj/3o`0000SoUgV`00?o0000oi]m
/OnKOK401onKOK400ol0003oWh>doin3]00:oin3]003o`000?nSRKWo0000013o]Z321_l00005olfm
b`03o`000?oOf=3ogmS@00GogmS@0_l00002on[[cP?o000000Sok?S4o`000?oVnkOo0000omkj[?l0
003oiO^fo`0000;ol>o30_l00003onSHa0;o00001?oL`Kh00ol0003objVhol^Y^006ol^Y^003o`00
0?nlVKGo_9Ve00So_9Ve00Ko0000ojn?]?n_SkCo[hndoj68^_l00008oj68^P03o`000?n;Ol7oRgo1
00;oRgo100Co0000ofQab?mXLLSoJ7780_l00002oaQ<a`03o`000?l06jSo026]00;o00007oooool0
0ol0003oooooooooo`0Sooooo`009oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
00Gooooo0ol00004oij>``WoVhJl00?o0000oiUo]_nIOkH01?nIOkH00ol0003oUgZaoiMj/@05oiMj
/@03o`000?nFMjkoUWN^00KoUWN^00?o0000oiEd[?nEM:`01OnEM:`00ol0003oUG>[oiEcZ`03o`00
00;oTgJ_00?o0000oiMi/?nGNK001onGNK000ol0003oVgfaoi]m/@07oi]m/@03o`000?nOPkCoWh>d
00WoWh>d0_l0000@okJP`P03o`000?o=_L_ocKg;00SocKg;00?o0000omoHd?oOf=001OoOf=07o`00
0008oncha?l0003oi_^gonKk]ooNnZco0000onGk]_l00002oo3_``04o`000?o^n;koj=S4onSHa0;o
00001OoL`Kh00ol0003objVhol^Y^006ol^Y^003o`000?nlVKGo_9Ve00So_9Ve00?o0000ojn?]?n_
Sk@01?n_Sk@00ol0003oXHRjoj68^P06oj68^P03o`000?n;Ol7oRgo100;oRgo100[o0000ofQab?mX
LLSo0000obaGbol0003o64c7o`0R[_l0003o01^X0_l0000Oooooo`03o`000?oooooooooo02?ooooo
000Wooooo`03o`000?oooooooooo02Cooooo00Co0000oooooooooooooooo0ol00008oij>``03o`00
0?nKQ[coVhJl00KoVhJl00?o0000oiUo]_nIOkH01?nIOkH00ol0003oUgZaoiMj/@05oiMj/@03o`00
0?nFMjkoUWN^00GoUWN^00?o0000oiEd[?nEM:`01?nEM:`4o`0000KoTgJ_00?o0000oiMi/?nGNK00
1onGNK000ol0003oVgfaoi]m/@07oi]m/@03o`000?nOPkCoWh>d00OoWh>d00Co0000ok2G__n`Ukko
/9Nn0_l0000<okJP`P03o`000?o=_L_ocKg;00SocKg;00?o0000omoHd?oOf=001OoOf=03o`0000?o
j^_>00Oo0000oncha?l0003oi_^go`000?oNnZcogOV/00;o00000_o`kl<01ol0003ok_RnonSHa?oX
f<Co0000ongSaOl000001OoL`Kh00ol0003objVhol^Y^005ol^Y^003o`000?nlVKGo_9Ve00So_9Ve
00?o0000ojn?]?n_Sk@01_n_Sk@2o`0000OoXHRj00?o0000oh]o`On;Ol400_n;Ol402_l0003oJ778
ofQab?l0003o;5O;o`000?lHC<Oo02:^o`000?l06jP2o`0001gooooo00?o0000ooooool000009?oo
ool002Oooooo0_l0000Vooooo`?o00000onQV</9oij>``03o`000?nKQ[coVhJl00KoVhJl00?o0000
oiUo]_nIOkH01?nIOkH00ol0003oUgZaoiMj/@05oiMj/@03o`000?nFMjkoUWN^00GoUWN^00?o0000
oiEd[?nEM:`00ol00002oi5d[`03o`000?nCMZooTgJ_00KoTgJ_00?o0000oiMi/?nGNK001_nGNK00
0ol0003oVgfaoi]m/@08oi]m/@03o`000?nOPkCoWh>d00CoWh>d0_l00006ok2G_P;o00002OnfX<80
0ol0003ocKg;olfmb`08olfmb`03o`000?oOf=3ogmS@00CogmS@0ol00004on[[cP03o`000?o/n<Co
000000;oi_^g00?o0000omkj[?l000000_l000001_o`kl?o0000onkh__l0003oj=S4o`0000;okN?5
1OoL`Kh00ol0003objVhol^Y^003ol^Y^0?o000000?o_9Veo`000?l000000_l00005okbI]@03o`00
0?n_SkCo[hnd00So[hnd0ol00006oj68^P03o`000?n;Ol7oRgo100;oRgo100[o0000ofQab?mXLLSo
0000obaGbol0003o64c7o`0R[_l0003o01^X0_l0000Oooooo`03o`000?oooooooooo027ooooo000V
ooooo`;o00009Oooool2o`0000SoXIS;00?o0000oij>`onNS/<01OnNS/<2o`0000OoVhJl00?o0000
oiUo]_nIOkH01?nIOkH00ol0003oUgZaoiMj/@05oiMj/@03o`000?nFMjkoUWN^00;oUWN^1Ol00006
oi5d[`03o`000?nCMZooTgJ_00KoTgJ_00?o0000oiMi/?nGNK001_nGNK000ol0003oVgfaoi]m/@08
oi]m/@04o`000?nOPkCoWh>doin3]0;o00002_n`Ukh00ol0003o]Z32okJP`P05okJP`P03o`000?o=
_L_ocKg;00SocKg;00?o0000omoHd?oOf=000_oOf=03o`000003omgDcol0003oj^_>00?oj^_>0ol0
0002onKk]`Go000000Kol>o3o`000?o^n;ko0000onSHa?l00002ongSa@Gog<6n00?o0000ol^Y^?l0
00001?l00002om6_^003o`000?o4W[?oa9jc00?oa9jc1Ol0000;ojn?]004o`000?n_SkCo[hndo`00
00KoXHRj00?o0000oh]o`On;Ol400_n;Ol402?l0003oJ778ofQab?l0003o;5O;o`000?lHC<Oo02:^
1?l0000Nooooo`03o`000?oooooooooo027ooooo000Vooooo`03o`000?oooooooooo02;ooooo0_l0
000<oj6Hb`03o`000?nNS/?oWXk300GoWXk300?o0000oi^6_?nKQ[`01OnKQ[`00ol0003oVGnfoiUo
]P04oiUo]P03o`000?nGN[7oUgZa00;oUgZa1ol00003ohic/003o`000?nAM:ooTGB_00KoTGB_00?o
0000oi=f[onCMZl01_nCMZl00ol0003oUgV`oiMi/006oiMi/003o`000?nKOK7oVgfa00SoVgfa00?o
0000oin3]?l000003On`Ukh2o`0000Co]Z3200?o0000olfmboo=_L/02?o=_L/00ol0003ogmS@omoH
d003o`0000?ogMC?00Co0000on[[c_oZjlkoj^_>0ol000000oo[nL7o0000onKk]`07o`000004onkh
__l0003o0000o`0000;okN?51?oL`Kh4o`0000KodJnh00?o0000olBN/oo4W[<01oo4W[<00ol0003o
^IBaokVD/@02o`0000Wo[hnd00?o0000ojn?]?n_Sk@02_l00002oh]o`@08o`000?mXLLSoJ778o`00
0?l/El_o0000oaQ<aol08Zh4o`0001kooooo00?o0000ooooooooool08?ooool002Kooooo00?o0000
ooooooooool07oooool3o`0000?oXj?D0_l0000:oj6Hb`;o00001_nNS/<00ol0003oVhJloi^6_005
oi^6_004o`000?nIOkKoVGnfoiUo]POo00000on=M;800ol0003oSW>`ohic/005ohic/003o`000?nA
M:ooTGB_00KoTGB_00?o0000oi=f[onCMZl01OnCMZl00ol0003oUgV`oiMi/007oiMi/003o`000?nK
OK7oVgfa00OoVgfa0_l0000@ok2G_P;o000000?o]Z32o`000?o=_L/02Oo=_L/4o`0000GogMC?00?o
0000on[[c_oZjlh00_l000001OoZjlgo0000on_i`Oo[nL7oi_^g00Co000000Co_nV:o`000?l0003o
k_Rn0_l00003ongSa@?og<6n0_l000000ooQbL7o0000om6_^006om6_^003o`000?o4W[?oa9jc00Oo
a9jc00?o0000okVD/OniU;400oniU;43o`0000Go[hnd0ol00003oj>8]`KoTH6n00?o0000ogEgaol0
00000ol00002ofQab005o`000?l/El_o0000o`000?l08Zh00ol0000Oooooo`03o`000?oooooooooo
01oooooo000Vooooo`03o`000?oooooooooo01cooooo0ol00008oj>Se0?o00002OnQV</2o`0000Go
WXk300?o0000oi^6_?nKQ[`00_nKQ[`6o`0000?oS7Nf00?o0000ohed/_n=M;801On=M;800ol0003o
SW>`ohic/005ohic/003o`000?nAM:ooTGB_00GoTGB_00?o0000oi=f[onCMZl01_nCMZl00ol0003o
UgV`oiMi/006oiMi/003o`000?nKOK7oVgfa00KoVgfa00Go0000ojR?^onXSk_oZ8nko`00000@ok2G
_Pgo00001ooMe<l01?l0003oj^_>on[[c_l00002on[[c@04o`000?o[nL7ojoW1onKk]`Oo00000_o^
n;h01_l0003okN?5ongSaOo]hlGo0000omc1_P;o00000_oQbL400ol0003odJnhom6_^005om6_^003
o`000?o4W[?oa9jc00Ooa9jc00?o0000okVD/OniU;401oniU;42o`000003ojn?]?l0003o000000?o
XhRg00Go0000oj>8]onSR;OoXhRgo`000005oi61_P04o`000?meMlOoMGO7ogEga`Co000000Go;5O;
o`0_^?l0;kSo0000o`0R[P03o`0001kooooo00?o0000ooooooooool07oooool002Kooooo00?o0000
ooooooooool06Oooool3o`0000?oYJgL0_l00009oj>Se0;o00002OnQV</:o`0000?oSG^k00?o0000
ohag]_n<MkH01?n<MkH00ol0003oSGBbohed/P05ohed/P03o`000?n>Lk3oSW>`00GoSW>`00?o0000
oi5d[onAM:l01OnAM:l00ol0003oTgJ_oi=f[`06oi=f[`03o`000?nGNK3oUgV`00KoUgV`00?o0000
oi]m/OnKOK400onKOK42o`0000GoZ8nk0_l0000=ok2G_P03o`000?o7]LSoakG800GoakG80ol00000
0oo7]LSo0000omgDc`06omgDc`04o`000?oZjlko0000o`0000;oj^_=00?o0000on_i`Oo[nL401_l0
00001OoJmjGo0000onkh__o^n;ko000000?okN?50ol00003on79`@03o`000?oA[kSodJnh00KodJnh
00?o0000olBN/oo4W[<01_o4W[<00ol0003o^IBaokVD/@0:okVD/@03o`000?nSR;OoXhRg00?oXhRg
00?o0000oj>8]onSR;L00_nSR;L00ol0003oTH6noi61_P03oi61_P06o`000?meMlOoMGO7ogEgaol0
003o@VC?0_l000001Ol/El_o02nho`0_^?l0003o02:^00?o00007?ooool00ol0003oooooo`00000P
ooooo`009Oooool3o`0001Oooooo0ol00009ojF]g0?o00001onSXm@2o`0000;oXIS;0ol00004oi6;
b@KoSX;11_n=Nk/00ol0003oS7Nfohag]P04ohag]P03o`000?n=M;;oSGBb00GoSGBb00?o0000ohic
/?n>Lk001On>Lk000ol0003oTGB_oi5d[`05oi5d[`03o`000?nCMZooTgJ_00KoTgJ_00?o0000oiMi
/?nGNK001_nGNK001Ol0003oVgfaoi]m/OnKOK7o000000WoZ8nk00?o0000ok2G__n`Ukh02On`Ukh0
0ol0003oakG8olNeb003olNeb0?o00000oo7]LP00ol0003ogMC?omgDc`05omgDc`?o00000ooZjld0
0ol0003ojoW1on_i`@02o`000003on3j[Ol0003o000000?o00000_o^n;h01?l0003okN?5ongSaOo]
hlD2o`0000GohLW100?o0000om6_^?oA[kP01OoA[kP00ol0003oa9jcolBN/`06olBN/`03o`000?ni
U;7o^IBa00Wo^IBa00Co0000ojn=/_n_SK;o[hfb1OnSR;L00ol0003oXhRgoj>8]`02oj>8]`03o`00
0?nAPKkoTH6n00?oTH6n00Ko0000ogEgaomeMlOoMGO7o`000?m2I<l2o`000003obaGbol0;kSo02nh
00Go00007_ooool00ol0003oooooooooo`0Mooooo`009_ooool00ol0003oooooooooo`0Cooooo`?o
00001?nW]N<2o`0000WoYJgL0ol00003oj>Se003o`000?nSXmCoXj?D00;o00002?nARlT00ol0003o
SX;1ohj2`@03ohj2`@03o`000?n=Nk_oSG^k00?oSG^k00?o0000ohag]_n<MkH01?n<MkH00ol0003o
SGBbohed/P05ohed/P03o`000?n>Lk3oSW>`00CoSW>`00?o0000oi5d[onAM:l01_nAM:l00ol0003o
TgJ_oi=f[`05oi=f[`03o`000?nGNK3oUgV`00OoUgV`00?o0000oi]m/Ol000002onXSk/2o`0000So
/9Nn00Co0000olNeb?o7]LSoakG80ol00005olNeb003o`000?oMe<oogMC?00GogMC?0_l00004on[[
c@03o`000?o[nL7ojoW100;o000000?oh?Z]o`000?l000000_l000000ooJmjGo0000onkh_P02o`00
0003ongSaOl0003o000000KohLW100?o0000om6_^?oA[kP01OoA[kP00ol0003oa9jcolBN/`06olBN
/`03o`000?niU;7o^IBa00Wo^IBa00?o0000ojn=/_n_SK800on_SK82o`0000?oXhRg00?o0000oj>8
]onSR;L00_nSR;L00ol0003oTH6noi61_P03oi61_P05o`000?meMlOoMGO7ogEgaol000000_m2I<l0
1?l0003o;5O;o`0_^?l0;kP4o`0001kooooo00?o0000ooooooooool07Oooool002Kooooo00?o0000
ooooooooool04Oooool2o`0000_oYkGS0ol00007ojF]g0?o00001OnEUM49oi6;b@03o`000?n>P/7o
SX;100?oSX;100?o0000ohek^on=Nk/00on=Nk/00ol0003oS7Nfohag]P04ohag]P03o`000?n=M;;o
SGBb00CoSGBb00?o0000ohic/?n>Lk001On>Lk000ol0003oTGB_oi5d[`05oi5d[`03o`000?nCMZoo
TgJ_00KoTgJ_00?o0000oiMi/?nGNK001_nGNK02o`0000koZ8nk00?o0000ok2G__n`Ukh01?n`Ukh0
0ol0003oakG8o`000002o`0000OoakG800?o0000omgDcooMe<l01OoMe<l2o`0000Coj^_=00?o0000
on_i`Oo[nL400_l000000ooPnZgo0000o`000002o`000009om[gYOl0003ok_Rno`000?oMo;OokN?5
o`000?o/l<_o000000GohLW100?o0000om6_^?oA[kP00ooA[kP<o`0000;o^IBa00?o0000okVD/Oni
U;401_niU;400ol0003o[hfbojn=/P06ojn=/P04o`000?nSR;OoXhRgo`0000GoXhRg00?o0000oi61
__nAPKh00onAPKh01Ol0003oMGO7ogEgaomeMlOo000000;o@VC?00Co0000obaGbol0;kSo02nh1?l0
000Nooooo`03o`000?oooooooooo01cooooo000Uooooo`03o`000?oooooooooo013ooooo0_l0000@
ojNeh`Co00001OnJXMT00ol0003oUIGAoiFEd@05oiFEd@03o`000?nARlWoTH_900GoTH_900?o0000
ohj2`On>P/400on>P/400ol0003oSG^kohek^`03ohek^`03o`000?n<MkKoS7Nf00CoS7Nf00?o0000
ohed/_n=M;801?n=M;800ol0003oSW>`ohic/005ohic/003o`000?nAM:ooTGB_00GoTGB_00?o0000
oi=f[onCMZl01_nCMZl00ol0003oUgV`oiMi/002oiMi/0?o00000onQQkT00ol0003oZ8nkojR?^`0;
ojR?^`;o00000on`Ukh3o`0000WoakG800?o0000omgDcooMe<l01?oMe<l2o`0000Goj^_=00Ko0000
on_i`Oo[nL7ojoW1o`000?oPnZd4o`000007om[gYOl0003ok_Rno`000?oMo;OokN?5o`000002onc`
b`KohLW100?o0000om6_^?oA[kP00ol00002omBe^P03o`000?o8Xk;ob:>b00Kob:>b00Co0000oknH
[onoV:oo_iR_1Ol00002okVD/@03o`000?n_SK;o[hfb00So[hfb00Co0000oj>8]onSR;Oo00001OnS
R;L00ol0003oTH6noi61_P03oi61_P05o`000?meMlOoMGO7ogEgaol000000_m2I<l2o`0000;o02nh
00Co02:^o`000?l0003o00007_ooool00ol0003oooooooooo`0Kooooo`009Oooool00ol0003ooooo
ooooo`0=ooooo`?o00001OnW^^L5o`0000CoYkGS0ol00004oin/h003o`000?nJXMWoVZ7I00GoVZ7I
0_l00006oiFEd@03o`000?nARlWoTH_900CoTH_900?o0000ohj2`On>P/400on>P/400ol0003oSG^k
ohek^`03ohek^`03o`000?n<MkKoS7Nf00CoS7Nf00?o0000ohed/_n=M;801?n=M;800ol0003oSW>`
ohic/005ohic/003o`000?nAM:ooTGB_00GoTGB_00?o0000oi=f[onCMZl01_nCMZl01?l0003oUgV`
o`000?l00007oj67^@03o`000?nXSk_oZ8nk00coZ8nk0ol0000<olNeb004o`000?oMe<oogMC?omgD
c`?o000000?ofLo?o`000?oZjld00ooZjld01Ol0003ojoW1on_i`Oo[nL7o000000;oh?Z]1ol00000
0ooMo;Oo0000o`000002onc`b`KohLW11?l00004omBe^P03o`000?o8Xk;ob:>b00Kob:>b00?o0000
oknH[onoV:l01onoV:l2o`0000co[hfb0_l000000onSR;Oo0000oj>8]`04oj>8]`03o`000?nAPKko
TH6n00?oTH6n00Wo0000ogEgaomeMlOoMGO7o`000?m2I<oo0000o`12a?l000000_l0;kP4o`0001co
oooo0_l0000Mooooo`009Oooool3o`0000[ooooo0ol0000=ojNji`Co00002_nO[>02o`0000KoVZ7I
0_l00004oiFEd@;o00001OnARlT00ol0003oSX;1ohj2`@03ohj2`@03o`000?n=Nk_oSG^k00?oSG^k
00?o0000ohag]_n<MkH00on<MkH00ol0003oSGBbohed/P05ohed/P03o`000?n>Lk3oSW>`00CoSW>`
00?o0000oi5d[onAM:l01OnAM:l00ol0003oTgJ_oi=f[`06oi=f[`;o00002_nQQkT00ol0003oZ8nk
ojR?^`08ojR?^`So00002Oo7]LP00ol0003ogMC?o`000002o`0000?ofLo?00Co0000on[[cOoZjlgo
j^_=0_l00003on_i`@03o`000?oPnZgoh?Z]00Oo000000?ogObgo`000?l000000_o/l</00ol0003o
hLW1on79`@02on79`@?o00001_oD]KX00ol0003ob:>bolRS/P06olRS/P03o`000?noV:oo_iR_00Wo
_iR_00Co0000okRA[ol0003o00002on_SK800ol0003oXhRgo`000002oj>8]`So000000?oTH6no`00
0?meMlL00_meMlL01_l0003o@VC?o`000?l0@/Co0000o`0_^0Co00007_ooool00ol0003ooooooooo
o`0Jooooo`009Oooool00ol0003oooooooooo`07ooooo`?o00001OnW_^X5o`0000CoYk[W0ol00004
oj:gj0;o00002OnO[>03o`0000GoVZ7I0_l00004oiFEd@;o00001?nARlT00ol0003oSX;1ohj2`@03
ohj2`@03o`000?n=Nk_oSG^k00?oSG^k00?o0000ohag]_n<MkH00on<MkH00ol0003oSGBbohed/P04
ohed/P03o`000?n>Lk3oSW>`00GoSW>`00?o0000oi5d[onAM:l01OnAM:l00ol0003oTgJ_oi=f[`02
oi=f[`?o00000_nIPKL00ol0003oXHNioj67^@08oj67^@;o00001OnXSk/3o`0000;oZ8nk00?o0000
okn/aono[<L00ono[<L5o`0000?oakG80ol00005omW?c`07o`000?oZjlgoj^_=on[[cOl0003oin_@
o`000002on_i`@;o000000?oh?Z]o`000?l000000_l000001?oJmjGo0000o`000?oMo;L2o`0000;o
k?3;00Co0000on79`OoQbL7ohLW10_l000000ooRdlSo0000omBe^P06omBe^P03o`000?o8Xk;ob:>b
00Kob:>b00?o0000oknH[onoV:l02?noV:l00ol0003o^96_okRA[`02okRA[`;o00002_n_SK84o`00
00GoV8Bl0on1OLH4o`0000;oMGO700Ko0000od9Tcol0003o04;4o`000?l0;kP4o`0001kooooo00?o
0000ooooooooool06Oooool001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo00Gooooo0_l0000=ojNnjPCo00002onR]nP3o`0000OoWjcP1_l000000onJXMWo0000o`00
0003o`000003oiFEdOl0003o000000;o000000?oTH_9o`000?n>P/401?n>P/400ol0003oSG^kohek
^`03ohek^`03o`000?n<MkKoS7Nf00?oS7Nf00?o0000ohed/_n=M;801?n=M;800ol0003oSW>`ohic
/005ohic/003o`000?nAM:ooTGB_00GoTGB_00Co0000oi=f[ol0003o00001_nIPKL00ol0003oXHNi
oj67^@09oj67^@03o`000?nXSk_o000000;o00001?nXSk/00ol0003o_jc7okn/a`09okn/a`?o0000
2?oIcll01_l0003oj^_=on[[cOl0003oin_@o`0000;ojoW100?o0000onKl`_oPnZd01ol00002omgl
]`05o`000?o/l<_ok?3;onc`bol000000_oQbL401?l0003oh]?8on;Cb?l00007omBe^P03o`000?o8
Xk;ob:>b00Kob:>b00?o0000oknH[onoV:l02?noV:l00ol0003o^96_okRA[`05okRA[`;o00001On_
SK82o`0000?oYhVe00?o0000oiR4_?nHQ;`01OnHQ;`5oh5maP?o000000CoMGO7o`000?m2I<oo0000
0_l0@/@00ol0;kSo0000o`000002o`0001gooooo00?o0000ooooooooool06Oooool001[ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Wooooo1Ol00004ojNnjP?o0000
1OnU_^`5o`0000OoX[OX1?l00005ohfSi0OoQYGK1_moR=<2og]nb`Oo000000?oSX;1o`000?n=Nk/0
1?n=Nk/00ol0003oS7Nfohag]P03ohag]P03o`000?n=M;;oSGBb00CoSGBb00?o0000ohic/?n>Lk00
1On>Lk000ol0003oTGB_oi5d[`02oi5d[`Co00002OnIPKL00ol0003oXHNioj67^@07oj67^@?o0000
1OnXSk/2o`0000ko_jc700?o0000omW?cooIcll01OoIcll01_l0003oj^_=o`000?l0003oin_@o`00
00;ojoW100?o0000onKl`_oPnZd01ol00002omgl]`06o`000?o/l<_ok?3;onc`bol0003ohLW10_l0
0002on;Cb003o`000?oD]K[oe;Fj00Goe;Fj00?o0000olRS/_o8Xk801_o8Xk800ol0003o_iR_oknH
[`08oknH[`03o`000?nhTJoo^96_00So^96_0_l000000on_SK;o0000o`000006ojN9]@03o`000?nH
Q;coV8Bl00GoV8Bl00?o0000oh5ma_n1OLH00_n1OLH00ol0003oF7;Bo`000002o`000005od9Tcol0
003o04;4o`12a?l0;kP00ol0000Nooooo`03o`000?oooooooooo01Sooooo000Jooooo`05oa0@4?oo
ooooooooooooool@41001Oooool00ol0003oooooooooo`0?ooooo`Co00003OnU_^`5o`0000GoU[3Y
00?o0000ohfSi?n=Xn@01On=Xn@00ol0003oQYGKohJEf`03ohJEf`03o`000?moR=?oOhSC00?oOhSC
1OmkO//3og]ga0go000000?oS7Nfo`000?n=M;801On=M;800ol0003oSW>`ohic/002ohic/0Oo0000
0onBNkH00ol0003oVH6goiV1]`08oiV1]`03o`000?nQQkWoXHNi00CoXHNi0_l00003oj67^@05o`00
0?nXSk_oZ8nkojR?^ol000003ono[<L00ol0003ofLo?omW?c`05omW?c`03o`000?oZjlgo000000?o
in_@00Co0000on_i`Ol0003oi_c22?l00002omgl]`04o`000?o/l<_ok?3;onc`b`?o00001?oRdlP0
0ol0003oe;FjomBe^P04omBe^P03o`000?o8Xk;ob:>b00Oob:>b00?o0000oknH[onoV:l02?noV:l0
0ol0003o^96_okRA[`0:okRA[`;o00002?nWRKD00ol0003oV8BloiR4_005oiR4_003o`000?n1OLKo
PGg600;oPGg600?o0000oeQbd_mHL]800_l000001?m2I<oo0000o`12a?l0@/@4o`0001gooooo00?o
0000ooooooooool01oooool4o`000003oa0@4?oooooooooo00[ooooo000Jooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`0Eooooo`Go00001?nU_^`3o`0000CoX[WY00?o
0000oiJ`jOnF/>T01OnF/>T2o`0000KoSJ?T1On6UM/00ol0003oOhSCogn8d`02ogn8d`03o`000?mk
O/_oNgk;00;oNgk;1?mkMl@00ol0003oO7>nogac_P03ogac_P03o`000?n0L[[oP7:j00;oP7:j3Ol0
0003oh]g]`03o`000?nBNkKoTW^f00GoTW^f00?o0000oiV1]onIPKL02?nIPKL00ol0003oXHNioj67
^@03o`0000KoXHNi00?o0000ojR?^ol000003ono[<L00ol0003ofLo?omW?c`05omW?c`?o00000ooW
jm001?l0003ojoW1o`000?oVo<82o`000003om;gY?l0003o000000?o00000_oMo;L2o`0000?ok?3;
00?o0000on;Cb?oRdlP00ooRdlP00ol0003oe;FjomBe^P05omBe^P03o`000?o8Xk;ob:>b00Kob:>b
00?o0000oknH[onoV:l02?noV:l00ol0003o^96_okRA[`09okRA[`05o`000?naSK3o/Hf`ok6=/?l0
00001onWRKD3o`0000KoV8Bl00?o0000oh5ma_n1OLH00_n1OLH01?l0003oF7;BoeQbd_mHL]83o`00
0003o`12a?l0003o000000;o00007?ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo
00cooooo000Jooooo`05o`000?ooooooooooooooool000001Oooool2o`0001_ooooo1?l0000;oj:i
j@?o00001?nF/>T3o`0000CoSJ?T00Go0000ohJEfon6UM_oQYGKo`000004ogn8d`03o`000?mkO/_o
Ngk;00;oNgk;00Go0000og]ga?mkMlCoNgO4o`000005ogac_P03o`000?n0L[[oP7:j00?oP7:j00?o
0000ohEc^?n5LkP01?n5LkP00ol0003oRgNgoh]g]`05oh]g]`03o`000?nBNkKoTW^f00GoTW^f00?o
0000oiV1]onIPKL01onIPKL3o`0000WoXHNi1?l0000=okn/a`03o`000?oIcloofLo?00KofLo?00?o
0000onO[d?oWjm000_oWjm001_l0003ojoW1o`000?oVo<;o0000on3j[@Oo000000?ogObgo`000?l0
00000_o/l</2o`0000Goh]?800?o0000omBe^_oD]KX01OoD]KX01?l0003ob:>bolRS/_o8Xk8;o`00
00Go_iR_00?o0000okRA[onhTJl02OnhTJl00ol0003o/Hf`ok6=/003ok6=/0;o00001_nWRKD00ol0
003oYhVeo`000006oiR4_003o`000?n1OLKoPGg600;oPGg600Co0000oeQbd_mHL];oF7;B0ol00000
0ol0@/Co0000o`000002o`0001kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<
ooooo`006_ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool08?ooool5
o`0000OoX[WY1Ol00002oiJ`j@Go000000CoSJ?To`000?n6UM_oQYGK0_l00004ogn8d`05o`000?mk
O/_oNgk;og]nbol000000omkMl@00ol0003oO7>nogac_P03ogac_P03o`000?n0L[[oP7:j00?oP7:j
00?o0000ohEc^?n5LkP01?n5LkP00ol0003oRgNgoh]g]`05oh]g]`03o`000?nBNkKoTW^f00GoTW^f
00?o0000oiV1]onIPKL00onIPKL3o`0000;oVH6g00?o0000oj67^OnQQkT01_nQQkT00ol0003o]J?6
okFSaP02okFSaP?o00002Ono[<L00ol0003ofLo?omW?c`06omW?c`03o`000?oWjm3oin_@00?oin_@
0_l00002onKl`P;o000000?od_NTo`000?l000000ol000000ooMo;Oo0000o`000002onc`b`03o`00
0?oNoM?o000000Coh]?800?o0000omBe^_oD]KX00ooD]KX7o`0000GobjNd00?o0000olBL[oo4W:l0
0oo4W:l7o`0000Wo^96_00?o0000ok6=/?naSK001_naSK000ol0003oYhVeojN9]@04ojN9]@03o`00
0?nWRKGo000000KoV8Bl00?o0000oh5ma_n1OLH00_n1OLH01?l0003oF7;BoeQbd_mHL]83o`000005
o`12a?l0003o0000o`0?V_l000007Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00cooooo000Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0Uoooo
o`Go00001_nB^o<5ogjZl0KoJiW[00CoGhSRohJEfon6UM_o00001?moR=<01Ol0003oNgk;og]nbomk
O/_o000000?oNgO400?o0000ogac__mlLkh00omlLkh00ol0003oP7:joh1b^P03oh1b^P03o`000?n5
LkSoQG>h00CoQG>h00?o0000oh]g]on;MkL01On;MkL00ol0003oTW^foi9k]P05oi9k]P03o`000?nI
PKOo000000;o00001_nIPKL00ol0003oXHNioj67^@03oj67^@;o00002?neXlH3o`0000Go_jc700?o
0000omW?cooIcll00ooIcll4o`0000Goin_@0_l00002onKl`P;o000000?od_NTo`000?l000000ol0
00001?oMo;Oo0000o`000?o/l</2o`000003omkmdol0003oh]?800Coh]?800?o0000omBe^_oD]KX0
0ol00002omFi_P03o`000?o;YkCobjNd00KobjNd00?o0000olBL[oo4W:l02?o4W:l00ol0003o_YB/
okjD[003o`0000Go^96_00?o0000ok6=/?naSK002?naSK000ol0003oYhVeojN9]@04ojN9]@03o`00
0?nWRKGo000000KoV8Bl00?o0000oh5ma_n1OLH00_n1OLH02?l0003oF7;BoeQbd_mHL];o0000oa1I
d_l0003o04;40_l000000ol03i[o0000ooooo`0Looooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool03?ooool001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooo
oooo02[ooooo00?o0000oi:klonB^o<01_nB^o<00ol0003oOZ[`ogjZl002ogjZl0GoJiW[0_mOR>83
o`0000;oOhSC00Go0000og]nbomkO/_oNgk;o`000003og]ga003o`000?mlLkkoO7>n00?oO7>n00?o
0000oh1b^_n0L[X00on0L[X00ol0003oQG>hohEc^004ohEc^003o`000?n;MkOoRgNg00CoRgNg00?o
0000oi9k]_nBNkH01?nBNkH3o`0000[oVH6g00Go0000oj67^OnQQkWoXHNio`00000=okFSaP?o0000
00?o_jc7o`000?oIcll01Ol00003om79d@03o`000?oWjm3oin_@00?oin_@00Ko0000onKl`_oVo<;o
i_c2o`000?oBmj@8o`000005onc`bol0003og_gComkmdol000001OoRdlP4o`0000CoeKVn00?o0000
ol^W]?o;Yk@01_o;Yk@00ol0003oa9b_olBL[`08olBL[`03o`000?nnU:co_YB/00Co_YB/0ol00000
0onhTJoo0000ok6=/00;ok6=/0;o00001?nWRKD00ol0003oYhVeo`000009o`0000?oPGg600So0000
oeQbd_mHL];oF7;Bo`000?l@FM;o0000o`12a0?o00007_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00cooooo000Sooooo`03o`000?oooooooooo033ooooo1Ol00002oi:kl`?o0000
0_mnZ_04of^Ij`;oGhSR00?oF7[Jo`000?l000000_l00003og]nb`05o`000?mkMlCoNgO4og]ga?l0
00001OmlLkh00ol0003oP7:joh1b^P03oh1b^P03o`000?n5LkSoQG>h00?oQG>h00?o0000oh]g]on;
MkL01On;MkL00ol0003oTW^foi9k]P03o`0000?oTW^f00?o0000oiV1]onIPKL02?nIPKL00ol0003o
XHNio`00000AokFSaP?o00001ooAbM400ol0003oin_@onO[d003onO[d005o`000?oVo<;oi_c2onKl
`_l000000_oBmj@5o`000004omgl]on]kZ?o0000o`0000?og_gC00Co0000on;Cb?oRdlSoh]?80ol0
0006omFi_P03o`000?o;YkCobjNd00OobjNd00?o0000olBL[oo4W:l01oo4W:l00ol0003o_YB/okjD
[008okjD[003o`000?naSK3o/Hf`00go/Hf`00?o0000ojN9]OnWRKD00ol00003oin9_0OoS8G60ol0
00000on1OLKo0000oeQbdP02oeQbdP03o`000?l@FM;o000000Co00006oooool3o`0000Oooooo00?o
0000ooooooooool03?ooool002?ooooo00?o0000ooooooooool0=Oooool00ol0003oL[Wkog:in`02
og:in`?o:Y;_00Ko0000ogjZl?m[VN_oJiW[o`000?mOR>83oeQjfPCo000000?oNgk;o`000?mkMl@0
0_mkMl@00ol0003oO7>nogac_P03ogac_P03o`000?n0L[[oP7:j00?oP7:j00?o0000ohEc^?n5LkP0
0on5LkP00ol0003oRgNgoh]g]`04oh]g]`?o00001onBNkH00ol0003oVH6goiV1]`07oiV1]`;o0000
4?neXlH00ol0003odLWAom79d@08om79d@03o`000?oWjm3oin_@00;oin_@0_l00002onKl`P;o0000
0_oBmj@5o`000004omgl]on]kZ?o0000o`0000?og_gC00?o0000on;Cb?oRdlP00_l000000ooNg]Go
0000omFi_P06omFi_P03o`000?o;YkCobjNd00KobjNd00?o0000olBL[oo4W:l01oo4W:l00ol0003o
_YB/okjD[009okjD[004o`000?niTJgo0000o`0000go/Hf`0_l00003oin9_005o`000?nORKcoWhVl
oin9_?l000001_n<QLH2ofaoe0?o00000omHL]800ol0003o45WBoa1IdP03o`0001kooooo00?o0000
ooooooooool00_ooool00omEEEGoIVIVo`00000>ooooo`008oooool2o`0003[ooooo0ol000000omb
^O_o:Y;_obZBk`02obZBk`04oaili_m[VN_o0000oen8hPCoF7[J00CoF7;Bo`000?l0003o00000omk
Ml@00ol0003oO7>nogac_P02ogac_P03o`000?n0L[[oP7:j00CoP7:j00?o0000ohEc^?n5LkP00on5
LkP00ol0003oRgNgoh]g]`03o`0000;oRgNg00?o0000oi9k]_nBNkH01_nBNkH00ol0003oVH6goiV1
]`04oiV1]`;o00000onZVLD2o`0000co]J?600?o0000om79dOoAbM402?oAbM401?l0003oin_@onO[
d?oWjm02o`000007on;[f?l0003oi_c2o`000?oLo/Oo0000om;gY006o`000003ojg^Xol0003og_gC
00?og_gC00Co0000on;Cb?l0003o00000_oNg]D00ol0003oeKVnomFi_P05omFi_P03o`000?o;YkCo
bjNd00KobjNd00?o0000olBL[oo4W:l01oo4W:l00ol0003o_YB/okjD[009okjD[003o`000?niTJgo
^I6]00;o^I6]0_l00008ok6=/0;o00000on[S;D4oin9_004o`000?nORKcoWhVloin9_0;o00001On<
QLH01?l0003oK7oDofaoe?m/Om@2o`0000;oF7;B00?o0000oa1Id_l@FM800ol0000Looooo`?o0000
5?ooool002?ooooo00?o0000ooooooooool0??ooool4o`0000?o:Y;_0_lNO>H00omOR>;oF7[JoeQj
fP02oeQjfP?oF7;B0ol000000omkMlCo0000ogac_P03ogac_P03o`000?n0L[[oP7:j00?oP7:j00?o
0000ohEc^?n5LkP00on5LkP3o`0000KoRgNg00?o0000oi9k]_nBNkH01_nBNkH00ol0003oVH6goiV1
]`02oiV1]`03o`000?nZVLGoZYW500GoZYW50_l00009okFSaP03o`000?oAbM7odLWA00SodLWA00?o
0000onO[d?oWjm000_l00002on;[f006o`000?oVo<;o0000omcnaol0003od_NT2?l00005omkmd`;o
00000ooNg]D00ol0003oeKVnomFi_P05omFi_P03o`000?o;YkCobjNd00OobjNd00?o0000olBL[oo4
W:l01oo4W:l00ol0003o_YB/okjD[008okjD[003o`000?niTJgo^I6]00Go^I6]0_l00005ok6=/003
o`000?n[S;GoZhbe00CoZhbe0_l000000onORKco0000oin9_004oin9_003o`000?n<QLKoS8G600?o
S8G600?o0000ofaoe?m/Om@00_m/Om@4o`0000;o45WB0_l0000Iooooo`?o00000_ooool00ol0003o
ooooooooo`0Booooo`008oooool00ol0003oooooooooo`10ooooo`?oEJci00Go:Y;_oaili_lNO>Ko
7WcVoen8hP03oeQjfP?oF7;B00?o0000oei`cOl000000_l00004ogac_P03o`000?n0L[[oP7:j00?o
P7:j00?o0000ohEc^?l000000_l00002ohEc^003o`000?n;MkOoRgNg00CoRgNg00?o0000oi9k]_nB
NkH01onBNkH01?l0003oVH6go`000?l0000:ojZIa@03o`000?neXlKo]J?600Go]J?600?o0000om79
dOoAbM402OoAbM400ol0003oin_@o`000003on;[f006o`000?oVo<;o0000omcnaol0003od_NT2?l0
0005omkmd`;o00001?oNg]D00ol0003oeKVnomFi_P05omFi_P03o`000?o;YkCobjNd00KobjNd00?o
0000olBL[oo4W:l01oo4W:l00ol0003o_YB/okjD[008okjD[003o`000?niTJgo^I6]00So^I6]0_l0
00000onaSK3o0000o`000009oj^<]@03o`000?nORKco000000GoWhVl0_l00005ohb5aP04o`000?m/
OmCoK7oDofaoe0;o<W7N0_l00002oa1IdP;o00005Oooool3o`0000Gooooo00?o0000ooooooooool0
4_ooool002?ooooo00?o0000ooooooooool0A?ooool2oeF/n@;o7WcV00Go2fOKoen8h_mHN][oF7[J
o`000002oeQbdP04o`000?mNL<goGW3=oei`c@?o00000_mlLkh01?l0003oP7:joh1b^_n0L[X3o`00
00GoQG>h00?o0000oh]g]on;MkL01On;MkL00ol0003oTW^foi9k]P05oi9k]P?o00003OnZVLD2o`00
00Co]J?600?o0000om79dOoAbM402OoAbM43o`0000?oh^_H0ol00002omcna`Wo00001?oNoM<2o`00
00Gog]kE00?o0000omFi__oE^Kh01OoE^Kh01?l0003objNdol^W]?o;Yk@;o`0000Coa9b_00?o0000
okjD[?nnU:`02OnnU:`00ol0003o^I6]okVA[@0:okVA[@;o00002on[S;D00ol0003oWhVlo`000006
oin9_003o`000?n<QLKoS8G600?oS8G600Go0000ofaoe?m/OmCoK7oDo`000002oc9agP;o000000?o
45WBo`000?l000004Oooool3o`0000Sooooo00?o0000ooooooooool04_ooool002?ooooo00?o0000
ooooooooool0AOooool00ol0003oooooooooo`02oailiP04o`]Wfol0003o0000o`0000;oF7;B00Ko
0000oei`cOmNL<goGW3=o`000?mXL/T6o`0000?oP7:j00?o0000ohEc^?n5LkP00on5LkP00ol0003o
RgNgoh]g]`05oh]g]`03o`000?nBNkKoTW^f00Co00001?nNT<D00ol0003oZYW5ojZIa@0;ojZIa@;o
000000?o]J?6o`000?oAbM402_oAbM42o`0000Coh^_H0_l00003omcna`Wo00000_oNoM<4o`0000Go
g]kE00?o0000omFi__oE^Kh00ooE^Kh7o`0000GobjZh00?o0000olFK[Oo5Vjd00oo5Vjd7o`0000So
_YB/00?o0000okVA[OniTJd02_niTJd00ol0003o]8naokB?/@02o`0000[oZhbe0ol00006oin9_003
o`000?n<QLKoS8G600?oS8G600Go0000ofaoe?m/OmCoK7oDo`000003oc9agP04o`000?l@FM;o0000
o`0000cooooo1?l0000;ooooo`03o`000?oooooooooo01;ooooo000Rooooo`03o`000?oooooooooo
04Oooooo00Go0000oooooooooooooooooailiP02o`]Wf`;o00000_mHL]801?l0003oGW3=oei`cOmN
L<d:o`000003oh1b^_l0003oQG>h00CoQG>h00?o0000oh]g]on;MkL00_n;MkL5o`0000WoWY3500?o
0000ojZIaOnZVLD03?nZVLD=o`0000Koh^_H00Co0000omcnaooLo/Oog?k70_l000000ongkY[o0000
o`000004o`000003omkmdol0003o000000;oYoSA00?o0000omkNeOoNg]D01?oNg]D00ol0003oeKVn
omFi_P03o`0000;od[o700?o0000ol^Z^?o;Z[P01_o;Z[P00ol0003oaI^]olFK[@07olFK[@04o`00
0?o2Ujco`YN/ol:G[0Go00000_nnU:`00ol0003o^I6]okVA[@0:okVA[@03o`000?ndSk7o]8na00?o
]8na00?o0000oj^<]On[S;D02On[S;D00ol0003oWhVloin9_002oin9_0So000000?oS8G6o`000?m/
Om@00_m/Om@01?l0003o<W7Noc9ag_lbLMh3o`0000Wooooo0ol0000@ooooo`03o`000?oooooooooo
017ooooo000Rooooo`;o0000BOooool00ol0003oooooooooo`02ooooo`04o`000?l;Im_o0000o`00
00;oF7;B1Ol00003ofQbb@03o`000?meMlOoMGO700;oMGO73?l00005oi67a@03o`000?nNT<GoWY35
00OoWY350_l0000:ojZIa@03o`000?o7`MGoal7E00Woal7E00?o0000on;[f?oRjmP01OoRjmP01?l0
003og?k7omcnaooLo/L2o`000003okO^V_l0003o000000;o000000Soooooo`000?l0003o0000ojOh
dOooooooYoSAo`0000Kog]kE1?l00004om:oa`03o`000?o;Z[SobjZh00KobjZh00?o0000olFK[Oo5
Vjd01oo5Vjd00ol0003o`YN/ol:G[007ol:G[0Co00002_niTJd00ol0003o]8naokB?/@05okB?/@;o
00002On[S;D5o`0000GoUXc70omnRmH4o`0000;oK7oD00Co0000oc9ag_lbLMko<W7N0ol00005oooo
o`?o00004oooool00ol0003oooooooooo`0Aooooo`008_ooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo00;ooooo00?o7WcVo`]Wfol8G]H01?l00003oei`c@05o`000?mXL/WoJ7;9ofQb
bOl000001OmeMlL00ol0003oPgk6oh=naP04oh=naP03o`000?nAQlGoTHO500KoTHO500?o0000oij@
aOnNT<D02?nNT<D00ol0003oZYW5ojZIa@06ojZIa@03o`000?o7`MGoal7E00Woal7E00?o0000on;[
f?oRjmP01OoRjmP00ol0003og?k7omcna`02omcna`03o`000?ngkY[o000000?o000000Goooooo`00
0?l0003oYoSAooooo`02ojOhd@03o`000?oNg]Gog]kE00;og]kE1?l00006om:oa`03o`000?o;Z[So
bjZh00OobjZh00?o0000olFK[Oo5Vjd01oo5Vjd00ol0003o`YN/ol:G[008ol:G[003o`000?nnU:co
_YB/00?o00001_niTJd00ol0003o]8naokB?/@08okB?/@;o00001?n[S;D3o`0000;oYHjm00?o0000
oiJ<aonFS<L01_nFS<L00ol0003oOX_Fogj;eP03ogj;ePCo00000olbLMh3o`000004ooooool0003o
0000o`0001Kooooo00?o0000ooooooooool04Oooool002;ooooo00?o0000ooooooooool0B_ooool0
0ol0003oooooooooo`02ooooo`Go000000?oF7;Bo`000?mNL<d00_mNL<d01Ol0003oJ7;9ofQbbOmX
L/Wo000000GoMGO700?o0000oh=na_n3O/H01?n3O/H00ol0003oTHO5oi67a@06oi67a@03o`000?nN
T<GoWY3500SoWY350_l00005ojZIa@03o`000?o7`MGoal7E00Woal7E00?o0000on;[f?oRjmP01?oR
jmP2o`0000Cog?k700?o0000okO^V_n7ehP01Ol000000onWn=7oooooojOhd@02ojOhd@03o`000?oN
g]Gog]kE00?o000000?oc>SZo`000?oB_lL01_oB_lL00ol0003objZhol^Z^007ol^Z^003o`000?o5
VjgoaI^]00OoaI^]00?o0000ol:G[?o2Uj`02?o2Uj`00ol0003o_YB/okjD[004okjD[0?o00000_ni
TJd00ol0003o]8naokB?/@0;okB?/@04o`000?n[S;Go0000o`0000KoYHjm0ol00006oiJ<a`03o`00
0?mnRmKoOX_F00?oOX_F00Co0000oe>8i_l0003o00001?lbLMh2o`0001Wooooo00?o0000oooooooo
ool04Oooool002;ooooo00?o0000ooooooooool0Boooool4o`0000?ooooo00?o2fOKo`QNe_l00000
0_l00003oei`c@05o`000?mXL/WoJ7;9ofQbbOl000001OmeMlL00ol0003oPgk6oh=naP04oh=naP03
o`000?nAQlGoTHO500KoTHO500?o0000oij@aOnNT<D02OnNT<D01Ol0003oZYW5ojZIaOnZVLGo0000
00_oal7E00?o0000on;[f?oRjmP00_oRjmP3o`000004omOZh_l0003og?k7omcna`;o000000?o]njJ
ohOGR?l000000ol00002ojOhd@04oooooonWn=7oYoSAojOhd@Co00000oo<j>X00ol0003od[o7om:o
a`05om:oa`03o`000?o;Z[SobjZh00OobjZh00?o0000olFK[Oo5Vjd02?o5Vjd00ol0003o`YN/ol:G
[007ol:G[003o`000?nnU:co_YB/00So_YB/0_l0000?okB?/@03o`000?nUS[goYHjm00KoYHjm00Co
0000ojF>_OnUS[go00001_nFS<L2o`0000CoOX_F00?o0000oe>8i_mCR>H00_l00003oc9agP03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool04Oooool002;ooooo00?o0000ooooooooool0BOoo
ool4o`0000Kooooo00?o2fOKo`QNe_lDGmH00_l00003oei`c@05o`000?mXL/WoJ7;9ofQbbOl00000
1OmeMlL00ol0003oPgk6oh=naP04oh=naP03o`000?nAQlGoTHO500KoTHO50_l0000:oij@a@03o`00
0?nZVLGo000000_oal7E00?o0000on;[f?oRjmP00ol00003omOZhP07o`000?oLo/Oog?k7o`000?o6
o/ko0000ohOGR004o`000004ojOhdOooooooYoSAojOhd@Co00001Oo<j>X00ol0003od[o7om:oa`06
om:oa`03o`000?o;Z[SobjZh00OobjZh00?o0000olFK[Oo5Vjd01oo5Vjd00ol0003o`YN/ol:G[008
ol:G[003o`000?nnU:co_YB/00Wo_YB/00Co0000ok^AZol0003o00002_ndSk401Ol0003o/92eok2@
]On`T;Go000000OoYHjm00Co0000ojF>_OnUS[go00001onFS<L00ol0003oOX_Fogj;eP02ogj;eP;o
00000_mCR>H3o`000003oc9ag_l0003ooooo01Oooooo00?o0000ooooooooool04Oooool0027ooooo
00?o0000ooooooooool0Aoooool3o`0000Cooooo0_l00006ooooo`03o`000?lDGmKo55oF00;o0000
0_mNL<d01Ol0003oJ7;9ofQbbOmXL/Wo000000GoMGO700?o0000oh=na_n3O/H01?n3O/H00ol0003o
THO5oi67a@07oi67a@03o`000?nNT<GoWY3500OoWY352?l00005olO1e@Co00001OoGj^801ol0003o
g?k7o`000?l0003oa_k>o`000?n7ehP01?l00002ojOhd@Co00001oo<j>X00ol0003od[o7om:oa`06
om:oa`03o`000?o;Z[SobjZh00OobjZh00?o0000olFK[Oo5Vjd01oo5Vjd00ol0003o`YN/ol:G[008
ol:G[003o`000?nnU:co_YB/00Wo_YB/00?o0000ok^AZonkTJ/00_nkTJ/2o`0000Oo]8na00?o0000
ok2@]On`T;D01?n`T;D00ol0003oYHjmojF>_@04ojF>_@03o`000?nUS[goYHjm00;o00001_nFS<L0
0ol0003oOX_Fogj;eP03ogj;eP03o`000?mCR>KoDhSV00Go00005oooool00ol0003oooooooooo`0A
ooooo`008Oooool00ol0003oooooooooo`14ooooo`?o00002Oooool00ol0003oooooooooo`04oooo
o`;o00000_lDGmH4o`0000?oJ7;900?o0000ogEgaomeMlL00omeMlL00ol0003oPgk6oh=naP04oh=n
aP03o`000?nAQlGoTHO500OoTHO500?o0000oij@aOnNT<D01?nNT<D2o`0000So]kSI1_l00007omOZ
hP03o`000?oLo/Oo000000;oa_k>00?o0000ohOGR?l000002?l00008olcXjP03o`000?oB_lOod[o7
00Kod[o700?o0000ol^Z^?o;Z[P02?o;Z[P00ol0003oaI^]olFK[@07olFK[@03o`000?o2Ujco`YN/
00So`YN/00?o0000okjD[?nnU:`02?nnU:`00ol0003o^i6[ok^AZ`05ok^AZ`;o00001?ndSk400ol0
003o/92eok2@]@06ok2@]@;o00001OnUS[d01Ol0003oYHjmojF>_OnUS[go000000KoUXc700?o0000
ogj;e_mnRmH00omnRmH01?l0003oDhSVoe>8i_mCR>H2o`000003obmli_l0003ooooo01Kooooo00?o
0000ooooooooool04?ooool0027ooooo0_l00012ooooo`?o00003Oooool00ol0003oooooooooo`05
ooooo`03o`QNe_lDGmKo55oF00;o;F[J0_l00003ofQbb@03o`000?meMlOoMGO700;oMGO700?o0000
oh=na_n3O/H01On3O/H00ol0003oTHO5oi67a@07oi67a@03o`000?nNT<GoWY3500;oWY3500?o0000
okNhfOng^=T02ong^=T00ol0003oen[RomOZhP06omOZhP?o00000_o6o/h00ol0003oQmN8ohOGR008
o`0000Soc>SZ00Co0000om:oaooB_lOod[o72ol00005ol^Z^003o`000?o5VjgoaI^]00OoaI^]00?o
0000ol:G[?o2Uj`02?o2Uj`00ol0003o_YB/okjD[009okjD[003o`000?nkTJ_o^i6[00Oo^i6[0_l0
00000ondSk7o0000ok2@]@0:ok2@]@;o00000onUS[d00ol0003oYHjmojF>_@0>o`000003ogj;e_l0
003oDhSV00?oDhSV0_l0000Gooooo`03o`000?oooooooooo013ooooo000Qooooo`03o`000?oooooo
oooo03kooooo0ol0000Aooooo`03o`000?oooooooooo00Gooooo00?o25kFoaAOe_lDGmH00ol]J]X2
o`0000;oJ7;900?o0000ogEgaomeMlL00_meMlL00ol0003oPgk6oh=naP05oh=naP03o`000?nAQlGo
THO500OoTHO500Co0000oij@aOl0003o00003Ong^=T00ol0003oen[RomOZhP06omOZhP;o00000oo6
o/h00ol0003oQmN8ohOGR00Eo`0000Go`M;W00?o0000olBY_oo4ZKl00oo4ZKl:o`0000GoaI^]00?o
0000ol:G[?o2Uj`01oo2Uj`00ol0003o_YB/okjD[009okjD[003o`000?nkTJ_o^i6[00[o^i6[00?o
0000ok2@]On`T;D03?n`T;D00ol0003oYHjmojF>_@03o`0000CoWiC91on>UmP3og2JjPGo00000_mC
R>H2o`0001Kooooo00?o0000ooooooooool04?ooool0027ooooo00?o0000ooooooooool0>oooool3
o`0001Gooooo00?o0000ooooooooool01_ooool00ol0003o55oFo`000003obeZfPCo00001?meMlL0
0ol0003oPgk6oh=naP05oh=naP03o`000?nAQlGoTHO500GoTHO50ol0000>okNhf@03o`000?oGj^;o
en[R00Koen[R0_l00004olKncP03o`000?n7ehSo000000Co000000?o3`00ojWMn_nYgOX01onYgOX0
0ol0003o`M;Wol7Bi`08ol7Bi`03o`000?o4ZKooa:Vo00Soa:Vo00?o0000olBV^oo4Y[/00oo4Y[/:
o`0000Go`YN/00?o0000okjD[?nnU:`02?nnU:`00ol0003o^i6[ok^AZ`0:ok^AZ`03o`000?nhTk3o
^9>`00;o00003?n`T;D2o`0000;oWiC900?o0000oinDbOnOU<T01?nOU<T00ol0003oSYOHohjGf004
ohjGf003o`000?m`V^[oL9[Z00;oL9[Z1_l0000Eooooo`03o`000?oooooooooo013ooooo000Qoooo
o`03o`000?oooooooooo03Sooooo0ol0000Iooooo`03o`000?oooooooooo00Kooooo00?o0000oaAO
e_l000000ol]J]X2odajgP;o00001?meMlL00ol0003oPgk6oh=naP05oh=naP03o`000?nAQlGoTHO5
00Co00001?nT[=d3o`0000Wo]kSI00?o0000omOZh_oGj^801_oGj^800ol0003oa_k>olKncP03olKn
cP?o00000_l?0002o`0000WoZMgj0_l0000:ol7Bi`03o`000?o4ZKooa:Vo00Soa:Vo00?o0000olBV
^oo4Y[/02?o4Y[/00ol0003o`j:hol>R^003ol>R^0So00002?nnU:`00ol0003o^i6[ok^AZ`09ok^A
Z`03o`000?nhTk3o^9>`00?o^9>`0ol00005ok2@]@?o00000on/U;h01?l0003oWiC9oinDbOl00006
oinDb@;o00001On>UmP2o`0000CoL9[Z00?o0000oeJEkomFUNl00_l0000Dooooo`03o`000?oooooo
oooo013ooooo000Pooooo`03o`000?oooooooooo03Kooooo0ol0000Mooooo`03o`000?oooooooooo
00Kooooo0ol00003obeZfP03o`000?m<N]koC7[N00Co000000?oMGO7o`000?n3O/H00on3O/H5o`00
00_oY:cM0ol00005okNhf@03o`000?oGj^;oen[R00?oen[R1?l00005olKncP?o000000?oooooo`00
0?l000000_nYgOX3o`0000GoZMgj00?o0000ol7Bioo1d^L02Oo1d^L00ol0003oa:VoolBY_`08olBY
_`03o`000?o4Y[_oa:Jk00Soa:Jk00?o0000ol>R^?o3X[P02?o3X[P01?l0003o_iN^oknG[_noUjh5
o`0000;o_YB/00?o0000ok^AZonkTJ/02OnkTJ/00ol0003o^9>`okRC/007okRC/0;o000000?o/92e
o`000?l000002?n/U;h2o`0000SoWiC90_l00005ohjGf0;o00000om`V^X2o`000003oeJEkol0003o
oooo01?ooooo00?o0000ooooooooool04?ooool0023ooooo0ol0000cooooo`?o00008Oooool00ol0
003oooooooooo`07ooooo`;o00000ol]J]X01?l0003oC7[Nodajg_m<N]h2ofb<h@Ko00001On;WN02
o`0000coY:cM0ol000000ong^=Wo0000omOZhP05o`0000;o`^K`1Oo6o/h4o`0000Wooooo1Ol00000
0oo1d^Oo0000o`000008ol7Bi`03o`000?o4ZKooa:Vo00Soa:Vo00?o0000olBV^oo4Y[/02?o4Y[/0
0ol0003o`j:hol>R^008ol>R^003o`000?noUjko_iN^00Oo_iN^1?l00009ok^AZ`03o`000?nhTk3o
^9>`00[o^9>`00?o0000ojbD__n/U;h02_n/U;h2o`0000SoWiC900?o0000ohjGf?n>UmP01?n>UmP0
0ol0003oL9[Zog2JjP02og2JjP?o00004oooool00ol0003oooooooooo`0@ooooo`008?ooool00ol0
003oooooooooo`0`ooooo`?o00009Oooool00ol0003oooooooooo`07ooooo`;o00000ol]J]X01Ol0
003oC7[Nodajg_m<N]ko000000CoK8cQ00?o0000oh^Mh?n;WN001_n;WN02o`0000goY:cM0ol00005
ol;Vl004o`000?o6o/koa_k>olKncPKo00004_ooool5o`0000;o`M;W00?o0000olBY_oo4ZKl02?o4
ZKl00ol0003oa:JkolBV^`08olBV^`03o`000?o3X[So`j:h00So`j:h00?o0000oknG[_noUjh02Ono
Ujh00ol0003o_YZcokjJ/`03o`0000Go^i6[00?o0000okRC/?nhTk002_nhTk000ol0003o]INhokFG
^002o`0000[o[9Bn0ol00004oinDb@oo000000?oL9[Zo`000?ooool04_ooool00ol0003ooooooooo
o`0@ooooo`001Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o
410@ooooooooool00oooool00ol0003oooooooooo`0]ooooo`?o0000:Oooool00ol0003ooooooooo
o`08ooooo`05o`000?l]J][o;F[JobeZf_l000000om<N]h00ol0003oK8cQofb<h@02ofb<h@;o0000
2?n;WN02o`0000SoY:cM0_l00008ol;Vl003o`000?o6o/koa_k>00;o000000?oUO7>o`000?l00000
0_l0000Hooooo`Oo00001Oo4ZKl00ol0003oa:JkolBV^`08olBV^`03o`000?o3X[So`j:h00Wo`j:h
00?o0000oknG[_noUjh02?noUjh00ol0003o_YZcokjJ/`04okjJ/`?o000000?o^i6[o`000?nhTk00
2onhTk000ol0003o]INhokFG^003okFG^0;o00002On/U;h00ol0003o[9Bno`000003o`0000GoVZ7I
00?o0000ohJWj_n6YnX01?n6YnX2o`000004ogFWlOl0003o0000o`0001?ooooo00?o0000oooooooo
ool03oooool000Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02[ooooo0ol0000]ooooo`03o`000?oooooooooo00So
oooo0_l00002obeZfP04o`000?m<N]koC7[NodajgP;o00001?m/S>400ol0003oRigPoh^Mh007oh^M
h0;o00001OnT[=d00ol0003o`^K`ol;Vl007ol;Vl004o`000?o6o/ko0000o`0000;oUO7>1?l0000P
ooooo`[o00001Oo4Y[/00ol0003o`j:hol>R^009ol>R^003o`000?noUjko_iN^00So_iN^00?o0000
okjJ/onnV[<02?nnV[<00ol0003o^9>`okRC/00:okRC/003o`000?neUkSo]INh00Ko]INh0_l00005
ojbD_P?o00000onWWL/00ol0003oVZ7IoiZQf@06oiZQf@;o00001On6YnX2o`000003ogFWlOl0003o
oooo01;ooooo00?o0000ooooooooool03oooool000Gooooo00Go410@oooooooooooooooooa0@400>
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09oooool3o`00037ooooo00?o0000
ooooooooool02?ooool5o`0000CoC7[N00?o0000ofb<hOm/S>400_m/S>42o`0000WoRigP0_l00000
0onT[=go0000o`000009ol;Vl0?o00000onElLh3o`0002cooooo1ol00009ol>R^003o`000?noUjko
_iN^00So_iN^00?o0000okjJ/onnV[<02?nnV[<01?l0003o_9bhokbL^?nlW;P3o`0000Ko^9>`00?o
0000okFG^?neUkP02OneUkP2o`000003ojbD__l0003o000000?oYig;00?o0000ojNMbonWWL/00_nW
WL/2o`0000OoVZ7I0_l00005ohJWjP?o00004_ooool00ol0003oooooooooo`0?ooooo`001Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Vooooo`;o0000=Oooool00ol0003oooooooooo`09ooooo`Co00001?m<N]h00ol0003oK8cQofb<
h@03ofb<h@03o`000?n;WN3oRigP00OoRigP3Ol00005oiGacP?o0000=?ooool3o`0000Ko`j:h00?o
0000oknG[_noUjh01onoUjh00ol0003o_YZcokjJ/`08okjJ/`03o`000?nlW;So_9bh00Go_9bh0ol0
0002okRC/003o`000?neUkSo]INh00co]INh00?o0000ojNMbonWWL/01?nWWL/00ol0003oYig;ojNM
b`03ojNMb`;o00001onJXMT2o`0000GoQZOZ0_l0000Aooooo`03o`000?oooooooooo00oooooo0005
ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo02?ooooo0ol0000hooooo`03o`000?oooooooooo00Wooooo1_l00002odajgP03o`000?m/
S>7oK8cQ00?oK8cQ0_l00004oh^Mh0?o00002_nMfO`00ol0003oUO7>oiGacP04oiGacP?o0000>?oo
ool3o`0000;o`j:h00?o0000oknG[_noUjh01onoUjh00ol0003o_YZcokjJ/`08okjJ/`03o`000?nl
W;So_9bh00Wo_9bh0_l0000=okFG^004o`000?ncVkoo/i^ook>K_`?o00000onWWL/00ol0003oYig;
ojNMb`04ojNMb`;o00001?nJXMT2o`000003oiZQfOl0003o000000Co000000?oQZOZo`000?ooool0
3oooool00ol0003oooooooooo`0?ooooo`001Oooool01Ol@413ooooooooooooooooo410@00kooooo
00?o0000ooooooooool01?ooool2o`00027ooooo0ol0000looooo`03o`000?oooooooooo00[ooooo
0_l000000ol0El7o0000o`000003o`0000KoK8cQ00Co0000oh^Mh?l0003o00002onMfO`2o`0000Co
UO7>1Ol0000looooo`Oo00001?noUjh00ol0003o_YZcokjJ/`08okjJ/`03o`000?nlW;So_9bh00[o
_9bh00Co0000okZI]onjVKOo^YVg0ol00006okFG^0;o00001oncVkl2o`000003ojNMbol0003oYig;
00OoYig;1?l00006oiJajP?o00000_n;/o000ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00oooooo0005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01gooooo0ol00010ooooo`03o`000?oooooooooo00_ooooo3_l00002oigI
o003o`000?nMfOcoWMWl00OoWMWl00?o0000oiGac_nElLh01ol00015ooooo`Co000000?o_YZco`00
0?l000000_l00005okjJ/`03o`000?nlW;So_9bh00[o_9bh00?o0000okZI]onjVKL01OnjVKL3o`00
00;o]INh00?o0000ok>K_oncVkl02OncVkl3o`0000;oYig;0ol00004ojBYf`?o00002?nF/NX4o`00
00kooooo00?o0000ooooooooool03oooool000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool06_ooool3o`0004Cooooo00?o0000oooo
ooooool02oooool2o`000003o`1G`Ol0003o000000;o58_W0ol00006of:mo@Go00000onMfO`4o`00
00;o@l>j1?l00016ooooo`Co00001Oooool5o`0000co_9bh00?o0000okZI]onjVKL02OnjVKL2o`00
00oo/i^o0_l0000:ojBYf`;o00002OnF/NX2o`0000kooooo00?o0000ooooooooool03_ooool001oo
oooo00?o0000ooooooooool05oooool3o`0004Sooooo00?o0000ooooooooool03?ooool5o`0000?o
58_W0ol00008of:mo@Co00001?m3`kX3o`0004Gooooo0ol0000@ooooo`?o00001_nlW;P00ol0003o
^YVgokZI]`09okZI]`03o`000?nhX/?o^:;300;o^:;30ol00006ok>K_`?o000000Co[jG=o`000?n_
YLgo[jG=0_l00009ojBYf`?o00000_nF/NX3o`0000;oVKW_00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0>ooooo`007oooool00ol0003oooooooooo`0Dooooo`?o0000C?ooool00ol0003o
ooooooooo`0>ooooo`Co00001?lDRnL3o`0000;oH[gm0ol00007od?3^P;o0000A?ooool3o`0001Ko
oooo0ol00002okbL^003o`000?njVKOo^YVg00So^YVg0_l00008okRR``?o000000?o/i^oo`000?l0
00001On_YLd00ol0003o[jG=ojnUc@02ojnUc@?o00002?nTZM/3o`0000GoVKW_00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0>ooooo`007_ooool00ol0003oooooooooo`0Booooo`?o0000
D?ooool00ol0003oooooooooo`0@oooooaCo0000@oooool3o`0001cooooo0_l0000:okZI]`03o`00
0?nhX/?o^:;300_o^:;300?o0000ojnUcOn_YLd01_n_YLd00ol0003o[jG=ojnUc@04ojnUc@Go0000
1_nR]nL6o`0000gooooo00?o0000ooooooooool03_ooool001kooooo0_l0000@ooooo`?o0000E?oo
ool00ol0003oooooooooo`0Aooooo`Wo00000olP0003o`0004;ooooo1?l0000Sooooo`Go00000_nj
VKL00ol0003o^:;3okRR``09okRR``;o00001OndZ/l5o`000003ojnUcOl0003o[jG=00?o00001OnZ
/]h3o`0000WoX[OW0_l0000<ooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooo
oooo00cooooo0ol0001Hooooo`03o`000?oooooooooo01?ooooo2Ol00012ooooo`?o0000;?ooool2
o`0000?o^:;30_l00005okRR``;o00003?ndZ/l3o`0000_oZ[;N0ol00002oj:gi`?o00000_nP_Nd0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooooooo
00Wooooo0ol0001Looooo`;o0000Foooool3o`0003Kooooo1Ol0000;okBZc`?o00000_na[]D00ol0
003o/JkEo`000002o`0000[oZ[;N1?l00004oj2mk@03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool03_ooool001kooooo00?o0000ooooooooool01_ooool3o`00067ooooo00?o0000oooooooo
ool0EOooool3o`00043ooooo1Ol00002okBZc`;o00001_na[]D01?l0003o/JkEok6^eOna[]D3o`00
00;oZ[;N0ol00006ojVii0Ko00002_ooool00ol0003oooooooooo`0>ooooo`007_ooool00ol0003o
ooooooooo`03ooooo`?o0000IOooool00ol0003oooooooooo`1@ooooo`Co0000B?ooool2o`0000Wo
/JkE00?o0000ok6^eOna[]D00ona[]D2o`0000koZKWT0_l0000:ooooo`03o`000?oooooooooo00go
oooo000Mooooo`04o`000?ooooooooooooooo`?o0000JOooool00ol0003oooooooooo`1<ooooo`?o
0000DOooool5o`000003ok6^eOl0003o/JkE00?o00001On/^^@5o`0000?oZKWT0ol00002ojJok003
o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool001gooooo1?l0001]ooooo`03o`00
0?oooooooooo04Sooooo0ol0001Iooooo`?o00003On/^^@7o`0000;oY[o/00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0=ooooo`007Oooool2o`00073ooooo00?o0000ooooooooool0A?oo
ool3o`0005oooooo1_l00003ojbji0?o00002?nY_NP4o`0000Sooooo00?o0000ooooooooool03Ooo
ool001oooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0oooooo`Co0000Hoooool0
0ol0003oooooooooo`02ooooo`?o00002OnY_NP3o`0000;oZ<3[00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
03_ooooo0ol0001Wooooo`03o`000?oooooooooo00Wooooo1ol00004ojS0j`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool03Oooool0027ooooo00?o0000ooooooooool0K_ooool00ol0003o
ooooooooo`0gooooo`?o0000Joooool00ol0003oooooooooo`0?ooooo`Ko00001_ooool00ol0003o
ooooooooo`0=ooooo`008_ooool2o`0006oooooo00?o0000ooooooooool0<oooool3o`0006oooooo
00?o0000ooooooooool04oooool2o`0000Kooooo00?o0000ooooooooool03?ooool002Cooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0^ooooo`Co0000Loooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00cooooo000Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool0:_ooool3o`0007Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<
ooooo`009_ooool2o`0006kooooo00?o0000ooooooooool09_ooool3o`0007_ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0<ooooo`00:?ooool00ol0003oooooooooo`1/ooooo`03
o`000?oooooooooo02;ooooo0ol0001oooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool03?ooool002Wooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0Mooooo`Co0000
Poooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00cooooo000Zooooo`03o`000?oo
oooooooo06cooooo00?o0000ooooooooool06Oooool3o`0008Oooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0<ooooo`00:oooool2o`0006gooooo00?o0000ooooooooool05Oooool3
o`0008_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0<ooooo`00;Oooool00ol0
003oooooooooo`1[ooooo`03o`000?oooooooooo017ooooo0ol0002?ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool02oooool002kooooo00?o0000ooooooooool0Joooool00ol0003o
ooooooooo`0<ooooo`Co0000Toooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_o
oooo000_ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool02?ooool3o`0009Oooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0;ooooo`00<?ooool2o`0006cooooo00?o
0000ooooooooool01?ooool3o`0009_ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0;ooooo`00<_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00?o0000Woooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo000cooooo`03o`000?oooooooooo
06[ooooo0_l0002Sooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool003Co
oooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool02oooool003Gooooo0_l0001Yooooo`03o`000?oooooooooo0:?ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`00=oooool00ol0003ooooooooo
o`1Vooooo`03o`000?oooooooooo0:Cooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0:ooooo`00>?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo0:Gooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0:ooooo`00>Oooool2o`0006Gooooo00?o0000oooo
ooooool0YOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00[ooooo000kooooo`03
o`000?oooooooooo06;ooooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00[ooooo000looooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0
Yoooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo000mooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00[ooooo000nooooo`;o0000H?ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool02_ooool0043ooooo00?o0000ooooooooool0GOooool00ol0
003oooooooooo`2Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Oooool0047o
oooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02Oooool004;ooooo00?o0000ooooooooool0Foooool00ol0003ooooo
ooooo`2[ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool004?ooooo0_l0
001Kooooo`03o`000?oooooooooo0:_ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`09ooooo`00AOooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo0:cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`00A_ooool00ol0003oooooooooo`1Foooo
o`03o`000?oooooooooo0:kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`00Aoooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo0:kooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`00B?ooool2o`0005Gooooo00?o0000ooooooooool0
[oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo001:ooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool0/?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo001;ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0/Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo001<ooooo`;o0000DOooool00ol0
003oooooooooo`2aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool004ko
oooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02?ooool004oooooo00?o0000ooooooooool0COooool00ol0003ooooo
ooooo`2cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool0053ooooo00?o
0000ooooooooool0C?ooool00ol0003oooooooooo`2dooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02?ooool0057ooooo0_l0001<ooooo`03o`000?oooooooooo0;Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`08ooooo`00Doooool00ol0003oooooooooo`19oooo
o`03o`000?oooooooooo0;Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07oooo
o`00E?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo0;Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`07ooooo`00EOooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo0;Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`00E_oo
ool2o`0004Oooooo00?o0000ooooooooool0]oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo001Hooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0^?ooool0
1Ol0003ooooooooooooooooo000000Wooooo001Iooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool0^Oooool01?l0003oooooooooool00009ooooo`00F_ooool00ol0003oooooooooo`12
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooool000002Oooool005_ooooo0_l00012oooo
o`03o`000?oooooooooo0;[ooooo00Co0000oooooooooooo00002?ooool005gooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`2kooooo`03o`000?oooooo000000Sooooo001Nooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0_?ooool2o`0000Sooooo001Oooooo`;o0000
?_ooool00ol0003oooooooooo`2kooooo`?o00002?ooool0067ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2gooooo`Co00002oooool006;ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`2cooooo`Co00003oooool006?ooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`2_ooooo`Co00004oooool006Cooooo0_l0000iooooo`03o`000?oooooooooo0:_o
oooo1?l0000Gooooo`00I_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo0:Oooooo
1?l0000Kooooo`00Ioooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo0:?ooooo1?l0
000Oooooo`00J?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo09oooooo1?l0000S
ooooo`00JOooool2o`0003?ooooo00?o0000ooooooooool0W?ooool4o`0002Oooooo001[ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0V?ooool4o`0002_ooooo001/ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool0U?ooool4o`0002oooooo001]ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0T?ooool4o`0003?ooooo001^ooooo`;o0000;_ooool0
0ol0003oooooooooo`2=ooooo`?o0000=oooool0073ooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`29ooooo`Co0000>_ooool0077ooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`25ooooo`Co0000?_ooool007;ooooo0_l0000Zooooo`03o`000?oooooooooo087ooooo
1?l00012ooooo`00M?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07gooooo1?l0
0016ooooo`00MOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07Wooooo1?l0001:
ooooo`00M_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07Gooooo1?l0001>oooo
o`00Moooool2o`0002Gooooo00?o0000ooooooooool0LOooool4o`0005;ooooo001iooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool0KOooool4o`0005Kooooo001jooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0JOooool4o`0005[ooooo001kooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0IOooool4o`0005kooooo001looooo`;o00008?ooool00ol0
003oooooooooo`1Qooooo`Co0000H_ooool007kooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`1Mooooo`Co0000I_ooool007oooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1Iooooo`Co0000J_ooool0083ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`1Eooooo`Co0000K_ooool0087ooooo0_l0000Kooooo`03o`000?oooooooooo057ooooo1?l0001b
ooooo`00Poooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04gooooo1?l0001foooo
o`00Q?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo1?l0001jooooo`00
QOooool2o`0001Oooooo00?o0000ooooooooool0AOooool4o`0007kooooo0027ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0@Oooool4o`0008;ooooo0028ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0?Oooool4o`0008Kooooo0029ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0>Oooool4o`0008[ooooo002:ooooo`;o00004_ooool00ol0003o
ooooooooo`0eooooo`Co0000S_ooool008cooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0aooooo`Co0000T_ooool008gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0^ooooo`Co0000U_ooool008kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0[
ooooo`?o0000V_ooool008oooooo0_l0000<ooooo`03o`000?oooooooooo02Oooooo1?l0002Moooo
o`00TOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02?ooooo1?l0002Qooooo`00
T_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo1?l0002Uooooo`00Tooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01_ooooo1?l0002Yooooo`00U?ooool2
o`0000Oooooo00?o0000ooooooooool05oooool4o`000:gooooo002Fooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool04oooool4o`000;7ooooo002Gooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03oooool4o`000;Gooooo002Hooooo`;o00000oooool00ol0003ooooo
ooooo`0;ooooo`Co0000^Oooool009[ooooo00Co0000oooooooooooo00002Oooool4o`000;gooooo
002Kooooo`03o`000?oooooo000000Gooooo1?l00031ooooo`00W?ooool2o`000003ooooool0003o
000000;o0000aOooool009gooooo0_l00039ooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00J?ooool01OlQ8B7o0000o`000?m4A4CogMgM
07Wooooo00Go8B4Qo`000?l0003oA4A4omgMg@1mooooo`00Joooool00omgMgOo<S8booooo`1koooo
o`03ogMgMolb<S;ooooo07cooooo001/ooooo`03o`000?oooooooooo07_ooooo00?o0000oooooooo
ool0Noooool0043ooooo00OoV9RHo`000?l0003oA4A4okZj^_oooooo410@00Go00001?ooool5o`00
00;ooooo00KoV9RHo`000?l0003oMgMgoa0@4?l00002ooooo`04oa0@4?l0003o0000ooooo`;o0000
00So410@ooooooo^k^koEEEEo`000?l@413oc<c<o`0000?ooooo00OoV9RHo`000?l0003oMgMgo`00
0?l@413ooooo00Go00000oooool02?nHV9So0000o`000?mgMgOo410@o`000?oooooo410@1Ol00006
ooooo`06onk^k_mEEEGo0000o`000?nHV9So00000_l@4105o`0000Cooooo00KoV9RHo`000?l0003o
MgMgo`000?l@4102o`0000;ooooo00Co0000oooooooooooo00000_l@4102o`000007ooooool0003o
0000oa0@4?ooooook^k^oeEEE@02o`000005odA4A?nj^[[ooooooooooonHV9P00_l000000omgMgOo
410@o`000002ooooo`07onk^k_mEEEGo0000o`000?nHV9So0000oa0@4004ooooo`06onk^k_mEEEGo
0000o`000?m4A4Co^[Zj0oooool5o`0000;ooooo00Kok^k^oeEEEOl0003o410@olc<c?l00002oooo
o`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0_ooool01?l@413o0000o`000?ooool2o`000003oa0@
4?l0003o000000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE00;o000000KoEEEEonk^
k_ooooooooooonk^k_mEEED2o`000006oiRHV?l0003o410@ooooooo^k^koEEEE0_l000001_m4A4Co
^[Zjoooooooooooo410@oc8b<P;o000000?o410@ojVYZOooool01?ooool01onHV9So0000o`000?mE
EEGok^k^ofIVI_l000002?ooool5o`0002cooooo0010ooooo`05oa0@4?nj^[[ok^k^ogMgMol@4100
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Go0000olc<c?o^k^ko
QhN7o`000004ooooo`05o`000?ooooooooooooooool000000_ooool01_mEEEGoMgMgooooooo^k^ko
EEEEo`0000?ooooo00Go0000ojVYZOooooooQhN7o`000004ooooo`03o`000?oooooooooo00?ooooo
00Go0000olc<c?o^k^koQhN7o`000004ooooo`03o`000?oooooooooo00Oooooo00KoEEEEogMgMooo
ooook^k^oeEEEOl00003ooooo`03o`000?oooooooooo00Gooooo00Go0000ojVYZOooooooQhN7o`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool02Ol0003o
oooooooooomEEEGoMgMgooooooo^k^koMgMgoa0@4002ooooo`05o`000?o<c<cok^k^ohN7Qol00000
0oooool01_mEEEGoMgMgooooooo^k^koEEEEo`0000Gooooo00KoEEEEogMgMoooooook^k^ogMgMol@
4105ooooo`03o`000?oooooooooo00;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00002ooooo`06
oeEEEOmgMgOoooooonk^k_mgMgOo410@0oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003ooooooeEEEOmgMgL2ooooo`0:ogMgMomEEEGooooooooo
oomEEEGoMgMgooooooo^k^koEEEEo`0000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102oooo
o`06o`000?nYZJWooooooooooonj^[[o00001Oooool01ol0003oZJVYoooooon7QhOo<S8bofIVI_oo
ool01_l00002ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;?ooool0043ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Go410@ohN7Qooo
ooook^k^o`000004ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003ooooooooooooo
ooook^k^o`0000?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?o
oooo00Go410@ohN7Qoooooook^k^o`000004ooooo`03o`000?oooooooooo00Oooooo00Ko0000oooo
ooooooooooooonk^k_l00003ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01?l0
003oooooooooool00007ooooo`05oa0@4?n7QhOoooooonk^k_l000000oooool01_l0003ooooooooo
ooooooook^k^o`0000Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`06
o`000?ooooooooooooooooo^k^ko00000_ooool00ol0003oooooooooo`06ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000Cooooo
00Co0000oooooooooooo00000oooool01Oo^k^ko0000oooooooooooo000000Sooooo00Go^[ZjohN7
QomVIVKoIVIVoa0@4005ooooo`06o`000?oooooooooooooooon7QhOoA4A42_ooool00onHV9So8B4Q
onk^kP0]ooooo`00@?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00_ooool00onj^[[o410@o`000002o`0000Cooooo00Go0000oooooooooooooooo
o`000002ooooo`06o`000?ooooooooooooooooo^k^ko00000oooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool00oooool00onj^[[o410@o`000002o`0000Cooooo00?o0000
ooooooooool01oooool01_l0003oooooooooooooooook^k^o`0000?ooooo00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo00Ko00000_ooool00onj^[[o410@o`000002
o`0000?ooooo00Ko0000ooooooooooooooooonk^k_l00005ooooo`Ko00001Oooool00ol0003ooooo
ooooo`02ooooo`06o`000?ooooooooooooooooo^k^ko00000_ooool6o`0000?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000001?oo
ool01?l0003oooooooooool00003ooooo`04onk^k_l0003oooooooooo`Ko00000_ooool01_lb<S;o
8B4QogMgMomgMgOoQhN7onk^kPGooooo00Oo8B4Qolc<c?oooooooooooiRHV?lb<S;ooooo00Ko0000
1?ooool00onHV9So8B4Qonk^kP0/ooooo`00@?ooool00ol0003oooooooooo`05ooooo`03o`000?lb
<S;ogMgM00Oooooo00?o0000ooooooooool01Oooool00oo<c<co0000ooooo`03ooooo`05o`000?n7
QhOoooooojVYZOl000000_ooool01_mEEEGoMgMgooooooo^k^koEEEEo`0000?ooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00Kooooo00?oc<c<o`000?ooool00oooool0
0ol0003o<S8bomgMg@07ooooo`06ofIVI_mgMgOoooooonk^k_mEEEGo00000oooool00ol0003o<S8b
omgMg@05ooooo`05o`000?ooooooooooooooool000000_ooool01ol0003oc<c<olc<c?l0003oZJVY
omgMgOlQ8B400_ooool01Ol0003oMgMgoooooonYZJWo000000;ooooo00KoEEEEohN7Qoo^k^kooooo
ohN7Qolb<S85ooooo`03olc<c?l0003ooooo00;ooooo00KoIVIVogMgMoooooook^k^oeEEEOl00005
ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b1Oooool00ol0003oooooooooo`02ooooo`06oeEE
EOmgMgOoooooonk^k_mEEEGo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00Go
0000ohN7QoooooooZJVYo`000002ooooo`0:o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8Ooooooo
EEEEogMgM`;ooooo00[oMgMgoeEEEOooooooooooofIVI_mgMgOoooooonk^k_mEEEGo00000_ooool0
1_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00Ko0000okZj^_ooooook^k^ogMgMol00005oooo
o`07ojVYZOlQ8B7ogMgMonk^k_lb<S;oEEEEokZj^P0;ooooo`03ogMgMomVIVKooooo02_ooooo000n
ooooo`03oa0@4?l0003o000000?o00000oooool2o`000004ojVYZOlQ8B7o0000ob4Q8@?ooooo00?o
410@o`000?l000001Oooool01?lb<S;o0000o`000?nHV9P3ooooo`03oa0@4?l0003oMgMg00;o0000
00goV9RHooooooooooook^k^oeEEEOl0003o8B4QojVYZOl0003o410@ooooool@413o000000;ooooo
0_l00004ooooo`03o`000?oooooooooo00Cooooo00Co<S8bo`000?l0003oV9RH0oooool2o`000004
ojVYZOlQ8B7o0000ob4Q8@Gooooo00Kok^k^oeEEEOl0003o410@olc<c?l00002ooooo`;o000000Co
ZJVYob4Q8Ol0003o8B4Q0_ooool01?l@413o0000ooooooooool2o`000009ooooool@413o0000ob4Q
8Ol0003oMgMgoa0@4?l0003oZJVY00;ooooo00Go0000ogMgMol0003o0000oiRHV002ooooo`06onk^
k_mEEEGo0000o`000?m4A4Cok^k^0oooool01?lb<S;o0000o`000?nHV9P3ooooo`06onk^k_mEEEGo
0000oa0@4?o<c<co00001Oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP?ooooo00?o410@o`00
0?l000001?ooool02_o^k^koEEEEo`000?lQ8B7oZJVYo`000?l@413oooooonk^k_mEEED2o`000007
odA4A?o^k^koooooooooool@413o0000ogMgM`02o`00000=oiRHV?oooooo410@o`000?lQ8B7o0000
ogMgMol@413o0000ojVYZOooooook^k^oeEEE@02o`00000:oeEEEOo^k^koooooooooooo^k^koEEEE
o`000?l@413oc<c<o`0000;ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`06ojVYZOlQ
8B7o0000o`000?lb<S;o00001_ooool01_nHV9So0000o`000?nHV9So^[Zjoc8b<Pcooooo00?o0000
ooooooooool0:_ooool0043ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo02;ooooo00Go0000okZj^_ooooooV9RHoa0@400/ooooo`00@?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo02;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00/
ooooo`00D_ooool00ol@413oooooooooo`0Rooooo`03oa0@4?l0003o000001cooooo0_l0000Joooo
o`03oa0@4?l0003ooooo01Wooooo0_l0000@ooooo`03oa0@4?oooooooooo02kooooo0_l0001Eoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0865833, 0.00525911, \
0.00369676, 0.00369676}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.66533e-16 1.05023 -0.0446497 1.05023 [
[.5 .87208 -104 0 ]
[.5 .87208 104 12 ]
[.05011 .23931 -6 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -16.6517 -9 ]
[.33812 .12455 1.34831 0 ]
[.495 .06208 -21.0373 -9 ]
[.495 .06208 2.96266 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.2956 .07454 -9.25094 -12 ]
[.2956 .07454 .74906 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 6 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 18 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 24 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.91306 .21061 0 -8.07062 ]
[.91306 .21061 10 3.92938 ]
[.03081 .27768 -24 -2.73146 ]
[.03081 .27768 0 6.26854 ]
[.01654 .36715 -6 -2.80783 ]
[.01654 .36715 0 6.19217 ]
[.00139 .46205 -18 -2.88932 ]
[.00139 .46205 0 6.11068 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .87208 -165 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(triangular) show
129.000 13.000 moveto
(drumhead) show
183.000 13.000 moveto
(eigenmodes) show
249.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
255.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
261.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
267.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(0)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(0.25)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0.5)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.75)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
gsave
.2956 .07454 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(0)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(0.25)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0.5)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.75)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
gsave
.91306 .21061 -61 -12.0706 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04303 .27288 m
.04914 .27048 L
s
[(-0.1)] .03081 .27768 1 -0.39301 Mshowa
.02882 .36253 m
.03497 .36022 L
s
[(0)] .01654 .36715 1 -0.37604 Mshowa
.01375 .45763 m
.01993 .45542 L
s
[(0.1)] .00139 .46205 1 -0.35793 Mshowa
.125 Mabswid
.04026 .2904 m
.04393 .28897 L
s
.03745 .30812 m
.04112 .3067 L
s
.03461 .32605 m
.03828 .32464 L
s
.03173 .34418 m
.03541 .34279 L
s
.02588 .3811 m
.02957 .37973 L
s
.0229 .39989 m
.0266 .39853 L
s
.01989 .41891 m
.02359 .41756 L
s
.01684 .43815 m
.02054 .43681 L
s
.04578 .25556 m
.04944 .25411 L
s
.01063 .47735 m
.01434 .47603 L
s
.00747 .49731 m
.01118 .496 L
s
.00427 .51751 m
.00799 .51622 L
s
.00102 .53797 m
.00475 .53669 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.92728 .52324 m .94807 .517 L .95575 .52814 L closepath p .662 .75 .916 r
F P
0 g
s
.94807 .517 m .92728 .52324 L .89858 .51785 L p .665 .736 .903 r
F P
0 g
s
.89858 .51785 m .91931 .5114 L .94807 .517 L p .665 .736 .903 r
F P
0 g
s
.91931 .5114 m .89858 .51785 L .86972 .51258 L p .677 .721 .882 r
F P
0 g
s
.91931 .5114 m .9403 .5057 L .94807 .517 L closepath p .649 .745 .919 r
F P
0 g
s
.86972 .51258 m .89034 .50535 L .91931 .5114 L p .677 .721 .882 r
F P
0 g
s
.89034 .50535 m .86972 .51258 L .8407 .50726 L p .699 .668 .816 r
F P
0 g
s
.9403 .5057 m .91931 .5114 L .89034 .50535 L p .666 .714 .884 r
F P
0 g
s
.8407 .50726 m .861 .4973 L .89034 .50535 L p .699 .668 .816 r
F P
0 g
s
.861 .4973 m .8407 .50726 L .81137 .5005 L p .708 .654 .793 r
F P
0 g
s
.89034 .50535 m .91118 .49877 L .9403 .5057 L p .666 .714 .884 r
F P
0 g
s
.91118 .49877 m .89034 .50535 L .861 .4973 L p .669 .686 .857 r
F P
0 g
s
.91118 .49877 m .93242 .49425 L .9403 .5057 L closepath p .624 .734 .926 r
F P
0 g
s
.861 .4973 m .88174 .49028 L .91118 .49877 L p .669 .686 .857 r
F P
0 g
s
.88174 .49028 m .861 .4973 L .83151 .48891 L p .688 .629 .785 r
F P
0 g
s
.81137 .5005 m .83151 .48891 L .861 .4973 L p .708 .654 .793 r
F P
0 g
s
.83151 .48891 m .81137 .5005 L .78206 .4957 L p .723 .625 .748 r
F P
0 g
s
.93242 .49425 m .91118 .49877 L .88174 .49028 L p .631 .703 .898 r
F P
0 g
s
.83151 .48891 m .85187 .47869 L .88174 .49028 L p .688 .629 .785 r
F P
0 g
s
.85187 .47869 m .83151 .48891 L .80185 .47989 L p .703 .594 .732 r
F P
0 g
s
.78206 .4957 m .80185 .47989 L .83151 .48891 L p .723 .625 .748 r
F P
0 g
s
.80185 .47989 m .78206 .4957 L .75252 .49039 L p .729 .593 .704 r
F P
0 g
s
.88174 .49028 m .90289 .48558 L .93242 .49425 L p .631 .703 .898 r
F P
0 g
s
.90289 .48558 m .88174 .49028 L .85187 .47869 L p .641 .648 .841 r
F P
0 g
s
.80185 .47989 m .82175 .46497 L .85187 .47869 L p .703 .594 .732 r
F P
0 g
s
.82175 .46497 m .80185 .47989 L .77193 .46905 L p .711 .584 .711 r
F P
0 g
s
.75252 .49039 m .77193 .46905 L .80185 .47989 L p .729 .593 .704 r
F P
0 g
s
.85187 .47869 m .87286 .47331 L .90289 .48558 L p .641 .648 .841 r
F P
0 g
s
.87286 .47331 m .85187 .47869 L .82175 .46497 L p .657 .6 .78 r
F P
0 g
s
.82175 .46497 m .8424 .45728 L .87286 .47331 L p .657 .6 .78 r
F P
0 g
s
.8424 .45728 m .82175 .46497 L .79157 .45093 L p .676 .573 .731 r
F P
0 g
s
.77193 .46905 m .79157 .45093 L .82175 .46497 L p .711 .584 .711 r
F P
0 g
s
.79157 .45093 m .81176 .43897 L .8424 .45728 L p .676 .573 .731 r
F P
0 g
s
.81176 .43897 m .79157 .45093 L .76138 .43709 L p .693 .563 .703 r
F P
0 g
s
.79157 .45093 m .77193 .46905 L .74213 .46104 L p .724 .572 .684 r
F P
0 g
s
.74213 .46104 m .76138 .43709 L .79157 .45093 L p .724 .572 .684 r
F P
0 g
s
.77193 .46905 m .75252 .49039 L .72263 .48229 L p .74 .611 .715 r
F P
0 g
s
.72263 .48229 m .74213 .46104 L .77193 .46905 L p .74 .611 .715 r
F P
0 g
s
.90289 .48558 m .92443 .48266 L .93242 .49425 L closepath p .587 .716 .933 r
F P
0 g
s
.76138 .43709 m .78115 .42041 L .81176 .43897 L p .693 .563 .703 r
F P
0 g
s
.78115 .42041 m .76138 .43709 L .73126 .42461 L p .71 .566 .69 r
F P
0 g
s
.76138 .43709 m .74213 .46104 L .71223 .45372 L p .735 .569 .668 r
F P
0 g
s
.71223 .45372 m .73126 .42461 L .76138 .43709 L p .735 .569 .668 r
F P
0 g
s
.8016 .41149 m .78115 .42041 L .75074 .40392 L p .675 .554 .71 r
F P
0 g
s
.75074 .40392 m .77074 .39031 L .8016 .41149 L p .675 .554 .71 r
F P
0 g
s
.73126 .42461 m .75074 .40392 L .78115 .42041 L p .71 .566 .69 r
F P
0 g
s
.77074 .39031 m .75074 .40392 L .72059 .39116 L p .701 .566 .699 r
F P
0 g
s
.75074 .40392 m .73126 .42461 L .70131 .41614 L p .729 .575 .682 r
F P
0 g
s
.70131 .41614 m .72059 .39116 L .75074 .40392 L p .729 .575 .682 r
F P
0 g
s
.83268 .43389 m .81176 .43897 L .78115 .42041 L p .65 .553 .733 r
F P
0 g
s
.78115 .42041 m .8016 .41149 L .83268 .43389 L p .65 .553 .733 r
F P
0 g
s
.79143 .38419 m .77074 .39031 L .74025 .37291 L p .66 .552 .722 r
F P
0 g
s
.74025 .37291 m .76046 .36205 L .79143 .38419 L p .66 .552 .722 r
F P
0 g
s
.72059 .39116 m .74025 .37291 L .77074 .39031 L p .701 .566 .699 r
F P
0 g
s
.76046 .36205 m .74025 .37291 L .71014 .36124 L p .696 .578 .72 r
F P
0 g
s
.74025 .37291 m .72059 .39116 L .69063 .38288 L p .728 .589 .7 r
F P
0 g
s
.69063 .38288 m .71014 .36124 L .74025 .37291 L p .728 .589 .7 r
F P
0 g
s
.72059 .39116 m .70131 .41614 L .67136 .41055 L p .747 .591 .682 r
F P
0 g
s
.67136 .41055 m .69063 .38288 L .72059 .39116 L p .747 .591 .682 r
F P
0 g
s
.73126 .42461 m .71223 .45372 L .68215 .44567 L p .748 .586 .675 r
F P
0 g
s
.68215 .44567 m .70131 .41614 L .73126 .42461 L p .748 .586 .675 r
F P
0 g
s
.82283 .40953 m .8016 .41149 L .77074 .39031 L p .625 .539 .738 r
F P
0 g
s
.77074 .39031 m .79143 .38419 L .82283 .40953 L p .625 .539 .738 r
F P
0 g
s
.86372 .45466 m .8424 .45728 L .81176 .43897 L p .625 .569 .772 r
F P
0 g
s
.81176 .43897 m .83268 .43389 L .86372 .45466 L p .625 .569 .772 r
F P
0 g
s
.92443 .48266 m .90289 .48558 L .87286 .47331 L p .578 .678 .908 r
F P
0 g
s
.74213 .46104 m .72263 .48229 L .69283 .47841 L p .747 .604 .699 r
F P
0 g
s
.69283 .47841 m .71223 .45372 L .74213 .46104 L p .747 .604 .699 r
F P
0 g
s
.71014 .36124 m .73001 .3459 L .76046 .36205 L p .696 .578 .72 r
F P
0 g
s
.73001 .3459 m .71014 .36124 L .68025 .35546 L p .732 .618 .731 r
F P
0 g
s
.71014 .36124 m .69063 .38288 L .66073 .37893 L p .754 .619 .71 r
F P
0 g
s
.66073 .37893 m .68025 .35546 L .71014 .36124 L p .754 .619 .71 r
F P
0 g
s
.89438 .4712 m .87286 .47331 L .8424 .45728 L p .598 .612 .836 r
F P
0 g
s
.8424 .45728 m .86372 .45466 L .89438 .4712 L p .598 .612 .836 r
F P
0 g
s
.87286 .47331 m .89438 .4712 L .92443 .48266 L p .578 .678 .908 r
F P
0 g
s
.78139 .35889 m .76046 .36205 L .73001 .3459 L p .645 .563 .748 r
F P
0 g
s
.73001 .3459 m .75045 .3379 L .78139 .35889 L p .645 .563 .748 r
F P
0 g
s
.75045 .3379 m .73001 .3459 L .69999 .33704 L p .693 .611 .761 r
F P
0 g
s
.68025 .35546 m .69999 .33704 L .73001 .3459 L p .732 .618 .731 r
F P
0 g
s
.70131 .41614 m .68215 .44567 L .65211 .44183 L p .759 .595 .675 r
F P
0 g
s
.65211 .44183 m .67136 .41055 L .70131 .41614 L p .759 .595 .675 r
F P
0 g
s
.69063 .38288 m .67136 .41055 L .64128 .40621 L p .764 .616 .696 r
F P
0 g
s
.64128 .40621 m .66073 .37893 L .69063 .38288 L p .764 .616 .696 r
F P
0 g
s
.81296 .38551 m .79143 .38419 L .76046 .36205 L p .597 .532 .753 r
F P
0 g
s
.76046 .36205 m .78139 .35889 L .81296 .38551 L p .597 .532 .753 r
F P
0 g
s
.85438 .43459 m .83268 .43389 L .8016 .41149 L p .588 .543 .771 r
F P
0 g
s
.8016 .41149 m .82283 .40953 L .85438 .43459 L p .588 .543 .771 r
F P
0 g
s
.71223 .45372 m .69283 .47841 L .66282 .4744 L p .749 .59 .679 r
F P
0 g
s
.66282 .4744 m .68215 .44567 L .71223 .45372 L p .749 .59 .679 r
F P
0 g
s
.69999 .33704 m .72011 .32488 L .75045 .3379 L p .693 .611 .761 r
F P
0 g
s
.72011 .32488 m .69999 .33704 L .67015 .33488 L p .741 .683 .795 r
F P
0 g
s
.69999 .33704 m .68025 .35546 L .65037 .35437 L p .766 .671 .757 r
F P
0 g
s
.65037 .35437 m .67015 .33488 L .69999 .33704 L p .766 .671 .757 r
F P
0 g
s
.68025 .35546 m .66073 .37893 L .63071 .37785 L p .776 .655 .729 r
F P
0 g
s
.63071 .37785 m .65037 .35437 L .68025 .35546 L p .776 .655 .729 r
F P
0 g
s
.84491 .41389 m .82283 .40953 L .79143 .38419 L p .546 .52 .777 r
F P
0 g
s
.79143 .38419 m .81296 .38551 L .84491 .41389 L p .546 .52 .777 r
F P
0 g
s
.88567 .4557 m .86372 .45466 L .83268 .43389 L p .546 .573 .833 r
F P
0 g
s
.83268 .43389 m .85438 .43459 L .88567 .4557 L p .546 .573 .833 r
F P
0 g
s
.8032 .36328 m .78139 .35889 L .75045 .3379 L p .564 .536 .782 r
F P
0 g
s
.75045 .3379 m .77162 .33744 L .8032 .36328 L p .564 .536 .782 r
F P
0 g
s
.77162 .33744 m .75045 .3379 L .72011 .32488 L p .625 .594 .798 r
F P
0 g
s
.67136 .41055 m .65211 .44183 L .62185 .43816 L p .764 .6 .675 r
F P
0 g
s
.62185 .43816 m .64128 .40621 L .67136 .41055 L p .764 .6 .675 r
F P
0 g
s
.89438 .4712 m .91634 .4709 L .92443 .48266 L closepath p .52 .683 .94 r
F P
0 g
s
.68215 .44567 m .66282 .4744 L .63245 .46613 L p .761 .628 .713 r
F P
0 g
s
.63245 .46613 m .65211 .44183 L .68215 .44567 L p .761 .628 .713 r
F P
0 g
s
.66073 .37893 m .64128 .40621 L .61105 .40429 L p .776 .639 .71 r
F P
0 g
s
.61105 .40429 m .63071 .37785 L .66073 .37893 L p .776 .639 .71 r
F P
0 g
s
.72011 .32488 m .7408 .31962 L .77162 .33744 L p .625 .594 .798 r
F P
0 g
s
.7408 .31962 m .72011 .32488 L .69018 .32033 L p .686 .685 .843 r
F P
0 g
s
.67015 .33488 m .69018 .32033 L .72011 .32488 L p .741 .683 .795 r
F P
0 g
s
.91634 .4709 m .89438 .4712 L .86372 .45466 L p .508 .635 .91 r
F P
0 g
s
.86372 .45466 m .88567 .4557 L .91634 .4709 L p .508 .635 .91 r
F P
0 g
s
.83541 .39349 m .81296 .38551 L .78139 .35889 L p .497 .501 .791 r
F P
0 g
s
.78139 .35889 m .8032 .36328 L .83541 .39349 L p .497 .501 .791 r
F P
0 g
s
.87679 .43946 m .85438 .43459 L .82283 .40953 L p .483 .531 .831 r
F P
0 g
s
.82283 .40953 m .84491 .41389 L .87679 .43946 L p .483 .531 .831 r
F P
0 g
s
.69018 .32033 m .67015 .33488 L .64024 .33741 L p .78 .785 .857 r
F P
0 g
s
.67015 .33488 m .65037 .35437 L .6203 .35596 L p .793 .734 .798 r
F P
0 g
s
.6203 .35596 m .64024 .33741 L .67015 .33488 L p .793 .734 .798 r
F P
0 g
s
.65037 .35437 m .63071 .37785 L .60043 .37765 L p .789 .692 .757 r
F P
0 g
s
.60043 .37765 m .6203 .35596 L .65037 .35437 L p .789 .692 .757 r
F P
0 g
s
.64128 .40621 m .62185 .43816 L .59134 .43293 L p .772 .624 .696 r
F P
0 g
s
.59134 .43293 m .61105 .40429 L .64128 .40621 L p .772 .624 .696 r
F P
0 g
s
.65211 .44183 m .63245 .46613 L .60206 .46213 L p .762 .632 .716 r
F P
0 g
s
.60206 .46213 m .62185 .43816 L .65211 .44183 L p .762 .632 .716 r
F P
0 g
s
.69018 .32033 m .7106 .31145 L .7408 .31962 L p .686 .685 .843 r
F P
0 g
s
.7106 .31145 m .69018 .32033 L .66035 .32276 L p .729 .83 .928 r
F P
0 g
s
.64024 .33741 m .66035 .32276 L .69018 .32033 L p .78 .785 .857 r
F P
0 g
s
.79367 .34429 m .77162 .33744 L .7408 .31962 L p .518 .555 .833 r
F P
0 g
s
.7408 .31962 m .7622 .32134 L .79367 .34429 L p .518 .555 .833 r
F P
0 g
s
.7622 .32134 m .7408 .31962 L .7106 .31145 L p .586 .662 .891 r
F P
0 g
s
.63071 .37785 m .61105 .40429 L .58057 .40276 L p .78 .653 .722 r
F P
0 g
s
.58057 .40276 m .60043 .37765 L .63071 .37785 L p .78 .653 .722 r
F P
0 g
s
.8678 .42284 m .84491 .41389 L .81296 .38551 L p .409 .489 .83 r
F P
0 g
s
.81296 .38551 m .83541 .39349 L .8678 .42284 L p .409 .489 .83 r
F P
0 g
s
.90814 .45899 m .88567 .4557 L .85438 .43459 L p .411 .576 .905 r
F P
0 g
s
.85438 .43459 m .87679 .43946 L .90814 .45899 L p .411 .576 .905 r
F P
0 g
s
.82597 .37438 m .8032 .36328 L .77162 .33744 L p .438 .489 .815 r
F P
0 g
s
.77162 .33744 m .79367 .34429 L .82597 .37438 L p .438 .489 .815 r
F P
0 g
s
.88567 .4557 m .90814 .45899 L .91634 .4709 L closepath p .417 .626 .94 r
F P
0 g
s
.7106 .31145 m .73155 .30861 L .7622 .32134 L p .586 .662 .891 r
F P
0 g
s
.73155 .30861 m .7106 .31145 L .68072 .31246 L p .604 .834 .987 r
F P
0 g
s
.66035 .32276 m .68072 .31246 L .7106 .31145 L p .729 .83 .928 r
F P
0 g
s
.61105 .40429 m .59134 .43293 L .56065 .4293 L p .774 .636 .709 r
F P
0 g
s
.56065 .4293 m .58057 .40276 L .61105 .40429 L p .774 .636 .709 r
F P
0 g
s
.62185 .43816 m .60206 .46213 L .57146 .45909 L p .757 .614 .699 r
F P
0 g
s
.57146 .45909 m .59134 .43293 L .62185 .43816 L p .757 .614 .699 r
F P
0 g
s
.66035 .32276 m .64024 .33741 L .61001 .3412 L p .77 .889 .93 r
F P
0 g
s
.64024 .33741 m .6203 .35596 L .58989 .35722 L p .794 .787 .846 r
F P
0 g
s
.58989 .35722 m .61001 .3412 L .64024 .33741 L p .794 .787 .846 r
F P
0 g
s
.6203 .35596 m .60043 .37765 L .56984 .37632 L p .785 .712 .783 r
F P
0 g
s
.56984 .37632 m .58989 .35722 L .6203 .35596 L p .785 .712 .783 r
F P
0 g
s
.85874 .40634 m .83541 .39349 L .8032 .36328 L p .327 .447 .83 r
F P
0 g
s
.8032 .36328 m .82597 .37438 L .85874 .40634 L p .327 .447 .83 r
F P
0 g
s
.89982 .44691 m .87679 .43946 L .84491 .41389 L p .295 .502 .888 r
F P
0 g
s
.84491 .41389 m .8678 .42284 L .89982 .44691 L p .295 .502 .888 r
F P
0 g
s
.60043 .37765 m .58057 .40276 L .5498 .39835 L p .773 .662 .741 r
F P
0 g
s
.5498 .39835 m .56984 .37632 L .60043 .37765 L p .773 .662 .741 r
F P
0 g
s
.68072 .31246 m .66035 .32276 L .63028 .32859 L p .616 .939 .954 r
F P
0 g
s
.61001 .3412 m .63028 .32859 L .66035 .32276 L p .77 .889 .93 r
F P
0 g
s
.59134 .43293 m .57146 .45909 L .5406 .45098 L p .76 .644 .733 r
F P
0 g
s
.5406 .45098 m .56065 .4293 L .59134 .43293 L p .76 .644 .733 r
F P
0 g
s
.81667 .3576 m .79367 .34429 L .7622 .32134 L p .361 .486 .851 r
F P
0 g
s
.7622 .32134 m .78443 .32972 L .81667 .3576 L p .361 .486 .851 r
F P
0 g
s
.70148 .30683 m .72271 .30591 L .73083 .30747 L p .405 .758 .994 r
F P
0 g
s
.73155 .30861 m .75316 .31175 L .78443 .32972 L p .433 .597 .913 r
F P
0 g
s
.74921 .31595 m .73155 .30861 L p .74466 .31385 L .433 .597 .913 r
F P
0 g
s
.68072 .31246 m .70148 .30683 L .73155 .30861 L p .604 .834 .987 r
F P
0 g
s
.75316 .31175 m .73155 .30861 L .70148 .30683 L p .405 .758 .994 r
F P
0 g
s
.73083 .30747 m .75316 .31175 L p .73671 .31018 L .405 .758 .994 r
F P
0 g
s
.70148 .30683 m .73083 .30747 L .73671 .31018 L .405 .758 .994 r
F
.78443 .32972 m .7622 .32134 L .74921 .31595 L p .433 .597 .913 r
F P
0 g
s
.75316 .31175 m .77552 .32048 L .79025 .33127 L p .253 .495 .894 r
F P
0 g
s
.74857 .31565 m .78443 .32972 L .74921 .31595 L .433 .597 .913 r
F
.75857 .3194 m .78443 .32972 L .74857 .31565 L F
.81667 .3576 m .78443 .32972 L p .80664 .34791 L .157 .387 .836 r
F P
0 g
s
.84061 .37571 m .81872 .35915 L p .80664 .34791 L .157 .387 .836 r
F P
0 g
s
.81872 .35915 m .81667 .3576 L p .80664 .34791 L .157 .387 .836 r
F P
0 g
s
.78443 .32972 m .80757 .34397 L .84061 .37571 L p .157 .387 .836 r
F P
0 g
s
.77554 .32461 m .75316 .31175 L p .7689 .32107 L .253 .495 .894 r
F P
0 g
s
.78443 .32972 m .77554 .32461 L p .80757 .34397 L .253 .495 .894 r
F P
0 g
s
.77187 .32265 m .80757 .34397 L .77554 .32461 L .253 .495 .894 r
F
.7689 .32107 m .7804 .32788 L .77187 .32265 L F
.7804 .32788 m .80757 .34397 L .77187 .32265 L F
.77552 .32048 m .7987 .33409 L .81845 .35118 L p .088 .386 .846 r
F P
0 g
s
.75316 .31175 m .79025 .33127 L .77905 .32708 L .253 .495 .894 r
F
.79025 .33127 m .80757 .34397 L p .79338 .33556 L F P
0 g
s
.78778 .33035 m .79025 .33127 L .79338 .33556 L .253 .495 .894 r
F
.77552 .32048 m .75316 .31175 L .73402 .30808 L p .211 .627 .952 r
F P
0 g
s
.73402 .30808 m .72271 .30591 L p .74441 .3119 L .211 .627 .952 r
F P
0 g
s
.74441 .3119 m .77552 .32048 L .73402 .30808 L .211 .627 .952 r
F
.72271 .30591 m .74451 .3095 L .75261 .31237 L p F P
0 g
s
.75261 .31237 m .77552 .32048 L p .75956 .31608 L .211 .627 .952 r
F P
0 g
s
.72271 .30591 m .75261 .31237 L .75956 .31608 L .211 .627 .952 r
F
.80296 .34058 m .77552 .32048 L p .79425 .33454 L .088 .386 .846 r
F P
0 g
s
.84061 .37571 m .80757 .34397 L p .83387 .36804 L 0 .283 .785 r
F P
0 g
s
.80757 .34397 m .83161 .36256 L .86539 .3969 L p 0 .283 .785 r
F P
0 g
s
.83161 .36256 m .81022 .34601 L p .80951 .34561 L .088 .386 .846 r
F P
0 g
s
.81022 .34601 m .80757 .34397 L p .80951 .34561 L .088 .386 .846 r
F P
0 g
s
.80757 .34397 m .80296 .34058 L p .80951 .34561 L .088 .386 .846 r
F P
0 g
s
.79425 .33454 m .83161 .36256 L .80296 .34058 L .088 .386 .846 r
F
.77552 .32048 m .8151 .34878 L .80747 .34445 L F
.8151 .34878 m .81845 .35118 L .81593 .34963 L F
.8151 .34878 m .81593 .34963 L .80747 .34445 L F
.86539 .3969 m .84507 .37953 L p .83387 .36804 L 0 .283 .785 r
F P
0 g
s
.84507 .37953 m .84061 .37571 L p .83387 .36804 L 0 .283 .785 r
F P
0 g
s
.7987 .33409 m .77552 .32048 L .76192 .31567 L p .093 .507 .904 r
F P
0 g
s
.76192 .31567 m .74451 .3095 L p .75794 .3156 L .093 .507 .904 r
F P
0 g
s
.75894 .31561 m .7987 .33409 L .76192 .31567 L .093 .507 .904 r
F
.76425 .31846 m .7987 .33409 L .75894 .31561 L F
.74451 .3095 m .76694 .31721 L .777 .32255 L p F P
0 g
s
.777 .32255 m .7987 .33409 L p .78403 .32743 L .093 .507 .904 r
F P
0 g
s
.75794 .3156 m .76425 .31846 L .75894 .31561 L .093 .507 .904 r
F
.74451 .3095 m .777 .32255 L .78403 .32743 L F
.83161 .36256 m .7987 .33409 L p .82051 .35291 L 0 .31 .802 r
F P
0 g
s
.85648 .38395 m .83178 .36271 L p .82051 .35291 L 0 .31 .802 r
F P
0 g
s
.83178 .36271 m .83161 .36256 L p .82051 .35291 L 0 .31 .802 r
F P
0 g
s
.7987 .33409 m .82269 .35131 L .85648 .38395 L p 0 .31 .802 r
F P
0 g
s
.78945 .32917 m .76694 .31721 L p .78329 .3272 L .055 .426 .869 r
F P
0 g
s
.82269 .35131 m .7987 .33409 L .78945 .32917 L p .055 .426 .869 r
F P
0 g
s
.78334 .32722 m .82269 .35131 L .78945 .32917 L .055 .426 .869 r
F
.78329 .3272 m .78361 .3274 L .78334 .32722 L F
.78361 .3274 m .82269 .35131 L .78334 .32722 L F
.7965 .33292 m .80176 .33661 L p .78586 .32775 L F P
0 g
s
.76694 .31721 m .78715 .32795 L .78586 .32775 L .055 .426 .869 r
F
.78715 .32795 m .7965 .33292 L .78586 .32775 L F
.76694 .31721 m .79006 .3284 L .7965 .33292 L p F P
0 g
s
.80176 .33661 m .81348 .34485 L p .80636 .34062 L .055 .426 .869 r
F P
0 g
s
.76694 .31721 m .80176 .33661 L .80636 .34062 L .055 .426 .869 r
F
.81348 .34485 m .82269 .35131 L p .80252 .33897 L F P
0 g
s
.76694 .31721 m .81348 .34485 L .80252 .33897 L .055 .426 .869 r
F
.82269 .35131 m .84744 .37082 L .85648 .38395 L closepath p 0 .238 .751 r
F P
0 g
s
.84744 .37082 m .82269 .35131 L .8184 .3483 L p .083 .387 .847 r
F P
0 g
s
.8184 .3483 m .79006 .3284 L p .80927 .34261 L .083 .387 .847 r
F P
0 g
s
.80927 .34261 m .84744 .37082 L .8184 .3483 L .083 .387 .847 r
F
.74466 .31385 m .75857 .3194 L .74857 .31565 L .433 .597 .913 r
F
.79006 .3284 m .76694 .31721 L .74025 .31489 L p 0 .481 .77 r
F P
0 g
s
.74025 .31489 m .73618 .31454 L p .74694 .31731 L 0 .481 .77 r
F P
0 g
s
.74694 .31731 m .79006 .3284 L .74025 .31489 L 0 .481 .77 r
F
.73618 .31454 m .75864 .31977 L .76845 .32246 L p F P
0 g
s
.73618 .31454 m .76845 .32246 L .77453 .3244 L 0 .481 .77 r
F
.79006 .3284 m .81384 .34215 L .84188 .36608 L p .083 .387 .847 r
F P
0 g
s
.79006 .3284 m .84188 .36608 L .83349 .36051 L .083 .387 .847 r
F
.76845 .32246 m .79006 .3284 L p .77453 .3244 L 0 .481 .77 r
F P
0 g
s
.77905 .32708 m .78778 .33035 L .79338 .33556 L .253 .495 .894 r
F
.81384 .34215 m .79006 .3284 L .77738 .32492 L p .089 .526 .906 r
F P
0 g
s
.77738 .32492 m .75864 .31977 L p .7729 .32555 L .089 .526 .906 r
F P
0 g
s
.7729 .32555 m .81384 .34215 L .77738 .32492 L .089 .526 .906 r
F
.72806 .32632 m .75051 .32765 L .75996 .32738 L p .178 0 0 r
F P
0 g
s
.75864 .31977 m .78159 .32676 L .79125 .33137 L p .089 .526 .906 r
F P
0 g
s
.75864 .31977 m .79125 .33137 L .7987 .33601 L .089 .526 .906 r
F
.75996 .32738 m .78159 .32676 L p .76531 .32662 L .178 0 0 r
F P
0 g
s
.72806 .32632 m .75996 .32738 L .76531 .32662 L .178 0 0 r
F
.79125 .33137 m .81384 .34215 L p .7987 .33601 L .089 .526 .906 r
F P
0 g
s
.84188 .36608 m .84744 .37082 L p .83349 .36051 L .083 .387 .847 r
F P
0 g
s
.7142 .31152 m .73618 .31454 L .74581 .31537 L p .177 0 0 r
F P
0 g
s
.74581 .31537 m .76694 .31721 L p .75078 .31546 L .177 0 0 r
F P
0 g
s
.7142 .31152 m .74581 .31537 L .75078 .31546 L .177 0 0 r
F
.81845 .35118 m .83161 .36256 L p .80747 .34445 L .088 .386 .846 r
F P
0 g
s
.58057 .40276 m .56065 .4293 L .52973 .42496 L p .761 .618 .7 r
F P
0 g
s
.52973 .42496 m .5498 .39835 L .58057 .40276 L p .761 .618 .7 r
F P
0 g
s
.87679 .43946 m .89982 .44691 L .90814 .45899 L closepath p .28 .544 .921 r
F P
0 g
s
.70148 .30683 m .68072 .31246 L .65077 .31944 L p .281 .782 .785 r
F P
0 g
s
.63028 .32859 m .65077 .31944 L .68072 .31246 L p .616 .939 .954 r
F P
0 g
s
.89139 .43466 m .8678 .42284 L .83541 .39349 L p .175 .422 .859 r
F P
0 g
s
.83541 .39349 m .85874 .40634 L .89139 .43466 L p .175 .422 .859 r
F P
0 g
s
.84966 .39045 m .82597 .37438 L .79367 .34429 L p .24 .411 .832 r
F P
0 g
s
.79367 .34429 m .81667 .3576 L .84966 .39045 L p .24 .411 .832 r
F P
0 g
s
.61001 .3412 m .58989 .35722 L .55911 .35562 L p .761 .8 .884 r
F P
0 g
s
.58989 .35722 m .56984 .37632 L .53896 .37223 L p .763 .702 .794 r
F P
0 g
s
.53896 .37223 m .55911 .35562 L .58989 .35722 L p .763 .702 .794 r
F P
0 g
s
.56984 .37632 m .5498 .39835 L .51882 .39264 L p .757 .649 .742 r
F P
0 g
s
.51882 .39264 m .53896 .37223 L .56984 .37632 L p .757 .649 .742 r
F P
0 g
s
.56065 .4293 m .5406 .45098 L .50958 .44543 L p .755 .645 .739 r
F P
0 g
s
.50958 .44543 m .52973 .42496 L .56065 .4293 L p .755 .645 .739 r
F P
0 g
s
.63028 .32859 m .61001 .3412 L .57936 .34285 L p .664 .923 .974 r
F P
0 g
s
.55911 .35562 m .57936 .34285 L .61001 .3412 L p .761 .8 .884 r
F P
0 g
s
.5498 .39835 m .52973 .42496 L .49861 .41804 L p .755 .615 .703 r
F P
0 g
s
.49861 .41804 m .51882 .39264 L .5498 .39835 L p .755 .615 .703 r
F P
0 g
s
.65077 .31944 m .67154 .31366 L .70148 .30683 L p .281 .782 .785 r
F P
0 g
s
.72271 .30591 m .70148 .30683 L .67154 .31366 L p .007 0 0 r
F P
0 g
s
.65077 .31944 m .63028 .32859 L .59977 .33372 L p .204 .722 .693 r
F P
0 g
s
.57936 .34285 m .59977 .33372 L .63028 .32859 L p .664 .923 .974 r
F P
0 g
s
.8678 .42284 m .89139 .43466 L .89982 .44691 L closepath p .125 .44 .877 r
F P
0 g
s
.55911 .35562 m .53896 .37223 L .50787 .36473 L p .735 .668 .784 r
F P
0 g
s
.53896 .37223 m .51882 .39264 L .48765 .38561 L p .743 .621 .724 r
F P
0 g
s
.48765 .38561 m .50787 .36473 L .53896 .37223 L p .743 .621 .724 r
F P
0 g
s
.52973 .42496 m .50958 .44543 L .47833 .44244 L p .749 .611 .705 r
F P
0 g
s
.47833 .44244 m .49861 .41804 L .52973 .42496 L p .749 .611 .705 r
F P
0 g
s
.88285 .42225 m .85874 .40634 L .82597 .37438 L p .068 .35 .823 r
F P
0 g
s
.82597 .37438 m .84966 .39045 L .88285 .42225 L p .068 .35 .823 r
F P
0 g
s
.57936 .34285 m .55911 .35562 L .52806 .34976 L p .713 .758 .887 r
F P
0 g
s
.50787 .36473 m .52806 .34976 L .55911 .35562 L p .735 .668 .784 r
F P
0 g
s
.51882 .39264 m .49861 .41804 L .46734 .4104 L p .75 .609 .702 r
F P
0 g
s
.46734 .4104 m .48765 .38561 L .51882 .39264 L p .75 .609 .702 r
F P
0 g
s
.67154 .31366 m .65077 .31944 L .62041 .32786 L p .196 0 0 r
F P
0 g
s
.62041 .32786 m .59977 .33372 L .56879 .33452 L p .114 0 0 r
F P
0 g
s
.62041 .32786 m .5895 .33311 L p .61784 .32851 L .413 0 0 r
F P
0 g
s
.59977 .33372 m .62041 .32786 L p .62294 .32723 L .204 .722 .693 r
F P
0 g
s
.64132 .3247 m .62041 .32786 L p .61784 .32851 L .413 0 0 r
F P
0 g
s
.62041 .32786 m .65077 .31944 L p .62294 .32723 L .204 .722 .693 r
F P
0 g
s
.59977 .33372 m .57936 .34285 L .54834 .33982 L p .531 .867 .993 r
F P
0 g
s
.52806 .34976 m .54834 .33982 L .57936 .34285 L p .713 .758 .887 r
F P
0 g
s
.52806 .34976 m .50787 .36473 L .47666 .35445 L p .716 .628 .759 r
F P
0 g
s
.50787 .36473 m .48765 .38561 L .45638 .37568 L p .732 .602 .711 r
F P
0 g
s
.45638 .37568 m .47666 .35445 L .50787 .36473 L p .732 .602 .711 r
F P
0 g
s
.49861 .41804 m .47833 .44244 L .44696 .43437 L p .746 .608 .705 r
F P
0 g
s
.44696 .43437 m .46734 .4104 L .49861 .41804 L p .746 .608 .705 r
F P
0 g
s
.48765 .38561 m .46734 .4104 L .43585 .40436 L p .743 .584 .677 r
F P
0 g
s
.43585 .40436 m .45638 .37568 L .48765 .38561 L p .743 .584 .677 r
F P
0 g
s
.54834 .33982 m .52806 .34976 L .49685 .3396 L p .679 .683 .846 r
F P
0 g
s
.47666 .35445 m .49685 .3396 L .52806 .34976 L p .716 .628 .759 r
F P
0 g
s
.74451 .3095 m .72271 .30591 L .69267 .31112 L p .151 0 0 r
F P
0 g
s
.67154 .31366 m .69267 .31112 L .72271 .30591 L p .007 0 0 r
F P
0 g
s
.49685 .3396 m .47666 .35445 L .44538 .343 L p .71 .6 .731 r
F P
0 g
s
.47666 .35445 m .45638 .37568 L .42498 .36612 L p .732 .59 .697 r
F P
0 g
s
.42498 .36612 m .44538 .343 L .47666 .35445 L p .732 .59 .697 r
F P
0 g
s
.45638 .37568 m .43585 .40436 L .40424 .39673 L p .746 .582 .671 r
F P
0 g
s
.40424 .39673 m .42498 .36612 L .45638 .37568 L p .746 .582 .671 r
F P
0 g
s
.46734 .4104 m .44696 .43437 L .4154 .42726 L p .751 .623 .717 r
F P
0 g
s
.4154 .42726 m .43585 .40436 L .46734 .4104 L p .751 .623 .717 r
F P
0 g
s
.85874 .40634 m .88285 .42225 L .89139 .43466 L closepath p 0 .334 .816 r
F P
0 g
s
.54834 .33982 m .56879 .33452 L .59977 .33372 L p .531 .867 .993 r
F P
0 g
s
.49685 .3396 m .51707 .33097 L .54834 .33982 L p .679 .683 .846 r
F P
0 g
s
.51707 .33097 m .49685 .3396 L .46559 .32655 L p .669 .625 .797 r
F P
0 g
s
.44538 .343 m .46559 .32655 L .49685 .3396 L p .71 .6 .731 r
F P
0 g
s
.46559 .32655 m .44538 .343 L .41397 .33241 L p .717 .589 .712 r
F P
0 g
s
.44538 .343 m .42498 .36612 L .39335 .35898 L p .739 .586 .684 r
F P
0 g
s
.39335 .35898 m .41397 .33241 L .44538 .343 L p .739 .586 .684 r
F P
0 g
s
.87418 .40966 m .84966 .39045 L .81667 .3576 L p 0 .299 .795 r
F P
0 g
s
.81667 .3576 m .84061 .37571 L .87418 .40966 L p 0 .299 .795 r
F P
0 g
s
.69267 .31112 m .67154 .31366 L .64132 .3247 L p .348 0 0 r
F P
0 g
s
.62041 .32786 m .64132 .3247 L .67154 .31366 L p .196 0 0 r
F P
0 g
s
.46559 .32655 m .48573 .31742 L .51707 .33097 L p .669 .625 .797 r
F P
0 g
s
.48573 .31742 m .46559 .32655 L .43428 .31313 L p .678 .597 .758 r
F P
0 g
s
.41397 .33241 m .43428 .31313 L .46559 .32655 L p .717 .589 .712 r
F P
0 g
s
.56879 .33452 m .54834 .33982 L .51707 .33097 L p .502 .773 .992 r
F P
0 g
s
.43428 .31313 m .45439 .30166 L .48573 .31742 L p .678 .597 .758 r
F P
0 g
s
.45439 .30166 m .43428 .31313 L .40281 .30238 L p .7 .594 .734 r
F P
0 g
s
.43428 .31313 m .41397 .33241 L .38233 .3247 L p .733 .597 .704 r
F P
0 g
s
.38233 .3247 m .40281 .30238 L .43428 .31313 L p .733 .597 .704 r
F P
0 g
s
.42498 .36612 m .40424 .39673 L .37245 .38928 L p .754 .594 .678 r
F P
0 g
s
.37245 .38928 m .39335 .35898 L .42498 .36612 L p .754 .594 .678 r
F P
0 g
s
.41397 .33241 m .39335 .35898 L .36148 .35311 L p .751 .596 .684 r
F P
0 g
s
.36148 .35311 m .38233 .3247 L .41397 .33241 L p .751 .596 .684 r
F P
0 g
s
.43585 .40436 m .4154 .42726 L .38348 .42445 L p .75 .598 .688 r
F P
0 g
s
.38348 .42445 m .40424 .39673 L .43585 .40436 L p .75 .598 .688 r
F P
0 g
s
.51707 .33097 m .53745 .32853 L .56879 .33452 L p .502 .773 .992 r
F P
0 g
s
.53745 .32853 m .51707 .33097 L .48573 .31742 L p .542 .671 .921 r
F P
0 g
s
.40281 .30238 m .42301 .28714 L .45439 .30166 L p .7 .594 .734 r
F P
0 g
s
.42301 .28714 m .40281 .30238 L .37101 .29637 L p .73 .614 .729 r
F P
0 g
s
.40281 .30238 m .38233 .3247 L .35027 .32139 L p .755 .617 .706 r
F P
0 g
s
.35027 .32139 m .37101 .29637 L .40281 .30238 L p .755 .617 .706 r
F P
0 g
s
.48573 .31742 m .50595 .31571 L .53745 .32853 L p .542 .671 .921 r
F P
0 g
s
.50595 .31571 m .48573 .31742 L .45439 .30166 L p .586 .611 .844 r
F P
0 g
s
.45439 .30166 m .47446 .29851 L .50595 .31571 L p .586 .611 .844 r
F P
0 g
s
.47446 .29851 m .45439 .30166 L .42301 .28714 L p .632 .594 .793 r
F P
0 g
s
.56879 .33452 m .5895 .33311 L p .58378 .33259 L .114 0 0 r
F P
0 g
s
.5895 .33311 m .56879 .33452 L .55692 .33225 L p .209 0 0 r
F P
0 g
s
.55692 .33225 m .53745 .32853 L p .54976 .32961 L .209 0 0 r
F P
0 g
s
.54976 .32961 m .5895 .33311 L .55692 .33225 L .209 0 0 r
F
.5581 .3313 m .5895 .33311 L p .55376 .32996 L F P
0 g
s
.53745 .32853 m .5581 .3313 L p .55376 .32996 L .209 0 0 r
F P
0 g
s
.5895 .33311 m .5581 .3313 L p .59529 .33363 L .52 .018 .005 r
F P
0 g
s
.5581 .3313 m .5791 .338 L .61053 .33459 L p .52 .018 .005 r
F P
0 g
s
.50595 .31571 m .47446 .29851 L p .5103 .31403 L .249 .563 .936 r
F P
0 g
s
.5264 .321 m .51716 .31861 L p .5103 .31403 L .249 .563 .936 r
F P
0 g
s
.51716 .31861 m .50595 .31571 L p .5103 .31403 L .249 .563 .936 r
F P
0 g
s
.49466 .3036 m .46301 .28294 L p .47961 .29355 L 0 .33 .788 r
F P
0 g
s
.49466 .3036 m .5264 .321 L p .49769 .30857 L .249 .563 .936 r
F P
0 g
s
.47446 .29851 m .49034 .30251 L p .49769 .30857 L .249 .563 .936 r
F P
0 g
s
.49034 .30251 m .49466 .3036 L p .49769 .30857 L .249 .563 .936 r
F P
0 g
s
.51515 .31627 m .50319 .30863 L p .49466 .3036 L .513 0 0 r
F P
0 g
s
.50942 .3123 m .51515 .31627 L .52107 .31916 L p .513 0 0 r
F P
0 g
s
.53821 .32484 m .5264 .321 L p .53532 .32388 L .575 .032 0 r
F P
0 g
s
.5264 .321 m .5581 .3313 L p .53813 .32532 L 0 .483 .8 r
F P
0 g
s
.5264 .321 m .49466 .3036 L p .52424 .31953 L .513 0 0 r
F P
0 g
s
.52854 .32246 m .5264 .321 L .53813 .32532 L 0 .483 .8 r
F
.5581 .3313 m .53745 .32853 L .50595 .31571 L p F P
0 g
s
.5581 .3313 m .53821 .32484 L p .56249 .33264 L .575 .032 0 r
F P
0 g
s
.53532 .32388 m .56249 .33264 L .53821 .32484 L .575 .032 0 r
F
.5791 .338 m .5581 .3313 L p .56249 .33264 L F P
0 g
s
.5264 .321 m .54721 .33191 L .5791 .338 L p .575 .032 0 r
F P
0 g
s
.54721 .33191 m .5264 .321 L p .52424 .31953 L .513 0 0 r
F P
0 g
s
.50595 .31571 m .5264 .321 L p .52854 .32246 L 0 .483 .8 r
F P
0 g
s
.51829 .31633 m .52107 .31916 L .5275 .32129 L .513 0 0 r
F
.49466 .3036 m .5162 .31629 L .51829 .31633 L F
.5162 .31629 m .52107 .31916 L .51829 .31633 L F
.48316 .29407 m .51515 .31627 L p .50723 .31121 L 0 .33 .788 r
F P
0 g
s
.47895 .29313 m .48316 .29407 L .50723 .31121 L 0 .33 .788 r
F
.43142 .26367 m .45133 .27063 L .48316 .29407 L p .253 .494 .893 r
F P
0 g
s
.48316 .29407 m .45133 .27063 L p .4591 .27694 L 0 .122 .601 r
F P
0 g
s
.47385 .28893 m .48316 .29407 L p .47895 .29313 L 0 .33 .788 r
F P
0 g
s
.47961 .29355 m .50723 .31121 L .49485 .30372 L 0 .33 .788 r
F
.51515 .31627 m .51072 .31354 L p .50723 .31121 L F P
0 g
s
.51072 .31354 m .49485 .30372 L p .50723 .31121 L 0 .33 .788 r
F P
0 g
s
.46301 .28294 m .43142 .26367 L p .47048 .28662 L .253 .494 .893 r
F P
0 g
s
.48316 .29407 m .47116 .28744 L p .47048 .28662 L .253 .494 .893 r
F P
0 g
s
.47116 .28744 m .46301 .28294 L p .47048 .28662 L .253 .494 .893 r
F P
0 g
s
.4591 .27694 m .47443 .28937 L .48316 .29407 L 0 .122 .601 r
F
.49485 .30372 m .49466 .3036 L p .47961 .29355 L 0 .33 .788 r
F P
0 g
s
.49466 .3036 m .47446 .29851 L .44303 .28055 L p .448 .571 .886 r
F P
0 g
s
.44303 .28055 m .46301 .28294 L .49466 .3036 L p .448 .571 .886 r
F P
0 g
s
.50366 .31308 m .48742 .29802 L p .47443 .28937 L 0 .122 .601 r
F P
0 g
s
.48742 .29802 m .48316 .29407 L p .47443 .28937 L 0 .122 .601 r
F P
0 g
s
.47143 .28648 m .50366 .31308 L p .46932 .28523 L 0 .122 .601 r
F P
0 g
s
.45133 .27063 m .46833 .28403 L p .46932 .28523 L 0 .122 .601 r
F P
0 g
s
.46833 .28403 m .47143 .28648 L p .46932 .28523 L 0 .122 .601 r
F P
0 g
s
.51515 .31627 m .48316 .29407 L p .51197 .31622 L .674 .124 0 r
F P
0 g
s
.53608 .33475 m .51515 .31627 L p .51197 .31622 L .674 .124 0 r
F P
0 g
s
.46301 .28294 m .47385 .28893 L p .47895 .29313 L 0 .33 .788 r
F P
0 g
s
.52107 .31916 m .54721 .33191 L p .5275 .32129 L .513 0 0 r
F P
0 g
s
.61053 .33459 m .5895 .33311 L p .59529 .33363 L .52 .018 .005 r
F P
0 g
s
.5895 .33311 m .62041 .32786 L p .58378 .33259 L .114 0 0 r
F P
0 g
s
.42301 .28714 m .44303 .28055 L .47446 .29851 L p .632 .594 .793 r
F P
0 g
s
.44303 .28055 m .42301 .28714 L .3914 .27731 L p .68 .608 .768 r
F P
0 g
s
.37101 .29637 m .3914 .27731 L .42301 .28714 L p .73 .614 .729 r
F P
0 g
s
.39335 .35898 m .37245 .38928 L .34024 .38608 L p .76 .594 .671 r
F P
0 g
s
.34024 .38608 m .36148 .35311 L .39335 .35898 L p .76 .594 .671 r
F P
0 g
s
.38233 .3247 m .36148 .35311 L .32922 .35015 L p .768 .619 .695 r
F P
0 g
s
.32922 .35015 m .35027 .32139 L .38233 .3247 L p .768 .619 .695 r
F P
0 g
s
.40424 .39673 m .38348 .42445 L .35153 .41733 L p .751 .598 .687 r
F P
0 g
s
.35153 .41733 m .37245 .38928 L .40424 .39673 L p .751 .598 .687 r
F P
0 g
s
.69267 .31112 m .7142 .31152 L .74451 .3095 L p .151 0 0 r
F P
0 g
s
.7142 .31152 m .69267 .31112 L .66253 .32359 L p .401 0 .001 r
F P
0 g
s
.64132 .3247 m .66253 .32359 L .69267 .31112 L p .348 0 0 r
F P
0 g
s
.84966 .39045 m .87418 .40966 L .88285 .42225 L closepath p 0 .248 .757 r
F P
0 g
s
.76694 .31721 m .74451 .3095 L .7142 .31152 L p .177 0 0 r
F P
0 g
s
.3914 .27731 m .4115 .26597 L .44303 .28055 L p .68 .608 .768 r
F P
0 g
s
.4115 .26597 m .3914 .27731 L .3593 .27425 L p .731 .65 .769 r
F P
0 g
s
.3914 .27731 m .37101 .29637 L .33864 .29633 L p .765 .652 .737 r
F P
0 g
s
.33864 .29633 m .3593 .27425 L .3914 .27731 L p .765 .652 .737 r
F P
0 g
s
.37101 .29637 m .35027 .32139 L .31765 .32264 L p .782 .652 .719 r
F P
0 g
s
.31765 .32264 m .33864 .29633 L .37101 .29637 L p .782 .652 .719 r
F P
0 g
s
.36148 .35311 m .34024 .38608 L .30783 .38215 L p .77 .611 .682 r
F P
0 g
s
.30783 .38215 m .32922 .35015 L .36148 .35311 L p .77 .611 .682 r
F P
0 g
s
.37245 .38928 m .35153 .41733 L .31941 .41007 L p .765 .639 .722 r
F P
0 g
s
.31941 .41007 m .34024 .38608 L .37245 .38928 L p .765 .639 .722 r
F P
0 g
s
.46301 .28294 m .44303 .28055 L .4115 .26597 L p .567 .592 .838 r
F P
0 g
s
.35027 .32139 m .32922 .35015 L .29639 .35131 L p .787 .649 .71 r
F P
0 g
s
.29639 .35131 m .31765 .32264 L .35027 .32139 L p .787 .649 .71 r
F P
0 g
s
.4115 .26597 m .43142 .26367 L .46301 .28294 L p .567 .592 .838 r
F P
0 g
s
.43142 .26367 m .4115 .26597 L .37962 .2584 L p .657 .637 .819 r
F P
0 g
s
.3593 .27425 m .37962 .2584 L .4115 .26597 L p .731 .65 .769 r
F P
0 g
s
.66253 .32359 m .64132 .3247 L .61053 .33459 L p .488 .049 .131 r
F P
0 g
s
.5895 .33311 m .61053 .33459 L .64132 .3247 L p .413 0 0 r
F P
0 g
s
.37962 .2584 m .3593 .27425 L .32644 .27863 L p .784 .715 .787 r
F P
0 g
s
.3593 .27425 m .33864 .29633 L .30551 .30216 L p .805 .71 .761 r
F P
0 g
s
.30551 .30216 m .32644 .27863 L .3593 .27425 L p .805 .71 .761 r
F P
0 g
s
.37962 .2584 m .39965 .25038 L .43142 .26367 L p .657 .637 .819 r
F P
0 g
s
.39965 .25038 m .37962 .2584 L .34705 .25944 L p .735 .714 .831 r
F P
0 g
s
.32644 .27863 m .34705 .25944 L .37962 .2584 L p .784 .715 .787 r
F P
0 g
s
.33864 .29633 m .31765 .32264 L .28436 .32772 L p .811 .706 .749 r
F P
0 g
s
.28436 .32772 m .30551 .30216 L .33864 .29633 L p .811 .706 .749 r
F P
0 g
s
.32922 .35015 m .30783 .38215 L .2751 .37893 L p .786 .653 .716 r
F P
0 g
s
.2751 .37893 m .29639 .35131 L .32922 .35015 L p .786 .653 .716 r
F P
0 g
s
.73618 .31454 m .7142 .31152 L .68407 .32388 L p .404 0 0 r
F P
0 g
s
.66253 .32359 m .68407 .32388 L .7142 .31152 L p .401 0 .001 r
F P
0 g
s
.84061 .37571 m .86539 .3969 L .87418 .40966 L closepath p 0 .197 .72 r
F P
0 g
s
.34024 .38608 m .31941 .41007 L .2868 .40711 L p .762 .63 .714 r
F P
0 g
s
.2868 .40711 m .30783 .38215 L .34024 .38608 L p .762 .63 .714 r
F P
0 g
s
.31765 .32264 m .29639 .35131 L .26308 .35389 L p .806 .694 .741 r
F P
0 g
s
.26308 .35389 m .28436 .32772 L .31765 .32264 L p .806 .694 .741 r
F P
0 g
s
.41951 .25136 m .43938 .26145 L .44707 .26745 L p .052 .398 .854 r
F P
0 g
s
.45133 .27063 m .43142 .26367 L .42497 .26098 L p .478 .591 .888 r
F P
0 g
s
.43178 .26297 m .45133 .27063 L .42497 .26098 L .478 .591 .888 r
F
.39965 .25038 m .41951 .25136 L .45133 .27063 L p F P
0 g
s
.45133 .27063 m .41951 .25136 L p .44517 .26871 L .052 .398 .854 r
F P
0 g
s
.44517 .26871 m .4531 .27408 L .45112 .27222 L .052 .398 .854 r
F
.45992 .27741 m .45133 .27063 L p .44517 .26871 L F P
0 g
s
.47143 .28648 m .45992 .27741 L p .45112 .27222 L .052 .398 .854 r
F P
0 g
s
.4531 .27408 m .47143 .28648 L .45112 .27222 L .052 .398 .854 r
F
.44707 .26745 m .47143 .28648 L p .44042 .2655 L F P
0 g
s
.41951 .25136 m .44707 .26745 L .44042 .2655 L .052 .398 .854 r
F
.43938 .26145 m .45946 .28017 L .46825 .2883 L p .491 0 0 r
F P
0 g
s
.46825 .2883 m .49192 .31018 L p .46181 .28226 L .491 0 0 r
F P
0 g
s
.43938 .26145 m .46825 .2883 L .46181 .28226 L .491 0 0 r
F
.41951 .25136 m .39965 .25038 L .36734 .24636 L p .626 .69 .89 r
F P
0 g
s
.36734 .24636 m .38737 .24077 L .41951 .25136 L p .626 .69 .89 r
F P
0 g
s
.41951 .25136 m .38737 .24077 L p .4075 .24877 L .369 .594 .933 r
F P
0 g
s
.43938 .26145 m .4237 .25349 L p .41221 .25014 L .369 .594 .933 r
F P
0 g
s
.4157 .25203 m .43938 .26145 L .41221 .25014 L .369 .594 .933 r
F
.4237 .25349 m .41951 .25136 L p .4075 .24877 L F P
0 g
s
.40724 .24369 m .43938 .26145 L p .41925 .25345 L .369 .594 .933 r
F P
0 g
s
.43938 .26145 m .40724 .24369 L p .42993 .25954 L 0 .334 .808 r
F P
0 g
s
.45946 .28017 m .44566 .26731 L p .43321 .26116 L 0 .334 .808 r
F P
0 g
s
.43574 .2636 m .45946 .28017 L .43321 .26116 L 0 .334 .808 r
F
.44566 .26731 m .43938 .26145 L p .42993 .25954 L F P
0 g
s
.40724 .24369 m .42713 .25512 L .44039 .2654 L p 0 .334 .808 r
F P
0 g
s
.42993 .25954 m .43574 .2636 L .43321 .26116 L 0 .334 .808 r
F
.44039 .2654 m .45946 .28017 L p .43116 .2604 L F P
0 g
s
.40724 .24369 m .44039 .2654 L .43116 .2604 L 0 .334 .808 r
F
.45946 .28017 m .42713 .25512 L p .45326 .2805 L 0 .02 .519 r
F P
0 g
s
.47994 .30639 m .46816 .29132 L p .45326 .2805 L 0 .02 .519 r
F P
0 g
s
.46816 .29132 m .45946 .28017 L p .45326 .2805 L 0 .02 .519 r
F P
0 g
s
.42713 .25512 m .44723 .27452 L .46313 .29002 L p 0 .02 .519 r
F P
0 g
s
.42713 .25512 m .46313 .29002 L .45374 .28096 L 0 .02 .519 r
F
.4075 .24877 m .4157 .25203 L .41221 .25014 L .369 .594 .933 r
F
.38737 .24077 m .40118 .2428 L p .41925 .25345 L F P
0 g
s
.42497 .26098 m .39965 .25038 L p .43178 .26297 L .478 .591 .888 r
F P
0 g
s
.40118 .2428 m .40724 .24369 L p .41925 .25345 L .369 .594 .933 r
F P
0 g
s
.38737 .24077 m .36734 .24636 L .33415 .25215 L p .731 .817 .918 r
F P
0 g
s
.33415 .25215 m .35448 .24125 L .38737 .24077 L p .731 .817 .918 r
F P
0 g
s
.40724 .24369 m .38737 .24077 L .35448 .24125 L p .572 .767 .971 r
F P
0 g
s
.37457 .23707 m .40724 .24369 L p .38679 .24275 L .572 .767 .971 r
F P
0 g
s
.42713 .25512 m .40724 .24369 L .37457 .23707 L p .261 .607 .954 r
F P
0 g
s
.39454 .24045 m .42713 .25512 L p .40687 .24817 L .261 .607 .954 r
F P
0 g
s
.37457 .23707 m .38952 .2396 L p .40687 .24817 L .261 .607 .954 r
F P
0 g
s
.38952 .2396 m .39454 .24045 L p .40687 .24817 L .261 .607 .954 r
F P
0 g
s
.42713 .25512 m .39454 .24045 L p .41516 .25378 L 0 .338 .8 r
F P
0 g
s
.44723 .27452 m .43155 .25939 L p .41658 .25427 L 0 .338 .8 r
F P
0 g
s
.41836 .25585 m .44723 .27452 L .41658 .25427 L 0 .338 .8 r
F
.43155 .25939 m .42713 .25512 L p .41516 .25378 L F P
0 g
s
.41516 .25378 m .41836 .25585 L .41658 .25427 L 0 .338 .8 r
F
.39454 .24045 m .40871 .24814 L p .42721 .26158 L F P
0 g
s
.40871 .24814 m .41453 .2513 L p .42721 .26158 L 0 .338 .8 r
F P
0 g
s
.41453 .2513 m .44723 .27452 L p .42721 .26158 L 0 .338 .8 r
F P
0 g
s
.44723 .27452 m .41453 .2513 L p .4376 .27272 L 0 .102 .614 r
F P
0 g
s
.46773 .30071 m .45347 .28249 L p .43789 .2729 L 0 .102 .614 r
F P
0 g
s
.43832 .27339 m .46773 .30071 L .43789 .2729 L 0 .102 .614 r
F
.45347 .28249 m .44723 .27452 L p .4376 .27272 L F P
0 g
s
.41453 .2513 m .43474 .26905 L .45528 .28877 L p 0 .102 .614 r
F P
0 g
s
.4376 .27272 m .43832 .27339 L .43789 .2729 L 0 .102 .614 r
F
.41453 .2513 m .45528 .28877 L .44504 .27964 L F
.45528 .28877 m .46773 .30071 L p .44504 .27964 L F P
0 g
s
.46773 .30071 m .43474 .26905 L p .46182 .30027 L 0 0 .482 r
F P
0 g
s
.48883 .33142 m .4765 .31347 L p .46182 .30027 L 0 0 .482 r
F P
0 g
s
.4765 .31347 m .46773 .30071 L p .46182 .30027 L 0 0 .482 r
F P
0 g
s
.43474 .26905 m .45534 .29258 L .48051 .32176 L p 0 0 .482 r
F P
0 g
s
.43474 .26905 m .48051 .32176 L .47198 .31199 L 0 0 .482 r
F
.35448 .24125 m .37033 .23795 L p .38679 .24275 L .572 .767 .971 r
F P
0 g
s
.37033 .23795 m .37457 .23707 L p .38679 .24275 L .572 .767 .971 r
F P
0 g
s
.35448 .24125 m .33415 .25215 L .31947 .25816 L p .775 .949 .933 r
F P
0 g
s
.31947 .25816 m .29987 .26617 L p .32585 .25432 L .775 .949 .933 r
F P
0 g
s
.32585 .25432 m .35448 .24125 L .31947 .25816 L .775 .949 .933 r
F
.32051 .25216 m .34094 .24279 L .3466 .24183 L p .658 .926 .974 r
F P
0 g
s
.29987 .26617 m .32051 .25216 L .35448 .24125 L p .775 .949 .933 r
F P
0 g
s
.37457 .23707 m .35448 .24125 L .33963 .24602 L p .658 .926 .974 r
F P
0 g
s
.33963 .24602 m .32051 .25216 L p .37457 .23707 L .658 .926 .974 r
F P
0 g
s
.3466 .24183 m .37457 .23707 L p .33713 .24752 L .658 .926 .974 r
F P
0 g
s
.32051 .25216 m .3466 .24183 L .33713 .24752 L .658 .926 .974 r
F
.39454 .24045 m .37457 .23707 L .34094 .24279 L p .462 .829 .993 r
F P
0 g
s
.34094 .24279 m .36119 .23895 L .39454 .24045 L p .462 .829 .993 r
F P
0 g
s
.41453 .2513 m .39454 .24045 L .36119 .23895 L p .193 .639 .944 r
F P
0 g
s
.38136 .24126 m .41453 .2513 L p .39396 .24654 L .193 .639 .944 r
F P
0 g
s
.41453 .2513 m .39077 .24411 L p .40421 .25173 L 0 .425 .849 r
F P
0 g
s
.36119 .23895 m .37711 .24077 L p .39396 .24654 L .193 .639 .944 r
F P
0 g
s
.37711 .24077 m .38136 .24126 L p .39396 .24654 L .193 .639 .944 r
F P
0 g
s
.34705 .25944 m .36734 .24636 L .39965 .25038 L p .735 .714 .831 r
F P
0 g
s
.39077 .24411 m .38136 .24126 L p .40058 .25127 L 0 .425 .849 r
F P
0 g
s
.40058 .25127 m .43474 .26905 L .39077 .24411 L 0 .425 .849 r
F
.38136 .24126 m .3969 .24767 L p .41462 .25858 L F P
0 g
s
.43474 .26905 m .41732 .25375 L p .40421 .25173 L 0 .425 .849 r
F P
0 g
s
.41732 .25375 m .41453 .2513 L p .40421 .25173 L 0 .425 .849 r
F P
0 g
s
.3969 .24767 m .40158 .2496 L p .41462 .25858 L 0 .425 .849 r
F P
0 g
s
.36734 .24636 m .34705 .25944 L .31355 .26862 L p .803 .817 .862 r
F P
0 g
s
.31355 .26862 m .33415 .25215 L .36734 .24636 L p .803 .817 .862 r
F P
0 g
s
.32051 .25216 m .29987 .26617 L .29986 .26618 L p .65 .968 .835 r
F P
0 g
s
.29986 .26618 m .26453 .28478 L p .29364 .26782 L .65 .968 .835 r
F P
0 g
s
.29364 .26782 m .32051 .25216 L .29986 .26618 L .65 .968 .835 r
F
.26453 .28478 m .28536 .27047 L .32051 .25216 L p F P
0 g
s
.34094 .24279 m .32051 .25216 L .30239 .2616 L p .534 .921 .809 r
F P
0 g
s
.30239 .2616 m .28536 .27047 L p .30888 .25875 L .534 .921 .809 r
F P
0 g
s
.30888 .25875 m .34094 .24279 L .30239 .2616 L .534 .921 .809 r
F
.30608 .25866 m .34094 .24279 L p .28733 .26949 L F P
0 g
s
.36119 .23895 m .34094 .24279 L .30608 .25866 L p .41 .86 .811 r
F P
0 g
s
.32668 .25018 m .33345 .24798 L p .30608 .25866 L .41 .86 .811 r
F P
0 g
s
.33345 .24798 m .36119 .23895 L p .32244 .25281 L .41 .86 .811 r
F P
0 g
s
.30608 .25866 m .33345 .24798 L .32244 .25281 L .41 .86 .811 r
F
.28536 .27047 m .28686 .26961 L p .28733 .26949 L .534 .921 .809 r
F P
0 g
s
.28686 .26961 m .30608 .25866 L p .28733 .26949 L .534 .921 .809 r
F P
0 g
s
.38136 .24126 m .36119 .23895 L .32668 .25018 L p .3 .794 .858 r
F P
0 g
s
.32668 .25018 m .34719 .24566 L .38136 .24126 L p .3 .794 .858 r
F P
0 g
s
.40158 .2496 m .38136 .24126 L .34719 .24566 L p .201 .7 .913 r
F P
0 g
s
.36768 .2455 m .40158 .2496 L p .38039 .24806 L .201 .7 .913 r
F P
0 g
s
.34719 .24566 m .36394 .24553 L p .38039 .24806 L .201 .7 .913 r
F P
0 g
s
.36394 .24553 m .36768 .2455 L p .38039 .24806 L .201 .7 .913 r
F P
0 g
s
.41462 .25858 m .40158 .2496 L .41564 .25911 L 0 .425 .849 r
F
.40158 .2496 m .43474 .26905 L p .41564 .25911 L F P
0 g
s
.43474 .26905 m .40158 .2496 L p .42242 .26626 L 0 .266 .764 r
F P
0 g
s
.45534 .29258 m .43894 .27385 L p .42242 .26626 L 0 .266 .764 r
F P
0 g
s
.43894 .27385 m .43474 .26905 L p .42242 .26626 L 0 .266 .764 r
F P
0 g
s
.40158 .2496 m .41725 .26019 L .43631 .27734 L 0 .266 .764 r
F
.40158 .2496 m .43631 .27734 L .43592 .27705 L F
.41725 .26019 m .422 .26341 L p .43659 .27759 L F P
0 g
s
.422 .26341 m .40158 .2496 L .36768 .2455 L p .159 .583 .934 r
F P
0 g
s
.38825 .24956 m .422 .26341 L p .40152 .25666 L .159 .583 .934 r
F P
0 g
s
.36768 .2455 m .38441 .2488 L p .40152 .25666 L .159 .583 .934 r
F P
0 g
s
.38441 .2488 m .38825 .24956 L p .40152 .25666 L .159 .583 .934 r
F P
0 g
s
.43592 .27705 m .43631 .27734 L .43659 .27759 L 0 .266 .764 r
F
.422 .26341 m .45534 .29258 L p .43659 .27759 L F P
0 g
s
.48051 .32176 m .48883 .33142 L p .47198 .31199 L 0 0 .482 r
F P
0 g
s
.46313 .29002 m .47994 .30639 L p .45374 .28096 L 0 .02 .519 r
F P
0 g
s
.68407 .32388 m .66253 .32359 L .63189 .33772 L p .505 .09 .187 r
F P
0 g
s
.61053 .33459 m .63189 .33772 L .66253 .32359 L p .488 .049 .131 r
F P
0 g
s
.30783 .38215 m .2868 .40711 L .25415 .40131 L p .763 .648 .735 r
F P
0 g
s
.25415 .40131 m .2751 .37893 L .30783 .38215 L p .763 .648 .735 r
F P
0 g
s
.34705 .25944 m .32644 .27863 L .29267 .28916 L p .833 .804 .824 r
F P
0 g
s
.29267 .28916 m .31355 .26862 L .34705 .25944 L p .833 .804 .824 r
F P
0 g
s
.32644 .27863 m .30551 .30216 L .27158 .3119 L p .84 .79 .803 r
F P
0 g
s
.27158 .3119 m .29267 .28916 L .32644 .27863 L p .84 .79 .803 r
F P
0 g
s
.29639 .35131 m .2751 .37893 L .24184 .37863 L p .793 .682 .742 r
F P
0 g
s
.24184 .37863 m .26308 .35389 L .29639 .35131 L p .793 .682 .742 r
F P
0 g
s
.63189 .33772 m .61053 .33459 L .5791 .338 L p .574 .143 .183 r
F P
0 g
s
.30551 .30216 m .28436 .32772 L .25043 .33499 L p .834 .773 .794 r
F P
0 g
s
.25043 .33499 m .27158 .3119 L .30551 .30216 L p .834 .773 .794 r
F P
0 g
s
.75864 .31977 m .73618 .31454 L .70591 .32494 L p .355 0 0 r
F P
0 g
s
.68407 .32388 m .70591 .32494 L .73618 .31454 L p .404 0 0 r
F P
0 g
s
.83161 .36256 m .85648 .38395 L .86539 .3969 L closepath p 0 .192 .715 r
F P
0 g
s
.2751 .37893 m .25415 .40131 L .22134 .39497 L p .767 .723 .812 r
F P
0 g
s
.22134 .39497 m .24184 .37863 L .2751 .37893 L p .767 .723 .812 r
F P
0 g
s
.28436 .32772 m .26308 .35389 L .22935 .35672 L p .819 .758 .795 r
F P
0 g
s
.22935 .35672 m .25043 .33499 L .28436 .32772 L p .819 .758 .795 r
F P
0 g
s
.70591 .32494 m .68407 .32388 L .65357 .34125 L p .496 .086 .192 r
F P
0 g
s
.63189 .33772 m .65357 .34125 L .68407 .32388 L p .505 .09 .187 r
F P
0 g
s
.26308 .35389 m .24184 .37863 L .20843 .37648 L p .791 .726 .792 r
F P
0 g
s
.20843 .37648 m .22935 .35672 L .26308 .35389 L p .791 .726 .792 r
F P
0 g
s
.5791 .338 m .60051 .34703 L .63189 .33772 L p .574 .143 .183 r
F P
0 g
s
.60051 .34703 m .5791 .338 L .54721 .33191 L p .643 .191 .163 r
F P
0 g
s
.24184 .37863 m .22134 .39497 L .18811 .39064 L p .749 .723 .829 r
F P
0 g
s
.65357 .34125 m .63189 .33772 L .60051 .34703 L p .577 .178 .25 r
F P
0 g
s
.18811 .39064 m .20843 .37648 L .24184 .37863 L p .749 .723 .829 r
F P
0 g
s
.48316 .29407 m .50366 .31308 L .53608 .33475 L p .674 .124 0 r
F P
0 g
s
.33415 .25215 m .31355 .26862 L .27902 .28363 L p .833 .936 .896 r
F P
0 g
s
.31355 .26862 m .29267 .28916 L .25803 .30305 L p .854 .912 .872 r
F P
0 g
s
.25803 .30305 m .27902 .28363 L .31355 .26862 L p .854 .912 .872 r
F P
0 g
s
.29267 .28916 m .27158 .3119 L .23698 .32299 L p .853 .882 .86 r
F P
0 g
s
.23698 .32299 m .25803 .30305 L .29267 .28916 L p .853 .882 .86 r
F P
0 g
s
.27902 .28363 m .29987 .26617 L .33415 .25215 L p .833 .936 .896 r
F P
0 g
s
.78159 .32676 m .75864 .31977 L .72806 .32632 L p .178 0 0 r
F P
0 g
s
.70591 .32494 m .72806 .32632 L .75864 .31977 L p .355 0 0 r
F P
0 g
s
.54721 .33191 m .56848 .34664 L .60051 .34703 L p .643 .191 .163 r
F P
0 g
s
.56848 .34664 m .54721 .33191 L .51515 .31627 L p .695 .199 .062 r
F P
0 g
s
.51515 .31627 m .53608 .33475 L .56848 .34664 L p .695 .199 .062 r
F P
0 g
s
.27158 .3119 m .25043 .33499 L .21601 .34206 L p .837 .851 .856 r
F P
0 g
s
.21601 .34206 m .23698 .32299 L .27158 .3119 L p .837 .851 .856 r
F P
0 g
s
.72806 .32632 m .70591 .32494 L .67553 .34402 L p .461 .038 .149 r
F P
0 g
s
.65357 .34125 m .67553 .34402 L .70591 .32494 L p .496 .086 .192 r
F P
0 g
s
.20843 .37648 m .18811 .39064 L .1548 .38483 L p .724 .751 .873 r
F P
0 g
s
.25043 .33499 m .22935 .35672 L .19524 .35926 L p .809 .818 .857 r
F P
0 g
s
.19524 .35926 m .21601 .34206 L .25043 .33499 L p .809 .818 .857 r
F P
0 g
s
.22935 .35672 m .20843 .37648 L .1748 .3737 L p .773 .789 .866 r
F P
0 g
s
.1748 .3737 m .19524 .35926 L .22935 .35672 L p .773 .789 .866 r
F P
0 g
s
.1548 .38483 m .1748 .3737 L .20843 .37648 L p .724 .751 .873 r
F P
0 g
s
.1748 .3737 m .1548 .38483 L .12128 .37896 L p .685 .782 .925 r
F P
0 g
s
.49192 .31018 m .47143 .28648 L .43938 .26145 L p .491 0 0 r
F P
0 g
s
.67553 .34402 m .65357 .34125 L .62232 .35646 L p .561 .177 .271 r
F P
0 g
s
.60051 .34703 m .62232 .35646 L .65357 .34125 L p .577 .178 .25 r
F P
0 g
s
.62232 .35646 m .60051 .34703 L .56848 .34664 L p .642 .235 .258 r
F P
0 g
s
.19524 .35926 m .1748 .3737 L .14091 .37059 L p .731 .807 .912 r
F P
0 g
s
.12128 .37896 m .14091 .37059 L .1748 .3737 L p .685 .782 .925 r
F P
0 g
s
.75051 .32765 m .72806 .32632 L .6977 .34503 L p .38 0 .027 r
F P
0 g
s
.67553 .34402 m .6977 .34503 L .72806 .32632 L p .461 .038 .149 r
F P
0 g
s
.52467 .33789 m .50366 .31308 L .47143 .28648 L p .734 .207 0 r
F P
0 g
s
.47143 .28648 m .49192 .31018 L .52467 .33789 L p .734 .207 0 r
F P
0 g
s
.14091 .37059 m .12128 .37896 L .0875 .37322 L p .672 .755 .914 r
F P
0 g
s
.81384 .34215 m .83827 .3575 L .84744 .37082 L closepath p 0 .345 .823 r
F P
0 g
s
.80655 .33867 m .78159 .32676 L p .79888 .33613 L .249 .512 .907 r
F P
0 g
s
.83827 .3575 m .81384 .34215 L .80655 .33867 L p .249 .512 .907 r
F P
0 g
s
.79888 .33613 m .83827 .3575 L .80655 .33867 L .249 .512 .907 r
F
.78159 .32676 m .80504 .33501 L .83827 .3575 L p F P
0 g
s
.80504 .33501 m .78159 .32676 L .75051 .32765 L p .223 .69 .943 r
F P
0 g
s
.77323 .32874 m .78138 .33034 L p .75203 .32778 L .223 .69 .943 r
F P
0 g
s
.78138 .33034 m .80504 .33501 L p .78888 .33283 L .223 .69 .943 r
F P
0 g
s
.75051 .32765 m .78138 .33034 L .78888 .33283 L .223 .69 .943 r
F
.80504 .33501 m .82897 .34399 L .83827 .3575 L closepath p .212 .5 .904 r
F P
0 g
s
.82897 .34399 m .80504 .33501 L .77323 .32874 L p .463 .657 .944 r
F P
0 g
s
.79624 .32961 m .82897 .34399 L p .77385 .32891 L .463 .657 .944 r
F P
0 g
s
.77323 .32874 m .79624 .32961 L p .77385 .32891 L .463 .657 .944 r
F P
0 g
s
.77323 .32874 m .74243 .33987 L p .79554 .32974 L .444 .868 .935 r
F P
0 g
s
.79624 .32961 m .77323 .32874 L p .79554 .32974 L .444 .868 .935 r
F P
0 g
s
.79624 .32961 m .81953 .33028 L .82897 .34399 L closepath p .472 .657 .942 r
F P
0 g
s
.76488 .33359 m .79624 .32961 L p .7474 .33893 L .444 .868 .935 r
F P
0 g
s
.74243 .33987 m .76488 .33359 L p .7474 .33893 L .444 .868 .935 r
F P
0 g
s
.79624 .32961 m .76488 .33359 L p .81893 .33032 L .668 .771 .927 r
F P
0 g
s
.81953 .33028 m .79624 .32961 L p .81893 .33032 L .668 .771 .927 r
F P
0 g
s
.78738 .32554 m .81953 .33028 L p .76773 .33342 L .668 .771 .927 r
F P
0 g
s
.76488 .33359 m .78738 .32554 L p .76773 .33342 L .668 .771 .927 r
F P
0 g
s
.76488 .33359 m .73425 .35468 L p .78252 .3282 L .666 .975 .864 r
F P
0 g
s
.78738 .32554 m .76488 .33359 L p .78252 .3282 L .666 .975 .864 r
F P
0 g
s
.78738 .32554 m .80996 .31637 L .81953 .33028 L closepath p .686 .76 .908 r
F P
0 g
s
.75642 .34002 m .78738 .32554 L p .74378 .34946 L .666 .975 .864 r
F P
0 g
s
.73425 .35468 m .75642 .34002 L p .74378 .34946 L .666 .975 .864 r
F P
0 g
s
.78738 .32554 m .75642 .34002 L p .80719 .3176 L .812 .83 .865 r
F P
0 g
s
.80996 .31637 m .78738 .32554 L p .80719 .3176 L .812 .83 .865 r
F P
0 g
s
.75051 .32765 m .77323 .32874 L p .75203 .32778 L .223 .69 .943 r
F P
0 g
s
.77323 .32874 m .75051 .32765 L .72003 .34373 L p .149 0 0 r
F P
0 g
s
.72003 .34373 m .74243 .33987 L .77323 .32874 L p .149 0 0 r
F P
0 g
s
.76488 .33359 m .74243 .33987 L .71188 .36471 L p .046 0 0 r
F P
0 g
s
.71188 .36471 m .73425 .35468 L .76488 .33359 L p .046 0 0 r
F P
0 g
s
.75642 .34002 m .7784 .32209 L .80996 .31637 L p .812 .83 .865 r
F P
0 g
s
.74926 .34702 m .72579 .36999 L p .74127 .35589 L .818 .997 .777 r
F P
0 g
s
.75642 .34002 m .73425 .35468 L .70344 .38672 L p 0 0 0 r
F P
0 g
s
.72579 .36999 m .75642 .34002 L p .7323 .36128 L 0 0 0 r
F P
0 g
s
.70344 .38672 m .72579 .36999 L p .7323 .36128 L 0 0 0 r
F P
0 g
s
.71321 .38477 m .69452 .40674 L p .70828 .39117 L 0 0 0 r
F P
0 g
s
.72579 .36999 m .70344 .38672 L .67166 .42003 L p .213 0 .077 r
F P
0 g
s
.75642 .34002 m .74926 .34702 L p .76914 .33052 L .818 .997 .777 r
F P
0 g
s
.74127 .35589 m .76914 .33052 L .74926 .34702 L .818 .997 .777 r
F
.7784 .32209 m .75642 .34002 L p .76914 .33052 L F P
0 g
s
.7477 .34654 m .7784 .32209 L p .74127 .35589 L .818 .997 .777 r
F P
0 g
s
.72579 .36999 m .7477 .34654 L p .74127 .35589 L .818 .997 .777 r
F P
0 g
s
.69452 .40674 m .71688 .38334 L .7477 .34654 L p 0 0 0 r
F P
0 g
s
.7477 .34654 m .72579 .36999 L p .71916 .37885 L 0 0 0 r
F P
0 g
s
.7477 .34654 m .72133 .37803 L p .75388 .33756 L .905 .981 .713 r
F P
0 g
s
.76921 .3185 m .7477 .34654 L p .75388 .33756 L .905 .981 .713 r
F P
0 g
s
.67166 .42003 m .69452 .40674 L .72579 .36999 L p .213 0 .077 r
F P
0 g
s
.69452 .40674 m .67166 .42003 L .66623 .42388 L p .387 0 .17 r
F P
0 g
s
.66623 .42388 m .63846 .44359 L p .67573 .41909 L .387 0 .17 r
F P
0 g
s
.67573 .41909 m .69452 .40674 L .66623 .42388 L .387 0 .17 r
F
.66191 .43885 m .68497 .42145 L .69514 .40931 L p .064 0 0 r
F P
0 g
s
.63846 .44359 m .66191 .43885 L .69452 .40674 L p .387 0 .17 r
F P
0 g
s
.69452 .40674 m .66191 .43885 L p .70215 .39822 L .064 0 0 r
F P
0 g
s
.70215 .39822 m .70512 .39522 L .70311 .39741 L .064 0 0 r
F
.70215 .39822 m .70311 .39741 L .69452 .40674 L F
.73425 .35468 m .71188 .36471 L .68077 .39566 L p .301 0 .114 r
F P
0 g
s
.68077 .39566 m .70344 .38672 L .73425 .35468 L p .301 0 .114 r
F P
0 g
s
.70344 .38672 m .68077 .39566 L .6485 .42278 L p .434 .058 .224 r
F P
0 g
s
.6485 .42278 m .67166 .42003 L .70344 .38672 L p .434 .058 .224 r
F P
0 g
s
.69722 .39396 m .72904 .35291 L p .68662 .41138 L .798 .941 .587 r
F P
0 g
s
.66191 .43885 m .69514 .40931 L .68721 .4133 L .064 0 0 r
F
.71688 .38334 m .70362 .39722 L p .70512 .39522 L F P
0 g
s
.70362 .39722 m .69452 .40674 L p .70512 .39522 L .064 0 0 r
F P
0 g
s
.69514 .40931 m .71688 .38334 L p .68721 .4133 L .064 0 0 r
F P
0 g
s
.6149 .43615 m .63846 .44359 L .67166 .42003 L p .542 .154 .255 r
F P
0 g
s
.63846 .44359 m .6149 .43615 L .58031 .42986 L p .645 .224 .23 r
F P
0 g
s
.58031 .42986 m .60392 .44841 L .63846 .44359 L p .645 .224 .23 r
F P
0 g
s
.66191 .43885 m .65317 .44062 L p .65471 .44004 L .528 .102 .176 r
F P
0 g
s
.63846 .44359 m .62497 .44547 L p .65471 .44004 L .528 .102 .176 r
F P
0 g
s
.63636 .44306 m .65471 .44004 L .62497 .44547 L .528 .102 .176 r
F
.65317 .44062 m .63846 .44359 L p .65471 .44004 L F P
0 g
s
.62497 .44547 m .60392 .44841 L p .63636 .44306 L .528 .102 .176 r
F P
0 g
s
.60392 .44841 m .62773 .45538 L .66191 .43885 L p .528 .102 .176 r
F P
0 g
s
.68497 .42145 m .66191 .43885 L .65181 .44374 L p .29 0 .037 r
F P
0 g
s
.65181 .44374 m .62773 .45538 L p .66257 .43473 L .29 0 .037 r
F P
0 g
s
.66257 .43473 m .68497 .42145 L .65181 .44374 L .29 0 .037 r
F
.66608 .43676 m .68497 .42145 L p .65528 .43905 L F P
0 g
s
.62773 .45538 m .65142 .44865 L .66608 .43676 L p .29 0 .037 r
F P
0 g
s
.62773 .45538 m .66608 .43676 L .65528 .43905 L .29 0 .037 r
F
.70739 .39211 m .68497 .42145 L .65142 .44865 L p 0 0 0 r
F P
0 g
s
.67468 .42785 m .68744 .41391 L p .66309 .43686 L 0 0 0 r
F P
0 g
s
.68744 .41391 m .70739 .39211 L p .67795 .42185 L 0 0 0 r
F P
0 g
s
.66309 .43686 m .68744 .41391 L .67795 .42185 L 0 0 0 r
F
.65142 .44865 m .6657 .43587 L p .66309 .43686 L F P
0 g
s
.6657 .43587 m .67468 .42785 L p .66309 .43686 L 0 0 0 r
F P
0 g
s
.67468 .42785 m .68435 .41331 L p .68662 .41138 L .798 .941 .587 r
F P
0 g
s
.68435 .41331 m .69722 .39396 L p .68662 .41138 L .798 .941 .587 r
F P
0 g
s
.70739 .39211 m .71004 .38867 L p .69126 .41323 L .568 .814 .435 r
F P
0 g
s
.71004 .38867 m .73862 .35143 L p .70767 .39182 L .568 .814 .435 r
F P
0 g
s
.69126 .41323 m .71004 .38867 L .70767 .39182 L .568 .814 .435 r
F
.68497 .42145 m .68951 .41551 L p .69126 .41323 L F P
0 g
s
.68951 .41551 m .70739 .39211 L p .69126 .41323 L .568 .814 .435 r
F P
0 g
s
.72579 .36999 m .71321 .38477 L p .71916 .37885 L 0 0 0 r
F P
0 g
s
.70828 .39117 m .71916 .37885 L .71321 .38477 L 0 0 0 r
F
.72133 .37803 m .71688 .38334 L p .71977 .37976 L .905 .981 .713 r
F P
0 g
s
.71977 .37976 m .76921 .3185 L .72133 .37803 L .905 .981 .713 r
F
.21601 .34206 m .19524 .35926 L .16096 .35965 L p .765 .856 .918 r
F P
0 g
s
.14091 .37059 m .16096 .35965 L .19524 .35926 L p .731 .807 .912 r
F P
0 g
s
.29987 .26617 m .27902 .28363 L .24364 .30055 L p .735 .991 .869 r
F P
0 g
s
.27902 .28363 m .25803 .30305 L .22274 .31677 L p .787 .985 .898 r
F P
0 g
s
.22274 .31677 m .24364 .30055 L .27902 .28363 L p .787 .985 .898 r
F P
0 g
s
.25803 .30305 m .23698 .32299 L .20194 .33249 L p .803 .954 .915 r
F P
0 g
s
.20194 .33249 m .22274 .31677 L .25803 .30305 L p .803 .954 .915 r
F P
0 g
s
.23698 .32299 m .21601 .34206 L .18133 .34687 L p .79 .91 .922 r
F P
0 g
s
.16096 .35965 m .18133 .34687 L .21601 .34206 L p .765 .856 .918 r
F P
0 g
s
.18133 .34687 m .20194 .33249 L .23698 .32299 L p .79 .91 .922 r
F P
0 g
s
.24364 .30055 m .26453 .28478 L .29987 .26617 L p .735 .991 .869 r
F P
0 g
s
.55757 .35683 m .53608 .33475 L .50366 .31308 L p .754 .276 .107 r
F P
0 g
s
.50366 .31308 m .52467 .33789 L .55757 .35683 L p .754 .276 .107 r
F P
0 g
s
.0875 .37322 m .107 .36539 L .14091 .37059 L p .672 .755 .914 r
F P
0 g
s
.107 .36539 m .0875 .37322 L .05358 .36696 L p .658 .756 .922 r
F P
0 g
s
.56848 .34664 m .59025 .363 L .62232 .35646 L p .642 .235 .258 r
F P
0 g
s
.59025 .363 m .56848 .34664 L .53608 .33475 L p .704 .271 .217 r
F P
0 g
s
.16096 .35965 m .14091 .37059 L .107 .36539 L p .686 .788 .928 r
F P
0 g
s
.6977 .34503 m .67553 .34402 L .64448 .36443 L p .528 .147 .263 r
F P
0 g
s
.62232 .35646 m .64448 .36443 L .67553 .34402 L p .561 .177 .271 r
F P
0 g
s
.53608 .33475 m .55757 .35683 L .59025 .363 L p .704 .271 .217 r
F P
0 g
s
.18133 .34687 m .16096 .35965 L .12673 .35686 L p .693 .849 .958 r
F P
0 g
s
.107 .36539 m .12673 .35686 L .16096 .35965 L p .686 .788 .928 r
F P
0 g
s
.6977 .34503 m .72003 .34373 L .75051 .32765 L p .38 0 .027 r
F P
0 g
s
.05358 .36696 m .07292 .35974 L .107 .36539 L p .658 .756 .922 r
F P
0 g
s
.12673 .35686 m .107 .36539 L .07292 .35974 L p .658 .778 .937 r
F P
0 g
s
.64448 .36443 m .62232 .35646 L .59025 .363 L p .622 .238 .294 r
F P
0 g
s
.20194 .33249 m .18133 .34687 L .14665 .34784 L p .703 .906 .967 r
F P
0 g
s
.12673 .35686 m .14665 .34784 L .18133 .34687 L p .693 .849 .958 r
F P
0 g
s
.51297 .33949 m .49192 .31018 L .45946 .28017 L p .741 .224 0 r
F P
0 g
s
.45946 .28017 m .47994 .30639 L .51297 .33949 L p .741 .224 0 r
F P
0 g
s
.22274 .31677 m .20194 .33249 L .16682 .33771 L p .69 .953 .953 r
F P
0 g
s
.14665 .34784 m .16682 .33771 L .20194 .33249 L p .703 .906 .967 r
F P
0 g
s
.07292 .35974 m .09242 .35246 L .12673 .35686 L p .658 .778 .937 r
F P
0 g
s
.14665 .34784 m .12673 .35686 L .09242 .35246 L p .656 .807 .956 r
F P
0 g
s
.72003 .34373 m .6977 .34503 L .66687 .36923 L p .469 .079 .217 r
F P
0 g
s
.64448 .36443 m .66687 .36923 L .6977 .34503 L p .528 .147 .263 r
F P
0 g
s
.24364 .30055 m .22274 .31677 L .18722 .32654 L p .621 .959 .887 r
F P
0 g
s
.16682 .33771 m .18722 .32654 L .22274 .31677 L p .69 .953 .953 r
F P
0 g
s
.26453 .28478 m .24364 .30055 L .20779 .31472 L p .501 .899 .766 r
F P
0 g
s
.18722 .32654 m .20779 .31472 L .24364 .30055 L p .621 .959 .887 r
F P
0 g
s
.28536 .27047 m .26453 .28478 L .22848 .30265 L p .362 .797 .627 r
F P
0 g
s
.20779 .31472 m .22848 .30265 L .26453 .28478 L p .501 .899 .766 r
F P
0 g
s
.54631 .36596 m .52467 .33789 L .49192 .31018 L p .789 .311 .093 r
F P
0 g
s
.49192 .31018 m .51297 .33949 L .54631 .36596 L p .789 .311 .093 r
F P
0 g
s
.16682 .33771 m .14665 .34784 L .11206 .34513 L p .643 .854 .98 r
F P
0 g
s
.09242 .35246 m .11206 .34513 L .14665 .34784 L p .656 .807 .956 r
F P
0 g
s
.59025 .363 m .61249 .37838 L .64448 .36443 L p .622 .238 .294 r
F P
0 g
s
.61249 .37838 m .59025 .363 L .55757 .35683 L p .685 .284 .281 r
F P
0 g
s
.30608 .25866 m .28536 .27047 L .24925 .29081 L p 0 0 0 r
F P
0 g
s
.24925 .29081 m .22848 .30265 L .19222 .31521 L p 0 0 0 r
F P
0 g
s
.19222 .31521 m .21266 .30758 L .24925 .29081 L p 0 0 0 r
F P
0 g
s
.24925 .29081 m .21266 .30758 L p .26031 .28446 L .003 0 0 r
F P
0 g
s
.24925 .29081 m .28536 .27047 L p .23828 .2971 L .362 .797 .627 r
F P
0 g
s
.24925 .29081 m .27005 .27973 L .30608 .25866 L p 0 0 0 r
F P
0 g
s
.27005 .27973 m .24925 .29081 L p .26031 .28446 L .003 0 0 r
F P
0 g
s
.22848 .30265 m .24925 .29081 L p .23828 .2971 L .362 .797 .627 r
F P
0 g
s
.66687 .36923 m .64448 .36443 L .61249 .37838 L p .59 .217 .303 r
F P
0 g
s
.18722 .32654 m .16682 .33771 L .13187 .33773 L p .597 .902 .985 r
F P
0 g
s
.11206 .34513 m .13187 .33773 L .16682 .33771 L p .643 .854 .98 r
F P
0 g
s
.74243 .33987 m .72003 .34373 L .68939 .36953 L p .354 0 .101 r
F P
0 g
s
.66687 .36923 m .68939 .36953 L .72003 .34373 L p .469 .079 .217 r
F P
0 g
s
.57964 .37974 m .55757 .35683 L .52467 .33789 L p .747 .314 .222 r
F P
0 g
s
.52467 .33789 m .54631 .36596 L .57964 .37974 L p .747 .314 .222 r
F P
0 g
s
.32668 .25018 m .30608 .25866 L .27005 .27973 L p 0 0 0 r
F P
0 g
s
.55757 .35683 m .57964 .37974 L .61249 .37838 L p .685 .284 .281 r
F P
0 g
s
.50101 .33778 m .47994 .30639 L .44723 .27452 L p .686 .178 0 r
F P
0 g
s
.44723 .27452 m .46773 .30071 L .50101 .33778 L p .686 .178 0 r
F P
0 g
s
.20779 .31472 m .18722 .32654 L .15182 .33028 L p .479 .894 .908 r
F P
0 g
s
.13187 .33773 m .15182 .33028 L .18722 .32654 L p .597 .902 .985 r
F P
0 g
s
.34719 .24566 m .32668 .25018 L .29088 .26996 L p 0 0 0 r
F P
0 g
s
.27005 .27973 m .29088 .26996 L .32668 .25018 L p 0 0 0 r
F P
0 g
s
.68939 .36953 m .71188 .36471 L .74243 .33987 L p .354 0 .101 r
F P
0 g
s
.22848 .30265 m .20779 .31472 L .17194 .32278 L p .292 .78 .715 r
F P
0 g
s
.15182 .33028 m .17194 .32278 L .20779 .31472 L p .479 .894 .908 r
F P
0 g
s
.68939 .36953 m .66687 .36923 L .6351 .39035 L p .541 .171 .288 r
F P
0 g
s
.61249 .37838 m .6351 .39035 L .66687 .36923 L p .59 .217 .303 r
F P
0 g
s
.53472 .3716 m .51297 .33949 L .47994 .30639 L p .803 .313 .016 r
F P
0 g
s
.47994 .30639 m .50101 .33778 L .53472 .3716 L p .803 .313 .016 r
F P
0 g
s
.17194 .32278 m .19222 .31521 L .22848 .30265 L p .292 .78 .715 r
F P
0 g
s
.6351 .39035 m .61249 .37838 L .57964 .37974 L p .654 .27 .306 r
F P
0 g
s
.36768 .2455 m .34719 .24566 L .31171 .26192 L p 0 0 0 r
F P
0 g
s
.29088 .26996 m .31171 .26192 L .34719 .24566 L p 0 0 0 r
F P
0 g
s
.56863 .39409 m .54631 .36596 L .51297 .33949 L p .783 .337 .189 r
F P
0 g
s
.51297 .33949 m .53472 .3716 L .56863 .39409 L p .783 .337 .189 r
F P
0 g
s
.29088 .26996 m .27005 .27973 L .23326 .29989 L p .059 0 0 r
F P
0 g
s
.21266 .30758 m .23326 .29989 L .27005 .27973 L p .003 0 0 r
F P
0 g
s
.71188 .36471 m .68939 .36953 L .65792 .39667 L p .459 .083 .237 r
F P
0 g
s
.6351 .39035 m .65792 .39667 L .68939 .36953 L p .541 .171 .288 r
F P
0 g
s
.57964 .37974 m .60226 .40032 L .6351 .39035 L p .654 .27 .306 r
F P
0 g
s
.60226 .40032 m .57964 .37974 L .54631 .36596 L p .721 .313 .273 r
F P
0 g
s
.54631 .36596 m .56863 .39409 L .60226 .40032 L p .721 .313 .273 r
F P
0 g
s
.38825 .24956 m .36768 .2455 L .33257 .25595 L p .281 .779 .874 r
F P
0 g
s
.31171 .26192 m .33257 .25595 L .36768 .2455 L p 0 0 0 r
F P
0 g
s
.31171 .26192 m .29088 .26996 L .25403 .29213 L p .065 0 0 r
F P
0 g
s
.23326 .29989 m .25403 .29213 L .29088 .26996 L p .059 0 0 r
F P
0 g
s
.7784 .32209 m .80024 .30226 L .80996 .31637 L closepath p .819 .802 .835 r
F P
0 g
s
.5228 .37145 m .50101 .33778 L .46773 .30071 L p .76 .26 0 r
F P
0 g
s
.46773 .30071 m .48883 .33142 L .5228 .37145 L p .76 .26 0 r
F P
0 g
s
.65792 .39667 m .68077 .39566 L .71188 .36471 L p .459 .083 .237 r
F P
0 g
s
.65792 .39667 m .6351 .39035 L .60226 .40032 L p .61 .235 .308 r
F P
0 g
s
.33257 .25595 m .31171 .26192 L .27496 .28432 L p .014 0 0 r
F P
0 g
s
.25403 .29213 m .27496 .28432 L .31171 .26192 L p .065 0 0 r
F P
0 g
s
.45534 .29258 m .422 .26341 L p .4455 .28771 L 0 .178 .712 r
F P
0 g
s
.48883 .33142 m .45534 .29258 L p .48885 .33575 L 0 0 .439 r
F P
0 g
s
.45924 .30192 m .45158 .29252 L p .4455 .28771 L 0 .178 .712 r
F P
0 g
s
.51063 .36381 m .50138 .35007 L p .48885 .33575 L 0 0 .439 r
F P
0 g
s
.50138 .35007 m .48883 .33142 L p .48885 .33575 L 0 0 .439 r
F P
0 g
s
.48588 .32424 m .46403 .30268 L .46076 .29936 L p .261 .356 .772 r
F P
0 g
s
.45534 .29258 m .46356 .30315 L p .46389 .30359 L 0 0 .439 r
F P
0 g
s
.45534 .29258 m .49911 .34894 L .50377 .35497 L 0 0 .439 r
F
.46122 .30014 m .45534 .29258 L p .4455 .28771 L 0 .178 .712 r
F P
0 g
s
.43007 .26822 m .45153 .28075 L .48588 .32424 L p .261 .356 .772 r
F P
0 g
s
.46076 .29936 m .43007 .26822 L p .45291 .29116 L .261 .356 .772 r
F P
0 g
s
.47648 .31975 m .49911 .34894 L p .46389 .30359 L 0 0 .439 r
F P
0 g
s
.44277 .2817 m .47648 .31975 L p .45924 .30192 L 0 .178 .712 r
F P
0 g
s
.422 .26341 m .43741 .27698 L p .45924 .30192 L 0 .178 .712 r
F P
0 g
s
.43741 .27698 m .44277 .2817 L p .45924 .30192 L 0 .178 .712 r
F P
0 g
s
.422 .26341 m .39305 .25152 L p .409 .26121 L .17 .468 .89 r
F P
0 g
s
.44277 .2817 m .42423 .26537 L p .409 .26121 L .17 .468 .89 r
F P
0 g
s
.42423 .26537 m .422 .26341 L p .409 .26121 L .17 .468 .89 r
F P
0 g
s
.39305 .25152 m .38825 .24956 L p .40052 .25679 L .17 .468 .89 r
F P
0 g
s
.40052 .25679 m .44277 .2817 L .39305 .25152 L .17 .468 .89 r
F
.38825 .24956 m .40544 .25604 L p .42361 .2704 L F P
0 g
s
.40544 .25604 m .40901 .25739 L p .42361 .2704 L .17 .468 .89 r
F P
0 g
s
.33257 .25595 m .35349 .25223 L .38825 .24956 L p .281 .779 .874 r
F P
0 g
s
.40901 .25739 m .38825 .24956 L .35349 .25223 L p .404 .758 .994 r
F P
0 g
s
.37453 .25067 m .40901 .25739 L p .38786 .25542 L .404 .758 .994 r
F P
0 g
s
.35349 .25223 m .37134 .25091 L p .38786 .25542 L .404 .758 .994 r
F P
0 g
s
.37134 .25091 m .37453 .25067 L p .38786 .25542 L .404 .758 .994 r
F P
0 g
s
.40901 .25739 m .44277 .2817 L p .42906 .27362 L .17 .468 .89 r
F P
0 g
s
.42361 .2704 m .40901 .25739 L .42906 .27362 L .17 .468 .89 r
F
.46356 .30315 m .47648 .31975 L p .46389 .30359 L 0 0 .439 r
F P
0 g
s
.47648 .31975 m .46122 .30014 L p .45416 .29456 L 0 .178 .712 r
F P
0 g
s
.47648 .31975 m .44277 .2817 L p .46967 .31384 L 0 .162 .701 r
F P
0 g
s
.49911 .34894 m .51063 .36381 L p .50377 .35497 L 0 0 .439 r
F P
0 g
s
.51063 .36381 m .47648 .31975 L p .53113 .39176 L 0 0 .461 r
F P
0 g
s
.53319 .39447 m .53249 .39353 L p .53113 .39176 L 0 0 .461 r
F P
0 g
s
.53249 .39353 m .51063 .36381 L p .53113 .39176 L 0 0 .461 r
F P
0 g
s
.47648 .31975 m .4983 .34804 L .53319 .39447 L p 0 0 .461 r
F P
0 g
s
.4983 .34804 m .48452 .33017 L p .46967 .31384 L 0 .162 .701 r
F P
0 g
s
.48452 .33017 m .47648 .31975 L p .46967 .31384 L 0 .162 .701 r
F P
0 g
s
.46403 .30268 m .4983 .34804 L p .48688 .3344 L 0 .162 .701 r
F P
0 g
s
.44277 .2817 m .45726 .29599 L p .48688 .3344 L 0 .162 .701 r
F P
0 g
s
.45726 .29599 m .46403 .30268 L p .48688 .3344 L 0 .162 .701 r
F P
0 g
s
.45976 .29847 m .44277 .2817 L .43834 .27851 L p .206 .391 .825 r
F P
0 g
s
.43834 .27851 m .40901 .25739 L p .43149 .27559 L .206 .391 .825 r
F P
0 g
s
.46403 .30268 m .45976 .29847 L p .40901 .25739 L .206 .391 .825 r
F P
0 g
s
.43149 .27559 m .45976 .29847 L .44346 .28328 L .206 .391 .825 r
F
.43149 .27559 m .44346 .28328 L .43834 .27851 L F
.40901 .25739 m .42657 .26643 L p .44438 .28602 L F P
0 g
s
.42657 .26643 m .43007 .26822 L p .44438 .28602 L .206 .391 .825 r
F P
0 g
s
.40901 .25739 m .46034 .29893 L .45953 .29836 L .206 .391 .825 r
F
.40901 .25739 m .46076 .29936 L .46209 .30108 L F
.43007 .26822 m .40901 .25739 L .37453 .25067 L p .457 .629 .927 r
F P
0 g
s
.39575 .251 m .43007 .26822 L p .41036 .262 L .457 .629 .927 r
F P
0 g
s
.37453 .25067 m .3932 .25096 L p .41036 .262 L .457 .629 .927 r
F P
0 g
s
.3932 .25096 m .39575 .251 L p .41036 .262 L .457 .629 .927 r
F P
0 g
s
.43007 .26822 m .46034 .29893 L p .44438 .28602 L .206 .391 .825 r
F P
0 g
s
.46034 .29893 m .46076 .29936 L p .45953 .29836 L .206 .391 .825 r
F P
0 g
s
.43007 .26822 m .39575 .251 L p .41451 .26101 L .471 .522 .829 r
F P
0 g
s
.45153 .28075 m .43117 .26887 L p .41451 .26101 L .471 .522 .829 r
F P
0 g
s
.43117 .26887 m .43007 .26822 L p .41451 .26101 L .471 .522 .829 r
F P
0 g
s
.39575 .251 m .41522 .25263 L p .43315 .27095 L .471 .522 .829 r
F P
0 g
s
.41522 .25263 m .41722 .2528 L p .43315 .27095 L .471 .522 .829 r
F P
0 g
s
.37453 .25067 m .35349 .25223 L .31734 .2685 L p .402 .857 .835 r
F P
0 g
s
.31734 .2685 m .3388 .26049 L .37453 .25067 L p .402 .857 .835 r
F P
0 g
s
.39575 .251 m .37453 .25067 L .3388 .26049 L p .626 .881 .988 r
F P
0 g
s
.3388 .26049 m .36043 .25242 L .39575 .251 L p .626 .881 .988 r
F P
0 g
s
.41722 .2528 m .39575 .251 L .36043 .25242 L p .656 .724 .899 r
F P
0 g
s
.38223 .24428 m .41722 .2528 L p .39682 .25266 L .656 .724 .899 r
F P
0 g
s
.36043 .25242 m .38046 .24494 L p .39682 .25266 L .656 .724 .899 r
F P
0 g
s
.38046 .24494 m .38223 .24428 L p .39682 .25266 L .656 .724 .899 r
F P
0 g
s
.41722 .2528 m .45153 .28075 L p .43315 .27095 L .471 .522 .829 r
F P
0 g
s
.45291 .29116 m .45981 .29807 L .4602 .2986 L .261 .356 .772 r
F
.45291 .29116 m .4602 .2986 L .46076 .29936 L F
.45981 .29807 m .48588 .32424 L .46076 .29936 L F
.46076 .29936 m .46403 .30268 L p .46209 .30108 L .206 .391 .825 r
F P
0 g
s
.80024 .30226 m .7784 .32209 L .7477 .34654 L p .893 .848 .792 r
F P
0 g
s
.76921 .3185 m .79038 .28793 L .80024 .30226 L closepath p .89 .81 .764 r
F P
0 g
s
.7477 .34654 m .76921 .3185 L .80024 .30226 L p .893 .848 .792 r
F P
0 g
s
.55718 .40303 m .53472 .3716 L .50101 .33778 L p .808 .337 .099 r
F P
0 g
s
.50101 .33778 m .5228 .37145 L .55718 .40303 L p .808 .337 .099 r
F P
0 g
s
.35349 .25223 m .33257 .25595 L .29607 .27644 L p 0 0 0 r
F P
0 g
s
.27496 .28432 m .29607 .27644 L .33257 .25595 L p .014 0 0 r
F P
0 g
s
.68077 .39566 m .65792 .39667 L .62528 .41557 L p .545 .173 .286 r
F P
0 g
s
.60226 .40032 m .62528 .41557 L .65792 .39667 L p .61 .235 .308 r
F P
0 g
s
.62528 .41557 m .60226 .40032 L .56863 .39409 L p .682 .287 .291 r
F P
0 g
s
.59154 .41862 m .56863 .39409 L .53472 .3716 L p .756 .328 .233 r
F P
0 g
s
.53472 .3716 m .55718 .40303 L .59154 .41862 L p .756 .328 .233 r
F P
0 g
s
.29607 .27644 m .31734 .2685 L .35349 .25223 L p 0 0 0 r
F P
0 g
s
.56863 .39409 m .59154 .41862 L .62528 .41557 L p .682 .287 .291 r
F P
0 g
s
.75975 .31387 m .78037 .27339 L .79038 .28793 L closepath p .926 .807 .708 r
F P
0 g
s
.79038 .28793 m .76921 .3185 L .73862 .35143 L p .936 .847 .73 r
F P
0 g
s
.73862 .35143 m .75975 .31387 L .79038 .28793 L p .936 .847 .73 r
F P
0 g
s
.62528 .41557 m .6485 .42278 L .68077 .39566 L p .545 .173 .286 r
F P
0 g
s
.54535 .40382 m .5228 .37145 L .48883 .33142 L p .78 .281 0 r
F P
0 g
s
.48883 .33142 m .51063 .36381 L .54535 .40382 L p .78 .281 0 r
F P
0 g
s
.71688 .38334 m .73862 .35143 L .76921 .3185 L p .905 .981 .713 r
F P
0 g
s
.74995 .30732 m .77021 .25863 L .78037 .27339 L closepath p .945 .801 .67 r
F P
0 g
s
.78037 .27339 m .75975 .31387 L .72904 .35291 L p .957 .84 .687 r
F P
0 g
s
.72904 .35291 m .74995 .30732 L .78037 .27339 L p .957 .84 .687 r
F P
0 g
s
.6485 .42278 m .62528 .41557 L .59154 .41862 L p .628 .238 .287 r
F P
0 g
s
.58031 .42986 m .55718 .40303 L .5228 .37145 L p .788 .322 .133 r
F P
0 g
s
.5228 .37145 m .54535 .40382 L .58031 .42986 L p .788 .322 .133 r
F P
0 g
s
.59154 .41862 m .6149 .43615 L .6485 .42278 L p .628 .238 .287 r
F P
0 g
s
.6149 .43615 m .59154 .41862 L .55718 .40303 L p .713 .291 .244 r
F P
0 g
s
.75975 .31387 m .73862 .35143 L .70739 .39211 L p .952 .953 .679 r
F P
0 g
s
.70739 .39211 m .72904 .35291 L .75975 .31387 L p .952 .953 .679 r
F P
0 g
s
.55718 .40303 m .58031 .42986 L .6149 .43615 L p .713 .291 .244 r
F P
0 g
s
.73976 .29809 m .75989 .24365 L .77021 .25863 L closepath p .954 .796 .648 r
F P
0 g
s
.77021 .25863 m .74995 .30732 L .71891 .3494 L p .967 .834 .66 r
F P
0 g
s
.71891 .3494 m .73976 .29809 L .77021 .25863 L p .967 .834 .66 r
F P
0 g
s
.67166 .42003 m .6485 .42278 L .6149 .43615 L p .542 .154 .255 r
F P
0 g
s
.52082 .37437 m .4983 .34804 L .46403 .30268 L p 0 .192 .712 r
F P
0 g
s
.46403 .30268 m .48588 .32424 L .52082 .37437 L p 0 .192 .712 r
F P
0 g
s
.47346 .29346 m .45153 .28075 L .41722 .2528 L p .48 .459 .757 r
F P
0 g
s
.41722 .2528 m .43898 .25534 L .47346 .29346 L p .48 .459 .757 r
F P
0 g
s
.43898 .25534 m .41722 .2528 L .38223 .24428 L p .632 .598 .797 r
F P
0 g
s
.51063 .36381 m .53319 .39447 L .56858 .43091 L p .764 .254 0 r
F P
0 g
s
.56858 .43091 m .54535 .40382 L .52936 .38539 L p .764 .254 0 r
F P
0 g
s
.5371 .39446 m .56858 .43091 L .52936 .38539 L .764 .254 0 r
F
.54535 .40382 m .56858 .43091 L .60392 .44841 L p .742 .271 .127 r
F P
0 g
s
.60392 .44841 m .58031 .42986 L .54535 .40382 L p .742 .271 .127 r
F P
0 g
s
.62773 .45538 m .60392 .44841 L .59167 .44234 L p .656 .168 .081 r
F P
0 g
s
.59167 .44234 m .56858 .43091 L p .58328 .43699 L .656 .168 .081 r
F P
0 g
s
.58328 .43699 m .62773 .45538 L .59167 .44234 L .656 .168 .081 r
F
.56858 .43091 m .59232 .44901 L .62773 .45538 L p F P
0 g
s
.59232 .44901 m .56858 .43091 L .5519 .41374 L p .701 .163 0 r
F P
0 g
s
.5519 .41374 m .54189 .40343 L p .55829 .41825 L .701 .163 0 r
F P
0 g
s
.55829 .41825 m .59232 .44901 L .5519 .41374 L .701 .163 0 r
F
.53997 .40073 m .59232 .44901 L .54189 .40343 L F
.56358 .42547 m .59232 .44901 L p .57037 .42876 L F P
0 g
s
.55167 .41152 m .56165 .4232 L .57037 .42876 L .701 .163 0 r
F
.56165 .4232 m .56358 .42547 L .57037 .42876 L F
.54189 .40343 m .53319 .39447 L p .53997 .40073 L F P
0 g
s
.53319 .39447 m .55643 .41961 L .56358 .42547 L p .701 .163 0 r
F P
0 g
s
.53319 .39447 m .56358 .42547 L .55167 .41152 L .701 .163 0 r
F
.65142 .44865 m .62773 .45538 L .59232 .44901 L p .469 0 0 r
F P
0 g
s
.59232 .44901 m .6163 .45485 L .65142 .44865 L p .469 0 0 r
F P
0 g
s
.6163 .45485 m .59232 .44901 L .57518 .43496 L p .539 0 0 r
F P
0 g
s
.57518 .43496 m .55643 .41961 L p .56887 .42693 L .539 0 0 r
F P
0 g
s
.56887 .42693 m .58575 .43687 L .57518 .43496 L .539 0 0 r
F
.58575 .43687 m .6163 .45485 L .57551 .43513 L F
.58575 .43687 m .57551 .43513 L .57518 .43496 L F
.55643 .41961 m .5802 .43574 L .59153 .44174 L p F P
0 g
s
.59153 .44174 m .6163 .45485 L p .57907 .43293 L .539 0 0 r
F P
0 g
s
.55643 .41961 m .59153 .44174 L .57907 .43293 L .539 0 0 r
F
.5802 .43574 m .60423 .43985 L .61811 .44237 L p 0 .483 .716 r
F P
0 g
s
.67468 .42785 m .65142 .44865 L .63765 .45108 L p .018 0 0 r
F P
0 g
s
.63765 .45108 m .6163 .45485 L p .64905 .4397 L .018 0 0 r
F P
0 g
s
.64905 .4397 m .67468 .42785 L .63765 .45108 L .018 0 0 r
F
.6163 .45485 m .64017 .44637 L .67468 .42785 L p F P
0 g
s
.64017 .44637 m .6636 .42333 L .67848 .41034 L p .641 .924 .647 r
F P
0 g
s
.67848 .41034 m .69722 .39396 L p .66789 .4209 L .641 .924 .647 r
F P
0 g
s
.64017 .44637 m .67848 .41034 L .66789 .4209 L .641 .924 .647 r
F
.61811 .44237 m .64017 .44637 L p .6057 .44026 L 0 .483 .716 r
F P
0 g
s
.5802 .43574 m .61811 .44237 L .6057 .44026 L 0 .483 .716 r
F
.52082 .37437 m .54399 .39542 L .54502 .39656 L p 0 .153 .69 r
F P
0 g
s
.54502 .39656 m .5802 .43574 L p .55679 .41155 L 0 .153 .69 r
F P
0 g
s
.52082 .37437 m .54502 .39656 L .55679 .41155 L 0 .153 .69 r
F
.4983 .34804 m .52082 .37437 L .52534 .38012 L p 0 0 .545 r
F P
0 g
s
.52936 .38539 m .51063 .36381 L p .5371 .39446 L .764 .254 0 r
F P
0 g
s
.52534 .38012 m .55643 .41961 L p .53217 .38974 L 0 0 .545 r
F P
0 g
s
.4983 .34804 m .52534 .38012 L .53217 .38974 L 0 0 .545 r
F
.73862 .35143 m .71688 .38334 L .68497 .42145 L p .568 .814 .435 r
F P
0 g
s
.38223 .24428 m .40422 .23607 L .43898 .25534 L p .632 .598 .797 r
F P
0 g
s
.72918 .28553 m .74942 .22843 L .75989 .24365 L closepath p .957 .794 .638 r
F P
0 g
s
.75989 .24365 m .73976 .29809 L .70818 .3396 L p .97 .831 .65 r
F P
0 g
s
.70818 .3396 m .72918 .28553 L .75989 .24365 L p .97 .831 .65 r
F P
0 g
s
.50835 .3439 m .48588 .32424 L .45153 .28075 L p .319 .349 .736 r
F P
0 g
s
.45153 .28075 m .47346 .29346 L .50835 .3439 L p .319 .349 .736 r
F P
0 g
s
.74995 .30732 m .72904 .35291 L .69722 .39396 L p .974 .923 .668 r
F P
0 g
s
.69722 .39396 m .71891 .3494 L .74995 .30732 L p .974 .923 .668 r
F P
0 g
s
.46108 .25784 m .43898 .25534 L .40422 .23607 L p .609 .522 .731 r
F P
0 g
s
.40422 .23607 m .42639 .22779 L .46108 .25784 L p .609 .522 .731 r
F P
0 g
s
.55643 .41961 m .53319 .39447 L .4983 .34804 L p 0 0 .545 r
F P
0 g
s
.4959 .30462 m .47346 .29346 L .43898 .25534 L p .491 .426 .712 r
F P
0 g
s
.43898 .25534 m .46108 .25784 L .4959 .30462 L p .491 .426 .712 r
F P
0 g
s
.71818 .26928 m .73878 .21298 L .74942 .22843 L closepath p .956 .795 .642 r
F P
0 g
s
.74942 .22843 m .72918 .28553 L .69686 .32271 L p .968 .83 .654 r
F P
0 g
s
.69686 .32271 m .71818 .26928 L .74942 .22843 L p .968 .83 .654 r
F P
0 g
s
.48354 .25941 m .46108 .25784 L .42639 .22779 L p .593 .476 .689 r
F P
0 g
s
.42639 .22779 m .44875 .21945 L .48354 .25941 L p .593 .476 .689 r
F P
0 g
s
.54399 .39542 m .52082 .37437 L .48588 .32424 L p .107 .254 .733 r
F P
0 g
s
.48588 .32424 m .50835 .3439 L .54399 .39542 L p .107 .254 .733 r
F P
0 g
s
.72904 .35291 m .70739 .39211 L .67468 .42785 L p .798 .941 .587 r
F P
0 g
s
.73976 .29809 m .71891 .3494 L .68633 .38688 L p .977 .893 .672 r
F P
0 g
s
.68633 .38688 m .70818 .3396 L .73976 .29809 L p .977 .893 .672 r
F P
0 g
s
.53141 .35901 m .50835 .3439 L .47346 .29346 L p .377 .361 .715 r
F P
0 g
s
.47346 .29346 m .4959 .30462 L .53141 .35901 L p .377 .361 .715 r
F P
0 g
s
.51883 .31244 m .4959 .30462 L .46108 .25784 L p .505 .413 .685 r
F P
0 g
s
.46108 .25784 m .48354 .25941 L .51883 .31244 L p .505 .413 .685 r
F P
0 g
s
.50635 .25918 m .48354 .25941 L .44875 .21945 L p .582 .449 .664 r
F P
0 g
s
.44875 .21945 m .47129 .21103 L .50635 .25918 L p .582 .449 .664 r
F P
0 g
s
.70682 .24931 m .72798 .19729 L .73878 .21298 L closepath p .949 .799 .66 r
F P
0 g
s
.73878 .21298 m .71818 .26928 L .68502 .29869 L p .959 .832 .674 r
F P
0 g
s
.68502 .29869 m .70682 .24931 L .73878 .21298 L p .959 .832 .674 r
F P
0 g
s
.52947 .25637 m .50635 .25918 L .47129 .21103 L p .577 .434 .65 r
F P
0 g
s
.47129 .21103 m .49402 .20255 L .52947 .25637 L p .577 .434 .65 r
F P
0 g
s
.5802 .43574 m .55643 .41961 L .52082 .37437 L p 0 .153 .69 r
F P
0 g
s
.54217 .31535 m .51883 .31244 L .48354 .25941 L p .522 .412 .67 r
F P
0 g
s
.48354 .25941 m .50635 .25918 L .54217 .31535 L p .522 .412 .67 r
F P
0 g
s
.72918 .28553 m .70818 .3396 L .67473 .36967 L p .965 .861 .686 r
F P
0 g
s
.67473 .36967 m .69686 .32271 L .72918 .28553 L p .965 .861 .686 r
F P
0 g
s
.55285 .25036 m .52947 .25637 L .49402 .20255 L p .574 .428 .645 r
F P
0 g
s
.49402 .20255 m .51695 .19399 L .55285 .25036 L p .574 .428 .645 r
F P
0 g
s
.71891 .3494 m .69722 .39396 L .6636 .42333 L p .929 .97 .699 r
F P
0 g
s
.6636 .42333 m .68633 .38688 L .71891 .3494 L p .929 .97 .699 r
F P
0 g
s
.55495 .36726 m .53141 .35901 L .4959 .30462 L p .436 .385 .704 r
F P
0 g
s
.4959 .30462 m .51883 .31244 L .55495 .36726 L p .436 .385 .704 r
F P
0 g
s
.56768 .40819 m .54399 .39542 L .50835 .3439 L p .253 .335 .754 r
F P
0 g
s
.50835 .3439 m .53141 .35901 L .56768 .40819 L p .253 .335 .754 r
F P
0 g
s
.69512 .22586 m .717 .18135 L .72798 .19729 L closepath p .933 .805 .695 r
F P
0 g
s
.72798 .19729 m .70682 .24931 L .67275 .26806 L p .941 .836 .711 r
F P
0 g
s
.67275 .26806 m .69512 .22586 L .72798 .19729 L p .941 .836 .711 r
F P
0 g
s
.5764 .2408 m .55285 .25036 L .51695 .19399 L p .575 .43 .647 r
F P
0 g
s
.51695 .19399 m .54007 .18536 L .5764 .2408 L p .575 .43 .647 r
F P
0 g
s
.56579 .31205 m .54217 .31535 L .50635 .25918 L p .542 .421 .664 r
F P
0 g
s
.50635 .25918 m .52947 .25637 L .56579 .31205 L p .542 .421 .664 r
F P
0 g
s
.71818 .26928 m .69686 .32271 L .66252 .34226 L p .938 .826 .707 r
F P
0 g
s
.66252 .34226 m .68502 .29869 L .71818 .26928 L p .938 .826 .707 r
F P
0 g
s
.69722 .39396 m .67468 .42785 L .64017 .44637 L p .641 .924 .647 r
F P
0 g
s
.60006 .22767 m .5764 .2408 L .54007 .18536 L p .58 .442 .658 r
F P
0 g
s
.54007 .18536 m .56339 .17666 L .60006 .22767 L p .58 .442 .658 r
F P
0 g
s
.70818 .3396 m .68633 .38688 L .65178 .4063 L p .948 .912 .749 r
F P
0 g
s
.65178 .4063 m .67473 .36967 L .70818 .3396 L p .948 .912 .749 r
F P
0 g
s
.68316 .19943 m .70586 .16516 L .717 .18135 L closepath p .9 .81 .751 r
F P
0 g
s
.717 .18135 m .69512 .22586 L .66016 .23191 L p .903 .835 .769 r
F P
0 g
s
.66016 .23191 m .68316 .19943 L .717 .18135 L p .903 .835 .769 r
F P
0 g
s
.57879 .36664 m .55495 .36726 L .51883 .31244 L p .494 .419 .7 r
F P
0 g
s
.51883 .31244 m .54217 .31535 L .57879 .36664 L p .494 .419 .7 r
F P
0 g
s
.60423 .43985 m .5802 .43574 L .54399 .39542 L p .083 .382 .844 r
F P
0 g
s
.54399 .39542 m .56768 .40819 L .60423 .43985 L p .083 .382 .844 r
F P
0 g
s
.58955 .30178 m .56579 .31205 L .52947 .25637 L p .566 .439 .667 r
F P
0 g
s
.52947 .25637 m .55285 .25036 L .58955 .30178 L p .566 .439 .667 r
F P
0 g
s
.62374 .21124 m .60006 .22767 L .56339 .17666 L p .589 .466 .68 r
F P
0 g
s
.56339 .17666 m .5869 .16788 L .62374 .21124 L p .589 .466 .68 r
F P
0 g
s
.59166 .4101 m .56768 .40819 L .53141 .35901 L p .395 .422 .77 r
F P
0 g
s
.53141 .35901 m .55495 .36726 L .59166 .4101 L p .395 .422 .77 r
F P
0 g
s
.70682 .24931 m .68502 .29869 L .64985 .30544 L p .895 .784 .731 r
F P
0 g
s
.64985 .30544 m .67275 .26806 L .70682 .24931 L p .895 .784 .731 r
F P
0 g
s
.64739 .19202 m .62374 .21124 L .5869 .16788 L p .605 .51 .72 r
F P
0 g
s
.5869 .16788 m .61062 .15902 L .64739 .19202 L p .605 .51 .72 r
F P
0 g
s
.69686 .32271 m .67473 .36967 L .63934 .37663 L p .902 .821 .758 r
F P
0 g
s
.63934 .37663 m .66252 .34226 L .69686 .32271 L p .902 .821 .758 r
F P
0 g
s
.61329 .28455 m .58955 .30178 L .55285 .25036 L p .595 .468 .677 r
F P
0 g
s
.55285 .25036 m .5764 .2408 L .61329 .28455 L p .595 .468 .677 r
F P
0 g
s
.68633 .38688 m .6636 .42333 L .62819 .43008 L p .871 .967 .856 r
F P
0 g
s
.62819 .43008 m .65178 .4063 L .68633 .38688 L p .871 .967 .856 r
F P
0 g
s
.69512 .22586 m .67275 .26806 L .63686 .26088 L p .831 .733 .756 r
F P
0 g
s
.63686 .26088 m .66016 .23191 L .69512 .22586 L p .831 .733 .756 r
F P
0 g
s
.67099 .1709 m .69453 .14871 L .70586 .16516 L closepath p .826 .803 .83 r
F P
0 g
s
.70586 .16516 m .68316 .19943 L .64739 .19202 L p .822 .817 .845 r
F P
0 g
s
.64739 .19202 m .67099 .1709 L .70586 .16516 L p .822 .817 .845 r
F P
0 g
s
.6027 .356 m .57879 .36664 L .54217 .31535 L p .554 .461 .704 r
F P
0 g
s
.54217 .31535 m .56579 .31205 L .6027 .356 L p .554 .461 .704 r
F P
0 g
s
.64017 .44637 m .6163 .45485 L .5802 .43574 L p 0 .483 .716 r
F P
0 g
s
.63686 .26088 m .61329 .28455 L .5764 .2408 L p .632 .511 .697 r
F P
0 g
s
.5764 .2408 m .60006 .22767 L .63686 .26088 L p .632 .511 .697 r
F P
0 g
s
.67099 .1709 m .64739 .19202 L .61062 .15902 L p .63 .592 .792 r
F P
0 g
s
.61062 .15902 m .63455 .15009 L .67099 .1709 L p .63 .592 .792 r
F P
0 g
s
.68502 .29869 m .66252 .34226 L .62645 .33533 L p .832 .729 .751 r
F P
0 g
s
.62645 .33533 m .64985 .30544 L .68502 .29869 L p .832 .729 .751 r
F P
0 g
s
.61564 .39959 m .59166 .4101 L .55495 .36726 L p .53 .509 .777 r
F P
0 g
s
.55495 .36726 m .57879 .36664 L .61564 .39959 L p .53 .509 .777 r
F P
0 g
s
.68316 .19943 m .66016 .23191 L .62374 .21124 L p .744 .67 .778 r
F P
0 g
s
.62374 .21124 m .64739 .19202 L .68316 .19943 L p .744 .67 .778 r
F P
0 g
s
.62819 .43008 m .60423 .43985 L .56768 .40819 L p .43 .607 .922 r
F P
0 g
s
.56768 .40819 m .59166 .4101 L .62819 .43008 L p .43 .607 .922 r
F P
0 g
s
.6636 .42333 m .64017 .44637 L .60423 .43985 L p .573 .924 .954 r
F P
0 g
s
.60423 .43985 m .62819 .43008 L .6636 .42333 L p .573 .924 .954 r
F P
0 g
s
.66016 .23191 m .63686 .26088 L .60006 .22767 L p .681 .574 .729 r
F P
0 g
s
.60006 .22767 m .62374 .21124 L .66016 .23191 L p .681 .574 .729 r
F P
0 g
s
.62645 .33533 m .6027 .356 L .56579 .31205 L p .617 .511 .711 r
F P
0 g
s
.56579 .31205 m .58955 .30178 L .62645 .33533 L p .617 .511 .711 r
F P
0 g
s
.67275 .26806 m .64985 .30544 L .61329 .28455 L p .756 .646 .74 r
F P
0 g
s
.61329 .28455 m .63686 .26088 L .67275 .26806 L p .756 .646 .74 r
F P
0 g
s
.67473 .36967 m .65178 .4063 L .61564 .39959 L p .828 .8 .824 r
F P
0 g
s
.61564 .39959 m .63934 .37663 L .67473 .36967 L p .828 .8 .824 r
F P
0 g
s
.69453 .14871 m .67099 .1709 L .63455 .15009 L p .658 .749 .917 r
F P
0 g
s
.63455 .15009 m .65868 .14108 L .69453 .14871 L p .658 .749 .917 r
F P
0 g
s
.65868 .14108 m .68302 .132 L .69453 .14871 L closepath p .658 .749 .917 r
F P
0 g
s
.64985 .30544 m .62645 .33533 L .58955 .30178 L p .684 .572 .723 r
F P
0 g
s
.58955 .30178 m .61329 .28455 L .64985 .30544 L p .684 .572 .723 r
F P
0 g
s
.63934 .37663 m .61564 .39959 L .57879 .36664 L p .649 .59 .775 r
F P
0 g
s
.57879 .36664 m .6027 .356 L .63934 .37663 L p .649 .59 .775 r
F P
0 g
s
.66252 .34226 m .63934 .37663 L .6027 .356 L p .749 .663 .766 r
F P
0 g
s
.6027 .356 m .62645 .33533 L .66252 .34226 L p .749 .663 .766 r
F P
0 g
s
.65178 .4063 m .62819 .43008 L .59166 .4101 L p .687 .741 .892 r
F P
0 g
s
.59166 .4101 m .61564 .39959 L .65178 .4063 L p .687 .741 .892 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(0)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(0.25)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0.5)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.75)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
gsave
.2956 .07454 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00k?ooool4o`000003oa0@4?oooooooooo07Gooooo003^ooooo`03o`00
0?oooooooooo07Oooooo003^ooooo`03o`000?oooooooooo07Oooooo003^ooooo`03o`000?oooooo
oooo07Oooooo003^ooooo`03o`000?oooooooooo07Oooooo003^ooooo`03o`000?oooooooooo07Oo
oooo003^ooooo`03o`000?oooooooooo07Oooooo003/ooooo`03oeEEEOmVIVKo000007Wooooo003o
ooooo`7ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00ooooool1ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0Hoooool00?oooooo0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003h
ooooo`;o00001_ooool01Ol0003ooooooooooooooooo000006?ooooo003eooooo`?o000000?ooooo
o`000?ooool01Oooool01Ol0003ooooooooooooooooo000006?ooooo003cooooo`;o00001?ooool2
o`0000Gooooo00Go410@oooooooooooooooooa0@401Sooooo`00l?ooool3o`000003ooooool0003o
oooo00?ooooo00?o0000ooooool000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg06?ooooo003^
ooooo`;o00001Oooool01ol0003ooooooooooooooooo0000ooooool000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003[ooooo`?o00002oooool2o`000003ooooool0003ooooo06[ooooo
003Xooooo`?o00003_ooool01Ol0003ooooooooooooooooo000006[ooooo003Vooooo`;o000000?o
ooooo`000?ooool03_ooool01Ol0003ooooooooooooooooo000006[ooooo003Sooooo`?o00004ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Oooooo003Qooooo`;o00005oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Kooooo003Nooooo`?o00006Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo06Kooooo002Pooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;o
gMgM01kooooo0ol0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0IOooool0
0:3ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07
ooooo`03ogMgMolb<S;ooooo01[ooooo0ol00002ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool00_ooool3o`0006Kooooo001cooooo`;o00000_ooool2o`0002Oooooo00Go410@oooo
oooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool05oooool2
o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Tooooo`00Loooool01_o^
k^ko8B4QohN7Qonj^[[o0000omgMgBOooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q
8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool05Oooool3o`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1Sooooo`00M?ooool01?oMgMgo0000oa0@4?o<c<`Xooooo`05o`00
0?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`05?ooool2o`0002Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Soooo
o`00M?ooool01?o^k^ko8B4Qoa0@4?o^k^hXooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo01?ooooo0ol00002ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Rooooo`00M?ooool01?lQ
8B7oMgMgogMgMolb<S8Xooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooo
oooooooo<S8b00Cooooo00?o0000ooooooooool04?ooool3o`0002_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1Qooooo`00Loooool2o`0000;ooooo0_l0000Wooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000=ooooo`;o0000;_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo067ooooo0037ooooo`?o0000<?ooool00ol0003ooooooooo
o`08ooooo`;o0000HOooool00<Gooooo0_l00002ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool01oooool00ol0003oooooo`00001Qooooo`00`_ooool3o`0003Gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`1Oooooo`00`?ooool2o`0003Sooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Nooooo`00_Oooool3o`0003[ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Mooooo`00^oooool2o`000003ooooool0003ooooo03[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`1Mooooo`00^?ooool3o`0000Cooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05cooooo002foooo
o`;o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05_ooooo002cooooo`?o
0000AOooool00ol0003oooooooooo`0;ooooo`?o0000G?ooool00;7ooooo0_l000000ooooooo0000
ooooo`15ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0F_ooool00:kooooo0ol0
001:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0FOooool00:_ooooo0ol0001=
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0FOooool007Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01oooooo0_l0
001@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0F?ooool007Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`?o000000?o
ooooo`000?ooool0Coooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05Sooooo001d
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Hooooo`;o0000EOoo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Oooooo001dooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`0Fooooo`?o0000Eoooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo05Kooooo001dooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Gooooo0_l0001Jooooo`03o`000?oooooooooo013ooooo
0_l00009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd0<Oooool007Cooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo01Cooooo0ol000000ooooooo0000ooooo`1Iooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0`ooooo`00M?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool2o`0005oooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo02oooooo001dooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000kooooo0ol0001Qooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^
k^h01oooool00omgMgOo<S8booooo`0`ooooo`00UOooool2o`0006Cooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0<Oooool009;ooooo0ol000000ooooooo
0000ooooo`1Sooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0coooo
o`00Soooool3o`0006Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000
ooooooooool0<oooool008gooooo0_l0001Xooooo`;o00000oooool00ol0003oooooooooo`0Coooo
o`?o00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`Co0000<_ooool008[ooooo0ol0001Wooooo`?o000000?oZ;oZo`000?ooool00_ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo053ooooo0028ooooo`;o00000_ooool00ol0
003oooooooooo`1Rooooo`?o00001OnX_nX01?l0003oooooooooool0000Hooooo`03o`000?oooooo
oooo053ooooo0025ooooo`?o00001Oooool00ol0003oooooooooo`1Oooooo`Co00001onX_nX00ol0
003oooooo`00000Iooooo`03o`000?oooooooooo04oooooo0023ooooo`;o0000Ioooool3o`0000Co
Z;oZ1?l00003ojRojP03o`000?oooooo000001[ooooo00?o0000ooooooooool0C_ooool0083ooooo
0ol0001Vooooo`?o00002onX_nX6o`0001[ooooo00?o0000ooooooooool0C_ooool007kooooo0_l0
0003ooooo`03o`000?oooooooooo067ooooo0_l0000BojRojP;o00006oooool00ol0003ooooooooo
o`1=ooooo`00Noooool3o`0006Kooooo0ol00003oj6GbP;o00003_nX_nX00ol0003odlgDo`00000J
ooooo`?o0000C_ooool003_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Pooooo`;o0000Ioooool2o`0000SoXIO:00?o
0000ojRoj_nX_nX02_nX_nX00ol0003odlgDom?=e002o`0001_ooooo00?o0000ooooooooool0C?oo
ool003_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool07?ooool3o`0006Oooooo0_l0000;oj6GbP;o0000
2OnX_nX01ol0003odlgDom?=e?oCcMCo0000om?=e?l000006oooool00ol0003oooooooooo`1;oooo
o`00>oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0
003oooooooooo`0Hooooo`?o00000oooool00ol0003oooooooooo`1Qooooo`?o00000_nJP[P00ol0
003oXIO:oj6GbP0:oj6GbP;o00001_nX_nX00ol0003odlgDom?=e002om?=e003o`000?oCcMCo0000
01_ooooo00?o0000ooooooooool0Boooool003_ooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool05oooool2o`0006Oooooo0ol00006oiZ2
^003o`000?nQUl[oXIO:00_oXIO:00?o0000ojRoj_nX_nX00_nX_nX00ol0003odlgDom?=e003om?=
e0Co00006oooool00ol0003oooooooooo`1:ooooo`00>oooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Gooooo0ol0001W
ooooo`;o00002_nJP[P00ol0003oXIO:oj6GbP0;oj6GbP;o000000?oZ;oZo`000?oCcM@01_l00002
om;Af003o`000?oooooooooo01[ooooo00?o0000ooooooooool0BOooool003_ooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05Oooool2
o`0000;ooooo00?o0000ooooooooool0H_ooool3o`000003oiIg[_l0003oVX:h00[oVX:h00?o0000
oj6Gb_nQUlX03?nQUlX3o`0000God]7H00Go0000om;Af?l0003oi/o0o`00000Kooooo`03o`000?oo
oooooooo04Wooooo000kooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool04_ooool3o`0006Kooooo0ol00005oiIg[P03o`00
0?nJP[SoVX:h00WoVX:h00?o0000oj6Gb_nQUlX02OnQUlX00ol0003od]7Hom;Af007om;Af0;o0000
0ooVcl000ol0003oooooooooo`0Hooooo`;o0000B_ooool003_ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000oooooo0_l0001Vooooo`?o
00002OnFMjh00ol0003oVX:hoiZ2^009oiZ2^003o`000?nQUl[oXIO:00OoXIO:00?o0000om;Af?oB
dMP02?oBdMP2o`0000Coi/o000?o0000ooooooooool06Oooool00ol0003oooooooooo`17ooooo`00
I?ooool3o`0006Gooooo0ol00002oiAaZ003o`000?nFMjkoUWN^00SoUWN^00?o0000oiZ2^?nJP[P0
2OnJP[P00ol0003oXIO:oj6GbP05oj6GbP03o`000?oBdMSod]7H00Wod]7H0_l00004onK?`0;o0000
6_ooool00ol0003oooooooooo`17ooooo`00H_ooool2o`0000;ooooo00?o0000ooooooooool0H?oo
ool3o`0000KoU76X00?o0000oiIg[_nFMjh02?nFMjh00ol0003oVX:hoiZ2^009oiZ2^003o`000?nQ
Ul[oXIO:00?oXIO:00?o0000om;Af?oBdMP02OoBdMP00ol0003oi/o0o`000002onK?`0;o000000?o
imG4o`000?ooool06_ooool00ol0003oooooooooo`0Sooooo`?o000000?o410@ooooooooool07Ooo
ool005oooooo0ol0001Tooooo`?o000000?oTfjUo`000?nDLJP01onDLJP00ol0003oUWN^oiIg[P08
oiIg[P03o`000?nJP[SoVX:h00WoVX:h00Go0000oj6Gb_nQUl[oXIO:o`00000<om;Af003o`000?oV
cl3o000000;o00000_oWeL@00ol0003ok/jao`00000Kooooo`03o`000?oooooooooo02Cooooo00?o
410@okZj^_ooool07_ooool005gooooo0_l0001Tooooo`?o00001OnCKZD00ol0003oU76XoiAaZ006
oiAaZ003o`000?nFMjkoUWN^00SoUWN^00?o0000oiZ2^?nJP[P02OnJP[P00ol0003oXIO:o`00000<
om;Af004o`000?oVcl3oi/o0o`0000CoimG400Co0000onk>/Oo^c[7o00006_ooool00ol0003ooooo
ooooo`0Tooooo`03oiRHV?lb<S;ooooo01kooooo001Jooooo`Co0000Hoooool2o`0000WoTfjU00?o
0000oiAaZ?nDLJP01OnDLJP00ol0003oUWN^oiIg[P08oiIg[P03o`000?nJP[SoVX:h00WoVX:h1Ol0
000:om;Af0Co00000ooWeL@01Ol0003ok/jaonk>/Oo^c[7o000001_ooooo00?o0000ooooooooool0
8oooool00ooMgMgo0000okZj^P0Nooooo`00F?ooool2o`0000Cooooo00?o0000ooooooooool0GOoo
ool3o`000003oi9]YOl0003oTfjU00SoTfjU00?o0000oiAaZ?nDLJP01_nDLJP00ol0003oUWN^oiIg
[P08oiIg[P03o`000?nJP[SoVX:h00OoVX:h00?o0000okj[aonnZlL00onnZlL6o`0000?od]7H0_l0
0002onOEa005o`000?oWeLCoimG4onOEa?l000000oo^c[42o`0001Wooooo0ol0000Tooooo`03oeEE
EOmgMgOoA4A401kooooo001Eooooo`?o0000I?ooool2o`0000GoTVfU00?o0000oi=^YOnCKZD01onC
KZD00ol0003oU76XoiAaZ006oiAaZ003o`000?nFMjkoUWN^00SoUWN^00?o0000oiZ2^?nJP[P01OnJ
P[P00ol0003o_Z_7okj[a`0:okj[a`?o00001?oWeL@01?l0003oimG4onOEa?l00003onk>/@03o`00
0?o`e[Ko000001_ooooo00?o0000ooooooooool08Oooool01OoMgMgo410@oooooolQ8B7ogMgM01go
oooo001Booooo`?o0000IOooool2o`0000SoTVfU00?o0000oi=^YOnCKZD01onCKZD00ol0003oU76X
oiAaZ006oiAaZ003o`000?nFMjkoUWN^00SoUWN^00?o0000oiZ2^?nJP[P00onJP[P00ol0003o_Z_7
okj[a`0=okj[a`03o`000?oWeLCoimG400;oimG400Co0000onOEa?oWeLCo00000_o^c[401Ol0003o
l=Jfoo3F]_obc:So000001_ooooo00?o0000ooooooooool08?ooool01OmVIVKoQhN7oooooonHV9So
EEEE01gooooo001@ooooo`;o000000?oooooo`000?l00000H_ooool3o`000003oi=_Y_l0003oTVfU
00OoTVfU00?o0000oi=^YOnCKZD01onCKZD00ol0003oU76XoiAaZ006oiAaZ003o`000?nFMjkoUWN^
00WoUWN^00Go0000oiZ2^?nJP[SoVX:ho`00000?okj[a`03o`000?oWeLCoimG400?oimG400?o0000
onOEa?l000000_o^c[401?l0003ol=Jfoo3F]_l00002oo;<Z003o`000?oooooooooo01Wooooo00?o
0000ooooooooool07_ooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo01_ooooo001=
ooooo`?o0000IOooool2o`0000GoTfnV00?o0000oi9]YOnBKJD01_nBKJD00ol0003oTfjUoi=^Y@07
oi=^Y@03o`000?nDLJSoU76X00KoU76X00?o0000oiIg[_nFMjh02OnFMjh00ol0003oVX:ho`00000?
okj[a`03o`000?oWeLCoimG400CoimG400Go0000onOEa?l0003ok/jao`000003oo3F]P05o`000?ob
c:Sol/bXoo;<Z?l000006_ooool00ol0003oooooooooo`0Nooooo`04oa0@4?l0003o0000ooooo`;o
000000?o410@ooooooooool06_ooool002Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`;o
0000IOooool3o`0000SoTfnV00?o0000oi9]YOnBKJD01_nBKJD00ol0003oTfjUoi=^Y@07oi=^Y@03
o`000?nDLJSoU76X00KoU76X00?o0000oiIg[_nFMjh02?nFMjh3o`0000oo_Z_700?o0000onOEa?oW
eL@01?oWeL@2o`000003onk>/Ol0003ol=Jf00;ol=Jf00?o0000oo;<Z?obc:P00oobc:P00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo043ooooo000Uooooo`05ogMgMonHV9SooooooiRHV?mg
MgL07_ooool3o`0006Cooooo0ol00002oiAbZ@03o`000?nCKjKoTfnV00KoTfnV00?o0000oi9]YOnB
KJD01_nBKJD00ol0003oTfjUoi=^Y@07oi=^Y@03o`000?nDLJSoU76X00OoU76X00?o0000oiIg[_nF
Mjh01_nFMjh01?l0003o[Y:jojjB^_n^T[X2o`0000co_Z_700?o0000onOEa?oWeL@01OoWeL@3o`00
00Col=Jf00?o0000oo;<Z?obc:P00oobc:P00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
03oooooo000Uooooo`05oa0@4?ooooooooooooooool@41007?ooool2o`0000?ooooo00?o0000oooo
ooooool0G_ooool3o`0000KoU7:Y00?o0000oi=_Y_nCKjH01_nCKjH00ol0003oTVfUoi9]Y@06oi9]
Y@03o`000?nCKZGoTfjU00OoTfjU00?o0000oiAaZ?nDLJP01_nDLJP00ol0003oUWN^oiIg[P04oiIg
[P;o00001_n^T[X2o`0000Wo_Z_700?o0000onOEa?oWeL@01_oWeL@2o`0000Gol=Jf00?o0000oo;<
Z?obc:P00_obc:P00ol0003om<^To`00000Iooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd08oooool002Gooooo00Go0000
ooooooooooooooooo`00000Iooooo`?o0000Hoooool3o`000003oiMi/?l0003oU7:Y00OoU7:Y00?o
0000oi=_Y_nCKjH01_nCKjH00ol0003oTVfUoi9]Y@06oi9]Y@03o`000?nCKZGoTfjU00OoTfjU00?o
0000oiAaZ?nDLJP01_nDLJP01?l0003oUWN^oiIg[_nFMjh2o`0000[o[Y:j0_l00006okj[a`03o`00
0?oWeLCoimG400OoimG400?o0000oo3F]_o`e[H00oo`e[H00ol0003ol/bXoo;<Z002oo;<Z0;o0000
0_odbj@00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Rooooo`009Oooool01Ol0003ooooo
oooooooooooo000001Oooooo0_l0001Sooooo`?o00001OnGNK000ol0003oU7:YoiAbZ@06oiAbZ@03
o`000?nCKjKoTfnV00KoTfnV00?o0000oi9]YOnBKJD01OnBKJD00ol0003oTfjUoi=^Y@07oi=^Y@03
o`000?nDLJSoU76X00OoU76X00?o0000oiIg[_l000003_n^T[X2o`0000Co_Z_700?o0000onOEa?oW
eL@00ooWeL@5o`0000Gol=Jf00Oo0000oo;<Z?obc:Sol/bXo`000?oee:co000000;om<^T00?o0000
ooooooooool06?ooool00ol0003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@41004?oo
ool00ol0003oooooooooo`0Qooooo`009Oooool01Ol@413ooooooooooooooooo410@01Cooooo1?l0
001Rooooo`;o00002OnGNK000ol0003oU7:YoiAbZ@05oiAbZ@03o`000?nCKjKoTfnV00KoTfnV00?o
0000oi9]YOnBKJD01_nBKJD00ol0003oTfjUoi=^Y@07oi=^Y@03o`000?nDLJSoU76X00KoU76X0_l0
000AojjB^P;o000000?o_Z_7o`000?oWeL@01Ol00003omBk`@;o00001Oo`e[H01_l0003ol/bXoo;<
Z?l0003omMB/o`0000Com<^T00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Rooooo`009Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg01;ooooo0_l00004ooooo`03o`000?oooooooooo05cooooo0ol00003oi^5
^`WoUgV`00?o0000oiAbZOnDLZT01OnDLZT00ol0003oTfnVoi=_YP06oi=_YP03o`000?nBKJGoTVfU
00KoTVfU00?o0000oi=^YOnCKZD01onCKZD00ol0003oU76XoiAaZ003oiAaZ0;o00000onQP[800ol0
003o[Y:jojjB^P0?ojjB^P?o00001ooD^l401?l0003ol=Jfoo3F]_l00003oo3F]P04o`000?obc:So
l/bXo`0000;omMB/00?o0000ooC;Y?odbj@00_odbj@00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`08oooool002Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0?ooooo`?o0000Hoooool2o`0000Oo
VhFk00?o0000oiMi/?nGNK001_nGNK000ol0003oU7:YoiAbZ@05oiAbZ@03o`000?nCKjKoTfnV00Ko
TfnV00?o0000oi9]YOnBKJD01OnBKJD00ol0003oTfjUoi=^Y@07oi=^Y@03o`000?nDLJSoU76X00;o
U76X00?o0000oj62/_nQP[801?nQP[800ol0003o[Y:jojjB^P0>ojjB^P03o`000?oD^l7oe;_100Oo
e;_100Co0000oo3F]_o`e[Ko00000oo`e[H01_l0003ol/bXoo;<Z?l0003omMB/o`0000Com<^T0ol0
000Jooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo02Gooooo000fooooo`?o0000F?ooool8o`0000?ooooo0ol0000:oi^5^`03o`000?nG
NK3oUgV`00KoUgV`00?o0000oiAbZOnDLZT01OnDLZT00ol0003oTfnVoi=_YP05oi=_YP03o`000?nB
KJGoTVfU00KoTVfU00?o0000oi=^YOnCKZD01onCKZD01?l0003oU76Xo`000?l00008oj62/P03o`00
0?n^T[[o[Y:j00co[Y:j00?o0000omBk`OoD^l401ooD^l401Ol0003ol=Jfoo3F]_o`e[Ko000000?o
l=Jf00?o0000oo;<Z?l000000_oee:`01?l0003om<^TooC;Y?odbj@2o`0000;om<^S00?o0000oooo
ooooool05_ooool3o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooo
oooo02Gooooo000dooooo`;o00000oooool00ol0003oooooooooo`1Aooooo`oo00001?nQVL`:oi^5
^`03o`000?nGNK3oUgV`00KoUgV`00?o0000oiAbZOnDLZT01?nDLZT00ol0003oTfnVoi=_YP06oi=_
YP03o`000?nBKJGoTVfU00KoTVfU00?o0000oi=^YOnCKZD01_nCKZD2o`0000_oXH:b00?o0000ojjB
^_n^T[X02_n^T[X00ol0003oe;_1omBk`@08omBk`@05o`000?o`e[Kol=Jfoo3F]_l000000_o`e[H0
0ol0003ol/bXo`000003ooGD[006o`000?odbjCom<^To`000?oge:Oo00000oodbj<00ol0003ooooo
ooooo`0Hooooo`09o`000?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000T
ooooo`00<Oooool3o`0005Gooooo1Ol000000om<bm_o0000o`000003o`0000?o<k?Y0_l00009oj6I
c003o`000?nKQK_oVhFk00KoVhFk0_l00006oiMi/003o`000?nDLZWoU7:Y00GoU7:Y00?o0000oi=_
Y_nCKjH01_nCKjH00ol0003oTVfUoi9]Y@05oi9]Y@03o`000?nCKZGoTfjU00?oTfjU0ol000000onH
Mjgo0000oj62/P0;oj62/P03o`000?n^T[[o[Y:j00So[Y:j00?o0000omBk`OoD^l402?oD^l400ol0
003ol=Jfoo3F]P02oo3F]P03o`000?o`e[Kol=Jf00;o00000ooee:`01ol0003om<^TooC;Y?odbjCo
0000ooODYol000001?odbj<00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03[ooooo000_
ooooo`;o0000EOoooolBo`0000;oYkWV2_nQVL`00ol0003oVhFkoi^5^`06oi^5^`03o`000?nGNK3o
UgV`00CoUgV`00?o0000oiAbZOnDLZT01OnDLZT00ol0003oTfnVoi=_YP06oi=_YP03o`000?nBKJGo
TVfU00GoTVfU00?o0000oi=^YOl000000_l00005oiQg[@03o`000?nQP[;oXH:b00[oXH:b00?o0000
ojjB^_n^T[X01_n^T[X00ol0003oe;_1omBk`@09omBk`@03o`000?o`e[Kol=Jf00;ol=Jf00Co0000
oo3F]_o`e[Ko00001?oee:`01_l0003om<^TooC;Y?l0003ommBWo`0000Gom<^S00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0iooooo`00;?ooool5o`0005?ooooo3?l00002odO7g`?o0000
2OnW^NH00ol0003oXIW<oj6Ic004oj6Ic0;o00001onKQK/00ol0003oUgV`oiMi/004oiMi/003o`00
0?nDLZWoU7:Y00CoU7:Y00?o0000oi=_Y_nCKjH01_nCKjH00ol0003oTVfUoi9]Y@04oi9]Y@?o0000
2OnHMjd00ol0003oXH:boj62/P0:oj62/P03o`000?n^T[[o[Y:j00Go[Y:j00?o0000omBk`OoD^l40
2?oD^l400ol0003ol=Jfoo3F]P03oo3F]P?o00001Ooee:`00ol0003om<^To`000002ooODY`03o`00
0?odbj?om<^S00;om<^S00?o0000ooC;YOl000006_ooool00ol0003oooooooooo`0hooooo`00:ooo
ool2o`0000Cooooo00?o0000ooooooooool0C_ooool@o`0000ooYkWV0_l00004oj6Ic0;o00001_nK
QK/00ol0003oUgV`oiMi/004oiMi/003o`000?nDLZWoU7:Y00CoU7:Y00?o0000oi=_Y_nCKjH01_nC
KjH00ol0003oTVfUoi9]Y@03o`0000;oT72Z00?o0000oiQg[OnHMjd02?nHMjd00ol0003oXH:boj62
/P0:oj62/P03o`000?n^T[[o[Y:j00?o[Y:j00?o0000omBk`OoD^l402OoD^l400ol0003ol=Jfoo3F
]P02oo3F]P;o000000?oiLRko`000?oee:`00ooee:`00ol0003om<^To`000003ooODY`04o`000?od
bj?om<^SooC;X`;o00000_odbjD00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03Sooooo
000[ooooo`?o0000D_ooool?o`0000WoX>7l0_mW`_h3ogBQk@OoN8GD0omjML400ol0003oXIW<o`00
0004o`0000;oVhFk00?o0000oiMi/?nGNK001?nGNK000ol0003oU7:YoiAbZ@04oiAbZ@03o`000?nC
KjKoTfnV00;oTfnV1_l00006oi1`ZP03o`000?nHMjgoV7N]00SoV7N]00?o0000oj62/_nQP[802_nQ
P[801Ol0003o[Y:jojjB^_n^T[[o000000_oe;_100Co0000oo3F]_o`e[Kol=Jf0_l000000ooUb;_o
0000o`000005ooGD[0;o00000ooge:L01ol0003om<^SooC;Xoodbj?o0000ooSDY_l000000_odbjD0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03Oooooo000[ooooo`04o`000?oooooooooo
o`0004oooooo3_l00006oj3Qo0Go00001_nXXm42ogBQk@KoN8GD1?mjML400ol0003oOFffoge]]P02
oge]]QGo00001?n:JjT00ol0003oT72Zoi1`ZP06oi1`ZP03o`000?nHMjgoV7N]00SoV7N]00?o0000
oj62/_nQP[802_nQP[800ol0003o[Y:jo`00000<omBk`@04o`000?o`e[Kol=Jfo`0000?oiLRk0_l0
0004ooGD[003o`000?odbjCo000000?ommBW00Co0000ooC;Xoodbj?om<^S0_l00004ooC;Y@03o`00
0?oooooooooo01Kooooo00?o0000ooooool00000>?ooool002_ooooo00Go0000oooooooooooooooo
o`00001<ooooo`Ko000000?o0`00o`000?l000001Ol00002oj3Qo0Wob;O91OnkY/@00ol0003oZ:?A
ojRSd@03ojRSd@03ogBQkOmhQMCoN8GD00?oN8GD1?mjML400ol0003oOFffoge]]P04oge]]P03o`00
0?n1JJooPFV_00CoPFV_00?o0000ohEYZon5JJ/01?n5JJ/00ol0003oRV^YohY[Z@06ohY[Z@03o`00
0?n@L:[oT72Z00GoT72Z00?o0000oiQg[OnHMjd02OnHMjd00ol0003oXH:boj62/P0:oj62/PCo0000
2OoD^l401?l0003ol=Jfo`000?l00004onG8^`03o`000?oee:comMB/00?omMB/0_l00004ooODY`06
o`000?odbj?om<^So`000?ohe:Ko00001?odbjD00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo03Kooooo000Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Aoooool5o`00
00;o0`001_l00002omG=dP03o`000?o8]lWob;O900Oob;O900?o0000ok^Va?nkY/@02OnkY/@2o`00
00;o:gOS00GoM:7]ogR5e?mhQMCoN8GDo`000003ogYe`@03o`000?mmKKKoOFff00CoOFff00?o0000
oh5Y[on1JJl01?n1JJl00ol0003oQFV[ohEYZ`04ohEYZ`03o`000?n:JjWoRV^Y00KoRV^Y00?o0000
oi1`Z_n@L:X01On@L:X00ol0003oV7N]oiQg[@08oiQg[@03o`000?nQP[;oXH:b00WoXH:b00?o0000
ol6U_Oo1YKd00_o1YKd6o`0000?oe;_10_l00006onG8^`03o`000?oee:comMB/00?omMB/00?o0000
ooODYooge:L00_oge:L01_l0003om<^SooC;Xol0003on=BVo`0000Com<^U00?o0000oo7=Zol00000
6_ooool00ol0003oooooooooo`0eooooo`00:_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo04Gooooo1Ol000000ol3003o0000o`000003o`0000CoeLgB00?o0000olRgbOo8]lT01oo8
]lT00ol0003o^jK4ok^Va009ok^Va0;o00000on^Vl@00ol[Mn?o=6CCo`000003ogR5e0?oNWG100?o
0000oge]]_mmKKH01?mmKKH00ol0003oPFV_oh5Y[`04oh5Y[`03o`000?n5JJ_oQFV[00CoQFV[00?o
0000ohY[ZOn:JjT01On:JjT00ol0003oT72Zoi1`ZP06oi1`ZP03o`000?nHMjgoV7N]00SoV7N]00?o
0000oj62/_nQP[801onQP[800ol0003o`JFmol6U_@09ol6U_@?o00002?oUb;/00ol0003omMB/ooGD
[002ooGD[003o`000?oge:OommBW00?ommBW00Ko0000ooC;Xoodbj?o0000ooSDY_l00003ooC;Y@;o
00000_oacJ/00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03Cooooo000Zooooo`?o0000
1Oooool00ol0003oooooooooo`12ooooo`Go00000_l30003o`0000KoeLgB00?o0000olRgbOo8]lT0
1oo8]lT00ol0003o^jK4ok^Va009ok^Va003o`000?n^VlCo[Y_400Co[Y_400Co:gOSocATdoldI=?o
00000_mhQM@01?l0003oNWG1ogYe`Ol00006oge]]P03o`000?n1JJooPFV_00?oPFV_00?o0000ohEY
Zon5JJ/01?n5JJ/00ol0003oRV^YohY[Z@06ohY[Z@03o`000?n@L:[oT72Z00KoT72Z00?o0000oiQg
[OnHMjd02?nHMjd00ol0003oXH:boj62/P05oj62/P03o`000?o1YKgo`JFm00co`JFm00?o0000onG8
^ooUb;/01OoUb;/2o`0000?omMB/0_l00005ooODY`03o`000?odbj?o000000;on=BV00Ko0000ooC;
YOodbjGo0000ooOEZ?l00002oo7=Z`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0=?oo
ool002[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0oooooo`Go00000_l30004
o`0000KoeLgB00?o0000olRgbOo8]lT00_o8]lT6o`0000;o^jK40ol00005ok^Va0;o00002On^Vl@2
ocATd`04o`000?mhQMCoN8GDo`0000;oNWG100?o0000oge]]_mmKKH00ommKKH00ol0003oPFV_oh5Y
[`04oh5Y[`03o`000?n5JJ_oQFV[00CoQFV[00?o0000ohY[ZOn:JjT01On:JjT00ol0003oT72Zoi1`
ZP06oi1`ZP03o`000?nHMjgoV7N]00WoV7N]00?o0000oj62/_nQP[800onQP[800ol0003o`JFmol6U
_@0<ol6U_@03o`000?oUb;_oiLRk00KoiLRk0_l00002ooGD[003o`000?o`dkCommBW00CommBW00?o
0000ooC;Xol000000_ohe:H01?l0003om<^UooC;YOodbjD2o`0000ColLf[00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0cooooo`003oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo03cooooo1_l000000ol3003o0000o`000002om[Yg`03o`000?oEcM;oeLgB00?oeLgB
1ol00004olje`P03o`000?o3Y[co`jJl00Co`jJl1Ol0000=ojjKa005ocATdol0003o0000ogR5e?l0
00000_mjML400ol0003oOFffoge]]P03oge]]P03o`000?n1JJooPFV_00CoPFV_00?o0000ohEYZon5
JJ/01?n5JJ/00ol0003oRV^YohY[Z@05ohY[Z@03o`000?n@L:[oT72Z00KoT72Z00?o0000oiQg[OnH
Mjd02OnHMjd01Ol0003oXH:boj62/_nQP[;o000000ko`JFm00?o0000onG8^ooUb;/01_oUb;/01ol0
003omMB/o`000?oee:co0000oo3C]?l000001Ooge:L2o`0000?on=BV00Ko0000ooC;YOodbjGo0000
ooOEZ?l00004oo7=Z`;o00006?ooool2o`0003Gooooo000?ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo03Wooooo2Ol00003om[Yg`04o`000?oEcM;oeLgBomG=dP?o000000?oel[=o`00
0?o>]L801oo>]L800ol0003o`jJlol>V_008ol>V_004o`000?njWK[o^YfjokZM^P?o00002On^Vl@0
1?ldI=?o0000o`000?m2FlD2o`000003ogYe`Ol0003oOFff00CoOFff00?o0000oh5Y[on1JJl00on1
JJl00ol0003oQFV[ohEYZ`04ohEYZ`03o`000?n:JjWoRV^Y00KoRV^Y00?o0000oi1`Z_n@L:X01_n@
L:X00ol0003oV7N]oiQg[@09oiQg[@03o`000?nQP[;o000000oo`JFm00?o0000onG8^ooUb;/01_oU
b;/01?l0003omMB/o`000?l00002oo3C]003o`000?oge:OommBW00?ommBW0_l00003ooSDYP03o`00
0?odbjGo000000;ommFX00Go0000oo7=ZooacJ_olLf[o`000002ong>]@03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0<_ooool000Oooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@
41003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0=_ooool8o`0000Gof^WO00?o0000omG=d_l000000_l00003omO:c@03o`000?o>]L;oc[G200Ko
c[G200?o0000ol>V_?o3Y[`02?o3Y[`00ol0003o^YfjokZM^P05okZM^P?o00000on^Vl@3o`000004
oj6HboldI=?o0000od9Ka@;oDEVl0ol00005oge]]P03o`000?n1JJooPFV_00?oPFV_00?o0000ohEY
Zon5JJ/01?n5JJ/00ol0003oRV^YohY[Z@05ohY[Z@03o`000?n@L:[oT72Z00KoT72Z00?o0000oiQg
[OnHMjd02OnHMjd3o`0000ko`JFm00?o0000onG8^ooUb;/01_oUb;/00ol0003omMB/ooGD[002o`00
0003oo3C]?l0003ommBW00CommBW0_l00003ooSDYP03o`000?odbjGo000000;ommFX00Co0000oo7=
ZooacJ_olLf[0_l00003ong>]@03o`000?oooooooooo01Oooooo00?o0000ooooooooool0<Oooool0
00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0cooooo`?o000000?o3`00o`000?l000000_l00006
om[Yg`?o00001OoGb/d00ol0003oc[G2olje`P06olje`P03o`000?o3Y[co`jJl00So`jJl00?o0000
okZM^_njWKX02OnjWKX3o`0000GoXIS;00?o=6CCo`000?m2FlD00omAFK`2o`0000CoOFff00?o0000
oh5Y[on1JJl01?n1JJl00ol0003oQFV[ohEYZ`04ohEYZ`03o`000?n:JjWoRV^Y00GoRV^Y00?o0000
oi1`Z_n@L:X01_n@L:X00ol0003oV7N]oiQg[@07oiQg[@05o`000?n_T[Wo[i:iojnB^Ol000003?o1
YKd00ol0003oiLRkonG8^`07onG8^`07o`000?oee:co0000oo3C]?l0003ol=>do`000005ooODY`03
o`000?ohe:Kon=BV00;on=BV0_l00003ooOEZ003o`000?oacJ_olLf[00;o00001?o]c[D2o`0001So
oooo00?o0000ooooooooool0<Oooool000oooooo00Go0000ooooooooooooooooo`00000>ooooo`03
o`000?oooooooooo00Cooooo0_l0000=ooooo`03o`000?oooooooooo033ooooo0ol000000ol?003o
0000o`000002o`000003olWliOoJjMoof^WO00?of^WO0_l00007omO:c@03o`000?o>]L;oc[G200Ko
c[G200?o0000ol>V_?o3Y[`02?o3Y[`00ol0003o^YfjokZM^P09okZM^P05o`000?ncV;_o/iRkok>H
^ol000001OnQV</00ol0;KKo0000od9Ka@03oe5I_0;o00001?mmKKH00ol0003oPFV_oh5Y[`03oh5Y
[`03o`000?n5JJ_oQFV[00CoQFV[00?o0000ohY[ZOn:JjT01On:JjT00ol0003oT72Zoi1`ZP07oi1`
ZP03o`000?nHMjgoV7N]00GoV7N]00?o0000ojnB^On_T[T00on_T[T2o`0000[o`JFm00?o0000onG8
^ooUb;/01ooUb;/2o`0000;ol=>d0_l00006ooODY`07o`000?ohe:Kon=BVooSDY_l0003om<^Uo`00
0002ooOEZ006o`000?oacJ_olLf[o`000?odejoo00000oo]c[D00ol0003okmRjo`00000Iooooo`03
o`000?oooooooooo033ooooo000?ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0;Oooool7o`0000;o
bOcU00Co0000om[YgooJjMoof^WO1?l00007omO:c@03o`000?o>]L;oc[G200Koc[G200?o0000ol>V
_?o3Y[`02?o3Y[`00ol0003o^YfjokZM^P09okZM^P03o`000?ncV;_o/iRk00Co/iRk0_l00003oj6H
b`03o`0]]_l0003o@U_500CoDEVl0_l00003oge]]P03o`000?n1JJooPFV_00?oPFV_00?o0000ohEY
Zon5JJ/01?n5JJ/00ol0003oRV^YohY[Z@05ohY[Z@03o`000?n@L:[oT72Z00OoT72Z00?o0000oiQg
[OnHMjd00_nHMjd2o`0000So[i:i0_l00007ol6U_@03o`000?oUb;_oiLRk00OoiLRk0_l00003oo3C
]0;o00001Ooge:L00ol0003on=BVooSDYP02ooSDYP;o00000oogeJP01Ol0003olLf[o`000?odejoo
000000?okLje00Go0000onoH^_o_f;[ohlo3o`00000Iooooo`03o`000?oooooooooo02oooooo000?
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0:_ooool7o`0000?obOcU00?o0000om[Ygol000000_l0
0002om[Qg003o`000?oGb/goel[=00Goel[=00?o0000olje`_o>]L800oo>]L8?o`0000;o^Yfj00?o
0000okZM^_njWKX01_njWKX00ol0003o/iRkok>H^`07ok>H^`;o00000_nQV</2o`000004od9KaOmA
FKcoDEVloe5I_0;oH5bg0_l000000ommKKKo0000oh5Y[`04oh5Y[`03o`000?n5JJ_oQFV[00GoQFV[
00?o0000ohY[ZOn:JjT01On:JjT00ol0003oT72Zoi1`ZP06oi1`ZP05o`000?nHMjgoV7N]oiQg[Ol0
00003?n_T[T00ol0003o`JFmol6U_@03ol6U_@03o`000?oUb;_oiLRk00SoiLRk00?o0000oo3C]?o`
dk@00_o`dk@2o`0000CommBW0_l00004ooSDYP03o`000?ogeJSommFX00;ommFX00Go0000oo7=Zol0
003om=N_o`000002ong>]@03o`000?o_f;[okmRj00?ohlo300?o0000ooooooooool05Oooool2o`00
037ooooo000?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000006oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:?ooool3o`000003oh3Va?l0003o0000
00CobOcU0ol00004om[Qg003o`000?oGb/goel[=00Goel[=00?o0000olje`_l000001?l00003olnd
_`03o`000?o8Y[Sob:Jh00Sob:Jh00Co0000ol6M]?o1WKCo`Ifd1Ol00002okZM^P03o`000?ncV;_o
/iRk00[o/iRk0_l000001?l0;KKo02Vco`000?l00003oe5I_0?oH5bg0ol00005oh5Y[`03o`000?n5
JJ_oQFV[00CoQFV[00?o0000ohY[ZOn:JjT01On:JjT00ol0003oT72Zoi1`ZP07oi1`ZP03o`000?nH
Mjgo000000ko[i:i0_l00003ol6U_@03o`000?oUb;_oiLRk00CoiLRk1?l00005oo3C]003o`000?og
e:OommBW00;ommBW00?o0000ooOL[ol000000oohe:H00ol0003ommFXooOEZ002ooOEZ003o`000?oa
cJ_o000000;om=N_00?o0000ong>]Ol000000_o_f;X01Ol0003ohlo3on??`ooScl?o000001Wooooo
00?o0000ooooooooool0;_ooool002Wooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Uooooo`Ko00001?o9o>D2o`0000Kof^7L00?o0000omO:cOoGb/d00ooGb/d5o`0000OockBo00?o
0000olRV^?o8Y[P02?o8Y[P00ol0003o`Ifdol6M]007ol6M]0;o00003oncV;/00ol0003o02ffo`0Y
/`02o`0000?oDEVl1?mPG;L2o`0000GoPFV_00?o0000ohEYZon5JJ/01?n5JJ/00ol0003oRV^YohY[
Z@05ohY[Z@03o`000?n@L:[oT72Z00KoT72Z0_l0000AojnB^@04o`000?o1YKgo0000onG8^`Ko0000
0ooD^/000ol0003ol=>doo3C]003oo3C]007o`000?oge:OommBWooODYol0003ommb_o`000004ooSD
YP03o`000?ogeJSommFX00;ommFX0_l00002ooCG[`03o`000?o]c[Go000000;okmRj00?o0000on??
`ooScl<00_oScl<2o`0001Wooooo00?o0000ooooooooool0;Oooool002Sooooo0_l0000Cooooo`03
o`000?oooooooooo02;ooooo1Ol000000onNmN?o0000olWli@02olWli@?o00001_oJhM`00ol0003o
el[=omO:c@04o`0000;oeLG;00?o0000olnd_oo?];l01_o?];l00ol0003ob:JholRV^008olRV^003
o`000?o1WKCo`Ifd00So`Ifd00?o0000ok^H]?nkV;@00ol00009ok>H^`06o`000?n]V<;o[IS2ojfH
`_l0:K?o036f0_l00003oe5I_0GoH5bg0ol00002oh5Y[`03o`000?n5JJ_oQFV[00GoQFV[00?o0000
ohY[ZOn:JjT01?n:JjT00ol0003oT72Zoi1`ZP03oi1`ZP?o00000onMP[H00ol0003o[i:iojnB^@0>
ojnB^@?o00002?oD^/000ol0003ol=>doo3C]003oo3C]0;o00000_oge:L01?l0003ommb_ooOL[ol0
0003ooSDYP03o`000?ogeJSommFX00?ommFX00Co0000ooCG[oodejoom=N_0_l00002onoH^P04o`00
0?oScl?ohlo3on??``;o000000?odLgEo`000?ooool06?ooool00ol0003oooooooooo`0]ooooo`00
:?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01kooooo1_l00002oikeh`03o`00
0?o9o>Go000000;o000000?ocOCZo`000?oJhM`01OoJhM`4o`0000GoeLG;00?o0000olnd_oo?];l0
1_o?];l00ol0003ob:JholRV^008olRV^003o`000?o1WKCo`Ifd00So`Ifd00?o0000ok^H]?nkV;@0
1?nkV;@2o`0000Go/iRk0_l00005ojfH`P04o`0Y/ol0<KKo0000o`0000;oDEVl00?o0000of1L]omP
G;L00_mPG;L3ofmR]0Co00001_n5JJ/00ol0003oRV^YohY[Z@05ohY[Z@03o`000?n@L:[o000000;o
00001onMP[H00ol0003o[i:iojnB^@0=ojnB^@03o`000?oD^/3oe;[000Soe;[000?o0000oo3C]?o`
dk@01Ol000001Ooge:Oo0000ooOL[oogg:oo000000?on=BV0_l00004ooOEZ004o`000?odejoom=N_
ooCG[`;o00000oo_f;X2on??``;o000000Goi=W:om7=eOoAcMGodLgEo`00000Iooooo`03o`000?oo
oooooooo02cooooo000Xooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06_ooool3
o`000004od[7]ol0003o0000o`0000?oW_GS0ol00003olgdjP03o`000?oJhMcof^7L00?of^7L0ol0
0007omG5b`03o`000?o?];oockBo00KockBo00?o0000olRV^?o8Y[P02?o8Y[P00ol0003o`Ifdol6M
]008ol6M]003o`000?nkV;Co^iRd00Oo^iRd0ol000000oncV;_o0000ojfH`P07ojfH`P03o`000?l0
<KKo000000?oDEVl00?o0000of1L]omPG;L00_mPG;L5ofmR]0Ko00000_n5JJ/00ol0003oRV^YohY[
Z@02ohY[Z@Co00002onMP[H00ol0003o[i:iojnB^@0;ojnB^@03o`000?oD^/3oe;[000Soe;[01?l0
0003oo3C]003o`000?oge:Oo000000?ommb_00Ko0000ooSDY_ohe:Ko0000oo[T[?l00004ooOEZ005
o`000?odejoom=N_ooCG[ol000000oo_f;X3o`0000;oi=W:1OoAcMD00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo02_ooooo000Xooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool05_ooool3o`000004od[7]ol0003o0000o`0000GoW_GS0_l00004olgdjP04o`000?oJhMcof^7L
om[Qg0?o000000?oe]WKo`000?oEaL/01_oEaL/00ol0003ockBoolnd_`07olnd_`03o`000?o8Y[So
b:Jh00Oob:Jh00?o0000ol6M]?o1WK@02?o1WK@00ol0003o^iRdok^H]00;ok^H]003o`000?n]V<;o
[IS200So[IS200?o0000o`0a]_l000000omAFK`00ol0003oH5bgof1L]`02of1L]`GoKf:d00?o0000
ogi[/omnJk<00_mnJk<7o`0000?oSGJd00?o0000oif2]_nMP[H02_nMP[H00ol0003o[i:iojnB^@09
ojnB^@03o`000?oD^/3oe;[000Ooe;[00ol00005oo3C]007o`000?oge:Oo0000ooOL[ol0003ommb_
o`000003ooSDYP;o00001?ogeJP01Ol0003om=N_ooCG[oodejoo000000?okmRj0_l00003onCIbPKo
dLgE00?o0000ooooooooool05_ooool2o`0000Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01oooool0
02Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Booooo`?o000000?oB/Ngo`00
0?l000000_l00004oikeh`?o00001Oo=m>X00ol0003of^7Lo`000002o`0000?oe]WK00?o0000omG5
booEaL/01_oEaL/00ol0003ockBoolnd_`06olnd_`03o`000?o8Y[Sob:Jh00Oob:Jh00?o0000ol6M
]?o1WK@02?o1WK@00ol0003o^iRdok^H]00:ok^H]004o`000?ngU[Ko]iJfokNF]P?o00001_n]V<80
1?l0:K?o0000o`0a]_l00003oe5I_005o`000?mPG;OoH5bgof1L]ol000001Om_H[@00ol0003oOV^c
ogi[/`04ogi[/`03o`000?n=M[CoSGJd00GoSGJd00?o0000oif2]_nMP[H02_nMP[H00ol0003o[i:i
ojnB^@08ojnB^@03o`000?oD^/3oe;[000Coe;[00ol000000ooD^/3o0000oo3C]005oo3C]0;o0000
0oogg:l2o`0000;on=BV00?o0000oo[T[?l000000oogeJP2o`0000?om=N_00Co0000onoH^_o_f;[o
00001?oTfLX3om7=e@Ko00006Oooool00ol0003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`06oooo
o`00:?ooool00ol0003oooooooooo`0Gooooo`;o00004?ooool2o`000003od[7]ol0003o000000;o
N^CX00?o0000oikehonNmN<01?l000000on`lo?ocOCZolgdjP04olgdjP?o00001OoFfM/00ol0003o
eLG;omG5b`06omG5b`03o`000?o?];oockBo00KockBo00?o0000olRV^?o8Y[P00_o8Y[P;o`0000Go
`Ifd00?o0000ok^H]?nkV;@02_nkV;@00ol0003o]iJfokNF]P05okNF]P;o00001On]V<801?l0:K?o
0000o`0a]_l00002oe5I_003o`000?mPG;OoH5bg00;oH5bg00?o0000ofmR]?m_H[@00om_H[@00ol0
003oOV^cogi[/`04ogi[/`03o`000?n=M[CoSGJd00GoSGJd00?o0000oif2]_nMP[H02_nMP[H00ol0
003o[i:iojnB^@06ojnB^@03o`000?oD^/3oe;[000;oe;[00ol00003omBj`003o`000?o`dkCol=>d
00Gol=>d00?o0000ooOL[oogg:l00_ogg:l2o`000005ooSDY_l0003on^B/oo[T[?l000000_ogeJP2
o`0000?om=N_00Go0000onoH^_o_f;[okmRjo`000002onCIbPGo00001?o?e=d00on_`^So0000oooo
o`0Iooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool01Oooool002Oooooo0_l0000Kooooo`03o`000?oo
oooooooo00_ooooo0ol00004og[Tj0Go00000_n`lo<2o`0000CocOCZ0ol00007omKIf`03o`000?oE
aL_oeLG;00KoeLG;00Co0000olnd_oo?];oockBo2ol00005olVV]@03o`000?o4W[7oa9ja00?oa9ja
1ol0000:ok^H]003o`000?ngU[Ko]iJf00So]iJf0ol000001?n]V<;o0000o`000?l0:K<2o`0a]P;o
000000?oDEVlo`000?mPG;L00omPG;L00ol0003oKf:dofmR]002ofmR]003o`000?mnJk?oOV^c00Go
OV^c00?o0000ohef]?n=M[@01On=M[@00ol0003oWH:foif2]P0:oif2]P03o`000?n_T[Wo[i:i00Co
[i:i00?o0000omBj`?oD^/000ol00006omBj`003o`000?o`dkCol=>d00?ol=>d0_l00005ooOL[`?o
00000_oji:`01?l0003ommFXooOEZ?ogeJP2o`0000;om=N_0_l00002onoH^P04o`000?oTfL[oi=W:
om7oaPKocmCM1On_`^P00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01_oo
ool002Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`?o000000?oN^CX
o`000?l000001Ol00005ok3cl`03o`000?o=m>[ocOCZ00Co000000?ob^S/o`000?oFfM/01ooFfM/0
0ol0003oeLG;omG5b`03omG5b`Oo00001Oo>/Kd00ol0003obJJeolVV]@07olVV]@03o`000?o4W[7o
a9ja00Soa9ja00?o0000ol2H[oo0V:l00ol00006ok^H]003o`000?ngU[Ko]iJf00co]iJf00Ko0000
oj^Oc?n[WlcoZio<o`0Y/ol0<KH2oa]1^`03o`000?mAFKco000000?oH5bg00?o0000ofmR]?m_H[@0
0om_H[@00ol0003oOV^cogi[/`04ogi[/`03o`000?n=M[CoSGJd00KoSGJd00?o0000oif2]_nMP[H0
2_nMP[H00ol0003o[i:iojnB^@02ojnB^@Co00002?oD^/000ol0003ol=>doo3C]002oo3C]0;o0000
00?oi];2o`000?ogg:l01?ogg:l3o`0000;on^B/00?o0000ooOEZ?ogeJP00_l00002ooCG[`;o0000
0_o_f;X01?l0003oi=W:onCIb_oAolH5oloDg@Go00000on_`^P00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c007ooooo`009oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00?ooooo1ol00002oiSVo0;o00001on`lo<4o`0000Cob^S/00?o0000omKI
fooFfM/01_oFfM/00ol0003oeLG;omG5b`04o`0000;odL;;00?o0000olja_Oo>/Kd01_o>/Kd00ol0
003obJJeolVV]@07olVV]@03o`000?o4W[7oa9ja00Soa9ja00?o0000ol2H[oo0V:l01?o0V:l3o`00
00;o^iRd00?o0000okNF]_ngU[H02ongU[H01?l0003o]IVkokFI^oneVK/4o`000006o`0a]_lK@K_o
6d6ko`000?mAFKco00000omPG;L00ol0003oKf:dofmR]003ofmR]003o`000?mnJk?oOV^c00CoOV^c
00?o0000ohef]?n=M[@01_n=M[@00ol0003oWH:foif2]P0:oif2]P03o`000?n_T[Wo000000;o0000
2ooD^/000ol0003ol=>doo3C]002o`0000;oi];200?o0000ooOL[oogg:l00oogg:l01?l0003on=BV
o`000?oji:`2o`0000;ommFX00Ko0000ooW/Zol0003om=N_o`000?ocljd2onoH^P04o`000?oTfL[o
i=W:om7oaP?ocmCM00?o0000oj_5kOn[aNd01On[aNd5o`0001Wooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`09ooooo`009oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo000000;o00001onH
i_`2o`0000?o/??c1ol00006ol[Xk003o`000?oFfM_oe]WK00Koe]WK1?l00005om72b`03o`000?o>
/Kgoc[6m00Koc[6m00?o0000olVV]Oo9Y[D01oo9Y[D00ol0003oa9jaolBN/@08olBN/@03o`000?o0
V:oo`9R_00So`9R_0_l0000<okNF]P;o00001oneVK/2o`000003o`0a]_lK@K_o6d6k00;o00001?mP
G;L00ol0003oKf:dofmR]002ofmR]003o`000?mnJk?oOV^c00GoOV^c00?o0000ohef]?n=M[@01_n=
M[@00ol0003oWH:foif2]P08oif2]P?o000000?o[i:io`000?oD^/002_oD^/001?l0003ol=>doo3C
]?l00004onKB`P03o`000?ogg:oommb_00?ommb_0_l00002oo[T[0;o000000commFXo`000?oik:_o
0000ooCG[ol0003olo>]o`000?o_f;[o0000onCIb_l00003oloDg@03oj[igOn[aNgoZlG]00?oZlG]
0_mfZ?43o`0000?oN:Sa00?o0000ooooooooool05Oooool3o`0000Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`09oooo
o`009oooool00ol0003oooooooooo`0Looooo`?o000000?oV>Klo`000?l000001ol000000on`lo?o
0000o`000002o`0000?o/nOg00?o0000ol[Xk?o:j>`01_o:j>`00ol0003oe]WKomKIf`03omKIf`Go
00001ooA`//00ol0003oc[6molja_@06olja_@03o`000?o9Y[GobJJe00OobJJe00?o0000olBN/Oo4
W[402?o4W[400ol0003o`9R_ol2H[`0:ol2H[`03o`000?nmUZoo_IJ_00?o00001_ngU[H00ol0003o
]IVkokFI^`08okFI^`03o`0Y/ol0003o036f00?o6d6k00Go0000of1L]omPG;OoH5bgo`000005ofmR
]003o`000?mnJk?oOV^c00CoOV^c00?o0000ohef]?n=M[@01_n=M[@00ol0003oWH:foif2]P05oif2
]P?o00000_nMP[H5o`0000Soe;[000Co0000oo3C]?l0003o00001?oVd/800ol0003ommb_ooOL[`04
ooOL[`03o`000?oji:con^B/00;on^B/0_l00002ooW/Z`05o`000?odejoo0000o`000?o_f;X00_l0
00001OoAolKocmCMoloDgOnZnMgo000000;oQ8kE00?o0000oealfOmLO=T00_m0O^@4ogJXl@?o0000
00?oN:Sao`000?ooool06?ooool02Ol0003oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`Go00001?ooool4o`0000Sooooo000Wooooo`03o`000?oooooooooo01Wooooo0ol00009ojCJ
nP;o00002?ncioL00ol0003ob^S/ol[Xk007ol[Xk003o`000?oFfM_o000000Co00000_o?dM/00ol0
003odL;;om72b`06om72b`03o`000?o>/Kgoc[6m00Koc[6m00?o0000olVV]Oo9Y[D02?o9Y[D00ol0
003oa9jaolBN/@07olBN/@03o`000?o0V:oo`9R_00[o`9R_00?o0000okfF[onmUZl01?nmUZl3o`00
00;o]iJf00?o0000okFI^oneVK/02_neVK/00ol0003o036fo`000003oa]1^`05o`000?mPG;OoH5bg
of1L]ol000001Om_H[@00ol0003oOV^cogi[/`04ogi[/`03o`000?n=M[CoSGJd00KoSGJd00Co0000
oif2]_nMP[KoWH:f0ol00004oif2]P03o`000?noZLCo_jW400?o_jW41Ol00003omBj`0;o00001_oV
d/800ol0003ommb_ooOL[`02ooOL[`;o00001?oji:`02?l0003ommFXo`000?oik:_o0000ooCG[ol0
003olo>]0_l000001?oWnkKodOo6oj[igOnZnMd3oi29b0?o000000KoQ8kEoealfOmLO=WoG7cIod1n
i?l>KMh2ocn3j0?oMZSa0ol0000Hooooo`03o`000?oooooooooo02Kooooo000Vooooo`;o00006Ooo
ool2o`0000_oY=[j00?o0000ok?WmoncioL01_ncioL2o`0000?ob^S/2Ol00006oloAf`03o`000?oA
`/_odL;;00KodL;;00?o0000olja_Oo>/Kd01oo>/Kd00ol0003obJJeolVV]@07olVV]@03o`000?o4
W[7oa9ja00Soa9ja00?o0000ol2H[oo0V:l02Oo0V:l00ol0003o_IJ_okfF[`08okfF[`;o00003_ne
VK/00ol0003o036fo`000003oa]1^`;o000000?oH5bgo`000?m_H[@01?m_H[@00ol0003oOV^cogi[
/`05ogi[/`03o`000?n=M[CoSGJd00KoSGJd0ol00006oif2]P03o`000?noZLCo_jW400Wo_jW40ol0
0007onKB`P03o`000?ogg:oommb_00;ommb_00?o0000oo;Y_ol000001?oji:`3o`000004ooW/Zol0
003o0000oo?c[@;o000000?oio^fom7oa_nZnMd01_n@RLP2og1md0?o00000_mLO=T01?lXHmKo5V;H
o`i]g_loPnP2o`0000;o=WoW00?oMZSao`000?ooool05oooool00ol0003oooooooooo`0Uooooo`00
9_ooool00ol0003oooooooooo`0Fooooo`;o00000_nTf_X4o`0000GoY=[j0_l00003ok?Wm`_o0000
1Oo3fn/9oloAf`03o`000?oA`/_odL;;00OodL;;00?o0000olja_Oo>/Kd01_o>/Kd00ol0003obJJe
olVV]@07olVV]@03o`000?o4W[7oa9ja00Soa9ja00?o0000ol2H[oo0V:l02Oo0V:l00ol0003o_IJ_
okfF[`0:okfF[`03o`000?nkUk;o000000;o00002OneVK/01?l0003o]j32o`000?l0<KH3oa]1^`;o
@5G100?o0000of1L]ol000001Om_H[@00ol0003oOV^cogi[/`04ogi[/`03o`000?n=M[CoSGJd00?o
SGJd0ol000000on=M[Co0000oif2]P04oif2]P;o00003_noZL@00ol0003oi];2onKB`P05onKB`P05
o`000?ogg:oommb_ooOL[ol000000_objKl5oo[T[003o`000?oik:_onNb[00;o000000Golo>]o`00
0?l0003oio^fom7oaP03ojF@_`KoT8W800Co0000og1md?m`OM3oL7g@0_l000001_mLO=Wo:6?FoaIR
f?l0003o5F?Hocn3j0;o000000?o=WoWo`000?ooool06?ooool00ol0003oooooooooo`0Tooooo`00
9_ooool00ol0003oooooooooo`0Cooooo`?o00002?nWc_@5o`000003ok?Wmol0003o000000;o0000
0onafOD00ol0003o`m_[ol?Kj`07ol?Kj`;o00002Oo?dM/00ol0003odL;;om72b`07om72b`03o`00
0?o>/Kgoc[6m00Koc[6m00?o0000olVV]Oo9Y[D00_o9Y[D;o`0000Goa9ja00?o0000ol2H[oo0V:l0
2_o0V:l00ol0003o_IJ_okfF[`09okfF[`03o`000?nkUk;o^iNb00?o^iNb0ol00005okFI^`06o`00
0?ngX<;o]j32okNP`_l0003o036f0olK@K/2od1E`@?o00001Om_H[@00ol0003oOV^cogi[/`04ogi[
/`03o`000?n=M[Co000000;o00001On=M[@01Ol0003oWH:foif2]_nMP[Ko000000oo_jW400?o0000
onKB`_oVd/801OoVd/801Ol0003ommb_ooOL[oogg:oo000000;ol^Vo00?o0000oo[T[?oji:`00_oj
i:`01?l0003onNb[ooW/Zooik:/2o`000004oo?c[Ol0003oio^fo`0000GoYI2o00?o0000oi29b?n@
RLP00on@RLP00ol0003oL7g@og1md002og1md0?o000000So:6?FoaIRf?lEHmSo5F?Hocn3j?l0003o
=WoWo`0001Sooooo0_l0000Uooooo`009_ooool00ol0003oooooooooo`0@ooooo`?o00003?nWc_@2
o`0000Wo/MWe00?o0000ol?Kjoo3fn/01oo3fn/00ol0003ocm7KoloAf`08oloAf`03o`000?oA`/_o
dL;;00OodL;;00Co0000olja_Oo>/Kgoc[6m2ol00005olVW]`03o`000?o5W:koaIb^00?oaIb^2?l0
0009ol2H[`03o`000?nmUZoo_IJ_00Wo_IJ_00?o0000ok^G/_nkUk801onkUk83o`000003okFI^ol0
003o]j3200?o]j320ol00003oa]1^`?o@5G100?o0000ofmR]?m_H[@00om_H[@00ol0003oOV^cogi[
/`03ogi[/`?o00002On=M[@00ol0003oWH:fo`00000?oknYa003o`000?oVd/;oi];200Koi];200Co
0000ooOL[oogg:oo00000_objKl00ol0003on^B/oo[T[003oo[T[004o`000?oik:_onNb[o`0000;o
lo>]00?o0000onOk]_l000002?nUT;l00ol0003oT8W8oi29b003oi29b006o`000?m`OM3oL7g@og1m
d?lmJMCo00000_lXHmH01?lFH]So0000o`000?loPnP3o`0001Oooooo0_l0000Uooooo`009_ooool0
0ol0003oooooooooo`0>ooooo`;o00001OnXanl5o`0000?oYlkd0_l0000:ok7Im@03o`000?o3fn_o
`m_[00Oo`m_[00?o0000oloAfoo?dM/02?o?dM/00ol0003odL;;om72b`02om72b`[o00001Oo;[[d0
0ol0003obJNgolVW]`07olVW]`03o`000?o5W:koaIb^00SoaIb^00Co0000ol:HZoo2V:_o`YR[1Ol0
0003ol2H[`03o`000?nmUZoo_IJ_00Wo_IJ_00?o0000ok^G/_nkUk802onkUk800ol0003o]j32okNP
`P04okNP`P?o00000_lK@K/01Ol0003o@5G1od1E`Om0EL7o000000GoKf:d00?o0000ogi[/ol00000
0_l00002ogi[/`03o`000?n=M[CoSGJd00OoSGJd0_l0000@oknYa003o`000?oVd/;oi];200Koi];2
00?o0000ooOL[ol000000oobjKl00ol0003on^B/oo[T[002oo[T[005o`000?oik:_onNb[ooW/Zol0
00000_ocljd00ol0003oio^fok:C^002o`0000SoYI2o00?o0000oi29b?n@RLP00_n@RLP01Ol0003o
L7g@og1md?m`OM3o?FWD00;o000000?o:6?Fo`000?lFH]P00_l000000oloPnSo0000ooooo`0Hoooo
o`03o`000?oooooooooo02;ooooo000Vooooo`03o`000?oooooooooo00cooooo0_l0000<ojS7k`?o
000000?o/MWeo`000?l000000ol00005ok7Im@03o`000?o3fn_o`m_[00;o`m_[5_l00005olZibP03
o`000?o;[[gobjjm00Kobjjm00?o0000olVW]oo9YkL01oo9YkL00ol0003oaIb^olFL[P08olFL[P03
o`000?o2V:_o`YR[00Oo`YR[1Ol0000:okfF[`03o`000?nkUk;o^iNb00[o^iNb00Co0000ok^J]_nk
V[Ko^iZf0ol00002okNP`P?o00000_lK@K/01?l0003o@5G1od1E`Om0EL42o`0000;oKf:d0ol00006
ogi[/`03o`000?n=M[CoSGJd00CoSGJd0_l00003ojJGaP;o00003?noZL@00ol0003oi];2onKB`P06
onKB`P03o`000?ogg:oo000000?ol^Vo00?o0000oo[T[?oji:`00_oji:`2o`0000;onNb[00Ko0000
oo?c[Oocljgo0000onOk]_l00003ok:C^0;o00001?nUT;l6o`0000;oT8W800Ko0000og1md?m`OM3o
L7g@o`000?lmJM@3o`000003o`18b?l0003o000000;o00006?ooool00ol0003oooooooooo`0Roooo
o`009Oooool3o`0000[ooooo0ol0000<ojS7k`?o00002?n_bNd5o`000003ol?Kjol0003o000000;o
00000onkc^T00ol0003oaLWMolG9g@08olG9g@03o`000?o:^L[ob[W:00Wob[W:00?o0000ol^^_Oo;
[[d01_o;[[d00ol0003obJNgolVW]`08olVW]`03o`000?o5W:koaIb^00SoaIb^00?o0000ol:HZoo2
V:/02Oo2V:/00ol0003o`IR]ol6H[@03o`0000Ko_IJ_00?o0000ok^G/_nkUk802_nkUk800ol0003o
^iZfok^J]P05ok^J]PKo00000_lK@K/00ol0003o@5G1od1E`@05o`000003ofmR]?l0003oOV^c00Go
OV^c00?o0000ohef]?n=M[@00_n=M[@2o`0000OoYYO600?o0000oknYa?noZL@02?noZL@00ol0003o
i];2onKB`P07onKB`P;o00001?objKl01?l0003on^B/oo[T[?oji:`2o`0000;onNb[0_l000000ooc
ljgo0000onOk]P02ok:C^003o`000?nbTkSo/Y>h00;o/Y>h1?l00005oiR8`003ogn0b_l0003o0000
00;o00000om`OM000ol0003o?FWDoceYe002o`000004o`18b?l0003o0000o`0001Wooooo00?o0000
ooooooooool08Oooool002Gooooo00?o0000ooooooooool01oooool3o`0000WoZ<7/1_l0000;ojo9
k@?o00002?nkc^T2o`0000[oaLWM00?o0000olZib_o:^LX02Oo:^LX00ol0003objjmol^^_@07ol^^
_@03o`000?o9YkOobJNg00OobJNg00?o0000olFL[_o5W:h02?o5W:h00ol0003o`YR[ol:HZ`09ol:H
Z`03o`000?o1V:go`IR]00Co`IR]0ol00002okfF[`03o`000?nkUk;o^iNb00[o^iNb00?o0000ok^J
]_nkV[H02OnkV[H3o`0000;o6d6k00?o0000od1E`Ol000000_l00003ofE/a@?o00001_mnJk<01?l0
003oSGJdo`000?l0000:ojJGaP;o00002?noZL@00ol0003oi];2onKB`P06onKB`P;o00001?objKl0
2?l0003on^B/oo[T[?oji:co0000ongh/_l0003onNb[0_l000000oocljgo0000o`000004ok:C^0?o
00000onXSKP8oiR8`0?oOh3:0ol00002og1md003o`000?lmJMCo?FWD00?o000000?o036go`000?l0
00006Oooool00ol0003oooooooooo`0Pooooo`006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool01Oooool2o`0000coZ<7/0ol00005ojc1j@Go00000_n_bNd2o`0000[o
^lkY00?o0000olG9gOo5bMd02Oo5bMd00ol0003ob[W:olZibP09olZibP03o`000?o;[[gobjjm00Oo
bjjm00?o0000olVW]oo9YkL01oo9YkL00ol0003oaIb^olFL[P09olFL[P03o`000?o2V:_o`YR[00So
`YR[00?o0000ol6H[Oo1V:d02?o1V:d4o`0000[o^iNb00?o0000ok^J]_nkV[H02_nkV[H2o`000003
o`00Rol0003o000000;o00000om0EL400ol0003oIFc5ofE/a@03ofE/a@So00003_nVUlH2o`0000Go
_jW400?o0000onKB`_oVd/801ooVd/800ol0003ol^Vooo;Y_`03oo;Y_`06o`000?oji:con^B/o`00
0?o]n;;o00000_oik:/00oo<l9Ko0000oo?c[@02o`0000Co/Y>h00?o0000ojR=^?nXSKP01?nXSKP0
0ol0003oV8S0oiR8`005oiR8`003o`000?moP<[oOh3:00;oOh3:1?l00002oceYe0?o000000?o036g
o`000?l000006?ooool00ol0003oooooooooo`0Pooooo`006_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool02Oooool5o`0000?oZ<7/0_l0000=ojc1j@;o000000?o^lkY
o`000?l000000ol00005ok_>j@03o`000?o5bMgoaLWM00WoaLWM00?o0000olZib_o:^LX02Oo:^LX0
0ol0003objjmol^^_@07ol^^_@03o`000?o9YkOobJNg00SobJNg00?o0000olFL[_o5W:h02?o5W:h0
0ol0003o`YR[ol:HZ`09ol:HZ`03o`000?o1V:go`IR]00Wo`IR]00?o0000okjDZonnU:/00ol00006
ok^G/P03o`000?nkV[Ko^iZf00[o^iZf00?o0000okjN^Ol000000ol00002oa]1^`05o`000?m0EL7o
@5G1od1E`Ol000001?mUK<D00ol0003oQh;6ohN2aP06ohN2aP03o`000?nVUlKoYYO600coYYO600?o
0000oknYa?noZL@00_noZL@00ol0003oi];2onKB`P03onKB`PCo00001_objKl00ol0003on^B/o`00
0002ongh/P07o`000?oik:_o0000o`000?ocljgo0000onOk]P02o`000005ok:C^?l0003o0000ojR=
^?l000001onXSKP00ol0003oV8S0oiR8`004oiR8`003o`000?moP<[oOh3:00;oOh3:0_mCL]@2o`00
00;o?FWD00Co04c;o`000?l0003o036g0_l0000Fooooo`03o`000?oooooo0000027ooooo000Joooo
o`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`0>ooooo`?o00003On/`NT2
o`0000So[lS/2ol00005olG9g@03o`000?o:^L[ob[W:00Wob[W:00?o0000ol^^_Oo;[[d02?o;[[d0
0ol0003obJNgolVW]`07olVW]`03o`000?o5W:koaIb^00SoaIb^00?o0000ol:HZoo2V:/02Oo2V:/0
0ol0003o`IR]ol6H[@09ol6H[@03o`000?nnU:_o_YB[00Co_YB[0ol00002ok^G/P03o`000?nkV[Ko
^iZf00[o^iZf0ol00002okjN^@05o`000?l008_o0000oa]1^ol000000om0EL400ol0003oIFc5ofE/
a@03ofE/a@03o`000?n7P/KoQh;600KoQh;600?o0000ojJGa_nVUlH03?nVUlH2o`000003oknYa?l0
003oi];200Go00000ooCc=800ol0003ol^Vooo;Y_`03oo;Y_`03o`000?oji:co000000;okORb00Oo
0000ooW/Zol0003o0000oo?c[Ol0003oio^f00?o^YJc0_l00003ojR=^003o`000?nXSKSoZ8fh00Go
Z8fh00?o0000oiR8`?nHR<001?nHR<000ol0003oOh3:ogn0bP02ogn0bP?oDg;D0_l000001_lmJMCo
04c;o`000?l0003o036go`0001Wooooo00?o0000ooooooooool07_ooool001[ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo01Cooooo1Ol00003ojc1j@;o00003?n_b>`0
0ol0003o^L3OokW0g`06okW0g`_o00001Oo:^LX00ol0003objjmol^^_@08ol^^_@03o`000?o9YkOo
bJNg00SobJNg00?o0000olFL[_o5W:h02?o5W:h00ol0003o`YR[ol:HZ`08ol:HZ`03o`000?o1V:go
`IR]00Wo`IR]00?o0000okjDZonnU:/02?nnU:/4o`0000So^iZf0ol00006okjN^@?o000000?o6d6k
o`000?m0EL400_m0EL400ol0003oIFc5ofE/a@03ofE/a@03o`000?n7P/KoQh;600KoQh;600?o0000
ojJGa_nVUlH03OnVUlH3o`0000OodlcB00?o0000oo;Y_oobjKl01?objKl2o`0000?okORb00?o0000
ooW/Zoo<l9H00ol00003okZF/`03o`000?ncT;;o/i2b00;o00000_nXSKP00ol0003oZ8fhojR=^005
ojR=^0;o00001OnHR<000ol0003oOh3:ogn0bP02ogn0bP03o`000?mCL]CoDg;D00;o000000Ko?FWD
o`1<bol0003o0000o`0a]ol0000Hooooo`03o`000?oooooooooo01kooooo000Jooooo`05o`000?oo
ooooooooooooool000001Oooool3o`0001[ooooo0ol0000<ojo8k0;o00002oni`=l00ol0003o_kWD
oknie006oknie1Go00001Oo9YkL00ol0003oaIb^olFL[P08olFL[P03o`000?o2V:_o`YR[00So`YR[
00?o0000ol6H[Oo1V:d02Oo1V:d00ol0003o_YB[okjDZ`0:okjDZ`03o`000?nnUJgo_YF]00?o0000
0_nkV[H3o`000003ok^J]_l0003o_Yji00Ko_Yji00Go001fo`000?l0003o6d6ko`000004od1E`@03
o`000?mUK<GoIFc500?oIFc500?o0000ohN2a_n7P/H01_n7P/H00ol0003oYYO6ojJGaP0:ojJGaP03
o`000?oCc=;odlcB00WodlcB00?o0000oo;Y_oobjKl00oobjKl2o`0000CokORb00Go0000olc`U_l0
003olo>]o`000003okZF/`03o`000?ncT;;o/i2b00?o/i2b0ol00009ojR=^003o`000?nHR<3oV8S0
00?oV8S000?o0000ogn0b_moP<X00_moP<X00ol0003oDg;Doe=be003o`000005o`1<bol0003o0000
o`0a]ol000006?ooool00ol0003oooooooooo`0Mooooo`006_ooool01Ol@413ooooooooooooooooo
410@00Gooooo00?o0000ooooooooool08?ooool5o`0000?o[lS/00?o0000okW0goni`=l02Oni`=l2
o`0000_o_kWD00?o0000olBicoo4^Ll02Oo4^Ll00ol0003o`jFlol>U_004ol>U_0_o00001Oo5W:h0
0ol0003o`YR[ol:HZ`08ol:HZ`03o`000?o1V:go`IR]00So`IR]00?o0000okjDZonnU:/02_nnU:/0
0ol0003o_YF]okjE[@03okjE[@Co00000_nkV[H00ol0003o_YjiokjN^@07okjN^@?o000000?o6d6k
o`000?m0EL400om0EL400ol0003oIFc5ofE/a@03ofE/a@03o`000?n7P/KoQh;600KoQh;60_l00009
ojJGaP03o`000?oCc=;odlcB00WodlcB00?o0000oo;Y_oobjKl01?objKl00ol0003okORbongh/P02
ongh/P;o000000?oc?2Fo`000?l000000onjU[<00ol0003o/i2bok>@/P06ok>@/P;o00001onXSKP7
o`000003oiR8`?l0003oOh3:00?oOh3:00Oo0000oe=be?mCL]Co0000oa5Id_l0003o04c;00;o0000
00?o036go`000?ooool05oooool00ol0003oooooooooo`0Looooo`006_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo00?o0000ooooooooool09Oooool3o`0000;o^L3O1?l00005okW0g`03o`00
0?no^MCo_kWD00Wo_kWD0_l0000;olBic`03o`000?o3YKco`jFl00Wo`jFl00?o0000ol>Q]_o3XKH0
1?o3XKH:o`0000Go`YR[00?o0000ol6H[Oo1V:d02Oo1V:d00ol0003o_YB[okjDZ`09okjDZ`04o`00
0?nnUJgo_YF]okjE[@?o00001?nnUJd5o`0000So_Yji0ol000000olK@K_o0000od1E`@02od1E`@03
o`000?mUK<GoIFc500CoIFc500?o0000ohN2a_n7P/H01on7P/H00ol0003oYYO6ojJGaP05ojJGaP03
o`000?oCc=;odlcB00WodlcB00?o0000oo;Y_oobjKl00oobjKl2o`0000GokORb00?o0000olc`U_l0
00000_l00002okZF/`03o`000?ncT;;o/i2b00Wo/i2b0_l00002ojR=^0?o00001?nORK`3oh^5aPGo
00000_moP<X01?l0003oDg;Doe=be?l00002oa5IdPCo00005oooool2o`0001kooooo000Jooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0^ooooo`Go00000_no^M@00ol0
003o_kWDoknie006oknie003o`000?o4^Looa;W?00[oa;W?00?o0000ol>U_?o3YK`02Oo3YK`00ol0
003o`j6fol>Q]P09ol>Q]P03o`000?o3XkSo`j>h00?o`j>h2?l00008ol6H[@03o`000?nnU:_o_YB[
00Wo_YB[00?o0000okjE[Ol000000_l00008okjE[@04o`000?noVk?o_i^coknK/`Go00000_nnW[T0
1_l0003o`JJmo`000?l0003o02N`o`0000Co@5G100?o0000ofE/aOmUK<D01?mUK<D00ol0003oQh;6
ohN2aP07ohN2aP03o`000?nVUlKoYYO600?oYYO600?o0000om?<d_oCc=802_oCc=800ol0003ol^Vo
oo;Y_`02oo;Y_`03o`000?oNmm_o000000CokORb00?o0000olc`U_o<l9H00_l00002okZF/`03o`00
0?ncT;;o/i2b00_o/i2b0ol00008oin9_003o`000?n;QLKoRhG600?oRhG600?oJ7gDo`000?l00000
0_l00002oe=be003o`000?lAFM;o4EWB00Co00006?ooool00ol0003oooooooooo`0Kooooo`009?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooo000000Co00000_no^M@00ol0003oa;W?olBi
c`0:olBic`03o`000?o3YKco`jFl00Wo`jFl00?o0000ol>Q]_o3XKH02Oo3XKH00ol0003o`j>hol>S
^008ol>S^004o`000?o0VJoo`9V_ol2I[`Go00000_o1V:d00ol0003o_YB[okjDZ`09okjDZ`?o0000
2_nnUJd00ol0003o_i^coknK/`07oknK/`Oo000000?o02N`o`000?m0EL400om0EL400ol0003oIFc5
ofE/a@03ofE/a@03o`000?n7P/KoQh;600SoQh;600Go0000ojJGa_nVUlKoYYO6o`00000<om?<dP04
o`000?objKool^Vooo;Y_`;o000000?og_OKo`000?o]n;801?o]n;801Ol0003oc?2Fo`000?l0003o
_iN^00;o00003OncT;82o`0000;o[8fe2OnORK`00ol0003oRhG6oh^5aP03oh^5aP?oJ7gD0ol00000
1OmCL]Co0000oa5Id_l0003o03o100?o00006?ooool00ol0003oooooooooo`0Jooooo`009?ooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo00?ooooo0_l000000oo4^Loo0000o`000009
olBic`03o`000?o3YKco`jFl00Wo`jFl00?o0000ol>Q]_o3XKH02Oo3XKH00ol0003o`j>hol>S^008
ol>S^003o`000?o0VJoo`9V_00Oo`9V_1?l00007okjDZ`Co00002onnUJd00ol0003o_i^coknK/`09
oknK/`04o`000?o1WK?o`Ifcol6M/`?o000000?o02N`o`000?l000000om0EL400ol0003oIFc5ofE/
a@03ofE/a@03o`000?n7P/KoQh;600SoQh;600?o0000ojJGa_l000003OoCc=801?l0003ol^Voo`00
0?l00003omkgf`04o`000?o]n;;okORbongh/P;o000000?oc?2Fo`000?l000000onoUjh00ol0003o
^Y>^o`000002o`0000So/i2b00Co0000ojb=]On/SKGo00000_n/SKD2o`0000OoWhVl00?o0000oh^5
a_n;QLH00on;QLH01?l0003oJ7gDofQme?mXOM@2o`000005oe=be?l0003o4EWBo`000?l0?l400_l0
000Hooooo`03o`000?oooooooooo01[ooooo000Sooooo`?o0000=oooool00ol0003oooooooooo`07
ooooo`Go00000oo4^Ll00ol0003o`jFlol>U_009ol>U_003o`000?o3XKKo`j6f00Wo`j6f00?o0000
ol>S^?o3XkP02?o3XkP00ol0003o`9V_ol2I[`09ol2I[`03o`000?noVK3o_iV`00?o000000Co_YB[
o`000?l0003o00000_nnU:/00ol0003o_YF]okjE[@09okjE[@03o`000?noVk?o_i^c00Wo_i^c00?o
0000ol6M/oo1WK<00oo1WK<4o`000005oaEQf?l0003o0000od1E`Ol000001_mUK<D00ol0003oQh;6
ohN2aP07ohN2aPCo00002ooCc=800ol0003ol^Voo`000004omkgf`06o`000?o]n;;okORbongh/_l0
003oY>bU0ol00003oknG[P03o`000?njTjko^Y>^00?o^Y>^0_l00005ok>@/P03o`000?n/SKGo[8fe
00;o[8fe00Go0000ojb=]On/SKGo[8feo`000007oin9_003o`000?n;QLKoRhG600?oRhG600Co0000
ofQme?mXOMCoJ7gD1?l000000olAFM;o0000o`0o`@02o`0001Sooooo00?o0000ooooooooool06Ooo
ool002?ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0;ooooo`Ko00002?o3YK`0
0ol0003o`j6fol>Q]P09ol>Q]P03o`000?o3XkSo`j>h00So`j>h00?o0000ol2I[oo0VJl02Oo0VJl0
0ol0003o_iV`oknI/002oknI/0Go00000_nnU:/00ol0003o_YF]okjE[@0:okjE[@03o`000?noVk?o
_i^c00So_i^c00?o0000ol6M/oo1WK<01Oo1WK<2o`000004o`0W/?l0003o5F7HoaEQf0?o00001_mU
K<D00ol0003oQh;6ohN2aP04ohN2aP;o00001?n__N@4o`0000KodlcB0ol00004omkgf`06o`000?o]
n;;okORbongh/_l0003oY>bU1?l00002oknG[P03o`000?njTjko^Y>^00Ko^Y>^0ol000000oncT;;o
0000ojb=]@04ojb=]@03o`000?n/SKGo[8fe00;o[8fe00?o0000oin9_?nORK`01OnORK`00ol0003o
RhG6oh^5aP03oh^5aP06o`000?mXOMCoJ7gDofQme?l0003o;6cK0_l000001?lAFM;o0000o`0o`Ol0
000Hooooo`;o00002?ooool4o`000003oa0@4?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool04?ooool5o`0000;o`jFl00?o0000ol>Q]_o3XKH02Oo3XKH0
0ol0003o`j>hol>S^008ol>S^003o`000?o0VJoo`9V_00Wo`9V_00?o0000oknI/?noVK000ol00005
oknI/0Go00002OnnUJd00ol0003o_i^coknK/`08oknK/`03o`000?o1WK?o`Ifc00Oo`Ifc0_l00000
0ol09k3o0000oaEQf002oaEQf0;o00001_mUK<D00ol0003oQh;6ohN2aP02ohN2aP03o`000?n__NCo
[kgT00So[kgT1?l00002om?<dP03o`000?oNmm_og_OK00Cog_OK00Go0000ongh/_o]n;;o0000ojC/
Y@04o`0000;o_iN^00?o0000okZC[_njTjh02_njTjh2o`0000Ko[8fe00?o0000ojb=]On/SKD00_n/
SKD2o`0000KoWhVl00?o0000oh^5a_n;QLH00on;QLH01Ol0003oJ7gDofQme?mXOMCo000000;o;6cK
00Go0000oa5Id_l0003o03o1o`00000Fooooo`03o`000?oooooo000000[ooooo00?o0000oooooooo
ool03Oooool002?ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Dooooo`So0000
1Oo3XKH00ol0003o`j>hol>S^009ol>S^003o`000?o0VJoo`9V_00Wo`9V_0ol00009oknI/004o`00
0?o0WkOo`9ngol2O]`Go00000onnUJd00ol0003o_i^coknK/`09oknK/`03o`000?o1WK?o`Ifc00So
`Ifc0_l000000ol09k3o0000oaEQf003oaEQf0Go00000_mUK<D01?l0003oQh;6o`000?l0000?ojnm
i0;o00001_oNmm/01Ol0003okORbo`000?l0003oY>bU00Co00000onoUjh00ol0003o^Y>^okZC[P08
okZC[P04o`000?neT;3o]I2`okF@/0;o00001On/SKD00ol0003o[8feojb=]@03ojb=]@03o`000?nO
RKcoWhVl00CoWhVl00?o0000oh^5a_n;QLH00on;QLH01Ol0003oJ7gDofQme?mXOMCo000000;o;6cK
0ol000000ol0?l7o0000ooooo`0Gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3Oooool002?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Kooooo`So00002?o3
XkP00ol0003o`9V_ol2I[`07ol2I[`?o00002onoVK000ol0003o`9ngol2O]`07ol2O]`Ko00002?no
Vk<00ol0003o`Ifcol6M/`09ol6M/`;o00000_l09k000ol0003o5F7HoaEQf003oaEQf0?oKY_/1?l0
000@ojnmi003o`000?oNmm_og_OK00Kog_OK0ol000000onTk:Go0000o`000002o`0000?o_iN^00?o
0000okZC[_njTjh02?njTjh00ol0003o]I2`okF@/004okF@/0;o00001?n/SKD00ol0003o[8feojb=
]@02ojb=]@go000000?oRhG6o`000?mXOM@00_mXOM@01?l0003o;6cKoba/fol/K=/2o`000003o`0o
`Ol0003ooooo01Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`008ooo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo02;ooooo1Ol00002ol>S^003o`000?o0
VJoo`9V_00Go`9V_0ol000000oo0VJoo0000oknI/00:oknI/003o`000?o0WkOo`9ng00[o`9ng00Co
0000okjK]?nnVkCo_Y^d1Ol00002oknK/`03o`000?o1WK?o`Ifc00Wo`Ifc00Co0000ol:N/oo2W[?o
00000_l09k000ol0003o5F7HoaEQf003oaEQf003o`000?m^VncoKY_/00CoKY_/0_l0000<ojnmi003
o`000?oNmm_og_OK00Kog_OK0_l00003ojC/Y@Co00000_noUjh00ol0003o^Y>^okZC[P08okZC[P03
o`000?neT;3o]I2`00Oo]I2`0_l00002ojb=]@03o`000?n/SKGo[8fe00;o00000onVSK/7oiJ;a@?o
NhOD1?l00002ofQme004o`000?l/K=_o;6cKoba/f`?o00006?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00gooooo000Sooooo`;o0000?_ooool00ol0003oooooooooo`0Vooooo`Go
00000_o0VJl3o`0000Co`9V_00?o0000oknI/?noVK002?noVK000ol0003o`9ngol2O]`0:ol2O]`03
o`000?nnVkCo_Y^d00Oo_Y^d1?l00009ol6M/`03o`000?o2W[?o`Yjc00;o`Yjc00Co0000o`0W/?l0
9k3o00001OlEHMP00ol0003oKY_/ofjKk005ofjKk0;o00002On__N@00ol0003og_OKomkgf`06omkg
f`03o`000?o]n;;oY>bU00;oY>bU0ol00002ol:H[0Co00002?njTjh00ol0003o]I2`okF@/00:okF@
/0;o000000?o[8feo`000?l000001_nVSK/00ol0003oUX_5oiJ;a@04oiJ;a@03o`000?mkQmCoNhOD
00?oNhOD1?l00003oba/f`?o00006?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00gooooo000Rooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0:Oooool6o`0000?o
`9V_00?o0000oknI/?noVK002?noVK000ol0003o`9ngol2O]`0:ol2O]`03o`000?nnVkCo_Y^d00Wo
_Y^d00?o0000oknL]?noW;@00ol00006ol6M/`03o`000?o2W[?o`Yjc00?o`Yjc0_l000000ol09k3o
0000oaEQf004oaEQf003o`000?m^VncoKY_/00KoKY_/00?o0000ojnmi?n__N@01On__N@00ol0003o
g_OKomkgf`07omkgf`04o`000?nTk:GoY>bUojC/Y@?o00001?o2V:`00ol0003o_iJ/oknF[005o`00
00;o^Y>^00?o0000okF@/?neT;003OneT;000ol0003oYXfko`000008ojJ=^`03o`000?nFRlGoUX_5
00?oUX_500?o0000og^7e?mkQm@00omkQm@2od^0h`;o00000ol/K=/2o`0001Kooooo0ol00007oooo
o`03o`000?oooooooooo00gooooo000Rooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool09Oooool3o`0000Kooooo2?l00005oknI/003o`000?o0WkOo`9ng00[o`9ng00?o0000okjK]?nn
Vk@02OnnVk@00ol0003o_ibdoknL]004oknL]0?o00000_o1WK<00ol0003o`Yjcol:N/`06ol:N/`03
o`000?l09k3o000000Go5F7H0_l00007ofjKk0;o00001?n__N@00ol0003og_OKomkgf`04omkgf`Co
00000onTk:D2o`0000Go`YR/00?o0000oknF[?noUZ`01_noUZ`2o`0000ko]I2`00Co0000ok6@/ona
T;?o/I2c0_l00008ojJ=^`03o`000?nFRlGoUX_500?oUX_50_l00004og^7e003o`000?m;P>?oBh3S
00;o00000_l/K=/2o`0001Sooooo00?o0000ooooooooool00_ooool00omEEEGoIVIVo`00000?oooo
o`008_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo02;ooooo0_l0000Aooooo`Go
000000?o`9ngo`000?o0WkL02Oo0WkL00ol0003o_Y^dokjK]009okjK]003o`000?noW;Co_ibd00So
_ibd1ol00005ol:N/`?o00001_lEHMP00ol0003oKY_/ofjKk006ofjKk0;o000000?o[kgTo`000?oN
mm/01_l000000onBk?Co0000ojC/Y@02ojC/Y@?o00001Oo2V:`00ol0003o_iJ/oknF[008oknF[003
o`000?nlTJ_o000000;o00002?neT;02o`0000Go/I2c0_l00008ojJ=^`;o00001OnFRlD00ol0003o
NhODog^7e002og^7e0;o00000_m;P><2o`000003oba/fol0003ooooo01Kooooo0ol0000Eooooo`00
8_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01kooooo0ol0000Jooooo`?o0000
1_o0WkL00ol0003o_Y^dokjK]009okjK]003o`000?noW;Co_ibd00So_ibd00?o0000ol6U_Oo1YKd0
1Oo1YKd6o`000003ohT00?l0003o000000Ko5F7H00?o0000ofjKk?m^Vn`01_m^Vn`4o`0000KoT^cd
0_l000000onTk:Go0000o`000002o`0000Ko`YR/00?o0000oknF[?noUZ`01onoUZ`00ol0003o_96[
okbAZ`03okbAZ`;o00001OneT;000ol0003o/I2cok6@/`06ok6@/`;o00002OnVSK/00ol0003oUX_5
oiJ;a@03oiJ;a@03o`000?mkQmCoNhOD00?oNhOD00?o0000od^0hom;P><01?l0000Cooooo`?o0000
0_ooool00ol0003oooooooooo`0Cooooo`008_ooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo01[ooooo0ol0000Pooooo`?o00000_o0WkL00ol0003o_Y^dokjK]009okjK]003o`000?no
W;Co_ibd00So_ibd00?o0000ol6U_Oo1YKd02Oo1YKd01?l0003o`ZBkol:T^oo2Y;/2ohT00003o`00
0?lEHMSo5F7H00Co5F7H00?o0000ofjKk?m^Vn`00_m^Vn`3o`0000WoT^cd00Go0000ojC/YOl0003o
0000o`@00002o`0000Ko`YR/00?o0000oknF[?noUZ`01onoUZ`00ol0003o_96[okbAZ`06okbAZ`?o
000000?o]I2`o`000?naT;<02OnaT;<3o`0000KoYXfk1ol000000onFRlGo0000og^7e004og^7e003
o`000?m;P>?oBh3S00Co00003oooool3o`0000Gooooo00?o0000ooooooooool04oooool002;ooooo
0_l00015ooooo`03o`000?oooooooooo01Kooooo0ol0000Vooooo`Go00002?nnVk@00ol0003o_ibd
oknL]008oknL]003o`000?o1YKgo`JFm00Wo`JFm00?o0000ol:T^oo2Y;/00oo2Y;/2ohT000Go0000
0_lEHMP01?l0003oKY_/o`000?l0000;oi;/m003o`000?nTk:Go000000;o10000_l00006ol:H[003
o`000?noUZco_iJ/00So_iJ/00?o0000okbAZonlTJ/02OnlTJ/00ol0003o/I2cok6@/`0:ok6@/`03
o`000?naT;?o000000;oYXfk0ol00004oinAa@?oRi;E1ol000000omkQmCo0000od^0h`02od^0h`03
o`000?lOL>3o000000_ooooo0ol00008ooooo`03o`000?oooooooooo01?ooooo000Qooooo`;o0000
Aoooool00ol0003oooooooooo`0Booooo`?o0000;_ooool5o`0000;o_Y^d00?o0000oknL]?noW;@0
2?noW;@00ol0003o`JFmol6U_@09ol6U_@03o`000?o2Y;_o`ZBk00Ko`ZBk0_n90002o`000003o`1k
]ol0003o000000;o000000?oT^cdo`000?l000002OnBk?@3o`0000;o100000?o0000ol:H[?o2V:`0
1_o2V:`00ol0003o_iJ/oknF[007oknF[003o`000?nlTJ_o_96[00[o_96[00Co0000okVB[ol0003o
00002OnaT;<00ol0003o/I2cok6@/`02o`0000SoWi750_l00004oh^Be@?oJI?W1?l00002od^0h`;o
00001oooool4o`0000_ooooo00?o0000ooooooooool04oooool0027ooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`0>ooooo`?o0000=_ooool2o`000003oknL]?l0003o000000;o0000
1OnoW;@00ol0003o`JFmol6U_@09ol6U_@03o`000?o2Y;_o`ZBk00So`ZBk00?o0000ohT00?n90000
0_l00006o`1k]`Go00000onBk?@2o`0000?o10001?l00005ol:H[003o`000?noUZco_iJ/00So_iJ/
00?o0000okbAZonlTJ/02OnlTJ/00ol0003o^I:_okVB[`02okVB[`;o00002?naT;<01Ol0003o[I:k
ojfB^on]T[_o000000WoWi7500?o0000oh^BeOn;T]D00on;T]D00ol0003oJI?WofVCi`02ofVCi`?o
000000?oBh3So`000?ooool00_ooool3o`00013ooooo00?o0000ooooooooool04_ooool0027ooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0:ooooo`?o0000@?ooool5o`000003ol6U
_Ol0003o000000So`JFm00?o0000ol:T^oo2Y;/02Oo2Y;/00ol0003o`Ifbo`000002ohT00003o`00
0?l0NkOo07^g00So07^g0ol00004o`@00003o`000?o2X;Ko`Z2f00;o`Z2f1ol00008oknF[003o`00
0?nlTJ_o_96[00Wo_96[00?o0000okVB[oniTZl01OniTZl2o`0000Co/I2c0_l000000on]T[_o0000
ojfB^`03ojfB^`03o`000?nOTLGoWi7500KoWi7500?o0000oh^BeOn;T]D00on;T]D2o`0000CoJI?W
1_l0000Cooooo`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo04Wooooo00?o
0000ooooooooool01_ooool3o`0004_ooooo1Ol00002ol6U_@03o`000?o2Y;_o`ZBk00Wo`ZBk00Co
0000ol6M/_o1WK;o`Ifb1Ol00006o`1k]`?o00000ol40003o`0000Wo`Z2f00?o0000oknG[OnoUjd0
0ol00004oknF[003o`000?nlTJ_o_96[00Wo_96[00?o0000okVB[oniTZl02?niTZl2o`000003ok6@
/ol0003o[I:k00?o[I:k00?o0000ojfB^on]T[/00_n]T[/2o`0000OoWi750_l00005oh^Be@;o0000
0omYTnL2o`000003odN;jol0003ooooo01?ooooo00?o0000ooooooooool04_ooool0027ooooo00?o
0000ooooooooool0B_ooool00ol0003oooooooooo`02ooooo`?o0000Doooool4o`0000Wo`ZBk00?o
0000ol6M/_o1WK801Oo1WK84o`000003o`1k]ol0003o000000So00002_o2X;H00ol0003o_iN]oknG
[@04oknG[@?o000000?o_iJ/o`000?nlTJ/02_nlTJ/00ol0003o^I:_okVB[`0:okVB[`03o`000?n]
T[_o[I:k00?o[I:k00?o0000ojfB^on]T[/01?n]T[/2o`0000OoWi7500?o0000oh^BeOn;T]D01?n;
T]D00ol0003oJI?WofVCi`02ofVCi`;o00005?ooool00ol0003oooooooooo`0Booooo`008Oooool2
o`0004cooooo1?l0001Jooooo`?o00001_o2Y;/00ol0003o`Ifbol6M/P08ol6M/POo00000oo3XKL0
0ol0003o`Z2fol:P]P08ol:P]P03o`000?noUjgo_iN]00So_iN]1?l00008okbAZ`03o`000?niTZoo
^I:_00[o^I:_00?o0000okJE]_nfUKH00ol00002ojfB^`03o`000?n]T[_o[I:k00Go[I:k00?o0000
oinAaOnOTLD00_nOTLD?o`000003ofVCiol0003ooooo01;ooooo00?o0000ooooooooool04_ooool0
023ooooo0_l0001;ooooo`Co0000Goooool3o`0000;o`ZBk00?o0000ol6M/_o1WK802?o1WK800ol0
003o`j6gol>Q]`08ol>Q]`03o`000?o2X;Ko`Z2f00Oo`Z2f00?o0000oknG[OnoUjd02OnoUjd01?l0
003o_iZboknJ/_noV[85o`0000;o_96[00?o0000okVB[oniTZl02_niTZl00ol0003o]YFfokJE]P04
okJE]P;o000000?o[I:ko`000?n]T[/01_n]T[/4o`0000GoVIcF00?o0000oh:Rj?n2X^P01?n2X^P2
o`000004ofZPl?l0003o0000o`0001;ooooo00?o0000ooooooooool04_ooool000Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00;ooooo00?o
0000ooooooooool0Aoooool3o`0000Cooooo0_l0001Pooooo`Oo00001Oo1WK800ol0003o`j6gol>Q
]`08ol>Q]`03o`000?o2X;Ko`Z2f00Oo`Z2f00?o0000oknG[OnoUjd02OnoUjd00ol0003o_iZboknJ
/P07oknJ/PCo00002_niTZl00ol0003o]YFfokJE]P07okJE]P?o00000_n]T[/3o`0000?oZ9W700?o
0000oiVLe_nIW=H01_nIW=H2o`0000GoPZ;X0_l000000omZX?3o0000ooooo`0Aooooo`03o`000?oo
oooooooo01;ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`14ooooo`?o00002Oooool00ol0003ooooooooo
o`1Tooooo`[o00001Oo3XKL00ol0003o`Z2fol:P]P08ol:P]P03o`000?noUjgo_iN]00So_iN]00?o
0000oknJ/_noV[802OnoV[800ol0003o_IbgokfL]`03o`0000Ko^I:_00?o0000okJE]_nfUKH02_nf
UKH3o`0000SoZ9W70_l00007oiVLeP;o00001On2X^P3o`0001;ooooo00?o0000ooooooooool04Ooo
ool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0@Oooool3o`0000gooooo00?o0000ooooooooool0KOooool7o`0000So`Z2f00?o
0000oknG[OnoUjd02?noUjd00ol0003o_iZboknJ/P09oknJ/P03o`000?nmW;Oo_Ibg00Co_Ibg0ol0
0002okVB[`03o`000?nfUKKo]YFf00[o]YFf00Co0000ok>H^ol0003o/iRk0_l00008ojRIa`;o0000
1onIW=H2o`0000GoPZ;X0_l0000Aooooo`03o`000?oooooooooo017ooooo0006ooooo`05o`000?oo
ooooooooooooool000003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo
0ol0000Aooooo`03o`000?oooooooooo07?ooooo1Ol00002ol:P]P03o`000?noUjgo_iN]00Wo_iN]
00?o0000oknJ/_noV[802?noV[800ol0003o_IbgokfL]`08okfL]`;o00002onfUKH2o`0000?o/iRk
00?o0000ok>H^oncV;/00_l00008ojRIa`;o00001?nIW=H9o`000003oh:Rj?l0003ooooo00oooooo
00?o0000ooooooooool04Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0>oooool3o`0001Gooooo00?o0000ooooooooool0
Moooool5o`0000So_iN]00?o0000oknJ/_noV[802?noV[800ol0003o_IbgokfL]`09okfL]`04o`00
0?njUkCo^YNdokZG]0?o00001OnfUKH00ol0003o/iRkok>H^`03ok>H^`03o`000?ncV;_o/iRk00;o
/iRk00?o0000ojRIaonXVLL01onXVLL4o`0000GoTjgX0ol00002ohF^l003o`000?oooooooooo00ko
oooo00?o0000ooooooooool04Oooool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03
o`000?oooooooooo00?ooooo0ol0000iooooo`?o00006Oooool00ol0003oooooooooo`1kooooo`Go
00000_noUjd00ol0003o_iZboknJ/P08oknJ/P03o`000?nmW;Oo_Ibg00Wo_Ibg00?o0000okZG]?nj
Uk@01OnjUk@3o`000003okJE]_l0003o/iRk00Ko/iRk00?o0000ok>H^oncV;/00_ncV;/2o`0000;o
Z9W70ol00004ojBUe`;o00002?nC[NP2o`000003ohF^l?l0003ooooo00kooooo00?o0000oooooooo
ool04Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0=_ooool3o`0001gooooo00?o0000ooooooooool0Ooooool7o`0000Go
_iZb00?o0000okfL]onmW;L02OnmW;L00ol0003o^YNdokZG]009okZG]003o`000?ncV;_o/iRk00Oo
/iRk00?o0000ok>H^oncV;/00oncV;/2o`0000[oY:GG0_l00007oi>]j0?o00003_ooool00ol0003o
ooooooooo`0Aooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l0
00001Oooool00ol0003oooooooooo`0cooooo`?o00008Oooool00ol0003oooooooooo`25ooooo`Go
000000?o_Ibgo`000?nmW;L02?nmW;L00ol0003o^YNdokZG]008okZG]003o`000?niWkoo^Ino00;o
^Ino0ol00005ok>H^`04o`000?ncV;_o0000o`0000?o/:780ol00009ojBUe`?o00001?nC[NP01?l0
003oTjgXoi>]j?l0000=ooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo
037ooooo0_l0000Uooooo`03o`000?oooooooooo08_ooooo0ol00005okfL]`03o`000?njUkCo^YNd
00So^YNd00?o0000okVO_oniWkl01_niWkl3o`0000;o/iRk0_l00008ok2Qb0;o00002_nTYML4o`00
00?oU[O^00?o0000ooooooooool02oooool00ol0003oooooooooo`0Aooooo`007oooool00ol0003o
ooooooooo`0^ooooo`?o0000:?ooool00ol0003oooooooooo`2=ooooo`?o000000?o_Ibgo`000?nj
Uk@02OnjUk@00ol0003o^InookVO_`0:okVO_`;o000000?o/:78o`000?n`XLP02On`XLP3o`0000;o
Y:GG0ol00005oj6ci@?o00000_nF]nh00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo013o
oooo000Oooooo`03o`000?oooooooooo02_ooooo0ol0000/ooooo`03o`000?oooooooooo08gooooo
0ol000000onjUkCo0000o`000002o`0000Go^YNd00?o0000okVO_oniWkl02OniWkl2o`0000Co]JO;
0ol0000:ok2Qb0;o00002onQ/nD3o`0000gooooo00?o0000ooooooooool04?ooool001oooooo0_l0
000Yooooo`?o0000<?ooool00ol0003oooooooooo`29ooooo`?o00002?ooool5o`0000_o^Ino00?o
0000okFWboneYl/01OneYl/00ol0003o]JO;o`000002o`0000;o/:780ol00005oj^_f`Go00002?nQ
/nD00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo000Nooooo`03o`000?oooooo
oooo02Kooooo0ol0000dooooo`03o`000?oooooooooo08Gooooo0ol0000Booooo`Go00000_niWkl2
o`0000So]JO;00?o0000okFWboneYl/00_neYl/2o`0000goZjoK1Ol00003oinkk@03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool04?ooool001kooooo00?o0000ooooooooool08oooool3o`00
03Sooooo00?o0000ooooooooool0P?ooool4o`0001[ooooo0_l0000;okFWb`?o00001OnbZm05o`00
00?oZjoK0ol00004ojZfhP?o00000_nO^nd00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
013ooooo000Nooooo`03o`000?oooooooooo023ooooo0ol0000looooo`03o`000?oooooooooo07co
oooo0ol0000Sooooo`Go00000_neYl/3o`0000_o/Z_@0ol0000:ojZfhPCo00002_ooool00ol0003o
ooooooooo`0@ooooo`007_ooool00ol0003oooooooooo`0Mooooo`?o0000@?ooool00ol0003ooooo
ooooo`1hooooo`?o0000:oooool2o`0000?o/Z_@00?o0000ok:[d?nbZm001OnbZm03o`0000Co[KSQ
1Ol00007ojZfhP;o00002Oooool00ol0003oooooooooo`0@ooooo`007_ooool00ol0003ooooooooo
o`0Jooooo`?o0000A?ooool00ol0003oooooooooo`1cooooo`Co0000<_ooool5o`0000;o/Z_@0_l0
000<ojfhh@Go00000onV_^/00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo000N
ooooo`03o`000?oooooooooo01Oooooo0ol00018ooooo`03o`000?oooooooooo06oooooo0ol0000h
ooooo`03o`000?oooooooooo00;o00002_n]^>43o`0000GoZ[cW1_l00009ooooo`03o`000?oooooo
oooo00oooooo000Mooooo`?o00005Oooool3o`0004cooooo00?o0000ooooooooool0Joooool3o`00
03cooooo00?o0000ooooooooool01_ooool5o`0000goZ[cW0_l00008ooooo`03o`000?oooooooooo
00oooooo000Mooooo`03o`000?oooooooooo01;ooooo0ol0001@ooooo`03o`000?oooooooooo06Oo
oooo0ol0000oooooo`03o`000?oooooooooo00gooooo1Ol00003ojZli`?o000000?oZKoZo`000?oo
ool01oooool00ol0003oooooooooo`0?ooooo`007Oooool00ol0003oooooooooo`0?ooooo`?o0000
E?ooool00ol0003oooooooooo`1Rooooo`Co0000@oooool00ol0003oooooooooo`0Aooooo`Co0000
1?nY_nX00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oo
oooooooo00cooooo0ol0001Hooooo`03o`000?oooooooooo05kooooo0ol00018ooooo`03o`000?oo
oooooooo01Cooooo1_l00006ooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oooooo
oooo00Wooooo0ol0001Looooo`;o0000Foooool3o`0004cooooo00?o0000ooooooooool06?ooool2
o`0000Gooooo00?o0000ooooooooool03oooool001gooooo00?o0000ooooooooool01_ooool3o`00
067ooooo00?o0000ooooooooool0EOooool3o`0004oooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0?ooooo`007Oooool00ol0003oooooooooo`03ooooo`?o0000IOooool00ol0003o
ooooooooo`1@ooooo`Co0000Doooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00ko
oooo000Looooo`?o000000Coooooo`000?l0003o0000JOooool00ol0003oooooooooo`1<ooooo`?o
0000F?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00kooooo000Looooo`Co0000
KOooool00ol0003oooooooooo`18ooooo`?o0000G?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00kooooo000Looooo`;o0000L?ooool00ol0003oooooooooo`14ooooo`?o0000Gooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool0?oooool4o`0006?ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0>ooooo`007oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
03_ooooo0ol0001Xooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool0023o
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0gooooo`?o0000K?ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00kooooo000Qooooo`;o0000Koooool00ol0003ooooo
ooooo`0cooooo`?o0000Koooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00gooooo
000Sooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0;_ooool4o`0007?ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0=ooooo`009?ooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02[ooooo0ol0001hooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool03Oooool002Gooooo0_l0001^ooooo`03o`000?oooooooooo02Kooooo0ol0001koooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03Oooool002Oooooo00?o0000oooooooo
ool0K?ooool00ol0003oooooooooo`0Rooooo`?o0000Ooooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00gooooo000Xooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0
7Oooool4o`0008?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0=ooooo`00:Ooo
ool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo01Wooooo0ol00028ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool03Oooool002[ooooo0_l0001]ooooo`03o`000?oooooo
oooo01Gooooo0ol0002;ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03Oooool0
02cooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0Aooooo`?o0000Soooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00cooooo000]ooooo`03o`000?oooooooooo06_o
oooo00?o0000ooooooooool03?ooool4o`0009?ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0<ooooo`00;_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Sooooo
0ol0002Hooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03?ooool002oooooo0_l0
001/ooooo`03o`000?oooooooooo00Cooooo0ol0002Kooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool03?ooool0037ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`03
o`0009oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<ooooo`00<_ooool00ol0
003oooooooooo`1Zooooo`;o0000Xoooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00cooooo000cooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0Xoooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00cooooo000dooooo`;o0000JOooool00ol0003ooooo
ooooo`2Sooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool003Kooooo00?o
0000ooooooooool0I_ooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool02oooool003Oooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`2U
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool003Sooooo0_l0001Uoooo
o`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0;oooo
o`00>_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo0:Kooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0;ooooo`00>oooool00ol0003oooooooooo`1Qooooo`03o`00
0?oooooooooo0:Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`00??oo
ool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo0:Sooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0;ooooo`00?Oooool2o`00063ooooo00?o0000ooooooooool0Z?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo000oooooo`03o`000?oooooooooo
05gooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00[ooooo0010ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0Z_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo0011ooooo`03o`000?oooooooooo05_ooooo
00?o0000ooooooooool0Zoooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
0012ooooo`;o0000Foooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02_ooool004Cooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`2/
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool004Gooooo00?o0000oooo
ooooool0E_ooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool004Kooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`2_ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool004Oooooo0_l0001Eooooo`03o`00
0?oooooooooo0:oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`00BOoo
ool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo0;3ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`09ooooo`00B_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo
oooo0;7ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`00Boooool2o`00
057ooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Wooooo001=ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Wooooo001>ooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool0/oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo
001?ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0]?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Wooooo001@ooooo`;o0000C?ooool00ol0003oooooooooo`2e
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool005;ooooo00?o0000oooo
ooooool0BOooool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02?ooool005?ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`2fooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool005Cooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`2gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2?ooool005Gooooo0_l00017ooooo`03o`000?oooooooooo0;Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`08ooooo`00Eoooool00ol0003oooooooooo`14ooooo`03o`000?oooooo
oooo0;Sooooo00Go0000ooooooooooooooooo`00000:ooooo`00F?ooool00ol0003oooooooooo`13
ooooo`03o`000?oooooooooo0;Wooooo00Co0000oooooooooooo00002_ooool005Wooooo00?o0000
ooooooooool0@_ooool00ol0003oooooooooo`2jooooo`03o`000?oooooo000000[ooooo001Joooo
o`;o0000@_ooool00ol0003oooooooooo`2jooooo`04o`000?ooooooooooo`0000Wooooo001Loooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool0^oooool00ol0003oooooo`000009oooo
o`00GOooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo0;cooooo0_l00009ooooo`00
G_ooool2o`0003kooooo00?o0000ooooooooool0^oooool3o`0000Wooooo001Pooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0]oooool4o`0000cooooo001Qooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool0/oooool4o`00013ooooo001Rooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool0[oooool4o`0001Cooooo001Sooooo`;o0000>Oooool00ol0003o
ooooooooo`2[ooooo`Co00006?ooool006Gooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`2Wooooo`Co00007?ooool006Kooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`2Sooooo`Co00008?ooool006Oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2O
ooooo`Co00009?ooool006Sooooo0_l0000cooooo`03o`000?oooooooooo09cooooo1?l0000Xoooo
o`00J_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo09Sooooo1?l0000/ooooo`00
Joooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo09Cooooo1?l0000`ooooo`00K?oo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo093ooooo1?l0000dooooo`00KOooool2
o`0002kooooo00?o0000ooooooooool0SOooool3o`0003Sooooo001_ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0ROooool4o`0003_ooooo001`ooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool0QOooool4o`0003oooooo001aooooo`;o0000:_ooool00ol0003ooooo
ooooo`21ooooo`Co0000@oooool007?ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`1mooooo`Co0000Aoooool007Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1i
ooooo`Co0000Boooool007Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1eoooo
o`Co0000Coooool007Kooooo0_l0000Uooooo`03o`000?oooooooooo077ooooo1?l0001Cooooo`00
N?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo06gooooo1?l0001Gooooo`00NOoo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo06Wooooo1?l0001Kooooo`00N_ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06Gooooo1?l0001Oooooo`00Noooool2o`00
023ooooo00?o0000ooooooooool0HOooool4o`0006?ooooo001mooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0GOooool4o`0006Oooooo001nooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0FOooool4o`0006_ooooo001oooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0EOooool4o`0006oooooo0020ooooo`;o00006oooool00ol0003oooooooooo`1A
ooooo`Co0000Loooool008;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1=oooo
o`Co0000Moooool008?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`19ooooo`Co
0000Noooool008Cooooo0_l0000Gooooo`03o`000?oooooooooo04Gooooo1?l0001oooooo`00Q_oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo047ooooo1?l00023ooooo`00Qoooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03gooooo1?l00027ooooo`00R?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo03Wooooo1?l0002;ooooo`00ROooool2o`0001;o
oooo00?o0000ooooooooool0=Oooool4o`0008oooooo002;ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0<Oooool4o`0009?ooooo002<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0;_ooool4o`0009Oooooo002=ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0:oooool3o`0009_ooooo002>ooooo`;o00003?ooool00ol0003oooooooooo`0Woooo
o`Co0000W_ooool0093ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Sooooo`Co
0000X_ooool0097ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Oooooo`Co0000
Y_ooool009;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Kooooo`Co0000Z_oo
ool009?ooooo0_l00007ooooo`03o`000?oooooooooo01Oooooo1?l0002^ooooo`00UOooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo1?l0002booooo`00U_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00oooooo1?l0002fooooo`00Uoooool2o`0000?ooooo
00?o0000ooooooooool02oooool4o`000;[ooooo002Iooooo`04o`000?ooooooooooo`0000Wooooo
1?l0002nooooo`00V_ooool00ol0003oooooo`000005ooooo`Co0000`_ooool009_ooooo0_l00000
0ooooooo0000o`000002o`000<Kooooo002Looooo`;o0000b_ooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool006Sooooo00Go8B4Qo`000?l0
003oA4A4omgMg@1iooooo`05ob4Q8Ol0003o0000odA4A?oMgMd0OOooool006_ooooo00?oMgMgoc8b
<_ooool0Noooool00omgMgOo<S8booooo`1looooo`00K?ooool00ol0003oooooooooo`1kooooo`03
o`000?oooooooooo07_ooooo0010ooooo`07oiRHV?l0003o0000odA4A?nj^[[ooooooa0@4005o`00
00Cooooo1Ol00002ooooo`06oiRHV?l0003o0000ogMgMol@413o00000_ooool01?l@413o0000o`00
0?ooool2o`000008oa0@4?ooooook^k^oeEEEOl0003o410@olc<c?l00003ooooo`07oiRHV?l0003o
0000ogMgMol0003o410@ooooo`05o`0000?ooooo00SoV9RHo`000?l0003oMgMgoa0@4?l0003ooooo
oa0@40Go00001Oooool01_o^k^koEEEEo`000?l0003oV9RHo`0000;o410@1Ol00004ooooo`06oiRH
V?l0003o0000ogMgMol0003o410@0_l00002ooooo`04o`000?ooooooooooo`0000;o410@0_l00000
1ooooooo0000o`000?l@413oooooonk^k_mEEED00_l000001Om4A4Co^[ZjooooooooooooV9RH00;o
000000?oMgMgoa0@4?l000000_ooool01oo^k^koEEEEo`000?l0003oV9RHo`000?l@41001Oooool0
1_o^k^koEEEEo`000?l0003oA4A4okZj^P?ooooo1Ol00002ooooo`06onk^k_mEEEGo0000oa0@4?o<
c<co00000_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P;ooooo00Co410@o`000?l0003ooooo
0_l000000ol@413o0000o`000002ooooo`07o`000?ooooooooooo`000?l@413ok^k^oeEEE@02o`00
0006oeEEEOo^k^koooooooooooo^k^koEEEE0_l000001_nHV9So0000oa0@4?ooooook^k^oeEEE@;o
000000KoA4A4okZj^_oooooooooooa0@4?lb<S82o`000003oa0@4?nYZJWooooo00?ooooo00OoV9RH
o`000?l0003oEEEEonk^k_mVIVKo000000Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c00]ooooo`00
@?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`02ooooo`05o`000?o<c<cok^k^ohN7Qol000001?ooool01Ol0003ooooooooooooooooo
000000;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00003ooooo`05o`000?nYZJWoooooohN7Qol0
00001?ooool00ol0003oooooooooo`03ooooo`05o`000?o<c<cok^k^ohN7Qol000001?ooool00ol0
003oooooooooo`06ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00000oooool00ol0003ooooooooo
o`05ooooo`05o`000?nYZJWoooooohN7Qol000000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000?ooooo00Wo0000ooooooooooooEEEEogMgMoooooook^k^ogMgMol@4100
0_ooool01Ol0003oc<c<onk^k_n7QhOo000000?ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00006
ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@1Oooool00ol0003oooooooooo`02ooooo`06oeEE
EOmgMgOoooooonk^k_mEEEGo00000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooomE
EEGoMgMg0_ooool02_mgMgOoEEEEooooooooooooEEEEogMgMoooooook^k^oeEEEOl00002ooooo`06
oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool01_l0003oZJVYoooooooooooo^[Zjo`0000Cooooo
00Ko0000ojVYZOooooooQhN7oc8b<_mVIVH2ooooo`Ko000000Kooooooa0@4?nj^[[oooooogMgMolb
<S8]ooooo`00@?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00_ooool01Ol@413oQhN7ooooooo^k^ko000000Cooooo00Go0000oooooooooooooooo
o`000002ooooo`06o`000?ooooooooooooooooo^k^ko00000oooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool00oooool01Ol@413oQhN7ooooooo^k^ko000000Cooooo00?o
0000ooooooooool01_ooool01_l0003oooooooooooooooook^k^o`0000?ooooo00?o0000oooooooo
ool01Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000Oooooo00Go410@ohN7Qooooooo
k^k^o`000003ooooo`06o`000?ooooooooooooooooo^k^ko00001_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00;ooooo00Ko0000ooooooooooooooooonk^k_l00002ooooo`03o`00
0?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooool000001?ooool01?l0003oooooooooool00003ooooo`05onk^k_l0003o
ooooooooool000002?ooool01Onj^[[oQhN7ofIVI_mVIVKo410@00Cooooo00Ko0000oooooooooooo
ooooohN7Qom4A4@=ooooo`03o`000?oooooooooo02_ooooo0010ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03okZj^_l@413o000000;o
00001?ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000ooooooooooooooooonk^k_l0
0003ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03okZj
^_l@413o000000;o00001?ooool00ol0003oooooooooo`06ooooo`06o`000?ooooooooooooooooo^
k^ko00000oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
1_l00002ooooo`03okZj^_l@413o000000;o00000oooool01_l0003oooooooooooooooook^k^o`00
00Kooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Ko0000ooooooooooooooooonk^k_l0
0002ooooo`Ko00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo00Cok^k^o`00
0?oooooooooo1_l00002ooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^1?ooool01_lQ8B7oc<c<
ooooooooooooV9RHoc8b<P;ooooo1_l00004ooooo`03ojVYZOl@413ooooo02cooooo0010ooooo`03
o`000?oooooooooo00Gooooo00?o0000oc8b<_oMgMd01oooool00ol0003oooooooooo`05ooooo`03
olc<c?l0003ooooo00?ooooo00Go0000ohN7QoooooooZJVYo`000002ooooo`06oeEEEOmgMgOooooo
onk^k_mEEEGo00000oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
1_ooool00oo<c<co0000ooooo`03ooooo`03o`000?lb<S;ogMgM00Kooooo00KoIVIVogMgMooooooo
k^k^oeEEEOl00003ooooo`03o`000?lb<S;ogMgM00Gooooo00Go0000ooooooooooooooooo`000002
ooooo`07o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8@02ooooo`05o`000?mgMgOoooooojVYZOl0
00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<PGooooo00?oc<c<o`000?ooool00_ooool0
1_mVIVKoMgMgooooooo^k^koEEEEo`0000Kooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S85oooo
o`03o`000?oooooooooo00;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00002ooooo`06oeEEEOn7
QhOok^k^oooooon7QhOo<S8b0oooool01Ol0003oQhN7oooooonYZJWo000000;ooooo00[o0000olc<
c?o<c<co0000ojVYZOoMgMgo8B4QoooooomEEEGoMgMg0_ooool02_mgMgOoEEEEooooooooooooIVIV
ogMgMoooooook^k^oeEEEOl00002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0_ooool01_l0
003o^[Zjooooooo^k^koMgMgo`0000Cooooo00OoZJVYob4Q8OoMgMgok^k^oc8b<_mEEEGo^[Zj00[o
oooo00?o410@o`000?nj^[X0;Oooool003kooooo00?o410@o`000?l000000ol00003ooooo`;o0000
00CoZJVYob4Q8Ol0003o8B4Q0oooool00ol@413o0000o`000005ooooo`04oc8b<_l0003o0000oiRH
V0?ooooo00?o410@o`000?mgMgL00_l000003OnHV9Soooooooooooo^k^koEEEEo`000?lQ8B7oZJVY
o`000?l@413ooooooa0@4?l000000_ooool2o`0000Cooooo00?o0000ooooooooool01?ooool01?lb
<S;o0000o`000?nHV9P3ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q1?ooool01_o^k^koEEEEo`00
0?l@413oc<c<o`0000;ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42ooooo`04oa0@4?l0003ooooo
ooooo`;o000000Wooooooa0@4?l0003o8B4Qo`000?mgMgOo410@o`000?nYZJT00_ooool01Ol0003o
MgMgo`000?l0003oV9RH00;ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h3ooooo`04oc8b<_l0
003o0000oiRHV0?ooooo00Kok^k^oeEEEOl0003o410@olc<c?l00006ooooo`06onk^k_mEEEGo0000
o`000?m4A4Cok^k^0oooool00ol@413o0000o`000004ooooo`0:onk^k_mEEEGo0000ob4Q8OnYZJWo
0000oa0@4?ooooook^k^oeEEE@;o000000OoA4A4onk^k_oooooooooooa0@4?l0003oMgMg00;o0000
00goV9RHooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^k^koEEEE00;o0000
00[oEEEEonk^k_ooooooooooonk^k_mEEEGo0000oa0@4?o<c<co00000_ooool01_o^k^koEEEEo`00
0?l0003oA4A4onk^kP;ooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00005ooooo`06oiRHV?l0003o
0000oiRHV?nj^[[o<S8b2oooool00onj^[[o8B4Qooooo`0/ooooo`00@?ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool08Oooool01Ol@413oV9RHoooo
oonj^[[o000002gooooo0010ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool08Ooo
ool01OnYZJWo410@o`000?l@413oZJVY02gooooo001Booooo`03oa0@4?oooooooooo02;ooooo00?o
410@o`000?l000006oooool2o`0001[ooooo00?o410@o`000?ooool06Oooool2o`00017ooooo00?o
410@ooooooooool0;_ooool2o`0005Gooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0844552, 0.00525911, \
0.00369676, 0.00369676}}]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["6.3.3 Galerkin-Method Eigenmodes", "Subsubtitle",
  CellTags->{"i:41", "c:34"}],

Cell[CellGroupData[{

Cell["General Theory", "Section",
  CellTags->"c:35"],

Cell["\<\
\t It is also possible to obtain numerical approximations to the \
low-order eigenvalues and eigenmodes of a system using the Galerkin method. \
In fact, this method is superior to the grid method in some respects. For \
instance, we will see that the error in the low-order eigenvalues scales far \
more favorably with the size of the operator matrix than in the grid method.  \
\
\>", "Text"],

Cell["\<\
\tFurthermore, the Galerkin method can be easily adapted to \
determine the eigenmodes and eigenvalues of  two- and even three-dimensional \
systems. As we saw above, it is rather difficult to apply the grid method to \
such problems, because of the complexity of identifying and modifying the \
boundary point equations in order to match homogeneous boundary conditions.  \
In the Galerkin method, boundary conditions are automatically satisfied by \
the choice of  functions used in the expansion. \
\>", "Text"],

Cell["\<\
\tIn the Galerkin method, we begin with  a general eigenmode \
problem in any number of spatial dimensions,\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) \[Psi]\_n = \(\[Lambda]\_n\) \[Psi]\_n\)]],
  ","
}], "NE3",
  CellTags->"(6.3.8)"],

Cell[TextData[{
  "for some spatial operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  ", subject to general homogeneous boundary conditions. We next expand ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_n\)]],
  " in a complete set of basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`{v\_m}\)]],
  " that match the boundary conditions, "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_n = \ \[Sum]\+m c\_m\%\((n)\)\ v\_m\)]],
  "."
}], "NE3",
  CellTags->"(6.3.9)"],

Cell[TextData[{
  " The constants ",
  Cell[BoxData[
      \(TraditionalForm\`c\_m\%\((n)\)\)]],
  " remain to be determined.  Equation ",
  ButtonBox["(6.3.8)",
    ButtonData:>"(6.3.8)",
    ButtonStyle->"Hyperlink"],
  " then becomes"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+m c\_m\%\((n)\)\ \(L\&^\) 
            v\_m = \[Sum]\+m\ \(c\_m\%\((n)\)\) \(\[Lambda]\_n\) v\_m\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "We now take an inner product of this equation with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`v\_l\)]],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Sum]\+m\ \((v\_l, \(L\&^\) v\_m)\) 
          c\_m\%\((n)\) = \[Lambda]\_n\ \(\[Sum]\+m\((v\_l, v\_m)\) 
            c\_m\%\((n)\)\)\)]]], "NE3",
  CellTags->"(6.3.10)"],

Cell[TextData[{
  " Let us define the matrices ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(L\_\(l\ m\)\)\(=\)\((v\_l, \(L\&^\) 
            v\_m)\)\(\ \)\)\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`S\_\(l\ m\) = \((v\_l, v\_m)\)\)]],
  ". Then Eq. ",
  ButtonBox["(6.3.10)",
    ButtonData:>"(6.3.10)",
    ButtonStyle->"Hyperlink"],
  " is a matrix equation,"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["L",
              FontWeight->"Bold",
              FontSlant->"Plain"], "\[CenterDot]", 
            SuperscriptBox[
              StyleBox["c",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[\((n)\),
                FontWeight->"Plain"]]}], "=", 
          RowBox[{\(\[Lambda]\_n\), 
            RowBox[{
              StyleBox["S",
                FontWeight->"Bold",
                FontSlant->"Plain"], "\[CenterDot]", 
              StyleBox[
                SuperscriptBox[
                  StyleBox["c",
                    FontSlant->"Plain"], 
                  StyleBox[\((n)\),
                    FontWeight->"Plain"]],
                FontWeight->"Bold"]}]}]}], TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SuperscriptBox["c", 
            StyleBox[\((n)\),
              FontWeight->"Plain"]],
          FontWeight->"Bold"], TraditionalForm]]],
  " is the vector with components ",
  Cell[BoxData[
      \(TraditionalForm\`{c\_m\%\((n)\)}\)]],
  ". This generalized matrix eigenvalue equation can be converted into a \
standard eigenvalue problem by multiplying both sides by the inverse of the \
matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["S",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " (assuming that this inverse exists):"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              SuperscriptBox[
                StyleBox["S",
                  FontSlant->"Plain"], 
                StyleBox[\(-1\),
                  FontWeight->"Plain"]],
              FontWeight->"Bold"], "\[CenterDot]", 
            StyleBox["L",
              FontWeight->"Bold",
              FontSlant->"Plain"], "\[CenterDot]", 
            SuperscriptBox[
              StyleBox["c",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[\((n)\),
                FontWeight->"Plain"]]}], "=", 
          RowBox[{\(\[Lambda]\_n\), 
            StyleBox[
              SuperscriptBox[
                StyleBox["c",
                  FontSlant->"Plain"], 
                StyleBox[\((n)\),
                  FontWeight->"Plain"]],
              FontWeight->"Bold"]}]}], TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(6.3.11)"],

Cell[TextData[{
  "Thus, the eigenvalues ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_n\)]],
  " of the operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " are also the eigenvalues of the matrix ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            SuperscriptBox[
              StyleBox["S",
                FontSlant->"Plain"], 
              StyleBox[\(-1\),
                FontWeight->"Plain"]],
            FontWeight->"Bold"], "\[CenterDot]", 
          StyleBox["L",
            FontWeight->"Bold",
            FontSlant->"Plain"]}], TraditionalForm]]],
  ", and the expansion coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{c\_m\%\((n)\)}\)]],
  "are the corresponding eigenvectors.  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 1: 1D Quantum Harmonic Oscillator Eigenmodes", "Section",
  CellTags->"c:36"],

Cell["\<\
\t Below, we illustrate the Galerkin method using the dimensionless \
quantum harmonic oscillator as our example system:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((\(-\(1\/2\)\) \[PartialD]\^2\/\[PartialD]x\^2 + \
\(1\/2\) x\^2)\) \(\(\[Psi]\_n\)(x)\) = E\_n\ \(\(\[Psi]\_n\)(x)\)\)]],
  "."
}], "NE3",
  CellTags->"(6.3.12)"],

Cell[TextData[{
  " We will solve for the eigenmodes and energy levels of the oscillator, \
choosing boundary conditions that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  " vanishes as ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Rule] \ \(\[PlusMinus]\[Infinity]\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tFirst, we must choose a set of basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`{v\_m}\)]],
  " that match these boundary conditions.  Any complete set will do, but \
there is a certain amount of art to making a good choice. We know that the \
eigenmodes of this system are peaked around ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x = 0\)\(,\)\)\)]],
  " so we choose ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_m\)(
          x) = \[ExponentialE]\^\(\(-x\^2\)/3\)\ x\^m\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0, 1, 2,  ... \)]],
  ". The choice of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-x\^2\)/3\)\)]],
  " is arbitrary: in principle, any smooth function that vanishes as infinity \
faster than ",
  Cell[BoxData[
      \(TraditionalForm\`1/x\^m\)]],
  " is valid. However, some choices work better than others. If we had chosen \
",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[\(\(v\_m\)(x) = \[ExponentialE]\^\(\(-x\^2\)/2\)\ x\^m\),
            "TraditionalForm"]}], TraditionalForm]]],
  ", we could construct any given exact eigenmode from a ",
  StyleBox["finite number ",
    FontSlant->"Italic"],
  "of our functions, since the exact modes are Hermite polynomials multiplied \
by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[ExponentialE]\^\(\(-x\^2\)/2\)\)\(\ \)\)\)]],
  "(see Eq. ",
  ButtonBox["(4.1.32)",
    ButtonData:>{"Chapter4.nb", "(4.1.32)"},
    ButtonStyle->"Hyperlink"],
  " ).  The choice ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-x\^2\)/3\)\)]],
  " implies that an infinite number of ",
  Cell[BoxData[
      \(TraditionalForm\`v\_m\)]],
  "'s  will be needed to exactly describe any one eigenmode, but it is not so \
different from ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-x\^2\)/2\)\)]],
  ", so that the expansion converges reasonably quickly. "
}], "Text"],

Cell[TextData[{
  "\tBasically, the main idea is to choose functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_m\)(x)\)]],
  " that look as much as possible like the eigenmodes one is trying to \
describe, so that the smallest possible number of terms need be kept in the \
expansions. While this requires a certain amount of foreknowledge  concerning \
the solutions, one can often make guesses that work admirably."
}], "Text"],

Cell[BoxData[{
    RowBox[{\(Clear["\<Global`*\>"];\), "\n", 
      RowBox[{
        StyleBox["(*",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[" ",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[\(define\ basis\ functions\),
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[" ",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox["*)",
          FontColor->RGBColor[0, 0, 1]]}]}], "\n", 
    RowBox[{\(v[n_, x_]\  = \ \(x\^n\) Exp[\(-x^2\)/3];\), "\n", 
      RowBox[{
        StyleBox["(*",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[" ",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[\(define\ the\ inner\ product\),
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[" ",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox["*)",
          FontColor->RGBColor[0, 0, 1]]}]}], "\n", 
    RowBox[{\(norm[f_, g_]\  := \ 
          Integrate[f\ g, {x, \(-Infinity\), Infinity}];\), 
      "\[IndentingNewLine]", 
      RowBox[{
        StyleBox["(*",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[\(define\ the\ quantum\ harmonic\ oscillator\ operator\),
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[" ",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox["*)",
          FontColor->RGBColor[0, 0, 1]]}]}], "\n", \(V[x_]\  = \ 
        1/2\ x^2;\), "\[IndentingNewLine]", \(\(L\&^\)[
          f_] := \(-1\)/2\ D[f, {x, 2}]\  + \ V[x]\ f;\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.155"],

Cell[TextData[{
  "The inner product is evaluated analytically, because we can do the \
required integrations to determine the projection of ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " onto the basis functions:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(L[j_, k_]\  = \ 
      FullSimplify[norm[v[j, x], L\&^[v[k, x]]], 
        j > \(-1\)\  && \ k > 0]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.156"],

Cell[BoxData[
    \(\(\(1\/\(1 + j + 
          k\)\)\((2\^\(1\/2\ \((\(-7\) - j - k)\)\)\ 3\^\(1\/2\ \((\(-1\) + j \
+ k)\)\)\ \((1 + \((\(-1\))\)\^\(j + k\))\)\ \((\(-4\)\ \((\(-1\) + 
                  k)\)\ k\ \((1 + j + k)\)\ Gamma[
                1\/2\ \((\(-1\) + j + k)\)] + \((13 + 5\ j + 21\ k)\)\ Gamma[
                1\/2\ \((3 + j + k)\)])\))\)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This form for the matrix elements ",
  Cell[BoxData[
      \(TraditionalForm\`L\_\(j\ k\)\)]],
  " does not work for ",
  Cell[BoxData[
      \(TraditionalForm\`L\_\(1\ 0\)\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`L\_\(\(\ \)\(0\ 1\)\)\)]],
  ", but these elements are zero by symmetry, so we simply set these elements \
equal to zero:"
}], "Text"],

Cell[BoxData[
    \(\(L[0, 1] = \(L[1, 0] = 0\);\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.157"],

Cell[TextData[{
  "The elements of the matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["S",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " can also be determined analytically :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(S[j_, k_]\  = \ 
      Simplify[norm[v[j, x], v[k, x]], j + k > \(-1\)]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.158"],

Cell[BoxData[
    \(\(\((2\/3)\)\^\(\(-\(1\/2\)\) - j\/2 - k\/2\)\ \((1 + \((\(-1\))\)\^\(j \
+ k\))\)\ Gamma[1\/2\ \((3 + j + k)\)]\)\/\(1 + j + k\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We now construct the matrices and determine their eigenvalues and \
eigenvectors, taking ",
  Cell[BoxData[
      \(TraditionalForm\`M = 10\)]],
  ":"
}], "Text"],

Cell[BoxData[{\(M = 10;\), "\[IndentingNewLine]", 
    StyleBox[\( (*\ construct\ the\ matrices\ *) \),
      FontColor->RGBColor[0, 0, 
      1]], "\[IndentingNewLine]", \(Smat\  = \ 
        Table[S[j, k], {j, 0, M}, {k, 0, M}];\), "\n", \(Lmat\  = \ 
        Table[L[j, k], {j, 0, M}, {k, 0, M}];\), "\[IndentingNewLine]", 
    StyleBox[\( (*\ 
        take\ the\ \((numerical)\)\ inverse\ of\ S\ and\ matrix\ multiply\ it\
\ by\ L\ *) \),
      FontColor->RGBColor[0, 0, 
      1]], "\[IndentingNewLine]", \(mat\  = \ 
        Inverse[Smat\  // N] . Lmat;\), "\[IndentingNewLine]", 
    StyleBox[\( (*\ find\ the\ eigenvalues\ and\ eigenvectors\ *) \),
      FontColor->RGBColor[0, 0, 
      1]], "\n", \(lam = Eigenvalues[mat];\), "\n", \(c = 
        Eigenvectors[mat];\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.159"],

Cell[TextData[{
  "The lowest eigenvalues are very close to the exact result, ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n = n + 1/2\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reverse[lam\ ]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.160"],

Cell[BoxData[
    \({0.5000000108181728`, 1.5000025657726987`, 2.500014487659602`, 
      3.5007342672320707`, 4.502009033309626`, 5.533931766890636`, 
      6.559606098799942`, 7.887756864326234`, 9.018403789946419`, 
      11.369241202442145`, 12.669966579461617`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(InputForm[%]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.161"],

Cell["\<\
{0.5000000108181728, 1.5000025657726987, 
 2.500014487659602, 3.5007342672320707, 
 4.502009033309626, 5.533931766890636, 
 6.559606098799942, 7.887756864326234, 
 9.018403789946419, 11.369241202442145, 
 12.669966579461617}\
\>", "Output"]
}, Open  ]],

Cell[TextData[{
  "The error could be reduced even further, by taking ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " larger. The eigenfunctions can also be constructed from the basis \
functions using Eq. ",
  ButtonBox["(6.3.9)",
    ButtonData:>"(6.3.9)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\[Psi][n_, x_]\  := \ 
      Sum[\(c[\([M - n + 1]\)]\)[\([j + 1]\)] v[j, x], {j, 0, M}]\)], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 6.162"],

Cell[TextData[{
  "In Cell ",
  ButtonBox["6.163",
    ButtonData:>"Cell 6.163",
    ButtonStyle->"Hyperlink"],
  " we plot the first few modes. One can easily check that they closely match \
the exact  eigenmodes. The reader is invited to vary ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " as well as the form of the basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_m\)(x)\)]],
  " in order to study the convergence properties of this method."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        Plot[Evaluate[\[Psi][n, x]], {x, \(-8\), 8}, PlotRange \[Rule] All, 
          PlotLabel \[Rule] \*"\"\<Galerkin \!\(\[Psi]\_n\)(x), n=\>\"" <> 
              ToString[n]], {n, 0, 3}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.163"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0595238 0.0147231 0.596769 [
[.05357 .00222 -12 -9 ]
[.05357 .00222 12 0 ]
[.20238 .00222 -6 -9 ]
[.20238 .00222 6 0 ]
[.35119 .00222 -12 -9 ]
[.35119 .00222 12 0 ]
[.64881 .00222 -9 -9 ]
[.64881 .00222 9 0 ]
[.79762 .00222 -3 -9 ]
[.79762 .00222 3 0 ]
[.94643 .00222 -9 -9 ]
[.94643 .00222 9 0 ]
[.4875 .13408 -18 -4.5 ]
[.4875 .13408 0 4.5 ]
[.4875 .25343 -18 -4.5 ]
[.4875 .25343 0 4.5 ]
[.4875 .37278 -18 -4.5 ]
[.4875 .37278 0 4.5 ]
[.4875 .49214 -18 -4.5 ]
[.4875 .49214 0 4.5 ]
[.4875 .61149 -6 -4.5 ]
[.4875 .61149 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05357 .01472 m
.05357 .02097 L
s
[(-7.5)] .05357 .00222 0 1 Mshowa
.20238 .01472 m
.20238 .02097 L
s
[(-5)] .20238 .00222 0 1 Mshowa
.35119 .01472 m
.35119 .02097 L
s
[(-2.5)] .35119 .00222 0 1 Mshowa
.64881 .01472 m
.64881 .02097 L
s
[(2.5)] .64881 .00222 0 1 Mshowa
.79762 .01472 m
.79762 .02097 L
s
[(5)] .79762 .00222 0 1 Mshowa
.94643 .01472 m
.94643 .02097 L
s
[(7.5)] .94643 .00222 0 1 Mshowa
.125 Mabswid
.08333 .01472 m
.08333 .01847 L
s
.1131 .01472 m
.1131 .01847 L
s
.14286 .01472 m
.14286 .01847 L
s
.17262 .01472 m
.17262 .01847 L
s
.23214 .01472 m
.23214 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.29167 .01472 m
.29167 .01847 L
s
.32143 .01472 m
.32143 .01847 L
s
.38095 .01472 m
.38095 .01847 L
s
.41071 .01472 m
.41071 .01847 L
s
.44048 .01472 m
.44048 .01847 L
s
.47024 .01472 m
.47024 .01847 L
s
.52976 .01472 m
.52976 .01847 L
s
.55952 .01472 m
.55952 .01847 L
s
.58929 .01472 m
.58929 .01847 L
s
.61905 .01472 m
.61905 .01847 L
s
.67857 .01472 m
.67857 .01847 L
s
.70833 .01472 m
.70833 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.76786 .01472 m
.76786 .01847 L
s
.82738 .01472 m
.82738 .01847 L
s
.85714 .01472 m
.85714 .01847 L
s
.8869 .01472 m
.8869 .01847 L
s
.91667 .01472 m
.91667 .01847 L
s
.02381 .01472 m
.02381 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .13408 m
.50625 .13408 L
s
[(0.2)] .4875 .13408 1 0 Mshowa
.5 .25343 m
.50625 .25343 L
s
[(0.4)] .4875 .25343 1 0 Mshowa
.5 .37278 m
.50625 .37278 L
s
[(0.6)] .4875 .37278 1 0 Mshowa
.5 .49214 m
.50625 .49214 L
s
[(0.8)] .4875 .49214 1 0 Mshowa
.5 .61149 m
.50625 .61149 L
s
[(1)] .4875 .61149 1 0 Mshowa
.125 Mabswid
.5 .04456 m
.50375 .04456 L
s
.5 .0744 m
.50375 .0744 L
s
.5 .10424 m
.50375 .10424 L
s
.5 .16392 m
.50375 .16392 L
s
.5 .19375 m
.50375 .19375 L
s
.5 .22359 m
.50375 .22359 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .31311 m
.50375 .31311 L
s
.5 .34295 m
.50375 .34295 L
s
.5 .40262 m
.50375 .40262 L
s
.5 .43246 m
.50375 .43246 L
s
.5 .4623 m
.50375 .4623 L
s
.5 .52198 m
.50375 .52198 L
s
.5 .55182 m
.50375 .55182 L
s
.5 .58165 m
.50375 .58165 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Galerkin) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
123.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
128.250 13.000 moveto
(H) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
140.250 13.000 moveto
(L) show
146.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
164.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
170.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
176.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .01472 m
.02846 .01472 L
.03279 .01472 L
.03754 .01472 L
.04262 .01472 L
.04795 .01472 L
.053 .01472 L
.05753 .01472 L
.06244 .01472 L
.06751 .01472 L
.07308 .01472 L
.0789 .01472 L
.08435 .01472 L
.0941 .01472 L
.10458 .01472 L
.11468 .01472 L
.12571 .01472 L
.1458 .01472 L
.15067 .01472 L
.15593 .01472 L
.16057 .01472 L
.16311 .01472 L
.16548 .01472 L
.1668 .01472 L
.16821 .01472 L
.16901 .01472 L
.16978 .01472 L
.17046 .01472 L
.17121 .01472 L
.17184 .01472 L
.17253 .01472 L
.17326 .01472 L
.17394 .01472 L
.17516 .01472 L
.17648 .01472 L
.17769 .01472 L
.17901 .01472 L
.18168 .01472 L
.18415 .01472 L
.18645 .01472 L
.1915 .01472 L
.19435 .01472 L
.19697 .01472 L
.2017 .01472 L
.20691 .01472 L
.21594 .01473 L
.22087 .01473 L
.22549 .01474 L
.23047 .01475 L
.2359 .01476 L
Mistroke
.24103 .01478 L
.24578 .0148 L
.25049 .01482 L
.25476 .01485 L
.25969 .0149 L
.26432 .01496 L
.26899 .01504 L
.27411 .01516 L
.27945 .01534 L
.28444 .01556 L
.28911 .01583 L
.29336 .01614 L
.29828 .0166 L
.30292 .01717 L
.30753 .01787 L
.3126 .01886 L
.3179 .02018 L
.32287 .02175 L
.33175 .02556 L
.33674 .02841 L
.3413 .03157 L
.35113 .04053 L
.36027 .05216 L
.37029 .06951 L
.38098 .09446 L
.39125 .12564 L
.40237 .16804 L
.42253 .26707 L
.44205 .38121 L
.4524 .44227 L
.4635 .50247 L
.47417 .55044 L
.47922 .56854 L
.4839 .58219 L
.48858 .59261 L
.49105 .59672 L
.49232 .59845 L
.49368 .60003 L
.49487 .60115 L
.49595 .60197 L
.49699 .60258 L
.49809 .60303 L
.49929 .60329 L
.50041 .60332 L
.50164 .60311 L
.50296 .60261 L
.50419 .60188 L
.50554 .60079 L
.50827 .59767 L
.51081 .59371 L
Mistroke
.51318 .58908 L
.51853 .5755 L
.52428 .55637 L
.5348 .51089 L
.54442 .46029 L
.56503 .33882 L
.58415 .23141 L
.60265 .14777 L
.61299 .11185 L
.62236 .08588 L
.6324 .06434 L
.64162 .04945 L
.65175 .03756 L
.65685 .03301 L
.66245 .02893 L
.6677 .02585 L
.67266 .02348 L
.68197 .02022 L
.68718 .01891 L
.692 .01795 L
.69728 .01714 L
.70289 .01648 L
.70779 .01605 L
.71227 .01574 L
.7172 .01548 L
.72238 .01527 L
.72691 .01514 L
.73111 .01504 L
.73573 .01496 L
.74066 .0149 L
.746 .01485 L
.75092 .01481 L
.75631 .01479 L
.76203 .01477 L
.76699 .01475 L
.77163 .01475 L
.77672 .01474 L
.78218 .01473 L
.78745 .01473 L
.79232 .01472 L
.79768 .01472 L
.80337 .01472 L
.80599 .01472 L
.80881 .01472 L
.8113 .01472 L
.81393 .01472 L
.8163 .01472 L
.81891 .01472 L
.82005 .01472 L
.82127 .01472 L
Mistroke
.82241 .01472 L
.82348 .01472 L
.8247 .01472 L
.82535 .01472 L
.82605 .01472 L
.82679 .01472 L
.82748 .01472 L
.82879 .01472 L
.83 .01472 L
.83113 .01472 L
.83237 .01472 L
.83369 .01472 L
.83668 .01472 L
.8395 .01472 L
.84477 .01472 L
.86491 .01472 L
.88328 .01472 L
.89371 .01472 L
.90345 .01472 L
.91307 .01472 L
.91846 .01472 L
.92338 .01472 L
.92856 .01472 L
.93419 .01472 L
.93952 .01472 L
.94444 .01472 L
.94818 .01472 L
.95222 .01472 L
.95953 .01472 L
.96376 .01472 L
.96822 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008oooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM02;ooooo00GoA4A4o`000?l0003o<S8bomgMg@0Pooooo`Go00001Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@12ooooo`Go00001Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@0Qooooo`05odA4A?l0003o0000oc8b<_oMgMd08oooool00ol0003o
k^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01oooooo000Sooooo`03
oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo02Cooooo00?oMgMgoc8b<_oo
ool07oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
047ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0S
ooooo`03ogMgMolb<S;ooooo02;ooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool07_ooool001Wooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000oooo
ooooool05oooool6o`0000Oooooo00?o0000ooooooooool05_ooool6o`0000?ooooo00?oV9RHob4Q
8Oo^k^h04Oooool00ol0003oooooooooo`11ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0Qooooo`03ojVYZOmEEEGooooo013ooooo00?o0000oooo
ooooool07Oooool002Cooooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8booooo`0Tooooo`03
ogMgMolb<S;ooooo027ooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`13ooooo`03
oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool08oooool00omgMgOo<S8booooo`0Sooooo`03
ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool07_ooool002Cooooo00?oEEEEolc<c?ooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<02;ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Soooo
o`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c015ooooo`03ogMgMomVIVKo
oooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Qooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
9?ooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07oooool002Cooooo
00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0Vooooo`03ojVYZOmgMgOooooo00_ooooo
00?o0000ooooooooool08Oooool0027ooooo00Go410@oooooooooooooooooc8b<P0<ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool08_ooool01Ol0003o^[ZjoooooonHV9So410@00co
oooo00?o0000ooooooooool0A?ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0Sooooo`05oa0@4?oooooooooooooooolb<S803?ooool0
0ol0003oooooooooo`0Qooooo`008Oooool5o`0000cooooo1?l0000Sooooo`Co00008Oooool01OnH
V9So410@o`000?lQ8B7oc<c<00cooooo1?l00013ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?oo
ool4o`0002;ooooo1?l0000Rooooo`Go00003?ooool4o`00023ooooo003oooooofWooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`00
0?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo000Hoooooooo0000>?l0000I
ooooo`007oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01?ooool9o`0000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00Co0000oooooooooooooooo2?l00007ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Nooooo`00:?ooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo01oooooo1Ol00007ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`07ooooo`?o00008Oooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo02Oooooo001nooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool0<_ooool3o`0007gooooo001oooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool0<?ooool2o`00083ooooo0020ooooo`?o0000<?ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo083ooooo0023ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0;Oooool2o`0008?ooooo0024ooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`23ooooo`00QOooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0Poooool008Gooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo08Cooooo0026ooooo`03o`000?oo
oooooooo02[ooooo0_l0000[ooooo`03o`000?oooooooooo08Gooooo0027ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`26ooooo`00R?ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Q_ooool008So
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo08Oo
oooo0029ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`28ooooo`00R_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0R?ooool008[ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo08Wooooo002;ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`29ooooo`00Roooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0R_ooool008cooooo00?o0000ooooooooool0
9?ooool2o`0002Kooooo00?o0000ooooooooool0R_ooool008cooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo08_ooooo002<ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2;ooooo`00SOooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0S?ooool008go
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo08co
oooo002=ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`2=ooooo`00S_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0SOooool008kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo08gooooo002>ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`0Qooooo`;o
00008_ooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo08oooooo002@ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2?ooooo`00T?ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Soooool0093o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo093o
oooo002Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`2@ooooo`00TOooool00ol0003oooooooooo`04ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
T?ooool0097ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo093ooooo002Aooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000Nooooo`03o`000?oooooooooo097o
oooo002Booooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2Aooooo`00
T_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`05ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0TOooool009;ooooo
00?o0000ooooooooool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo097ooooo002Cooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo09;ooooo002Cooooo`03
o`000?oooooooooo00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo09;ooooo002Coooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`2Boooo
o`00U?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool0T_ooool009Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo09?ooooo002Dooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`2Cooooo`00UOooool00ol0003oooooooooo`0Kooooo`;o00007Oooool0
0ol0003oooooooooo`2Cooooo`00UOooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0Toooool009Gooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo09Cooooo002Eooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`2Dooooo`00UOooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0U?ooool009Kooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo09Cooooo002Foooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`2Doooo
o`00U_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0UOooool009Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo09Gooooo002Fooooo`03o`000?oooooooooo01[ooooo0_l0000Kooooo`03o`000?oo
oooooooo09Gooooo002Gooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`2Eooooo`00Uoooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0U_ooool009Oooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo09Kooooo002Gooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`2Fooooo`00Uoooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0U_ooool009Sooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo09Oooooo002Hoooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`2Goooo
o`00V?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0Uoooool009Sooooo00?o0000ooooooooool06?ooool2o`0001Wooooo00?o0000ooooooooool0
Uoooool009Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo09Oooooo002Iooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`2Hooooo`00VOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0V?ooool009Wooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo09Sooooo002Iooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`2Hooooo`00VOooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0V?ooool009Sooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`2Iooooo`00V?ooool01OmgMgOoV9RHo`000?nH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`2Iooooo`00V?ooool01Ol@413oooooo`000?oooooo410@00_ooooo1Ol0
0006ooooo`?o00005_ooool00ol0003oooooooooo`2Iooooo`00V?ooool01Ol0003oooooo`000?oo
oooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo09Wooooo002Hooooo`05o`000?oooooo0000ooooool000002oooool01?oMgMgoEEEE
ooooool00007ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0VOooool009Sooooo
00Go410@oooooooooooo0000oa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`2Jooooo`00V?ooool01OmgMgOoV9RHooooool0003oMgMg00co
oooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo09[o
oooo002Hooooo`05onk^k_lb<S;o0000o`000?o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0V_ooool009_ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo09[ooooo002Kooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2Jooooo`00Voooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0V_ooool0
09cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
09_ooooo002Looooo`03o`000?oooooooooo01Cooooo0_l0000Eooooo`03o`000?oooooooooo09_o
oooo002Looooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`2Kooooo`00W?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0Voooool009cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo09_ooooo002Looooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`2Looooo`00WOooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0W?ooool009gooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo09cooooo002Mooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2Looooo`00WOooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0W?ooool0
09gooooo00?o0000ooooooooool04oooool2o`0001Cooooo00?o0000ooooooooool0W?ooool009go
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo09go
oooo002Nooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`2Mooooo`00W_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0WOooool009kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo09gooooo002Nooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`2Mooooo`00W_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0W_ooool009oooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo09kooooo002Oooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`2Nooooo`00Woooool0
0ol0003oooooooooo`0Aooooo`;o00004_ooool00ol0003oooooooooo`2Nooooo`00Woooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0W_ooool009oo
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo09ko
oooo002Oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`2Oooooo`00X?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0Woooool00:3ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo09oooooo002Pooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`2Oooooo`00V?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Co0000oooooolQ8B7o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`2Oooooo`00V?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00Co0000oooooolQ8B7o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Ko
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`2Oooooo`00V?ooool01Ol@413ooooo
oooooooooooo410@00?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00Kooooo0ol0000?ooooo`03o`000?oooooooooo0:3ooooo002Hooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`04ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0:3ooooo002Hooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`04ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0:3ooooo002Hooooo`05oa0@4?oooooo
ooooooooool@41001?ooool00ol0003oooooooooo`04ooooo`03oeEEEOn7QhOooooo00Sooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2Pooooo`00V?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Cooooo00?o0000ooooooooool01?ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0X?ooool009Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP04ooooo`03o`000?oooooooooo00Gooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0:3ooooo002Qooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2Pooooo`00X_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0XOooool00:;ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0:7ooooo002Rooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2Qooooo`00
X_ooool00ol0003oooooooooo`0>ooooo`;o00003oooool00ol0003oooooooooo`2Qooooo`00X_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0XOoo
ool00:;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo0:7ooooo002Sooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`2Rooooo`00Xoooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0X_ooool00:?ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo0:;ooooo002Sooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`2Rooooo`00Xoooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0X_ooool00:?ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:;ooooo002Sooooo`03
o`000?oooooooooo00gooooo0_l0000=ooooo`03o`000?oooooooooo0:?ooooo002Tooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2Sooooo`00Y?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Xooo
ool00:Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo0:?ooooo002Tooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`2Sooooo`00Y?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0Xoooool00:Gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo0:?ooooo002Uooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2Tooooo`00YOooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Y?ooool00:Gooooo00?o0000oooo
ooooool02oooool2o`0000cooooo00?o0000ooooooooool0Y?ooool00:Gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0:Cooooo002Vooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2Tooooo`00Y_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0YOoo
ool00:Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo0:Gooooo002Vooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`2Uooooo`00Y_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0YOooool009Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q0oooool01_l0003oc<c<ob4Q8Ol0003o8B4Qolc<c0Kooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`2Uooooo`00V?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B43
ooooo`06o`000?lQ8B7oV9RHoooooonHV9So8B4Q1_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo0:Kooooo002Hooooo`05oa0@4?ooooooooooooooool@41002_ooool2o`0000?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0:Kooooo
002Hooooo`05o`000?ooooooooooooooool000002_ooool01_l0003o<S8boiRHV?ooooooV9RHoc8b
<PKooooo0ol00009ooooo`03o`000?oooooooooo0:Kooooo002Hooooo`05o`000?oooooooooooooo
ool000002_ooool00ol0003oc<c<o`000002o`000003olc<c?oooooooooo00Cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`2Vooooo`00V?ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0Y_ooool009Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooookZj^_l000001_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0:Oooooo002H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Ol0003o410@o`000?l@413oZJVY00Kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Wooooo`00Z?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Yoooool00:Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0:Oooooo002Yoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Woooo
o`00ZOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0Z?ooool00:Wooooo00?o0000ooooooooool01oooool2o`0000Sooooo00?o0000ooooooooool0
Z?ooool00:Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0:Sooooo002Zooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2Xooooo`00Z_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0Z?ooool00:[ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0:Wooooo002Zooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Yooooo`00Z_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ZOooool00:_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0:Wooooo002[oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Yoooo
o`00Zoooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`2Zooooo`00
Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
Z_ooool00:cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0:[ooooo002/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`2[ooooo`00[?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0Zoooool00:gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0:_ooooo002]ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`2/ooooo`00[Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[?ooool00:kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0:cooooo002^oooo
o`03o`000?oooooooooo00;ooooo0_l00003ooooo`03o`000?oooooooooo0:gooooo002^ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2]ooooo`00
[_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
[Oooool00:oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo0:kooooo
002_ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`2_ooooo`00/?oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo0:oooooo002aooooo`05o`000?oo
oooo0000ooooool00000/_ooool00:Wooooo1?l000000ol@413oooooooooo`02ooooo`?o0000/ooo
ool00:_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2booooo`00Zoooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo002[ooooo`03o`000?oooooooooo00Go
oooo0ol0002booooo`00Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo
002[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:Wooooo00?oEEEEofIVI_l00000_?ooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00;;ooooo00?o^[Zjoc8b<_ooool00_ooool01?l0003oooooooooool0
0008ooooo`03ogMgMomVIVKooooo00Sooooo00?oIVIVogMgMoooool01Oooool00ol0003o^[Zjoooo
o`2?ooooo`00/oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01Ooo
ool00ooMgMgo410@onk^kP09ooooo`03onk^k_l@413ogMgM00Gooooo0_lb<S:@ooooo`00KOooool0
1OnYZJWo410@o`000?l@413oEEEE00?ooooo00KoV9RHo`000?l0003oMgMgoa0@4?l00002ooooo`Go
00000oooool02?o^k^koEEEEo`000?l0003oA4A4okZj^_oooooo410@1Ol00003ooooo`;o00000_oo
ool00ol@413o0000o`000002ooooo`Go00000_ooool01?l@413o0000o`000?ooool2o`000003oa0@
4?oooooooooo00?ooooo00OoV9RHoa0@4?l0003o0000ojVYZOoooooo000000;ooooo00?o0000oooo
ooooool01Oooool01?mEEEGoV9RHooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7QomVIVKo
oooo00Cooooo00?oQhN7o`000?nj^[X02oooool01?l@413o0000o`000?ooool2o`000003oa0@4?oo
oooooooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1`ooooo`00K?ooool01_nYZJWo0000okZj
^_ooooooc<c<o`0000?ooooo00Go0000olc<c?o^k^koQhN7o`000005ooooo`03o`000?oooooooooo
00?ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4103ooooo`03o`000?oooooooooo00Gooooo00Go
0000ooooooo^k^ko<S8bolc<c005ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000006ooooo`06o`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj0ol00008ooooo`0:o`000?oooooo
ooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?ok^k^o`000?ooool01?ooool00oo<
c<co0000oa0@400<ooooo`05o`000?ooooooooooooooool000000_ooool6o`000006oooooomgMgOo
V9RHoooooonHV9SoMgMgL?ooool006cooooo00?o8B4QojVYZOooool00_ooool02Ol0003ooooooooo
oooooooo410@ohN7Qoooooook^k^o`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`04o`000?nHV9So<S8bolc<c0Kooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Ko<S8bonk^k_nHV9SoEEEE
omgMgOl@410;ooooo`03oc8b<_oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<1Oooool00ol0
003oooooooooo`0Booooo`05o`000?ooooooooooooooool000002Oooool01Ol@413ooooooooooooo
oooo410@073ooooo001/ooooo`03o`000?oooooooooo00?o000000Go410@oooooooooooo^[Zjoa0@
4003o`0000Gooooo00?o0000ooooooooool00oooool6o`0000?ooooo00?o0000ooooooooool01Ooo
ool00ol0003o410@oiRHV007ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000006ooooo`07okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c00:ooooo`03oc8b<_oooooooooo
00;ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool00ol0003oooooooooo`0Booooo`05o`000?oooooo
ooooooooool000000_ooool6o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool0K_oo
ool006cooooo00?o0000ooooooooool02Oooool00oo<c<co0000ooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?lb<S;ogMgM00Gooooo
00Co0000onk^k_mEEEGoQhN71_ooool00ol0003oooooooooo`03ooooo`05o`000?n7QhOoooooojVY
ZOl000001_ooool01oo^k^ko0000ooooool0003oooooofIVI_n7QhL02_ooool00ol0003ok^k^oooo
o`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<PCooooo00?ok^k^o`000?ooool04oooool01Ol0003oQhN7
oooooonYZJWo000000Wooooo00Go0000ooooooooooooooooo`00001`ooooo`00K?ooool01_lQ8B7o
ZJVYooooooooooook^k^oa0@40Cooooo00Co<S8bo`000?l0003oV9RH1Oooool00ol0003ooooooooo
o`03ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool2o`000004ojVYZOlQ8B7o0000ob4Q
8@?ooooo00Go0000oooooom4A4Co0000oa0@4003ooooo`03oa0@4?l0003o000000Cooooo00?o410@
o`000?mgMgL00_l000000onHV9Soooooooooo`04ooooo`04ofIVI_nHV9Sooooooc8b<P;o^[Zj00?o
0000ooooooooool02?ooool01?mEEEGoMgMgooooooooool2o`0000;ooooo0_l00003ooooo`03ogMg
MomEEEGooooo01;ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`07ooooo`05oa0@
4?ooooooooooooooool@4100L?ooool006cooooo00KoZJVYob4Q8OoMgMgoooooohN7Qol0000=oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06oooool00omVIVKoQhN7ooooo`0;oooo
o`03omgMgOl@413ok^k^00Wooooo00?ok^k^oa0@4?oMgMd08_ooool01OmgMgOoV9RHoooooonHV9So
MgMg073ooooo001]ooooo`05oiRHV?l@413o0000ob4Q8Ol000003Oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00onYZJWoA4A4ooooo`0<
ooooo`03ogMgMomVIVKooooo00Sooooo00?oIVIVogMgMoooool08_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^073ooooo001mooooo`03oa0@4?l0003o000001Gooooo0_l00009ooooo`03oa0@4?oooooo
oooo0<Gooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-9.71045, -0.0816598, \
0.0676215, 0.0067448}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0595238 0.30903 0.491191 [
[.05357 .29653 -12 -9 ]
[.05357 .29653 12 0 ]
[.20238 .29653 -6 -9 ]
[.20238 .29653 6 0 ]
[.35119 .29653 -12 -9 ]
[.35119 .29653 12 0 ]
[.64881 .29653 -9 -9 ]
[.64881 .29653 9 0 ]
[.79762 .29653 -3 -9 ]
[.79762 .29653 3 0 ]
[.94643 .29653 -9 -9 ]
[.94643 .29653 9 0 ]
[.4875 .01432 -24 -4.5 ]
[.4875 .01432 0 4.5 ]
[.4875 .11255 -24 -4.5 ]
[.4875 .11255 0 4.5 ]
[.4875 .21079 -24 -4.5 ]
[.4875 .21079 0 4.5 ]
[.4875 .40727 -18 -4.5 ]
[.4875 .40727 0 4.5 ]
[.4875 .50551 -18 -4.5 ]
[.4875 .50551 0 4.5 ]
[.4875 .60374 -18 -4.5 ]
[.4875 .60374 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05357 .30903 m
.05357 .31528 L
s
[(-7.5)] .05357 .29653 0 1 Mshowa
.20238 .30903 m
.20238 .31528 L
s
[(-5)] .20238 .29653 0 1 Mshowa
.35119 .30903 m
.35119 .31528 L
s
[(-2.5)] .35119 .29653 0 1 Mshowa
.64881 .30903 m
.64881 .31528 L
s
[(2.5)] .64881 .29653 0 1 Mshowa
.79762 .30903 m
.79762 .31528 L
s
[(5)] .79762 .29653 0 1 Mshowa
.94643 .30903 m
.94643 .31528 L
s
[(7.5)] .94643 .29653 0 1 Mshowa
.125 Mabswid
.08333 .30903 m
.08333 .31278 L
s
.1131 .30903 m
.1131 .31278 L
s
.14286 .30903 m
.14286 .31278 L
s
.17262 .30903 m
.17262 .31278 L
s
.23214 .30903 m
.23214 .31278 L
s
.2619 .30903 m
.2619 .31278 L
s
.29167 .30903 m
.29167 .31278 L
s
.32143 .30903 m
.32143 .31278 L
s
.38095 .30903 m
.38095 .31278 L
s
.41071 .30903 m
.41071 .31278 L
s
.44048 .30903 m
.44048 .31278 L
s
.47024 .30903 m
.47024 .31278 L
s
.52976 .30903 m
.52976 .31278 L
s
.55952 .30903 m
.55952 .31278 L
s
.58929 .30903 m
.58929 .31278 L
s
.61905 .30903 m
.61905 .31278 L
s
.67857 .30903 m
.67857 .31278 L
s
.70833 .30903 m
.70833 .31278 L
s
.7381 .30903 m
.7381 .31278 L
s
.76786 .30903 m
.76786 .31278 L
s
.82738 .30903 m
.82738 .31278 L
s
.85714 .30903 m
.85714 .31278 L
s
.8869 .30903 m
.8869 .31278 L
s
.91667 .30903 m
.91667 .31278 L
s
.02381 .30903 m
.02381 .31278 L
s
.97619 .30903 m
.97619 .31278 L
s
.25 Mabswid
0 .30903 m
1 .30903 L
s
.5 .01432 m
.50625 .01432 L
s
[(-0.6)] .4875 .01432 1 0 Mshowa
.5 .11255 m
.50625 .11255 L
s
[(-0.4)] .4875 .11255 1 0 Mshowa
.5 .21079 m
.50625 .21079 L
s
[(-0.2)] .4875 .21079 1 0 Mshowa
.5 .40727 m
.50625 .40727 L
s
[(0.2)] .4875 .40727 1 0 Mshowa
.5 .50551 m
.50625 .50551 L
s
[(0.4)] .4875 .50551 1 0 Mshowa
.5 .60374 m
.50625 .60374 L
s
[(0.6)] .4875 .60374 1 0 Mshowa
.125 Mabswid
.5 .03887 m
.50375 .03887 L
s
.5 .06343 m
.50375 .06343 L
s
.5 .08799 m
.50375 .08799 L
s
.5 .13711 m
.50375 .13711 L
s
.5 .16167 m
.50375 .16167 L
s
.5 .18623 m
.50375 .18623 L
s
.5 .23535 m
.50375 .23535 L
s
.5 .25991 m
.50375 .25991 L
s
.5 .28447 m
.50375 .28447 L
s
.5 .33359 m
.50375 .33359 L
s
.5 .35815 m
.50375 .35815 L
s
.5 .38271 m
.50375 .38271 L
s
.5 .43183 m
.50375 .43183 L
s
.5 .45639 m
.50375 .45639 L
s
.5 .48095 m
.50375 .48095 L
s
.5 .53007 m
.50375 .53007 L
s
.5 .55463 m
.50375 .55463 L
s
.5 .57918 m
.50375 .57918 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Galerkin) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
123.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
128.250 13.000 moveto
(H) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
140.250 13.000 moveto
(L) show
146.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
164.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
170.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
176.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .30903 m
.02846 .30903 L
.03279 .30903 L
.03754 .30903 L
.04262 .30903 L
.04795 .30903 L
.053 .30903 L
.05753 .30903 L
.06244 .30903 L
.06751 .30903 L
.07308 .30903 L
.0789 .30903 L
.08435 .30903 L
.0941 .30904 L
.09957 .30904 L
.10458 .30904 L
.11442 .30904 L
.12357 .30905 L
.14429 .30907 L
.16309 .30909 L
.17297 .3091 L
.17837 .30911 L
.18342 .30911 L
.18598 .30911 L
.1873 .30911 L
.18873 .30911 L
.18955 .30911 L
.1903 .30911 L
.19101 .30911 L
.19179 .30911 L
.19248 .30911 L
.19314 .30911 L
.19383 .30911 L
.19457 .30911 L
.19581 .30911 L
.19652 .30911 L
.19718 .30911 L
.1985 .30911 L
.19992 .30911 L
.20249 .30911 L
.20483 .30911 L
.20981 .30911 L
.21243 .3091 L
.21521 .3091 L
.21638 .3091 L
.21763 .3091 L
.21835 .3091 L
.21901 .3091 L
.2203 .3091 L
.22145 .3091 L
Mistroke
.22271 .3091 L
.2239 .3091 L
.225 .3091 L
.22629 .3091 L
.22765 .30911 L
.22882 .30911 L
.23009 .30911 L
.23147 .30911 L
.23294 .30912 L
.2356 .30913 L
.23828 .30914 L
.24081 .30916 L
.24309 .30918 L
.24556 .30921 L
.25026 .30928 L
.25263 .30932 L
.25524 .30938 L
.25986 .30952 L
.26418 .3097 L
.26889 .30995 L
.27404 .31032 L
.27941 .31084 L
.2844 .31147 L
.2891 .31223 L
.29336 .31309 L
.30292 .31575 L
.30779 .31761 L
.31293 .32003 L
.32214 .32582 L
.32727 .33002 L
.33206 .33469 L
.34296 .34849 L
.35339 .36656 L
.36328 .38865 L
.38183 .44316 L
.40003 .50786 L
.41039 .54426 L
.42013 .57372 L
.42476 .58497 L
.42963 .59428 L
.43218 .59796 L
.43353 .59954 L
.43498 .60094 L
.43631 .60196 L
.43752 .60264 L
.43873 .6031 L
.43988 .60332 L
.44109 .60331 L
.44178 .6032 L
.44242 .60301 L
Mistroke
.44372 .60243 L
.44445 .60198 L
.44512 .60148 L
.4463 .6004 L
.4476 .59893 L
.44995 .59548 L
.4527 .59015 L
.45562 .58292 L
.46088 .56586 L
.46624 .54318 L
.47117 .51784 L
.48231 .44689 L
.50248 .28884 L
.51235 .21063 L
.52292 .13571 L
.5329 .079 L
.53731 .05929 L
.54199 .04225 L
.5443 .03536 L
.54685 .02893 L
.54919 .0241 L
.55134 .02056 L
.55386 .01749 L
.55519 .01634 L
.55586 .01587 L
.55658 .01546 L
.5578 .01497 L
.55893 .01475 L
.55963 .01472 L
.56028 .01476 L
.5615 .01503 L
.56257 .01546 L
.56375 .01614 L
.56497 .01707 L
.56612 .01815 L
.57037 .02378 L
.57279 .02805 L
.57501 .03257 L
.57998 .04463 L
.60063 .11259 L
.61976 .18018 L
.6383 .23328 L
.64865 .25545 L
.65803 .27101 L
.66809 .28353 L
.67733 .29185 L
.68217 .29521 L
.68747 .29824 L
.69297 .30076 L
.69817 .30267 L
Mistroke
.70308 .30411 L
.70841 .30535 L
.71284 .30617 L
.71773 .30688 L
.72301 .30747 L
.72861 .30794 L
.7338 .30826 L
.73866 .30848 L
.74362 .30865 L
.74643 .30872 L
.74904 .30877 L
.75381 .30885 L
.75648 .30888 L
.7589 .3089 L
.76113 .30891 L
.76348 .30893 L
.76606 .30894 L
.76844 .30895 L
.7695 .30895 L
.77065 .30895 L
.77272 .30895 L
.77398 .30896 L
.77518 .30896 L
.77625 .30896 L
.77742 .30896 L
.77864 .30896 L
.77975 .30896 L
.78098 .30896 L
.78227 .30896 L
.78339 .30896 L
.78444 .30896 L
.78681 .30896 L
.79225 .30895 L
.79719 .30895 L
.79969 .30895 L
.80111 .30895 L
.80241 .30895 L
.80355 .30895 L
.8048 .30895 L
.80611 .30895 L
.80734 .30895 L
.80801 .30895 L
.80874 .30895 L
.80943 .30895 L
.81007 .30895 L
.81128 .30895 L
.81257 .30895 L
.81552 .30895 L
.81819 .30895 L
.82308 .30896 L
Mistroke
.82824 .30896 L
.83747 .30897 L
.8583 .30899 L
.86779 .309 L
.87797 .30901 L
.88757 .30902 L
.89631 .30902 L
.90113 .30902 L
.90624 .30902 L
.91542 .30903 L
.92052 .30903 L
.9253 .30903 L
.93055 .30903 L
.93619 .30903 L
.94102 .30903 L
.94551 .30903 L
.95043 .30903 L
.95569 .30903 L
.96122 .30903 L
.96643 .30903 L
.97112 .30903 L
.97619 .30903 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00
V?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`2booooo`00V?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2b
ooooo`00T?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`2booooo`00V?ooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o00003oooool4o`0009oooooo
002Hooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Ko
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02o`0009kooooo002Hooooo`05oa0@
4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Looooo`00V?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0Voooool009Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo09[ooooo002cooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Jooooo`00/oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0V_ooool00;?ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo09[ooooo002c
ooooo`;o00003?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo09Wooooo002coooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Ioooo
o`00/oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0V?ooool00;?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo09Sooooo002cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`2Hooooo`00/oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0Uoooool00;?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo09Oooooo002cooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2Gooooo`00/oooool2o`0000[ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`2Fooooo`00/oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0U_ooool00;?ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo09Kooooo002coooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Eoooo
o`00/oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0UOooool00;?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo09Gooooo002cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`2Dooooo`00/oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0U?ooool00;?ooooo0_l00008ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0U?ooool00;?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo09?ooooo002cooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`2Cooooo`00/oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Toooool00;?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo09;ooooo002Hoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2B
ooooo`00V?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo09;ooooo002@ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2A
ooooo`00V?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001ooo
ool3o`0000Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2Aooooo`00V?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0TOooool009Sooooo00Go
410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo097ooooo002Hooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`2@ooooo`00V?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0T?ooool00;?ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo093ooooo002cooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2?ooooo`00/oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Soooool00;?o
oooo0_l00005ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Soooool00;?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo08oooooo
002cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`2>ooooo`00/oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0S_ooool00;?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo08kooooo002cooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`2>ooooo`00/oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0SOooool00;?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo08gooooo002cooooo`;o00001?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo08gooooo002cooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`2<ooooo`00/oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0S?ooool00;?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo08cooooo
002cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`2<ooooo`00/oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0Roooool00;?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo08_ooooo002cooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`2;ooooo`00/oooool2o`0000?ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`2:ooooo`00/oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0R_ooool00;?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo08[ooooo002cooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`29ooooo`00/oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0ROooool009Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00Go0000oooooooo
ooooooooo`00000Tooooo`03o`000?oooooooooo08Wooooo002Hooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`05o`000?oooooo
ooooooooool000009Oooool00ol0003oooooooooo`28ooooo`00T?ooool6o`0000;ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00Go0000oooooooooooooooo
o`00000Uooooo`03o`000?oooooooooo08Sooooo002Hooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP06ooooo`?o000000?oooooo`000?ooool09?ooool00ol0003ooooo
ooooo`28ooooo`00V?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0
1Oooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool0Qoooool009Sooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`00000Vooooo`03o`000?oooooooooo08Oooooo002Hooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00Go0000ooooooooooooooooo`00
000Vooooo`03o`000?oooooooooo08Oooooo002Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00Go0000ooooooooooooooooo`00000Wooooo`03
o`000?oooooooooo08Kooooo002cooooo`04o`000?ooooooooooo`0002Sooooo00?o0000oooooooo
ool0Q_ooool00;?ooooo00Co0000oooooooooooo0000:?ooool00ol0003oooooooooo`26ooooo`00
/oooool01?l0003oooooooooool0000Yooooo`03o`000?oooooooooo08Gooooo002cooooo`;o0000
00?oooooo`000?ooool0:?ooool00ol0003oooooooooo`25ooooo`00/oooool01?l0003ooooooooo
ool0000Zooooo`03o`000?oooooooooo08Cooooo002cooooo`04o`000?ooooooooooo`0002[ooooo
00?o0000ooooooooool0Q?ooool00;?ooooo00Co0000oooooooooooo0000:oooool00ol0003ooooo
ooooo`23ooooo`00/oooool01?l0003oooooooooool0000[ooooo`03o`000?oooooooooo08?ooooo
002cooooo`03o`000?oooooo000002cooooo00?o0000ooooooooool0Poooool00;?ooooo00?o0000
ooooool00000;Oooool00ol0003oooooooooo`22ooooo`00/oooool00ol0003oooooo`00000]oooo
o`03o`000?oooooooooo08;ooooo002cooooo`?o0000;_ooool00ol0003oooooooooo`21ooooo`00
/oooool00ol0003oooooo`00000_ooooo`03o`000?oooooooooo083ooooo002cooooo`03o`000?oo
oooo000002oooooo00?o0000ooooooooool0P?ooool001gooooo00?o0000onk^k_ooool01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Sooooo`05odA4A?l0003o0000oc8b<_oMgMd0
8oooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd08Oooool00ol0003o
ooooo`00000Rooooo`Go00001Oooool2ob4Q8@;ooooo00Co0000ooooooooooooA4A40_l000000olb
<S;ogMgMooooo`0Sooooo`05odA4A?l0003o0000oc8b<_oMgMd09?ooool00ol0003ok^k^ooooo`05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Wooooo000Mooooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo02Gooooo00?oMgMgoc8b<_ooool08_ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo023ooooo00?o
0000ooooool000008_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B43ooooo`03o`00
0?oooooooooo00;ooooo00?oMgMgoc8b<_ooool09_ooool00omgMgOo<S8booooo`0Sooooo`03oeEE
EOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01Sooooo000Cooooo`Ko00001?oo
ool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo01Sooooo1_l00007ooooo`03o`000?oo
oooooooo01Wooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooo`00000Sooooo`03oiRHV?lQ8B7ok^k^00cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02;ooooo00?oZJVYoeEEEOooool04?oo
ool00ol0003oooooooooo`0Gooooo`007_ooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;o
oooo02Gooooo00?oMgMgoc8b<_ooool09?ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;o
oooo023ooooo0_l0000Uooooo`03oiRHV?lQ8B7ok^k^00cooooo00Go0000ooooooooooooMgMgoc8b
<P0Wooooo`03ogMgMolb<S;ooooo02Cooooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8boooo
o`0Hooooo`007_ooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`08ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<027ooooo0_l0000Vooooo`03ogMgMomVIVKooooo00_ooooo0ol000000olb<S;o
c<c<ooooo`0Sooooo`05o`000?lQ8B7o0000oc8b<_o<c<`09Oooool00omEEEGoc<c<ooooo`0;oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`06Oooool001kooooo00?oZJVYogMgMoooool02oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Sooooo`;o00009oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo0000
02Kooooo00?o0000ooooooooool09oooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo
01_ooooo000Kooooo`05oa0@4?oooooooooooooooolb<S803?ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo02Gooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooo
oooo02?ooooo0_l0000Sooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool01?l0003ooooooooo
ool0000Uooooo`03o`000?oooooooooo02Cooooo00Go410@oooooooooooooooooc8b<P0<ooooo`03
o`000?oooooooooo01_ooooo000Kooooo`Go00003?ooool4o`0002Cooooo1?l0000Tooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`03?ooool4o`0002;ooooo0_l0000Sooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`03?ooool5o`0002Cooooo1?l0000Sooooo`Go00003?ooool4o`0001[ooooo002cooooo`;o
0000>Oooool2o`0007Sooooo002cooooo`;o0000>oooool2o`0007Kooooo002cooooo`;o0000?Ooo
ool2o`0007Cooooo002cooooo`03o`000?oooooooooo03kooooo0ol0001aooooo`00/oooool00ol0
003oooooooooo`11ooooo`So0000JOooool0013oooooool00018o`00017ooooo000Hooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`Ko0000
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo000Rooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool08Oooool007Cooooo1?l0000kooooo`03o`000?oooooo
oooo0;;ooooo001hooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0/_ooool007Wo
oooo00?o0000ooooooooool0=_ooool2o`000;Cooooo001jooooo`03o`000?oooooooooo03Gooooo
0_l0002dooooo`00Noooool00ol0003oooooooooo`0dooooo`;o0000]?ooool007cooooo00?o0000
ooooooooool0<oooool3o`000;?ooooo001looooo`03o`000?oooooooooo03?ooooo0_l0002doooo
o`00OOooool00ol0003oooooooooo`0booooo`;o0000]?ooool007kooooo00?o0000ooooooooool0
<Oooool2o`000;Cooooo001oooooo`03o`000?oooooooooo033ooooo0_l0002dooooo`00P?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooo00000;Cooooo0020ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooool00000]?ooool0087ooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooo`00002dooooo`00POooool00ol0003oooooooooo`0]ooooo`04o`000?oooooo0000o`000;?o
oooo0022ooooo`03o`000?oooooooooo02cooooo00?o0000ooooool00000]?ooool008;ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooo`00002dooooo`00Poooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooo00000;Cooooo0023ooooo`03o`000?oooooooooo02[ooooo00Co0000oooo
oooooooo0000]?ooool008Cooooo00?o0000ooooooooool0:Oooool01?l0003oooooooooool0002d
ooooo`00Q?ooool00ol0003oooooooooo`0Yooooo`04o`000?ooooooooooo`000;Cooooo0025oooo
o`03o`000?oooooooooo02Sooooo00Co0000oooooooooooo0000]?ooool008Gooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`02o`000;?ooooo0025ooooo`03o`000?oooooooooo02So
oooo00Co0000oooooooooooo0000]?ooool008Kooooo00?o0000ooooooooool09oooool01?l0003o
ooooooooool0002dooooo`00Q_ooool00ol0003oooooooooo`0Vooooo`05o`000?oooooooooooooo
ool00000]?ooool008Oooooo00?o0000ooooooooool09Oooool01Ol0003ooooooooooooooooo0000
0;Cooooo0027ooooo`03o`000?oooooooooo00kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000;ooooo00Go0000ooooooooooooooooo`00002dooooo`00Qoooool00ol0
003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A002ooooo`05o`000?ooooooooooooooool00000]?ooool008Sooooo00?o
0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0
0oooool01Ol0003ooooooooooooooooo00000;Cooooo0028ooooo`03o`000?oooooooooo00gooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00;ooooo00Co0000oooooooo
oooooooo0ol0002booooo`00ROooool00ol0003oooooooooo`0<ooooo`05o`000?oooooooooooooo
ool000003_ooool01OmgMgOoIVIVoooooooooooo000000?ooooo00?o0000ooooooooool0/_ooool0
08Wooooo00?o0000ooooooooool03?ooool01Ol@413ooooooooooooooooo410@00oooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`2booooo`00R_ooool00ol0003oooooooooo`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01ol0003o^[ZjoooooonHV9So410@ooooool0
00001?ooool00ol0003oooooooooo`2booooo`00R_ooool00ol0003oooooooooo`0;ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01onHV9So410@o`000?lQ8B7oc<c<ooooool000001?ooool0
0ol0003oooooooooo`2booooo`00R_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0/_ooool008_ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo0;;ooooo002;ooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`2booooo`00S?ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo00;ooooo0_l0002cooooo`00S?ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0/_ooool008cooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;;ooooo002=ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2booooo`00
SOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
/_ooool008gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0;;ooooo002>ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`2booooo`00S_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0/_ooool008kooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`03ooooo`;o0000/oooool008kooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0;;ooooo002>ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`2booooo`00Soooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/_ooool008oooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;;ooooo002?ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2booooo`00
Soooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
/_ooool0093ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0;;ooooo002@ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01?ooool2
o`000;?ooooo002@ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`2booooo`00T?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0/_ooool0097ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0;;ooooo002Aooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`2booooo`00TOooool00ol0003oooooooooo`04
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`04ooooo`03o`000?oooooooooo0;;ooooo002Aooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0;;ooooo002Aooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@
400;ooooo`Go00001_ooool00ol0003oooooooooo`2booooo`00T_ooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`?o0000
/_ooool009;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000_ooooo
00CogMgMoeEEEOl0003o00001oooool00ol0003oooooooooo`2booooo`00T_ooool00ol0003ooooo
ooooo`03ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOo0000o`000007ooooo`03
o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03onk^k_l0003o000000Oooooo00?o0000ooooooooool0/_ooool009?ooooo
00?o0000ooooooooool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo0_l00007ooooo`03
o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`2booooo`00U?ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0/_ooool009Cooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Dooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool01oooool2o`000;?ooooo002Eooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00UOooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool009Gooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0;;ooooo002F
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2b
ooooo`00U_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0/_ooool009Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo0;;ooooo002Gooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`2booooo`00Uoooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Wooooo0_l0002cooooo`00Uoooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0/_ooool009Sooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo0;;ooooo002Hooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2booooo`00V?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0/_ooool009Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0;;ooooo002I
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2b
ooooo`00VOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0/_ooool009Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`;o
0000/oooool009[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo0;;ooooo002Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`2booooo`00V_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo0;;ooooo002Hooooo`05onk^k_lb<S;o0000oc8b
<_l000001Oooool00olQ8B7o0000ooooo`03ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool0
0ol0003oooooooooo`2booooo`00V?ooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000Cooooo00?o
0000ob4Q8Oooool00oooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0
/_ooool009Sooooo00Ko410@oooooooooooooooooa0@4?ooool2o`000003ooooool0003o000000Go
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;;ooooo002Hooooo`05
o`000?ooooooooooooooool000000_ooool2o`0000Oooooo00Go0000oiRHV?ooooooV9RHob4Q8@06
ooooo`?o0000/_ooool009Sooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2booooo`00V?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2booooo`00V?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003ooooooooo
o`2booooo`00V?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@
1_ooool00ol0003oooooooooo`2booooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00/_ooool00onj^[[o<S8booooo`02
ooooo`04o`000?ooooooooooo`0000Sooooo00?oMgMgofIVI_ooool02?ooool00omVIVKoMgMgoooo
o`05ooooo`03o`000?nj^[[ooooo08oooooo002cooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooooooo`05ooooo`03omgMgOl@413ok^k^00Wooooo00?ok^k^oa0@4?oMgMd01Ooo
ool2oc8b<Y3ooooo001]ooooo`05ojVYZOl@413o0000oa0@4?mEEED00oooool01_nHV9So0000o`00
0?mgMgOo410@o`0000;ooooo1Ol00003ooooo`08onk^k_mEEEGo0000o`000?m4A4Co^[Zjooooool@
4105o`0000?ooooo0_l00002ooooo`03oa0@4?l0003o000000;ooooo1Ol00002ooooo`04oa0@4?l0
003o0000ooooo`;o000000?o410@ooooooooool00oooool01onHV9So410@o`000?l0003oZJVYoooo
ool000000_ooool00ol0003oooooooooo`05ooooo`04oeEEEOnHV9Soooooooooo`;o00000_ooool2
o`0000?ooooo00?oQhN7ofIVI_ooool01?ooool00on7QhOo0000okZj^P0;ooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool01oooool4o`000003oa0@4?oooooooooo06gooooo001/
ooooo`06ojVYZOl0003o^[Zjooooooo<c<co00000oooool01Ol0003oc<c<onk^k_n7QhOo000000Go
oooo00?o0000ooooooooool00oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00?o0000
ooooooooool01Oooool01Ol0003oooooonk^k_lb<S;oc<c<00Gooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00Ko0000ojVYZOmEEEGoV9RHoeEEEOnj^[X3o`00
00Sooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo^k^ko
0000ooooo`04ooooo`03olc<c?l0003o410@00cooooo00Go0000ooooooooooooooooo`000002oooo
o`Ko00001?ooool00ol0003oooooooooo`1_ooooo`00K?ooool00olQ8B7oZJVYooooo`02ooooo`09
o`000?ooooooooooooooool@413oQhN7ooooooo^k^ko000000Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00Co0000oiRHV?lb<S;oc<c<
1_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01_lb<S;o
k^k^oiRHV?mEEEGogMgMoa0@40_ooooo00?o<S8booooooooool00_ooool01?oMgMgo0000oa0@4?o<
c<`5ooooo`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`00
0?oooooooooo06oooooo001/ooooo`03o`000?oooooooooo00?o000000Go410@oooooooooooo^[Zj
oa0@4003o`0000Gooooo00?o0000ooooooooool00oooool6o`0000?ooooo00?o0000ooooooooool0
1Oooool00ol0003o410@oiRHV007ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000006ooooo`07okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c00:ooooo`03oc8b<_oooooo
oooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool00ol0003oooooooooo`0Booooo`05o`000?oo
ooooooooooooool000000_ooool6o`0000Cooooo00?o0000ooooooooool0Koooool006cooooo00?o
0000ooooooooool02Oooool00oo<c<co0000ooooo`04ooooo`03o`000?oooooooooo00?ooooo00Ko
EEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?lb<S;ogMgM00Gooooo00Co0000onk^k_mE
EEGoQhN71_ooool00ol0003oooooooooo`03ooooo`05o`000?n7QhOoooooojVYZOl000001_ooool0
1oo^k^ko0000ooooool0003oooooofIVI_n7QhL02_ooool00ol0003ok^k^ooooo`02ooooo`04ob4Q
8OmgMgOoMgMgoc8b<PCooooo00?ok^k^o`000?ooool04oooool01Ol0003oQhN7oooooonYZJWo0000
00cooooo00?o0000ooooooooool0Koooool006cooooo00Ko8B4QojVYZOooooooooooonk^k_l@4104
ooooo`04oc8b<_l0003o0000oiRHV0Gooooo00?o0000ooooooooool00oooool01_o^k^koEEEEo`00
0?l0003oA4A4onk^kP;ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B43ooooo`05o`000?ooooooA4A4
o`000?l@41000oooool00ol@413o0000o`000004ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RH
ooooooooool01?ooool01?mVIVKoV9RHoooooolb<S82okZj^P03o`000?oooooooooo00Sooooo00Co
EEEEogMgMooooooooooo0_l00002ooooo`;o00000oooool00omgMgOoEEEEooooo`0Booooo`03oa0@
4?l0003oMgMg00;o000000?oV9RHooooooooool02_ooool00ol0003oooooooooo`1_ooooo`00K?oo
ool01_nYZJWo8B4QomgMgOooooooQhN7o`0000gooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Kooooo`03ofIVI_n7QhOooooo00_ooooo00?ogMgMoa0@4?o^k^h02Oooool00oo^k^ko
410@omgMg@0Uooooo`03o`000?oooooooooo06oooooo001]ooooo`05oiRHV?l@413o0000ob4Q8Ol0
00003Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool04Oooool00onYZJWoA4A4ooooo`0<ooooo`03ogMgMomVIVKooooo00Sooooo00?oIVIVogMgMooo
ool08oooool00omEEEGoIVIVo`00001aooooo`00OOooool00ol@413o0000o`00000Eooooo`;o0000
2Oooool00ol@413oooooooooo`35ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-9.2566, -0.635149, \
0.064461, 0.00781155}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0595238 0.329376 0.658474 [
[.05357 .31688 -12 -9 ]
[.05357 .31688 12 0 ]
[.20238 .31688 -6 -9 ]
[.20238 .31688 6 0 ]
[.35119 .31688 -12 -9 ]
[.35119 .31688 12 0 ]
[.64881 .31688 -9 -9 ]
[.64881 .31688 9 0 ]
[.79762 .31688 -3 -9 ]
[.79762 .31688 3 0 ]
[.94643 .31688 -9 -9 ]
[.94643 .31688 9 0 ]
[.4875 .06599 -24 -4.5 ]
[.4875 .06599 0 4.5 ]
[.4875 .19768 -24 -4.5 ]
[.4875 .19768 0 4.5 ]
[.4875 .46107 -18 -4.5 ]
[.4875 .46107 0 4.5 ]
[.4875 .59277 -18 -4.5 ]
[.4875 .59277 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05357 .32938 m
.05357 .33563 L
s
[(-7.5)] .05357 .31688 0 1 Mshowa
.20238 .32938 m
.20238 .33563 L
s
[(-5)] .20238 .31688 0 1 Mshowa
.35119 .32938 m
.35119 .33563 L
s
[(-2.5)] .35119 .31688 0 1 Mshowa
.64881 .32938 m
.64881 .33563 L
s
[(2.5)] .64881 .31688 0 1 Mshowa
.79762 .32938 m
.79762 .33563 L
s
[(5)] .79762 .31688 0 1 Mshowa
.94643 .32938 m
.94643 .33563 L
s
[(7.5)] .94643 .31688 0 1 Mshowa
.125 Mabswid
.08333 .32938 m
.08333 .33313 L
s
.1131 .32938 m
.1131 .33313 L
s
.14286 .32938 m
.14286 .33313 L
s
.17262 .32938 m
.17262 .33313 L
s
.23214 .32938 m
.23214 .33313 L
s
.2619 .32938 m
.2619 .33313 L
s
.29167 .32938 m
.29167 .33313 L
s
.32143 .32938 m
.32143 .33313 L
s
.38095 .32938 m
.38095 .33313 L
s
.41071 .32938 m
.41071 .33313 L
s
.44048 .32938 m
.44048 .33313 L
s
.47024 .32938 m
.47024 .33313 L
s
.52976 .32938 m
.52976 .33313 L
s
.55952 .32938 m
.55952 .33313 L
s
.58929 .32938 m
.58929 .33313 L
s
.61905 .32938 m
.61905 .33313 L
s
.67857 .32938 m
.67857 .33313 L
s
.70833 .32938 m
.70833 .33313 L
s
.7381 .32938 m
.7381 .33313 L
s
.76786 .32938 m
.76786 .33313 L
s
.82738 .32938 m
.82738 .33313 L
s
.85714 .32938 m
.85714 .33313 L
s
.8869 .32938 m
.8869 .33313 L
s
.91667 .32938 m
.91667 .33313 L
s
.02381 .32938 m
.02381 .33313 L
s
.97619 .32938 m
.97619 .33313 L
s
.25 Mabswid
0 .32938 m
1 .32938 L
s
.5 .06599 m
.50625 .06599 L
s
[(-0.4)] .4875 .06599 1 0 Mshowa
.5 .19768 m
.50625 .19768 L
s
[(-0.2)] .4875 .19768 1 0 Mshowa
.5 .46107 m
.50625 .46107 L
s
[(0.2)] .4875 .46107 1 0 Mshowa
.5 .59277 m
.50625 .59277 L
s
[(0.4)] .4875 .59277 1 0 Mshowa
.125 Mabswid
.5 .09891 m
.50375 .09891 L
s
.5 .13183 m
.50375 .13183 L
s
.5 .16476 m
.50375 .16476 L
s
.5 .2306 m
.50375 .2306 L
s
.5 .26353 m
.50375 .26353 L
s
.5 .29645 m
.50375 .29645 L
s
.5 .3623 m
.50375 .3623 L
s
.5 .39522 m
.50375 .39522 L
s
.5 .42815 m
.50375 .42815 L
s
.5 .49399 m
.50375 .49399 L
s
.5 .52692 m
.50375 .52692 L
s
.5 .55984 m
.50375 .55984 L
s
.5 .03306 m
.50375 .03306 L
s
.5 .00014 m
.50375 .00014 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Galerkin) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
123.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
128.250 13.000 moveto
(H) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
140.250 13.000 moveto
(L) show
146.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
164.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
170.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
176.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .32938 m
.02846 .32937 L
.03279 .32937 L
.03754 .32937 L
.04262 .32937 L
.04795 .32937 L
.053 .32937 L
.05753 .32937 L
.06244 .32937 L
.06751 .32937 L
.07308 .32936 L
.0789 .32936 L
.08435 .32936 L
.0941 .32935 L
.10458 .32933 L
.11468 .32931 L
.12571 .32929 L
.1458 .32923 L
.15593 .3292 L
.1609 .32919 L
.16548 .32918 L
.16805 .32917 L
.17076 .32917 L
.17217 .32917 L
.17349 .32917 L
.17424 .32917 L
.17493 .32917 L
.17572 .32917 L
.17648 .32917 L
.17768 .32917 L
.17896 .32917 L
.18005 .32917 L
.18125 .32917 L
.18254 .32917 L
.18393 .32917 L
.18645 .32918 L
.19141 .32919 L
.19602 .3292 L
.20151 .32922 L
.20649 .32923 L
.20901 .32924 L
.21043 .32924 L
.21174 .32924 L
.21288 .32924 L
.21414 .32924 L
.21546 .32924 L
.21669 .32924 L
.21737 .32924 L
.2181 .32924 L
.21944 .32923 L
Mistroke
.22074 .32923 L
.22195 .32922 L
.22468 .3292 L
.22621 .32918 L
.22759 .32917 L
.22992 .32913 L
.23248 .32908 L
.23515 .32901 L
.23764 .32893 L
.2421 .32873 L
.24687 .32845 L
.25248 .32797 L
.25778 .32734 L
.26254 .32658 L
.26771 .32551 L
.27257 .32422 L
.27713 .32269 L
.28256 .32041 L
.28752 .31778 L
.29764 .3104 L
.30296 .3052 L
.30854 .29852 L
.31811 .28369 L
.32832 .26231 L
.33796 .23623 L
.3467 .2075 L
.36755 .12422 L
.37669 .08614 L
.38674 .0492 L
.39141 .0354 L
.39398 .02905 L
.39642 .02398 L
.39868 .02018 L
.39987 .01856 L
.40114 .01712 L
.40221 .01617 L
.40339 .01539 L
.40445 .01493 L
.40546 .01472 L
.40661 .01476 L
.40788 .01515 L
.4092 .01595 L
.41043 .01707 L
.41158 .01845 L
.41263 .01999 L
.41498 .02446 L
.41752 .03084 L
.42026 .03966 L
.42526 .06075 L
.43014 .0876 L
Mistroke
.4347 .11808 L
.44511 .204 L
.46614 .41195 L
.47653 .50428 L
.48165 .54114 L
.4864 .56852 L
.49069 .58682 L
.49309 .59419 L
.49527 .59902 L
.49651 .60099 L
.49766 .60227 L
.49892 .6031 L
.49955 .60329 L
.50025 .60332 L
.50142 .60294 L
.50267 .60196 L
.50386 .60047 L
.50493 .59865 L
.50722 .59334 L
.50975 .58524 L
.51486 .56195 L
.51959 .53284 L
.52403 .49979 L
.5448 .30225 L
.55374 .21466 L
.56329 .13297 L
.56878 .09438 L
.57377 .06564 L
.57878 .0432 L
.58351 .02807 L
.58594 .02254 L
.58727 .02015 L
.58852 .01833 L
.58967 .01697 L
.59072 .01602 L
.59188 .01527 L
.59313 .01481 L
.59378 .01472 L
.59446 .01472 L
.59569 .01498 L
.59645 .0153 L
.59716 .01572 L
.59848 .01677 L
.59976 .01811 L
.60093 .01962 L
.60356 .02394 L
.60846 .03505 L
.61383 .05106 L
.62467 .09164 L
.64587 .17967 L
Mistroke
.66516 .24533 L
.67477 .26944 L
.6852 .28934 L
.69505 .30296 L
.70414 .31193 L
.7088 .31544 L
.71381 .31854 L
.72286 .32269 L
.72838 .3245 L
.73363 .32582 L
.73834 .32674 L
.74348 .3275 L
.74879 .32809 L
.75379 .32849 L
.75829 .32875 L
.76315 .32895 L
.76568 .32903 L
.76846 .3291 L
.77136 .32915 L
.77407 .32919 L
.77537 .3292 L
.7766 .32921 L
.77892 .32923 L
.78021 .32923 L
.78141 .32924 L
.78272 .32924 L
.78338 .32924 L
.78412 .32924 L
.78533 .32924 L
.78646 .32924 L
.7877 .32924 L
.7884 .32924 L
.78903 .32924 L
.7903 .32924 L
.79169 .32924 L
.7942 .32923 L
.80345 .3292 L
.80872 .32919 L
.8116 .32918 L
.8143 .32918 L
.8166 .32917 L
.81778 .32917 L
.81906 .32917 L
.81979 .32917 L
.82047 .32917 L
.82117 .32917 L
.8218 .32917 L
.82302 .32917 L
.82431 .32917 L
.82551 .32917 L
Mistroke
.82664 .32917 L
.82787 .32917 L
.82919 .32917 L
.83189 .32917 L
.83435 .32918 L
.83909 .32919 L
.84358 .3292 L
.86441 .32926 L
.88266 .32931 L
.89304 .32933 L
.90278 .32934 L
.91232 .32935 L
.91768 .32936 L
.92259 .32936 L
.93283 .32937 L
.93798 .32937 L
.9436 .32937 L
.94786 .32937 L
.95187 .32937 L
.95937 .32937 L
.96357 .32937 L
.96744 .32937 L
.97619 .32938 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o/oooool2
o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002C
ooooo`?o00007Oooool00ol0003oooooooooo`0Kooooo`?o0000U?ooool009;ooooo0_l00002oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02o`00
09?ooooo002Booooo`05o`000?ooooooooooooooool000007?ooool00ol0003oooooooooo`0Joooo
o`05o`000?ooooooooooooooool00000Toooool0097ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`2@ooooo`00TOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo093o
oooo002@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Soooool0093ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Hooooo`;o00006Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo08oooooo002?ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0S_ooool008oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2>oooo
o`00Soooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo08kooooo002>ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0SOooool008kooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`2=ooooo`00S_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo08gooooo002>ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0SOooool008go
oooo00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?l0003ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0SOooool008gooooo00?o0000ooooooooool02?ooool01OmgMgOo
V9RHooooool0003oMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo08cooooo002=ooooo`03
o`000?oooooooooo00Ko00000_ooool01Ol@413oooooooooool0003o410@00_ooooo1Ol00006oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2<oooo
o`00SOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;o00002oooool01?m4A4Co
gMgMooooool00007ooooo`?o00005Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
08cooooo002<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_l0000;ooooo`04
omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo08_ooooo002<ooooo`03o`000?oooooooooo00Wooooo00Go410@oooooooo
oooo0000oa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo08_ooooo002<ooooo`03o`000?oooooooooo00Wo
oooo00GoMgMgoiRHV?ooooooV9RHo`00000<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08_ooooo002<ooooo`03
o`000?oooooooooo00Wooooo00Gok^k^oc8b<_l0003o<S8bo`00000=ooooo`03ogMgMol0003ooooo
00Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
08[ooooo002;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0R_ooool008_ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`2:ooooo`00Roooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo08Wooooo002;ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0ROooool008[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`29oooo
o`00R_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo0_l0000Eooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0ROooool008[ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`28ooooo`00R_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo08Sooooo0029ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0R?ooool0
08Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`28ooooo`00ROooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo08Oooooo0029ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0Qoooool008Wooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`27ooooo`00R?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo08Oooooo0028oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Q_ooool008Sooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`26ooooo`00R?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01;ooooo0_l0000Cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
Q_ooool008Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`26ooooo`00Qoooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo08Gooooo0027ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0QOooool008Oooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`25ooooo`00Q_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo08Gooooo
0026ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0QOooool008Kooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`24ooooo`00Q_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo08Cooooo0025ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0Q?ooool008Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`24ooooo`00QOoo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo013ooooo0_l0000Booooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0Poooool008Cooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`23ooooo`00Q?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
08?ooooo0024ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Poooool008Cooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`22ooooo`00Poooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo08;ooooo0023ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0P_ooool008?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`22oooo
o`00Poooool00ol0003oooooooooo`0Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01?l0
003oooooob4Q8OlQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool0POooool008;ooooo00?o0000ooooooooool04oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ob4Q8OlQ8B401?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo087ooooo0022ooooo`03o`000?oooooooooo00_ooooo1_l00002ooooo`05oa0@4?oooooo
ooooooooool@41001?ooool00ol0003oooooooooo`05ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo087ooooo0022
ooooo`03o`000?oooooooooo01?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo00Kooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`00013ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`20ooooo`00P_ooool00ol0003oooooooooo`0Cooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo083ooooo0021
ooooo`03o`000?oooooooooo01Cooooo00Go410@oooooooooooooooooa0@4004ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0P?ooool0087ooooo00?o0000ooooooooool05?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool01?ooool01Ol0003o^[Zjoooo
oonHV9So410@00Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo083ooooo0021ooooo`03o`000?oooooooooo01Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP04ooooo`03o`000?oooooooooo00Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1oooooo`00
P?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo07oooooo0020ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool0Ooooool0083ooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`1nooooo`00Ooooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
07kooooo001oooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0O_ooool007oooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`1nooooo`00O_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00kooooo0_l0000?ooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool0OOooool007kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1m
ooooo`00O_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo07gooooo001mooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool0O?ooool007gooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`1looooo`00OOooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo07cooooo001looooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0Noooool0
07cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1kooooo`00O?ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo07_ooooo001kooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0N_ooool007_ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0=ooooo`;o00003_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07[ooooo001k
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0N_ooool007[ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`1iooooo`00N_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo07Wooooo001iooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
N?ooool007Sooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1hooooo`00N?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07Oooooo001gooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0M_ooool007Oooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`1fooooo`007?ooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM02Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Mooooo`03o`000?oooooooooo
00;ooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01?ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Cooooo1Ol00005
ooooo`;o8B4Q1Oooool01om4A4Co0000o`000?lb<S;ogMgMooooool000008Oooool01Om4A4Co0000
o`000?lb<S;ogMgM02Gooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Hooooo`007?ooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`0Vooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000ooooooooool00oooool01OnHV9So
8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01;ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool01?mgMgOo<S8booooool0000Tooooo`03ogMgMolb
<S;ooooo02Cooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05ooo
ool001;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool06Oooool6
o`0000Oooooo00?o0000ooooooooool06?ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h04Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00cooooo0_l0000=ooooo`03o`000?oooooo
oooo01Gooooo00?oV9RHob4Q8Oo^k^h04Oooool01?l0003oooooooooool0000Tooooo`03o`000?oo
oooooooo02?ooooo00?oZJVYoeEEEOooool04?ooool00ol0003oooooooooo`0Fooooo`007Oooool0
0olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo02Kooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool04_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05_ooool0
0onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00;ooooo00?o0000ooooooooool08?ooool0
0omgMgOo<S8booooo`0Uooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool05oooool0
01gooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00Kooooo`03o`000?oooooooooo00Oooooo00?oMgMgofIVI_ooool02ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo01Oooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool07?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
02Kooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Sooooo000Moooo
o`03ojVYZOmgMgOooooo00_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo02Sooooo00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`0Joooo
o`006_ooool01Ol@413ooooooooooooooooo<S8b00cooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00Kooooo00Go0000okZj^_ooooooV9RHoa0@400<
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01Cooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Uooooo`05oa0@4?oo
oooooooooooooolb<S803?ooool00ol0003oooooooooo`0Jooooo`006_ooool5o`0000cooooo1?l0
000Uooooo`Co00006?ooool2o`0000Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co0000
5Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
5?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00008ooooo`03o`000?oooooooooo01Wo
oooo1?l0000Tooooo`Go00003?ooool4o`0001Wooooo001^ooooo`;o0000=Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0<_ooool2o`0006oooooo
001]ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo03Cooooo0_l0001]ooooo`00Joooool2o`0003Sooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool0J_ooool006Sooooo0ol0000jooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0hooooo`?o0000JOooool0067ooooo1ol0000mooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0kooooo`Go
0000I?ooool000ooooooool0001:o`00013ooooo000Gooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
2Oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool0027ooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo023ooooo
002Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`2Tooooo`00Y_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0Y?ooool00:Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo0:Cooooo002Vooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`2Uooooo`00Y_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0YOooool00:Kooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0:Gooooo002Vooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Uooooo`00Y_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0YOooool00:Ko
oooo00?o0000ooooooooool02_ooool2o`0000_ooooo00?o0000ooooooooool0YOooool00:Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0:Gooooo
002Wooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`2Uooooo`00Yoooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0YOooool00:Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo0:Kooooo002Wooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`2Vooooo`00Yoooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0Y_ooool00:Oooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0:Kooooo002Wooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Vooooo`00Yoooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Y_ooool00:Oo
oooo00?o0000ooooooooool02Oooool2o`0000[ooooo00?o0000ooooooooool0Y_ooool00:Oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0:Kooooo
002Xooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`2Vooooo`00Z?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0Yoooool00:Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo0:Oooooo002Xooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`2Wooooo`00Z?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0Yoooool00:Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0:Oooooo002Xooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Wooooo`00Z?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Yoooool00:So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0:Oo
oooo002Xooooo`03o`000?oooooooooo00Sooooo0_l00009ooooo`03o`000?oooooooooo0:Oooooo
002Yooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`2Wooooo`00ZOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0Z?ooool00:Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0:Sooooo002Yooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`2Xooooo`00ZOooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0Z?ooool00:Wooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0:Sooooo002Yooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Xooooo`00ZOooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Z?ooool009So
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`2Xooooo`00V?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?l0003ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0:Sooooo002Hooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0onHV9So0000onk^kP07ooooo`?o00001_ooool00ol0003oooooooooo`2Yooooo`00V?ooool01Ol0
003ooooooooooooooooo000000gooooo00?o0000ob4Q8Oo^k^h01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo0:Wooooo002Hooooo`05o`000?ooooooooooooooool000003Oooool0
0ol0003oMgMgofIVIP06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ZOooool0
09Sooooo00Go410@oooooooooooooooooa0@400=ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`2Yooooo`00V?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_l0003oV9RHoa0@4006ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0ZOooool009Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0:Wooooo
002Zooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`2Yooooo`00Z_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0ZOooool00:[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0:Wooooo002Zooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2Zooooo`00Zoooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0Z_ooool00:_ooooo00?o0000ooooooooool01Ooo
ool2o`0000Kooooo00?o0000ooooooooool0Z_ooool00:_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:[ooooo002[ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Zooooo`00Zoooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Z_ooool00:_ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:[ooooo
002[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2Zooooo`00Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0Zoooool00:cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0:_ooooo002/ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`2[ooooo`00[?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0Zoooool00:cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:_ooooo002/ooooo`03o`000?oooooo
oooo00Cooooo0_l00004ooooo`03o`000?oooooooooo0:cooooo002/ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2/ooooo`00[Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[?ooool00:gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0:cooooo
002]ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`2/ooooo`00[Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0[?ooool00:gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo0:cooooo002^ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`2]ooooo`00[_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0[Oooool00:kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:gooooo002^ooooo`03o`000?oooooo
oooo00;ooooo0_l00003ooooo`03o`000?oooooooooo0:gooooo002^ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2]ooooo`00[oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool0[Oooool00:oooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo0:gooooo002_ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`2^ooooo`00[oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool0[_ooool00:oooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo0:kooooo002`ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool0[_ooool00;3ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`2_oooo
o`00V?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000Go410@oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`000;7ooooo002Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo0:oooooo002Hooooo`05oa0@4?ooooooooooooooool@4100
2oooool5o`0000Cooooo00?o0000ooooool000000_l0002booooo`00V?ooool01Ol0003ooooooooo
oooooooo000000_ooooo00CoA4A4omgMgOoooooo00001Oooool01Ol0003oooooo`000?oooooo0000
0;;ooooo002Hooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00005
ooooo`05o`000?oooooo0000ooooool00000/_ooool009Sooooo00Go410@oooooooooooooooooa0@
400<ooooo`03ogMgMoo<c<co000000Kooooo0ol0002cooooo`00V?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2booooo`00V?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooooooo
o`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool00ol0003oooooooooo`2booooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00/_ooool00onj^[[o<S8boooo
o`02ooooo`04o`000?ooooooooooo`0000Sooooo00?oMgMgofIVI_ooool02?ooool00omVIVKoMgMg
ooooo`05ooooo`03o`000?nj^[[ooooo08oooooo002cooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`05ooooo`03omgMgOl@413ok^k^00Wooooo00?ok^k^oa0@4?oMgMd0
1Oooool2oc8b<Y3ooooo001]ooooo`05ojVYZOl@413o0000oa0@4?mEEED00oooool01_nHV9So0000
o`000?mgMgOo410@o`0000;ooooo1Ol00003ooooo`08onk^k_mEEEGo0000o`000?m4A4Co^[Zjoooo
ool@4105o`0000?ooooo0_l00002ooooo`03oa0@4?l0003o000000;ooooo1Ol00002ooooo`04oa0@
4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool01onHV9So410@o`000?l0003oZJVY
ooooool000000_ooool00ol0003oooooooooo`05ooooo`04oeEEEOnHV9Soooooooooo`;o00000_oo
ool2o`0000?ooooo00?oQhN7ofIVI_ooool01?ooool00on7QhOo0000okZj^P0;ooooo`04oa0@4?l0
003o0000ooooo`;o000000?o410@ooooooooool01_ooool5o`00073ooooo001/ooooo`06ojVYZOl0
003o^[Zjooooooo<c<co00000oooool01Ol0003oc<c<onk^k_n7QhOo000000Gooooo00?o0000oooo
ooooool00oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool01Ooo
ool01Ol0003oooooonk^k_lb<S;oc<c<00Gooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Ko0000ojVYZOmEEEGoV9RHoeEEEOnj^[X3o`0000Sooooo00[o0000
ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo^k^ko0000ooooo`04oooo
o`03olc<c?l0003o410@00cooooo00Go0000ooooooooooooooooo`000002ooooo`Ko000000Kooooo
oiRHV?lQ8B7ok^k^oooooom4A4A`ooooo`00K?ooool00olQ8B7oZJVYooooo`02ooooo`09o`000?oo
ooooooooooooool@413oQhN7ooooooo^k^ko000000Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00Co0000oiRHV?lb<S;oc<c<1_ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01_lb<S;ok^k^oiRH
V?mEEEGogMgMoa0@40_ooooo00?o<S8booooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`5oooo
o`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`00000:ooooo`03oiRHV?lQ8B7o
k^k^077ooooo001/ooooo`03o`000?oooooooooo00?o000000Go410@oooooooooooo^[Zjoa0@4003
o`0000Gooooo00?o0000ooooooooool00oooool6o`0000?ooooo00?o0000ooooooooool01Oooool0
0ol0003o410@oiRHV007ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`07okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c00:ooooo`03oc8b<_oooooooooo00;o
oooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool00ol0003oooooooooo`0Booooo`05o`000?oooooooooo
ooooool000000_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h0L?ooool006cooooo00?o0000oooo
ooooool02Oooool00oo<c<co0000ooooo`04ooooo`03o`000?oooooooooo00?ooooo00KoEEEEohN7
Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?lb<S;ogMgM00Gooooo00Co0000onk^k_mEEEGoQhN7
1_ooool00ol0003oooooooooo`03ooooo`05o`000?n7QhOoooooojVYZOl000001_ooool01oo^k^ko
0000ooooool0003oooooofIVI_n7QhL02_ooool00ol0003ok^k^ooooo`02ooooo`04ob4Q8OmgMgOo
MgMgoc8b<PCooooo00?ok^k^o`000?ooool04oooool01Ol0003oQhN7oooooonYZJWo000000cooooo
00?oMgMgofIVI_ooool0Koooool006cooooo00Ko8B4QojVYZOooooooooooonk^k_l@4104ooooo`04
oc8b<_l0003o0000oiRHV0Gooooo00?o0000ooooooooool00oooool01_o^k^koEEEEo`000?l0003o
A4A4onk^kP;ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B43ooooo`05o`000?ooooooA4A4o`000?l@
41000oooool00ol@413o0000o`000004ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooooooo
ool01?ooool01?mVIVKoV9RHoooooolb<S82okZj^P03o`000?oooooooooo00Sooooo00CoEEEEogMg
Mooooooooooo0_l00002ooooo`;o00000oooool00omgMgOoEEEEooooo`0Booooo`03oa0@4?l0003o
MgMg00;o000000?oV9RHooooooooool02oooool00ol0003oooooooooo`1^ooooo`00K?ooool01_nY
ZJWo8B4QomgMgOooooooQhN7o`0000gooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Kooooo`03ofIVI_n7QhOooooo00_ooooo00?ogMgMoa0@4?o^k^h02Oooool00oo^k^ko410@omgM
g@0Rooooo`05o`000?nj^[[ooooooiRHV?l@4100L?ooool006gooooo00GoV9RHoa0@4?l0003o8B4Q
o`00000=ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Aooooo`03ojVYZOm4A4Cooooo00cooooo00?oMgMgofIVI_ooool02?ooool00omVIVKoMgMg
ooooo`0Rooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0L?ooool007gooooo00?o410@o`000?l00000
5Oooool2o`0000Wooooo00?o410@ooooooooool0aOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-9.21355, -0.500216, \
0.0641612, 0.00579995}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0595238 0.30902 0.818412 [
[.05357 .29652 -12 -9 ]
[.05357 .29652 12 0 ]
[.20238 .29652 -6 -9 ]
[.20238 .29652 6 0 ]
[.35119 .29652 -12 -9 ]
[.35119 .29652 12 0 ]
[.64881 .29652 -9 -9 ]
[.64881 .29652 9 0 ]
[.79762 .29652 -3 -9 ]
[.79762 .29652 3 0 ]
[.94643 .29652 -9 -9 ]
[.94643 .29652 9 0 ]
[.4875 .0635 -24 -4.5 ]
[.4875 .0635 0 4.5 ]
[.4875 .14534 -24 -4.5 ]
[.4875 .14534 0 4.5 ]
[.4875 .22718 -24 -4.5 ]
[.4875 .22718 0 4.5 ]
[.4875 .39086 -18 -4.5 ]
[.4875 .39086 0 4.5 ]
[.4875 .4727 -18 -4.5 ]
[.4875 .4727 0 4.5 ]
[.4875 .55454 -18 -4.5 ]
[.4875 .55454 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05357 .30902 m
.05357 .31527 L
s
[(-7.5)] .05357 .29652 0 1 Mshowa
.20238 .30902 m
.20238 .31527 L
s
[(-5)] .20238 .29652 0 1 Mshowa
.35119 .30902 m
.35119 .31527 L
s
[(-2.5)] .35119 .29652 0 1 Mshowa
.64881 .30902 m
.64881 .31527 L
s
[(2.5)] .64881 .29652 0 1 Mshowa
.79762 .30902 m
.79762 .31527 L
s
[(5)] .79762 .29652 0 1 Mshowa
.94643 .30902 m
.94643 .31527 L
s
[(7.5)] .94643 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.1131 .30902 m
.1131 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.17262 .30902 m
.17262 .31277 L
s
.23214 .30902 m
.23214 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.29167 .30902 m
.29167 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.41071 .30902 m
.41071 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.47024 .30902 m
.47024 .31277 L
s
.52976 .30902 m
.52976 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.58929 .30902 m
.58929 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.70833 .30902 m
.70833 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.76786 .30902 m
.76786 .31277 L
s
.82738 .30902 m
.82738 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.8869 .30902 m
.8869 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .0635 m
.50625 .0635 L
s
[(-0.3)] .4875 .0635 1 0 Mshowa
.5 .14534 m
.50625 .14534 L
s
[(-0.2)] .4875 .14534 1 0 Mshowa
.5 .22718 m
.50625 .22718 L
s
[(-0.1)] .4875 .22718 1 0 Mshowa
.5 .39086 m
.50625 .39086 L
s
[(0.1)] .4875 .39086 1 0 Mshowa
.5 .4727 m
.50625 .4727 L
s
[(0.2)] .4875 .4727 1 0 Mshowa
.5 .55454 m
.50625 .55454 L
s
[(0.3)] .4875 .55454 1 0 Mshowa
.125 Mabswid
.5 .07986 m
.50375 .07986 L
s
.5 .09623 m
.50375 .09623 L
s
.5 .1126 m
.50375 .1126 L
s
.5 .12897 m
.50375 .12897 L
s
.5 .16171 m
.50375 .16171 L
s
.5 .17807 m
.50375 .17807 L
s
.5 .19444 m
.50375 .19444 L
s
.5 .21081 m
.50375 .21081 L
s
.5 .24355 m
.50375 .24355 L
s
.5 .25992 m
.50375 .25992 L
s
.5 .27628 m
.50375 .27628 L
s
.5 .29265 m
.50375 .29265 L
s
.5 .32539 m
.50375 .32539 L
s
.5 .34176 m
.50375 .34176 L
s
.5 .35812 m
.50375 .35812 L
s
.5 .37449 m
.50375 .37449 L
s
.5 .40723 m
.50375 .40723 L
s
.5 .4236 m
.50375 .4236 L
s
.5 .43997 m
.50375 .43997 L
s
.5 .45633 m
.50375 .45633 L
s
.5 .48907 m
.50375 .48907 L
s
.5 .50544 m
.50375 .50544 L
s
.5 .52181 m
.50375 .52181 L
s
.5 .53818 m
.50375 .53818 L
s
.5 .04713 m
.50375 .04713 L
s
.5 .03076 m
.50375 .03076 L
s
.5 .01439 m
.50375 .01439 L
s
.5 .57091 m
.50375 .57091 L
s
.5 .58728 m
.50375 .58728 L
s
.5 .60365 m
.50375 .60365 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Galerkin) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
123.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
128.250 13.000 moveto
(H) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
140.250 13.000 moveto
(L) show
146.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
164.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
170.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
176.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .30902 m
.02846 .30902 L
.03279 .30902 L
.03754 .30902 L
.04262 .30901 L
.04795 .30901 L
.053 .30901 L
.05753 .309 L
.06244 .309 L
.06751 .30899 L
.07308 .30898 L
.0789 .30897 L
.08435 .30895 L
.0941 .30891 L
.09957 .30888 L
.10458 .30884 L
.11442 .30876 L
.12357 .30865 L
.1336 .30849 L
.14429 .3083 L
.16426 .30788 L
.16974 .30777 L
.17273 .30772 L
.17552 .30768 L
.1781 .30765 L
.18045 .30763 L
.1818 .30762 L
.18307 .30762 L
.18376 .30761 L
.18441 .30761 L
.18512 .30761 L
.18587 .30761 L
.18707 .30761 L
.18834 .30761 L
.18942 .30762 L
.1906 .30763 L
.19187 .30764 L
.19324 .30765 L
.19569 .30769 L
.19818 .30775 L
.20053 .30781 L
.20492 .30797 L
.21016 .30824 L
.215 .30857 L
.22031 .30904 L
.22594 .30967 L
.23537 .31109 L
.24067 .31214 L
.24551 .31328 L
.25491 .31614 L
Mistroke
.26382 .31994 L
.26887 .32273 L
.27344 .32577 L
.27836 .32969 L
.28367 .33486 L
.29315 .34702 L
.30207 .36277 L
.3116 .38517 L
.32205 .41696 L
.34312 .50014 L
.35317 .54202 L
.36267 .57603 L
.36792 .59018 L
.37089 .59615 L
.3723 .59842 L
.37363 .60018 L
.37483 .60145 L
.37593 .60233 L
.37715 .603 L
.37847 .60332 L
.37966 .60325 L
.38097 .60276 L
.38163 .60235 L
.38233 .60179 L
.3836 .60045 L
.38484 .59872 L
.3862 .59634 L
.38895 .58996 L
.39149 .58214 L
.39387 .57314 L
.39923 .54689 L
.40499 .50984 L
.42515 .32612 L
.43531 .2239 L
.44067 .17493 L
.44637 .13021 L
.45133 .09949 L
.45415 .08602 L
.45681 .07628 L
.45799 .0729 L
.45924 .06999 L
.4603 .06805 L
.46146 .06648 L
.46272 .06548 L
.46342 .06522 L
.46406 .06519 L
.4653 .06565 L
.46648 .06672 L
.46763 .06838 L
.46887 .07082 L
Mistroke
.4711 .07696 L
.47376 .08708 L
.47619 .09894 L
.48146 .13256 L
.48647 .17318 L
.50491 .36098 L
.51451 .45338 L
.51978 .49427 L
.52236 .51087 L
.52473 .52388 L
.52695 .53392 L
.52937 .54256 L
.53063 .54603 L
.53181 .54864 L
.53305 .55072 L
.53375 .55158 L
.53438 .55217 L
.5355 .55277 L
.53653 .55282 L
.53767 .55233 L
.53887 .55117 L
.53992 .54964 L
.5409 .54777 L
.54313 .54195 L
.54556 .5332 L
.54783 .5229 L
.55297 .49243 L
.56332 .40712 L
.58183 .22171 L
.59237 .12809 L
.59754 .09084 L
.60231 .06277 L
.60664 .04282 L
.60886 .03472 L
.61123 .0276 L
.61361 .02207 L
.61584 .01833 L
.61719 .0167 L
.61848 .01561 L
.61964 .015 L
.6209 .01472 L
.62155 .01472 L
.62224 .01484 L
.62347 .01533 L
.62479 .01625 L
.62554 .01695 L
.62624 .0177 L
.62866 .02112 L
.63125 .02605 L
.63616 .03851 L
Mistroke
.64063 .0528 L
.66162 .13801 L
.67169 .17853 L
.68237 .21545 L
.69226 .24269 L
.70153 .2622 L
.71034 .27598 L
.71981 .28668 L
.72519 .29125 L
.73032 .29481 L
.73536 .29769 L
.73994 .29986 L
.74952 .30337 L
.75478 .30484 L
.75973 .30599 L
.76856 .3076 L
.7735 .3083 L
.77812 .30884 L
.78308 .30931 L
.78762 .30966 L
.79265 .30996 L
.79545 .31008 L
.79805 .31018 L
.80051 .31026 L
.80323 .31033 L
.80596 .31038 L
.80745 .3104 L
.80886 .31041 L
.81011 .31042 L
.81143 .31043 L
.81256 .31043 L
.81379 .31043 L
.81449 .31043 L
.81512 .31043 L
.81585 .31043 L
.81654 .31043 L
.81777 .31042 L
.81911 .31041 L
.82146 .31039 L
.82399 .31036 L
.82857 .31029 L
.83897 .3101 L
.86001 .30966 L
.87014 .30948 L
.88118 .30933 L
.89161 .30923 L
.90128 .30916 L
.90637 .30913 L
.91187 .3091 L
.91671 .30909 L
Mistroke
.92183 .30907 L
.92646 .30906 L
.93153 .30905 L
.9358 .30904 L
.94045 .30904 L
.94509 .30903 L
.94948 .30903 L
.95339 .30903 L
.95771 .30903 L
.96237 .30902 L
.96731 .30902 L
.97189 .30902 L
.97619 .30902 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool2o`0002Gooooo0ol0002;ooooo`00/oooool00ol0003oooooooooo`0Soooo
o`04o`000?ooooooooooo`0008_ooooo002cooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`28ooooo`00/oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0R?ooool00;?ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Oooooo002cooooo`;o00008_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Oooooo002cooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`26ooooo`00/oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Q_ooool00;?o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo08Go
oooo002cooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`25ooooo`00/oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0QOooool00;?ooooo0_l0000Qooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0Q?ooool00;?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo08Cooooo002Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`24ooooo`00V?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Q?ooool0093ooooo1_l00002
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`23ooooo`00V?ooool0
1Ol0003ooooooooooooooooo000000[ooooo00Ko0000ooooooooooooooooojVYZOl@4106ooooo`?o
00007_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo08?ooooo002Hooooo`05o`00
0?ooooooooooooooool000002Oooool3o`000004ooooool@413o0000okZj^PKooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo08?ooooo002Hooooo`05
oa0@4?ooooooooooooooool@41002Oooool01ol0003oooooo`000?l0003ooooookZj^_lQ8B401_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Pooo
ool009Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`08o`000?oooooooooooa0@4?l0003o
oooookZj^_l00006ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`22ooooo`00V?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00So0000oooo
ooooooooZJVYoa0@4?l0003o410@ojVYZ@Kooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo08;ooooo002Uooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01_ooool2o`0001kooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`22ooooo`00Y?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08;ooooo002Toooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0POooool00:Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`21ooooo`00Y?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo087ooooo002Sooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0POoo
ool00:?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o00007_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo083ooooo002Sooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0P?ooool00:?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`20ooooo`00Xoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo083ooooo
002Rooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Ooooool00:;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`04ooooo`;o00007Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo07oooooo002Rooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0Ooooool00:;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1oooooo`00
X_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo07kooooo002Qooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0O_ooool00:7ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`03ooooo`;o00007?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo07kooooo002Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0O_ooool00:7o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1mooooo`00V?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Cooooo00?o0000ob4Q8OlQ8B401?ooool6o`0000Gooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo07gooooo002Hooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01?ooool00ol0003o8B4Qob4Q8@04ooooo`06oiRHV?lQ8B7ok^k^oooo
oom4A4Co00001Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0OOooool0093ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41001?ooool0
0ol0003oooooooooo`05ooooo`05oiRHV?lQ8B7ok^k^ooooool000001Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0OOooool009Sooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^kooooo
o`000004ooooo`?o00006_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo07cooooo
002Hooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`07ooooo`04ogMg
MomVIVKoooooo`0000Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo07cooooo002Hooooo`05oa0@4?ooooooooooooooool@41001?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo07cooooo002Hooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool00ol0003oooooooooo`05ooooo`07o`000?nj^[[ooooooiRHV?l@413oooooo`000004
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1l
ooooo`00V?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool01Oooool0
1onHV9So410@o`000?lQ8B7oc<c<ooooool000001?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0O?ooool00:3ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`02ooooo`;o00006oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo07_ooooo002Pooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Noooool0
0:3ooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo000001cooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`1kooooo`00X?ooool00ol0003oooooooooo`0<oooo
o`05o`000?ooooooooooooooool000007?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo07_ooooo002Pooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`00000L
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Noooool00:3ooooo00?o0000oooo
ooooool03?ooool01?l0003oooooooooooooool2o`0001[ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`1jooooo`00X?ooool00ol0003oooooooooo`0<ooooo`05o`000?oooooooooo
ooooool000006oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo07[ooooo002Poooo
o`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0N_ooool00:3ooooo00?o0000ooooooooool03?ooool01Ol0
003ooooooooooooooooo000001_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1i
ooooo`00Woooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000006oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo07Wooooo002Oooooo`03o`000?oooooooooo
00kooooo00Co0000oooooooooooo00006oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo07Wooooo002Oooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_l0000Joooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0N?ooool009oooooo00?o0000oooooooo
ool03_ooool01?l0003oooooooooool0000Kooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool0N?ooool009oooooo00?o0000ooooooooool03_ooool01?l0003oooooooooool0000Koooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0N?ooool009oooooo00?o0000oooooooo
ool03_ooool01?l0003oooooooooool0000Kooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0Moooool009oooooo00?o0000ooooooooool03_ooool01?l0003oooooooooool0000Koooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0Moooool009oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`02o`0001Wooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`1gooooo`00W_ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`0001[o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1fooooo`00W_ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?ooooooooooo`0001[ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`1fooooo`00V?ooool01oo^k^ko<S8bo`000?lb<S;ok^k^ooooool000000oooool2ob4Q
8@Gooooo1?l000001?l@413oooooooooool00002ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`1fooooo`00V?ooool01omgMgOoV9RHoooooonHV9So
MgMgooooool000000oooool2ob4Q8@Oooooo00?o0000ooooooooool00oooool00ol0003oooooo`00
000Jooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0MOooool0093ooooo1_l00002
ooooo`07oa0@4?ooooooooooooooool@413oooooo`00000<ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooool000000_l0000Hooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
MOooool009Sooooo00Oo0000ooooooooooooooooo`000?oooooo000000cooooo00?o0000oooooooo
ool00oooool00ol0003oooooo`00000Jooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool0MOooool009Sooooo00Oo0000ooooooooooooooooo`000?oooooo000000cooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`00000Jooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0M?ooool009Sooooo00Oo410@oooooooooooooooooa0@4?oooooo000000cooooo00?o0000
ooooooooool00oooool00ol0003oooooo`00000Jooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0M?ooool009Sooooo00OoMgMgoiRHV?ooooooV9RHogMgMooooooo000000cooooo00?o
0000ooooooooool00oooool00ol0003oooooo`00000Jooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0M?ooool009Sooooo00Ook^k^oc8b<_l0003o<S8bonk^k_oooooo000000[ooooo
00?oEEEEofIVI_l000001Oooool00ol0003oooooo`00000Iooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0Loooool009gooooo00?o0000ooooooooool04Oooool01?l0003oooooo`00
0?l0000Hooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Loooool009gooooo00?o
0000ooooooooool04Oooool00ol0003oooooo`00000Iooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0Loooool009gooooo00?o0000ooooooooool04Oooool00ol0003oooooo`00000I
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0L_ooool009gooooo00?o0000oooo
ooooool04_ooool2o`0001Wooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1boooo
o`00WOooool00ol0003oooooooooo`0Booooo`;o00006Oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo077ooooo002Mooooo`03o`000?oooooooooo01;ooooo0ol0000Hooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0LOooool009gooooo00?o0000ooooooooool04_oo
ool2o`0001Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1`ooooo`00WOooool0
0ol0003oooooooooo`0Booooo`;o00006Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo073ooooo000Looooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd09?ooool01Om4A4Co0000o`000?lb<S;ogMgM02;ooooo1Ol00005ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00cooooo00?o0000ooooooooool04_ooool2o`0001Wooooo
00?o0000ooooooooool02Oooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01oooool00ol0003oooooooooo`0Iooooo`05odA4A?l0003o0000oc8b<_oMgMd09Oooool00ol0
003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo000Loooo
o`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo02Kooooo00?oMgMgoc8b
<_ooool08Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00_ooooo00?o0000ooooooooool04_ooool2o`0001Sooooo00?o0000ooooooooool02_ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Oooooo00?o
0000ooooooooool06oooool00omgMgOo<S8booooo`0Tooooo`03oeEEEOnYZJWooooo00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo01Oooooo000Booooo`Ko00001?ooool00onYZJWoEEEEooooo`0@
ooooo`03o`000?oooooooooo01Wooooo1_l00007ooooo`03o`000?oooooooooo01Sooooo1_l00003
ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0B
ooooo`;o00006?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02?ooooo00?oZJVY
oeEEEOooool04?ooool00ol0003oooooooooo`0Fooooo`007Oooool00olQ8B7oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo02Kooooo00?oMgMgoc8b<_ooool08oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo00[ooooo00?o0000ooooooooool04oooool3o`0001Oooooo00?o0000oooo
ooooool03?ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00Sooooo00?o0000oooo
ooooool06_ooool00omgMgOo<S8booooo`0Uooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b
<_ooool05oooool001gooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
02Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Uooooo`03ogMgMomVIVKooooo00_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00;ooooo`03o`000?oooooooooo01?ooooo0_l0000Hooooo`03o`000?oo
oooooooo00gooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00[ooooo
00?o0000ooooooooool05_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo00?oEEEEolc<c?oo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Sooooo000Mooooo`03ojVYZOmgMgOooooo00_o
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Cooooo`;o00006?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo02Sooooo00?oZJVYogMgMoooool02oooool00ol0003o
ooooooooo`0Jooooo`006_ooool01Ol@413ooooooooooooooooo<S8b00cooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Tooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`0>
ooooo`;o00005Oooool00ol0003oooooooooo`0Uooooo`05oa0@4?oooooooooooooooolb<S803?oo
ool00ol0003oooooooooo`0Jooooo`006_ooool5o`0000cooooo1?l0000Uooooo`Co00008oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0000<ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0:ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
3?ooool4o`0000oooooo00?o0000ooooooooool04_ooool4o`0002Cooooo1Ol0000<ooooo`Co0000
6Oooool009cooooo00?o0000ooooooooool05?ooool2o`0001Oooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`1Xooooo`00W?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0;oooool2o`0006Sooooo002Looooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0aooooo`Go0000Hoooool009co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0H?ooool009cooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo03Sooooo1Ol0001Mooooo`003oooooooo`0004[o00004?oo
ool001Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool5o`0000Gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`05oooooa?o00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Kooooo000Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02oooool3o`00
01oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool08?ooool006?ooooo0ol0000eooooo`03o`000?oooooooooo01Go
oooo0_l0000Fooooo`03o`000?oooooooooo09[ooooo001Vooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool05Oooool2o`0001Kooooo00?o0000ooooooooool0V_ooool006Oooooo0_l0
000booooo`03o`000?oooooooooo01Gooooo0_l0000Fooooo`03o`000?oooooooooo09[ooooo001Y
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05Oooool2o`0001Kooooo00?o0000
ooooooooool0V_ooool006[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Eoooo
o`;o00005_ooool00ol0003oooooooooo`2Jooooo`00Joooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo01Gooooo0_l0000Eooooo`03o`000?oooooooooo09_ooooo001/ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool05Oooool2o`0001Gooooo00?o0000ooooooooool0
Voooool006cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Eooooo`;o00005Ooo
ool00ol0003oooooooooo`2Kooooo`00KOooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo01Kooooo0_l0000Eooooo`03o`000?oooooooooo09_ooooo001^ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool05_ooool2o`0001Gooooo00?o0000ooooooooool0Voooool006oo
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo000001Co
oooo00?o0000ooooooooool0Voooool006oooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooo000001Cooooo00?o0000ooooooooool0Voooool0073ooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo000001Cooooo00?o
0000ooooooooool0Voooool0077ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0F
ooooo`?o00005?ooool00ol0003oooooooooo`2Kooooo`00LOooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooool000005?ooool00ol0003oooooooooo`2Koooo
o`00L_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Kooooo00?o0000ooooool0
00004oooool00ol0003oooooooooo`2Looooo`00L_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooool000004oooool00ol0003oooooooooo`2Looooo`00Looo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Oooooo00?o0000ooooool000004ooo
ool00ol0003oooooooooo`2Looooo`00Loooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooool000004oooool00ol0003oooooooooo`2Looooo`00M?ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo01Oooooo0ol0000Cooooo`03o`000?oooooooooo
09cooooo001dooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05oooool01?l0003o
ooooooooool0000Booooo`03o`000?oooooooooo09cooooo001dooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool05oooool01?l0003oooooooooool0000Booooo`03o`000?oooooooooo
09cooooo001eooooo`03o`000?oooooooooo023ooooo00Gok^k^o`000?l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooo00004_ooool0
0ol0003oooooooooo`2Looooo`00MOooool00ol0003oooooooooo`0Pooooo`05ogMgMol0003ooooo
oiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0
000Booooo`03o`000?oooooooooo09cooooo001fooooo`03o`000?oooooooooo01oooooo00Go410@
o`000?oooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo1?l0000Booooo`03o`000?oo
oooooooo09cooooo001fooooo`03o`000?oooooooooo01oooooo00Go0000ooooooooooooooooo`00
000>ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00004Oooool00ol0003ooooo
ooooo`2Mooooo`00M_ooool00ol0003oooooooooo`0Oooooo`05o`000?ooooooooooooooool00000
3_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`00017ooooo00?o0000oooooooo
ool0WOooool007Oooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooooooo410@00ko
oooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo
09gooooo001gooooo`03o`000?oooooooooo01kooooo00Go0000oiRHV?ooooooV9RHogMgM`0>oooo
o`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`2M
ooooo`00Moooool00ol0003oooooooooo`0Nooooo`05o`000?lb<S;o0000oc8b<_o^k^h03?ooool0
0omEEEGoIVIVo`000007ooooo`;o000000?oooooo`000?ooool04?ooool00ol0003oooooooooo`2M
ooooo`00N?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Sooooo00Go0000oooo
ooooooooooooo`00000@ooooo`03o`000?oooooooooo09gooooo001hooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000
ooooooooool0WOooool007Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Hoooo
o`05o`000?ooooooooooooooool000004?ooool00ol0003oooooooooo`2Mooooo`00NOooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000?
ooooo`03o`000?oooooooooo09kooooo001iooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool06Oooool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooooooool0W_ooool0
07Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Iooooo`;o00000_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo09kooooo001jooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo000000oooooo00?o0000oooo
ooooool0W_ooool007[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`05
o`000?ooooooooooooooool000003oooool00ol0003oooooooooo`2Nooooo`00N_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03o`000?oooooooooo09kooooo001jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06Oooool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooooooool0W_ooool007_o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`;o00000_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo09oooooo001kooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0Woooool007_ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`2Oooooo`00Noooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo09oooooo001loooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Woooool007cooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Jooooo`;o00000oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo09oooooo001looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
Woooool007gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Pooooo`00OOooool0
0ol0003oooooooooo`0Fooooo`07o`000?ooooook^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo0:3ooooo001mooooo`03o`000?oooooooooo01Kooooo00Oo0000oooooomgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0X?ooool007go
oooo00?o0000ooooooooool05_ooool00ol0003ooooooa0@4003ooooo`03oa0@4?oooooooooo00[o
oooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0X?ooool007kooooo00?o0000ooooooooool05?ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0000;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Pooooo`00O_ooool00ol0003ooooo
ooooo`0Dooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool03?ooool00omgMgOo
IVIVooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`2Pooooo`00O_ooool00ol0003oooooooooo`0Dooooo`04o`000?oooooooooooa0@40?o
oooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Pooooo`00O_ooool00ol0003ooooo
ooooo`0Dooooo`08o`000?ooooooooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0XOooool007oooooo00?o0000ooooooooool04oooool02?l0003oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0:7ooooo001oooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool06oooool2o`0000Cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`2Qooooo`00Ooooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo0:7ooooo001oooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0XOoo
ool0083ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Qooooo`00P?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo0:7ooooo0020ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0XOooool0083ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Looooo`;o00001Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0:7ooooo
0021ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0X_ooool0087ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`2Rooooo`00POooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0:;ooooo0021ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0X_ooool0087ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Mooooo`;o0000
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:;ooooo0022ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0X_ooool008;ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`2Rooooo`00P_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0:?ooooo0022ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Xoooool008;ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Mooooo`;o00001oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0:?ooooo0023ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool00000
Y_ooool008?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00Oooooo00Go0000ooooooooooooooooo`00002Vooooo`00Poooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool01oooool01?l0003o
ooooooooool0002Wooooo`00Poooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo
<S8b00Kooooo00?o0000ooooooooool01oooool2o`000003ooooool0003ooooo0:Kooooo0024oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`?o0000Yoooool0
08Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000/_ooool008Cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000003Oooool0
0ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0;;ooooo0025ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zj
ob4Q8Oooool01Oooool00ol0003oooooooooo`2booooo`00QOooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9So
oooookZj^_l000001_ooool00ol0003oooooooooo`2booooo`00QOooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@
413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`2booooo`00QOooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo023ooooo0_l0002cooooo`00Q_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0/_ooool008Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0;;ooooo0026ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`2booooo`00
Qoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
/_ooool008Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Qooooo`;o0000/ooo
ool008Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo0;;ooooo0028ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`2booooo`00ROooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool0/_ooool008Wooooo00Go0000ooooooooooooooooo`00000Uooooo`03
o`000?oooooooooo0;;ooooo002:ooooo`Co00009Oooool00ol0003oooooooooo`2booooo`00Rooo
ool2o`0002Kooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooo
ooooo`2booooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00/_ooool00onj^[[o<S8booooo`02ooooo`04o`000?oooooo
ooooo`0000Sooooo00?oMgMgofIVI_ooool02?ooool00omVIVKoMgMgooooo`05ooooo`03o`000?nj
^[[ooooo08oooooo002cooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`05ooooo`03omgMgOl@413ok^k^00Wooooo00?ok^k^oa0@4?oMgMd01Oooool2oc8b<Y3ooooo001]
ooooo`05ojVYZOl@413o0000oa0@4?mEEED00oooool01_nHV9So0000o`000?mgMgOo410@o`0000;o
oooo1Ol00003ooooo`08onk^k_mEEEGo0000o`000?m4A4Co^[Zjooooool@4105o`0000?ooooo0_l0
0002ooooo`03oa0@4?l0003o000000;ooooo1Ol00002ooooo`04oa0@4?l0003o0000ooooo`;o0000
00?o410@ooooooooool00oooool01onHV9So410@o`000?l0003oZJVYooooool000000_ooool00ol0
003oooooooooo`05ooooo`04oeEEEOnHV9Soooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7
ofIVI_ooool01?ooool00on7QhOo0000okZj^P0;ooooo`04oa0@4?l0003o0000ooooo`;o000000?o
410@ooooooooool01_ooool01OnHV9So410@o`000?lb<S;oc<c<073ooooo001/ooooo`06ojVYZOl0
003o^[Zjooooooo<c<co00000oooool01Ol0003oc<c<onk^k_n7QhOo000000Gooooo00?o0000oooo
ooooool00oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool01Ooo
ool01Ol0003oooooonk^k_lb<S;oc<c<00Gooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Ko0000ojVYZOmEEEGoV9RHoeEEEOnj^[X3o`0000Sooooo00[o0000
ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo^k^ko0000ooooo`04oooo
o`03olc<c?l0003o410@00cooooo00Go0000ooooooooooooooooo`000002ooooo`Ko000000Kooooo
oa0@4?nj^[[oooooogMgMolb<S9`ooooo`00K?ooool00olQ8B7oZJVYooooo`02ooooo`09o`000?oo
ooooooooooooool@413oQhN7ooooooo^k^ko000000Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00Co0000oiRHV?lb<S;oc<c<1_ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01_lb<S;ok^k^oiRH
V?mEEEGogMgMoa0@40_ooooo00?o<S8booooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`5oooo
o`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooo
oooo06kooooo001/ooooo`03o`000?oooooooooo00?o000000Go410@oooooooooooo^[Zjoa0@4003
o`0000Gooooo00?o0000ooooooooool00oooool6o`0000?ooooo00?o0000ooooooooool01Oooool0
0ol0003o410@oiRHV007ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`07okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c00:ooooo`03oc8b<_oooooooooo00;o
oooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool00ol0003oooooooooo`0Booooo`05o`000?oooooooooo
ooooool000000_ooool6o`0000Cooooo00?oZJVYoa0@4?ooool0Koooool006cooooo00?o0000oooo
ooooool02Oooool00oo<c<co0000ooooo`04ooooo`03o`000?oooooooooo00?ooooo00KoEEEEohN7
Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?lb<S;ogMgM00Gooooo00Co0000onk^k_mEEEGoQhN7
1_ooool00ol0003oooooooooo`03ooooo`05o`000?n7QhOoooooojVYZOl000001_ooool01oo^k^ko
0000ooooool0003oooooofIVI_n7QhL02_ooool00ol0003ok^k^ooooo`02ooooo`04ob4Q8OmgMgOo
MgMgoc8b<PCooooo00?ok^k^o`000?ooool04oooool01Ol0003oQhN7oooooonYZJWo000000_ooooo
00?o410@o`000?nj^[X0L?ooool006cooooo00Ko8B4QojVYZOooooooooooonk^k_l@4104ooooo`04
oc8b<_l0003o0000oiRHV0Gooooo00?o0000ooooooooool00oooool01_o^k^koEEEEo`000?l0003o
A4A4onk^kP;ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B43ooooo`05o`000?ooooooA4A4o`000?l@
41000oooool00ol@413o0000o`000004ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooooooo
ool01?ooool01?mVIVKoV9RHoooooolb<S82okZj^P03o`000?oooooooooo00Sooooo00CoEEEEogMg
Mooooooooooo0_l00002ooooo`;o00000oooool00omgMgOoEEEEooooo`0Booooo`03oa0@4?l0003o
MgMg00;o000000?oV9RHooooooooool02_ooool00onj^[[o8B4Qooooo`1_ooooo`00K?ooool01_nY
ZJWo8B4QomgMgOooooooQhN7o`0000gooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Kooooo`03ofIVI_n7QhOooooo00_ooooo00?ogMgMoa0@4?o^k^h02Oooool00oo^k^ko410@omgM
g@0Rooooo`05oa0@4?nHV9SooooookZj^_l00000L?ooool006gooooo00GoV9RHoa0@4?l0003o8B4Q
o`00000=ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Aooooo`03ojVYZOm4A4Cooooo00cooooo00?oMgMgofIVI_ooool02?ooool00omVIVKoMgMg
ooooo`0Rooooo`05ojVYZOl@413o0000oa0@4?nYZJT0L?ooool007gooooo00?o410@o`000?l00000
5Oooool2o`0000Wooooo00?o410@ooooooooool0aOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-9.21355, -0.377589, \
0.0641612, 0.0046665}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 2: 2D Drumhead Eigenmodes", "Section",
  CellTags->{"i:48", "c:37"}],

Cell[TextData[{
  "The Galerkin method for determining eigenmodes works in any number of \
spatial dimensions: no mention of dimensionality was made in Eqs. ",
  ButtonBox["(6.3.8)",
    ButtonData:>"(6.3.8)",
    ButtonStyle->"Hyperlink"],
  "-",
  ButtonBox["(6.3.11)",
    ButtonData:>"(6.3.11)",
    ButtonStyle->"Hyperlink"],
  ". Therefore, we can find the eigenmodes for any spatial linear operator in \
a region of almost any shape (subject to the restrictions discussed in Sec. \
",
  ButtonBox["6.1.2",
    ButtonData:>"c:4",
    ButtonStyle->"Hyperlink"],
  "). Below, we find the low-order modes of a 2D drumhead with an unusual \
parabolic shape. The boundary of the drumhead is specified by the equations \
",
  Cell[BoxData[
      \(TraditionalForm\`y = 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y = x\^2\)]],
  ". These eigenmodes satisfy the following PDE:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\(\( \[Psi]\_n\)(x, 
            y)\)\  = \(\[Lambda]\_n\) \(\(\[Psi]\_n\)(x, y)\)\)]],
  ","
}], "Text"],

Cell[TextData[{
  "subject to the boundary conditions that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_n = 0\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`y = 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y = x\^2\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tIn order to match the boundary conditions, our basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`{v\_\(i\ j\)}\)]],
  "are chosen as ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\(i\ j\) = 
        x\^i\ y\^j\ \((y - 1)\) \((y - x\^2)\)\)]],
  ". The one piece of tricky business is to note that, in order to construct \
the matrices  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(S\_\(m\ n\)\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`L\_\(m\ n\)\)]],
  ", the counters ",
  Cell[BoxData[
      \(TraditionalForm\`\((i, j)\)\)]],
  " must be converted to a single counter ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " that runs over all ",
  Cell[BoxData[
      \(TraditionalForm\`\((M + 1)\)\^2\)]],
  " basis functions.  This is most easily accomplished by means of the ",
  StyleBox["Mod",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Quotient",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions. The function ",
  StyleBox["Quotient[m,n]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " gives the number of times that",
  StyleBox[" ",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        StyleBox["n",
          FontFamily->"Courier",
          FontSlant->"Plain"], TraditionalForm]],
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " can be divided into ",
  Cell[BoxData[
      FormBox[
        StyleBox["m",
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["Mod",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["m",
                FontFamily->"Courier",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox["n",
                FontFamily->"Courier",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}], "=", 
          RowBox[{
            StyleBox["m",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["-",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[" ",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["n",
                FontFamily->"Courier",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[" ",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              RowBox[{
                StyleBox["Quotient",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                StyleBox["[",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                RowBox[{
                  StyleBox["m",
                    FontFamily->"Courier",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[",",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["n",
                    FontFamily->"Courier",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}], 
                StyleBox["]",
                  FontFamily->"Courier",
                  FontWeight->"Bold"]}]}]}]}], TraditionalForm]]],
  StyleBox[" ",
    FontWeight->"Bold"],
  " is what is left over after taking away the multiples of",
  StyleBox[" ",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        StyleBox["n",
          FontFamily->"Courier",
          FontSlant->"Plain"], TraditionalForm]],
    FontWeight->"Bold",
    FontSlant->"Italic"],
  ". For example, ",
  Cell[BoxData[
      FormBox[
        StyleBox[Cell[TextData[{
            "Quotient[7,3]",
            StyleBox["=2",
              FontFamily->"Times",
              FontWeight->"Plain"]
          }]],
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\(Mod[7, 3]\),
            FontFamily->"Courier",
            FontWeight->"Bold"], "=", \(7 - 3\[Cross]\ 2 = 1\)}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "\tTo evaluate the matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["S",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " we first create the matrix  element ",
  Cell[BoxData[
      \(TraditionalForm\`S\_\(\(i\)\(\ \)\(j\)\(\ \ \)\(k\)\(\ \)\(l\)\(\ \
\)\) = \((v\_\(i\ j\), v\_\(k\ l\))\)\)]],
  ". Then for  the matrix elements ",
  Cell[BoxData[
      \(TraditionalForm\`S\_\(m\ n\)\)]],
  ", we let ",
  Cell[BoxData[
      \(TraditionalForm\`m\ and\ n\ run\ from\ 0\ to\ \((M + 1)\)\^2 - 1\)]],
  ", and set ",
  Cell[BoxData[
      \(TraditionalForm\`S\_\(m\ n\) = \ S\_\(i\ j\ k\ l\)\)]],
  " where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["i",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["=",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["Mod",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              RowBox[{
                StyleBox["m",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                RowBox[{
                  StyleBox["M",
                    FontFamily->"Courier",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox["+",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["1",
                    FontFamily->"Courier",
                    FontWeight->"Bold"]}]}], 
              StyleBox["]",
                FontFamily->"Courier",
                FontWeight->"Bold"]}]}], 
          StyleBox[",",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[" ",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["j",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["=",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["Quotient",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              RowBox[{
                StyleBox["m",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                RowBox[{
                  StyleBox["M",
                    FontFamily->"Courier",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox["+",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["1",
                    FontFamily->"Courier",
                    FontWeight->"Bold"]}]}], 
              StyleBox["]",
                FontFamily->"Courier",
                FontWeight->"Bold"]}]}]}], TraditionalForm]]],
  ",  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["k",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["=",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["Mod",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              RowBox[{
                StyleBox["n",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                RowBox[{
                  StyleBox["M",
                    FontFamily->"Courier",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox["+",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["1",
                    FontFamily->"Courier",
                    FontWeight->"Bold"]}]}], 
              StyleBox["]",
                FontFamily->"Courier",
                FontWeight->"Bold"]}]}], 
          StyleBox[",",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[" ",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["l",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["=",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["Quotient",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              RowBox[{
                StyleBox["n",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                RowBox[{
                  StyleBox["M",
                    FontFamily->"Courier",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox["+",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["1",
                    FontFamily->"Courier",
                    FontWeight->"Bold"]}]}], 
              StyleBox["]",
                FontFamily->"Courier",
                FontWeight->"Bold"]}]}]}], TraditionalForm]]],
  ". We do the same thing for ",
  Cell[BoxData[
      \(TraditionalForm\`L\_\(m\ n\)\)]],
  ".  For ",
  Cell[BoxData[
      \(TraditionalForm\`M = 2\)]],
  " the matrix ",
  Cell[BoxData[
      \(TraditionalForm\`S\_\(m\ n\)\)]],
  " has the form shown below:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(M = 2;\)\), "\n", 
    \(\(i = Mod[m, M + 1];\)\), "\n", 
    \(\(j = Quotient[m, M + 1];\)\), "\n", 
    \(\(k = Mod[n, M + 1];\)\), "\n", 
    \(\(\(l = Quotient[n, M + 1];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(Smat\  = \ 
        Table[S\_\(\(\ \)\(i, j, k, l\)\), {m, 0, \((M + 1)\)^2\  - 1}, {n, 
            0, \((M + 1)\)\^2 - 1}];\)\), "\n", 
    \(MatrixForm[Smat]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.164"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(S\_\(0, 0, 0, 0\)\), \(S\_\(0, 0, 1, 0\)\), \(S\_\(0, 0, 2, 
                  0\)\), \(S\_\(0, 0, 0, 1\)\), \(S\_\(0, 0, 1, 
                  1\)\), \(S\_\(0, 0, 2, 1\)\), \(S\_\(0, 0, 0, 
                  2\)\), \(S\_\(0, 0, 1, 2\)\), \(S\_\(0, 0, 2, 2\)\)},
            {\(S\_\(1, 0, 0, 0\)\), \(S\_\(1, 0, 1, 0\)\), \(S\_\(1, 0, 2, 
                  0\)\), \(S\_\(1, 0, 0, 1\)\), \(S\_\(1, 0, 1, 
                  1\)\), \(S\_\(1, 0, 2, 1\)\), \(S\_\(1, 0, 0, 
                  2\)\), \(S\_\(1, 0, 1, 2\)\), \(S\_\(1, 0, 2, 2\)\)},
            {\(S\_\(2, 0, 0, 0\)\), \(S\_\(2, 0, 1, 0\)\), \(S\_\(2, 0, 2, 
                  0\)\), \(S\_\(2, 0, 0, 1\)\), \(S\_\(2, 0, 1, 
                  1\)\), \(S\_\(2, 0, 2, 1\)\), \(S\_\(2, 0, 0, 
                  2\)\), \(S\_\(2, 0, 1, 2\)\), \(S\_\(2, 0, 2, 2\)\)},
            {\(S\_\(0, 1, 0, 0\)\), \(S\_\(0, 1, 1, 0\)\), \(S\_\(0, 1, 2, 
                  0\)\), \(S\_\(0, 1, 0, 1\)\), \(S\_\(0, 1, 1, 
                  1\)\), \(S\_\(0, 1, 2, 1\)\), \(S\_\(0, 1, 0, 
                  2\)\), \(S\_\(0, 1, 1, 2\)\), \(S\_\(0, 1, 2, 2\)\)},
            {\(S\_\(1, 1, 0, 0\)\), \(S\_\(1, 1, 1, 0\)\), \(S\_\(1, 1, 2, 
                  0\)\), \(S\_\(1, 1, 0, 1\)\), \(S\_\(1, 1, 1, 
                  1\)\), \(S\_\(1, 1, 2, 1\)\), \(S\_\(1, 1, 0, 
                  2\)\), \(S\_\(1, 1, 1, 2\)\), \(S\_\(1, 1, 2, 2\)\)},
            {\(S\_\(2, 1, 0, 0\)\), \(S\_\(2, 1, 1, 0\)\), \(S\_\(2, 1, 2, 
                  0\)\), \(S\_\(2, 1, 0, 1\)\), \(S\_\(2, 1, 1, 
                  1\)\), \(S\_\(2, 1, 2, 1\)\), \(S\_\(2, 1, 0, 
                  2\)\), \(S\_\(2, 1, 1, 2\)\), \(S\_\(2, 1, 2, 2\)\)},
            {\(S\_\(0, 2, 0, 0\)\), \(S\_\(0, 2, 1, 0\)\), \(S\_\(0, 2, 2, 
                  0\)\), \(S\_\(0, 2, 0, 1\)\), \(S\_\(0, 2, 1, 
                  1\)\), \(S\_\(0, 2, 2, 1\)\), \(S\_\(0, 2, 0, 
                  2\)\), \(S\_\(0, 2, 1, 2\)\), \(S\_\(0, 2, 2, 2\)\)},
            {\(S\_\(1, 2, 0, 0\)\), \(S\_\(1, 2, 1, 0\)\), \(S\_\(1, 2, 2, 
                  0\)\), \(S\_\(1, 2, 0, 1\)\), \(S\_\(1, 2, 1, 
                  1\)\), \(S\_\(1, 2, 2, 1\)\), \(S\_\(1, 2, 0, 
                  2\)\), \(S\_\(1, 2, 1, 2\)\), \(S\_\(1, 2, 2, 2\)\)},
            {\(S\_\(2, 2, 0, 0\)\), \(S\_\(2, 2, 1, 0\)\), \(S\_\(2, 2, 2, 
                  0\)\), \(S\_\(2, 2, 0, 1\)\), \(S\_\(2, 2, 1, 
                  1\)\), \(S\_\(2, 2, 2, 1\)\), \(S\_\(2, 2, 0, 
                  2\)\), \(S\_\(2, 2, 1, 2\)\), \(S\_\(2, 2, 2, 2\)\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["The following module performs the required calculations:", "Text"],

Cell[BoxData[
    RowBox[{\(galerkinmodes[M_]\), ":=", " ", 
      RowBox[{"Module", "[", 
        RowBox[{\({i, j, k, l, \[Phi], z, norm, L, S, Lmat, Smat, mat}\), ",",
           "\[IndentingNewLine]", 
          
          StyleBox[\( (*\ 
              define\ the\ curves\ that\ determine\ the\ \
\(\(boundary\)\(:\)\)\ *) \),
            FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
          
          RowBox[{\(z[1, x_, y_]\  = \ y - 1\), ";", 
            "\[IndentingNewLine]", \(z[2, x_, y_]\  = \ y - x\^2\), ";", " ", 
            "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ define\ the\ basis\ \(\(functions\)\(:\)\)\ *) \),
              
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(v[i_, j_, x_, y_]\  = \ \(x\^i\) 
                y\^j\ \ \ \ Product[z[p, x, y], {p, 1, 2}]\), ";", 
            "\[IndentingNewLine]", 
            RowBox[{
              StyleBox["(*",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[" ",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[\(define\ the\ inner\ product\),
                FontColor->RGBColor[1, 0, 0]], " ", 
              StyleBox["*)",
                FontColor->RGBColor[1, 0, 0]]}], 
            "\[IndentingNewLine]", \(norm[f_, g_]\  := \ 
              Integrate[Integrate[f\ g, {y, x\^2, 1}], {x, \(-1\), 1}]\  // 
                N\), ";", "\[IndentingNewLine]", 
            StyleBox[\( (*\ define\ the\ \(\(operator\)\(:\)\)\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(L\&^[f_]\  := \ 
              D[f, {x, 2}]\  + \ D[f, {y, 2}]\), ";", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                determine\ the\ projection\ of\ the\ operator\ onto\ the\ \
basis\ \(\(functions\)\(:\)\)\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(L[i_, j_, k_, l_]\  := \ 
              norm[v[i, j, x, y], \ L\&^[v[k, l, x, y]]]\), ";", 
            "\[IndentingNewLine]", \(S[i_, j_, k_, l_]\  := \ 
              norm[v[i, j, x, y], v[k, l, x, y]]\), ";", 
            "\[IndentingNewLine]", 
            RowBox[{
              StyleBox["(*",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[" ",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[\(create\ matrixes\ L\ and\ S\),
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[" ",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox["*)",
                FontColor->RGBColor[1, 0, 0]]}], 
            "\[IndentingNewLine]", \(Lmat\  = \ 
              Table[L[Mod[m, M + 1], Quotient[m, M + 1], Mod[n, M + 1], 
                  Quotient[n, M + 1]], {m, 0, \((M + 1)\)^2\  - 1}, {n, 
                  0, \((M + 1)\)\^2 - 1}]\), ";", 
            "\[IndentingNewLine]", \(Smat\  = \ 
              Table[S[Mod[m, M + 1], Quotient[m, M + 1], Mod[n, M + 1], 
                  Quotient[n, M + 1]], {m, 0, \((M + 1)\)^2\  - 1}, {n, 
                  0, \((M + 1)\)\^2 - 1}]\), ";", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                take\ the\ \((numerical)\)\ inverse\ of\ S\ and\ matrix\ \
multiply\ it\ by\ L\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(mat\  = \ Inverse[Smat\  // N] . Lmat\), 
            ";", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                find\ the\ eigenvalues\ and\ eigenvectors\ of\ the\ matrix\ \
problem\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[Lambda] = Eigenvalues[mat]\), ";", 
            "\[IndentingNewLine]", \(c = Eigenvectors[mat]\), ";"}]}], 
        "]"}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.165"],

Cell[TextData[{
  "We now call the module for ",
  Cell[BoxData[
      \(TraditionalForm\`M = 4\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(galerkinmodes[4]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.166"],

Cell["The eigenvalues are", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Lambda]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.167"],

Cell[BoxData[
    \({\(-800.5458534151196`\), \(-665.718537158086`\), \(-657.4570023522167`\
\), \(-523.724190178983`\), \(-463.1344894626117`\), \(-402.4931348775189`\), \
\(-364.73933897630917`\), \(-353.0668486863827`\), \(-303.6987744256372`\), \
\(-293.61793118112524`\), \(-256.19190339151845`\), \(-225.71610910497614`\), \
\(-224.19832751857808`\), \(-185.43115785754514`\), \(-182.13204515997697`\), \
\(-153.61489723894437`\), \(-127.67960060211539`\), \(-112.60818763533226`\), \
\(-111.75951996688694`\), \(-92.68187645632872`\), \(-71.03878610903246`\), \
\(-59.18138278943286`\), \(-47.25446476096206`\), \(-33.333228542144596`\), \
\(-16.94683560026165`\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The numbers are negative and real, as expected, since they equal -",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_n\^2\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_n\)]],
  " is the frequency of a given drumhead mode.  In order to test the accuracy \
of the method, we increase ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(galerkinmodes[5];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\[Lambda]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.168"],

Cell[BoxData[
    \({\(-1391.3870788531817`\), \(-1167.1370503837777`\), \
\(-1153.634563723851`\), \(-952.1043003694479`\), \(-884.9811846210089`\), \
\(-715.8134933425775`\), \(-690.8244164760657`\), \(-614.935918456444`\), \
\(-580.4886186732188`\), \(-535.955192409204`\), \(-500.6305803603995`\), \
\(-481.68009938928003`\), \(-424.64154725352677`\), \(-422.8934466192252`\), \
\(-395.83056109121196`\), \(-376.46893918826044`\), \(-346.4795966834327`\), \
\(-280.09141398501976`\), \(-278.15326085916945`\), \(-271.44504020770927`\), \
\(-230.20704885377086`\), \(-229.95594878067266`\), \(-190.19616002660553`\), \
\(-186.03561790009636`\), \(-177.48637671484343`\), \(-153.11652624899176`\), \
\(-151.81662313564348`\), \(-119.8518754476218`\), \(-111.71542022904302`\), \
\(-92.58863688538456`\), \(-90.96573719387683`\), \(-69.09239781570932`\), \
\(-59.16315554932787`\), \(-47.235455868341845`\), \(-33.24411088666115`\), \
\(-16.946833399000536`\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The lowest eigenvalues are nearly the same as for ",
  Cell[BoxData[
      \(TraditionalForm\`M = 4\)]],
  ", indicating that the method has converged reasonably well for the lowest \
modes. In Cell ",
  ButtonBox["6.169",
    ButtonData:>"Cell 6.169",
    ButtonStyle->"Hyperlink"],
  " we plot a few of the corresponding eigenmodes, using Eq. ",
  ButtonBox["(6.3.9)",
    ButtonData:>"(6.3.9)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text",
  CellTags->"i:67"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(\[Psi][n_, x_]\  := \ 
        Sum[\(c[\([\((M + 1)\)^2 - n]\)]\)[\([j + 1]\)]\ v[Mod[j, M + 1], 
              Quotient[j, M + 1], x, y], {j, 
            0, \((M + 1)\)^2 - 1}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(<< Calculus`;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(z[1, x_, y_]\  = \ y - 1;\)\), "\[IndentingNewLine]", 
    \(\(z[2, x_, y_]\  = \ y - x\^2;\)\), "\n", 
    \(\(Table[
        Plot3D[\[Psi][n, x]\ Boole[
              z[1, x, y] \[LessEqual] \ 0\  && \ 
                z[2, x, y] \[GreaterEqual] \ 0], {x, \(-1.01\), 
            1}, {y, \(-0.01\), 1.3}, PlotPoints \[Rule] 50, 
          PlotRange \[Rule] All, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
          PlotLabel -> \*"\"\<\!\(\[Psi]\_n\)[x,y], n=\>\"" <> 
              ToString[n]], {n, 0, 3}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.169"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -37.6875 0 ]
[.5 .82364 37.6875 10.125 ]
[.03045 .24505 -12 -8.71092 ]
[.03045 .24505 0 .28908 ]
[.17875 .18668 -23.5791 -9 ]
[.17875 .18668 .42091 0 ]
[.33612 .12478 -5.58359 -9 ]
[.33612 .12478 .41641 0 ]
[.5034 .05901 -15.8172 -9 ]
[.5034 .05901 2.18278 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.29165 .07573 -9.31117 -9.8125 ]
[.29165 .07573 .68883 0 ]
[.70361 -0.00072 0 -6.25801 ]
[.70361 -0.00072 6 2.74199 ]
[.82501 .18517 0 -6.07699 ]
[.82501 .18517 18 2.92301 ]
[.92763 .34231 0 -5.92977 ]
[.92763 .34231 6 3.07023 ]
[.91861 .21225 0 -6.57576 ]
[.91861 .21225 10.0625 3.23674 ]
[.0216 .28084 -30 -2.7556 ]
[.0216 .28084 0 6.2444 ]
[.01374 .33014 -30 -2.79732 ]
[.01374 .33014 0 6.20268 ]
[.00562 .38104 -30 -2.84054 ]
[.00562 .38104 0 6.15946 ]
[-0.00277 .43362 -30 -2.88532 ]
[-0.00277 .43362 0 6.11468 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -98.6875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
74.312 11.250 moveto
(@) show
80.312 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
86.312 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
92.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
98.375 11.250 moveto
(D) show
104.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
116.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
122.375 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
128.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
134.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.04003 .25401 m
.04482 .2585 L
s
[(-1)] .03045 .24505 1 .93576 Mshowa
.18786 .19613 m
.19242 .20085 L
s
[(-0.5)] .17875 .18668 .96492 1 Mshowa
.34468 .13472 m
.34896 .13969 L
s
[(0)] .33612 .12478 .8612 1 Mshowa
.51132 .06947 m
.51528 .0747 L
s
[(0.5)] .5034 .05901 .75747 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06892 .2427 m
.07176 .24542 L
s
.09814 .23126 m
.10096 .23401 L
s
.1277 .21969 m
.13049 .22246 L
s
.1576 .20797 m
.16037 .21078 L
s
.21848 .18414 m
.22119 .187 L
s
.24947 .172 m
.25214 .1749 L
s
.28082 .15973 m
.28346 .16265 L
s
.31256 .1473 m
.31516 .15025 L
s
.37719 .12199 m
.37973 .125 L
s
.41011 .1091 m
.4126 .11215 L
s
.44343 .09606 m
.44588 .09913 L
s
.47716 .08285 m
.47958 .08595 L
s
.54591 .05593 m
.54824 .0591 L
s
.58094 .04221 m
.58323 .04541 L
s
.61641 .02832 m
.61866 .03155 L
s
.65234 .01425 m
.65454 .01752 L
s
gsave
.29165 .07573 -70.3112 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69139 .00406 m
.68528 .00644 L
s
[(0)] .70361 -0.00072 -1 .39067 Mshowa
.81263 .18951 m
.80643 .19168 L
s
[(0.5)] .82501 .18517 -1 .35044 Mshowa
.91512 .34629 m
.90887 .34827 L
s
[(1)] .92763 .34231 -1 .31773 Mshowa
.125 Mabswid
.71738 .04381 m
.7137 .04521 L
s
.74245 .08216 m
.73876 .08354 L
s
.76665 .11918 m
.76296 .12054 L
s
.79003 .15495 m
.78632 .15627 L
s
.83448 .22293 m
.83075 .22421 L
s
.85562 .25527 m
.85189 .25653 L
s
.87608 .28658 m
.87235 .28781 L
s
.89591 .3169 m
.89216 .31811 L
s
.93375 .37478 m
.92999 .37595 L
s
.95181 .40242 m
.94805 .40357 L
s
gsave
.91861 .21225 -61 -10.5758 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.062 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.062 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03384 .2761 m
.03996 .27372 L
s
[(-0.08)] .0216 .28084 1 -0.38764 Mshowa
.02601 .3255 m
.03215 .32318 L
s
[(-0.06)] .01374 .33014 1 -0.37837 Mshowa
.01793 .3765 m
.02408 .37423 L
s
[(-0.04)] .00562 .38104 1 -0.36877 Mshowa
.00958 .42918 m
.01575 .42697 L
s
[(-0.02)] -0.00277 .43362 1 -0.35882 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(0)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.0319 .2883 m
.03558 .28689 L
s
.02996 .3006 m
.03363 .29919 L
s
.02799 .313 m
.03167 .3116 L
s
.02401 .3381 m
.0277 .33671 L
s
.022 .35079 m
.02569 .34942 L
s
.01997 .3636 m
.02366 .36223 L
s
.01587 .38951 m
.01956 .38816 L
s
.01379 .40263 m
.01749 .40128 L
s
.01169 .41585 m
.01539 .41451 L
s
.00745 .44263 m
.01116 .44131 L
s
.0053 .45618 m
.00901 .45487 L
s
.00313 .46985 m
.00685 .46854 L
s
.03576 .26399 m
.03943 .26256 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.646 .762 .934 r
.39143 .80041 .39806 .80578 .40912 .80287 .40252 .79748 Metetra
.646 .762 .934 r
.40252 .79748 .40912 .80287 .42022 .79996 .41365 .79454 Metetra
.646 .762 .934 r
.41365 .79454 .42022 .79996 .43137 .79703 .42483 .79159 Metetra
.646 .762 .934 r
.42483 .79159 .43137 .79703 .44256 .79408 .43605 .78862 Metetra
.646 .762 .934 r
.43605 .78862 .44256 .79408 .4538 .79113 .44732 .78564 Metetra
.646 .762 .934 r
.44732 .78564 .4538 .79113 .46509 .78816 .45864 .78266 Metetra
.646 .762 .934 r
.45864 .78266 .46509 .78816 .47642 .78519 .47001 .77965 Metetra
.646 .762 .934 r
.47001 .77965 .47642 .78519 .48781 .78219 .48142 .77664 Metetra
.646 .762 .934 r
.48142 .77664 .48781 .78219 .49924 .77919 .49288 .77361 Metetra
.646 .762 .934 r
.49288 .77361 .49924 .77919 .51071 .77617 .50439 .77057 Metetra
.646 .762 .934 r
.50439 .77057 .51071 .77617 .52224 .77315 .51594 .76752 Metetra
.646 .762 .934 r
.51594 .76752 .52224 .77315 .53381 .7701 .52755 .76446 Metetra
.646 .762 .934 r
.52755 .76446 .53381 .7701 .54544 .76705 .53921 .76138 Metetra
.646 .762 .934 r
.53921 .76138 .54544 .76705 .55711 .76398 .55091 .75829 Metetra
.646 .762 .934 r
.55091 .75829 .55711 .76398 .56883 .7609 .56267 .75518 Metetra
.646 .762 .934 r
.56267 .75518 .56883 .7609 .5806 .75781 .57447 .75206 Metetra
.646 .762 .934 r
.57447 .75206 .5806 .75781 .59242 .7547 .58633 .74893 Metetra
.646 .762 .934 r
.58633 .74893 .59242 .7547 .6043 .75158 .59823 .74579 Metetra
.646 .762 .934 r
.59823 .74579 .6043 .75158 .61622 .74845 .61019 .74263 Metetra
.646 .762 .934 r
.61019 .74263 .61622 .74845 .62819 .7453 .6222 .73946 Metetra
.646 .762 .934 r
.6222 .73946 .62819 .7453 .64022 .74214 .63426 .73627 Metetra
.646 .762 .934 r
.63426 .73627 .64022 .74214 .65229 .73897 .64637 .73307 Metetra
.646 .762 .934 r
.64637 .73307 .65229 .73897 .66442 .73578 .65853 .72986 Metetra
.646 .762 .934 r
.65853 .72986 .66442 .73578 .67661 .73258 .67075 .72663 Metetra
.646 .762 .934 r
.67075 .72663 .67661 .73258 .68884 .72937 .68302 .72339 Metetra
.646 .762 .934 r
.68302 .72339 .68884 .72937 .70113 .72614 .69535 .72014 Metetra
.646 .762 .934 r
.69535 .72014 .70113 .72614 .71347 .72289 .70772 .71687 Metetra
.646 .762 .934 r
.70772 .71687 .71347 .72289 .72586 .71964 .72016 .71359 Metetra
.646 .762 .934 r
.72016 .71359 .72586 .71964 .73831 .71637 .73264 .71029 Metetra
.646 .762 .934 r
.73264 .71029 .73831 .71637 .75081 .71308 .74518 .70698 Metetra
.646 .762 .934 r
.74518 .70698 .75081 .71308 .76337 .70978 .75778 .70365 Metetra
.646 .762 .934 r
.75778 .70365 .76337 .70978 .77598 .70647 .77043 .70031 Metetra
.646 .762 .934 r
.77043 .70031 .77598 .70647 .78865 .70314 .78314 .69695 Metetra
.646 .762 .934 r
.78314 .69695 .78865 .70314 .80138 .69979 .79591 .69358 Metetra
.646 .762 .934 r
.79591 .69358 .80138 .69979 .81416 .69643 .80873 .69019 Metetra
.646 .762 .934 r
.80873 .69019 .81416 .69643 .827 .69306 .82161 .68679 Metetra
.646 .762 .934 r
.82161 .68679 .827 .69306 .83989 .68967 .83454 .68338 Metetra
.646 .762 .934 r
.83454 .68338 .83989 .68967 .85284 .68627 .84753 .67994 Metetra
.646 .762 .934 r
.84753 .67994 .85284 .68627 .86585 .68285 .86059 .6765 Metetra
.646 .762 .934 r
.86059 .6765 .86585 .68285 .87892 .67941 .8737 .67303 Metetra
.646 .762 .934 r
.8737 .67303 .87892 .67941 .89205 .67597 .88687 .66956 Metetra
.646 .762 .934 r
.88687 .66956 .89205 .67597 .90523 .6725 .9001 .66606 Metetra
.646 .762 .934 r
.9001 .66606 .90523 .6725 .91848 .66902 .91338 .66255 Metetra
.646 .762 .934 r
.91338 .66255 .91848 .66902 .93178 .66552 .92673 .65903 Metetra
.646 .762 .934 r
.92673 .65903 .93178 .66552 .94515 .66201 .94014 .65549 Metetra
.646 .762 .934 r
.94014 .65549 .94515 .66201 .95858 .65848 .95361 .65193 Metetra
.646 .762 .934 r
.95361 .65193 .95858 .65848 .97206 .65494 .96715 .64835 Metetra
.646 .762 .934 r
.96715 .64835 .97206 .65494 .98561 .65138 .98074 .64476 Metetra
.646 .762 .934 r
.98074 .64476 .98561 .65138 .99922 .6478 .9944 .64116 Metetra
.646 .762 .934 r
.38476 .79499 .39143 .80041 .40252 .79748 .39587 .79204 Metetra
.646 .762 .934 r
.39587 .79204 .40252 .79748 .41365 .79454 .40703 .78908 Metetra
.646 .762 .934 r
.40703 .78908 .41365 .79454 .42483 .79159 .41824 .7861 Metetra
.646 .762 .934 r
.41824 .7861 .42483 .79159 .43605 .78862 .42949 .78312 Metetra
.646 .762 .934 r
.42949 .78312 .43605 .78862 .44732 .78564 .44079 .78012 Metetra
.646 .762 .934 r
.44079 .78012 .44732 .78564 .45864 .78266 .45214 .7771 Metetra
.646 .762 .934 r
.45214 .7771 .45864 .78266 .47001 .77965 .46354 .77408 Metetra
.646 .762 .934 r
.46354 .77408 .47001 .77965 .48142 .77664 .47498 .77104 Metetra
.646 .762 .934 r
.47498 .77104 .48142 .77664 .49288 .77361 .48647 .76799 Metetra
.646 .762 .934 r
.48647 .76799 .49288 .77361 .50439 .77057 .49801 .76493 Metetra
.646 .762 .934 r
.49801 .76493 .50439 .77057 .51594 .76752 .5096 .76185 Metetra
.646 .762 .934 r
.5096 .76185 .51594 .76752 .52755 .76446 .52124 .75876 Metetra
.646 .762 .934 r
.52124 .75876 .52755 .76446 .53921 .76138 .53293 .75566 Metetra
.646 .762 .934 r
.53293 .75566 .53921 .76138 .55091 .75829 .54466 .75254 Metetra
.646 .762 .934 r
.54466 .75254 .55091 .75829 .56267 .75518 .55645 .74941 Metetra
.646 .762 .934 r
.55645 .74941 .56267 .75518 .57447 .75206 .56829 .74627 Metetra
.646 .762 .934 r
.56829 .74627 .57447 .75206 .58633 .74893 .58018 .74312 Metetra
.646 .762 .934 r
.58018 .74312 .58633 .74893 .59823 .74579 .59212 .73995 Metetra
.646 .762 .934 r
.59212 .73995 .59823 .74579 .61019 .74263 .60411 .73676 Metetra
.646 .762 .934 r
.60411 .73676 .61019 .74263 .6222 .73946 .61615 .73357 Metetra
.646 .762 .934 r
.61615 .73357 .6222 .73946 .63426 .73627 .62825 .73036 Metetra
.646 .762 .934 r
.62825 .73036 .63426 .73627 .64637 .73307 .6404 .72713 Metetra
.646 .762 .934 r
.6404 .72713 .64637 .73307 .65853 .72986 .6526 .72389 Metetra
.646 .762 .934 r
.6526 .72389 .65853 .72986 .67075 .72663 .66485 .72064 Metetra
.646 .762 .934 r
.66485 .72064 .67075 .72663 .68302 .72339 .67716 .71737 Metetra
.646 .762 .934 r
.67716 .71737 .68302 .72339 .69535 .72014 .68952 .71409 Metetra
.646 .762 .934 r
.68952 .71409 .69535 .72014 .70772 .71687 .70193 .7108 Metetra
.646 .762 .934 r
.70193 .7108 .70772 .71687 .72016 .71359 .7144 .70749 Metetra
.646 .762 .934 r
.7144 .70749 .72016 .71359 .73264 .71029 .72693 .70416 Metetra
.646 .762 .934 r
.72693 .70416 .73264 .71029 .74518 .70698 .73951 .70082 Metetra
.646 .762 .934 r
.73951 .70082 .74518 .70698 .75778 .70365 .75214 .69747 Metetra
.646 .762 .934 r
.75214 .69747 .75778 .70365 .77043 .70031 .76484 .6941 Metetra
.646 .762 .934 r
.76484 .6941 .77043 .70031 .78314 .69695 .77758 .69072 Metetra
.646 .762 .934 r
.77758 .69072 .78314 .69695 .79591 .69358 .79039 .68732 Metetra
.646 .762 .934 r
.79039 .68732 .79591 .69358 .80873 .69019 .80325 .6839 Metetra
.646 .762 .934 r
.80325 .6839 .80873 .69019 .82161 .68679 .81617 .68047 Metetra
.646 .762 .934 r
.81617 .68047 .82161 .68679 .83454 .68338 .82915 .67703 Metetra
.646 .762 .934 r
.82915 .67703 .83454 .68338 .84753 .67994 .84218 .67357 Metetra
.646 .762 .934 r
.84218 .67357 .84753 .67994 .86059 .6765 .85528 .67009 Metetra
.646 .762 .934 r
.85528 .67009 .86059 .6765 .8737 .67303 .86843 .6666 Metetra
.646 .762 .934 r
.86843 .6666 .8737 .67303 .88687 .66956 .88164 .66309 Metetra
.646 .762 .934 r
.88164 .66309 .88687 .66956 .9001 .66606 .89491 .65957 Metetra
.646 .762 .934 r
.89491 .65957 .9001 .66606 .91338 .66255 .90825 .65603 Metetra
.646 .762 .934 r
.90825 .65603 .91338 .66255 .92673 .65903 .92164 .65248 Metetra
.646 .762 .934 r
.92164 .65248 .92673 .65903 .94014 .65549 .9351 .6489 Metetra
.646 .762 .934 r
.9351 .6489 .94014 .65549 .95361 .65193 .94861 .64532 Metetra
.646 .762 .934 r
.94861 .64532 .95361 .65193 .96715 .64835 .96219 .64171 Metetra
.646 .762 .934 r
.96219 .64171 .96715 .64835 .98074 .64476 .97583 .63809 Metetra
.646 .762 .934 r
.97583 .63809 .98074 .64476 .9944 .64116 .98953 .63445 Metetra
.646 .762 .934 r
.37803 .78953 .38476 .79499 .39587 .79204 .38918 .78656 Metetra
.646 .762 .934 r
.38918 .78656 .39587 .79204 .40703 .78908 .40037 .78358 Metetra
.646 .762 .934 r
.40037 .78358 .40703 .78908 .41824 .7861 .4116 .78058 Metetra
.646 .762 .934 r
.4116 .78058 .41824 .7861 .42949 .78312 .42289 .77757 Metetra
.646 .762 .934 r
.42289 .77757 .42949 .78312 .44079 .78012 .43422 .77455 Metetra
.646 .762 .934 r
.43422 .77455 .44079 .78012 .45214 .7771 .44559 .77151 Metetra
.646 .762 .934 r
.44559 .77151 .45214 .7771 .46354 .77408 .45702 .76846 Metetra
.646 .762 .934 r
.45702 .76846 .46354 .77408 .47498 .77104 .46849 .7654 Metetra
.646 .762 .934 r
.46849 .7654 .47498 .77104 .48647 .76799 .48002 .76233 Metetra
.646 .762 .934 r
.48002 .76233 .48647 .76799 .49801 .76493 .49159 .75924 Metetra
.646 .762 .934 r
.49159 .75924 .49801 .76493 .5096 .76185 .50321 .75614 Metetra
.646 .762 .934 r
.50321 .75614 .5096 .76185 .52124 .75876 .51488 .75302 Metetra
.646 .762 .934 r
.51488 .75302 .52124 .75876 .53293 .75566 .5266 .7499 Metetra
.646 .762 .934 r
.5266 .7499 .53293 .75566 .54466 .75254 .53837 .74676 Metetra
.646 .762 .934 r
.53837 .74676 .54466 .75254 .55645 .74941 .55019 .7436 Metetra
.646 .762 .934 r
.55019 .7436 .55645 .74941 .56829 .74627 .56206 .74044 Metetra
.646 .762 .934 r
.56206 .74044 .56829 .74627 .58018 .74312 .57398 .73725 Metetra
.646 .762 .934 r
.57398 .73725 .58018 .74312 .59212 .73995 .58596 .73406 Metetra
.646 .762 .934 r
.58596 .73406 .59212 .73995 .60411 .73676 .59798 .73085 Metetra
.646 .762 .934 r
.59798 .73085 .60411 .73676 .61615 .73357 .61006 .72763 Metetra
.646 .762 .934 r
.61006 .72763 .61615 .73357 .62825 .73036 .62219 .72439 Metetra
.646 .762 .934 r
.62219 .72439 .62825 .73036 .6404 .72713 .63438 .72114 Metetra
.646 .762 .934 r
.63438 .72114 .6404 .72713 .6526 .72389 .64661 .71788 Metetra
.646 .762 .934 r
.64661 .71788 .6526 .72389 .66485 .72064 .6589 .7146 Metetra
.646 .762 .934 r
.6589 .7146 .66485 .72064 .67716 .71737 .67125 .7113 Metetra
.646 .762 .934 r
.67125 .7113 .67716 .71737 .68952 .71409 .68365 .708 Metetra
.646 .762 .934 r
.68365 .708 .68952 .71409 .70193 .7108 .6961 .70467 Metetra
.646 .762 .934 r
.6961 .70467 .70193 .7108 .7144 .70749 .70861 .70134 Metetra
.646 .762 .934 r
.70861 .70134 .7144 .70749 .72693 .70416 .72117 .69799 Metetra
.646 .762 .934 r
.72117 .69799 .72693 .70416 .73951 .70082 .73379 .69462 Metetra
.646 .762 .934 r
.73379 .69462 .73951 .70082 .75214 .69747 .74646 .69124 Metetra
.646 .762 .934 r
.74646 .69124 .75214 .69747 .76484 .6941 .75919 .68784 Metetra
.646 .762 .934 r
.75919 .68784 .76484 .6941 .77758 .69072 .77198 .68443 Metetra
.646 .762 .934 r
.77198 .68443 .77758 .69072 .79039 .68732 .78483 .681 Metetra
.646 .762 .934 r
.78483 .681 .79039 .68732 .80325 .6839 .79773 .67756 Metetra
.646 .762 .934 r
.79773 .67756 .80325 .6839 .81617 .68047 .81069 .6741 Metetra
.646 .762 .934 r
.81069 .6741 .81617 .68047 .82915 .67703 .82371 .67063 Metetra
.646 .762 .934 r
.82371 .67063 .82915 .67703 .84218 .67357 .83678 .66714 Metetra
.646 .762 .934 r
.83678 .66714 .84218 .67357 .85528 .67009 .84992 .66363 Metetra
.646 .762 .934 r
.84992 .66363 .85528 .67009 .86843 .6666 .86312 .66011 Metetra
.646 .762 .934 r
.86312 .66011 .86843 .6666 .88164 .66309 .87637 .65658 Metetra
.646 .762 .934 r
.87637 .65658 .88164 .66309 .89491 .65957 .88969 .65302 Metetra
.646 .762 .934 r
.88969 .65302 .89491 .65957 .90825 .65603 .90307 .64945 Metetra
.646 .762 .934 r
.90307 .64945 .90825 .65603 .92164 .65248 .9165 .64587 Metetra
.646 .762 .934 r
.9165 .64587 .92164 .65248 .9351 .6489 .93 .64227 Metetra
.646 .762 .934 r
.93 .64227 .9351 .6489 .94861 .64532 .94357 .63865 Metetra
.646 .762 .934 r
.94357 .63865 .94861 .64532 .96219 .64171 .95719 .63501 Metetra
.646 .762 .934 r
.95719 .63501 .96219 .64171 .97583 .63809 .97088 .63136 Metetra
.646 .762 .934 r
.97088 .63136 .97583 .63809 .98953 .63445 .98463 .62769 Metetra
.646 .762 .934 r
.37126 .78404 .37803 .78953 .38918 .78656 .38243 .78104 Metetra
.646 .762 .934 r
.38243 .78104 .38918 .78656 .40037 .78358 .39365 .77803 Metetra
.646 .762 .934 r
.39365 .77803 .40037 .78358 .4116 .78058 .40491 .77501 Metetra
.646 .762 .934 r
.40491 .77501 .4116 .78058 .42289 .77757 .41622 .77198 Metetra
.646 .762 .934 r
.41622 .77198 .42289 .77757 .43422 .77455 .42759 .76893 Metetra
.646 .762 .934 r
.42759 .76893 .43422 .77455 .44559 .77151 .43899 .76587 Metetra
.646 .762 .934 r
.43899 .76587 .44559 .77151 .45702 .76846 .45045 .7628 Metetra
.646 .762 .934 r
.45045 .7628 .45702 .76846 .46849 .7654 .46196 .75971 Metetra
.646 .762 .934 r
.46196 .75971 .46849 .7654 .48002 .76233 .47351 .75662 Metetra
.646 .762 .934 r
.47351 .75662 .48002 .76233 .49159 .75924 .48511 .7535 Metetra
.646 .762 .934 r
.48511 .7535 .49159 .75924 .50321 .75614 .49677 .75038 Metetra
.646 .762 .934 r
.49677 .75038 .50321 .75614 .51488 .75302 .50847 .74724 Metetra
.646 .762 .934 r
.50847 .74724 .51488 .75302 .5266 .7499 .52022 .74409 Metetra
.646 .762 .934 r
.52022 .74409 .5266 .7499 .53837 .74676 .53202 .74092 Metetra
.646 .762 .934 r
.53202 .74092 .53837 .74676 .55019 .7436 .54388 .73774 Metetra
.646 .762 .934 r
.54388 .73774 .55019 .7436 .56206 .74044 .55578 .73455 Metetra
.646 .762 .934 r
.55578 .73455 .56206 .74044 .57398 .73725 .56774 .73135 Metetra
.646 .762 .934 r
.56774 .73135 .57398 .73725 .58596 .73406 .57975 .72813 Metetra
.646 .762 .934 r
.57975 .72813 .58596 .73406 .59798 .73085 .59181 .72489 Metetra
.646 .762 .934 r
.59181 .72489 .59798 .73085 .61006 .72763 .60392 .72164 Metetra
.646 .762 .934 r
.60392 .72164 .61006 .72763 .62219 .72439 .61609 .71838 Metetra
.646 .762 .934 r
.61609 .71838 .62219 .72439 .63438 .72114 .62831 .7151 Metetra
.646 .762 .934 r
.62831 .7151 .63438 .72114 .64661 .71788 .64058 .71181 Metetra
.646 .762 .934 r
.64058 .71181 .64661 .71788 .6589 .7146 .65291 .70851 Metetra
.646 .762 .934 r
.65291 .70851 .6589 .7146 .67125 .7113 .66529 .70519 Metetra
.646 .762 .934 r
.66529 .70519 .67125 .7113 .68365 .708 .67772 .70185 Metetra
.646 .762 .934 r
.67772 .70185 .68365 .708 .6961 .70467 .69021 .6985 Metetra
.646 .762 .934 r
.69021 .6985 .6961 .70467 .70861 .70134 .70276 .69514 Metetra
.646 .762 .934 r
.70276 .69514 .70861 .70134 .72117 .69799 .71536 .69176 Metetra
.646 .762 .934 r
.71536 .69176 .72117 .69799 .73379 .69462 .72802 .68836 Metetra
.646 .762 .934 r
.72802 .68836 .73379 .69462 .74646 .69124 .74073 .68495 Metetra
.646 .762 .934 r
.74073 .68495 .74646 .69124 .75919 .68784 .7535 .68153 Metetra
.646 .762 .934 r
.7535 .68153 .75919 .68784 .77198 .68443 .76633 .67809 Metetra
.646 .762 .934 r
.76633 .67809 .77198 .68443 .78483 .681 .77922 .67463 Metetra
.646 .762 .934 r
.77922 .67463 .78483 .681 .79773 .67756 .79216 .67116 Metetra
.646 .762 .934 r
.79216 .67116 .79773 .67756 .81069 .6741 .80516 .66768 Metetra
.646 .762 .934 r
.80516 .66768 .81069 .6741 .82371 .67063 .81822 .66417 Metetra
.646 .762 .934 r
.81822 .66417 .82371 .67063 .83678 .66714 .83134 .66066 Metetra
.646 .762 .934 r
.83134 .66066 .83678 .66714 .84992 .66363 .84452 .65712 Metetra
.646 .762 .934 r
.84452 .65712 .84992 .66363 .86312 .66011 .85776 .65357 Metetra
.646 .762 .934 r
.85776 .65357 .86312 .66011 .87637 .65658 .87106 .65 Metetra
.646 .762 .934 r
.87106 .65 .87637 .65658 .88969 .65302 .88442 .64642 Metetra
.646 .762 .934 r
.88442 .64642 .88969 .65302 .90307 .64945 .89784 .64282 Metetra
.646 .762 .934 r
.89784 .64282 .90307 .64945 .9165 .64587 .91132 .63921 Metetra
.646 .762 .934 r
.91132 .63921 .9165 .64587 .93 .64227 .92487 .63557 Metetra
.646 .762 .934 r
.92487 .63557 .93 .64227 .94357 .63865 .93848 .63193 Metetra
.646 .762 .934 r
.93848 .63193 .94357 .63865 .95719 .63501 .95215 .62826 Metetra
.646 .762 .934 r
.95215 .62826 .95719 .63501 .97088 .63136 .96588 .62458 Metetra
.646 .762 .934 r
.96588 .62458 .97088 .63136 .98463 .62769 .97968 .62088 Metetra
.646 .762 .934 r
.36443 .7785 .37126 .78404 .38243 .78104 .37563 .77548 Metetra
.646 .762 .934 r
.37563 .77548 .38243 .78104 .39365 .77803 .38688 .77245 Metetra
.646 .762 .934 r
.38688 .77245 .39365 .77803 .40491 .77501 .39817 .7694 Metetra
.646 .762 .934 r
.39817 .7694 .40491 .77501 .41622 .77198 .40951 .76634 Metetra
.646 .762 .934 r
.40951 .76634 .41622 .77198 .42759 .76893 .4209 .76327 Metetra
.646 .762 .934 r
.4209 .76327 .42759 .76893 .43899 .76587 .43234 .76019 Metetra
.646 .762 .934 r
.43234 .76019 .43899 .76587 .45045 .7628 .44383 .75709 Metetra
.646 .762 .934 r
.44383 .75709 .45045 .7628 .46196 .75971 .45537 .75398 Metetra
.646 .762 .934 r
.45537 .75398 .46196 .75971 .47351 .75662 .46695 .75086 Metetra
.646 .762 .934 r
.46695 .75086 .47351 .75662 .48511 .7535 .47859 .74772 Metetra
.646 .762 .934 r
.47859 .74772 .48511 .7535 .49677 .75038 .49027 .74457 Metetra
.646 .762 .934 r
.49027 .74457 .49677 .75038 .50847 .74724 .50201 .74141 Metetra
.646 .762 .934 r
.50201 .74141 .50847 .74724 .52022 .74409 .51379 .73823 Metetra
.646 .762 .934 r
.51379 .73823 .52022 .74409 .53202 .74092 .52563 .73504 Metetra
.646 .762 .934 r
.52563 .73504 .53202 .74092 .54388 .73774 .53752 .73184 Metetra
.646 .762 .934 r
.53752 .73184 .54388 .73774 .55578 .73455 .54945 .72862 Metetra
.646 .762 .934 r
.54945 .72862 .55578 .73455 .56774 .73135 .56145 .72539 Metetra
.646 .762 .934 r
.56145 .72539 .56774 .73135 .57975 .72813 .57349 .72214 Metetra
.646 .762 .934 r
.57349 .72214 .57975 .72813 .59181 .72489 .58558 .71888 Metetra
.646 .762 .934 r
.58558 .71888 .59181 .72489 .60392 .72164 .59773 .71561 Metetra
.646 .762 .934 r
.59773 .71561 .60392 .72164 .61609 .71838 .60993 .71232 Metetra
.646 .762 .934 r
.60993 .71232 .61609 .71838 .62831 .7151 .62219 .70902 Metetra
.646 .762 .934 r
.62219 .70902 .62831 .7151 .64058 .71181 .6345 .7057 Metetra
.646 .762 .934 r
.6345 .7057 .64058 .71181 .65291 .70851 .64686 .70237 Metetra
.646 .762 .934 r
.64686 .70237 .65291 .70851 .66529 .70519 .65928 .69902 Metetra
.646 .762 .934 r
.65928 .69902 .66529 .70519 .67772 .70185 .67175 .69566 Metetra
.646 .762 .934 r
.67175 .69566 .67772 .70185 .69021 .6985 .68428 .69228 Metetra
.646 .762 .934 r
.68428 .69228 .69021 .6985 .70276 .69514 .69687 .68889 Metetra
.646 .762 .934 r
.69687 .68889 .70276 .69514 .71536 .69176 .70951 .68548 Metetra
.646 .762 .934 r
.70951 .68548 .71536 .69176 .72802 .68836 .7222 .68206 Metetra
.646 .762 .934 r
.7222 .68206 .72802 .68836 .74073 .68495 .73496 .67862 Metetra
.646 .762 .934 r
.73496 .67862 .74073 .68495 .7535 .68153 .74777 .67517 Metetra
.646 .762 .934 r
.74777 .67517 .7535 .68153 .76633 .67809 .76063 .6717 Metetra
.646 .762 .934 r
.76063 .6717 .76633 .67809 .77922 .67463 .77356 .66821 Metetra
.646 .762 .934 r
.77356 .66821 .77922 .67463 .79216 .67116 .78654 .66471 Metetra
.646 .762 .934 r
.78654 .66471 .79216 .67116 .80516 .66768 .79959 .6612 Metetra
.646 .762 .934 r
.79959 .6612 .80516 .66768 .81822 .66417 .81269 .65767 Metetra
.646 .762 .934 r
.81269 .65767 .81822 .66417 .83134 .66066 .82585 .65412 Metetra
.646 .762 .934 r
.82585 .65412 .83134 .66066 .84452 .65712 .83908 .65055 Metetra
.646 .762 .934 r
.83908 .65055 .84452 .65712 .85776 .65357 .85236 .64697 Metetra
.646 .762 .934 r
.85236 .64697 .85776 .65357 .87106 .65 .8657 .64338 Metetra
.646 .762 .934 r
.8657 .64338 .87106 .65 .88442 .64642 .87911 .63976 Metetra
.646 .762 .934 r
.87911 .63976 .88442 .64642 .89784 .64282 .89257 .63613 Metetra
.646 .762 .934 r
.89257 .63613 .89784 .64282 .91132 .63921 .9061 .63249 Metetra
.646 .762 .934 r
.9061 .63249 .91132 .63921 .92487 .63557 .91969 .62882 Metetra
.646 .762 .934 r
.91969 .62882 .92487 .63557 .93848 .63193 .93335 .62514 Metetra
.646 .762 .934 r
.93335 .62514 .93848 .63193 .95215 .62826 .94706 .62145 Metetra
.646 .762 .934 r
.94706 .62145 .95215 .62826 .96588 .62458 .96084 .61773 Metetra
.646 .762 .934 r
.96084 .61773 .96588 .62458 .97968 .62088 .97469 .614 Metetra
.646 .762 .934 r
.35754 .77291 .36443 .7785 .37563 .77548 .36877 .76987 Metetra
.646 .762 .934 r
.36877 .76987 .37563 .77548 .38688 .77245 .38005 .76681 Metetra
.646 .762 .934 r
.38005 .76681 .38688 .77245 .39817 .7694 .39138 .76375 Metetra
.646 .762 .934 r
.39138 .76375 .39817 .7694 .40951 .76634 .40275 .76066 Metetra
.646 .762 .934 r
.40275 .76066 .40951 .76634 .4209 .76327 .41417 .75757 Metetra
.646 .762 .934 r
.41417 .75757 .4209 .76327 .43234 .76019 .42564 .75446 Metetra
.646 .762 .934 r
.42564 .75446 .43234 .76019 .44383 .75709 .43716 .75134 Metetra
.646 .762 .934 r
.43716 .75134 .44383 .75709 .45537 .75398 .44872 .74821 Metetra
.646 .762 .934 r
.44872 .74821 .45537 .75398 .46695 .75086 .46034 .74506 Metetra
.646 .762 .934 r
.46034 .74506 .46695 .75086 .47859 .74772 .47201 .7419 Metetra
.646 .762 .934 r
.47201 .7419 .47859 .74772 .49027 .74457 .48373 .73872 Metetra
.646 .762 .934 r
.48373 .73872 .49027 .74457 .50201 .74141 .49549 .73554 Metetra
.646 .762 .934 r
.49549 .73554 .50201 .74141 .51379 .73823 .50731 .73233 Metetra
.646 .762 .934 r
.50731 .73233 .51379 .73823 .52563 .73504 .51918 .72912 Metetra
.646 .762 .934 r
.51918 .72912 .52563 .73504 .53752 .73184 .5311 .72589 Metetra
.646 .762 .934 r
.5311 .72589 .53752 .73184 .54945 .72862 .54308 .72264 Metetra
.646 .762 .934 r
.54308 .72264 .54945 .72862 .56145 .72539 .5551 .71939 Metetra
.646 .762 .934 r
.5551 .71939 .56145 .72539 .57349 .72214 .56718 .71611 Metetra
.646 .762 .934 r
.56718 .71611 .57349 .72214 .58558 .71888 .57931 .71283 Metetra
.646 .762 .934 r
.57931 .71283 .58558 .71888 .59773 .71561 .59149 .70953 Metetra
.646 .762 .934 r
.59149 .70953 .59773 .71561 .60993 .71232 .60373 .70621 Metetra
.646 .762 .934 r
.60373 .70621 .60993 .71232 .62219 .70902 .61602 .70288 Metetra
.646 .762 .934 r
.61602 .70288 .62219 .70902 .6345 .7057 .62837 .69953 Metetra
.646 .762 .934 r
.62837 .69953 .6345 .7057 .64686 .70237 .64077 .69617 Metetra
.646 .762 .934 r
.64077 .69617 .64686 .70237 .65928 .69902 .65322 .6928 Metetra
.646 .762 .934 r
.65322 .6928 .65928 .69902 .67175 .69566 .66573 .68941 Metetra
.646 .762 .934 r
.66573 .68941 .67175 .69566 .68428 .69228 .6783 .68601 Metetra
.646 .762 .934 r
.6783 .68601 .68428 .69228 .69687 .68889 .69092 .68259 Metetra
.646 .762 .934 r
.69092 .68259 .69687 .68889 .70951 .68548 .7036 .67915 Metetra
.646 .762 .934 r
.7036 .67915 .70951 .68548 .7222 .68206 .71634 .6757 Metetra
.646 .762 .934 r
.71634 .6757 .7222 .68206 .73496 .67862 .72913 .67223 Metetra
.646 .762 .934 r
.72913 .67223 .73496 .67862 .74777 .67517 .74198 .66875 Metetra
.646 .762 .934 r
.74198 .66875 .74777 .67517 .76063 .6717 .75489 .66525 Metetra
.646 .762 .934 r
.75489 .66525 .76063 .6717 .77356 .66821 .76786 .66174 Metetra
.646 .762 .934 r
.76786 .66174 .77356 .66821 .78654 .66471 .78088 .65821 Metetra
.646 .762 .934 r
.78088 .65821 .78654 .66471 .79959 .6612 .79397 .65467 Metetra
.646 .762 .934 r
.79397 .65467 .79959 .6612 .81269 .65767 .80711 .6511 Metetra
.646 .762 .934 r
.80711 .6511 .81269 .65767 .82585 .65412 .82032 .64753 Metetra
.646 .762 .934 r
.82032 .64753 .82585 .65412 .83908 .65055 .83358 .64393 Metetra
.646 .762 .934 r
.83358 .64393 .83908 .65055 .85236 .64697 .84691 .64032 Metetra
.646 .762 .934 r
.84691 .64032 .85236 .64697 .8657 .64338 .8603 .63669 Metetra
.646 .762 .934 r
.8603 .63669 .8657 .64338 .87911 .63976 .87375 .63305 Metetra
.646 .762 .934 r
.87375 .63305 .87911 .63976 .89257 .63613 .88726 .62939 Metetra
.646 .762 .934 r
.88726 .62939 .89257 .63613 .9061 .63249 .90083 .62571 Metetra
.646 .762 .934 r
.90083 .62571 .9061 .63249 .91969 .62882 .91447 .62202 Metetra
.646 .762 .934 r
.91447 .62202 .91969 .62882 .93335 .62514 .92817 .6183 Metetra
.646 .762 .934 r
.92817 .6183 .93335 .62514 .94706 .62145 .94193 .61457 Metetra
.646 .762 .934 r
.94193 .61457 .94706 .62145 .96084 .61773 .95576 .61083 Metetra
.646 .762 .934 r
.95576 .61083 .96084 .61773 .97469 .614 .96966 .60706 Metetra
.646 .762 .934 r
.35061 .76729 .35754 .77291 .36877 .76987 .36187 .76422 Metetra
.646 .762 .934 r
.36187 .76422 .36877 .76987 .38005 .76681 .37317 .76114 Metetra
.646 .762 .934 r
.37317 .76114 .38005 .76681 .39138 .76375 .38453 .75805 Metetra
.646 .762 .934 r
.38453 .75805 .39138 .76375 .40275 .76066 .39593 .75494 Metetra
.646 .762 .934 r
.39593 .75494 .40275 .76066 .41417 .75757 .40738 .75182 Metetra
.646 .762 .934 r
.40738 .75182 .41417 .75757 .42564 .75446 .41888 .74869 Metetra
.646 .762 .934 r
.41888 .74869 .42564 .75446 .43716 .75134 .43043 .74555 Metetra
.646 .762 .934 r
.43043 .74555 .43716 .75134 .44872 .74821 .44203 .74239 Metetra
.646 .762 .934 r
.44203 .74239 .44872 .74821 .46034 .74506 .45368 .73921 Metetra
.646 .762 .934 r
.45368 .73921 .46034 .74506 .47201 .7419 .46538 .73603 Metetra
.646 .762 .934 r
.46538 .73603 .47201 .7419 .48373 .73872 .47713 .73283 Metetra
.646 .762 .934 r
.47713 .73283 .48373 .73872 .49549 .73554 .48893 .72961 Metetra
.646 .762 .934 r
.48893 .72961 .49549 .73554 .50731 .73233 .50078 .72639 Metetra
.646 .762 .934 r
.50078 .72639 .50731 .73233 .51918 .72912 .51268 .72314 Metetra
.646 .762 .934 r
.51268 .72314 .51918 .72912 .5311 .72589 .52464 .71989 Metetra
.646 .762 .934 r
.52464 .71989 .5311 .72589 .54308 .72264 .53664 .71662 Metetra
.646 .762 .934 r
.53664 .71662 .54308 .72264 .5551 .71939 .5487 .71333 Metetra
.646 .762 .934 r
.5487 .71333 .5551 .71939 .56718 .71611 .56082 .71003 Metetra
.646 .762 .934 r
.56082 .71003 .56718 .71611 .57931 .71283 .57298 .70672 Metetra
.646 .762 .934 r
.57298 .70672 .57931 .71283 .59149 .70953 .5852 .70339 Metetra
.646 .762 .934 r
.5852 .70339 .59149 .70953 .60373 .70621 .59748 .70005 Metetra
.646 .762 .934 r
.59748 .70005 .60373 .70621 .61602 .70288 .6098 .69669 Metetra
.646 .762 .934 r
.6098 .69669 .61602 .70288 .62837 .69953 .62219 .69332 Metetra
.646 .762 .934 r
.62219 .69332 .62837 .69953 .64077 .69617 .63462 .68993 Metetra
.646 .762 .934 r
.63462 .68993 .64077 .69617 .65322 .6928 .64712 .68653 Metetra
.646 .762 .934 r
.64712 .68653 .65322 .6928 .66573 .68941 .65966 .68311 Metetra
.646 .762 .934 r
.65966 .68311 .66573 .68941 .6783 .68601 .67227 .67968 Metetra
.646 .762 .934 r
.67227 .67968 .6783 .68601 .69092 .68259 .68493 .67623 Metetra
.646 .762 .934 r
.68493 .67623 .69092 .68259 .7036 .67915 .69765 .67277 Metetra
.646 .762 .934 r
.69765 .67277 .7036 .67915 .71634 .6757 .71042 .66929 Metetra
.646 .762 .934 r
.71042 .66929 .71634 .6757 .72913 .67223 .72326 .66579 Metetra
.646 .762 .934 r
.72326 .66579 .72913 .67223 .74198 .66875 .73615 .66228 Metetra
.646 .762 .934 r
.73615 .66228 .74198 .66875 .75489 .66525 .7491 .65875 Metetra
.646 .762 .934 r
.7491 .65875 .75489 .66525 .76786 .66174 .76211 .65521 Metetra
.646 .762 .934 r
.76211 .65521 .76786 .66174 .78088 .65821 .77517 .65165 Metetra
.646 .762 .934 r
.77517 .65165 .78088 .65821 .79397 .65467 .7883 .64808 Metetra
.646 .762 .934 r
.7883 .64808 .79397 .65467 .80711 .6511 .80149 .64449 Metetra
.646 .762 .934 r
.80149 .64449 .80711 .6511 .82032 .64753 .81474 .64088 Metetra
.646 .762 .934 r
.81474 .64088 .82032 .64753 .83358 .64393 .82805 .63725 Metetra
.646 .762 .934 r
.82805 .63725 .83358 .64393 .84691 .64032 .84142 .63361 Metetra
.646 .762 .934 r
.84142 .63361 .84691 .64032 .8603 .63669 .85485 .62995 Metetra
.646 .762 .934 r
.85485 .62995 .8603 .63669 .87375 .63305 .86834 .62628 Metetra
.646 .762 .934 r
.86834 .62628 .87375 .63305 .88726 .62939 .8819 .62259 Metetra
.646 .762 .934 r
.8819 .62259 .88726 .62939 .90083 .62571 .89552 .61888 Metetra
.646 .762 .934 r
.89552 .61888 .90083 .62571 .91447 .62202 .9092 .61515 Metetra
.646 .762 .934 r
.9092 .61515 .91447 .62202 .92817 .6183 .92295 .61141 Metetra
.646 .762 .934 r
.92295 .61141 .92817 .6183 .94193 .61457 .93676 .60764 Metetra
.646 .762 .934 r
.93676 .60764 .94193 .61457 .95576 .61083 .95064 .60386 Metetra
.646 .762 .934 r
.95064 .60386 .95576 .61083 .96966 .60706 .96458 .60007 Metetra
.646 .762 .934 r
.34362 .76161 .35061 .76729 .36187 .76422 .35491 .75852 Metetra
.646 .762 .934 r
.35491 .75852 .36187 .76422 .37317 .76114 .36624 .75542 Metetra
.646 .762 .934 r
.36624 .75542 .37317 .76114 .38453 .75805 .37763 .7523 Metetra
.646 .762 .934 r
.37763 .7523 .38453 .75805 .39593 .75494 .38906 .74917 Metetra
.646 .762 .934 r
.38906 .74917 .39593 .75494 .40738 .75182 .40054 .74603 Metetra
.646 .762 .934 r
.40054 .74603 .40738 .75182 .41888 .74869 .41207 .74287 Metetra
.646 .762 .934 r
.41207 .74287 .41888 .74869 .43043 .74555 .42365 .7397 Metetra
.646 .762 .934 r
.42365 .7397 .43043 .74555 .44203 .74239 .43528 .73652 Metetra
.646 .762 .934 r
.43528 .73652 .44203 .74239 .45368 .73921 .44696 .73332 Metetra
.646 .762 .934 r
.44696 .73332 .45368 .73921 .46538 .73603 .45869 .73011 Metetra
.646 .762 .934 r
.45869 .73011 .46538 .73603 .47713 .73283 .47048 .72688 Metetra
.646 .762 .934 r
.47048 .72688 .47713 .73283 .48893 .72961 .48231 .72364 Metetra
.646 .762 .934 r
.48231 .72364 .48893 .72961 .50078 .72639 .49419 .72039 Metetra
.646 .762 .934 r
.49419 .72039 .50078 .72639 .51268 .72314 .50613 .71712 Metetra
.646 .762 .934 r
.50613 .71712 .51268 .72314 .52464 .71989 .51812 .71384 Metetra
.646 .762 .934 r
.51812 .71384 .52464 .71989 .53664 .71662 .53016 .71054 Metetra
.646 .762 .934 r
.53016 .71054 .53664 .71662 .5487 .71333 .54226 .70723 Metetra
.646 .762 .934 r
.54226 .70723 .5487 .71333 .56082 .71003 .5544 .70391 Metetra
.646 .762 .934 r
.5544 .70391 .56082 .71003 .57298 .70672 .5666 .70057 Metetra
.646 .762 .934 r
.5666 .70057 .57298 .70672 .5852 .70339 .57886 .69721 Metetra
.646 .762 .934 r
.57886 .69721 .5852 .70339 .59748 .70005 .59117 .69384 Metetra
.646 .762 .934 r
.59117 .69384 .59748 .70005 .6098 .69669 .60353 .69045 Metetra
.646 .762 .934 r
.60353 .69045 .6098 .69669 .62219 .69332 .61595 .68705 Metetra
.646 .762 .934 r
.61595 .68705 .62219 .69332 .63462 .68993 .62843 .68364 Metetra
.646 .762 .934 r
.62843 .68364 .63462 .68993 .64712 .68653 .64096 .68021 Metetra
.646 .762 .934 r
.64096 .68021 .64712 .68653 .65966 .68311 .65355 .67676 Metetra
.646 .762 .934 r
.65355 .67676 .65966 .68311 .67227 .67968 .66619 .6733 Metetra
.646 .762 .934 r
.66619 .6733 .67227 .67968 .68493 .67623 .67889 .66982 Metetra
.646 .762 .934 r
.67889 .66982 .68493 .67623 .69765 .67277 .69165 .66633 Metetra
.646 .762 .934 r
.69165 .66633 .69765 .67277 .71042 .66929 .70446 .66282 Metetra
.646 .762 .934 r
.70446 .66282 .71042 .66929 .72326 .66579 .71733 .6593 Metetra
.646 .762 .934 r
.71733 .6593 .72326 .66579 .73615 .66228 .73027 .65576 Metetra
.646 .762 .934 r
.73027 .65576 .73615 .66228 .7491 .65875 .74326 .6522 Metetra
.646 .762 .934 r
.74326 .6522 .7491 .65875 .76211 .65521 .75631 .64863 Metetra
.646 .762 .934 r
.75631 .64863 .76211 .65521 .77517 .65165 .76942 .64504 Metetra
.646 .762 .934 r
.76942 .64504 .77517 .65165 .7883 .64808 .78259 .64143 Metetra
.646 .762 .934 r
.78259 .64143 .7883 .64808 .80149 .64449 .79582 .63781 Metetra
.646 .762 .934 r
.79582 .63781 .80149 .64449 .81474 .64088 .80911 .63417 Metetra
.646 .762 .934 r
.80911 .63417 .81474 .64088 .82805 .63725 .82246 .63052 Metetra
.646 .762 .934 r
.82246 .63052 .82805 .63725 .84142 .63361 .83587 .62684 Metetra
.646 .762 .934 r
.83587 .62684 .84142 .63361 .85485 .62995 .84935 .62316 Metetra
.646 .762 .934 r
.84935 .62316 .85485 .62995 .86834 .62628 .86289 .61945 Metetra
.646 .762 .934 r
.86289 .61945 .86834 .62628 .8819 .62259 .87649 .61572 Metetra
.646 .762 .934 r
.87649 .61572 .8819 .62259 .89552 .61888 .89016 .61198 Metetra
.646 .762 .934 r
.89016 .61198 .89552 .61888 .9092 .61515 .90389 .60822 Metetra
.646 .762 .934 r
.90389 .60822 .9092 .61515 .92295 .61141 .91768 .60445 Metetra
.646 .762 .934 r
.91768 .60445 .92295 .61141 .93676 .60764 .93154 .60065 Metetra
.646 .762 .934 r
.93154 .60065 .93676 .60764 .95064 .60386 .94547 .59684 Metetra
.646 .762 .934 r
.94547 .59684 .95064 .60386 .96458 .60007 .95946 .59301 Metetra
.646 .762 .934 r
.33657 .7559 .34362 .76161 .35491 .75852 .34789 .75278 Metetra
.646 .762 .934 r
.34789 .75278 .35491 .75852 .36624 .75542 .35926 .74966 Metetra
.646 .762 .934 r
.35926 .74966 .36624 .75542 .37763 .7523 .37067 .74651 Metetra
.646 .762 .934 r
.37067 .74651 .37763 .7523 .38906 .74917 .38213 .74336 Metetra
.646 .762 .934 r
.38213 .74336 .38906 .74917 .40054 .74603 .39364 .74019 Metetra
.646 .762 .934 r
.39364 .74019 .40054 .74603 .41207 .74287 .40521 .73701 Metetra
.646 .762 .934 r
.40521 .73701 .41207 .74287 .42365 .7397 .41682 .73381 Metetra
.646 .762 .934 r
.41682 .73381 .42365 .7397 .43528 .73652 .42848 .7306 Metetra
.646 .762 .934 r
.42848 .7306 .43528 .73652 .44696 .73332 .44019 .72738 Metetra
.646 .762 .934 r
.44019 .72738 .44696 .73332 .45869 .73011 .45196 .72414 Metetra
.646 .762 .934 r
.45196 .72414 .45869 .73011 .47048 .72688 .46377 .72089 Metetra
.646 .762 .934 r
.46377 .72089 .47048 .72688 .48231 .72364 .47564 .71763 Metetra
.646 .762 .934 r
.47564 .71763 .48231 .72364 .49419 .72039 .48756 .71435 Metetra
.646 .762 .934 r
.48756 .71435 .49419 .72039 .50613 .71712 .49953 .71105 Metetra
.646 .762 .934 r
.49953 .71105 .50613 .71712 .51812 .71384 .51155 .70774 Metetra
.646 .762 .934 r
.51155 .70774 .51812 .71384 .53016 .71054 .52363 .70442 Metetra
.646 .762 .934 r
.52363 .70442 .53016 .71054 .54226 .70723 .53576 .70108 Metetra
.646 .762 .934 r
.53576 .70108 .54226 .70723 .5544 .70391 .54794 .69773 Metetra
.646 .762 .934 r
.54794 .69773 .5544 .70391 .5666 .70057 .56017 .69436 Metetra
.646 .762 .934 r
.56017 .69436 .5666 .70057 .57886 .69721 .57247 .69098 Metetra
.646 .762 .934 r
.57247 .69098 .57886 .69721 .59117 .69384 .58481 .68758 Metetra
.646 .762 .934 r
.58481 .68758 .59117 .69384 .60353 .69045 .59721 .68417 Metetra
.646 .762 .934 r
.59721 .68417 .60353 .69045 .61595 .68705 .60967 .68074 Metetra
.646 .762 .934 r
.60967 .68074 .61595 .68705 .62843 .68364 .62218 .67729 Metetra
.646 .762 .934 r
.62218 .67729 .62843 .68364 .64096 .68021 .63475 .67383 Metetra
.646 .762 .934 r
.63475 .67383 .64096 .68021 .65355 .67676 .64738 .67036 Metetra
.646 .762 .934 r
.64738 .67036 .65355 .67676 .66619 .6733 .66006 .66687 Metetra
.646 .762 .934 r
.66006 .66687 .66619 .6733 .67889 .66982 .6728 .66336 Metetra
.646 .762 .934 r
.6728 .66336 .67889 .66982 .69165 .66633 .68559 .65984 Metetra
.646 .762 .934 r
.68559 .65984 .69165 .66633 .70446 .66282 .69845 .6563 Metetra
.646 .762 .934 r
.69845 .6563 .70446 .66282 .71733 .6593 .71136 .65275 Metetra
.646 .762 .934 r
.71136 .65275 .71733 .6593 .73027 .65576 .72434 .64918 Metetra
.646 .762 .934 r
.72434 .64918 .73027 .65576 .74326 .6522 .73737 .64559 Metetra
.646 .762 .934 r
.73737 .64559 .74326 .6522 .75631 .64863 .75046 .64199 Metetra
.646 .762 .934 r
.75046 .64199 .75631 .64863 .76942 .64504 .76361 .63837 Metetra
.646 .762 .934 r
.76361 .63837 .76942 .64504 .78259 .64143 .77682 .63473 Metetra
.646 .762 .934 r
.77682 .63473 .78259 .64143 .79582 .63781 .7901 .63108 Metetra
.646 .762 .934 r
.7901 .63108 .79582 .63781 .80911 .63417 .80343 .62741 Metetra
.646 .762 .934 r
.80343 .62741 .80911 .63417 .82246 .63052 .81683 .62372 Metetra
.646 .762 .934 r
.81683 .62372 .82246 .63052 .83587 .62684 .83029 .62002 Metetra
.646 .762 .934 r
.83029 .62002 .83587 .62684 .84935 .62316 .84381 .6163 Metetra
.646 .762 .934 r
.84381 .6163 .84935 .62316 .86289 .61945 .85739 .61256 Metetra
.646 .762 .934 r
.85739 .61256 .86289 .61945 .87649 .61572 .87104 .6088 Metetra
.646 .762 .934 r
.87104 .6088 .87649 .61572 .89016 .61198 .88475 .60503 Metetra
.646 .762 .934 r
.88475 .60503 .89016 .61198 .90389 .60822 .89853 .60124 Metetra
.646 .762 .934 r
.89853 .60124 .90389 .60822 .91768 .60445 .91237 .59743 Metetra
.646 .762 .934 r
.91237 .59743 .91768 .60445 .93154 .60065 .92628 .5936 Metetra
.646 .762 .934 r
.92628 .5936 .93154 .60065 .94547 .59684 .94025 .58976 Metetra
.646 .762 .934 r
.94025 .58976 .94547 .59684 .95946 .59301 .95429 .58589 Metetra
.646 .762 .934 r
.32947 .75014 .33657 .7559 .34789 .75278 .34082 .747 Metetra
.646 .762 .934 r
.34082 .747 .34789 .75278 .35926 .74966 .35221 .74385 Metetra
.646 .762 .934 r
.35221 .74385 .35926 .74966 .37067 .74651 .36366 .74068 Metetra
.646 .762 .934 r
.36366 .74068 .37067 .74651 .38213 .74336 .37515 .7375 Metetra
.646 .762 .934 r
.37515 .7375 .38213 .74336 .39364 .74019 .38669 .73431 Metetra
.646 .762 .934 r
.38669 .73431 .39364 .74019 .40521 .73701 .39829 .7311 Metetra
.646 .762 .934 r
.39829 .7311 .40521 .73701 .41682 .73381 .40993 .72788 Metetra
.646 .762 .934 r
.40993 .72788 .41682 .73381 .42848 .7306 .42162 .72464 Metetra
.646 .762 .934 r
.42162 .72464 .42848 .7306 .44019 .72738 .43337 .72139 Metetra
.646 .762 .934 r
.43337 .72139 .44019 .72738 .45196 .72414 .44517 .71813 Metetra
.646 .762 .934 r
.44517 .71813 .45196 .72414 .46377 .72089 .45701 .71485 Metetra
.646 .762 .934 r
.45701 .71485 .46377 .72089 .47564 .71763 .46891 .71156 Metetra
.646 .762 .934 r
.46891 .71156 .47564 .71763 .48756 .71435 .48086 .70825 Metetra
.646 .762 .934 r
.48086 .70825 .48756 .71435 .49953 .71105 .49287 .70493 Metetra
.646 .762 .934 r
.49287 .70493 .49953 .71105 .51155 .70774 .50493 .70159 Metetra
.646 .762 .934 r
.50493 .70159 .51155 .70774 .52363 .70442 .51704 .69824 Metetra
.646 .762 .934 r
.51704 .69824 .52363 .70442 .53576 .70108 .5292 .69488 Metetra
.646 .762 .934 r
.5292 .69488 .53576 .70108 .54794 .69773 .54142 .6915 Metetra
.646 .762 .934 r
.54142 .6915 .54794 .69773 .56017 .69436 .55369 .6881 Metetra
.646 .762 .934 r
.55369 .6881 .56017 .69436 .57247 .69098 .56602 .68469 Metetra
.646 .762 .934 r
.56602 .68469 .57247 .69098 .58481 .68758 .5784 .68127 Metetra
.646 .762 .934 r
.5784 .68127 .58481 .68758 .59721 .68417 .59084 .67782 Metetra
.646 .762 .934 r
.59084 .67782 .59721 .68417 .60967 .68074 .60333 .67437 Metetra
.646 .762 .934 r
.60333 .67437 .60967 .68074 .62218 .67729 .61588 .6709 Metetra
.646 .762 .934 r
.61588 .6709 .62218 .67729 .63475 .67383 .62849 .66741 Metetra
.646 .762 .934 r
.62849 .66741 .63475 .67383 .64738 .67036 .64115 .6639 Metetra
.646 .762 .934 r
.64115 .6639 .64738 .67036 .66006 .66687 .65387 .66038 Metetra
.646 .762 .934 r
.65387 .66038 .66006 .66687 .6728 .66336 .66665 .65685 Metetra
.646 .762 .934 r
.66665 .65685 .6728 .66336 .68559 .65984 .67949 .6533 Metetra
.646 .762 .934 r
.67949 .6533 .68559 .65984 .69845 .6563 .69239 .64973 Metetra
.646 .762 .934 r
.69239 .64973 .69845 .6563 .71136 .65275 .70534 .64615 Metetra
.646 .762 .934 r
.70534 .64615 .71136 .65275 .72434 .64918 .71835 .64255 Metetra
.646 .762 .934 r
.71835 .64255 .72434 .64918 .73737 .64559 .73143 .63893 Metetra
.646 .762 .934 r
.73143 .63893 .73737 .64559 .75046 .64199 .74456 .63529 Metetra
.646 .762 .934 r
.74456 .63529 .75046 .64199 .76361 .63837 .75775 .63164 Metetra
.646 .762 .934 r
.75775 .63164 .76361 .63837 .77682 .63473 .77101 .62798 Metetra
.646 .762 .934 r
.77101 .62798 .77682 .63473 .7901 .63108 .78433 .62429 Metetra
.646 .762 .934 r
.78433 .62429 .7901 .63108 .80343 .62741 .79771 .62059 Metetra
.646 .762 .934 r
.79771 .62059 .80343 .62741 .81683 .62372 .81115 .61687 Metetra
.646 .762 .934 r
.81115 .61687 .81683 .62372 .83029 .62002 .82465 .61314 Metetra
.646 .762 .934 r
.82465 .61314 .83029 .62002 .84381 .6163 .83822 .60938 Metetra
.646 .762 .934 r
.83822 .60938 .84381 .6163 .85739 .61256 .85185 .60561 Metetra
.646 .762 .934 r
.85185 .60561 .85739 .61256 .87104 .6088 .86554 .60182 Metetra
.646 .762 .934 r
.86554 .60182 .87104 .6088 .88475 .60503 .8793 .59802 Metetra
.646 .762 .934 r
.8793 .59802 .88475 .60503 .89853 .60124 .89312 .59419 Metetra
.646 .762 .934 r
.89312 .59419 .89853 .60124 .91237 .59743 .90701 .59035 Metetra
.646 .762 .934 r
.90701 .59035 .91237 .59743 .92628 .5936 .92097 .58649 Metetra
.646 .762 .934 r
.92097 .58649 .92628 .5936 .94025 .58976 .93499 .58261 Metetra
.646 .762 .934 r
.93499 .58261 .94025 .58976 .95429 .58589 .94908 .57871 Metetra
.646 .762 .934 r
.32231 .74433 .32947 .75014 .34082 .747 .33369 .74117 Metetra
.646 .762 .934 r
.33369 .74117 .34082 .747 .35221 .74385 .34512 .73799 Metetra
.646 .762 .934 r
.34512 .73799 .35221 .74385 .36366 .74068 .35659 .7348 Metetra
.646 .762 .934 r
.35659 .7348 .36366 .74068 .37515 .7375 .36811 .73159 Metetra
.646 .762 .934 r
.36811 .73159 .37515 .7375 .38669 .73431 .37969 .72837 Metetra
.646 .762 .934 r
.37969 .72837 .38669 .73431 .39829 .7311 .39131 .72514 Metetra
.646 .762 .934 r
.39131 .72514 .39829 .7311 .40993 .72788 .40299 .72189 Metetra
.646 .762 .934 r
.40299 .72189 .40993 .72788 .42162 .72464 .41471 .71863 Metetra
.646 .762 .934 r
.41471 .71863 .42162 .72464 .43337 .72139 .42649 .71536 Metetra
.646 .762 .934 r
.42649 .71536 .43337 .72139 .44517 .71813 .43832 .71207 Metetra
.646 .762 .934 r
.43832 .71207 .44517 .71813 .45701 .71485 .4502 .70876 Metetra
.646 .762 .934 r
.4502 .70876 .45701 .71485 .46891 .71156 .46213 .70544 Metetra
.646 .762 .934 r
.46213 .70544 .46891 .71156 .48086 .70825 .47412 .70211 Metetra
.646 .762 .934 r
.47412 .70211 .48086 .70825 .49287 .70493 .48616 .69876 Metetra
.646 .762 .934 r
.48616 .69876 .49287 .70493 .50493 .70159 .49825 .6954 Metetra
.646 .762 .934 r
.49825 .6954 .50493 .70159 .51704 .69824 .51039 .69202 Metetra
.646 .762 .934 r
.51039 .69202 .51704 .69824 .5292 .69488 .52259 .68863 Metetra
.646 .762 .934 r
.52259 .68863 .5292 .69488 .54142 .6915 .53485 .68522 Metetra
.646 .762 .934 r
.53485 .68522 .54142 .6915 .55369 .6881 .54716 .68179 Metetra
.646 .762 .934 r
.54716 .68179 .55369 .6881 .56602 .68469 .55952 .67836 Metetra
.646 .762 .934 r
.55952 .67836 .56602 .68469 .5784 .68127 .57194 .6749 Metetra
.646 .762 .934 r
.57194 .6749 .5784 .68127 .59084 .67782 .58441 .67143 Metetra
.646 .762 .934 r
.58441 .67143 .59084 .67782 .60333 .67437 .59694 .66795 Metetra
.646 .762 .934 r
.59694 .66795 .60333 .67437 .61588 .6709 .60953 .66444 Metetra
.646 .762 .934 r
.60953 .66444 .61588 .6709 .62849 .66741 .62218 .66093 Metetra
.646 .762 .934 r
.62218 .66093 .62849 .66741 .64115 .6639 .63488 .65739 Metetra
.646 .762 .934 r
.63488 .65739 .64115 .6639 .65387 .66038 .64764 .65385 Metetra
.646 .762 .934 r
.64764 .65385 .65387 .66038 .66665 .65685 .66046 .65028 Metetra
.646 .762 .934 r
.66046 .65028 .66665 .65685 .67949 .6533 .67334 .6467 Metetra
.646 .762 .934 r
.67334 .6467 .67949 .6533 .69239 .64973 .68627 .6431 Metetra
.646 .762 .934 r
.68627 .6431 .69239 .64973 .70534 .64615 .69927 .63949 Metetra
.646 .762 .934 r
.69927 .63949 .70534 .64615 .71835 .64255 .71232 .63585 Metetra
.646 .762 .934 r
.71232 .63585 .71835 .64255 .73143 .63893 .72544 .63221 Metetra
.646 .762 .934 r
.72544 .63221 .73143 .63893 .74456 .63529 .73861 .62854 Metetra
.646 .762 .934 r
.73861 .62854 .74456 .63529 .75775 .63164 .75185 .62486 Metetra
.646 .762 .934 r
.75185 .62486 .75775 .63164 .77101 .62798 .76515 .62116 Metetra
.646 .762 .934 r
.76515 .62116 .77101 .62798 .78433 .62429 .77851 .61745 Metetra
.646 .762 .934 r
.77851 .61745 .78433 .62429 .79771 .62059 .79193 .61371 Metetra
.646 .762 .934 r
.79193 .61371 .79771 .62059 .81115 .61687 .80542 .60996 Metetra
.646 .762 .934 r
.80542 .60996 .81115 .61687 .82465 .61314 .81896 .60619 Metetra
.646 .762 .934 r
.81896 .60619 .82465 .61314 .83822 .60938 .83258 .60241 Metetra
.646 .762 .934 r
.83258 .60241 .83822 .60938 .85185 .60561 .84625 .5986 Metetra
.646 .762 .934 r
.84625 .5986 .85185 .60561 .86554 .60182 .85999 .59478 Metetra
.646 .762 .934 r
.85999 .59478 .86554 .60182 .8793 .59802 .8738 .59094 Metetra
.646 .762 .934 r
.8738 .59094 .8793 .59802 .89312 .59419 .88767 .58708 Metetra
.646 .762 .934 r
.88767 .58708 .89312 .59419 .90701 .59035 .90161 .58321 Metetra
.646 .762 .934 r
.90161 .58321 .90701 .59035 .92097 .58649 .91561 .57931 Metetra
.646 .762 .934 r
.91561 .57931 .92097 .58649 .93499 .58261 .92968 .5754 Metetra
.646 .762 .934 r
.92968 .5754 .93499 .58261 .94908 .57871 .94382 .57146 Metetra
.648 .763 .933 r
.3151 .73848 .32231 .74433 .33369 .74117 .32651 .73523 Metetra
.654 .762 .929 r
.32651 .73523 .33369 .74117 .34512 .73799 .33798 .73183 Metetra
.658 .757 .923 r
.33798 .73183 .34512 .73799 .35659 .7348 .34949 .7283 Metetra
.662 .749 .914 r
.34949 .7283 .35659 .7348 .36811 .73159 .36107 .72465 Metetra
.666 .737 .903 r
.36107 .72465 .36811 .73159 .37969 .72837 .37269 .72087 Metetra
.669 .723 .89 r
.37269 .72087 .37969 .72837 .39131 .72514 .38437 .71697 Metetra
.67 .707 .876 r
.38437 .71697 .39131 .72514 .40299 .72189 .39609 .71296 Metetra
.67 .69 .86 r
.39609 .71296 .40299 .72189 .41471 .71863 .40787 .70886 Metetra
.669 .673 .845 r
.40787 .70886 .41471 .71863 .42649 .71536 .41969 .70466 Metetra
.667 .655 .829 r
.41969 .70466 .42649 .71536 .43832 .71207 .43157 .70039 Metetra
.664 .638 .814 r
.43157 .70039 .43832 .71207 .4502 .70876 .44348 .69607 Metetra
.66 .622 .8 r
.44348 .69607 .4502 .70876 .46213 .70544 .45545 .6917 Metetra
.657 .607 .788 r
.45545 .6917 .46213 .70544 .47412 .70211 .46746 .68732 Metetra
.653 .594 .776 r
.46746 .68732 .47412 .70211 .48616 .69876 .47951 .68292 Metetra
.649 .581 .765 r
.47951 .68292 .48616 .69876 .49825 .6954 .49162 .67854 Metetra
.645 .57 .756 r
.49162 .67854 .49825 .6954 .51039 .69202 .50377 .67418 Metetra
.641 .56 .748 r
.50377 .67418 .51039 .69202 .52259 .68863 .51596 .66987 Metetra
.638 .551 .74 r
.51596 .66987 .52259 .68863 .53485 .68522 .52821 .66561 Metetra
.634 .544 .734 r
.52821 .66561 .53485 .68522 .54716 .68179 .5405 .66142 Metetra
.631 .537 .729 r
.5405 .66142 .54716 .68179 .55952 .67836 .55285 .65732 Metetra
.629 .531 .725 r
.55285 .65732 .55952 .67836 .57194 .6749 .56525 .6533 Metetra
.626 .527 .722 r
.56525 .6533 .57194 .6749 .58441 .67143 .5777 .64939 Metetra
.624 .523 .719 r
.5777 .64939 .58441 .67143 .59694 .66795 .5902 .64558 Metetra
.621 .52 .718 r
.5902 .64558 .59694 .66795 .60953 .66444 .60277 .64188 Metetra
.619 .518 .717 r
.60277 .64188 .60953 .66444 .62218 .66093 .61539 .6383 Metetra
.618 .517 .717 r
.61539 .6383 .62218 .66093 .63488 .65739 .62808 .63483 Metetra
.616 .517 .718 r
.62808 .63483 .63488 .65739 .64764 .65385 .64082 .63148 Metetra
.615 .518 .72 r
.64082 .63148 .64764 .65385 .66046 .65028 .65364 .62823 Metetra
.614 .519 .723 r
.65364 .62823 .66046 .65028 .67334 .6467 .66651 .62509 Metetra
.614 .522 .727 r
.66651 .62509 .67334 .6467 .68627 .6431 .67946 .62205 Metetra
.613 .525 .731 r
.67946 .62205 .68627 .6431 .69927 .63949 .69247 .61909 Metetra
.613 .53 .737 r
.69247 .61909 .69927 .63949 .71232 .63585 .70556 .61621 Metetra
.613 .536 .743 r
.70556 .61621 .71232 .63585 .72544 .63221 .71872 .6134 Metetra
.614 .543 .751 r
.71872 .6134 .72544 .63221 .73861 .62854 .73194 .61063 Metetra
.614 .551 .76 r
.73194 .61063 .73861 .62854 .75185 .62486 .74524 .6079 Metetra
.616 .561 .77 r
.74524 .6079 .75185 .62486 .76515 .62116 .75861 .60519 Metetra
.617 .572 .782 r
.75861 .60519 .76515 .62116 .77851 .61745 .77206 .60247 Metetra
.618 .585 .794 r
.77206 .60247 .77851 .61745 .79193 .61371 .78557 .59974 Metetra
.62 .6 .808 r
.78557 .59974 .79193 .61371 .80542 .60996 .79915 .59698 Metetra
.622 .616 .823 r
.79915 .59698 .80542 .60996 .81896 .60619 .81281 .59416 Metetra
.625 .633 .838 r
.81281 .59416 .81896 .60619 .83258 .60241 .82653 .59128 Metetra
.627 .651 .854 r
.82653 .59128 .83258 .60241 .84625 .5986 .84031 .58831 Metetra
.629 .67 .87 r
.84031 .58831 .84625 .5986 .85999 .59478 .85416 .58523 Metetra
.631 .689 .885 r
.85416 .58523 .85999 .59478 .8738 .59094 .86807 .58205 Metetra
.633 .707 .899 r
.86807 .58205 .8738 .59094 .88767 .58708 .88205 .57874 Metetra
.635 .723 .911 r
.88205 .57874 .88767 .58708 .90161 .58321 .89608 .5753 Metetra
.637 .738 .921 r
.89608 .5753 .90161 .58321 .91561 .57931 .91017 .57173 Metetra
.64 .749 .928 r
.91017 .57173 .91561 .57931 .92968 .5754 .92432 .56802 Metetra
.643 .758 .932 r
.92432 .56802 .92968 .5754 .94382 .57146 .93852 .56416 Metetra
.648 .763 .933 r
.30783 .73258 .3151 .73848 .32651 .73523 .31927 .72931 Metetra
.663 .767 .927 r
.31927 .72931 .32651 .73523 .33798 .73183 .33078 .72561 Metetra
.672 .76 .917 r
.33078 .72561 .33798 .73183 .34949 .7283 .34235 .72165 Metetra
.68 .75 .904 r
.34235 .72165 .34949 .7283 .36107 .72465 .35398 .71742 Metetra
.686 .736 .889 r
.35398 .71742 .36107 .72465 .37269 .72087 .36566 .71293 Metetra
.689 .719 .872 r
.36566 .71293 .37269 .72087 .38437 .71697 .3774 .70819 Metetra
.691 .701 .854 r
.3774 .70819 .38437 .71697 .39609 .71296 .38919 .70321 Metetra
.69 .681 .836 r
.38919 .70321 .39609 .71296 .40787 .70886 .40102 .69803 Metetra
.688 .662 .819 r
.40102 .69803 .40787 .70886 .41969 .70466 .4129 .69267 Metetra
.684 .642 .802 r
.4129 .69267 .41969 .70466 .43157 .70039 .42482 .68717 Metetra
.68 .624 .786 r
.42482 .68717 .43157 .70039 .44348 .69607 .43678 .68155 Metetra
.674 .607 .772 r
.43678 .68155 .44348 .69607 .45545 .6917 .44878 .67587 Metetra
.669 .591 .759 r
.44878 .67587 .45545 .6917 .46746 .68732 .46082 .67015 Metetra
.663 .577 .747 r
.46082 .67015 .46746 .68732 .47951 .68292 .47289 .66444 Metetra
.658 .563 .737 r
.47289 .66444 .47951 .68292 .49162 .67854 .485 .65877 Metetra
.652 .552 .728 r
.485 .65877 .49162 .67854 .50377 .67418 .49715 .65318 Metetra
.647 .541 .721 r
.49715 .65318 .50377 .67418 .51596 .66987 .50934 .64771 Metetra
.642 .532 .714 r
.50934 .64771 .51596 .66987 .52821 .66561 .52157 .64238 Metetra
.637 .523 .708 r
.52157 .64238 .52821 .66561 .5405 .66142 .53384 .63723 Metetra
.632 .516 .704 r
.53384 .63723 .5405 .66142 .55285 .65732 .54615 .63229 Metetra
.628 .51 .7 r
.54615 .63229 .55285 .65732 .56525 .6533 .55851 .62758 Metetra
.623 .504 .697 r
.55851 .62758 .56525 .6533 .5777 .64939 .57093 .62311 Metetra
.62 .5 .695 r
.57093 .62311 .5777 .64939 .5902 .64558 .58339 .61891 Metetra
.616 .496 .694 r
.58339 .61891 .5902 .64558 .60277 .64188 .59592 .61497 Metetra
.612 .493 .693 r
.59592 .61497 .60277 .64188 .61539 .6383 .6085 .61131 Metetra
.609 .491 .693 r
.6085 .61131 .61539 .6383 .62808 .63483 .62116 .60793 Metetra
.606 .49 .695 r
.62116 .60793 .62808 .63483 .64082 .63148 .63388 .60483 Metetra
.604 .489 .696 r
.63388 .60483 .64082 .63148 .65364 .62823 .64667 .602 Metetra
.601 .49 .699 r
.64667 .602 .65364 .62823 .66651 .62509 .65953 .59942 Metetra
.599 .491 .703 r
.65953 .59942 .66651 .62509 .67946 .62205 .67248 .59708 Metetra
.597 .494 .707 r
.67248 .59708 .67946 .62205 .69247 .61909 .6855 .59497 Metetra
.595 .497 .713 r
.6855 .59497 .69247 .61909 .70556 .61621 .69861 .59304 Metetra
.594 .502 .72 r
.69861 .59304 .70556 .61621 .71872 .6134 .71181 .59129 Metetra
.593 .508 .727 r
.71181 .59129 .71872 .6134 .73194 .61063 .72508 .58967 Metetra
.592 .515 .737 r
.72508 .58967 .73194 .61063 .74524 .6079 .73845 .58815 Metetra
.592 .524 .747 r
.73845 .58815 .74524 .6079 .75861 .60519 .75189 .58669 Metetra
.592 .534 .759 r
.75189 .58669 .75861 .60519 .77206 .60247 .76543 .58526 Metetra
.592 .547 .773 r
.76543 .58526 .77206 .60247 .78557 .59974 .77904 .58381 Metetra
.594 .562 .788 r
.77904 .58381 .78557 .59974 .79915 .59698 .79273 .58231 Metetra
.595 .579 .805 r
.79273 .58231 .79915 .59698 .81281 .59416 .8065 .58072 Metetra
.598 .597 .822 r
.8065 .58072 .81281 .59416 .82653 .59128 .82034 .57899 Metetra
.601 .618 .841 r
.82034 .57899 .82653 .59128 .84031 .58831 .83425 .57709 Metetra
.604 .64 .86 r
.83425 .57709 .84031 .58831 .85416 .58523 .84823 .57498 Metetra
.608 .663 .878 r
.84823 .57498 .85416 .58523 .86807 .58205 .86226 .57265 Metetra
.613 .686 .895 r
.86226 .57265 .86807 .58205 .88205 .57874 .87635 .57006 Metetra
.618 .708 .91 r
.87635 .57006 .88205 .57874 .89608 .5753 .89049 .56719 Metetra
.624 .727 .921 r
.89049 .56719 .89608 .5753 .91017 .57173 .90468 .56405 Metetra
.63 .744 .93 r
.90468 .56405 .91017 .57173 .92432 .56802 .91891 .56062 Metetra
.641 .759 .934 r
.91891 .56062 .92432 .56802 .93852 .56416 .93316 .55678 Metetra
.646 .762 .934 r
.3005 .72663 .30783 .73258 .31927 .72931 .31196 .72339 Metetra
.67 .77 .925 r
.31196 .72339 .31927 .72931 .33078 .72561 .32352 .71948 Metetra
.685 .767 .914 r
.32352 .71948 .33078 .72561 .34235 .72165 .33514 .71508 Metetra
.696 .757 .899 r
.33514 .71508 .34235 .72165 .35398 .71742 .34683 .71027 Metetra
.704 .743 .883 r
.34683 .71027 .35398 .71742 .36566 .71293 .35858 .70507 Metetra
.709 .727 .865 r
.35858 .70507 .36566 .71293 .3774 .70819 .37038 .69949 Metetra
.711 .71 .847 r
.37038 .69949 .3774 .70819 .38919 .70321 .38223 .69356 Metetra
.711 .691 .829 r
.38223 .69356 .38919 .70321 .40102 .69803 .39413 .68731 Metetra
.709 .672 .812 r
.39413 .68731 .40102 .69803 .4129 .69267 .40606 .6808 Metetra
.705 .653 .796 r
.40606 .6808 .4129 .69267 .42482 .68717 .41804 .67408 Metetra
.7 .635 .781 r
.41804 .67408 .42482 .68717 .43678 .68155 .43005 .66719 Metetra
.694 .618 .767 r
.43005 .66719 .43678 .68155 .44878 .67587 .44209 .6602 Metetra
.687 .602 .755 r
.44209 .6602 .44878 .67587 .46082 .67015 .45416 .65318 Metetra
.681 .588 .744 r
.45416 .65318 .46082 .67015 .47289 .66444 .46626 .64617 Metetra
.674 .574 .735 r
.46626 .64617 .47289 .66444 .485 .65877 .47838 .63923 Metetra
.667 .562 .727 r
.47838 .63923 .485 .65877 .49715 .65318 .49054 .63244 Metetra
.661 .551 .719 r
.49054 .63244 .49715 .65318 .50934 .64771 .50272 .62583 Metetra
.654 .541 .713 r
.50272 .62583 .50934 .64771 .52157 .64238 .51494 .61946 Metetra
.648 .531 .708 r
.51494 .61946 .52157 .64238 .53384 .63723 .52719 .61338 Metetra
.641 .523 .704 r
.52719 .61338 .53384 .63723 .54615 .63229 .53947 .60762 Metetra
.635 .516 .7 r
.53947 .60762 .54615 .63229 .55851 .62758 .5518 .60223 Metetra
.629 .509 .698 r
.5518 .60223 .55851 .62758 .57093 .62311 .56418 .59722 Metetra
.624 .504 .696 r
.56418 .59722 .57093 .62311 .58339 .61891 .57661 .59262 Metetra
.618 .499 .695 r
.57661 .59262 .58339 .61891 .59592 .61497 .5891 .58846 Metetra
.613 .495 .695 r
.5891 .58846 .59592 .61497 .6085 .61131 .60165 .58472 Metetra
.608 .492 .695 r
.60165 .58472 .6085 .61131 .62116 .60793 .61427 .58143 Metetra
.603 .489 .696 r
.61427 .58143 .62116 .60793 .63388 .60483 .62696 .57858 Metetra
.599 .488 .699 r
.62696 .57858 .63388 .60483 .64667 .602 .63973 .57614 Metetra
.594 .487 .702 r
.63973 .57614 .64667 .602 .65953 .59942 .65258 .57412 Metetra
.59 .487 .705 r
.65258 .57412 .65953 .59942 .67248 .59708 .66553 .57247 Metetra
.586 .488 .71 r
.66553 .57247 .67248 .59708 .6855 .59497 .67856 .57117 Metetra
.582 .491 .716 r
.67856 .57117 .6855 .59497 .69861 .59304 .69169 .57018 Metetra
.579 .494 .723 r
.69169 .57018 .69861 .59304 .71181 .59129 .70491 .56946 Metetra
.576 .499 .731 r
.70491 .56946 .71181 .59129 .72508 .58967 .71824 .56896 Metetra
.573 .505 .741 r
.71824 .56896 .72508 .58967 .73845 .58815 .73166 .56862 Metetra
.571 .514 .752 r
.73166 .56862 .73845 .58815 .75189 .58669 .74518 .5684 Metetra
.569 .524 .765 r
.74518 .5684 .75189 .58669 .76543 .58526 .75879 .56823 Metetra
.568 .536 .779 r
.75879 .56823 .76543 .58526 .77904 .58381 .7725 .56804 Metetra
.568 .55 .795 r
.7725 .56804 .77904 .58381 .79273 .58231 .7863 .56778 Metetra
.568 .567 .812 r
.7863 .56778 .79273 .58231 .8065 .58072 .80018 .56739 Metetra
.57 .586 .83 r
.80018 .56739 .8065 .58072 .82034 .57899 .81414 .5668 Metetra
.573 .607 .849 r
.81414 .5668 .82034 .57899 .83425 .57709 .82817 .56596 Metetra
.577 .63 .868 r
.82817 .56596 .83425 .57709 .84823 .57498 .84226 .56481 Metetra
.583 .654 .886 r
.84226 .56481 .84823 .57498 .86226 .57265 .85642 .56332 Metetra
.59 .679 .902 r
.85642 .56332 .86226 .57265 .87635 .57006 .87062 .56144 Metetra
.598 .702 .917 r
.87062 .56144 .87635 .57006 .89049 .56719 .88487 .55915 Metetra
.608 .724 .928 r
.88487 .55915 .89049 .56719 .90468 .56405 .89915 .55645 Metetra
.618 .743 .936 r
.89915 .55645 .90468 .56405 .91891 .56062 .91347 .55332 Metetra
.644 .765 .937 r
.91347 .55332 .91891 .56062 .93316 .55678 .92776 .54934 Metetra
.646 .762 .934 r
.29311 .72064 .3005 .72663 .31196 .72339 .30461 .71737 Metetra
.667 .767 .925 r
.30461 .71737 .31196 .72339 .32352 .71948 .31619 .71351 Metetra
.698 .776 .912 r
.31619 .71351 .32352 .71948 .33514 .71508 .32787 .70865 Metetra
.711 .766 .895 r
.32787 .70865 .33514 .71508 .34683 .71027 .33962 .70327 Metetra
.721 .752 .877 r
.33962 .70327 .34683 .71027 .35858 .70507 .35143 .69737 Metetra
.727 .736 .859 r
.35143 .69737 .35858 .70507 .37038 .69949 .3633 .69096 Metetra
.73 .719 .841 r
.3633 .69096 .37038 .69949 .38223 .69356 .37522 .68408 Metetra
.73 .701 .823 r
.37522 .68408 .38223 .69356 .39413 .68731 .38718 .67679 Metetra
.728 .682 .806 r
.38718 .67679 .39413 .68731 .40606 .6808 .39919 .66915 Metetra
.724 .664 .791 r
.39919 .66915 .40606 .6808 .41804 .67408 .41122 .66122 Metetra
.718 .646 .776 r
.41122 .66122 .41804 .67408 .43005 .66719 .42329 .65309 Metetra
.712 .63 .764 r
.42329 .65309 .43005 .66719 .44209 .6602 .43537 .64483 Metetra
.705 .614 .752 r
.43537 .64483 .44209 .6602 .45416 .65318 .44748 .63652 Metetra
.698 .599 .742 r
.44748 .63652 .45416 .65318 .46626 .64617 .45961 .62824 Metetra
.69 .585 .733 r
.45961 .62824 .46626 .64617 .47838 .63923 .47175 .62008 Metetra
.682 .573 .726 r
.47175 .62008 .47838 .63923 .49054 .63244 .48392 .6121 Metetra
.674 .561 .719 r
.48392 .6121 .49054 .63244 .50272 .62583 .4961 .60439 Metetra
.666 .55 .713 r
.4961 .60439 .50272 .62583 .51494 .61946 .50831 .597 Metetra
.659 .54 .708 r
.50831 .597 .51494 .61946 .52719 .61338 .52055 .59001 Metetra
.651 .531 .705 r
.52055 .59001 .52719 .61338 .53947 .60762 .53281 .58346 Metetra
.643 .523 .702 r
.53281 .58346 .53947 .60762 .5518 .60223 .54512 .5774 Metetra
.636 .515 .699 r
.54512 .5774 .5518 .60223 .56418 .59722 .55746 .57186 Metetra
.628 .509 .698 r
.55746 .57186 .56418 .59722 .57661 .59262 .56986 .56689 Metetra
.621 .503 .697 r
.56986 .56689 .57661 .59262 .5891 .58846 .58231 .56249 Metetra
.614 .498 .697 r
.58231 .56249 .5891 .58846 .60165 .58472 .59482 .55869 Metetra
.607 .493 .698 r
.59482 .55869 .60165 .58472 .61427 .58143 .60741 .55548 Metetra
.6 .49 .699 r
.60741 .55548 .61427 .58143 .62696 .57858 .62008 .55286 Metetra
.594 .487 .702 r
.62008 .55286 .62696 .57858 .63973 .57614 .63282 .55082 Metetra
.587 .485 .705 r
.63282 .55082 .63973 .57614 .65258 .57412 .64566 .54932 Metetra
.581 .484 .709 r
.64566 .54932 .65258 .57412 .66553 .57247 .6586 .54834 Metetra
.575 .484 .714 r
.6586 .54834 .66553 .57247 .67856 .57117 .67164 .54784 Metetra
.569 .485 .72 r
.67164 .54784 .67856 .57117 .69169 .57018 .68479 .54776 Metetra
.563 .487 .728 r
.68479 .54776 .69169 .57018 .70491 .56946 .69804 .54805 Metetra
.557 .491 .736 r
.69804 .54805 .70491 .56946 .71824 .56896 .71141 .54864 Metetra
.552 .496 .746 r
.71141 .54864 .71824 .56896 .73166 .56862 .72488 .54946 Metetra
.548 .503 .758 r
.72488 .54946 .73166 .56862 .74518 .5684 .73847 .55044 Metetra
.544 .513 .771 r
.73847 .55044 .74518 .5684 .75879 .56823 .75217 .55149 Metetra
.541 .524 .786 r
.75217 .55149 .75879 .56823 .7725 .56804 .76596 .55254 Metetra
.539 .538 .802 r
.76596 .55254 .7725 .56804 .7863 .56778 .77986 .5535 Metetra
.539 .555 .819 r
.77986 .5535 .7863 .56778 .80018 .56739 .79385 .55428 Metetra
.539 .574 .838 r
.79385 .55428 .80018 .56739 .81414 .5668 .80792 .55481 Metetra
.542 .596 .857 r
.80792 .55481 .81414 .5668 .82817 .56596 .82207 .55501 Metetra
.547 .62 .876 r
.82207 .55501 .82817 .56596 .84226 .56481 .83628 .5548 Metetra
.555 .646 .895 r
.83628 .5548 .84226 .56481 .85642 .56332 .85055 .55414 Metetra
.564 .672 .911 r
.85055 .55414 .85642 .56332 .87062 .56144 .86486 .55297 Metetra
.576 .698 .925 r
.86486 .55297 .87062 .56144 .88487 .55915 .87922 .55126 Metetra
.59 .722 .936 r
.87922 .55126 .88487 .55915 .89915 .55645 .8936 .54899 Metetra
.614 .748 .941 r
.8936 .54899 .89915 .55645 .91347 .55332 .90798 .54591 Metetra
.646 .764 .935 r
.90798 .54591 .91347 .55332 .92776 .54934 .92232 .54183 Metetra
.646 .762 .934 r
.28566 .7146 .29311 .72064 .30461 .71737 .29719 .7113 Metetra
.655 .765 .93 r
.29719 .7113 .30461 .71737 .31619 .71351 .30878 .70776 Metetra
.711 .786 .91 r
.30878 .70776 .31619 .71351 .32787 .70865 .32052 .70245 Metetra
.726 .775 .892 r
.32052 .70245 .32787 .70865 .33962 .70327 .33234 .69649 Metetra
.737 .762 .873 r
.33234 .69649 .33962 .70327 .35143 .69737 .34422 .68989 Metetra
.744 .746 .854 r
.34422 .68989 .35143 .69737 .3633 .69096 .35616 .68266 Metetra
.747 .729 .835 r
.35616 .68266 .3633 .69096 .37522 .68408 .36815 .67486 Metetra
.748 .711 .818 r
.36815 .67486 .37522 .68408 .38718 .67679 .38019 .66655 Metetra
.746 .693 .801 r
.38019 .66655 .38718 .67679 .39919 .66915 .39226 .6578 Metetra
.742 .676 .786 r
.39226 .6578 .39919 .66915 .41122 .66122 .40436 .6487 Metetra
.736 .658 .773 r
.40436 .6487 .41122 .66122 .42329 .65309 .41648 .63935 Metetra
.73 .642 .761 r
.41648 .63935 .42329 .65309 .43537 .64483 .42862 .62985 Metetra
.722 .626 .75 r
.42862 .62985 .43537 .64483 .44748 .63652 .44078 .62029 Metetra
.714 .611 .741 r
.44078 .62029 .44748 .63652 .45961 .62824 .45294 .61078 Metetra
.705 .597 .732 r
.45294 .61078 .45961 .62824 .47175 .62008 .46511 .60141 Metetra
.697 .584 .725 r
.46511 .60141 .47175 .62008 .48392 .6121 .47729 .59229 Metetra
.688 .572 .719 r
.47729 .59229 .48392 .6121 .4961 .60439 .48948 .58351 Metetra
.679 .56 .714 r
.48948 .58351 .4961 .60439 .50831 .597 .50169 .57513 Metetra
.67 .55 .71 r
.50169 .57513 .50831 .597 .52055 .59001 .51391 .56725 Metetra
.661 .54 .706 r
.51391 .56725 .52055 .59001 .53281 .58346 .52616 .55993 Metetra
.651 .531 .704 r
.52616 .55993 .53281 .58346 .54512 .5774 .53844 .55323 Metetra
.642 .522 .702 r
.53844 .55323 .54512 .5774 .55746 .57186 .55076 .54719 Metetra
.633 .514 .7 r
.55076 .54719 .55746 .57186 .56986 .56689 .56313 .54185 Metetra
.624 .507 .7 r
.56313 .54185 .56986 .56689 .58231 .56249 .57555 .53723 Metetra
.615 .501 .7 r
.57555 .53723 .58231 .56249 .59482 .55869 .58803 .53336 Metetra
.606 .496 .701 r
.58803 .53336 .59482 .55869 .60741 .55548 .60059 .53023 Metetra
.598 .491 .703 r
.60059 .53023 .60741 .55548 .62008 .55286 .61323 .52784 Metetra
.589 .487 .706 r
.61323 .52784 .62008 .55286 .63282 .55082 .62596 .52617 Metetra
.58 .483 .709 r
.62596 .52617 .63282 .55082 .64566 .54932 .63878 .52519 Metetra
.571 .481 .714 r
.63878 .52519 .64566 .54932 .6586 .54834 .65171 .52485 Metetra
.562 .48 .719 r
.65171 .52485 .6586 .54834 .67164 .54784 .66476 .52512 Metetra
.554 .479 .726 r
.66476 .52512 .67164 .54784 .68479 .54776 .67792 .52592 Metetra
.546 .48 .733 r
.67792 .52592 .68479 .54776 .69804 .54805 .6912 .52718 Metetra
.537 .483 .742 r
.6912 .52718 .69804 .54805 .71141 .54864 .7046 .52883 Metetra
.53 .487 .753 r
.7046 .52883 .71141 .54864 .72488 .54946 .71813 .53078 Metetra
.523 .493 .765 r
.71813 .53078 .72488 .54946 .73847 .55044 .73178 .53292 Metetra
.516 .501 .778 r
.73178 .53292 .73847 .55044 .75217 .55149 .74555 .53517 Metetra
.511 .512 .793 r
.74555 .53517 .75217 .55149 .76596 .55254 .75943 .53742 Metetra
.507 .526 .81 r
.75943 .53742 .76596 .55254 .77986 .5535 .77342 .53956 Metetra
.505 .542 .828 r
.77342 .53956 .77986 .5535 .79385 .55428 .78751 .5415 Metetra
.505 .562 .847 r
.78751 .5415 .79385 .55428 .80792 .55481 .80169 .54312 Metetra
.508 .584 .867 r
.80169 .54312 .80792 .55481 .82207 .55501 .81595 .54433 Metetra
.514 .61 .886 r
.81595 .54433 .82207 .55501 .83628 .5548 .83028 .54504 Metetra
.523 .637 .904 r
.83028 .54504 .83628 .5548 .85055 .55414 .84466 .54519 Metetra
.536 .666 .921 r
.84466 .54519 .85055 .55414 .86486 .55297 .85909 .54472 Metetra
.551 .694 .934 r
.85909 .54472 .86486 .55297 .87922 .55126 .87355 .54357 Metetra
.569 .721 .945 r
.87355 .54357 .87922 .55126 .8936 .54899 .88803 .54176 Metetra
.621 .76 .945 r
.88803 .54176 .8936 .54899 .90798 .54591 .90243 .53837 Metetra
.646 .762 .934 r
.90243 .53837 .90798 .54591 .92232 .54183 .91682 .53426 Metetra
.646 .762 .934 r
.27815 .70851 .28566 .7146 .29719 .7113 .28971 .70519 Metetra
.646 .762 .934 r
.28971 .70519 .29719 .7113 .30878 .70776 .30132 .70185 Metetra
.71 .782 .908 r
.30132 .70185 .30878 .70776 .32052 .70245 .31309 .69652 Metetra
.74 .786 .89 r
.31309 .69652 .32052 .70245 .33234 .69649 .32498 .69 Metetra
.752 .773 .87 r
.32498 .69 .33234 .69649 .34422 .68989 .33693 .68271 Metetra
.76 .757 .85 r
.33693 .68271 .34422 .68989 .35616 .68266 .34895 .67469 Metetra
.764 .74 .831 r
.34895 .67469 .35616 .68266 .36815 .67486 .36102 .66598 Metetra
.765 .723 .813 r
.36102 .66598 .36815 .67486 .38019 .66655 .37313 .65667 Metetra
.763 .705 .797 r
.37313 .65667 .38019 .66655 .39226 .6578 .38528 .64685 Metetra
.759 .687 .783 r
.38528 .64685 .39226 .6578 .40436 .6487 .39745 .63661 Metetra
.753 .67 .77 r
.39745 .63661 .40436 .6487 .41648 .63935 .40964 .62608 Metetra
.746 .654 .758 r
.40964 .62608 .41648 .63935 .42862 .62985 .42184 .61537 Metetra
.739 .639 .748 r
.42184 .61537 .42862 .62985 .44078 .62029 .43404 .6046 Metetra
.73 .624 .74 r
.43404 .6046 .44078 .62029 .45294 .61078 .44624 .59389 Metetra
.721 .61 .732 r
.44624 .59389 .45294 .61078 .46511 .60141 .45845 .58336 Metetra
.711 .596 .726 r
.45845 .58336 .46511 .60141 .47729 .59229 .47065 .57313 Metetra
.701 .583 .72 r
.47065 .57313 .47729 .59229 .48948 .58351 .48285 .56331 Metetra
.691 .571 .715 r
.48285 .56331 .48948 .58351 .50169 .57513 .49507 .55398 Metetra
.681 .56 .712 r
.49507 .55398 .50169 .57513 .51391 .56725 .50729 .54525 Metetra
.671 .55 .709 r
.50729 .54525 .51391 .56725 .52616 .55993 .51953 .53719 Metetra
.66 .54 .706 r
.51953 .53719 .52616 .55993 .53844 .55323 .53179 .52986 Metetra
.65 .53 .705 r
.53179 .52986 .53844 .55323 .55076 .54719 .54408 .52333 Metetra
.639 .521 .704 r
.54408 .52333 .55076 .54719 .56313 .54185 .55642 .51763 Metetra
.628 .513 .704 r
.55642 .51763 .56313 .54185 .57555 .53723 .56882 .51281 Metetra
.617 .506 .704 r
.56882 .51281 .57555 .53723 .58803 .53336 .58127 .50886 Metetra
.606 .499 .706 r
.58127 .50886 .58803 .53336 .60059 .53023 .5938 .50581 Metetra
.595 .493 .708 r
.5938 .50581 .60059 .53023 .61323 .52784 .60641 .50364 Metetra
.584 .487 .711 r
.60641 .50364 .61323 .52784 .62596 .52617 .61912 .50233 Metetra
.572 .483 .715 r
.61912 .50233 .62596 .52617 .63878 .52519 .63194 .50184 Metetra
.561 .479 .719 r
.63194 .50184 .63878 .52519 .65171 .52485 .64486 .50213 Metetra
.549 .476 .725 r
.64486 .50213 .65171 .52485 .66476 .52512 .65791 .50313 Metetra
.538 .474 .732 r
.65791 .50313 .66476 .52512 .67792 .52592 .67108 .50478 Metetra
.526 .474 .74 r
.67108 .50478 .67792 .52592 .6912 .52718 .68439 .50699 Metetra
.515 .475 .75 r
.68439 .50699 .6912 .52718 .7046 .52883 .69782 .50966 Metetra
.505 .477 .76 r
.69782 .50966 .7046 .52883 .71813 .53078 .7114 .51269 Metetra
.494 .482 .773 r
.7114 .51269 .71813 .53078 .73178 .53292 .72511 .51596 Metetra
.485 .489 .787 r
.72511 .51596 .73178 .53292 .74555 .53517 .73895 .51937 Metetra
.477 .499 .802 r
.73895 .51937 .74555 .53517 .75943 .53742 .75291 .52278 Metetra
.471 .512 .819 r
.75291 .52278 .75943 .53742 .77342 .53956 .76699 .52607 Metetra
.467 .529 .837 r
.76699 .52607 .77342 .53956 .78751 .5415 .78118 .52912 Metetra
.466 .549 .857 r
.78118 .52912 .78751 .5415 .80169 .54312 .79547 .5318 Metetra
.469 .572 .876 r
.79547 .5318 .80169 .54312 .81595 .54433 .80984 .53399 Metetra
.476 .599 .896 r
.80984 .53399 .81595 .54433 .83028 .54504 .82427 .53561 Metetra
.487 .629 .914 r
.82427 .53561 .83028 .54504 .84466 .54519 .83877 .53655 Metetra
.503 .66 .931 r
.83877 .53655 .84466 .54519 .85909 .54472 .8533 .53675 Metetra
.523 .691 .944 r
.8533 .53675 .85909 .54472 .87355 .54357 .86787 .53617 Metetra
.546 .721 .955 r
.86787 .53617 .87355 .54357 .88803 .54176 .88245 .5348 Metetra
.64 .779 .948 r
.88245 .5348 .88803 .54176 .90243 .53837 .89683 .53076 Metetra
.646 .762 .934 r
.89683 .53076 .90243 .53837 .91682 .53426 .91127 .52661 Metetra
.646 .762 .934 r
.27058 .70237 .27815 .70851 .28971 .70519 .28217 .69902 Metetra
.646 .762 .934 r
.28217 .69902 .28971 .70519 .30132 .70185 .29381 .69566 Metetra
.691 .772 .913 r
.29381 .69566 .30132 .70185 .31309 .69652 .30558 .69093 Metetra
.753 .799 .889 r
.30558 .69093 .31309 .69652 .32498 .69 .31754 .68385 Metetra
.767 .784 .868 r
.31754 .68385 .32498 .69 .33693 .68271 .32957 .67589 Metetra
.775 .769 .847 r
.32957 .67589 .33693 .68271 .34895 .67469 .34167 .6671 Metetra
.78 .752 .828 r
.34167 .6671 .34895 .67469 .36102 .66598 .35382 .65752 Metetra
.781 .734 .81 r
.35382 .65752 .36102 .66598 .37313 .65667 .36601 .64724 Metetra
.779 .717 .794 r
.36601 .64724 .37313 .65667 .38528 .64685 .37824 .63638 Metetra
.775 .7 .78 r
.37824 .63638 .38528 .64685 .39745 .63661 .39048 .62504 Metetra
.77 .683 .768 r
.39048 .62504 .39745 .63661 .40964 .62608 .40274 .61336 Metetra
.763 .667 .757 r
.40274 .61336 .40964 .62608 .42184 .61537 .415 .60148 Metetra
.755 .652 .747 r
.415 .60148 .42184 .61537 .43404 .6046 .42726 .58954 Metetra
.746 .637 .739 r
.42726 .58954 .43404 .6046 .44624 .59389 .43951 .57768 Metetra
.736 .623 .732 r
.43951 .57768 .44624 .59389 .45845 .58336 .45175 .56604 Metetra
.726 .609 .726 r
.45175 .56604 .45845 .58336 .47065 .57313 .46399 .55474 Metetra
.715 .596 .722 r
.46399 .55474 .47065 .57313 .48285 .56331 .47621 .54391 Metetra
.704 .584 .717 r
.47621 .54391 .48285 .56331 .49507 .55398 .48843 .53367 Metetra
.693 .572 .714 r
.48843 .53367 .49507 .55398 .50729 .54525 .50066 .52411 Metetra
.681 .56 .712 r
.50066 .52411 .50729 .54525 .51953 .53719 .51289 .51534 Metetra
.669 .55 .71 r
.51289 .51534 .51953 .53719 .53179 .52986 .52514 .50741 Metetra
.657 .539 .709 r
.52514 .50741 .53179 .52986 .54408 .52333 .53742 .50041 Metetra
.645 .53 .708 r
.53742 .50041 .54408 .52333 .55642 .51763 .54974 .49437 Metetra
.632 .52 .709 r
.54974 .49437 .55642 .51763 .56882 .51281 .56211 .48934 Metetra
.619 .512 .71 r
.56211 .48934 .56882 .51281 .58127 .50886 .57454 .48533 Metetra
.606 .503 .712 r
.57454 .48533 .58127 .50886 .5938 .50581 .58704 .48235 Metetra
.592 .496 .714 r
.58704 .48235 .5938 .50581 .60641 .50364 .59963 .48039 Metetra
.578 .489 .717 r
.59963 .48039 .60641 .50364 .61912 .50233 .61232 .47943 Metetra
.564 .483 .722 r
.61232 .47943 .61912 .50233 .63194 .50184 .62512 .47941 Metetra
.55 .477 .727 r
.62512 .47941 .63194 .50184 .64486 .50213 .63804 .48029 Metetra
.535 .473 .733 r
.63804 .48029 .64486 .50213 .65791 .50313 .65109 .48201 Metetra
.52 .469 .74 r
.65109 .48201 .65791 .50313 .67108 .50478 .66428 .48447 Metetra
.505 .467 .748 r
.66428 .48447 .67108 .50478 .68439 .50699 .6776 .48758 Metetra
.49 .466 .758 r
.6776 .48758 .68439 .50699 .69782 .50966 .69108 .49123 Metetra
.476 .467 .769 r
.69108 .49123 .69782 .50966 .7114 .51269 .70469 .4953 Metetra
.462 .471 .781 r
.70469 .4953 .7114 .51269 .72511 .51596 .71846 .49967 Metetra
.449 .476 .795 r
.71846 .49967 .72511 .51596 .73895 .51937 .73236 .50419 Metetra
.438 .485 .811 r
.73236 .50419 .73895 .51937 .75291 .52278 .7464 .50872 Metetra
.429 .497 .828 r
.7464 .50872 .75291 .52278 .76699 .52607 .76057 .51311 Metetra
.423 .513 .847 r
.76057 .51311 .76699 .52607 .78118 .52912 .77485 .51723 Metetra
.42 .534 .866 r
.77485 .51723 .78118 .52912 .79547 .5318 .78924 .52093 Metetra
.423 .558 .886 r
.78924 .52093 .79547 .5318 .80984 .53399 .80372 .52408 Metetra
.432 .587 .906 r
.80372 .52408 .80984 .53399 .82427 .53561 .81826 .52657 Metetra
.446 .619 .924 r
.81826 .52657 .82427 .53561 .83877 .53655 .83286 .52828 Metetra
.466 .653 .941 r
.83286 .52828 .83877 .53655 .8533 .53675 .84751 .52914 Metetra
.491 .688 .955 r
.84751 .52914 .8533 .53675 .86787 .53617 .86217 .52911 Metetra
.558 .74 .961 r
.86217 .52911 .86787 .53617 .88245 .5348 .87675 .52725 Metetra
.645 .765 .936 r
.87675 .52725 .88245 .5348 .89683 .53076 .89118 .52308 Metetra
.646 .762 .934 r
.89118 .52308 .89683 .53076 .91127 .52661 .90567 .5189 Metetra
.646 .762 .934 r
.26295 .69617 .27058 .70237 .28217 .69902 .27457 .6928 Metetra
.646 .762 .934 r
.27457 .6928 .28217 .69902 .29381 .69566 .28624 .68941 Metetra
.656 .765 .93 r
.28624 .68941 .29381 .69566 .30558 .69093 .29798 .68573 Metetra
.767 .812 .889 r
.29798 .68573 .30558 .69093 .31754 .68385 .31001 .6781 Metetra
.781 .797 .866 r
.31001 .6781 .31754 .68385 .32957 .67589 .32212 .6695 Metetra
.79 .781 .844 r
.32212 .6695 .32957 .67589 .34167 .6671 .3343 .65995 Metetra
.795 .764 .825 r
.3343 .65995 .34167 .6671 .35382 .65752 .34654 .64953 Metetra
.796 .747 .807 r
.34654 .64953 .35382 .65752 .36601 .64724 .35882 .63832 Metetra
.795 .73 .791 r
.35882 .63832 .36601 .64724 .37824 .63638 .37113 .62645 Metetra
.791 .713 .778 r
.37113 .62645 .37824 .63638 .39048 .62504 .38345 .61406 Metetra
.786 .696 .766 r
.38345 .61406 .39048 .62504 .40274 .61336 .39579 .60128 Metetra
.779 .681 .756 r
.39579 .60128 .40274 .61336 .415 .60148 .40812 .58828 Metetra
.77 .665 .747 r
.40812 .58828 .415 .60148 .42726 .58954 .42044 .57522 Metetra
.761 .651 .739 r
.42044 .57522 .42726 .58954 .43951 .57768 .43274 .56225 Metetra
.751 .637 .733 r
.43274 .56225 .43951 .57768 .45175 .56604 .44503 .54953 Metetra
.741 .623 .728 r
.44503 .54953 .45175 .56604 .46399 .55474 .4573 .5372 Metetra
.73 .61 .724 r
.4573 .5372 .46399 .55474 .47621 .54391 .46955 .52542 Metetra
.718 .597 .72 r
.46955 .52542 .47621 .54391 .48843 .53367 .48179 .5143 Metetra
.705 .585 .717 r
.48179 .5143 .48843 .53367 .50066 .52411 .49402 .50395 Metetra
.693 .573 .716 r
.49402 .50395 .50066 .52411 .51289 .51534 .50626 .49449 Metetra
.679 .561 .714 r
.50626 .49449 .51289 .51534 .52514 .50741 .5185 .486 Metetra
.666 .55 .714 r
.5185 .486 .52514 .50741 .53742 .50041 .53077 .47854 Metetra
.651 .539 .714 r
.53077 .47854 .53742 .50041 .54974 .49437 .54307 .47218 Metetra
.637 .529 .715 r
.54307 .47218 .54974 .49437 .56211 .48934 .55542 .46696 Metetra
.621 .519 .716 r
.55542 .46696 .56211 .48934 .57454 .48533 .56783 .46288 Metetra
.606 .509 .719 r
.56783 .46288 .57454 .48533 .58704 .48235 .58031 .45997 Metetra
.589 .5 .722 r
.58031 .45997 .58704 .48235 .59963 .48039 .59289 .45821 Metetra
.573 .492 .725 r
.59289 .45821 .59963 .48039 .61232 .47943 .60556 .45757 Metetra
.555 .484 .73 r
.60556 .45757 .61232 .47943 .62512 .47941 .61835 .458 Metetra
.537 .476 .735 r
.61835 .458 .62512 .47941 .63804 .48029 .63126 .45946 Metetra
.519 .47 .742 r
.63126 .45946 .63804 .48029 .65109 .48201 .64431 .46185 Metetra
.5 .464 .749 r
.64431 .46185 .65109 .48201 .66428 .48447 .65751 .46508 Metetra
.481 .46 .758 r
.65751 .46508 .66428 .48447 .6776 .48758 .67085 .46906 Metetra
.461 .457 .767 r
.67085 .46906 .6776 .48758 .69108 .49123 .68436 .47365 Metetra
.442 .456 .779 r
.68436 .47365 .69108 .49123 .70469 .4953 .69802 .47872 Metetra
.424 .458 .791 r
.69802 .47872 .70469 .4953 .71846 .49967 .71183 .48412 Metetra
.407 .462 .805 r
.71183 .48412 .71846 .49967 .73236 .50419 .7258 .48971 Metetra
.391 .469 .82 r
.7258 .48971 .73236 .50419 .7464 .50872 .73991 .49532 Metetra
.379 .48 .837 r
.73991 .49532 .7464 .50872 .76057 .51311 .75416 .50077 Metetra
.371 .496 .855 r
.75416 .50077 .76057 .51311 .77485 .51723 .76854 .50592 Metetra
.367 .516 .874 r
.76854 .50592 .77485 .51723 .78924 .52093 .78302 .51061 Metetra
.37 .542 .894 r
.78302 .51061 .78924 .52093 .80372 .52408 .7976 .51467 Metetra
.38 .573 .914 r
.7976 .51467 .80372 .52408 .81826 .52657 .81225 .51799 Metetra
.398 .607 .933 r
.81225 .51799 .81826 .52657 .83286 .52828 .82695 .52044 Metetra
.422 .645 .95 r
.82695 .52044 .83286 .52828 .84751 .52914 .8417 .52194 Metetra
.453 .683 .964 r
.8417 .52194 .84751 .52914 .86217 .52911 .85647 .52245 Metetra
.592 .771 .965 r
.85647 .52245 .86217 .52911 .87675 .52725 .871 .51954 Metetra
.646 .762 .934 r
.871 .51954 .87675 .52725 .89118 .52308 .88548 .51534 Metetra
.646 .762 .934 r
.88548 .51534 .89118 .52308 .90567 .5189 .90002 .51111 Metetra
.646 .762 .934 r
.25526 .68993 .26295 .69617 .27457 .6928 .2669 .68653 Metetra
.646 .762 .934 r
.2669 .68653 .27457 .6928 .28624 .68941 .2786 .68311 Metetra
.646 .762 .934 r
.2786 .68311 .28624 .68941 .29798 .68573 .29036 .67968 Metetra
.745 .788 .887 r
.29036 .67968 .29798 .68573 .31001 .6781 .30238 .6728 Metetra
.794 .81 .865 r
.30238 .6728 .31001 .6781 .32212 .6695 .31457 .66357 Metetra
.804 .794 .843 r
.31457 .66357 .32212 .6695 .3343 .65995 .32684 .65331 Metetra
.809 .777 .823 r
.32684 .65331 .3343 .65995 .34654 .64953 .33917 .64207 Metetra
.811 .76 .805 r
.33917 .64207 .34654 .64953 .35882 .63832 .35154 .62998 Metetra
.81 .743 .789 r
.35154 .62998 .35882 .63832 .37113 .62645 .36394 .61715 Metetra
.806 .726 .776 r
.36394 .61715 .37113 .62645 .38345 .61406 .37635 .60374 Metetra
.801 .71 .765 r
.37635 .60374 .38345 .61406 .39579 .60128 .38877 .58991 Metetra
.794 .695 .755 r
.38877 .58991 .39579 .60128 .40812 .58828 .40117 .57584 Metetra
.786 .68 .747 r
.40117 .57584 .40812 .58828 .42044 .57522 .41356 .5617 Metetra
.777 .665 .74 r
.41356 .5617 .42044 .57522 .43274 .56225 .42593 .54767 Metetra
.767 .651 .734 r
.42593 .54767 .43274 .56225 .44503 .54953 .43827 .53393 Metetra
.756 .638 .73 r
.43827 .53393 .44503 .54953 .4573 .5372 .45058 .52063 Metetra
.744 .624 .726 r
.45058 .52063 .4573 .5372 .46955 .52542 .46286 .50792 Metetra
.732 .611 .723 r
.46286 .50792 .46955 .52542 .48179 .5143 .47512 .49596 Metetra
.719 .599 .721 r
.47512 .49596 .48179 .5143 .49402 .50395 .48737 .48487 Metetra
.705 .586 .72 r
.48737 .48487 .49402 .50395 .50626 .49449 .49961 .47476 Metetra
.69 .574 .72 r
.49961 .47476 .50626 .49449 .5185 .486 .51186 .46572 Metetra
.675 .562 .72 r
.51186 .46572 .5185 .486 .53077 .47854 .52412 .45783 Metetra
.659 .55 .721 r
.52412 .45783 .53077 .47854 .54307 .47218 .53641 .45116 Metetra
.642 .539 .722 r
.53641 .45116 .54307 .47218 .55542 .46696 .54875 .44574 Metetra
.624 .528 .724 r
.54875 .44574 .55542 .46696 .56783 .46288 .56114 .44161 Metetra
.606 .517 .727 r
.56114 .44161 .56783 .46288 .58031 .45997 .57361 .43876 Metetra
.587 .506 .731 r
.57361 .43876 .58031 .45997 .59289 .45821 .58616 .43719 Metetra
.566 .496 .735 r
.58616 .43719 .59289 .45821 .60556 .45757 .59882 .43686 Metetra
.545 .486 .74 r
.59882 .43686 .60556 .45757 .61835 .458 .6116 .43772 Metetra
.523 .476 .746 r
.6116 .43772 .61835 .458 .63126 .45946 .62451 .43971 Metetra
.5 .468 .752 r
.62451 .43971 .63126 .45946 .64431 .46185 .63757 .44275 Metetra
.477 .46 .76 r
.63757 .44275 .64431 .46185 .65751 .46508 .65077 .44672 Metetra
.452 .453 .769 r
.65077 .44672 .65751 .46508 .67085 .46906 .66414 .45152 Metetra
.428 .447 .778 r
.66414 .45152 .67085 .46906 .68436 .47365 .67767 .457 Metetra
.403 .444 .789 r
.67767 .457 .68436 .47365 .69802 .47872 .69136 .46302 Metetra
.379 .443 .801 r
.69136 .46302 .69802 .47872 .71183 .48412 .70523 .46942 Metetra
.357 .444 .814 r
.70523 .46942 .71183 .48412 .7258 .48971 .71926 .47603 Metetra
.337 .45 .828 r
.71926 .47603 .7258 .48971 .73991 .49532 .73344 .48265 Metetra
.32 .46 .844 r
.73344 .48265 .73991 .49532 .75416 .50077 .74777 .48913 Metetra
.309 .475 .861 r
.74777 .48913 .75416 .50077 .76854 .50592 .76223 .49526 Metetra
.305 .495 .88 r
.76223 .49526 .76854 .50592 .78302 .51061 .7768 .50088 Metetra
.308 .522 .899 r
.7768 .50088 .78302 .51061 .7976 .51467 .79148 .50582 Metetra
.32 .555 .919 r
.79148 .50582 .7976 .51467 .81225 .51799 .80623 .50993 Metetra
.342 .593 .938 r
.80623 .50993 .81225 .51799 .82695 .52044 .82104 .51309 Metetra
.372 .634 .956 r
.82104 .51309 .82695 .52044 .8417 .52194 .83589 .5152 Metetra
.421 .684 .972 r
.83589 .5152 .8417 .52194 .85647 .52245 .85074 .51599 Metetra
.638 .8 .96 r
.85074 .51599 .85647 .52245 .871 .51954 .86519 .51176 Metetra
.646 .762 .934 r
.86519 .51176 .871 .51954 .88548 .51534 .87972 .50752 Metetra
.646 .762 .934 r
.87972 .50752 .88548 .51534 .90002 .51111 .89432 .50326 Metetra
.646 .762 .934 r
.2475 .68364 .25526 .68993 .2669 .68653 .25918 .68021 Metetra
.646 .762 .934 r
.25918 .68021 .2669 .68653 .2786 .68311 .27091 .67676 Metetra
.646 .762 .934 r
.27091 .67676 .2786 .68311 .29036 .67968 .28269 .6733 Metetra
.705 .775 .906 r
.28269 .6733 .29036 .67968 .30238 .6728 .29465 .66799 Metetra
.807 .824 .864 r
.29465 .66799 .30238 .6728 .31457 .66357 .30693 .65816 Metetra
.817 .807 .841 r
.30693 .65816 .31457 .66357 .32684 .65331 .31929 .64721 Metetra
.823 .79 .821 r
.31929 .64721 .32684 .65331 .33917 .64207 .33171 .63521 Metetra
.825 .773 .803 r
.33171 .63521 .33917 .64207 .35154 .62998 .34417 .62227 Metetra
.824 .756 .788 r
.34417 .62227 .35154 .62998 .36394 .61715 .35666 .60853 Metetra
.821 .74 .775 r
.35666 .60853 .36394 .61715 .37635 .60374 .36917 .59415 Metetra
.816 .724 .764 r
.36917 .59415 .37635 .60374 .38877 .58991 .38167 .57933 Metetra
.81 .709 .755 r
.38167 .57933 .38877 .58991 .40117 .57584 .39416 .56423 Metetra
.802 .695 .747 r
.39416 .56423 .40117 .57584 .41356 .5617 .40662 .54907 Metetra
.793 .681 .741 r
.40662 .54907 .41356 .5617 .42593 .54767 .41905 .53404 Metetra
.782 .667 .736 r
.41905 .53404 .42593 .54767 .43827 .53393 .43145 .51932 Metetra
.771 .653 .732 r
.43145 .51932 .43827 .53393 .45058 .52063 .44381 .50508 Metetra
.759 .64 .729 r
.44381 .50508 .45058 .52063 .46286 .50792 .45613 .49151 Metetra
.746 .627 .727 r
.45613 .49151 .46286 .50792 .47512 .49596 .46843 .47875 Metetra
.732 .614 .726 r
.46843 .47875 .47512 .49596 .48737 .48487 .4807 .46695 Metetra
.717 .601 .726 r
.4807 .46695 .48737 .48487 .49961 .47476 .49295 .45621 Metetra
.702 .589 .726 r
.49295 .45621 .49961 .47476 .51186 .46572 .50521 .44666 Metetra
.685 .576 .727 r
.50521 .44666 .51186 .46572 .52412 .45783 .51747 .43836 Metetra
.667 .563 .729 r
.51747 .43836 .52412 .45783 .53641 .45116 .52975 .4314 Metetra
.648 .551 .731 r
.52975 .4314 .53641 .45116 .54875 .44574 .54208 .4258 Metetra
.628 .538 .734 r
.54208 .4258 .54875 .44574 .56114 .44161 .55446 .4216 Metetra
.606 .526 .738 r
.55446 .4216 .56114 .44161 .57361 .43876 .56692 .41881 Metetra
.584 .513 .742 r
.56692 .41881 .57361 .43876 .58616 .43719 .57946 .41742 Metetra
.56 .501 .747 r
.57946 .41742 .58616 .43719 .59882 .43686 .59211 .41738 Metetra
.534 .489 .752 r
.59211 .41738 .59882 .43686 .6116 .43772 .60488 .41865 Metetra
.507 .477 .758 r
.60488 .41865 .6116 .43772 .62451 .43971 .61779 .42115 Metetra
.479 .466 .765 r
.61779 .42115 .62451 .43971 .63757 .44275 .63085 .42479 Metetra
.449 .455 .773 r
.63085 .42479 .63757 .44275 .65077 .44672 .64406 .42947 Metetra
.418 .445 .781 r
.64406 .42947 .65077 .44672 .66414 .45152 .65745 .43504 Metetra
.387 .436 .79 r
.65745 .43504 .66414 .45152 .67767 .457 .671 .44137 Metetra
.356 .429 .799 r
.671 .44137 .67767 .457 .69136 .46302 .68474 .4483 Metetra
.325 .425 .81 r
.68474 .4483 .69136 .46302 .70523 .46942 .69865 .45564 Metetra
.297 .424 .821 r
.69865 .45564 .70523 .46942 .71926 .47603 .71273 .4632 Metetra
.271 .427 .834 r
.71273 .4632 .71926 .47603 .73344 .48265 .72698 .4708 Metetra
.251 .434 .848 r
.72698 .4708 .73344 .48265 .74777 .48913 .74138 .47823 Metetra
.237 .448 .863 r
.74138 .47823 .74777 .48913 .76223 .49526 .75593 .4853 Metetra
.231 .469 .881 r
.75593 .4853 .76223 .49526 .7768 .50088 .77059 .49181 Metetra
.235 .497 .899 r
.77059 .49181 .7768 .50088 .79148 .50582 .78536 .49757 Metetra
.251 .532 .919 r
.78536 .49757 .79148 .50582 .80623 .50993 .80021 .50244 Metetra
.277 .574 .939 r
.80021 .50244 .80623 .50993 .82104 .51309 .81513 .50627 Metetra
.313 .62 .957 r
.81513 .50627 .82104 .51309 .83589 .5152 .83008 .50897 Metetra
.484 .738 .983 r
.83008 .50897 .83589 .5152 .85074 .51599 .84483 .50817 Metetra
.646 .762 .934 r
.84483 .50817 .85074 .51599 .86519 .51176 .85933 .50391 Metetra
.646 .762 .934 r
.85933 .50391 .86519 .51176 .87972 .50752 .87391 .49963 Metetra
.646 .762 .934 r
.87391 .49963 .87972 .50752 .89432 .50326 .88857 .49533 Metetra
.646 .762 .934 r
.23968 .67729 .2475 .68364 .25918 .68021 .25139 .67383 Metetra
.646 .762 .934 r
.25139 .67383 .25918 .68021 .27091 .67676 .26315 .67036 Metetra
.646 .762 .934 r
.26315 .67036 .27091 .67676 .28269 .6733 .27496 .66687 Metetra
.646 .762 .934 r
.27496 .66687 .28269 .6733 .29465 .66799 .28683 .66336 Metetra
.812 .83 .864 r
.28683 .66336 .29465 .66799 .30693 .65816 .29918 .65331 Metetra
.83 .821 .84 r
.29918 .65331 .30693 .65816 .31929 .64721 .31163 .64171 Metetra
.836 .804 .819 r
.31163 .64171 .31929 .64721 .33171 .63521 .32415 .62898 Metetra
.839 .787 .802 r
.32415 .62898 .33171 .63521 .34417 .62227 .33671 .61524 Metetra
.838 .77 .786 r
.33671 .61524 .34417 .62227 .35666 .60853 .3493 .60063 Metetra
.836 .754 .774 r
.3493 .60063 .35666 .60853 .36917 .59415 .3619 .58535 Metetra
.831 .739 .763 r
.3619 .58535 .36917 .59415 .38167 .57933 .37449 .56958 Metetra
.825 .725 .754 r
.37449 .56958 .38167 .57933 .39416 .56423 .38707 .55352 Metetra
.817 .71 .747 r
.38707 .55352 .39416 .56423 .40662 .54907 .39961 .53739 Metetra
.808 .697 .742 r
.39961 .53739 .40662 .54907 .41905 .53404 .41211 .52141 Metetra
.798 .683 .738 r
.41211 .52141 .41905 .53404 .43145 .51932 .42458 .50576 Metetra
.787 .67 .735 r
.42458 .50576 .43145 .51932 .44381 .50508 .43699 .49065 Metetra
.774 .657 .733 r
.43699 .49065 .44381 .50508 .45613 .49151 .44936 .47625 Metetra
.761 .644 .732 r
.44936 .47625 .45613 .49151 .46843 .47875 .4617 .46274 Metetra
.747 .631 .732 r
.4617 .46274 .46843 .47875 .4807 .46695 .47399 .45026 Metetra
.731 .618 .732 r
.47399 .45026 .4807 .46695 .49295 .45621 .48627 .43894 Metetra
.714 .605 .733 r
.48627 .43894 .49295 .45621 .50521 .44666 .49854 .42889 Metetra
.696 .592 .735 r
.49854 .42889 .50521 .44666 .51747 .43836 .51081 .42021 Metetra
.676 .578 .738 r
.51081 .42021 .51747 .43836 .52975 .4314 .52309 .41296 Metetra
.655 .565 .742 r
.52309 .41296 .52975 .4314 .54208 .4258 .53542 .4072 Metetra
.632 .551 .745 r
.53542 .4072 .54208 .4258 .55446 .4216 .54779 .40294 Metetra
.607 .537 .75 r
.54779 .40294 .55446 .4216 .56692 .41881 .56024 .40021 Metetra
.58 .523 .755 r
.56024 .40021 .56692 .41881 .57946 .41742 .57277 .39898 Metetra
.552 .508 .761 r
.57277 .39898 .57946 .41742 .59211 .41738 .58542 .39921 Metetra
.521 .493 .767 r
.58542 .39921 .59211 .41738 .60488 .41865 .59818 .40086 Metetra
.488 .479 .773 r
.59818 .40086 .60488 .41865 .61779 .42115 .61109 .40384 Metetra
.453 .464 .78 r
.61109 .40384 .61779 .42115 .63085 .42479 .62415 .40806 Metetra
.416 .449 .787 r
.62415 .40806 .63085 .42479 .64406 .42947 .63738 .41339 Metetra
.378 .435 .794 r
.63738 .41339 .64406 .42947 .65745 .43504 .65078 .4197 Metetra
.338 .422 .801 r
.65078 .4197 .65745 .43504 .671 .44137 .66437 .42683 Metetra
.299 .411 .809 r
.66437 .42683 .671 .44137 .68474 .4483 .67813 .4346 Metetra
.26 .403 .817 r
.67813 .4346 .68474 .4483 .69865 .45564 .69209 .44283 Metetra
.225 .398 .825 r
.69209 .44283 .69865 .45564 .71273 .4632 .70623 .4513 Metetra
.193 .397 .835 r
.70623 .4513 .71273 .4632 .72698 .4708 .72054 .45982 Metetra
.168 .403 .845 r
.72054 .45982 .72698 .4708 .74138 .47823 .73501 .46816 Metetra
.152 .415 .858 r
.73501 .46816 .74138 .47823 .75593 .4853 .74964 .4761 Metetra
.145 .436 .873 r
.74964 .4761 .75593 .4853 .77059 .49181 .76439 .48344 Metetra
.151 .465 .89 r
.76439 .48344 .77059 .49181 .78536 .49757 .77925 .48999 Metetra
.17 .503 .91 r
.77925 .48999 .78536 .49757 .80021 .50244 .7942 .49556 Metetra
.202 .549 .931 r
.7942 .49556 .80021 .50244 .81513 .50627 .80921 .50003 Metetra
.246 .6 .951 r
.80921 .50003 .81513 .50627 .83008 .50897 .82426 .50328 Metetra
.574 .802 .986 r
.82426 .50328 .83008 .50897 .84483 .50817 .83886 .50029 Metetra
.646 .762 .934 r
.83886 .50029 .84483 .50817 .85933 .50391 .85342 .49599 Metetra
.646 .762 .934 r
.85342 .49599 .85933 .50391 .87391 .49963 .86805 .49167 Metetra
.646 .762 .934 r
.86805 .49167 .87391 .49963 .88857 .49533 .88276 .48732 Metetra
.646 .762 .934 r
.23179 .6709 .23968 .67729 .25139 .67383 .24353 .66741 Metetra
.646 .762 .934 r
.24353 .66741 .25139 .67383 .26315 .67036 .25532 .6639 Metetra
.646 .762 .934 r
.25532 .6639 .26315 .67036 .27496 .66687 .26717 .66038 Metetra
.646 .762 .934 r
.26717 .66038 .27496 .66687 .28683 .66336 .27907 .65685 Metetra
.76 .782 .871 r
.27907 .65685 .28683 .66336 .29918 .65331 .29131 .64904 Metetra
.842 .835 .839 r
.29131 .64904 .29918 .65331 .31163 .64171 .30386 .63683 Metetra
.849 .817 .818 r
.30386 .63683 .31163 .64171 .32415 .62898 .31648 .62341 Metetra
.852 .801 .8 r
.31648 .62341 .32415 .62898 .33671 .61524 .32914 .60892 Metetra
.852 .784 .785 r
.32914 .60892 .33671 .61524 .3493 .60063 .34183 .59351 Metetra
.849 .769 .773 r
.34183 .59351 .3493 .60063 .3619 .58535 .35453 .57737 Metetra
.845 .754 .763 r
.35453 .57737 .3619 .58535 .37449 .56958 .36722 .56071 Metetra
.839 .74 .754 r
.36722 .56071 .37449 .56958 .38707 .55352 .37989 .54375 Metetra
.832 .726 .748 r
.37989 .54375 .38707 .55352 .39961 .53739 .39252 .52671 Metetra
.823 .713 .743 r
.39252 .52671 .39961 .53739 .41211 .52141 .4051 .50983 Metetra
.814 .7 .74 r
.4051 .50983 .41211 .52141 .42458 .50576 .41763 .49331 Metetra
.803 .688 .738 r
.41763 .49331 .42458 .50576 .43699 .49065 .43011 .47737 Metetra
.79 .675 .737 r
.43011 .47737 .43699 .49065 .44936 .47625 .44254 .4622 Metetra
.777 .662 .737 r
.44254 .4622 .44936 .47625 .4617 .46274 .45491 .44798 Metetra
.762 .649 .738 r
.45491 .44798 .4617 .46274 .47399 .45026 .46725 .43486 Metetra
.745 .636 .739 r
.46725 .43486 .47399 .45026 .48627 .43894 .47955 .42299 Metetra
.727 .623 .742 r
.47955 .42299 .48627 .43894 .49854 .42889 .49184 .41249 Metetra
.708 .61 .745 r
.49184 .41249 .49854 .42889 .51081 .42021 .50412 .40344 Metetra
.686 .596 .749 r
.50412 .40344 .51081 .42021 .52309 .41296 .51642 .39593 Metetra
.662 .581 .754 r
.51642 .39593 .52309 .41296 .53542 .4072 .52874 .39 Metetra
.636 .566 .759 r
.52874 .39 .53542 .4072 .54779 .40294 .54112 .38569 Metetra
.608 .551 .765 r
.54112 .38569 .54779 .40294 .56024 .40021 .55356 .383 Metetra
.577 .534 .771 r
.55356 .383 .56024 .40021 .57277 .39898 .5661 .38192 Metetra
.543 .517 .777 r
.5661 .38192 .57277 .39898 .58542 .39921 .57874 .38242 Metetra
.505 .499 .784 r
.57874 .38242 .58542 .39921 .59818 .40086 .5915 .38442 Metetra
.465 .481 .79 r
.5915 .38442 .59818 .40086 .61109 .40384 .60441 .38785 Metetra
.422 .462 .796 r
.60441 .38785 .61109 .40384 .62415 .40806 .61748 .39261 Metetra
.376 .442 .802 r
.61748 .39261 .62415 .40806 .63738 .41339 .63072 .39856 Metetra
.328 .423 .807 r
.63072 .39856 .63738 .41339 .65078 .4197 .64414 .40555 Metetra
.278 .405 .812 r
.64414 .40555 .65078 .4197 .66437 .42683 .65775 .41343 Metetra
.229 .388 .815 r
.65775 .41343 .66437 .42683 .67813 .4346 .67155 .422 Metetra
.182 .374 .819 r
.67155 .422 .67813 .4346 .69209 .44283 .68555 .43105 Metetra
.138 .365 .822 r
.68555 .43105 .69209 .44283 .70623 .4513 .69974 .44038 Metetra
.101 .36 .826 r
.69974 .44038 .70623 .4513 .72054 .45982 .71411 .44975 Metetra
.072 .363 .832 r
.71411 .44975 .72054 .45982 .73501 .46816 .72866 .45894 Metetra
.053 .374 .841 r
.72866 .45894 .73501 .46816 .74964 .4761 .74335 .4677 Metetra
.048 .395 .853 r
.74335 .4677 .74964 .4761 .76439 .48344 .75819 .47582 Metetra
.057 .426 .869 r
.75819 .47582 .76439 .48344 .77925 .48999 .77314 .48309 Metetra
.081 .467 .889 r
.77314 .48309 .77925 .48999 .7942 .49556 .78818 .48933 Metetra
.119 .517 .912 r
.78818 .48933 .7942 .49556 .80921 .50003 .80329 .49439 Metetra
.272 .641 .965 r
.80329 .49439 .80921 .50003 .82426 .50328 .8183 .49665 Metetra
.639 .799 .96 r
.8183 .49665 .82426 .50328 .83886 .50029 .83284 .49233 Metetra
.646 .762 .934 r
.83284 .49233 .83886 .50029 .85342 .49599 .84745 .48799 Metetra
.646 .762 .934 r
.84745 .48799 .85342 .49599 .86805 .49167 .86214 .48363 Metetra
.646 .762 .934 r
.86214 .48363 .86805 .49167 .88276 .48732 .8769 .47925 Metetra
.646 .762 .934 r
.22384 .66444 .23179 .6709 .24353 .66741 .23561 .66093 Metetra
.646 .762 .934 r
.23561 .66093 .24353 .66741 .25532 .6639 .24743 .65739 Metetra
.646 .762 .934 r
.24743 .65739 .25532 .6639 .26717 .66038 .25931 .65385 Metetra
.646 .762 .934 r
.25931 .65385 .26717 .66038 .27907 .65685 .27125 .65028 Metetra
.69 .772 .914 r
.27125 .65028 .27907 .65685 .29131 .64904 .28333 .64536 Metetra
.853 .849 .838 r
.28333 .64536 .29131 .64904 .30386 .63683 .29597 .63259 Metetra
.86 .832 .817 r
.29597 .63259 .30386 .63683 .31648 .62341 .30869 .61854 Metetra
.864 .815 .799 r
.30869 .61854 .31648 .62341 .32914 .60892 .32146 .60335 Metetra
.864 .799 .784 r
.32146 .60335 .32914 .60892 .34183 .59351 .33425 .58719 Metetra
.863 .784 .772 r
.33425 .58719 .34183 .59351 .35453 .57737 .34706 .57026 Metetra
.859 .77 .762 r
.34706 .57026 .35453 .57737 .36722 .56071 .35985 .55277 Metetra
.854 .756 .755 r
.35985 .55277 .36722 .56071 .37989 .54375 .37261 .53496 Metetra
.847 .743 .749 r
.37261 .53496 .37989 .54375 .39252 .52671 .38534 .51708 Metetra
.839 .731 .745 r
.38534 .51708 .39252 .52671 .4051 .50983 .39801 .49936 Metetra
.829 .718 .742 r
.39801 .49936 .4051 .50983 .41763 .49331 .41062 .48203 Metetra
.819 .706 .741 r
.41062 .48203 .41763 .49331 .43011 .47737 .42316 .46531 Metetra
.806 .694 .741 r
.42316 .46531 .43011 .47737 .44254 .4622 .43565 .44942 Metetra
.793 .682 .742 r
.43565 .44942 .44254 .4622 .45491 .44798 .44808 .43453 Metetra
.778 .67 .744 r
.44808 .43453 .45491 .44798 .46725 .43486 .46046 .42082 Metetra
.761 .657 .747 r
.46046 .42082 .46725 .43486 .47955 .42299 .4728 .40843 Metetra
.742 .644 .751 r
.4728 .40843 .47955 .42299 .49184 .41249 .48511 .39749 Metetra
.721 .63 .756 r
.48511 .39749 .49184 .41249 .50412 .40344 .49741 .3881 Metetra
.697 .616 .762 r
.49741 .3881 .50412 .40344 .51642 .39593 .50972 .38033 Metetra
.671 .601 .768 r
.50972 .38033 .51642 .39593 .52874 .39 .52205 .37426 Metetra
.642 .585 .775 r
.52205 .37426 .52874 .39 .54112 .38569 .53443 .36989 Metetra
.609 .567 .782 r
.53443 .36989 .54112 .38569 .55356 .383 .54688 .36725 Metetra
.572 .549 .79 r
.54688 .36725 .55356 .383 .5661 .38192 .55942 .36631 Metetra
.531 .528 .797 r
.55942 .36631 .5661 .38192 .57874 .38242 .57206 .36704 Metetra
.486 .507 .804 r
.57206 .36704 .57874 .38242 .5915 .38442 .58482 .36938 Metetra
.437 .484 .81 r
.58482 .36938 .5915 .38442 .60441 .38785 .59774 .37323 Metetra
.383 .459 .815 r
.59774 .37323 .60441 .38785 .61748 .39261 .61081 .37848 Metetra
.325 .433 .818 r
.61081 .37848 .61748 .39261 .63072 .39856 .62407 .38501 Metetra
.265 .407 .819 r
.62407 .38501 .63072 .39856 .64414 .40555 .63751 .39264 Metetra
.204 .382 .818 r
.63751 .39264 .64414 .40555 .65775 .41343 .65114 .40122 Metetra
.144 .358 .816 r
.65114 .40122 .65775 .41343 .67155 .422 .66498 .41053 Metetra
.087 .338 .812 r
.66498 .41053 .67155 .422 .68555 .43105 .67902 .42036 Metetra
.036 .322 .807 r
.67902 .42036 .68555 .43105 .69974 .44038 .69326 .43048 Metetra
0 .314 .804 r
.69326 .43048 .69974 .44038 .71411 .44975 .70769 .44064 Metetra
0 .314 .804 r
.70769 .44064 .71411 .44975 .72866 .45894 .7223 .45061 Metetra
0 .324 .808 r
.7223 .45061 .72866 .45894 .74335 .4677 .73708 .46014 Metetra
0 .345 .817 r
.73708 .46014 .74335 .4677 .75819 .47582 .75199 .46898 Metetra
0 .378 .832 r
.75199 .46898 .75819 .47582 .77314 .48309 .76703 .47693 Metetra
0 .423 .854 r
.76703 .47693 .77314 .48309 .78818 .48933 .78216 .48378 Metetra
.03 .477 .879 r
.78216 .48378 .78818 .48933 .80329 .49439 .79736 .48938 Metetra
.428 .757 .995 r
.79736 .48938 .80329 .49439 .8183 .49665 .81217 .48866 Metetra
.646 .762 .934 r
.81217 .48866 .8183 .49665 .83284 .49233 .82676 .4843 Metetra
.646 .762 .934 r
.82676 .4843 .83284 .49233 .84745 .48799 .84143 .47992 Metetra
.646 .762 .934 r
.84143 .47992 .84745 .48799 .86214 .48363 .85617 .47552 Metetra
.646 .762 .934 r
.85617 .47552 .86214 .48363 .8769 .47925 .87098 .47109 Metetra
.646 .762 .934 r
.21582 .65794 .22384 .66444 .23561 .66093 .22762 .65439 Metetra
.646 .762 .934 r
.22762 .65439 .23561 .66093 .24743 .65739 .23948 .65083 Metetra
.646 .762 .934 r
.23948 .65083 .24743 .65739 .25931 .65385 .25139 .64725 Metetra
.646 .762 .934 r
.25139 .64725 .25931 .65385 .27125 .65028 .26335 .64365 Metetra
.646 .762 .934 r
.26335 .64365 .27125 .65028 .28333 .64536 .27537 .64004 Metetra
.818 .815 .846 r
.27537 .64004 .28333 .64536 .29597 .63259 .28796 .62901 Metetra
.871 .846 .816 r
.28796 .62901 .29597 .63259 .30869 .61854 .30078 .61438 Metetra
.875 .829 .798 r
.30078 .61438 .30869 .61854 .32146 .60335 .31365 .59855 Metetra
.876 .813 .783 r
.31365 .59855 .32146 .60335 .33425 .58719 .32656 .5817 Metetra
.875 .799 .771 r
.32656 .5817 .33425 .58719 .34706 .57026 .33947 .56403 Metetra
.872 .785 .762 r
.33947 .56403 .34706 .57026 .35985 .55277 .35237 .54578 Metetra
.867 .772 .755 r
.35237 .54578 .35985 .55277 .37261 .53496 .36524 .52719 Metetra
.861 .76 .75 r
.36524 .52719 .37261 .53496 .38534 .51708 .37805 .50852 Metetra
.854 .748 .746 r
.37805 .50852 .38534 .51708 .39801 .49936 .39081 .49002 Metetra
.845 .737 .744 r
.39081 .49002 .39801 .49936 .41062 .48203 .40351 .47193 Metetra
.835 .726 .744 r
.40351 .47193 .41062 .48203 .42316 .46531 .41613 .4545 Metetra
.823 .714 .745 r
.41613 .4545 .42316 .46531 .43565 .44942 .42869 .43793 Metetra
.809 .703 .748 r
.42869 .43793 .43565 .44942 .44808 .43453 .44117 .42242 Metetra
.794 .692 .751 r
.44117 .42242 .44808 .43453 .46046 .42082 .4536 .40815 Metetra
.777 .68 .756 r
.4536 .40815 .46046 .42082 .4728 .40843 .46598 .39528 Metetra
.757 .667 .762 r
.46598 .39528 .4728 .40843 .48511 .39749 .47833 .38394 Metetra
.735 .654 .769 r
.47833 .38394 .48511 .39749 .49741 .3881 .49066 .37423 Metetra
.71 .639 .776 r
.49066 .37423 .49741 .3881 .50972 .38033 .50299 .36623 Metetra
.681 .624 .785 r
.50299 .36623 .50972 .38033 .52205 .37426 .51534 .36001 Metetra
.648 .606 .794 r
.51534 .36001 .52205 .37426 .53443 .36989 .52773 .35559 Metetra
.61 .587 .803 r
.52773 .35559 .53443 .36989 .54688 .36725 .54019 .35299 Metetra
.567 .566 .812 r
.54019 .35299 .54688 .36725 .55942 .36631 .55273 .35218 Metetra
.518 .542 .821 r
.55273 .35218 .55942 .36631 .57206 .36704 .56537 .35313 Metetra
.462 .516 .828 r
.56537 .35313 .57206 .36704 .58482 .36938 .57815 .35577 Metetra
.401 .487 .832 r
.57815 .35577 .58482 .36938 .59774 .37323 .59107 .36001 Metetra
.334 .455 .834 r
.59107 .36001 .59774 .37323 .61081 .37848 .60416 .36572 Metetra
.262 .421 .832 r
.60416 .36572 .61081 .37848 .62407 .38501 .61742 .37278 Metetra
.187 .386 .827 r
.61742 .37278 .62407 .38501 .63751 .39264 .63089 .38101 Metetra
.113 .351 .817 r
.63089 .38101 .63751 .39264 .65114 .40122 .64455 .39023 Metetra
.041 .319 .804 r
.64455 .39023 .65114 .40122 .66498 .41053 .65842 .40022 Metetra
0 .291 .79 r
.65842 .40022 .66498 .41053 .67902 .42036 .6725 .41077 Metetra
0 .27 .776 r
.6725 .41077 .67902 .42036 .69326 .43048 .68679 .42162 Metetra
0 .258 .764 r
.68679 .42162 .69326 .43048 .70769 .44064 .70128 .43252 Metetra
0 .256 .757 r
.70128 .43252 .70769 .44064 .7223 .45061 .71595 .44321 Metetra
0 .265 .757 r
.71595 .44321 .7223 .45061 .73708 .46014 .7308 .45344 Metetra
0 .287 .764 r
.7308 .45344 .73708 .46014 .75199 .46898 .74579 .46294 Metetra
0 .323 .78 r
.74579 .46294 .75199 .46898 .76703 .47693 .76091 .4715 Metetra
0 .371 .803 r
.76091 .4715 .76703 .47693 .78216 .48378 .77613 .47891 Metetra
0 .433 .834 r
.77613 .47891 .78216 .48378 .79736 .48938 .79142 .48498 Metetra
.603 .863 .992 r
.79142 .48498 .79736 .48938 .81217 .48866 .80599 .4806 Metetra
.646 .762 .934 r
.80599 .4806 .81217 .48866 .82676 .4843 .82063 .4762 Metetra
.646 .762 .934 r
.82063 .4762 .82676 .4843 .84143 .47992 .83535 .47178 Metetra
.646 .762 .934 r
.83535 .47178 .84143 .47992 .85617 .47552 .85014 .46733 Metetra
.646 .762 .934 r
.85014 .46733 .85617 .47552 .87098 .47109 .86501 .46286 Metetra
.646 .762 .934 r
.20773 .65138 .21582 .65794 .22762 .65439 .21957 .6478 Metetra
.646 .762 .934 r
.21957 .6478 .22762 .65439 .23948 .65083 .23145 .64421 Metetra
.646 .762 .934 r
.23145 .64421 .23948 .65083 .25139 .64725 .2434 .6406 Metetra
.646 .762 .934 r
.2434 .6406 .25139 .64725 .26335 .64365 .25539 .63697 Metetra
.646 .762 .934 r
.25539 .63697 .26335 .64365 .27537 .64004 .26745 .63333 Metetra
.746 .781 .882 r
.26745 .63333 .27537 .64004 .28796 .62901 .27981 .62609 Metetra
.881 .859 .815 r
.27981 .62609 .28796 .62901 .30078 .61438 .29274 .61094 Metetra
.886 .843 .797 r
.29274 .61094 .30078 .61438 .31365 .59855 .30572 .59453 Metetra
.887 .828 .783 r
.30572 .59453 .31365 .59855 .32656 .5817 .31874 .57704 Metetra
.887 .814 .771 r
.31874 .57704 .32656 .5817 .33947 .56403 .33176 .5587 Metetra
.884 .801 .762 r
.33176 .5587 .33947 .56403 .35237 .54578 .34477 .53975 Metetra
.881 .789 .755 r
.34477 .53975 .35237 .54578 .36524 .52719 .35774 .52045 Metetra
.875 .777 .75 r
.35774 .52045 .36524 .52719 .37805 .50852 .37066 .50105 Metetra
.868 .767 .748 r
.37066 .50105 .37805 .50852 .39081 .49002 .38352 .48184 Metetra
.86 .756 .747 r
.38352 .48184 .39081 .49002 .40351 .47193 .3963 .46306 Metetra
.851 .746 .747 r
.3963 .46306 .40351 .47193 .41613 .4545 .40901 .44495 Metetra
.839 .736 .75 r
.40901 .44495 .41613 .4545 .42869 .43793 .42164 .42776 Metetra
.826 .726 .754 r
.42164 .42776 .42869 .43793 .44117 .42242 .43419 .41168 Metetra
.811 .715 .759 r
.43419 .41168 .44117 .42242 .4536 .40815 .44668 .3969 Metetra
.794 .704 .765 r
.44668 .3969 .4536 .40815 .46598 .39528 .45911 .38358 Metetra
.774 .693 .773 r
.45911 .38358 .46598 .39528 .47833 .38394 .47149 .37186 Metetra
.751 .68 .783 r
.47149 .37186 .47833 .38394 .49066 .37423 .48386 .36185 Metetra
.723 .666 .793 r
.48386 .36185 .49066 .37423 .50299 .36623 .49622 .35364 Metetra
.691 .65 .804 r
.49622 .35364 .50299 .36623 .51534 .36001 .50859 .34728 Metetra
.654 .632 .816 r
.50859 .34728 .51534 .36001 .52773 .35559 .521 .34281 Metetra
.61 .611 .828 r
.521 .34281 .52773 .35559 .54019 .35299 .53347 .34025 Metetra
.559 .587 .839 r
.53347 .34025 .54019 .35299 .55273 .35218 .54602 .33956 Metetra
.499 .559 .848 r
.54602 .33956 .55273 .35218 .56537 .35313 .55868 .34071 Metetra
.431 .526 .854 r
.55868 .34071 .56537 .35313 .57815 .35577 .57146 .34363 Metetra
.354 .489 .856 r
.57146 .34363 .57815 .35577 .59107 .36001 .58439 .34822 Metetra
.27 .447 .852 r
.58439 .34822 .59107 .36001 .60416 .36572 .5975 .35436 Metetra
.181 .402 .841 r
.5975 .35436 .60416 .36572 .61742 .37278 .61078 .36191 Metetra
.09 .355 .824 r
.61078 .36191 .61742 .37278 .63089 .38101 .62427 .37068 Metetra
.003 .31 .801 r
.62427 .37068 .63089 .38101 .64455 .39023 .63796 .38049 Metetra
0 .268 .775 r
.63796 .38049 .64455 .39023 .65842 .40022 .65186 .39111 Metetra
0 .234 .748 r
.65186 .39111 .65842 .40022 .6725 .41077 .66599 .40231 Metetra
0 .208 .723 r
.66599 .40231 .6725 .41077 .68679 .42162 .68032 .41383 Metetra
0 .193 .704 r
.68032 .41383 .68679 .42162 .70128 .43252 .69487 .4254 Metetra
0 .191 .692 r
.69487 .4254 .70128 .43252 .71595 .44321 .7096 .43675 Metetra
0 .201 .689 r
.7096 .43675 .71595 .44321 .7308 .45344 .72451 .4476 Metetra
0 .225 .696 r
.72451 .4476 .7308 .45344 .74579 .46294 .73958 .45771 Metetra
0 .264 .713 r
.73958 .45771 .74579 .46294 .76091 .4715 .75478 .46682 Metetra
0 .316 .74 r
.75478 .46682 .76091 .4715 .77613 .47891 .77009 .47473 Metetra
.173 .631 .937 r
.77009 .47473 .77613 .47891 .79142 .48498 .78512 .47688 Metetra
.646 .762 .934 r
.78512 .47688 .79142 .48498 .80599 .4806 .79974 .47246 Metetra
.646 .762 .934 r
.79974 .47246 .80599 .4806 .82063 .4762 .81444 .46802 Metetra
.646 .762 .934 r
.81444 .46802 .82063 .4762 .83535 .47178 .82921 .46355 Metetra
.646 .762 .934 r
.82921 .46355 .83535 .47178 .85014 .46733 .84405 .45906 Metetra
.646 .762 .934 r
.84405 .45906 .85014 .46733 .86501 .46286 .85898 .45455 Metetra
.646 .762 .934 r
.19958 .64476 .20773 .65138 .21957 .6478 .21144 .64116 Metetra
.646 .762 .934 r
.21144 .64116 .21957 .6478 .23145 .64421 .22336 .63753 Metetra
.646 .762 .934 r
.22336 .63753 .23145 .64421 .2434 .6406 .23534 .63389 Metetra
.646 .762 .934 r
.23534 .63389 .2434 .6406 .25539 .63697 .24737 .63024 Metetra
.646 .762 .934 r
.24737 .63024 .25539 .63697 .26745 .63333 .25945 .62656 Metetra
.646 .762 .934 r
.25945 .62656 .26745 .63333 .27981 .62609 .27159 .62287 Metetra
.874 .856 .821 r
.27159 .62287 .27981 .62609 .29274 .61094 .28456 .60821 Metetra
.895 .857 .796 r
.28456 .60821 .29274 .61094 .30572 .59453 .29766 .59128 Metetra
.897 .842 .782 r
.29766 .59128 .30572 .59453 .31874 .57704 .31079 .57323 Metetra
.898 .828 .77 r
.31079 .57323 .31874 .57704 .33176 .5587 .32392 .55429 Metetra
.896 .816 .761 r
.32392 .55429 .33176 .5587 .34477 .53975 .33704 .5347 Metetra
.893 .805 .755 r
.33704 .5347 .34477 .53975 .35774 .52045 .35013 .51475 Metetra
.888 .795 .751 r
.35013 .51475 .35774 .52045 .37066 .50105 .36316 .4947 Metetra
.882 .785 .749 r
.36316 .4947 .37066 .50105 .38352 .48184 .37612 .47483 Metetra
.875 .776 .749 r
.37612 .47483 .38352 .48184 .3963 .46306 .38899 .45541 Metetra
.866 .767 .751 r
.38899 .45541 .3963 .46306 .40901 .44495 .40179 .4367 Metetra
.856 .758 .754 r
.40179 .4367 .40901 .44495 .42164 .42776 .41449 .41893 Metetra
.844 .75 .76 r
.41449 .41893 .42164 .42776 .43419 .41168 .42712 .40232 Metetra
.829 .741 .767 r
.42712 .40232 .43419 .41168 .44668 .3969 .43967 .38707 Metetra
.812 .731 .775 r
.43967 .38707 .44668 .3969 .45911 .38358 .45216 .37334 Metetra
.791 .721 .786 r
.45216 .37334 .45911 .38358 .47149 .37186 .46459 .36127 Metetra
.767 .709 .798 r
.46459 .36127 .47149 .37186 .48386 .36185 .477 .35099 Metetra
.738 .696 .811 r
.477 .35099 .48386 .36185 .49622 .35364 .48939 .34257 Metetra
.703 .681 .826 r
.48939 .34257 .49622 .35364 .50859 .34728 .50179 .33609 Metetra
.661 .663 .841 r
.50179 .33609 .50859 .34728 .521 .34281 .51422 .33158 Metetra
.609 .64 .856 r
.51422 .33158 .521 .34281 .53347 .34025 .52671 .32904 Metetra
.548 .613 .869 r
.52671 .32904 .53347 .34025 .54602 .33956 .53928 .32846 Metetra
.475 .578 .879 r
.53928 .32846 .54602 .33956 .55868 .34071 .55195 .32979 Metetra
.39 .537 .883 r
.55195 .32979 .55868 .34071 .57146 .34363 .56475 .33296 Metetra
.293 .488 .878 r
.56475 .33296 .57146 .34363 .58439 .34822 .5777 .33788 Metetra
.188 .433 .863 r
.5777 .33788 .58439 .34822 .5975 .35436 .59082 .3444 Metetra
.08 .373 .838 r
.59082 .3444 .5975 .35436 .61078 .36191 .60413 .35239 Metetra
0 .313 .804 r
.60413 .35239 .61078 .36191 .62427 .37068 .61764 .36166 Metetra
0 .256 .763 r
.61764 .36166 .62427 .37068 .63796 .38049 .63136 .37201 Metetra
0 .206 .722 r
.63136 .37201 .63796 .38049 .65186 .39111 .6453 .3832 Metetra
0 .167 .682 r
.6453 .3832 .65186 .39111 .66599 .40231 .65946 .39499 Metetra
0 .139 .649 r
.65946 .39499 .66599 .40231 .68032 .41383 .67385 .40711 Metetra
0 .125 .625 r
.67385 .40711 .68032 .41383 .69487 .4254 .68844 .41929 Metetra
0 .124 .611 r
.68844 .41929 .69487 .4254 .7096 .43675 .70324 .43123 Metetra
0 .136 .608 r
.70324 .43123 .7096 .43675 .72451 .4476 .71822 .44265 Metetra
0 .163 .616 r
.71822 .44265 .72451 .4476 .73958 .45771 .73336 .45328 Metetra
0 .204 .637 r
.73336 .45328 .73958 .45771 .75478 .46682 .74864 .46289 Metetra
0 .259 .668 r
.74864 .46289 .75478 .46682 .77009 .47473 .76403 .47124 Metetra
.463 .83 .993 r
.76403 .47124 .77009 .47473 .78512 .47688 .77876 .4687 Metetra
.646 .762 .934 r
.77876 .4687 .78512 .47688 .79974 .47246 .79344 .46424 Metetra
.646 .762 .934 r
.79344 .46424 .79974 .47246 .81444 .46802 .80819 .45976 Metetra
.646 .762 .934 r
.80819 .45976 .81444 .46802 .82921 .46355 .82301 .45525 Metetra
.646 .762 .934 r
.82301 .45525 .82921 .46355 .84405 .45906 .83791 .45072 Metetra
.646 .762 .934 r
.83791 .45072 .84405 .45906 .85898 .45455 .85289 .44617 Metetra
.646 .762 .934 r
.19135 .63809 .19958 .64476 .21144 .64116 .20325 .63445 Metetra
.646 .762 .934 r
.20325 .63445 .21144 .64116 .22336 .63753 .2152 .6308 Metetra
.646 .762 .934 r
.2152 .6308 .22336 .63753 .23534 .63389 .22721 .62713 Metetra
.646 .762 .934 r
.22721 .62713 .23534 .63389 .24737 .63024 .23927 .62344 Metetra
.646 .762 .934 r
.23927 .62344 .24737 .63024 .25945 .62656 .25139 .61973 Metetra
.646 .762 .934 r
.25139 .61973 .25945 .62656 .27159 .62287 .26356 .61601 Metetra
.788 .784 .848 r
.26356 .61601 .27159 .62287 .28456 .60821 .27624 .60618 Metetra
.903 .87 .795 r
.27624 .60618 .28456 .60821 .29766 .59128 .28945 .58879 Metetra
.906 .856 .781 r
.28945 .58879 .29766 .59128 .31079 .57323 .30269 .57025 Metetra
.907 .843 .769 r
.30269 .57025 .31079 .57323 .32392 .55429 .31595 .55077 Metetra
.907 .832 .761 r
.31595 .55077 .32392 .55429 .33704 .5347 .32918 .53062 Metetra
.904 .821 .755 r
.32918 .53062 .33704 .5347 .35013 .51475 .34238 .51008 Metetra
.901 .812 .751 r
.34238 .51008 .35013 .51475 .36316 .4947 .35552 .48944 Metetra
.896 .804 .75 r
.35552 .48944 .36316 .4947 .37612 .47483 .36859 .46899 Metetra
.889 .796 .751 r
.36859 .46899 .37612 .47483 .38899 .45541 .38156 .44899 Metetra
.881 .788 .753 r
.38156 .44899 .38899 .45541 .40179 .4367 .39445 .42973 Metetra
.872 .781 .758 r
.39445 .42973 .40179 .4367 .41449 .41893 .40725 .41144 Metetra
.861 .775 .765 r
.40725 .41144 .41449 .41893 .42712 .40232 .41995 .39435 Metetra
.847 .767 .774 r
.41995 .39435 .42712 .40232 .43967 .38707 .43257 .37867 Metetra
.83 .76 .786 r
.43257 .37867 .43967 .38707 .45216 .37334 .44512 .36456 Metetra
.809 .752 .799 r
.44512 .36456 .45216 .37334 .46459 .36127 .45761 .35218 Metetra
.784 .743 .814 r
.45761 .35218 .46459 .36127 .477 .35099 .47006 .34164 Metetra
.753 .731 .832 r
.47006 .34164 .477 .35099 .48939 .34257 .4825 .33304 Metetra
.715 .717 .851 r
.4825 .33304 .48939 .34257 .50179 .33609 .49493 .32644 Metetra
.667 .699 .87 r
.49493 .32644 .50179 .33609 .51422 .33158 .5074 .32188 Metetra
.606 .674 .889 r
.5074 .32188 .51422 .33158 .52671 .32904 .51991 .31937 Metetra
.532 .642 .904 r
.51991 .31937 .52671 .32904 .53928 .32846 .53251 .31888 Metetra
.441 .6 .912 r
.53251 .31888 .53928 .32846 .55195 .32979 .5452 .32038 Metetra
.333 .546 .91 r
.5452 .32038 .55195 .32979 .56475 .33296 .55802 .32378 Metetra
.212 .482 .893 r
.55802 .32378 .56475 .33296 .5777 .33788 .57099 .32898 Metetra
.084 .408 .86 r
.57099 .32898 .5777 .33788 .59082 .3444 .58413 .33586 Metetra
0 .331 .813 r
.58413 .33586 .59082 .3444 .60413 .35239 .59746 .34425 Metetra
0 .257 .757 r
.59746 .34425 .60413 .35239 .61764 .36166 .61099 .35397 Metetra
0 .191 .699 r
.61099 .35397 .61764 .36166 .63136 .37201 .62475 .36479 Metetra
0 .137 .644 r
.62475 .36479 .63136 .37201 .6453 .3832 .63872 .3765 Metetra
0 .096 .597 r
.63872 .3765 .6453 .3832 .65946 .39499 .65293 .38882 Metetra
0 .07 .56 r
.65293 .38882 .65946 .39499 .67385 .40711 .66736 .40147 Metetra
0 .058 .535 r
.66736 .40147 .67385 .40711 .68844 .41929 .68201 .41418 Metetra
.473 0 0 r
.68201 .41418 .68844 .41929 .70324 .43123 .69686 .42664 Metetra
.468 0 0 r
.69686 .42664 .70324 .43123 .71822 .44265 .71191 .43856 Metetra
.449 0 0 r
.71191 .43856 .71822 .44265 .73336 .45328 .72712 .44966 Metetra
.416 0 0 r
.72712 .44966 .73336 .45328 .74864 .46289 .74247 .45969 Metetra
0 .411 .758 r
.74247 .45969 .74864 .46289 .76403 .47124 .7577 .46493 Metetra
.634 .816 .97 r
.7577 .46493 .76403 .47124 .77876 .4687 .77235 .46045 Metetra
.646 .762 .934 r
.77235 .46045 .77876 .4687 .79344 .46424 .78707 .45594 Metetra
.646 .762 .934 r
.78707 .45594 .79344 .46424 .80819 .45976 .80188 .45142 Metetra
.646 .762 .934 r
.80188 .45142 .80819 .45976 .82301 .45525 .81676 .44687 Metetra
.646 .762 .934 r
.81676 .44687 .82301 .45525 .83791 .45072 .83171 .4423 Metetra
.646 .762 .934 r
.83171 .4423 .83791 .45072 .85289 .44617 .84674 .4377 Metetra
.646 .762 .934 r
.18306 .63136 .19135 .63809 .20325 .63445 .19499 .62769 Metetra
.646 .762 .934 r
.19499 .62769 .20325 .63445 .2152 .6308 .20697 .62401 Metetra
.646 .762 .934 r
.20697 .62401 .2152 .6308 .22721 .62713 .21901 .62031 Metetra
.646 .762 .934 r
.21901 .62031 .22721 .62713 .23927 .62344 .23111 .61659 Metetra
.646 .762 .934 r
.23111 .61659 .23927 .62344 .25139 .61973 .24326 .61285 Metetra
.646 .762 .934 r
.24326 .61285 .25139 .61973 .26356 .61601 .25547 .60909 Metetra
.663 .767 .927 r
.25547 .60909 .26356 .61601 .27624 .60618 .26777 .60483 Metetra
.91 .883 .794 r
.26777 .60483 .27624 .60618 .28945 .58879 .28109 .58705 Metetra
.914 .869 .78 r
.28109 .58705 .28945 .58879 .30269 .57025 .29445 .56808 Metetra
.916 .857 .768 r
.29445 .56808 .30269 .57025 .31595 .55077 .30783 .54814 Metetra
.916 .846 .76 r
.30783 .54814 .31595 .55077 .32918 .53062 .32118 .5275 Metetra
.915 .837 .754 r
.32118 .5275 .32918 .53062 .34238 .51008 .3345 .50645 Metetra
.912 .829 .751 r
.3345 .50645 .34238 .51008 .35552 .48944 .34775 .48528 Metetra
.908 .822 .75 r
.34775 .48528 .35552 .48944 .36859 .46899 .36093 .4643 Metetra
.903 .816 .752 r
.36093 .4643 .36859 .46899 .38156 .44899 .37401 .4438 Metetra
.896 .81 .756 r
.37401 .4438 .38156 .44899 .39445 .42973 .387 .42404 Metetra
.887 .805 .762 r
.387 .42404 .39445 .42973 .40725 .41144 .39988 .40529 Metetra
.877 .8 .771 r
.39988 .40529 .40725 .41144 .41995 .39435 .41267 .38777 Metetra
.864 .796 .782 r
.41267 .38777 .41995 .39435 .43257 .37867 .42537 .37169 Metetra
.848 .791 .796 r
.42537 .37169 .43257 .37867 .44512 .36456 .43799 .35725 Metetra
.828 .785 .812 r
.43799 .35725 .44512 .36456 .45761 .35218 .45054 .34458 Metetra
.802 .779 .832 r
.45054 .34458 .45761 .35218 .47006 .34164 .46305 .33381 Metetra
.769 .77 .854 r
.46305 .33381 .47006 .34164 .4825 .33304 .47553 .32504 Metetra
.727 .758 .877 r
.47553 .32504 .4825 .33304 .49493 .32644 .48801 .31833 Metetra
.671 .74 .902 r
.48801 .31833 .49493 .32644 .5074 .32188 .50051 .31372 Metetra
.599 .714 .924 r
.50051 .31372 .5074 .32188 .51991 .31937 .51306 .31123 Metetra
.507 .675 .94 r
.51306 .31123 .51991 .31937 .53251 .31888 .52568 .31083 Metetra
.392 .621 .944 r
.52568 .31083 .53251 .31888 .5452 .32038 .5384 .31246 Metetra
.257 .55 .928 r
.5384 .31246 .5452 .32038 .55802 .32378 .55124 .31607 Metetra
.108 .463 .889 r
.55124 .31607 .55802 .32378 .57099 .32898 .56424 .32153 Metetra
0 .368 .83 r
.56424 .32153 .57099 .32898 .58413 .33586 .5774 .32872 Metetra
0 .273 .757 r
.5774 .32872 .58413 .33586 .59746 .34425 .59076 .33747 Metetra
0 .189 .68 r
.59076 .33747 .59746 .34425 .61099 .35397 .60432 .34758 Metetra
0 .119 .609 r
.60432 .34758 .61099 .35397 .62475 .36479 .61811 .35883 Metetra
0 .066 .548 r
.61811 .35883 .62475 .36479 .63872 .3765 .63212 .37098 Metetra
.497 0 0 r
.63212 .37098 .63872 .3765 .65293 .38882 .64637 .38377 Metetra
.527 0 0 r
.64637 .38377 .65293 .38882 .66736 .40147 .66085 .39689 Metetra
.543 .001 0 r
.66085 .39689 .66736 .40147 .68201 .41418 .67555 .41006 Metetra
.545 0 0 r
.67555 .41006 .68201 .41418 .69686 .42664 .69046 .42297 Metetra
.535 0 0 r
.69046 .42297 .69686 .42664 .71191 .43856 .70557 .43532 Metetra
.512 0 0 r
.70557 .43532 .71191 .43856 .72712 .44966 .72085 .44681 Metetra
.476 0 0 r
.72085 .44681 .72712 .44966 .74247 .45969 .73628 .4572 Metetra
.25 .733 .93 r
.73628 .4572 .74247 .45969 .7577 .46493 .75117 .45664 Metetra
.646 .762 .934 r
.75117 .45664 .7577 .46493 .77235 .46045 .76587 .45212 Metetra
.646 .762 .934 r
.76587 .45212 .77235 .46045 .78707 .45594 .78065 .44757 Metetra
.646 .762 .934 r
.78065 .44757 .78707 .45594 .80188 .45142 .79551 .443 Metetra
.646 .762 .934 r
.79551 .443 .80188 .45142 .81676 .44687 .81044 .43841 Metetra
.646 .762 .934 r
.81044 .43841 .81676 .44687 .83171 .4423 .82545 .43379 Metetra
.646 .762 .934 r
.82545 .43379 .83171 .4423 .84674 .4377 .84054 .42915 Metetra
.646 .762 .934 r
.17469 .62458 .18306 .63136 .19499 .62769 .18665 .62088 Metetra
.646 .762 .934 r
.18665 .62088 .19499 .62769 .20697 .62401 .19867 .61716 Metetra
.646 .762 .934 r
.19867 .61716 .20697 .62401 .21901 .62031 .21074 .61342 Metetra
.646 .762 .934 r
.21074 .61342 .21901 .62031 .23111 .61659 .22287 .60967 Metetra
.646 .762 .934 r
.22287 .60967 .23111 .61659 .24326 .61285 .23505 .6059 Metetra
.646 .762 .934 r
.23505 .6059 .24326 .61285 .25547 .60909 .2473 .60211 Metetra
.646 .762 .934 r
.2473 .60211 .25547 .60909 .26777 .60483 .2596 .59831 Metetra
.822 .794 .826 r
.2596 .59831 .26777 .60483 .28109 .58705 .27258 .58603 Metetra
.921 .882 .779 r
.27258 .58603 .28109 .58705 .29445 .56808 .28606 .56669 Metetra
.924 .87 .767 r
.28606 .56669 .29445 .56808 .30783 .54814 .29955 .54636 Metetra
.924 .861 .759 r
.29955 .54636 .30783 .54814 .32118 .5275 .31303 .5253 Metetra
.924 .853 .754 r
.31303 .5253 .32118 .5275 .3345 .50645 .32646 .50381 Metetra
.922 .846 .751 r
.32646 .50381 .3345 .50645 .34775 .48528 .33984 .4822 Metetra
.919 .84 .75 r
.33984 .4822 .34775 .48528 .36093 .4643 .35312 .46076 Metetra
.915 .835 .753 r
.35312 .46076 .36093 .4643 .37401 .4438 .36632 .43981 Metetra
.909 .832 .757 r
.36632 .43981 .37401 .4438 .387 .42404 .37941 .41961 Metetra
.902 .829 .765 r
.37941 .41961 .387 .42404 .39988 .40529 .39239 .40045 Metetra
.892 .826 .775 r
.39239 .40045 .39988 .40529 .41267 .38777 .40527 .38254 Metetra
.88 .825 .788 r
.40527 .38254 .41267 .38777 .42537 .37169 .41805 .36612 Metetra
.865 .823 .805 r
.41805 .36612 .42537 .37169 .43799 .35725 .43075 .35137 Metetra
.845 .821 .825 r
.43075 .35137 .43799 .35725 .45054 .34458 .44337 .33844 Metetra
.819 .818 .849 r
.44337 .33844 .45054 .34458 .46305 .33381 .45594 .32747 Metetra
.784 .813 .876 r
.45594 .32747 .46305 .33381 .47553 .32504 .46848 .31854 Metetra
.736 .803 .905 r
.46848 .31854 .47553 .32504 .48801 .31833 .481 .31173 Metetra
.672 .786 .935 r
.481 .31173 .48801 .31833 .50051 .31372 .49355 .30709 Metetra
.584 .757 .96 r
.49355 .30709 .50051 .31372 .51306 .31123 .50613 .30461 Metetra
.469 .708 .973 r
.50613 .30461 .51306 .31123 .52568 .31083 .51879 .30427 Metetra
.323 .636 .964 r
.51879 .30427 .52568 .31083 .5384 .31246 .53154 .30604 Metetra
.156 .539 .924 r
.53154 .30604 .5384 .31246 .55124 .31607 .54442 .30982 Metetra
0 .426 .854 r
.54442 .30982 .55124 .31607 .56424 .32153 .55744 .31551 Metetra
0 .309 .763 r
.55744 .31551 .56424 .32153 .5774 .32872 .57064 .32296 Metetra
0 .204 .667 r
.57064 .32296 .5774 .32872 .59076 .33747 .58402 .33202 Metetra
0 .116 .579 r
.58402 .33202 .59076 .33747 .60432 .34758 .59762 .34247 Metetra
.488 0 0 r
.59762 .34247 .60432 .34758 .61811 .35883 .61144 .3541 Metetra
.541 0 0 r
.61144 .3541 .61811 .35883 .63212 .37098 .62549 .36664 Metetra
.575 .031 0 r
.62549 .36664 .63212 .37098 .64637 .38377 .63978 .37982 Metetra
.595 .048 0 r
.63978 .37982 .64637 .38377 .66085 .39689 .65431 .39335 Metetra
.602 .052 0 r
.65431 .39335 .66085 .39689 .67555 .41006 .66906 .40691 Metetra
.599 .043 0 r
.66906 .40691 .67555 .41006 .69046 .42297 .68403 .4202 Metetra
.584 .022 0 r
.68403 .4202 .69046 .42297 .70557 .43532 .6992 .4329 Metetra
.559 0 0 r
.6992 .4329 .70557 .43532 .72085 .44681 .71455 .44471 Metetra
.406 0 0 r
.71455 .44471 .72085 .44681 .73628 .4572 .72989 .45281 Metetra
.601 .867 .993 r
.72989 .45281 .73628 .4572 .75117 .45664 .74457 .44827 Metetra
.646 .762 .934 r
.74457 .44827 .75117 .45664 .76587 .45212 .75933 .44371 Metetra
.646 .762 .934 r
.75933 .44371 .76587 .45212 .78065 .44757 .77417 .43912 Metetra
.646 .762 .934 r
.77417 .43912 .78065 .44757 .79551 .443 .78908 .4345 Metetra
.646 .762 .934 r
.78908 .4345 .79551 .443 .81044 .43841 .80406 .42987 Metetra
.646 .762 .934 r
.80406 .42987 .81044 .43841 .82545 .43379 .81913 .42521 Metetra
.646 .762 .934 r
.81913 .42521 .82545 .43379 .84054 .42915 .83428 .42052 Metetra
.646 .762 .934 r
.16626 .61773 .17469 .62458 .18665 .62088 .17825 .614 Metetra
.646 .762 .934 r
.17825 .614 .18665 .62088 .19867 .61716 .1903 .61025 Metetra
.646 .762 .934 r
.1903 .61025 .19867 .61716 .21074 .61342 .2024 .60648 Metetra
.646 .762 .934 r
.2024 .60648 .21074 .61342 .22287 .60967 .21456 .6027 Metetra
.646 .762 .934 r
.21456 .6027 .22287 .60967 .23505 .6059 .22678 .5989 Metetra
.646 .762 .934 r
.22678 .5989 .23505 .6059 .2473 .60211 .23906 .59508 Metetra
.646 .762 .934 r
.23906 .59508 .2473 .60211 .2596 .59831 .25139 .59124 Metetra
.7 .775 .91 r
.25139 .59124 .2596 .59831 .27258 .58603 .26391 .58568 Metetra
.926 .893 .778 r
.26391 .58568 .27258 .58603 .28606 .56669 .27751 .56606 Metetra
.93 .883 .766 r
.27751 .56606 .28606 .56669 .29955 .54636 .29112 .5454 Metetra
.931 .874 .758 r
.29112 .5454 .29955 .54636 .31303 .5253 .30472 .524 Metetra
.932 .867 .753 r
.30472 .524 .31303 .5253 .32646 .50381 .31828 .50214 Metetra
.931 .862 .75 r
.31828 .50214 .32646 .50381 .33984 .4822 .33177 .48015 Metetra
.929 .857 .75 r
.33177 .48015 .33984 .4822 .35312 .46076 .34517 .45833 Metetra
.925 .855 .753 r
.34517 .45833 .35312 .46076 .36632 .43981 .35848 .43699 Metetra
.921 .853 .758 r
.35848 .43699 .36632 .43981 .37941 .41961 .37168 .41642 Metetra
.915 .852 .767 r
.37168 .41642 .37941 .41961 .39239 .40045 .38477 .39689 Metetra
.906 .853 .779 r
.38477 .39689 .39239 .40045 .40527 .38254 .39774 .37866 Metetra
.895 .854 .794 r
.39774 .37866 .40527 .38254 .41805 .36612 .41061 .36193 Metetra
.881 .856 .813 r
.41061 .36193 .41805 .36612 .43075 .35137 .42339 .34691 Metetra
.861 .858 .836 r
.42339 .34691 .43075 .35137 .44337 .33844 .43609 .33375 Metetra
.834 .859 .864 r
.43609 .33375 .44337 .33844 .45594 .32747 .44873 .32259 Metetra
.796 .858 .896 r
.44873 .32259 .45594 .32747 .46848 .31854 .46132 .31353 Metetra
.742 .851 .931 r
.46132 .31353 .46848 .31854 .481 .31173 .47391 .30663 Metetra
.665 .834 .965 r
.47391 .30663 .481 .31173 .49355 .30709 .4865 .30194 Metetra
.556 .798 .989 r
.4865 .30194 .49355 .30709 .50613 .30461 .49913 .29947 Metetra
.41 .734 .991 r
.49913 .29947 .50613 .30461 .51879 .30427 .51183 .29919 Metetra
.229 .635 .957 r
.51183 .29919 .51879 .30427 .53154 .30604 .52462 .30106 Metetra
.032 .506 .881 r
.52462 .30106 .53154 .30604 .54442 .30982 .53753 .305 Metetra
0 .367 .775 r
.53753 .305 .54442 .30982 .55744 .31551 .55059 .31088 Metetra
0 .238 .661 r
.55059 .31088 .55744 .31551 .57064 .32296 .56382 .31857 Metetra
.425 0 0 r
.56382 .31857 .57064 .32296 .58402 .33202 .57724 .32789 Metetra
.509 0 0 r
.57724 .32789 .58402 .33202 .59762 .34247 .59087 .33863 Metetra
.568 .012 0 r
.59087 .33863 .59762 .34247 .61144 .3541 .60472 .35057 Metetra
.606 .054 0 r
.60472 .35057 .61144 .3541 .62549 .36664 .61882 .36344 Metetra
.63 .079 0 r
.61882 .36344 .62549 .36664 .63978 .37982 .63315 .37695 Metetra
.642 .091 0 r
.63315 .37695 .63978 .37982 .65431 .39335 .64772 .39081 Metetra
.644 .091 0 r
.64772 .39081 .65431 .39335 .66906 .40691 .66253 .40469 Metetra
.636 .08 0 r
.66253 .40469 .66906 .40691 .68403 .4202 .67756 .41828 Metetra
.62 .057 0 r
.67756 .41828 .68403 .4202 .6992 .4329 .69279 .43125 Metetra
.592 .022 0 r
.69279 .43125 .6992 .4329 .71455 .44471 .70821 .44332 Metetra
.023 .588 .792 r
.70821 .44332 .71455 .44471 .72989 .45281 .72318 .44441 Metetra
.646 .762 .934 r
.72318 .44441 .72989 .45281 .74457 .44827 .73792 .43982 Metetra
.646 .762 .934 r
.73792 .43982 .74457 .44827 .75933 .44371 .75273 .43522 Metetra
.646 .762 .934 r
.75273 .43522 .75933 .44371 .77417 .43912 .76762 .43058 Metetra
.646 .762 .934 r
.76762 .43058 .77417 .43912 .78908 .4345 .78258 .42592 Metetra
.646 .762 .934 r
.78258 .42592 .78908 .4345 .80406 .42987 .79763 .42124 Metetra
.646 .762 .934 r
.79763 .42124 .80406 .42987 .81913 .42521 .81275 .41654 Metetra
.646 .762 .934 r
.81275 .41654 .81913 .42521 .83428 .42052 .82795 .41181 Metetra
.646 .762 .934 r
.15775 .61083 .16626 .61773 .17825 .614 .16977 .60706 Metetra
.646 .762 .934 r
.16977 .60706 .17825 .614 .1903 .61025 .18185 .60328 Metetra
.646 .762 .934 r
.18185 .60328 .1903 .61025 .2024 .60648 .19399 .59948 Metetra
.646 .762 .934 r
.19399 .59948 .2024 .60648 .21456 .6027 .20618 .59566 Metetra
.646 .762 .934 r
.20618 .59566 .21456 .6027 .22678 .5989 .21843 .59183 Metetra
.646 .762 .934 r
.21843 .59183 .22678 .5989 .23906 .59508 .23074 .58797 Metetra
.646 .762 .934 r
.23074 .58797 .23906 .59508 .25139 .59124 .24311 .5841 Metetra
.646 .762 .934 r
.24311 .5841 .25139 .59124 .26391 .58568 .25554 .58021 Metetra
.85 .817 .817 r
.25554 .58021 .26391 .58568 .27751 .56606 .2688 .56611 Metetra
.934 .895 .765 r
.2688 .56611 .27751 .56606 .29112 .5454 .28253 .54522 Metetra
.937 .887 .757 r
.28253 .54522 .29112 .5454 .30472 .524 .29625 .52355 Metetra
.938 .881 .752 r
.29625 .52355 .30472 .524 .31828 .50214 .30993 .5014 Metetra
.938 .877 .749 r
.30993 .5014 .31828 .50214 .33177 .48015 .32354 .4791 Metetra
.937 .874 .749 r
.32354 .4791 .33177 .48015 .34517 .45833 .33707 .45696 Metetra
.934 .873 .752 r
.33707 .45696 .34517 .45833 .35848 .43699 .35049 .4353 Metetra
.931 .873 .758 r
.35049 .4353 .35848 .43699 .37168 .41642 .3638 .41441 Metetra
.925 .875 .768 r
.3638 .41441 .37168 .41642 .38477 .39689 .377 .39458 Metetra
.918 .878 .78 r
.377 .39458 .38477 .39689 .39774 .37866 .39007 .37606 Metetra
.908 .882 .797 r
.39007 .37606 .39774 .37866 .41061 .36193 .40304 .35908 Metetra
.893 .888 .819 r
.40304 .35908 .41061 .36193 .42339 .34691 .41591 .34382 Metetra
.873 .894 .845 r
.41591 .34382 .42339 .34691 .43609 .33375 .42869 .33047 Metetra
.844 .9 .876 r
.42869 .33047 .43609 .33375 .44873 .32259 .4414 .31914 Metetra
.802 .903 .912 r
.4414 .31914 .44873 .32259 .46132 .31353 .45406 .30996 Metetra
.739 .899 .951 r
.45406 .30996 .46132 .31353 .47391 .30663 .46671 .30298 Metetra
.645 .879 .984 r
.46671 .30298 .47391 .30663 .4865 .30194 .47936 .29825 Metetra
.508 .83 1 r
.47936 .29825 .4865 .30194 .49913 .29947 .49204 .29578 Metetra
.325 .74 .978 r
.49204 .29578 .49913 .29947 .51183 .29919 .50478 .29555 Metetra
.111 .605 .906 r
.50478 .29555 .51183 .29919 .52462 .30106 .51762 .29751 Metetra
0 .447 .791 r
.51762 .29751 .52462 .30106 .53753 .305 .53057 .30156 Metetra
0 .293 .661 r
.53057 .30156 .53753 .305 .55059 .31088 .54367 .30761 Metetra
.415 0 0 r
.54367 .30761 .55059 .31088 .56382 .31857 .55693 .31548 Metetra
.511 0 0 r
.55693 .31548 .56382 .31857 .57724 .32789 .57039 .32502 Metetra
.577 .01 0 r
.57039 .32502 .57724 .32789 .59087 .33863 .58406 .33601 Metetra
.622 .062 0 r
.58406 .33601 .59087 .33863 .60472 .35057 .59796 .3482 Metetra
.65 .096 0 r
.59796 .3482 .60472 .35057 .61882 .36344 .61209 .36133 Metetra
.666 .117 0 r
.61209 .36133 .61882 .36344 .63315 .37695 .62647 .37511 Metetra
.673 .125 0 r
.62647 .37511 .63315 .37695 .64772 .39081 .64109 .38922 Metetra
.671 .122 0 r
.64109 .38922 .64772 .39081 .66253 .40469 .65595 .40335 Metetra
.662 .108 0 r
.65595 .40335 .66253 .40469 .67756 .41828 .67104 .41716 Metetra
.643 .084 0 r
.67104 .41716 .67756 .41828 .69279 .43125 .68633 .43034 Metetra
.551 0 0 r
.68633 .43034 .69279 .43125 .70821 .44332 .7017 .44053 Metetra
.546 .891 .982 r
.7017 .44053 .70821 .44332 .72318 .44441 .71641 .43593 Metetra
.646 .762 .934 r
.71641 .43593 .72318 .44441 .73792 .43982 .7312 .4313 Metetra
.646 .762 .934 r
.7312 .4313 .73792 .43982 .75273 .43522 .74606 .42664 Metetra
.646 .762 .934 r
.74606 .42664 .75273 .43522 .76762 .43058 .76101 .42196 Metetra
.646 .762 .934 r
.76101 .42196 .76762 .43058 .78258 .42592 .77603 .41726 Metetra
.646 .762 .934 r
.77603 .41726 .78258 .42592 .79763 .42124 .79113 .41253 Metetra
.646 .762 .934 r
.79113 .41253 .79763 .42124 .81275 .41654 .80631 .40778 Metetra
.646 .762 .934 r
.80631 .40778 .81275 .41654 .82795 .41181 .82157 .40301 Metetra
.646 .762 .934 r
.14916 .60386 .15775 .61083 .16977 .60706 .16122 .60007 Metetra
.646 .762 .934 r
.16122 .60007 .16977 .60706 .18185 .60328 .17333 .59625 Metetra
.646 .762 .934 r
.17333 .59625 .18185 .60328 .19399 .59948 .1855 .59242 Metetra
.646 .762 .934 r
.1855 .59242 .19399 .59948 .20618 .59566 .19773 .58857 Metetra
.646 .762 .934 r
.19773 .58857 .20618 .59566 .21843 .59183 .21001 .5847 Metetra
.646 .762 .934 r
.21001 .5847 .21843 .59183 .23074 .58797 .22236 .58081 Metetra
.646 .762 .934 r
.22236 .58081 .23074 .58797 .24311 .5841 .23476 .5769 Metetra
.646 .762 .934 r
.23476 .5769 .24311 .5841 .25554 .58021 .24722 .57298 Metetra
.713 .777 .903 r
.24722 .57298 .25554 .58021 .2688 .56611 .25992 .56681 Metetra
.938 .906 .765 r
.25992 .56681 .2688 .56611 .28253 .54522 .27377 .54575 Metetra
.941 .899 .756 r
.27377 .54575 .28253 .54522 .29625 .52355 .28761 .52388 Metetra
.943 .894 .75 r
.28761 .52388 .29625 .52355 .30993 .5014 .30141 .50152 Metetra
.944 .891 .748 r
.30141 .50152 .30993 .5014 .32354 .4791 .31515 .47898 Metetra
.943 .889 .748 r
.31515 .47898 .32354 .4791 .33707 .45696 .3288 .4566 Metetra
.941 .89 .751 r
.3288 .4566 .33707 .45696 .35049 .4353 .34234 .43468 Metetra
.938 .892 .757 r
.34234 .43468 .35049 .4353 .3638 .41441 .35577 .41354 Metetra
.934 .896 .767 r
.35577 .41354 .3638 .41441 .377 .39458 .36908 .39347 Metetra
.927 .902 .781 r
.36908 .39347 .377 .39458 .39007 .37606 .38226 .37471 Metetra
.917 .909 .798 r
.38226 .37471 .39007 .37606 .40304 .35908 .39532 .35751 Metetra
.902 .918 .821 r
.39532 .35751 .40304 .35908 .41591 .34382 .40828 .34206 Metetra
.881 .928 .849 r
.40828 .34206 .41591 .34382 .42869 .33047 .42115 .32854 Metetra
.848 .938 .882 r
.42115 .32854 .42869 .33047 .4414 .31914 .43394 .31707 Metetra
.799 .943 .92 r
.43394 .31707 .4414 .31914 .45406 .30996 .44668 .30778 Metetra
.722 .938 .957 r
.44668 .30778 .45406 .30996 .46671 .30298 .4594 .30073 Metetra
.605 .909 .982 r
.4594 .30073 .46671 .30298 .47936 .29825 .47211 .29597 Metetra
.435 .837 .976 r
.47211 .29597 .47936 .29825 .49204 .29578 .48485 .2935 Metetra
.217 .712 .917 r
.48485 .2935 .49204 .29578 .50478 .29555 .49765 .2933 Metetra
0 .545 .805 r
.49765 .2933 .50478 .29555 .51762 .29751 .51053 .29532 Metetra
.221 0 0 r
.51053 .29532 .51762 .29751 .53057 .30156 .52353 .29947 Metetra
.379 0 0 r
.52353 .29947 .53057 .30156 .54367 .30761 .53667 .30564 Metetra
.492 0 0 r
.53667 .30564 .54367 .30761 .55693 .31548 .54997 .31367 Metetra
.569 0 0 r
.54997 .31367 .55693 .31548 .57039 .32502 .56347 .32337 Metetra
.621 .056 0 r
.56347 .32337 .57039 .32502 .58406 .33601 .57719 .33454 Metetra
.656 .1 0 r
.57719 .33454 .58406 .33601 .59796 .3482 .59113 .34693 Metetra
.677 .128 0 r
.59113 .34693 .59796 .3482 .61209 .36133 .60531 .36026 Metetra
.689 .144 0 r
.60531 .36026 .61209 .36133 .62647 .37511 .61973 .37424 Metetra
.693 .149 0 r
.61973 .37424 .62647 .37511 .64109 .38922 .63441 .38854 Metetra
.689 .144 0 r
.63441 .38854 .64109 .38922 .65595 .40335 .64932 .40283 Metetra
.677 .128 0 r
.64932 .40283 .65595 .40335 .67104 .41716 .66446 .41679 Metetra
.658 .103 0 r
.66446 .41679 .67104 .41716 .68633 .43034 .67981 .43009 Metetra
.132 0 0 r
.67981 .43009 .68633 .43034 .7017 .44053 .69481 .43201 Metetra
.646 .762 .934 r
.69481 .43201 .7017 .44053 .71641 .43593 .70958 .42736 Metetra
.646 .762 .934 r
.70958 .42736 .71641 .43593 .7312 .4313 .72442 .42269 Metetra
.646 .762 .934 r
.72442 .42269 .7312 .4313 .74606 .42664 .73934 .41799 Metetra
.646 .762 .934 r
.73934 .41799 .74606 .42664 .76101 .42196 .75433 .41326 Metetra
.646 .762 .934 r
.75433 .41326 .76101 .42196 .77603 .41726 .76941 .40852 Metetra
.646 .762 .934 r
.76941 .40852 .77603 .41726 .79113 .41253 .78456 .40374 Metetra
.646 .762 .934 r
.78456 .40374 .79113 .41253 .80631 .40778 .7998 .39894 Metetra
.646 .762 .934 r
.7998 .39894 .80631 .40778 .82157 .40301 .81512 .39412 Metetra
.646 .762 .934 r
.1405 .59684 .14916 .60386 .16122 .60007 .15259 .59301 Metetra
.646 .762 .934 r
.15259 .59301 .16122 .60007 .17333 .59625 .16474 .58916 Metetra
.646 .762 .934 r
.16474 .58916 .17333 .59625 .1855 .59242 .17694 .5853 Metetra
.646 .762 .934 r
.17694 .5853 .1855 .59242 .19773 .58857 .1892 .58141 Metetra
.646 .762 .934 r
.1892 .58141 .19773 .58857 .21001 .5847 .20152 .57751 Metetra
.646 .762 .934 r
.20152 .57751 .21001 .5847 .22236 .58081 .2139 .57358 Metetra
.646 .762 .934 r
.2139 .57358 .22236 .58081 .23476 .5769 .22634 .56964 Metetra
.646 .762 .934 r
.22634 .56964 .23476 .5769 .24722 .57298 .23883 .56568 Metetra
.646 .762 .934 r
.23883 .56568 .24722 .57298 .25992 .56681 .25139 .5617 Metetra
.859 .828 .815 r
.25139 .5617 .25992 .56681 .27377 .54575 .26484 .54692 Metetra
.944 .909 .755 r
.26484 .54692 .27377 .54575 .28761 .52388 .2788 .52494 Metetra
.946 .906 .749 r
.2788 .52494 .28761 .52388 .30141 .50152 .29273 .50244 Metetra
.948 .904 .746 r
.29273 .50244 .30141 .50152 .31515 .47898 .30659 .47974 Metetra
.948 .903 .746 r
.30659 .47974 .31515 .47898 .3288 .4566 .32036 .45718 Metetra
.946 .905 .749 r
.32036 .45718 .3288 .4566 .34234 .43468 .33403 .43508 Metetra
.944 .909 .755 r
.33403 .43508 .34234 .43468 .35577 .41354 .34757 .41375 Metetra
.939 .915 .765 r
.34757 .41375 .35577 .41354 .36908 .39347 .36099 .39349 Metetra
.932 .923 .779 r
.36099 .39349 .36908 .39347 .38226 .37471 .37428 .37455 Metetra
.922 .933 .797 r
.37428 .37455 .38226 .37471 .39532 .35751 .38746 .35717 Metetra
.906 .945 .819 r
.38746 .35717 .39532 .35751 .40828 .34206 .40051 .34156 Metetra
.881 .958 .848 r
.40051 .34156 .40828 .34206 .42115 .32854 .41347 .3279 Metetra
.843 .969 .88 r
.41347 .3279 .42115 .32854 .43394 .31707 .42635 .31633 Metetra
.783 .974 .915 r
.42635 .31633 .43394 .31707 .44668 .30778 .43917 .30694 Metetra
.687 .961 .943 r
.43917 .30694 .44668 .30778 .4594 .30073 .45196 .29983 Metetra
.541 .913 .949 r
.45196 .29983 .4594 .30073 .47211 .29597 .46474 .29503 Metetra
.338 .81 .909 r
.46474 .29503 .47211 .29597 .48485 .2935 .47754 .29255 Metetra
.1 .651 .812 r
.47754 .29255 .48485 .2935 .49765 .2933 .4904 .29237 Metetra
.13 0 0 r
.4904 .29237 .49765 .2933 .51053 .29532 .50334 .29444 Metetra
.314 0 0 r
.50334 .29444 .51053 .29532 .52353 .29947 .51639 .29866 Metetra
.449 0 0 r
.51639 .29866 .52353 .29947 .53667 .30564 .52958 .30492 Metetra
.542 0 0 r
.52958 .30492 .53667 .30564 .54997 .31367 .54293 .31306 Metetra
.605 .035 0 r
.54293 .31306 .54997 .31367 .56347 .32337 .55648 .32289 Metetra
.648 .09 0 r
.55648 .32289 .56347 .32337 .57719 .33454 .57024 .33419 Metetra
.676 .127 0 r
.57024 .33419 .57719 .33454 .59113 .34693 .58422 .34671 Metetra
.693 .151 0 r
.58422 .34671 .59113 .34693 .60531 .36026 .59845 .36017 Metetra
.702 .164 0 r
.59845 .36017 .60531 .36026 .61973 .37424 .61293 .37427 Metetra
.703 .166 0 r
.61293 .37427 .61973 .37424 .63441 .38854 .62765 .38868 Metetra
.698 .159 0 r
.62765 .38868 .63441 .38854 .64932 .40283 .64261 .40307 Metetra
.686 .142 0 r
.64261 .40307 .64932 .40283 .66446 .41679 .65781 .4171 Metetra
.608 .039 0 r
.65781 .4171 .66446 .41679 .67981 .43009 .67312 .42808 Metetra
.51 .892 .961 r
.67312 .42808 .67981 .43009 .69481 .43201 .68786 .42341 Metetra
.646 .762 .934 r
.68786 .42341 .69481 .43201 .70958 .42736 .70267 .41871 Metetra
.646 .762 .934 r
.70267 .41871 .70958 .42736 .72442 .42269 .71757 .41399 Metetra
.646 .762 .934 r
.71757 .41399 .72442 .42269 .73934 .41799 .73254 .40925 Metetra
.646 .762 .934 r
.73254 .40925 .73934 .41799 .75433 .41326 .74759 .40448 Metetra
.646 .762 .934 r
.74759 .40448 .75433 .41326 .76941 .40852 .76273 .39968 Metetra
.646 .762 .934 r
.76273 .39968 .76941 .40852 .78456 .40374 .77794 .39486 Metetra
.646 .762 .934 r
.77794 .39486 .78456 .40374 .7998 .39894 .79323 .39002 Metetra
.646 .762 .934 r
.79323 .39002 .7998 .39894 .81512 .39412 .8086 .38515 Metetra
.646 .762 .934 r
.13177 .58976 .1405 .59684 .15259 .59301 .14389 .58589 Metetra
.646 .762 .934 r
.14389 .58589 .15259 .59301 .16474 .58916 .15607 .58201 Metetra
.646 .762 .934 r
.15607 .58201 .16474 .58916 .17694 .5853 .1683 .57811 Metetra
.646 .762 .934 r
.1683 .57811 .17694 .5853 .1892 .58141 .1806 .57419 Metetra
.646 .762 .934 r
.1806 .57419 .1892 .58141 .20152 .57751 .19295 .57025 Metetra
.646 .762 .934 r
.19295 .57025 .20152 .57751 .2139 .57358 .20536 .56629 Metetra
.646 .762 .934 r
.20536 .56629 .2139 .57358 .22634 .56964 .21784 .56232 Metetra
.646 .762 .934 r
.21784 .56232 .22634 .56964 .23883 .56568 .23037 .55832 Metetra
.646 .762 .934 r
.23037 .55832 .23883 .56568 .25139 .5617 .24296 .55431 Metetra
.696 .774 .912 r
.24296 .55431 .25139 .5617 .26484 .54692 .25575 .54866 Metetra
.945 .919 .755 r
.25575 .54866 .26484 .54692 .2788 .52494 .26983 .52665 Metetra
.948 .916 .749 r
.26983 .52665 .2788 .52494 .29273 .50244 .28387 .50408 Metetra
.95 .915 .745 r
.28387 .50408 .29273 .50244 .30659 .47974 .29785 .48131 Metetra
.95 .916 .744 r
.29785 .48131 .30659 .47974 .32036 .45718 .31175 .45864 Metetra
.949 .919 .747 r
.31175 .45864 .32036 .45718 .33403 .43508 .32554 .43642 Metetra
.947 .925 .753 r
.32554 .43642 .33403 .43508 .34757 .41375 .3392 .41497 Metetra
.942 .932 .762 r
.3392 .41497 .34757 .41375 .36099 .39349 .35274 .39457 Metetra
.934 .942 .775 r
.35274 .39457 .36099 .39349 .37428 .37455 .36615 .37549 Metetra
.922 .954 .792 r
.36615 .37549 .37428 .37455 .38746 .35717 .37943 .35799 Metetra
.903 .967 .813 r
.37943 .35799 .38746 .35717 .40051 .34156 .39259 .34226 Metetra
.874 .98 .839 r
.39259 .34226 .40051 .34156 .41347 .3279 .40564 .32849 Metetra
.827 .99 .867 r
.40564 .32849 .41347 .3279 .42635 .31633 .41862 .31683 Metetra
.751 .989 .893 r
.41862 .31683 .42635 .31633 .43917 .30694 .43152 .30737 Metetra
.632 .961 .904 r
.43152 .30737 .43917 .30694 .45196 .29983 .44439 .3002 Metetra
.457 .886 .881 r
.44439 .3002 .45196 .29983 .46474 .29503 .45725 .29537 Metetra
.231 .75 .806 r
.45725 .29537 .46474 .29503 .47754 .29255 .47012 .29288 Metetra
.009 0 0 r
.47012 .29288 .47754 .29255 .4904 .29237 .48304 .2927 Metetra
.219 0 0 r
.48304 .2927 .4904 .29237 .50334 .29444 .49604 .2948 Metetra
.38 0 0 r
.49604 .2948 .50334 .29444 .51639 .29866 .50914 .29906 Metetra
.493 0 0 r
.50914 .29906 .51639 .29866 .52958 .30492 .52239 .30537 Metetra
.572 0 0 r
.52239 .30537 .52958 .30492 .54293 .31306 .53579 .31358 Metetra
.625 .066 0 r
.53579 .31358 .54293 .31306 .55648 .32289 .54939 .32348 Metetra
.662 .114 0 r
.54939 .32348 .55648 .32289 .57024 .33419 .5632 .33486 Metetra
.686 .146 0 r
.5632 .33486 .57024 .33419 .58422 .34671 .57723 .34745 Metetra
.701 .167 0 r
.57723 .34745 .58422 .34671 .59845 .36017 .59151 .36098 Metetra
.708 .177 0 r
.59151 .36098 .59845 .36017 .61293 .37427 .60604 .37513 Metetra
.708 .177 0 r
.60604 .37513 .61293 .37427 .62765 .38868 .62081 .38958 Metetra
.703 .168 0 r
.62081 .38958 .62765 .38868 .64261 .40307 .63583 .40398 Metetra
.69 .151 0 r
.63583 .40398 .64261 .40307 .65781 .4171 .65108 .418 Metetra
.171 0 0 r
.65108 .418 .65781 .4171 .67312 .42808 .66604 .41944 Metetra
.646 .762 .934 r
.66604 .41944 .67312 .42808 .68786 .42341 .68083 .41472 Metetra
.646 .762 .934 r
.68083 .41472 .68786 .42341 .70267 .41871 .6957 .40998 Metetra
.646 .762 .934 r
.6957 .40998 .70267 .41871 .71757 .41399 .71065 .40521 Metetra
.646 .762 .934 r
.71065 .40521 .71757 .41399 .73254 .40925 .72568 .40042 Metetra
.646 .762 .934 r
.72568 .40042 .73254 .40925 .74759 .40448 .74079 .39561 Metetra
.646 .762 .934 r
.74079 .39561 .74759 .40448 .76273 .39968 .75598 .39076 Metetra
.646 .762 .934 r
.75598 .39076 .76273 .39968 .77794 .39486 .77124 .3859 Metetra
.646 .762 .934 r
.77124 .3859 .77794 .39486 .79323 .39002 .7866 .381 Metetra
.646 .762 .934 r
.7866 .381 .79323 .39002 .8086 .38515 .80203 .37608 Metetra
.646 .762 .934 r
.12296 .58261 .13177 .58976 .14389 .58589 .13511 .57871 Metetra
.646 .762 .934 r
.13511 .57871 .14389 .58589 .15607 .58201 .14732 .57479 Metetra
.646 .762 .934 r
.14732 .57479 .15607 .58201 .1683 .57811 .15959 .57086 Metetra
.646 .762 .934 r
.15959 .57086 .1683 .57811 .1806 .57419 .17192 .5669 Metetra
.646 .762 .934 r
.17192 .5669 .1806 .57419 .19295 .57025 .18431 .56293 Metetra
.646 .762 .934 r
.18431 .56293 .19295 .57025 .20536 .56629 .19675 .55894 Metetra
.646 .762 .934 r
.19675 .55894 .20536 .56629 .21784 .56232 .20926 .55493 Metetra
.646 .762 .934 r
.20926 .55493 .21784 .56232 .23037 .55832 .22183 .5509 Metetra
.646 .762 .934 r
.22183 .5509 .23037 .55832 .24296 .55431 .23446 .54684 Metetra
.646 .762 .934 r
.23446 .54684 .24296 .55431 .25575 .54866 .24715 .54277 Metetra
.844 .818 .823 r
.24715 .54277 .25575 .54866 .26983 .52665 .26067 .52891 Metetra
.949 .925 .748 r
.26067 .52891 .26983 .52665 .28387 .50408 .27484 .50637 Metetra
.951 .925 .744 r
.27484 .50637 .28387 .50408 .29785 .48131 .28894 .48358 Metetra
.951 .927 .743 r
.28894 .48358 .29785 .48131 .31175 .45864 .30296 .46089 Metetra
.95 .932 .744 r
.30296 .46089 .31175 .45864 .32554 .43642 .31687 .43862 Metetra
.947 .938 .749 r
.31687 .43862 .32554 .43642 .3392 .41497 .33066 .4171 Metetra
.941 .947 .757 r
.33066 .4171 .3392 .41497 .35274 .39457 .34432 .39663 Metetra
.932 .957 .769 r
.34432 .39663 .35274 .39457 .36615 .37549 .35784 .37747 Metetra
.918 .97 .784 r
.35784 .37747 .36615 .37549 .37943 .35799 .37123 .35989 Metetra
.894 .983 .803 r
.37123 .35989 .37943 .35799 .39259 .34226 .3845 .34408 Metetra
.857 .995 .824 r
.3845 .34408 .39259 .34226 .40564 .32849 .39766 .33023 Metetra
.798 .999 .844 r
.39766 .33023 .40564 .32849 .41862 .31683 .41073 .3185 Metetra
.705 .985 .855 r
.41073 .3185 .41862 .31683 .43152 .30737 .42372 .30899 Metetra
.561 .935 .843 r
.42372 .30899 .43152 .30737 .44439 .3002 .43668 .30177 Metetra
.363 .832 .789 r
.43668 .30177 .44439 .3002 .45725 .29537 .44961 .29691 Metetra
.44961 .29691 .45725 .29537 .47012 .29288 .46256 .29439 Metetra
.097 0 0 r
.46256 .29439 .47012 .29288 .48304 .2927 .47555 .29421 Metetra
.283 0 0 r
.47555 .29421 .48304 .2927 .49604 .2948 .48862 .29631 Metetra
.422 0 0 r
.48862 .29631 .49604 .2948 .50914 .29906 .50178 .30059 Metetra
.52 0 0 r
.50178 .30059 .50914 .29906 .52239 .30537 .51509 .30692 Metetra
.588 .028 0 r
.51509 .30692 .52239 .30537 .53579 .31358 .52855 .31515 Metetra
.636 .088 0 r
.52855 .31515 .53579 .31358 .54939 .32348 .5422 .32508 Metetra
.668 .13 0 r
.5422 .32508 .54939 .32348 .5632 .33486 .55606 .33647 Metetra
.69 .159 0 r
.55606 .33647 .5632 .33486 .57723 .34745 .57015 .34908 Metetra
.703 .176 0 r
.57015 .34908 .57723 .34745 .59151 .36098 .58448 .3626 Metetra
.709 .184 0 r
.58448 .3626 .59151 .36098 .60604 .37513 .59906 .37673 Metetra
.709 .183 0 r
.59906 .37673 .60604 .37513 .62081 .38958 .61389 .39114 Metetra
.703 .173 0 r
.61389 .39114 .62081 .38958 .63583 .40398 .62896 .40547 Metetra
.599 .035 0 r
.62896 .40547 .63583 .40398 .65108 .418 .64413 .41545 Metetra
.537 .894 .976 r
.64413 .41545 .65108 .418 .66604 .41944 .65889 .41071 Metetra
.646 .762 .934 r
.65889 .41071 .66604 .41944 .68083 .41472 .67374 .40595 Metetra
.646 .762 .934 r
.67374 .40595 .68083 .41472 .6957 .40998 .68867 .40116 Metetra
.646 .762 .934 r
.68867 .40116 .6957 .40998 .71065 .40521 .70367 .39635 Metetra
.646 .762 .934 r
.70367 .39635 .71065 .40521 .72568 .40042 .71875 .39151 Metetra
.646 .762 .934 r
.71875 .39151 .72568 .40042 .74079 .39561 .73392 .38665 Metetra
.646 .762 .934 r
.73392 .38665 .74079 .39561 .75598 .39076 .74916 .38176 Metetra
.646 .762 .934 r
.74916 .38176 .75598 .39076 .77124 .3859 .76449 .37684 Metetra
.646 .762 .934 r
.76449 .37684 .77124 .3859 .7866 .381 .77989 .3719 Metetra
.646 .762 .934 r
.77989 .3719 .7866 .381 .80203 .37608 .79539 .36693 Metetra
.646 .762 .934 r
.11407 .5754 .12296 .58261 .13511 .57871 .12625 .57146 Metetra
.646 .762 .934 r
.12625 .57146 .13511 .57871 .14732 .57479 .1385 .56751 Metetra
.646 .762 .934 r
.1385 .56751 .14732 .57479 .15959 .57086 .1508 .56354 Metetra
.646 .762 .934 r
.1508 .56354 .15959 .57086 .17192 .5669 .16316 .55955 Metetra
.646 .762 .934 r
.16316 .55955 .17192 .5669 .18431 .56293 .17558 .55554 Metetra
.646 .762 .934 r
.17558 .55554 .18431 .56293 .19675 .55894 .18807 .55152 Metetra
.646 .762 .934 r
.18807 .55152 .19675 .55894 .20926 .55493 .20061 .54747 Metetra
.646 .762 .934 r
.20061 .54747 .20926 .55493 .22183 .5509 .21321 .5434 Metetra
.646 .762 .934 r
.21321 .5434 .22183 .5509 .23446 .54684 .22588 .53931 Metetra
.646 .762 .934 r
.22588 .53931 .23446 .54684 .24715 .54277 .23861 .53521 Metetra
.646 .762 .934 r
.23861 .53521 .24715 .54277 .26067 .52891 .25139 .53108 Metetra
.945 .93 .756 r
.25139 .53108 .26067 .52891 .27484 .50637 .26563 .50919 Metetra
.95 .934 .743 r
.26563 .50919 .27484 .50637 .28894 .48358 .27985 .48647 Metetra
.95 .937 .741 r
.27985 .48647 .28894 .48358 .30296 .46089 .29399 .46383 Metetra
.949 .942 .742 r
.29399 .46383 .30296 .46089 .31687 .43862 .30802 .44158 Metetra
.945 .949 .746 r
.30802 .44158 .31687 .43862 .33066 .4171 .32193 .42006 Metetra
.938 .958 .752 r
.32193 .42006 .33066 .4171 .34432 .39663 .33571 .39957 Metetra
.927 .969 .761 r
.33571 .39957 .34432 .39663 .35784 .37747 .34935 .38039 Metetra
.908 .981 .774 r
.34935 .38039 .35784 .37747 .37123 .35989 .36286 .36277 Metetra
.879 .993 .788 r
.36286 .36277 .37123 .35989 .3845 .34408 .37624 .34692 Metetra
.833 .999 .802 r
.37624 .34692 .3845 .34408 .39766 .33023 .38951 .33303 Metetra
.76 .994 .81 r
.38951 .33303 .39766 .33023 .41073 .3185 .40268 .32125 Metetra
.647 .964 .803 r
.40268 .32125 .41073 .3185 .42372 .30899 .41577 .3117 Metetra
.483 .891 .767 r
.41577 .3117 .42372 .30899 .43668 .30177 .42881 .30445 Metetra
.273 .764 .69 r
.42881 .30445 .43668 .30177 .44961 .29691 .44184 .29955 Metetra
.44184 .29955 .44961 .29691 .46256 .29439 .45486 .29701 Metetra
.162 0 0 r
.45486 .29701 .46256 .29439 .47555 .29421 .46793 .29681 Metetra
.327 0 0 r
.46793 .29681 .47555 .29421 .48862 .29631 .48107 .29889 Metetra
.448 0 0 r
.48107 .29889 .48862 .29631 .50178 .30059 .4943 .30315 Metetra
.535 0 0 r
.4943 .30315 .50178 .30059 .51509 .30692 .50767 .30947 Metetra
.596 .048 0 r
.50767 .30947 .51509 .30692 .52855 .31515 .52119 .31768 Metetra
.639 .102 0 r
.52119 .31768 .52855 .31515 .5422 .32508 .5349 .32758 Metetra
.669 .14 0 r
.5349 .32758 .5422 .32508 .55606 .33647 .54882 .33894 Metetra
.69 .166 0 r
.54882 .33894 .55606 .33647 .57015 .34908 .56297 .35149 Metetra
.702 .181 0 r
.56297 .35149 .57015 .34908 .58448 .3626 .57735 .36494 Metetra
.708 .187 0 r
.57735 .36494 .58448 .3626 .59906 .37673 .59198 .37898 Metetra
.707 .185 0 r
.59198 .37898 .59906 .37673 .61389 .39114 .60687 .39326 Metetra
.701 .174 0 r
.60687 .39326 .61389 .39114 .62896 .40547 .622 .40745 Metetra
.075 0 0 r
.622 .40745 .62896 .40547 .64413 .41545 .63686 .40668 Metetra
.646 .762 .934 r
.63686 .40668 .64413 .41545 .65889 .41071 .65168 .4019 Metetra
.646 .762 .934 r
.65168 .4019 .65889 .41071 .67374 .40595 .66658 .39709 Metetra
.646 .762 .934 r
.66658 .39709 .67374 .40595 .68867 .40116 .68156 .39226 Metetra
.646 .762 .934 r
.68156 .39226 .68867 .40116 .70367 .39635 .69662 .3874 Metetra
.646 .762 .934 r
.69662 .3874 .70367 .39635 .71875 .39151 .71176 .38251 Metetra
.646 .762 .934 r
.71176 .38251 .71875 .39151 .73392 .38665 .72698 .3776 Metetra
.646 .762 .934 r
.72698 .3776 .73392 .38665 .74916 .38176 .74228 .37266 Metetra
.646 .762 .934 r
.74228 .37266 .74916 .38176 .76449 .37684 .75766 .3677 Metetra
.646 .762 .934 r
.75766 .3677 .76449 .37684 .77989 .3719 .77313 .36271 Metetra
.646 .762 .934 r
.77313 .36271 .77989 .3719 .79539 .36693 .78868 .35769 Metetra
.646 .762 .934 r
.1051 .56812 .11407 .5754 .12625 .57146 .11732 .56416 Metetra
.646 .762 .934 r
.11732 .56416 .12625 .57146 .1385 .56751 .1296 .56017 Metetra
.646 .762 .934 r
.1296 .56017 .1385 .56751 .1508 .56354 .14193 .55616 Metetra
.646 .762 .934 r
.14193 .55616 .1508 .56354 .16316 .55955 .15433 .55214 Metetra
.646 .762 .934 r
.15433 .55214 .16316 .55955 .17558 .55554 .16678 .54809 Metetra
.646 .762 .934 r
.16678 .54809 .17558 .55554 .18807 .55152 .1793 .54403 Metetra
.646 .762 .934 r
.1793 .54403 .18807 .55152 .20061 .54747 .19188 .53994 Metetra
.646 .762 .934 r
.19188 .53994 .20061 .54747 .21321 .5434 .20452 .53584 Metetra
.646 .762 .934 r
.20452 .53584 .21321 .5434 .22588 .53931 .21722 .53172 Metetra
.646 .762 .934 r
.21722 .53172 .22588 .53931 .23861 .53521 .22998 .52757 Metetra
.646 .762 .934 r
.22998 .52757 .23861 .53521 .25139 .53108 .24281 .52341 Metetra
.796 .787 .844 r
.24281 .52341 .25139 .53108 .26563 .50919 .25624 .51245 Metetra
.948 .942 .744 r
.25624 .51245 .26563 .50919 .27985 .48647 .27058 .48988 Metetra
.948 .945 .741 r
.27058 .48988 .27985 .48647 .29399 .46383 .28484 .46735 Metetra
.946 .951 .74 r
.28484 .46735 .29399 .46383 .30802 .44158 .29899 .4452 Metetra
.941 .958 .742 r
.29899 .4452 .30802 .44158 .32193 .42006 .31303 .42375 Metetra
.932 .967 .747 r
.31303 .42375 .32193 .42006 .33571 .39957 .32693 .4033 Metetra
.918 .978 .753 r
.32693 .4033 .33571 .39957 .34935 .38039 .34069 .38415 Metetra
.895 .988 .762 r
.34069 .38415 .34935 .38039 .36286 .36277 .35431 .36653 Metetra
.859 .996 .77 r
.35431 .36653 .36286 .36277 .37624 .34692 .36781 .35068 Metetra
.802 .996 .775 r
.36781 .35068 .37624 .34692 .38951 .33303 .38118 .33678 Metetra
.715 .979 .771 r
.38118 .33678 .38951 .33303 .40268 .32125 .39446 .32499 Metetra
.585 .931 .746 r
.39446 .32499 .40268 .32125 .41577 .3117 .40765 .31541 Metetra
.407 .837 .689 r
.40765 .31541 .41577 .3117 .42881 .30445 .42079 .30813 Metetra
.42079 .30813 .42881 .30445 .44184 .29955 .4339 .30321 Metetra
.021 0 0 r
.4339 .30321 .44184 .29955 .45486 .29701 .44702 .30064 Metetra
.208 0 0 r
.44702 .30064 .45486 .29701 .46793 .29681 .46016 .3004 Metetra
.355 0 0 r
.46016 .3004 .46793 .29681 .48107 .29889 .47338 .30244 Metetra
.464 0 0 r
.47338 .30244 .48107 .29889 .4943 .30315 .48668 .30666 Metetra
.542 0 0 r
.48668 .30666 .4943 .30315 .50767 .30947 .50012 .31292 Metetra
.598 .062 0 r
.50012 .31292 .50767 .30947 .52119 .31768 .51371 .32106 Metetra
.639 .111 0 r
.51371 .32106 .52119 .31768 .5349 .32758 .52748 .33088 Metetra
.667 .145 0 r
.52748 .33088 .5349 .32758 .54882 .33894 .54146 .34215 Metetra
.686 .169 0 r
.54146 .34215 .54882 .33894 .56297 .35149 .55567 .35458 Metetra
.698 .182 0 r
.55567 .35458 .56297 .35149 .57735 .36494 .57011 .36789 Metetra
.703 .187 0 r
.57011 .36789 .57735 .36494 .59198 .37898 .5848 .38176 Metetra
.703 .183 0 r
.5848 .38176 .59198 .37898 .60687 .39326 .59974 .39585 Metetra
.513 0 0 r
.59974 .39585 .60687 .39326 .622 .40745 .61473 .40264 Metetra
.609 .865 .991 r
.61473 .40264 .622 .40745 .63686 .40668 .62952 .39783 Metetra
.646 .762 .934 r
.62952 .39783 .63686 .40668 .65168 .4019 .6444 .393 Metetra
.646 .762 .934 r
.6444 .393 .65168 .4019 .66658 .39709 .65935 .38815 Metetra
.646 .762 .934 r
.65935 .38815 .66658 .39709 .68156 .39226 .67438 .38327 Metetra
.646 .762 .934 r
.67438 .38327 .68156 .39226 .69662 .3874 .68949 .37836 Metetra
.646 .762 .934 r
.68949 .37836 .69662 .3874 .71176 .38251 .70469 .37342 Metetra
.646 .762 .934 r
.70469 .37342 .71176 .38251 .72698 .3776 .71997 .36846 Metetra
.646 .762 .934 r
.71997 .36846 .72698 .3776 .74228 .37266 .73532 .36348 Metetra
.646 .762 .934 r
.73532 .36348 .74228 .37266 .75766 .3677 .75077 .35846 Metetra
.646 .762 .934 r
.75077 .35846 .75766 .3677 .77313 .36271 .76629 .35342 Metetra
.646 .762 .934 r
.76629 .35342 .77313 .36271 .78868 .35769 .7819 .34835 Metetra
.646 .762 .934 r
.09606 .56078 .1051 .56812 .11732 .56416 .10831 .55678 Metetra
.646 .762 .934 r
.10831 .55678 .11732 .56416 .1296 .56017 .12062 .55276 Metetra
.646 .762 .934 r
.12062 .55276 .1296 .56017 .14193 .55616 .13298 .54872 Metetra
.646 .762 .934 r
.13298 .54872 .14193 .55616 .15433 .55214 .14541 .54466 Metetra
.646 .762 .934 r
.14541 .54466 .15433 .55214 .16678 .54809 .1579 .54057 Metetra
.646 .762 .934 r
.1579 .54057 .16678 .54809 .1793 .54403 .17046 .53647 Metetra
.646 .762 .934 r
.17046 .53647 .1793 .54403 .19188 .53994 .18307 .53235 Metetra
.646 .762 .934 r
.18307 .53235 .19188 .53994 .20452 .53584 .19574 .52821 Metetra
.646 .762 .934 r
.19574 .52821 .20452 .53584 .21722 .53172 .20848 .52405 Metetra
.646 .762 .934 r
.20848 .52405 .21722 .53172 .22998 .52757 .22128 .51987 Metetra
.646 .762 .934 r
.22128 .51987 .22998 .52757 .24281 .52341 .23415 .51566 Metetra
.646 .762 .934 r
.23415 .51566 .24281 .52341 .25624 .51245 .24707 .51144 Metetra
.911 .909 .806 r
.24707 .51144 .25624 .51245 .27058 .48988 .26114 .49369 Metetra
.945 .952 .741 r
.26114 .49369 .27058 .48988 .28484 .46735 .27551 .47136 Metetra
.942 .958 .739 r
.27551 .47136 .28484 .46735 .29899 .4452 .28978 .44936 Metetra
.936 .966 .739 r
.28978 .44936 .29899 .4452 .31303 .42375 .30394 .42804 Metetra
.925 .974 .741 r
.30394 .42804 .31303 .42375 .32693 .4033 .31796 .4077 Metetra
.907 .984 .745 r
.31796 .4077 .32693 .4033 .34069 .38415 .33184 .38863 Metetra
.879 .991 .749 r
.33184 .38863 .34069 .38415 .35431 .36653 .34558 .37107 Metetra
.835 .994 .751 r
.34558 .37107 .35431 .36653 .36781 .35068 .35919 .35526 Metetra
.768 .986 .747 r
.35919 .35526 .36781 .35068 .38118 .33678 .37268 .34138 Metetra
.667 .956 .729 r
.37268 .34138 .38118 .33678 .39446 .32499 .38606 .32959 Metetra
.524 .891 .688 r
.38606 .32959 .39446 .32499 .40765 .31541 .39936 .32001 Metetra
.39936 .32001 .40765 .31541 .42079 .30813 .4126 .31271 Metetra
.4126 .31271 .42079 .30813 .4339 .30321 .42581 .30776 Metetra
.07 0 0 r
.42581 .30776 .4339 .30321 .44702 .30064 .43901 .30515 Metetra
.24 0 0 r
.43901 .30515 .44702 .30064 .46016 .3004 .45225 .30487 Metetra
.372 0 0 r
.45225 .30487 .46016 .3004 .47338 .30244 .46554 .30684 Metetra
.471 0 0 r
.46554 .30684 .47338 .30244 .48668 .30666 .47893 .31098 Metetra
.544 .007 0 r
.47893 .31098 .48668 .30666 .50012 .31292 .49244 .31716 Metetra
.597 .069 0 r
.49244 .31716 .50012 .31292 .51371 .32106 .5061 .32519 Metetra
.635 .114 0 r
.5061 .32519 .51371 .32106 .52748 .33088 .51994 .33488 Metetra
.662 .146 .001 r
.51994 .33488 .52748 .33088 .54146 .34215 .53398 .34599 Metetra
.681 .167 .009 r
.53398 .34599 .54146 .34215 .55567 .35458 .54825 .35824 Metetra
.692 .179 .009 r
.54825 .35824 .55567 .35458 .57011 .36789 .56275 .37134 Metetra
.697 .183 .002 r
.56275 .37134 .57011 .36789 .5848 .38176 .5775 .38497 Metetra
.693 .173 0 r
.5775 .38497 .5848 .38176 .59974 .39585 .59249 .39857 Metetra
.59249 .39857 .59974 .39585 .61473 .40264 .60726 .39375 Metetra
.646 .762 .934 r
.60726 .39375 .61473 .40264 .62952 .39783 .62211 .3889 Metetra
.646 .762 .934 r
.62211 .3889 .62952 .39783 .6444 .393 .63704 .38402 Metetra
.646 .762 .934 r
.63704 .38402 .6444 .393 .65935 .38815 .65205 .37911 Metetra
.646 .762 .934 r
.65205 .37911 .65935 .38815 .67438 .38327 .66713 .37418 Metetra
.646 .762 .934 r
.66713 .37418 .67438 .38327 .68949 .37836 .6823 .36923 Metetra
.646 .762 .934 r
.6823 .36923 .68949 .37836 .70469 .37342 .69755 .36424 Metetra
.646 .762 .934 r
.69755 .36424 .70469 .37342 .71997 .36846 .71289 .35923 Metetra
.646 .762 .934 r
.71289 .35923 .71997 .36846 .73532 .36348 .7283 .3542 Metetra
.646 .762 .934 r
.7283 .3542 .73532 .36348 .75077 .35846 .7438 .34913 Metetra
.646 .762 .934 r
.7438 .34913 .75077 .35846 .76629 .35342 .75939 .34404 Metetra
.646 .762 .934 r
.75939 .34404 .76629 .35342 .7819 .34835 .77506 .33892 Metetra
.646 .762 .934 r
.08693 .55338 .09606 .56078 .10831 .55678 .09921 .54934 Metetra
.646 .762 .934 r
.09921 .54934 .10831 .55678 .12062 .55276 .11155 .54528 Metetra
.646 .762 .934 r
.11155 .54528 .12062 .55276 .13298 .54872 .12396 .5412 Metetra
.646 .762 .934 r
.12396 .5412 .13298 .54872 .14541 .54466 .13642 .53711 Metetra
.646 .762 .934 r
.13642 .53711 .14541 .54466 .1579 .54057 .14894 .53299 Metetra
.646 .762 .934 r
.14894 .53299 .1579 .54057 .17046 .53647 .16153 .52885 Metetra
.646 .762 .934 r
.16153 .52885 .17046 .53647 .18307 .53235 .17418 .52469 Metetra
.646 .762 .934 r
.17418 .52469 .18307 .53235 .19574 .52821 .18689 .52051 Metetra
.646 .762 .934 r
.18689 .52051 .19574 .52821 .20848 .52405 .19966 .51631 Metetra
.646 .762 .934 r
.19966 .51631 .20848 .52405 .22128 .51987 .2125 .51209 Metetra
.646 .762 .934 r
.2125 .51209 .22128 .51987 .23415 .51566 .2254 .50785 Metetra
.646 .762 .934 r
.2254 .50785 .23415 .51566 .24707 .51144 .23837 .50358 Metetra
.693 .774 .914 r
.23837 .50358 .24707 .51144 .26114 .49369 .25152 .49779 Metetra
.941 .958 .742 r
.25152 .49779 .26114 .49369 .27551 .47136 .26601 .47571 Metetra
.937 .964 .739 r
.26601 .47571 .27551 .47136 .28978 .44936 .28039 .45395 Metetra
.93 .971 .738 r
.28039 .45395 .28978 .44936 .30394 .42804 .29466 .43283 Metetra
.916 .979 .737 r
.29466 .43283 .30394 .42804 .31796 .4077 .3088 .41266 Metetra
.895 .987 .738 r
.3088 .41266 .31796 .4077 .33184 .38863 .3228 .39371 Metetra
.862 .992 .737 r
.3228 .39371 .33184 .38863 .34558 .37107 .33667 .37626 Metetra
.81 .989 .733 r
.33667 .37626 .34558 .37107 .35919 .35526 .35039 .36053 Metetra
.733 .972 .719 r
.35039 .36053 .35919 .35526 .37268 .34138 .364 .34671 Metetra
.621 .93 .69 r
.364 .34671 .37268 .34138 .38606 .32959 .37749 .33495 Metetra
.469 .852 .636 r
.37749 .33495 .38606 .32959 .39936 .32001 .3909 .32537 Metetra
.3909 .32537 .39936 .32001 .4126 .31271 .40424 .31807 Metetra
.40424 .31807 .4126 .31271 .42581 .30776 .41755 .31309 Metetra
.104 0 0 r
.41755 .31309 .42581 .30776 .43901 .30515 .43085 .31044 Metetra
.26 0 0 r
.43085 .31044 .43901 .30515 .45225 .30487 .44417 .31009 Metetra
.382 0 0 r
.44417 .31009 .45225 .30487 .46554 .30684 .45755 .31198 Metetra
.474 0 0 r
.45755 .31198 .46554 .30684 .47893 .31098 .47102 .31602 Metetra
.542 .014 0 r
.47102 .31602 .47893 .31098 .49244 .31716 .48461 .32206 Metetra
.593 .071 0 r
.48461 .32206 .49244 .31716 .5061 .32519 .49834 .32994 Metetra
.629 .113 0 r
.49834 .32994 .5061 .32519 .51994 .33488 .51226 .33945 Metetra
.656 .143 .012 r
.51226 .33945 .51994 .33488 .53398 .34599 .52637 .35034 Metetra
.674 .163 .017 r
.52637 .35034 .53398 .34599 .54825 .35824 .5407 .36235 Metetra
.685 .173 .014 r
.5407 .36235 .54825 .35824 .56275 .37134 .55526 .37516 Metetra
.69 .175 .005 r
.55526 .37516 .56275 .37134 .5775 .38497 .57007 .38847 Metetra
.273 0 0 r
.57007 .38847 .5775 .38497 .59249 .39857 .5849 .38964 Metetra
.646 .762 .934 r
.5849 .38964 .59249 .39857 .60726 .39375 .59973 .38477 Metetra
.646 .762 .934 r
.59973 .38477 .60726 .39375 .62211 .3889 .61463 .37987 Metetra
.646 .762 .934 r
.61463 .37987 .62211 .3889 .63704 .38402 .62961 .37494 Metetra
.646 .762 .934 r
.62961 .37494 .63704 .38402 .65205 .37911 .64467 .36999 Metetra
.646 .762 .934 r
.64467 .36999 .65205 .37911 .66713 .37418 .65981 .36501 Metetra
.646 .762 .934 r
.65981 .36501 .66713 .37418 .6823 .36923 .67504 .36001 Metetra
.646 .762 .934 r
.67504 .36001 .6823 .36923 .69755 .36424 .69035 .35497 Metetra
.646 .762 .934 r
.69035 .35497 .69755 .36424 .71289 .35923 .70574 .34991 Metetra
.646 .762 .934 r
.70574 .34991 .71289 .35923 .7283 .3542 .72121 .34483 Metetra
.646 .762 .934 r
.72121 .34483 .7283 .3542 .7438 .34913 .73677 .33971 Metetra
.646 .762 .934 r
.73677 .33971 .7438 .34913 .75939 .34404 .75241 .33457 Metetra
.646 .762 .934 r
.75241 .33457 .75939 .34404 .77506 .33892 .76814 .32939 Metetra
.646 .762 .934 r
.07772 .54591 .08693 .55338 .09921 .54934 .09003 .54183 Metetra
.646 .762 .934 r
.09003 .54183 .09921 .54934 .11155 .54528 .10241 .53774 Metetra
.646 .762 .934 r
.10241 .53774 .11155 .54528 .12396 .5412 .11485 .53362 Metetra
.646 .762 .934 r
.11485 .53362 .12396 .5412 .13642 .53711 .12734 .52949 Metetra
.646 .762 .934 r
.12734 .52949 .13642 .53711 .14894 .53299 .1399 .52533 Metetra
.646 .762 .934 r
.1399 .52533 .14894 .53299 .16153 .52885 .15252 .52115 Metetra
.646 .762 .934 r
.15252 .52115 .16153 .52885 .17418 .52469 .16521 .51696 Metetra
.646 .762 .934 r
.16521 .51696 .17418 .52469 .18689 .52051 .17795 .51274 Metetra
.646 .762 .934 r
.17795 .51274 .18689 .52051 .19966 .51631 .19076 .5085 Metetra
.646 .762 .934 r
.19076 .5085 .19966 .51631 .2125 .51209 .20364 .50424 Metetra
.646 .762 .934 r
.20364 .50424 .2125 .51209 .2254 .50785 .21658 .49996 Metetra
.646 .762 .934 r
.21658 .49996 .2254 .50785 .23837 .50358 .22958 .49566 Metetra
.646 .762 .934 r
.22958 .49566 .23837 .50358 .25152 .49779 .24265 .49133 Metetra
.807 .823 .864 r
.24265 .49133 .25152 .49779 .26601 .47571 .25633 .4803 Metetra
.932 .969 .741 r
.25633 .4803 .26601 .47571 .28039 .45395 .27082 .45884 Metetra
.923 .976 .738 r
.27082 .45884 .28039 .45395 .29466 .43283 .28521 .43798 Metetra
.907 .983 .735 r
.28521 .43798 .29466 .43283 .3088 .41266 .29947 .41803 Metetra
.882 .989 .732 r
.29947 .41803 .3088 .41266 .3228 .39371 .31358 .39928 Metetra
.844 .99 .727 r
.31358 .39928 .3228 .39371 .33667 .37626 .32757 .38198 Metetra
.786 .982 .717 r
.32757 .38198 .33667 .37626 .35039 .36053 .34141 .36636 Metetra
.701 .957 .695 r
.34141 .36636 .35039 .36053 .364 .34671 .35513 .35263 Metetra
.58 .905 .656 r
.35513 .35263 .364 .34671 .37749 .33495 .36874 .34092 Metetra
.423 .817 .594 r
.36874 .34092 .37749 .33495 .3909 .32537 .38226 .33138 Metetra
.38226 .33138 .3909 .32537 .40424 .31807 .39571 .32408 Metetra
.39571 .32408 .40424 .31807 .41755 .31309 .40912 .31907 Metetra
.127 0 0 r
.40912 .31907 .41755 .31309 .43085 .31044 .42252 .31637 Metetra
.272 0 0 r
.42252 .31637 .43085 .31044 .44417 .31009 .43594 .31594 Metetra
.386 0 0 r
.43594 .31594 .44417 .31009 .45755 .31198 .44941 .31772 Metetra
.473 0 0 r
.44941 .31772 .45755 .31198 .47102 .31602 .46296 .32162 Metetra
.538 .015 0 r
.46296 .32162 .47102 .31602 .48461 .32206 .47663 .3275 Metetra
.586 .069 0 r
.47663 .3275 .48461 .32206 .49834 .32994 .49044 .33518 Metetra
.622 .109 .006 r
.49044 .33518 .49834 .32994 .51226 .33945 .50443 .34445 Metetra
.648 .137 .016 r
.50443 .34445 .51226 .33945 .52637 .35034 .51861 .35507 Metetra
.665 .155 .019 r
.51861 .35507 .52637 .35034 .5407 .36235 .53301 .36676 Metetra
.676 .164 .014 r
.53301 .36676 .5407 .36235 .55526 .37516 .54765 .37923 Metetra
.516 0 0 r
.54765 .37923 .55526 .37516 .57007 .38847 .56244 .38552 Metetra
.557 .894 .983 r
.56244 .38552 .57007 .38847 .5849 .38964 .57724 .38063 Metetra
.646 .762 .934 r
.57724 .38063 .5849 .38964 .59973 .38477 .59211 .3757 Metetra
.646 .762 .934 r
.59211 .3757 .59973 .38477 .61463 .37987 .60707 .37076 Metetra
.646 .762 .934 r
.60707 .37076 .61463 .37987 .62961 .37494 .6221 .36578 Metetra
.646 .762 .934 r
.6221 .36578 .62961 .37494 .64467 .36999 .63722 .36078 Metetra
.646 .762 .934 r
.63722 .36078 .64467 .36999 .65981 .36501 .65242 .35575 Metetra
.646 .762 .934 r
.65242 .35575 .65981 .36501 .67504 .36001 .6677 .35069 Metetra
.646 .762 .934 r
.6677 .35069 .67504 .36001 .69035 .35497 .68307 .34561 Metetra
.646 .762 .934 r
.68307 .34561 .69035 .35497 .70574 .34991 .69851 .3405 Metetra
.646 .762 .934 r
.69851 .3405 .70574 .34991 .72121 .34483 .71405 .33536 Metetra
.646 .762 .934 r
.71405 .33536 .72121 .34483 .73677 .33971 .72967 .33019 Metetra
.646 .762 .934 r
.72967 .33019 .73677 .33971 .75241 .33457 .74537 .325 Metetra
.646 .762 .934 r
.74537 .325 .75241 .33457 .76814 .32939 .76116 .31977 Metetra
.646 .762 .934 r
.06842 .53837 .07772 .54591 .09003 .54183 .08077 .53426 Metetra
.646 .762 .934 r
.08077 .53426 .09003 .54183 .10241 .53774 .09318 .53012 Metetra
.646 .762 .934 r
.09318 .53012 .10241 .53774 .11485 .53362 .10565 .52597 Metetra
.646 .762 .934 r
.10565 .52597 .11485 .53362 .12734 .52949 .11819 .5218 Metetra
.646 .762 .934 r
.11819 .5218 .12734 .52949 .1399 .52533 .13078 .51761 Metetra
.646 .762 .934 r
.13078 .51761 .1399 .52533 .15252 .52115 .14344 .51339 Metetra
.646 .762 .934 r
.14344 .51339 .15252 .52115 .16521 .51696 .15616 .50916 Metetra
.646 .762 .934 r
.15616 .50916 .16521 .51696 .17795 .51274 .16894 .5049 Metetra
.646 .762 .934 r
.16894 .5049 .17795 .51274 .19076 .5085 .18178 .50062 Metetra
.646 .762 .934 r
.18178 .50062 .19076 .5085 .20364 .50424 .1947 .49632 Metetra
.646 .762 .934 r
.1947 .49632 .20364 .50424 .21658 .49996 .20767 .492 Metetra
.646 .762 .934 r
.20767 .492 .21658 .49996 .22958 .49566 .22071 .48766 Metetra
.646 .762 .934 r
.22071 .48766 .22958 .49566 .24265 .49133 .23382 .48329 Metetra
.646 .762 .934 r
.23382 .48329 .24265 .49133 .25633 .4803 .24699 .47891 Metetra
.884 .927 .845 r
.24699 .47891 .25633 .4803 .27082 .45884 .26108 .46389 Metetra
.916 .98 .74 r
.26108 .46389 .27082 .45884 .28521 .43798 .27558 .44336 Metetra
.898 .986 .735 r
.27558 .44336 .28521 .43798 .29947 .41803 .28995 .42369 Metetra
.87 .99 .729 r
.28995 .42369 .29947 .41803 .31358 .39928 .30418 .40518 Metetra
.827 .988 .721 r
.30418 .40518 .31358 .39928 .32757 .38198 .31828 .38808 Metetra
.764 .975 .705 r
.31828 .38808 .32757 .38198 .34141 .36636 .33224 .37262 Metetra
.672 .943 .676 r
.33224 .37262 .34141 .36636 .35513 .35263 .34608 .35901 Metetra
.546 .883 .63 r
.34608 .35901 .35513 .35263 .36874 .34092 .3598 .34739 Metetra
.3598 .34739 .36874 .34092 .38226 .33138 .37344 .33789 Metetra
.37344 .33789 .38226 .33138 .39571 .32408 .387 .3306 Metetra
.387 .3306 .39571 .32408 .40912 .31907 .40051 .32557 Metetra
.141 0 0 r
.40051 .32557 .40912 .31907 .42252 .31637 .41401 .3228 Metetra
.277 0 0 r
.41401 .3228 .42252 .31637 .43594 .31594 .42753 .32228 Metetra
.385 0 0 r
.42753 .32228 .43594 .31594 .44941 .31772 .4411 .32393 Metetra
.468 0 0 r
.4411 .32393 .44941 .31772 .46296 .32162 .45474 .32767 Metetra
.531 .011 0 r
.45474 .32767 .46296 .32162 .47663 .3275 .4685 .33333 Metetra
.578 .062 0 r
.4685 .33333 .47663 .3275 .49044 .33518 .48239 .34077 Metetra
.613 .1 .006 r
.48239 .34077 .49044 .33518 .50443 .34445 .49646 .34975 Metetra
.638 .127 .014 r
.49646 .34975 .50443 .34445 .51861 .35507 .51072 .36004 Metetra
.656 .144 .015 r
.51072 .36004 .51861 .35507 .53301 .36676 .52519 .37136 Metetra
.624 .099 0 r
.52519 .37136 .53301 .36676 .54765 .37923 .53988 .38138 Metetra
.255 .756 .708 r
.53988 .38138 .54765 .37923 .56244 .38552 .55465 .37646 Metetra
.646 .762 .934 r
.55465 .37646 .56244 .38552 .57724 .38063 .5695 .37152 Metetra
.646 .762 .934 r
.5695 .37152 .57724 .38063 .59211 .3757 .58443 .36655 Metetra
.646 .762 .934 r
.58443 .36655 .59211 .3757 .60707 .37076 .59944 .36155 Metetra
.646 .762 .934 r
.59944 .36155 .60707 .37076 .6221 .36578 .61453 .35653 Metetra
.646 .762 .934 r
.61453 .35653 .6221 .36578 .63722 .36078 .6297 .35147 Metetra
.646 .762 .934 r
.6297 .35147 .63722 .36078 .65242 .35575 .64495 .34639 Metetra
.646 .762 .934 r
.64495 .34639 .65242 .35575 .6677 .35069 .66029 .34129 Metetra
.646 .762 .934 r
.66029 .34129 .6677 .35069 .68307 .34561 .67571 .33615 Metetra
.646 .762 .934 r
.67571 .33615 .68307 .34561 .69851 .3405 .69122 .33099 Metetra
.646 .762 .934 r
.69122 .33099 .69851 .3405 .71405 .33536 .70681 .3258 Metetra
.646 .762 .934 r
.70681 .3258 .71405 .33536 .72967 .33019 .72249 .32058 Metetra
.646 .762 .934 r
.72249 .32058 .72967 .33019 .74537 .325 .73825 .31533 Metetra
.646 .762 .934 r
.73825 .31533 .74537 .325 .76116 .31977 .7541 .31005 Metetra
.646 .762 .934 r
.05905 .53076 .06842 .53837 .08077 .53426 .07143 .52661 Metetra
.646 .762 .934 r
.07143 .52661 .08077 .53426 .09318 .53012 .08387 .52244 Metetra
.646 .762 .934 r
.08387 .52244 .09318 .53012 .10565 .52597 .09638 .51825 Metetra
.646 .762 .934 r
.09638 .51825 .10565 .52597 .11819 .5218 .10894 .51404 Metetra
.646 .762 .934 r
.10894 .51404 .11819 .5218 .13078 .51761 .12157 .50981 Metetra
.646 .762 .934 r
.12157 .50981 .13078 .51761 .14344 .51339 .13426 .50556 Metetra
.646 .762 .934 r
.13426 .50556 .14344 .51339 .15616 .50916 .14702 .50128 Metetra
.646 .762 .934 r
.14702 .50128 .15616 .50916 .16894 .5049 .15984 .49698 Metetra
.646 .762 .934 r
.15984 .49698 .16894 .5049 .18178 .50062 .17272 .49267 Metetra
.646 .762 .934 r
.17272 .49267 .18178 .50062 .1947 .49632 .18567 .48833 Metetra
.646 .762 .934 r
.18567 .48833 .1947 .49632 .20767 .492 .19868 .48397 Metetra
.646 .762 .934 r
.19868 .48397 .20767 .492 .22071 .48766 .21176 .47958 Metetra
.646 .762 .934 r
.21176 .47958 .22071 .48766 .23382 .48329 .22491 .47518 Metetra
.646 .762 .934 r
.22491 .47518 .23382 .48329 .24699 .47891 .23812 .47075 Metetra
.646 .762 .934 r
.23812 .47075 .24699 .47891 .26108 .46389 .2514 .4663 Metetra
.903 .977 .801 r
.2514 .4663 .26108 .46389 .27558 .44336 .26578 .44882 Metetra
.89 .988 .738 r
.26578 .44882 .27558 .44336 .28995 .42369 .28026 .4295 Metetra
.859 .99 .73 r
.28026 .4295 .28995 .42369 .30418 .40518 .2946 .41128 Metetra
.813 .986 .718 r
.2946 .41128 .30418 .40518 .31828 .38808 .30882 .39442 Metetra
.745 .969 .697 r
.30882 .39442 .31828 .38808 .33224 .37262 .3229 .37917 Metetra
.649 .932 .664 r
.3229 .37917 .33224 .37262 .34608 .35901 .33685 .3657 Metetra
.52 .867 .613 r
.33685 .3657 .34608 .35901 .3598 .34739 .35069 .35419 Metetra
.35069 .35419 .3598 .34739 .37344 .33789 .36443 .34475 Metetra
.36443 .34475 .37344 .33789 .387 .3306 .37811 .33748 Metetra
.37811 .33748 .387 .3306 .40051 .32557 .39173 .33243 Metetra
.146 0 0 r
.39173 .33243 .40051 .32557 .41401 .3228 .40534 .3296 Metetra
.277 0 0 r
.40534 .3296 .41401 .3228 .42753 .32228 .41896 .32896 Metetra
.38 0 0 r
.41896 .32896 .42753 .32228 .4411 .32393 .43262 .33047 Metetra
.46 0 0 r
.43262 .33047 .4411 .32393 .45474 .32767 .44636 .334 Metetra
.521 .003 0 r
.44636 .334 .45474 .32767 .4685 .33333 .46021 .33942 Metetra
.568 .052 0 r
.46021 .33942 .4685 .33333 .48239 .34077 .47419 .34656 Metetra
.602 .088 0 r
.47419 .34656 .48239 .34077 .49646 .34975 .48834 .3552 Metetra
.627 .114 .006 r
.48834 .3552 .49646 .34975 .51072 .36004 .50267 .3651 Metetra
.644 .129 .004 r
.50267 .3651 .51072 .36004 .52519 .37136 .51722 .37598 Metetra
.51722 .37598 .52519 .37136 .53988 .38138 .53196 .37228 Metetra
.646 .762 .934 r
.53196 .37228 .53988 .38138 .55465 .37646 .54678 .36731 Metetra
.646 .762 .934 r
.54678 .36731 .55465 .37646 .5695 .37152 .56168 .36232 Metetra
.646 .762 .934 r
.56168 .36232 .5695 .37152 .58443 .36655 .57666 .3573 Metetra
.646 .762 .934 r
.57666 .3573 .58443 .36655 .59944 .36155 .59173 .35225 Metetra
.646 .762 .934 r
.59173 .35225 .59944 .36155 .61453 .35653 .60687 .34718 Metetra
.646 .762 .934 r
.60687 .34718 .61453 .35653 .6297 .35147 .6221 .34207 Metetra
.646 .762 .934 r
.6221 .34207 .6297 .35147 .64495 .34639 .63741 .33694 Metetra
.646 .762 .934 r
.63741 .33694 .64495 .34639 .66029 .34129 .6528 .33178 Metetra
.646 .762 .934 r
.6528 .33178 .66029 .34129 .67571 .33615 .66828 .3266 Metetra
.646 .762 .934 r
.66828 .3266 .67571 .33615 .69122 .33099 .68385 .32138 Metetra
.646 .762 .934 r
.68385 .32138 .69122 .33099 .70681 .3258 .6995 .31614 Metetra
.646 .762 .934 r
.6995 .31614 .70681 .3258 .72249 .32058 .71524 .31086 Metetra
.646 .762 .934 r
.71524 .31086 .72249 .32058 .73825 .31533 .73106 .30556 Metetra
.646 .762 .934 r
.73106 .30556 .73825 .31533 .7541 .31005 .74698 .30023 Metetra
.646 .762 .934 r
.04958 .52308 .05905 .53076 .07143 .52661 .062 .5189 Metetra
.646 .762 .934 r
.062 .5189 .07143 .52661 .08387 .52244 .07448 .51469 Metetra
.646 .762 .934 r
.07448 .51469 .08387 .52244 .09638 .51825 .08701 .51046 Metetra
.646 .762 .934 r
.08701 .51046 .09638 .51825 .10894 .51404 .09962 .50621 Metetra
.646 .762 .934 r
.09962 .50621 .10894 .51404 .12157 .50981 .11228 .50194 Metetra
.646 .762 .934 r
.11228 .50194 .12157 .50981 .13426 .50556 .12501 .49765 Metetra
.646 .762 .934 r
.12501 .49765 .13426 .50556 .14702 .50128 .1378 .49333 Metetra
.646 .762 .934 r
.1378 .49333 .14702 .50128 .15984 .49698 .15065 .489 Metetra
.646 .762 .934 r
.15065 .489 .15984 .49698 .17272 .49267 .16357 .48464 Metetra
.646 .762 .934 r
.16357 .48464 .17272 .49267 .18567 .48833 .17656 .48026 Metetra
.646 .762 .934 r
.17656 .48026 .18567 .48833 .19868 .48397 .18961 .47586 Metetra
.646 .762 .934 r
.18961 .47586 .19868 .48397 .21176 .47958 .20273 .47143 Metetra
.646 .762 .934 r
.20273 .47143 .21176 .47958 .22491 .47518 .21591 .46699 Metetra
.646 .762 .934 r
.21591 .46699 .22491 .47518 .23812 .47075 .22916 .46252 Metetra
.646 .762 .934 r
.22916 .46252 .23812 .47075 .2514 .4663 .24248 .45803 Metetra
.646 .762 .934 r
.24248 .45803 .2514 .4663 .26578 .44882 .25587 .45351 Metetra
.883 .992 .762 r
.25587 .45351 .26578 .44882 .28026 .4295 .27039 .4353 Metetra
.851 .991 .734 r
.27039 .4353 .28026 .4295 .2946 .41128 .28485 .41743 Metetra
.802 .985 .719 r
.28485 .41743 .2946 .41128 .30882 .39442 .29918 .40086 Metetra
.731 .965 .696 r
.29918 .40086 .30882 .39442 .3229 .37917 .31337 .38584 Metetra
.633 .925 .659 r
.31337 .38584 .3229 .37917 .33685 .3657 .32744 .37256 Metetra
.502 .857 .605 r
.32744 .37256 .33685 .3657 .35069 .35419 .34139 .36118 Metetra
.34139 .36118 .35069 .35419 .36443 .34475 .35525 .35183 Metetra
.35525 .35183 .36443 .34475 .37811 .33748 .36904 .34458 Metetra
.36904 .34458 .37811 .33748 .39173 .33243 .38277 .33951 Metetra
.145 0 0 r
.38277 .33951 .39173 .33243 .40534 .3296 .39649 .3366 Metetra
.271 0 0 r
.39649 .3366 .40534 .3296 .41896 .32896 .41021 .33584 Metetra
.371 0 0 r
.41021 .33584 .41896 .32896 .43262 .33047 .42398 .33717 Metetra
.449 0 0 r
.42398 .33717 .43262 .33047 .44636 .334 .43781 .34047 Metetra
.509 0 0 r
.43781 .34047 .44636 .334 .46021 .33942 .45175 .34561 Metetra
.555 .037 0 r
.45175 .34561 .46021 .33942 .47419 .34656 .46583 .35241 Metetra
.589 .072 0 r
.46583 .35241 .47419 .34656 .48834 .3552 .48006 .36066 Metetra
.614 .096 0 r
.48006 .36066 .48834 .3552 .50267 .3651 .49448 .37012 Metetra
.124 0 0 r
.49448 .37012 .50267 .3651 .51722 .37598 .50917 .36808 Metetra
.642 .794 .955 r
.50917 .36808 .51722 .37598 .53196 .37228 .52396 .36309 Metetra
.646 .762 .934 r
.52396 .36309 .53196 .37228 .54678 .36731 .53883 .35807 Metetra
.646 .762 .934 r
.53883 .35807 .54678 .36731 .56168 .36232 .55379 .35303 Metetra
.646 .762 .934 r
.55379 .35303 .56168 .36232 .57666 .3573 .56882 .34796 Metetra
.646 .762 .934 r
.56882 .34796 .57666 .3573 .59173 .35225 .58394 .34286 Metetra
.646 .762 .934 r
.58394 .34286 .59173 .35225 .60687 .34718 .59914 .33773 Metetra
.646 .762 .934 r
.59914 .33773 .60687 .34718 .6221 .34207 .61442 .33258 Metetra
.646 .762 .934 r
.61442 .33258 .6221 .34207 .63741 .33694 .62979 .3274 Metetra
.646 .762 .934 r
.62979 .3274 .63741 .33694 .6528 .33178 .64524 .32219 Metetra
.646 .762 .934 r
.64524 .32219 .6528 .33178 .66828 .3266 .66078 .31695 Metetra
.646 .762 .934 r
.66078 .31695 .66828 .3266 .68385 .32138 .6764 .31168 Metetra
.646 .762 .934 r
.6764 .31168 .68385 .32138 .6995 .31614 .69211 .30638 Metetra
.646 .762 .934 r
.69211 .30638 .6995 .31614 .71524 .31086 .70791 .30105 Metetra
.646 .762 .934 r
.70791 .30105 .71524 .31086 .73106 .30556 .7238 .29569 Metetra
.646 .762 .934 r
.7238 .29569 .73106 .30556 .74698 .30023 .73977 .2903 Metetra
.646 .762 .934 r
.04004 .51534 .04958 .52308 .062 .5189 .05248 .51111 Metetra
.646 .762 .934 r
.05248 .51111 .062 .5189 .07448 .51469 .06499 .50687 Metetra
.646 .762 .934 r
.06499 .50687 .07448 .51469 .08701 .51046 .07757 .5026 Metetra
.646 .762 .934 r
.07757 .5026 .08701 .51046 .09962 .50621 .0902 .49831 Metetra
.646 .762 .934 r
.0902 .49831 .09962 .50621 .11228 .50194 .1029 .494 Metetra
.646 .762 .934 r
.1029 .494 .11228 .50194 .12501 .49765 .11566 .48967 Metetra
.646 .762 .934 r
.11566 .48967 .12501 .49765 .1378 .49333 .12849 .48531 Metetra
.646 .762 .934 r
.12849 .48531 .1378 .49333 .15065 .489 .14138 .48094 Metetra
.646 .762 .934 r
.14138 .48094 .15065 .489 .16357 .48464 .15434 .47654 Metetra
.646 .762 .934 r
.15434 .47654 .16357 .48464 .17656 .48026 .16736 .47212 Metetra
.646 .762 .934 r
.16736 .47212 .17656 .48026 .18961 .47586 .18045 .46767 Metetra
.646 .762 .934 r
.18045 .46767 .18961 .47586 .20273 .47143 .19361 .46321 Metetra
.646 .762 .934 r
.19361 .46321 .20273 .47143 .21591 .46699 .20683 .45872 Metetra
.646 .762 .934 r
.20683 .45872 .21591 .46699 .22916 .46252 .22012 .45421 Metetra
.646 .762 .934 r
.22012 .45421 .22916 .46252 .24248 .45803 .23348 .44967 Metetra
.646 .762 .934 r
.23348 .44967 .24248 .45803 .25587 .45351 .24691 .44511 Metetra
.646 .762 .934 r
.24691 .44511 .25587 .45351 .27039 .4353 .26041 .44053 Metetra
.845 .995 .754 r
.26041 .44053 .27039 .4353 .28485 .41743 .27493 .42347 Metetra
.794 .986 .726 r
.27493 .42347 .28485 .41743 .29918 .40086 .28937 .40724 Metetra
.722 .965 .701 r
.28937 .40724 .29918 .40086 .31337 .38584 .30367 .3925 Metetra
.623 .923 .662 r
.30367 .3925 .31337 .38584 .32744 .37256 .31785 .37943 Metetra
.493 .853 .607 r
.31785 .37943 .32744 .37256 .34139 .36118 .33192 .36821 Metetra
.33192 .36821 .34139 .36118 .35525 .35183 .3459 .35895 Metetra
.3459 .35895 .35525 .35183 .36904 .34458 .35979 .35174 Metetra
.35979 .35174 .36904 .34458 .38277 .33951 .37364 .34664 Metetra
.137 0 0 r
.37364 .34664 .38277 .33951 .39649 .3366 .38747 .34366 Metetra
.26 0 0 r
.38747 .34366 .39649 .3366 .41021 .33584 .4013 .34276 Metetra
.358 0 0 r
.4013 .34276 .41021 .33584 .42398 .33717 .41517 .34388 Metetra
.435 0 0 r
.41517 .34388 .42398 .33717 .43781 .34047 .4291 .34693 Metetra
.495 0 0 r
.4291 .34693 .43781 .34047 .45175 .34561 .44314 .35175 Metetra
.54 .018 0 r
.44314 .35175 .45175 .34561 .46583 .35241 .45731 .35817 Metetra
.574 .052 0 r
.45731 .35817 .46583 .35241 .48006 .36066 .47163 .36598 Metetra
.127 0 0 r
.47163 .36598 .48006 .36066 .49448 .37012 .48627 .36386 Metetra
.631 .837 .979 r
.48627 .36386 .49448 .37012 .50917 .36808 .50103 .35885 Metetra
.646 .762 .934 r
.50103 .35885 .50917 .36808 .52396 .36309 .51588 .35381 Metetra
.646 .762 .934 r
.51588 .35381 .52396 .36309 .53883 .35807 .5308 .34874 Metetra
.646 .762 .934 r
.5308 .34874 .53883 .35807 .55379 .35303 .54581 .34365 Metetra
.646 .762 .934 r
.54581 .34365 .55379 .35303 .56882 .34796 .5609 .33853 Metetra
.646 .762 .934 r
.5609 .33853 .56882 .34796 .58394 .34286 .57607 .33338 Metetra
.646 .762 .934 r
.57607 .33338 .58394 .34286 .59914 .33773 .59133 .3282 Metetra
.646 .762 .934 r
.59133 .3282 .59914 .33773 .61442 .33258 .60667 .32299 Metetra
.646 .762 .934 r
.60667 .32299 .61442 .33258 .62979 .3274 .62209 .31775 Metetra
.646 .762 .934 r
.62209 .31775 .62979 .3274 .64524 .32219 .6376 .31249 Metetra
.646 .762 .934 r
.6376 .31249 .64524 .32219 .66078 .31695 .6532 .30719 Metetra
.646 .762 .934 r
.6532 .30719 .66078 .31695 .6764 .31168 .66888 .30187 Metetra
.646 .762 .934 r
.66888 .30187 .6764 .31168 .69211 .30638 .68465 .29652 Metetra
.646 .762 .934 r
.68465 .29652 .69211 .30638 .70791 .30105 .70051 .29113 Metetra
.646 .762 .934 r
.70051 .29113 .70791 .30105 .7238 .29569 .71646 .28572 Metetra
.646 .762 .934 r
.71646 .28572 .7238 .29569 .73977 .2903 .7325 .28028 Metetra
.646 .762 .934 r
.0304 .50752 .04004 .51534 .05248 .51111 .04288 .50326 Metetra
.646 .762 .934 r
.04288 .50326 .05248 .51111 .06499 .50687 .05542 .49897 Metetra
.646 .762 .934 r
.05542 .49897 .06499 .50687 .07757 .5026 .06803 .49466 Metetra
.646 .762 .934 r
.06803 .49466 .07757 .5026 .0902 .49831 .0807 .49033 Metetra
.646 .762 .934 r
.0807 .49033 .0902 .49831 .1029 .494 .09343 .48598 Metetra
.646 .762 .934 r
.09343 .48598 .1029 .494 .11566 .48967 .10623 .48161 Metetra
.646 .762 .934 r
.10623 .48161 .11566 .48967 .12849 .48531 .1191 .47722 Metetra
.646 .762 .934 r
.1191 .47722 .12849 .48531 .14138 .48094 .13202 .4728 Metetra
.646 .762 .934 r
.13202 .4728 .14138 .48094 .15434 .47654 .14502 .46836 Metetra
.646 .762 .934 r
.14502 .46836 .15434 .47654 .16736 .47212 .15808 .4639 Metetra
.646 .762 .934 r
.15808 .4639 .16736 .47212 .18045 .46767 .17121 .45941 Metetra
.646 .762 .934 r
.17121 .45941 .18045 .46767 .19361 .46321 .1844 .4549 Metetra
.646 .762 .934 r
.1844 .4549 .19361 .46321 .20683 .45872 .19766 .45037 Metetra
.646 .762 .934 r
.19766 .45037 .20683 .45872 .22012 .45421 .21099 .44582 Metetra
.646 .762 .934 r
.21099 .44582 .22012 .45421 .23348 .44967 .22439 .44124 Metetra
.646 .762 .934 r
.22439 .44124 .23348 .44967 .24691 .44511 .23786 .43664 Metetra
.646 .762 .934 r
.23786 .43664 .24691 .44511 .26041 .44053 .2514 .43201 Metetra
.646 .762 .934 r
.2514 .43201 .26041 .44053 .27493 .42347 .26501 .42736 Metetra
.791 .998 .799 r
.26501 .42736 .27493 .42347 .28937 .40724 .27939 .41341 Metetra
.718 .967 .712 r
.27939 .41341 .28937 .40724 .30367 .3925 .29381 .39898 Metetra
.62 .925 .673 r
.29381 .39898 .30367 .3925 .31785 .37943 .3081 .38615 Metetra
.492 .857 .618 r
.3081 .38615 .31785 .37943 .33192 .36821 .32228 .37511 Metetra
.32228 .37511 .33192 .36821 .3459 .35895 .33637 .36596 Metetra
.33637 .36596 .3459 .35895 .35979 .35174 .35038 .3588 Metetra
.35038 .3588 .35979 .35174 .37364 .34664 .36434 .35368 Metetra
.123 0 0 r
.36434 .35368 .37364 .34664 .38747 .34366 .37828 .3506 Metetra
.243 0 0 r
.37828 .3506 .38747 .34366 .4013 .34276 .39222 .34955 Metetra
.341 0 0 r
.39222 .34955 .4013 .34276 .41517 .34388 .40619 .35046 Metetra
.417 0 0 r
.40619 .35046 .41517 .34388 .4291 .34693 .42023 .35321 Metetra
.477 0 0 r
.42023 .35321 .4291 .34693 .44314 .35175 .43437 .35768 Metetra
.523 0 0 r
.43437 .35768 .44314 .35175 .45731 .35817 .44863 .36368 Metetra
.44863 .36368 .45731 .35817 .47163 .36598 .46327 .35962 Metetra
.632 .835 .978 r
.46327 .35962 .47163 .36598 .48627 .36386 .478 .35459 Metetra
.646 .762 .934 r
.478 .35459 .48627 .36386 .50103 .35885 .49282 .34952 Metetra
.646 .762 .934 r
.49282 .34952 .50103 .35885 .51588 .35381 .50772 .34443 Metetra
.646 .762 .934 r
.50772 .34443 .51588 .35381 .5308 .34874 .5227 .33932 Metetra
.646 .762 .934 r
.5227 .33932 .5308 .34874 .54581 .34365 .53776 .33417 Metetra
.646 .762 .934 r
.53776 .33417 .54581 .34365 .5609 .33853 .5529 .32899 Metetra
.646 .762 .934 r
.5529 .32899 .5609 .33853 .57607 .33338 .56813 .32379 Metetra
.646 .762 .934 r
.56813 .32379 .57607 .33338 .59133 .3282 .58344 .31856 Metetra
.646 .762 .934 r
.58344 .31856 .59133 .3282 .60667 .32299 .59884 .3133 Metetra
.646 .762 .934 r
.59884 .3133 .60667 .32299 .62209 .31775 .61432 .30801 Metetra
.646 .762 .934 r
.61432 .30801 .62209 .31775 .6376 .31249 .62988 .30269 Metetra
.646 .762 .934 r
.62988 .30269 .6376 .31249 .6532 .30719 .64554 .29734 Metetra
.646 .762 .934 r
.64554 .29734 .6532 .30719 .66888 .30187 .66128 .29196 Metetra
.646 .762 .934 r
.66128 .29196 .66888 .30187 .68465 .29652 .67711 .28655 Metetra
.646 .762 .934 r
.67711 .28655 .68465 .29652 .70051 .29113 .69303 .28111 Metetra
.646 .762 .934 r
.69303 .28111 .70051 .29113 .71646 .28572 .70904 .27564 Metetra
.646 .762 .934 r
.70904 .27564 .71646 .28572 .7325 .28028 .72514 .27014 Metetra
.646 .762 .934 r
.02067 .49963 .0304 .50752 .04288 .50326 .03319 .49533 Metetra
.646 .762 .934 r
.03319 .49533 .04288 .50326 .05542 .49897 .04577 .491 Metetra
.646 .762 .934 r
.04577 .491 .05542 .49897 .06803 .49466 .05841 .48665 Metetra
.646 .762 .934 r
.05841 .48665 .06803 .49466 .0807 .49033 .07111 .48228 Metetra
.646 .762 .934 r
.07111 .48228 .0807 .49033 .09343 .48598 .08388 .47789 Metetra
.646 .762 .934 r
.08388 .47789 .09343 .48598 .10623 .48161 .09671 .47348 Metetra
.646 .762 .934 r
.09671 .47348 .10623 .48161 .1191 .47722 .10961 .46904 Metetra
.646 .762 .934 r
.10961 .46904 .1191 .47722 .13202 .4728 .12258 .46458 Metetra
.646 .762 .934 r
.12258 .46458 .13202 .4728 .14502 .46836 .13561 .4601 Metetra
.646 .762 .934 r
.13561 .4601 .14502 .46836 .15808 .4639 .14871 .4556 Metetra
.646 .762 .934 r
.14871 .4556 .15808 .4639 .17121 .45941 .16187 .45107 Metetra
.646 .762 .934 r
.16187 .45107 .17121 .45941 .1844 .4549 .17511 .44652 Metetra
.646 .762 .934 r
.17511 .44652 .1844 .4549 .19766 .45037 .18841 .44194 Metetra
.646 .762 .934 r
.18841 .44194 .19766 .45037 .21099 .44582 .20178 .43735 Metetra
.646 .762 .934 r
.20178 .43735 .21099 .44582 .22439 .44124 .21522 .43272 Metetra
.646 .762 .934 r
.21522 .43272 .22439 .44124 .23786 .43664 .22873 .42808 Metetra
.646 .762 .934 r
.22873 .42808 .23786 .43664 .2514 .43201 .24231 .42341 Metetra
.646 .762 .934 r
.24231 .42341 .2514 .43201 .26501 .42736 .25596 .41871 Metetra
.646 .762 .934 r
.25596 .41871 .26501 .42736 .27939 .41341 .26968 .41399 Metetra
.69 .976 .909 r
.26968 .41399 .27939 .41341 .29381 .39898 .28379 .40512 Metetra
.623 .932 .692 r
.28379 .40512 .29381 .39898 .3081 .38615 .29819 .39257 Metetra
.5 .866 .638 r
.29819 .39257 .3081 .38615 .32228 .37511 .31248 .38172 Metetra
.31248 .38172 .32228 .37511 .33637 .36596 .32668 .3727 Metetra
.32668 .3727 .33637 .36596 .35038 .3588 .3408 .3656 Metetra
.3408 .3656 .35038 .3588 .36434 .35368 .35488 .36045 Metetra
.101 0 0 r
.35488 .36045 .36434 .35368 .37828 .3506 .36892 .35728 Metetra
.221 0 0 r
.36892 .35728 .37828 .3506 .39222 .34955 .38297 .35606 Metetra
.318 0 0 r
.38297 .35606 .39222 .34955 .40619 .35046 .39706 .35672 Metetra
.395 0 0 r
.39706 .35672 .40619 .35046 .42023 .35321 .4112 .35916 Metetra
.331 0 0 r
.4112 .35916 .42023 .35321 .43437 .35768 .42553 .36039 Metetra
.252 .752 .695 r
.42553 .36039 .43437 .35768 .44863 .36368 .44016 .35536 Metetra
.644 .786 .95 r
.44016 .35536 .44863 .36368 .46327 .35962 .45487 .3503 Metetra
.646 .762 .934 r
.45487 .3503 .46327 .35962 .478 .35459 .46965 .34522 Metetra
.646 .762 .934 r
.46965 .34522 .478 .35459 .49282 .34952 .48452 .3401 Metetra
.646 .762 .934 r
.48452 .3401 .49282 .34952 .50772 .34443 .49947 .33496 Metetra
.646 .762 .934 r
.49947 .33496 .50772 .34443 .5227 .33932 .5145 .32979 Metetra
.646 .762 .934 r
.5145 .32979 .5227 .33932 .53776 .33417 .52962 .32459 Metetra
.646 .762 .934 r
.52962 .32459 .53776 .33417 .5529 .32899 .54482 .31937 Metetra
.646 .762 .934 r
.54482 .31937 .5529 .32899 .56813 .32379 .5601 .31411 Metetra
.646 .762 .934 r
.5601 .31411 .56813 .32379 .58344 .31856 .57547 .30883 Metetra
.646 .762 .934 r
.57547 .30883 .58344 .31856 .59884 .3133 .59092 .30351 Metetra
.646 .762 .934 r
.59092 .30351 .59884 .3133 .61432 .30801 .60646 .29817 Metetra
.646 .762 .934 r
.60646 .29817 .61432 .30801 .62988 .30269 .62209 .29279 Metetra
.646 .762 .934 r
.62209 .29279 .62988 .30269 .64554 .29734 .6378 .28739 Metetra
.646 .762 .934 r
.6378 .28739 .64554 .29734 .66128 .29196 .6536 .28195 Metetra
.646 .762 .934 r
.6536 .28195 .66128 .29196 .67711 .28655 .6695 .27649 Metetra
.646 .762 .934 r
.6695 .27649 .67711 .28655 .69303 .28111 .68548 .27099 Metetra
.646 .762 .934 r
.68548 .27099 .69303 .28111 .70904 .27564 .70155 .26546 Metetra
.646 .762 .934 r
.70155 .26546 .70904 .27564 .72514 .27014 .71771 .2599 Metetra
.646 .762 .934 r
.01086 .49167 .02067 .49963 .03319 .49533 .02341 .48732 Metetra
.646 .762 .934 r
.02341 .48732 .03319 .49533 .04577 .491 .03602 .48296 Metetra
.646 .762 .934 r
.03602 .48296 .04577 .491 .05841 .48665 .04869 .47857 Metetra
.646 .762 .934 r
.04869 .47857 .05841 .48665 .07111 .48228 .06143 .47416 Metetra
.646 .762 .934 r
.06143 .47416 .07111 .48228 .08388 .47789 .07424 .46973 Metetra
.646 .762 .934 r
.07424 .46973 .08388 .47789 .09671 .47348 .08711 .46527 Metetra
.646 .762 .934 r
.08711 .46527 .09671 .47348 .10961 .46904 .10004 .46079 Metetra
.646 .762 .934 r
.10004 .46079 .10961 .46904 .12258 .46458 .11304 .45629 Metetra
.646 .762 .934 r
.11304 .45629 .12258 .46458 .13561 .4601 .12611 .45177 Metetra
.646 .762 .934 r
.12611 .45177 .13561 .4601 .14871 .4556 .13925 .44722 Metetra
.646 .762 .934 r
.13925 .44722 .14871 .4556 .16187 .45107 .15245 .44265 Metetra
.646 .762 .934 r
.15245 .44265 .16187 .45107 .17511 .44652 .16572 .43805 Metetra
.646 .762 .934 r
.16572 .43805 .17511 .44652 .18841 .44194 .17906 .43344 Metetra
.646 .762 .934 r
.17906 .43344 .18841 .44194 .20178 .43735 .19247 .42879 Metetra
.646 .762 .934 r
.19247 .42879 .20178 .43735 .21522 .43272 .20596 .42413 Metetra
.646 .762 .934 r
.20596 .42413 .21522 .43272 .22873 .42808 .21951 .41944 Metetra
.646 .762 .934 r
.21951 .41944 .22873 .42808 .24231 .42341 .23313 .41472 Metetra
.646 .762 .934 r
.23313 .41472 .24231 .42341 .25596 .41871 .24682 .40998 Metetra
.646 .762 .934 r
.24682 .40998 .25596 .41871 .26968 .41399 .26059 .40521 Metetra
.646 .762 .934 r
.26059 .40521 .26968 .41399 .28379 .40512 .27443 .40042 Metetra
.616 .864 .99 r
.27443 .40042 .28379 .40512 .29819 .39257 .28834 .39561 Metetra
.491 .898 .787 r
.28834 .39561 .29819 .39257 .31248 .38172 .30252 .3879 Metetra
.373 .795 .601 r
.30252 .3879 .31248 .38172 .32668 .3727 .31683 .37902 Metetra
.31683 .37902 .32668 .3727 .3408 .3656 .33107 .37197 Metetra
.33107 .37197 .3408 .3656 .35488 .36045 .34525 .36681 Metetra
.072 0 0 r
.34525 .36681 .35488 .36045 .36892 .35728 .35941 .36354 Metetra
.191 0 0 r
.35941 .36354 .36892 .35728 .38297 .35606 .37357 .36213 Metetra
.212 0 0 r
.37357 .36213 .38297 .35606 .39706 .35672 .38782 .36116 Metetra
.38782 .36116 .39706 .35672 .4112 .35916 .40234 .35614 Metetra
.568 .896 .984 r
.40234 .35614 .4112 .35916 .42553 .36039 .41694 .35108 Metetra
.646 .762 .934 r
.41694 .35108 .42553 .36039 .44016 .35536 .43162 .346 Metetra
.646 .762 .934 r
.43162 .346 .44016 .35536 .45487 .3503 .44638 .34089 Metetra
.646 .762 .934 r
.44638 .34089 .45487 .3503 .46965 .34522 .46122 .33576 Metetra
.646 .762 .934 r
.46122 .33576 .46965 .34522 .48452 .3401 .47614 .33059 Metetra
.646 .762 .934 r
.47614 .33059 .48452 .3401 .49947 .33496 .49114 .3254 Metetra
.646 .762 .934 r
.49114 .3254 .49947 .33496 .5145 .32979 .50623 .32017 Metetra
.646 .762 .934 r
.50623 .32017 .5145 .32979 .52962 .32459 .5214 .31492 Metetra
.646 .762 .934 r
.5214 .31492 .52962 .32459 .54482 .31937 .53665 .30964 Metetra
.646 .762 .934 r
.53665 .30964 .54482 .31937 .5601 .31411 .55199 .30433 Metetra
.646 .762 .934 r
.55199 .30433 .5601 .31411 .57547 .30883 .56741 .29899 Metetra
.646 .762 .934 r
.56741 .29899 .57547 .30883 .59092 .30351 .58293 .29362 Metetra
.646 .762 .934 r
.58293 .29362 .59092 .30351 .60646 .29817 .59852 .28822 Metetra
.646 .762 .934 r
.59852 .28822 .60646 .29817 .62209 .29279 .61421 .28279 Metetra
.646 .762 .934 r
.61421 .28279 .62209 .29279 .6378 .28739 .62998 .27733 Metetra
.646 .762 .934 r
.62998 .27733 .6378 .28739 .6536 .28195 .64584 .27184 Metetra
.646 .762 .934 r
.64584 .27184 .6536 .28195 .6695 .27649 .6618 .26632 Metetra
.646 .762 .934 r
.6618 .26632 .6695 .27649 .68548 .27099 .67784 .26076 Metetra
.646 .762 .934 r
.67784 .26076 .68548 .27099 .70155 .26546 .69398 .25518 Metetra
.646 .762 .934 r
.69398 .25518 .70155 .26546 .71771 .2599 .71021 .24956 Metetra
.646 .762 .934 r
.00095 .48363 .01086 .49167 .02341 .48732 .01353 .47925 Metetra
.646 .762 .934 r
.01353 .47925 .02341 .48732 .03602 .48296 .02618 .47484 Metetra
.646 .762 .934 r
.02618 .47484 .03602 .48296 .04869 .47857 .03889 .47041 Metetra
.646 .762 .934 r
.03889 .47041 .04869 .47857 .06143 .47416 .05166 .46596 Metetra
.646 .762 .934 r
.05166 .46596 .06143 .47416 .07424 .46973 .0645 .46148 Metetra
.646 .762 .934 r
.0645 .46148 .07424 .46973 .08711 .46527 .07741 .45699 Metetra
.646 .762 .934 r
.07741 .45699 .08711 .46527 .10004 .46079 .09038 .45247 Metetra
.646 .762 .934 r
.09038 .45247 .10004 .46079 .11304 .45629 .10342 .44792 Metetra
.646 .762 .934 r
.10342 .44792 .11304 .45629 .12611 .45177 .11652 .44335 Metetra
.646 .762 .934 r
.11652 .44335 .12611 .45177 .13925 .44722 .1297 .43876 Metetra
.646 .762 .934 r
.1297 .43876 .13925 .44722 .15245 .44265 .14294 .43415 Metetra
.646 .762 .934 r
.14294 .43415 .15245 .44265 .16572 .43805 .15625 .42951 Metetra
.646 .762 .934 r
.15625 .42951 .16572 .43805 .17906 .43344 .16963 .42485 Metetra
.646 .762 .934 r
.16963 .42485 .17906 .43344 .19247 .42879 .18308 .42016 Metetra
.646 .762 .934 r
.18308 .42016 .19247 .42879 .20596 .42413 .1966 .41545 Metetra
.646 .762 .934 r
.1966 .41545 .20596 .42413 .21951 .41944 .21019 .41071 Metetra
.646 .762 .934 r
.21019 .41071 .21951 .41944 .23313 .41472 .22386 .40595 Metetra
.646 .762 .934 r
.22386 .40595 .23313 .41472 .24682 .40998 .23759 .40116 Metetra
.646 .762 .934 r
.23759 .40116 .24682 .40998 .26059 .40521 .2514 .39635 Metetra
.646 .762 .934 r
.2514 .39635 .26059 .40521 .27443 .40042 .26528 .39151 Metetra
.646 .762 .934 r
.26528 .39151 .27443 .40042 .28834 .39561 .27924 .38665 Metetra
.646 .762 .934 r
.27924 .38665 .28834 .39561 .30252 .3879 .29327 .38176 Metetra
.633 .834 .978 r
.29327 .38176 .30252 .3879 .31683 .37902 .30738 .37684 Metetra
.547 .9 .974 r
.30738 .37684 .31683 .37902 .33107 .37197 .32156 .3719 Metetra
.448 .879 .9 r
.32156 .3719 .33107 .37197 .34525 .36681 .33582 .36693 Metetra
.435 .873 .888 r
.33582 .36693 .34525 .36681 .35941 .36354 .35015 .36194 Metetra
.519 .899 .957 r
.35015 .36194 .35941 .36354 .37357 .36213 .36456 .35691 Metetra
.619 .861 .989 r
.36456 .35691 .37357 .36213 .38782 .36116 .37905 .35186 Metetra
.646 .762 .934 r
.37905 .35186 .38782 .36116 .40234 .35614 .39362 .34679 Metetra
.646 .762 .934 r
.39362 .34679 .40234 .35614 .41694 .35108 .40827 .34168 Metetra
.646 .762 .934 r
.40827 .34168 .41694 .35108 .43162 .346 .423 .33655 Metetra
.646 .762 .934 r
.423 .33655 .43162 .346 .44638 .34089 .43781 .33139 Metetra
.646 .762 .934 r
.43781 .33139 .44638 .34089 .46122 .33576 .4527 .3262 Metetra
.646 .762 .934 r
.4527 .3262 .46122 .33576 .47614 .33059 .46767 .32098 Metetra
.646 .762 .934 r
.46767 .32098 .47614 .33059 .49114 .3254 .48273 .31573 Metetra
.646 .762 .934 r
.48273 .31573 .49114 .3254 .50623 .32017 .49787 .31046 Metetra
.646 .762 .934 r
.49787 .31046 .50623 .32017 .5214 .31492 .51309 .30515 Metetra
.646 .762 .934 r
.51309 .30515 .5214 .31492 .53665 .30964 .5284 .29981 Metetra
.646 .762 .934 r
.5284 .29981 .53665 .30964 .55199 .30433 .5438 .29445 Metetra
.646 .762 .934 r
.5438 .29445 .55199 .30433 .56741 .29899 .55928 .28905 Metetra
.646 .762 .934 r
.55928 .28905 .56741 .29899 .58293 .29362 .57485 .28363 Metetra
.646 .762 .934 r
.57485 .28363 .58293 .29362 .59852 .28822 .5905 .27817 Metetra
.646 .762 .934 r
.5905 .27817 .59852 .28822 .61421 .28279 .60625 .27269 Metetra
.646 .762 .934 r
.60625 .27269 .61421 .28279 .62998 .27733 .62208 .26717 Metetra
.646 .762 .934 r
.62208 .26717 .62998 .27733 .64584 .27184 .638 .26162 Metetra
.646 .762 .934 r
.638 .26162 .64584 .27184 .6618 .26632 .65402 .25604 Metetra
.646 .762 .934 r
.65402 .25604 .6618 .26632 .67784 .26076 .67013 .25042 Metetra
.646 .762 .934 r
.67013 .25042 .67784 .26076 .69398 .25518 .68632 .24478 Metetra
.646 .762 .934 r
.68632 .24478 .69398 .25518 .71021 .24956 .70262 .2391 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.04003 .25401 m
.04482 .2585 L
s
[(-1)] .03045 .24505 1 .93576 Mshowa
.18786 .19613 m
.19242 .20085 L
s
[(-0.5)] .17875 .18668 .96492 1 Mshowa
.34468 .13472 m
.34896 .13969 L
s
[(0)] .33612 .12478 .8612 1 Mshowa
.51132 .06947 m
.51528 .0747 L
s
[(0.5)] .5034 .05901 .75747 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06892 .2427 m
.07176 .24542 L
s
.09814 .23126 m
.10096 .23401 L
s
.1277 .21969 m
.13049 .22246 L
s
.1576 .20797 m
.16037 .21078 L
s
.21848 .18414 m
.22119 .187 L
s
.24947 .172 m
.25214 .1749 L
s
.28082 .15973 m
.28346 .16265 L
s
.31256 .1473 m
.31516 .15025 L
s
.37719 .12199 m
.37973 .125 L
s
.41011 .1091 m
.4126 .11215 L
s
.44343 .09606 m
.44588 .09913 L
s
.47716 .08285 m
.47958 .08595 L
s
.54591 .05593 m
.54824 .0591 L
s
.58094 .04221 m
.58323 .04541 L
s
.61641 .02832 m
.61866 .03155 L
s
.65234 .01425 m
.65454 .01752 L
s
gsave
.29165 .07573 -70.3112 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00o?ooool4o`000003oa0@4?oooooooooo06Gooooo003nooooo`03o`00
0?oooooooooo06Oooooo003nooooo`03o`000?oooooooooo06Oooooo003nooooo`03o`000?oooooo
oooo06Oooooo003nooooo`03o`000?oooooooooo06Oooooo003nooooo`03o`000?oooooooooo06Oo
oooo003nooooo`03o`000?oooooooooo06Oooooo003looooo`03oeEEEOmVIVKo000000Wooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP1Kooooo`00ooooool9ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Foooool00?oooooo2Oooool01Ol@413ooooooooooooooooo410@05_ooooo003oooooo`Wooooo00Go
0000ooooooooooooooooo`00001Kooooo`00ooooool9ooooo`05o`000?ooooooooooooooool00000
Foooool00?oooooo0oooool2o`0000Cooooo00Go410@oooooooooooooooooa0@401Kooooo`00oooo
ool3o`000003ooooool0003ooooo00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Kooooo`00oOoo
ool2o`0000;ooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0Foooool00?[ooooo0ol0
0006ooooo`03o`000?oooooo000006;ooooo003hooooo`;o00002Oooool00ol0003oooooo`00001R
ooooo`00mOooool3o`0000_ooooo00Co0000oooooooooooo0000HOooool00?;ooooo0ol00003oooo
o`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00001Pooooo`00l?ooool2o`00
017ooooo00Go0000ooooooooooooooooo`00001Pooooo`00kOooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Mooooo`00joooool2o`0001Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Mooooo`00/oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd07oooool3o`000003ooooool0003ooooo
01Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Looooo`00/oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01cooooo0_l0000Loooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Foooool00;?ooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo01Sooooo0ol0000Nooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0Foooool00;?ooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01Oooooo0_l0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0F_ooool00;?ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`05Oooool3o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1I
ooooo`00/oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool3
o`0000?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`04ooooo`;o0000Foooool0
0;?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo01;ooooo0_l0000Y
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0F?ooool007_ooooo0_l00002oooo
o`;o0000<_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000>ooooo`?o0000:oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Oooooo001kooooo`06onk^k_lQ8B7oQhN7
okZj^_l0003ogMgMDoooool2o`0002kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Gooooo`00O?ooool01?oMgMgo0000oa0@4?o<c<aAooooo`?o00000_ooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0E_ooool007cooooo00Cok^k^
ob4Q8Ol@413ok^k^Coooool2o`0003?ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`1Eooooo`00O?ooool01?lQ8B7oMgMgogMgMolb<S9<ooooo`?o0000=Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo05Gooooo001kooooo`;o00000_ooool2o`0004Wooooo0_l0000h
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0E?ooool00<Oooooo1?l0000ioooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Doooool00<Gooooo0_l00004ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Cooooo`00
`_ooool3o`0003oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Booooo`00_ooo
ool3o`0004;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Booooo`00_Oooool3
o`0004Cooooo00?o0000ooooooooool03?ooool2o`0005?ooooo002jooooo`?o00000oooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0D?ooool00;So
oooo0_l0001:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0D?ooool00;Gooooo
0ol0001<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Coooool008_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Sooooo`;o0000D?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo04kooooo002;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08?ooool3o`0000;ooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04kooooo
002;ooooo`05oa0@4?ooooooooooooooool@41007_ooool2o`0005Gooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`1=ooooo`00Roooool01Ol0003ooooooooooooooooo000001_ooooo
0ol0001Gooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C?ooool008_ooooo00Go
0000ooooooooooooooooo`00000Iooooo`;o0000F_ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo04cooooo002;ooooo`05oa0@4?ooooooooooooooool@41005_ooool3o`000003oooo
ool0003ooooo05Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1;ooooo`00Rooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo0ol0001Oooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0B_ooool008_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`;o0000
H_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04[ooooo002Nooooo`?o0000I?oo
ool00ol0003oooooooooo`0Booooo`?o0000Boooool009cooooo0_l00002ooooo`03o`000?oooooo
oooo06;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`19ooooo`00VOooool3o`00
06Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`18ooooo`00Uoooool2o`0006co
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`17ooooo`00U?ooool3o`0006kooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`17ooooo`00T_ooool2o`000003ooooool0
003ooooo06kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`16ooooo`00Soooool3
o`0000Cooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo04Gooooo002<ooooo`?o0000M_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
04Gooooo002:ooooo`;o0000NOooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Co
oooo0027ooooo`Go0000NOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo
0025ooooo`;o0000O_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo0022
ooooo`?o0000POooool00ol0003oooooooooo`0Iooooo`;o0000A?ooool004Wooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM027ooooo0_l0
0024ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@Oooool004Wooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Mooooo`?o000000?o
ooooo`000?ooool0Poooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo047ooooo0011
ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool06_oo
ool2o`0008Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`10ooooo`00BOooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool06?ooool3o`0008_ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0oooooo`00BOooool01Ol0003ooooooooooooo
oooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Gooooo`;o0000S_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM02?ooooo0019ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`0Fooooo`?o000000?oooooo`000?ooool0SOooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Rooooo`00BOooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool04oooool3o`0009?ooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0Qooooo`00BOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`;o0000U_oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo02;ooooo001[ooooo`?o0000V?ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`08oooool006Wooooo0_l00002ooooo`03o`000?oooooooooo09Kooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`0Uooooo`00I_ooool3o`0009gooooo00?o0000ooooooooool0
8?ooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00co
oooo0ol000000ol@413oooooooooo`0Cooooo`00I?ooool2o`000:3ooooo00?o0000ooooooooool0
7oooool01?l0003oooooooooool00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
00gooooo00?o410@okZj^_ooool05?ooool0067ooooo0ol0002Rooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool08oooool00onHV9So<S8booooo`0Dooooo`00Goooool2o`0000;ooooo
00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02;ooooo
00?ogMgMo`000?nj^[X05?ooool005cooooo0ol00005ooooo`03o`000?oooooooooo09oooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0Qooooo`03oeEEEOmgMgOoA4A401Cooooo001J
ooooo`;o0000Z_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo023ooooo00GogMgM
oa0@4?oooooo8B4QomgMg@0Cooooo`00Eoooool3o`000:cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Oooooo`05ofIVI_n7QhOooooooiRHV?mEEED04oooool005Cooooo0ol00003
ooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0M
ooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool04Oooool005;ooooo0_l0002boooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07Oooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo013ooooo000Zooooo`Co000000?o410@ooooooooool07_ooool3o`00
0;Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0eooooo`00;?ooool00ol0003o
ooooooooo`0Nooooo`?o0000]oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Go
oooo000Qooooo`Ko00001Oooool00ol0003oooooooooo`0Kooooo`?o00000oooool00ol0003ooooo
ooooo`2dooooo`03o`000?oooooooooo02Kooooo0_l0000fooooo`00;?ooool00ol0003ooooooooo
o`0Iooooo`;o0000_Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03?ooooo000/
ooooo`03o`000?oooooooooo01Kooooo0ol0002oooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool0<oooool002cooooo00?o0000ooooooooool05?ooool2o`0000;ooooo00?o0000oooo
ooooool0_Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03;ooooo000/ooooo`03
o`000?oooooooooo017ooooo0ol00034ooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool0<Oooool002[ooooo00?oEEEEofIVI_l000004?ooool3o`000<Kooooo0_l0000/ooooo`03o`00
0?oooooooooo037ooooo000kooooo`;o0000a_ooool3o`000003ojG3kol0003ooooo02cooooo00?o
0000ooooooooool0<?ooool003Sooooo0ol00002ooooo`03o`000?oooooooooo0<3ooooo0ol00003
ojG3k`?o0000;Oooool00ol0003oooooooooo`0_ooooo`00=_ooool2o`000<Cooooo1?l00002ojG3
k`Co000000CoYL?_o`000?l0003o0000;?ooool00ol0003oooooooooo`0_ooooo`00<oooool3o`00
0<?ooooo0ol000001?nU`noo0000ojG3konU`nl4o`000003ojG3kol0003o000000?o0000;Oooool0
0ol0003oooooooooo`0^ooooo`00<_ooool3o`000<7ooooo0ol00004ojG3k`?o00000onU`nl2o`00
00CoYL?_0_l0000/ooooo`;o0000;oooool003;ooooo00Co0000ooooool0003o0000_Oooool3o`00
0004ojG3kol0003oYL?_ojG3k`?o000000?oYL?_o`000?nU`nl00ol00002ojG3k`03o`000?nU`noo
YL?_00;oYL?_0_l0000/ooooo`03o`000?oooooooooo02gooooo000booooo`;o000000?oooooo`00
0?ooool0^_ooool2o`0000CoYL?_0ol00004ojG3k`;o00001_nU`nl01?l0003oYL?_ojG3konU`nl3
o`0002cooooo00?o0000ooooooooool0;?ooool003;ooooo00Go0000ooooooooooooooooo`00002g
ooooo`?o00000_nU`nl4o`0000;oYL?_00?o0000ojG3kol000000_l00002ojG3k`03o`000?nU`noo
YL?_00?oYL?_1?l000000onU`noo0000o`00000/ooooo`03o`000?oooooooooo02cooooo000aoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/_ooool2o`0000?oYL?_1?l00003ojG3
k`?o00001_nU`nl00ol0003oYL?_o`000002o`000003ojG3kol0003oYL?_00?oYL?_0_l0000/oooo
o`03o`000?oooooooooo02_ooooo000aooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0[_ooool3o`0000;oYL?_0ol00003ojG3k`Co00000_nU`nl00ol0003oYL?_ojG3k`04ojG3k`;o
00001OnU`nl01?l0003oYL?_ojG3konU`nl3o`0002cooooo00?o0000ooooooooool0:_ooool0037o
oooo0ol00005ooooo`03o`000?oooooooooo0:[ooooo0ol00003ojG3k`;o000000?oYL?_o`000?nU
`nl00ol000000onU`noo0000ojG3k`04ojG3k`03o`000?nU`nooYL?_00?o000000?oYL?_o`000?nU
`nl01?nU`nl00ol0003oYL?_o`000003o`000003ojG3kol0003ooooo02[ooooo00?o0000oooooooo
ool0:_ooool0037ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Uooooo`Co0000
0onU`nl3o`0000?oYL?_0_l00005ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol00005ojG3k`04o`00
0?nU`nooYL?_ojG3k`?o00001?nU`nl00ol0003oYL?_o`00000[ooooo`03o`000?oooooooooo02Wo
oooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0:7ooooo0ol000001?nU`noo0000ojG3konU`nl3o`000003ojG3kol0
003oYL?_00?o000000?oYL?_o`000?nU`nl01?nU`nl00ol0003oYL?_o`000002o`0000;oYL?_00?o
0000ojG3konU`nl00onU`nl4o`0000;oYL?_00?o0000ojG3konU`nl00onU`nl3o`0002_ooooo00?o
0000ooooooooool0:?ooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0W_ooool2o`0000CoYL?_0ol00004ojG3k`;o
00001OnU`nl01?l0003oYL?_ojG3konU`nl3o`0000KoYL?_00?o0000ojG3kol000000_l000000onU
`noo0000ojG3k`04ojG3k`03o`000?nU`nooYL?_00?o000000?oYL?_o`000?ooool0:_ooool00ol0
003oooooooooo`0Xooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol0003ooooooooooooooooo000000Gooooo0ol0
000:ooooo`03o`000?oooooooooo09[ooooo0ol00002ojG3k`Co00000_nU`nl00ol0003oYL?_o`00
0002o`000003ojG3kol0003oYL?_00CoYL?_1?l00003ojG3k`03o`000?nU`nooYL?_00?oYL?_0_l0
0005ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol00003ojG3k`03o`000?nU`noo000002[ooooo0_l0
000Yooooo`003_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooooooooooooooo
o`000003ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo09Oooooo0_l00003ojG3k`Co00000onU`nl3o`0000GoYL?_00?o0000ojG3kol0
00000_l00002ojG3k`03o`000?nU`nooYL?_00?oYL?_00?o0000ojG3kol000000_l000000onU`noo
0000ojG3k`04ojG3k`03o`000?nU`noo000000;o00000_nU`nl00ol0003oYL?_ojG3k`02ojG3k`?o
0000:oooool00ol0003oooooooooo`0Vooooo`003_ooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000ooooooooooooooooo`000003ooooo`05olc<c?l0003o0000o`000?o<c<`01Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07Wooooo3_l0000<ooooo`?o00000_nU`nl3
o`0000?oYL?_1?l00002ojG3k`03o`000?nU`nooYL?_00?oYL?_0_l00006ojG3k`04o`000?nU`noo
YL?_ojG3k`?o00001OnU`nl01?l0003oYL?_ojG3konU`nl3o`0000KoYL?_00?o0000ojG3kol00000
1?l0000[ooooo`03o`000?oooooooooo02Kooooo000>ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@okZj^_oooooo^[Zjoa0@4005oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0L_ooool:o`0000?oD`002ol00005oooo
o`?o00000_nU`nl3o`000003ojG3kol0003oYL?_00?o000000?oYL?_o`000?nU`nl01?nU`nl00ol0
003oYL?_o`000002o`0000;oYL?_00?o0000ojG3konU`nl00onU`nl4o`0000;oYL?_00?o0000ojG3
konU`nl00onU`nl4o`0000?oYL?_00?o0000ojG3konU`nl00onU`nl2o`0000?oYL?_00?o0000ojG3
kol00000:oooool00ol0003oooooooooo`0Uooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05o`000?nj^[[ooooookZj^_l000001Ooo
ool2o`0000oooooo0_l0001`ooooo`[o00000_mJ0004o`0000;oLP000_l000000om/003o0000o`00
0008o`0000?oYL?_0_l00004ojG3k`;o00001OnU`nl01?l0003oYL?_ojG3konU`nl3o`0000KoYL?_
00?o0000ojG3kol000000_l000000onU`noo0000ojG3k`04ojG3k`03o`000?nU`noo000000;o0000
0_nU`nl00ol0003oYL?_ojG3k`03ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl0
0onU`nl3o`0002_ooooo00?o0000ooooooooool09?ooool000kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01OnYZJWo410@o`000?l@413oZJVY
00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Zooooo`Oo000000?o?@00o`00
0?mO00000omO0004o`0000;oMP001_l00002ohD000?o00000_nU`nl00ol0003oYL?_o`000002o`00
0003ojG3kol0003oYL?_00?o000000?oYL?_o`000?nU`nl01?nU`nl4o`0000?oYL?_00?o0000ojG3
konU`nl00onU`nl2o`0000GoYL?_00?o0000ojG3konU`nl00_nU`nl2o`0000KoYL?_00Co0000ojG3
konU`nooYL?_0ol00005ojG3k`03o`000?nU`noo000000Co0000:oooool00ol0003oooooooooo`0T
ooooo`00<?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Oooooo0_l000000olA
003o0000o`000007o`0000;oG`0000?o0000ogP00?mh00000_mh0003o`0000;oRP001Ol00004ojG3
k`?o00000onU`nl3o`0000GoYL?_00?o0000ojG3kol000000_l000000onU`noo0000ojG3k`05ojG3
k`03o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl01?nU`nl00ol0003oYL?_o`000002o`00
00;oYL?_00?o0000ojG3konU`nl00onU`nl4o`0000;oYL?_00?o0000ojG3konU`nl00onU`nl2o`00
00CoYL?_0_l0000[ooooo`03o`000?oooooooooo02?ooooo000_ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0I?ooool6o`0000?o@P0000?o0000of400?mQ00000_mQ0004o`0000;o
N00000Co0000oh/10?n;0@3oR`400_l000000on:003o0000o`000002ojG3k`Co00000_nU`nl4o`00
00;oYL?_00?o0000ojG3konU`nl00onU`nl2o`0000GoYL?_00?o0000ojG3konU`nl00onU`nl2o`00
00GoYL?_00Co0000ojG3konU`nooYL?_0ol00006ojG3k`03o`000?nU`noo000000;o000000?oYL?_
o`000?nU`nl01?nU`nl00ol0003oYL?_o`000002o`000003ojG3kol0003oYL?_00?oYL?_0_l0000/
ooooo`03o`000?oooooooooo02;ooooo000_ooooo`;o00005Oooool00ol0003oooooooooo`1Poooo
oa?o00000_mi0003o`0000?oR`400ol00002ojG3k`Co000000KoYL?_o`000?l0003o0000ojG3kol0
0005ojG3k`03o`000?nU`noo000000;o00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`03o`000?nU
`noo000000;o000000?oYL?_o`000?nU`nl01?nU`nl4o`0000?oYL?_00?o0000ojG3konU`nl00onU
`nl2o`0000GoYL?_00?o0000ojG3konU`nl00_nU`nl2o`0000GoYL?_00Co0000ojG3konU`nooYL?_
0ol0000[ooooo`03o`000?oooooooooo02;ooooo000_ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0G_ooool7o`000003odD00?l0003o000000?o00000_mR00000ol0003oN@00ogT0
0002ogT000?o000000?oRP<0o`000?l000000_l00002ojG3k`?o00000onU`nl2o`0000GoYL?_00?o
0000ojG3konU`nl00_nU`nl2o`0000KoYL?_00Co0000ojG3konU`nooYL?_0ol00005ojG3k`03o`00
0?nU`noo000000;o00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`03o`000?nU`noo000000;o0000
00?oYL?_o`000?nU`nl01?nU`nl00ol0003oYL?_o`000002o`000003ojG3kol0003oYL?_00CoYL?_
1?l00002ojG3k`;o0000:oooool00ol0003oooooooooo`0Qooooo`00;oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo05_ooooo2ol00004of8000Co00000_mi00000ol0003oR@<0o`00
0002o`000003ojG3kol0003oYL?_00?o000000?oYL?_o`000?nU`nl00ol00002ojG3k`03o`000?nU
`nooYL?_00?oYL?_00Co0000ojG3kol0003o00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`Co0000
0_nU`nl00ol0003oYL?_ojG3k`03ojG3k`;o00001_nU`nl01?l0003oYL?_ojG3konU`nl3o`0000Go
YL?_00Co0000ojG3konU`nooYL?_0ol00005ojG3k`03o`000?nU`noo000000;o00000_nU`nl01ol0
003oYL?_ojG3konU`noo0000ojG3kol00000:_ooool2o`0002;ooooo000_ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0F?ooool5o`0000?o90001_l00002of800003o`000?mg003o
M`0000;oM`001?l00003ojG3k`?o00000onU`nl3o`0000KoYL?_00Co0000ojG3konU`nooYL?_0ol0
0005ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl01?nU`nl00ol0003oYL?_o`00
0002o`0000;oYL?_00?o0000ojG3konU`nl00onU`nl4o`0000;oYL?_00?o0000ojG3konU`nl00onU
`nl4o`0000;oYL?_00?o0000ojG3konU`nl00onU`nl2o`0000KoYL?_00Co0000ojG3konU`nooYL?_
0ol0000Zooooo`03o`000?oooooooooo023ooooo000_ooooo`?o00006?ooool00ol0003ooooooooo
o`1Fooooo`Go000000?o9000o`000?l000000_l000000om6003o0000of400002of4000Go000000Co
M`00o`000?l0003o00000_nU`nl3o`0000;oYL?_1?l00003ojG3k`03o`000?nU`nooYL?_00?oYL?_
1?l00002ojG3k`03o`000?nU`nooYL?_00?oYL?_0_l00005ojG3k`04o`000?nU`nooYL?_ojG3k`?o
00001_nU`nl00ol0003oYL?_o`000002o`000003ojG3kol0003oYL?_00CoYL?_00?o0000ojG3kol0
00000_l000000onU`noo0000ojG3k`04ojG3k`03o`000?nU`noo000000;o00000_nU`nl00ol0003o
YL?_ojG3k`03ojG3k`Co000000?oYL?_o`000?l00000:oooool00ol0003oooooooooo`0Oooooo`00
;_ooool2o`0001_ooooo00?o0000ooooooooool0E?ooool8o`0000?oAP0000?o0000of400?mQ0000
0_mQ00000ol0003oM@00ogD00003o`0000?oYL?_0_l000000onU`noo0000ojG3k`02o`000003ojG3
kol0003oYL?_00GoYL?_00?o0000ojG3kol000000_l000000onU`noo0000ojG3k`04ojG3k`03o`00
0?nU`noo000000;o00000_nU`nl00ol0003oYL?_ojG3k`02ojG3k`Co00000onU`nl00ol0003oYL?_
ojG3k`03ojG3k`;o00001OnU`nl00ol0003oYL?_ojG3k`02ojG3k`;o00001OnU`nl01?l0003oYL?_
ojG3konU`nl3o`0000KoYL?_00?o0000ojG3kol000000_l000000onU`noo0000ojG3k`03ojG3k`;o
0000:_ooool00ol0003oooooooooo`08ooooo`Co000000?o410@ooooooooool04?ooool000cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o410@olc<c005ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0DOoooolEo`0000?oYL?_0ol00003ojG3k`;o00001?nU`nl00ol0003oYL?_ojG3k`03
ojG3k`;o00001OnU`nl01?l0003oYL?_ojG3konU`nl3o`0000KoYL?_00Co0000ojG3kol0003o0000
0_nU`nl00ol0003oYL?_ojG3k`03ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl0
1?nU`nl00ol0003oYL?_o`000002o`000003ojG3kol0003oYL?_00CoYL?_1?l00003ojG3k`03o`00
0?nU`nooYL?_00?oYL?_0_l00005ojG3k`04o`000?nU`nooYL?_ojG3k`?o0000:_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01;ooooo000<ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B401Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04kooooo2Ol00003
odD00003o`000?mN003oGP0000;oGP000_l00002ojG3k`03o`000?nU`noo000000;o000000?oYL?_
o`000?nU`nl00ol000000onU`noo0000ojG3k`04ojG3k`03o`000?nU`noo000000;o000000?oYL?_
o`000?nU`nl01?nU`nl4o`0000?oYL?_00?o0000ojG3konU`nl00onU`nl2o`0000GoYL?_00Co0000
ojG3konU`nooYL?_0ol00005ojG3k`04o`000?nU`nooYL?_ojG3k`?o00001OnU`nl00ol0003oYL?_
o`000002o`0000;oYL?_00?o0000ojG3konU`nl00onU`nl00ol0003oYL?_o`000002o`000003ojG3
kol0003oYL?_00CoYL?_1?l000000onU`noo0000o`00000[ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool04_ooool000Cooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go0000ooooooooooooooooo`000005oooo
o`;o00007_ooool00ol0003oooooooooo`1<oooooa;o00000onU`nl3o`0000?oYL?_0ol00005ojG3
k`04o`000?nU`nooYL?_ojG3k`?o00001OnU`nl00ol0003oYL?_o`000002o`0000;oYL?_00?o0000
ojG3konU`nl00onU`nl00ol0003oYL?_o`000002o`000003ojG3kol0003oYL?_00CoYL?_1?l00002
ojG3k`03o`000?nU`nooYL?_00?oYL?_1?l00002ojG3k`03o`000?nU`nooYL?_00?oYL?_0_l00006
ojG3k`04o`000?nU`nooYL?_ojG3k`?o00001OnU`nl00ol0003oYL?_o`000002o`000003ojG3kol0
003oYL?_00?oYL?_0_l0000Zooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_oo
ool000cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003oV9RHoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool07_ooool2o`0004_o
oooo2?l00004od800003o`000?mK003o000000;o000000?oYL?_o`000?l000000_l00002ojG3k`Co
00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`Co00000onU`nl00ol0003oYL?_ojG3k`02ojG3k`;o
00001_nU`nl01?l0003oYL?_ojG3konU`nl3o`0000GoYL?_00?o0000ojG3kol000000_l000000onU
`noo0000ojG3k`04ojG3k`03o`000?nU`noo000000;o00000_nU`nl00ol0003oYL?_ojG3k`02ojG3
k`03o`000?nU`noo000000;o00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`Co00000_nU`nl00ol0
003oYL?_ojG3k`03ojG3k`;o00001OnU`nl01?l0003oYL?_ojG3konU`nl3o`0002[ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Booooo`003?ooool01Ol0003ooooooooooooooooo
000000_ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo04Oooooo3ol00002ojG3k`Co0000
00CoYL?_o`000?l0003o00000_nU`nl00ol0003oYL?_ojG3k`02ojG3k`03o`000?nU`noo000000;o
00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o0000ojG3
konU`nl00onU`nl4o`0000;oYL?_00?o0000ojG3konU`nl00onU`nl2o`0000GoYL?_00Co0000ojG3
konU`nooYL?_0ol00006ojG3k`03o`000?nU`nooYL?_00?o00001_nU`nl00ol0003oYL?_o`000002
o`000003ojG3kol0003oYL?_00CoYL?_00?o0000ojG3kol000000_l000000onU`noo0000ojG3k`04
ojG3k`Co000000?oYL?_o`000?l00000:oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01;ooooo000<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00?oEEEEohN7Qoooool01_ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo04Gooooo1_l000000olO003o0000och00004o`0000;oYL?_0ol00003ojG3k`;o00001_nU
`nl00ol0003oYL?_ojG3k`03o`0000KoYL?_00Co0000ojG3konU`nooYL?_0ol00005ojG3k`03o`00
0?nU`noo000000;o000000?oYL?_o`000?nU`nl01?nU`nl00ol0003oYL?_o`000002o`0000;oYL?_
00?o0000ojG3konU`nl00_nU`nl4o`0000?oYL?_00?o0000ojG3konU`nl00onU`nl3o`0000?oYL?_
00?o0000ojG3konU`nl00onU`nl2o`0000GoYL?_00Co0000ojG3konU`nooYL?_0ol00005ojG3k`03
o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl00onU`nl2o`0002[ooooo0_l00007ooooo`03
o`000?oooooooooo01;ooooo000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00?ogMgMoa0@4?nHV9P01_ooool2o`0002Cooooo00?o0000oooo
ooooool0@_ooool6o`0000;o7`000ol00002ojG3k`Co00000_nU`nl01?l0003oYL?_o`000?l00002
ojG3k`03o`000?nU`nooYL?_00?oYL?_0ol00003ojG3k`03o`000?nU`nooYL?_00?oYL?_1?l00002
ojG3k`03o`000?nU`nooYL?_00?oYL?_0_l00005ojG3k`04o`000?nU`nooYL?_ojG3k`?o00001_nU
`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00?oYL?_00?o0000ojG3kol00000
0_l000000onU`noo0000ojG3k`04ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl0
1?nU`nl4o`0000;oYL?_00?o0000ojG3konU`nl00onU`nl2o`0000GoYL?_00Co0000ojG3konU`noo
YL?_0ol0000Xooooo`03o`000?oooooo000000Gooooo00?oEEEEofIVI_l000005?ooool000cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01?o<
c<coA4A4o`000?l@4104ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0@?ooool:
o`0000;oYL?_1?l00003ojG3k`?o00001OnU`nl00ol0003oYL?_o`000002o`000003ojC9lol0003o
YL?_00CoYL?_00?o0000ojG3kol000000_l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_00?o0000
ojG3kol000000_l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_1?l00003ojG3k`03o`000?nU`noo
YL?_00?oYL?_0_l00005ojG3k`04o`000?nU`nooYL?_ojG3k`?o00001OnU`nl01?l0003oYL?_ojG3
konU`nl3o`0000GoYL?_00?o0000ojG3kol000000_l000000onU`noo0000ojG3k`04ojG3k`03o`00
0?nU`noo000000;o000000?oYL?_o`000?nU`nl01?nU`nl4o`000004ojG3kol0003oYL?_o`0002[o
oooo00?o0000ooooooooool06Oooool002gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0mooooo`[o000000CoW]cmo`000?l0003o00000onU`nl4o`0000;oTNGk00?o0000ojG3konU
`nl00onU`nl2o`0000GoY<Wc00Co0000ojG3konU`nooYL?_0ol00006ojG3k`03o`000?nU`nooYL?_
00?o00001_nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00?oYL?_00?o0000
ojG3kol000000_l000000onU`noo0000ojG3k`04ojG3k`Co00000_nU`nl00ol0003oYL?_ojG3k`03
ojG3k`Co00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`;o00001OnU`nl01?l0003oYL?_ojG3konU
`nl3o`0000GoYL?_00?o0000ojG3kol000000_l00002ojG3k`07o`000?nU`nooYL?_ojG3kol0003o
YL?_o`00000Yooooo`03o`000?oooooooooo01Wooooo000]ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool0>oooool>o`000003ojG3kol0003o000000Wo000000?oYL?_o`000?l00000
0_l000000om0`;7o0000ojC9l`03ojC9l`Co00000onQeOX00ol0003oYL?_ojG3k`03ojG3k`?o0000
0onU`nl00ol0003oYL?_ojG3k`03ojG3k`;o00001OnU`nl01?l0003oYL?_ojG3konU`nl3o`0000Go
YL?_00?o0000ojG3kol000000_l000000onU`noo0000ojG3k`04ojG3k`03o`000?nU`noo000000;o
000000?oYL?_o`000?nU`nl01?nU`nl00ol0003oYL?_o`000002o`000003ojG3kol0003oYL?_00Co
YL?_1?l00002ojG3k`03o`000?nU`nooYL?_00?oYL?_0_l00006ojG3k`04o`000?nU`nooYL?_ojG3
k`?o0000:Oooool00ol0003oooooooooo`0Hooooo`00;Oooool2o`0002Sooooo00?o0000oooooooo
ool0>?ooool7o`0000;oQ>Kd2?l00002onc^c003o`000?oZj<co000000;oj>7<0_l000001ooQfm3o
0000o`000?l0003ogM;>o`000?oIb//00ol000000onTbO?o0000o`000002olo0c0;o00001?nQeOX0
0ol0003oYL?_o`000002o`000003oj7Fn_l0003oYL?_00CoYL?_00?o0000ojG3kol000000_l00000
0onU`noo0000ojG3k`04ojG3k`Co00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`;o00001OnU`nl0
1?l0003oYL?_ojG3konU`nl3o`0000GoYL?_00Co0000ojG3konU`nooYL?_1?l00004ojG3k`03o`00
0?nU`noo000000;o00000_nU`nl00ol0003oYL?_ojG3k`02ojG3k`03o`000?nU`noo000000;o0000
0_nU`nl00ol0003oYL?_ojG3k`03ojG3k`Co000000?oYL?_o`000?l00000:Oooool00ol0003ooooo
ooooo`0Hooooo`00;?ooool2o`0002[ooooo00?o0000ooooooooool0=_ooool4o`0000;oKmoS1Ol0
00000ooXnlKo0000o`000002oncdbP06o`000?o/k/cok>k<o`000?oZj<co00000ooXhL`00ol0003o
iM[;o`000003omgBcP03o`000?oIb/_ofL[;00;ofL[;0_l00003olo0c0;o000000?oa;G<o`000?l0
00001?l00005oj7FnP04o`000?nU`nooYL?_ojG3k`?o00001OnU`nl00ol0003oYL?_o`000002o`00
0003ojG3kol0003oYL?_00CoYL?_00?o0000ojG3kol000000_l000000onU`noo0000ojG3k`04ojG3
k`Co00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`Co00001?nU`nl00ol0003oYL?_ojG3k`03o`00
00KoYL?_00?o0000ojG3konU`nl00ol00006ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`00
0?nU`nl00_nU`nl00ol0003oYL?_o`00000Yooooo`03o`000?oooooooooo01Oooooo000/ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0<oooool;o`0000;oj?_60_l00002oncdbP06
o`000?o/k/cok>k<o`000?oZj<co00000ooXhL`00ol0003oiM[;onGJb`02o`000003omgBc_l0003o
fL[;00CofL[;00Go0000olo0c?o?`<cocl3<o`000002olZhb@03o`000?o4]Lco000000?o`:k80_l0
0003oj7FnPGo00000onTbo@01?l0003oYL?_ojG3konU`nl3o`0000GoYL?_00Co0000ojG3konU`noo
YL?_0ol00005ojG3k`03o`000?nU`noo000000;o00000_nU`nl00ol0003oYL?_ojG3k`02ojG3k`03
o`000?nU`noo000000;o00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`?o00000onU`nl00ol0003o
YL?_ojG3k`03ojG3k`?o00000onU`nl00ol0003oYL?_ojG3k`03ojG3k`;o00001OnU`nl01?l0003o
YL?_ojG3konU`nl3o`0002Wooooo00?o0000ooooooooool05_ooool002cooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0_ooooo`go00000_oXnlH2o`0000;ok?C:00Co0000onc^c?o/
k/co00000_oZj<`01?l0003oj>7<onSQc?l00002onGJb`04o`000?oQdlWohM?9o`0000GofL[;00Go
0000omC2bOl0003ocl3<o`000004olZhb@03o`000?o0[/So`:k800;o`:k800?o0000okVZbol00000
0ol00002ojjOb003o`000?nTboCoY<_d00;oY<_d1?l00003ojG3k`03o`000?nU`nooYL?_00;oYL?_
1?l00003ojG3k`03o`000?nU`nooYL?_00;oYL?_0_l00006ojG3k`03o`000?nU`nooYL?_00?o0000
1_nU`nl00ol0003oYL?_o`000002o`000003ojG3kol0003oYL?_00CoYL?_00?o0000ojG3kol00000
0_l000000onU`noo0000ojG3k`04ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl0
1?nU`nl4o`000003ojG3kol0003o000002Wooooo00?o0000ooooooooool05_ooool002cooooo0ol0
000/ooooo`03o`000?oooooooooo02cooooo0_l00002ohcVn@Ko000000Kog?flo`000?l0003oiOc3
o`000?oXnlH9o`000005on[Xc?l0003oj>7<onSQc?l000000_oUf//01?l0003ohM?9on7CbOoQdlT2
o`0000?ofL[;00Go0000omC2bOoD`/Woe<;9o`000004olZhb@;o00001?o0[/P2o`0000Co]J?600Go
0000ojjOb?n^WlSo0000ojC;m002o`000003ojBEa_l0003o000000GoYL?_00Co0000ojG3kol0003o
00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o0000ojG3
konU`nl00onU`nl3o`0000?oYL?_00?o0000ojG3konU`nl00onU`nl2o`0000GoYL?_00Co0000ojG3
konU`nooYL?_0ol00005ojG3k`04o`000?nU`nooYL?_ojG3k`?o00001OnU`nl00ol0003oYL?_o`00
0002o`000003ojG3kol0003oYL?_00?oYL?_0_l0000Yooooo`;o00005_ooool002cooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0Xooooo`co000000Cog?flo`000?l0003oiOc30ol0
00001Oo^m<Co0000onoaa_o_lLKo000000;ok^c700Ko0000ongVaol0003o0000onSQc?l00003onGJ
b`04o`000?oQdlWohM?9o`0000;ogL_800?o0000omW:bol000000ooD`/T2o`0000?ob[S900Co0000
olJaaOo6/LGo00000_o0[/P00ol0003o_:O4o`000004okFSaP03o`000?n^WlSo000000?o00001?nT
ULH01?l0003oYL?_ojG3konU`nl3o`0000GoYL?_00Co0000ojG3konU`nooYL?_0ol00005ojG3k`03
o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl01?nU`nl00ol0003oYL?_o`000002o`000003
ojG3kol0003oYL?_00CoYL?_1?l00002ojG3k`03o`000?nU`nooYL?_00?oYL?_1?l00003ojG3k`04
o`000?nU`nooYL?_ojG3k`?o00001OnU`nl01?l0003oYL?_ojG3konU`nl3o`0002Sooooo0_l0000F
ooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0Sooooo`Co00000onReOX7o`000003omSm^_l0003o000000Co000000?o
kOS2o`000?l000000_o_lLH01?l0003ok^c7onk/aol00002ongVa`03o`000?o[h<Oo000000;o0000
00GoiM[;o`000?oQdlWohM?9o`000004omg;b005o`000?oD`/Woe<;9omC2bOl000000_o?^lH00ol0
003ob[S9o`000003olJaa@03o`000?o0[/So000000?o_:O400Co0000okFSa_neXlKo]J?60_l00004
oj^Ia004o`000?nTULKoY9G6ojBEaPGo000000?o@L6eo`000?nU`nl01?nU`nl4o`0000?oYL?_00Co
0000ojG3konU`nooYL?_0ol00005ojG3k`04o`000?nU`nooYL?_ojG3k`?o00001OnU`nl00ol0003o
YL?_o`000002o`000003ojG3kol0003oYL?_00CoYL?_00?o0000ojG3kol000000_l000000onU`noo
0000ojG3k`04ojG3k`Co00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`Co000000?oYL?_o`000?l0
0000:Oooool00ol0003oooooooooo`0Dooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo02oooooo0_l0000Qooooo`;o00000onU`nl:o`000003omSm^_l0003o0000
00;o000000Sojo[0o`000?o]n<;o0000onkda?l0003oko76o`0000;ok^c700Co0000ongVaoo]i/Oo
00000_o[h<L00ol0003oim[7onOJa`02o`000003on7CbOl0003ogL_800CogL_80_l000000ooD`/Wo
0000olnkaP03olnkaP03o`000?o6/LGoa[7500?oa[7500?o0000okbWa?nlYl@00_nlYl@01_l0003o
]J?6okFSa_l0003o/Yg3o`0000CoZiW400Go0000ojBEa_nTULKoY9G6o`000002oi^Ab0Go000000Ko
YL?_o`000?l0003o0000ohkTnol00005ojG3k`Co00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`Co
00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`;o00001OnU`nl01?l0003oYL?_ojG3konU`nl3o`00
00GoYL?_00?o0000ojG3kol000000_l000000onU`noo0000ojG3k`04ojG3k`03o`000?nU`noo0000
00;o000000?oYL?_o`000?nU`nl00onU`nl2o`0002Wooooo00?o0000ooooooooool04oooool00003
ooooool0003o000000Co00000_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`Go00001Oooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo01cooooo0_l00003ojG3k`Oo000000Co^oNbo`000?l0003odobh0ol000002?oXnkko0000on_j
`?l0003okOS2o`000?o^m<Co00000_o_lLH00ol0003ok^c7o`000002ongVa`04o`000?o[h<Oojn37
o`0000?oim[700?o0000onCCa_l000001OoMblP01?l0003of<C6omS4a_l00004olnkaP;o00001?o6
/LD2o`0000Co_:O400?o0000okFSa_l000000onbWL<01Ol0003oZiW4oj^Ia?n[VLCo000000;oY9G6
1?l00002oi^=``03o`000?nCR<GoThS500?o00000on>i?/00ol0003oYL?_o`000002o`0000;oYL?_
00?o0000ojG3konU`nl00_nU`nl00ol0003oYL?_o`000002o`000003ojG3kol0003oYL?_00CoYL?_
00?o0000ojG3kol000000_l000000onU`noo0000ojG3k`04ojG3k`Co00000_nU`nl00ol0003oYL?_
ojG3k`03ojG3k`;o00001OnU`nl01?l0003oYL?_ojG3konU`nl3o`0000GoYL?_00Co0000ojG3konU
`nooYL?_0ol0000Yooooo`03o`000?oooooooooo01;ooooo0009ooooo`05o`000?oooooooooooooo
ool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00CoA4A4omgMgOoooooo00001_oo
ool3o`0003?ooooo00?o0000ooooooooool06?ooool3o`000003ojG3kol0003o000000Co000000Co
ONG9o`000?l0003o^?Nc0ol000003?oCo;So0000o`000?l0003oj?^no`000?o[n/3o0000ongh`_l0
003ok_C4o`0000;oko7600?o0000onk/aol000000oo]i/L00ol0003ojn37o`000003onOJa`03o`00
0?oTdlKoi=?600;o00000ooMblP01Ol0003of<C6omS4a_oHa<Ko000000?ock_600Co0000ol^d`oo;
]<?o00000_o6/LD01?l0003o`J[3ol6Z`ol00003okbWa0;o00001?nbWL<01?l0003oZiW4oj^Ia?n[
VL@3o`0000;oXY3200?o0000oi^=`onKSL<00_nKSL<01?l0003oThS5oi>8aOnCR<D6o`0000KoYL?_
00?o0000ojG3konU`nl00ol00005ojG3k`04o`000?nU`nooYL?_ojG3k`?o00001OnU`nl00ol0003o
YL?_o`000002o`000003ojG3kol0003oYL?_00CoYL?_00?o0000ojG3kol000000_l000000onU`noo
0000ojG3k`04ojG3k`Co00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`Co000000CoYL?_o`000?nU
`noo0000:?ooool00ol0003oooooooooo`0Booooo`002Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go0000ooooooooooooooooo`000003ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0Dooooo`Co000000?oYL?_o`000?l000000_l0
00000onU`noo0000o`000003o`000004okSg/ol0003o0000om3l]`?o000000?oiOblo`000?l00000
0_o[n/02o`0000;ok_C41ol000001?o]i/Oo0000on_Paol00003onOJa`04o`000?oTdlKoi=?6o`00
00;oh<c500?o0000omg;b?l000000ooHa<H01Ol0003oe;g4o`000?o?^lKo000000?obkC300?o0000
olJaaOl000000oo1Z/<01_l0003o_:O4okbWa?l0003o^:71o`0000Co/Yg300Ko0000oj^Ia?l0003o
0000ojVD`Ol00004oj:@`P05o`000?nKSL?oVhg3oi^=`ol000000onCR<D00ol0003oRhC6oh^4aP02
oh^4aP;o00001OnU`nl3o`0000?oYL?_00?o0000ojG3konU`nl00_nU`nl4o`0000?oYL?_00Co0000
ojG3konU`nooYL?_0ol00005ojG3k`04o`000?nU`nooYL?_ojG3k`?o00001OnU`nl00ol0003oYL?_
o`000002o`000003ojG3kol0003oYL?_00CoYL?_00?o0000ojG3kol000000_l000000onU`noo0000
ojG3k`03ojG3k`?o0000:?ooool00ol0003oooooooooo`0Aooooo`002Oooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4004ooooo`03ogMgMoo<c<co000000Ko
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0@ooooo`?o00000_nU`nl3o`0000;o
YL?_1_l000001OngmkKo0000o`000?l0003od?bg00;o000000KohOfko`000?l0003oj?^no`000?o[
n/06o`000004oo7^`ol0003ol>[3o`0000;oknG41Ol000001OoWf/Oo0000onCCa_oTdlKo000000Co
h<c500Go0000omS4a_oHa<Kof<C6o`000003omBma003o`000?o;]<?obkC300?obkC300?o0000ol6Z
`oo1Z/<00_o1Z/<00ol0003o_:O4o`000003okRQ`@04o`000?nbWL?o/Yg3ok:M``;o00001?nYU<40
1Ol0003oXY32oj:@`_nRT<;o000000?oVhg300Go0000oi>8aOnCR<GoThS5o`000004oh^4aP04o`00
0?n1OlSo0000ojG3k`Go00001OnU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_
00;oYL?_1?l00003ojG3k`03o`000?nU`nooYL?_00;oYL?_1?l00003ojG3k`04o`000?nU`nooYL?_
ojG3k`?o00001OnU`nl01?l0003oYL?_ojG3konU`nl3o`0000GoYL?_00?o0000ojG3kol000001?l0
000Yooooo`03o`000?oooooooooo013ooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?ok^k^odA4A?l000001_ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo00cooooo0ol00002ojG3k`?o00000_nU`nl3o`0000?oWMgm
0_l000001OngmkKo0000o`000?l0003od?bg00;o000000CohOfko`000?l0003oj?^n0ol000002Oo`
mL3o0000oo3b`Oo`l/7o0000oo7^`ol0003ol>[3o`000003onoUa003o`000?o/glCo000000;oj][4
00Go0000onCCa_oTdlKoi=?6o`000004on3<a@;o000000?of<C6o`000?oD_L@00ooD_L@00ol0003o
bkC3ol^d``02ol^d``;o00001?o1Z/<2o`0000Go^:7100Go0000ok:M`ol0003o[iRoo`000004ojVD
`@05o`000?nRT<;oXY32oj:@`_l000000_nKSL<?o`0000;oMg_:0ol00003ojG3k`?o00001OnU`nl0
1?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00?oYL?_00Co0000ojG3kol0003o0000
0_nU`nl00ol0003oYL?_ojG3k`02ojG3k`Co00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`Co0000
0_nU`nl00ol0003oYL?_ojG3k`03ojG3k`;o00000onU`nl00ol0003oYL?_o`00000Xooooo`03o`00
0?oooooooooo013ooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo00?oMgMgo`000?ooool01Oooool2o`0003Sooooo00?o0000oooooooo
ool02?ooool3o`0000;oYL?_0ol000000onU`noo0000ojG3k`02o`0000?oYL?_00Co0000oigMoOl0
003o/?WX1?l000000oo@o;Oo0000omkm^P02o`000005onGl_?l0003o0000o`000?o^mkl00_l00002
oo3b`@03o`000?oak/?o000000;ol>[300Ko0000onoUa?o_iLCo0000oncOa?l00003on[Ja0;o0000
00?oi=?6o`000?oPc<D00ooPc<D01?l0003og<K3omc6`ol00004omBma003o`000?o?]l;o000000;o
bkC300Co0000olJ^`Oo6[/7o00000_o1Z/<00ol0003o_JC0o`000005okRQ`@;o00000on_V;l00ol0
003oZIC1ojVD`@02ojVD`@03o`000?nRT<;oXY3200?o00000_nKRKl01Ol0003oU8G1oiB5`OnDQL7o
000000CoSH;200?o0000ohEna?n5O/@01?l000000omgNl[o0000o`000002o`0000?oVmgm00Co0000
ojG3konU`nooYL?_0ol00005ojG3k`04o`000?nU`nooYL?_ojG3k`?o00001OnU`nl01?l0003oYL?_
o`000?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_00?o0000ojG3kol000000_l000000onU`noo
0000ojG3k`04ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl00onU`nl3o`0002So
oooo0_l0000@ooooo`00:_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Cooooo
0ol00002ojG3k`?o00001?nU`nl2o`0000GoYL?_0_l000000on`nNSo0000o`000004o`00000?omkm
^_l0003o0000onGl_?l0003ok?Vmo`000?o^mkoo0000oo3e`?l0003ol?;1o`000?oak/?o000000;o
l>[300Co0000onoUa?o_iLCo00000_o/gl@01?l0003oj][4on[Ja?l00002onKD``;o00000ooPc<D0
1Ol0003og<K3omc6`ooLa/?o000000?oe;g400Ko0000olng`_o?]l;o0000ol^d`ol00003olJ^`@03
o`000?o1Z/?o000000?o_JC000Oo0000okRQ`OnhXL7o^:71o`000?neW;ko000000Co[iRo00Wo0000
ojVD`OnYU<7oZIC1o`000?nRT<;o0000oj6=__l000001?nKRKl01Ol0003oU8G1oiB5`OnDQL7o0000
00CoSH;200Co0000ohEna?n5O/Co00000_mlN/D4o`0000?oVmgm1Ol00002ojG3k`03o`000?nU`noo
YL?_00?oYL?_1?l00002ojG3k`03o`000?nU`nooYL?_00?oYL?_0_l00005ojG3k`03o`000?nU`noo
YL?_00?o00001OnU`nl01?l0003oYL?_ojG3konU`nl3o`0000GoYL?_00?o0000ojG3kol000001?l0
000Yooooo`03o`000?oooooooooo00kooooo000Zooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool00ol00002ojG3k`?o00000_nU`nl00ol0003oYL?_o`000002o`0000;oYL?_00Go0000
ojG3konU`nooYL?_o`000002ok3ij0Go000000?ofofjo`000?l000000ol000001_o/nKgo0000onkg
_ol0003ol?G0o`0000;ol?;100Go0000oo7^`ol0003ol>[3o`000003onoUa003o`000?o/glCo0000
00?oj][400So0000onKD`ooVe<?o0000on?>`ol0003oh<c5o`0000?og<K300Go0000omRo`_l0003o
e;g4o`000004olng`P03o`000?o6[/7oaZk100?oaZk100?o0000okfT`?nmY<000onmY<000ol0003o
^:71o`000003okFL_P05o`000?n_V;oo[iRoojnH_ol000000_nYU<43o`0000?oXHfn00Go0000oi^9
_onKRKooVhVoo`000003oiB5`@03o`000?n=P/;oSH;200;oSH;200Go0000ohEna?n5O/CoQGk4o`00
0002ogaja@03o`000?mcM/OoLgK700?o000000?oH77=o`000?l000001OnU`nl00ol0003oYL?_o`00
0002o`000003ojG3kol0003oYL?_00CoYL?_00?o0000ojG3kol000000_l000000onU`noo0000ojG3
k`04ojG3k`?o00000onU`nl00ol0003oYL?_ojG3k`02ojG3k`Co00000onU`nl01?l0003oYL?_ojG3
konU`nl3o`0000CoYL?_0_l0000Xooooo`03o`000?oooooooooo00kooooo000Zooooo`03o`000?oo
oooooooo03[ooooo0ol00003ojG3k`Co00000_nU`nl4o`0000GoYL?_00?o0000ojG3kol000000_n`
nNP4o`0000;ofofj1?l000001ooZn[co0000o`000?o^mkoo0000oo3e`?l000000_o`l/400ol0003o
lNk3o`000002oo3Z``06o`000?o_iLCoknG4o`000?o/glCo00000ooZf/@01?l0003oi]C3onKD`ol0
0003on?>``05o`000?oLa/?og<K3omc6`ol000000ooH_l800ol0003ockO2olng`P03olng`P03o`00
0?o6[/7oaZk100?oaZk100?o0000okfT`?nmY<001?nmY<000ol0003o]IbnokFL_P02okFL_P04o`00
0?n_V;oo[iRoojnH_`?o00000_nWT;d01Ol0003oXHfnoj6=__nQSKko000000CoVhVo00Go0000oiB5
`OnDQL7oU8G1o`000003ohf2`P05o`000?n5O/CoQGk4ohEna?l000000omlN/D01Ol0003oLgK7og=f
aol0003oJW;900;o000000?oDfc>o`000?nU`nl00_nU`nl3o`0000GoYL?_00Co0000ojG3konU`noo
YL?_0ol00005ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl01?nU`nl01_l0003o
YL?_o`000?l0003oYL?_o`0000GoYL?_1?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol0000X
ooooo`03o`000?oooooooooo00gooooo000Zooooo`;o0000>?ooool3o`0000?oYL?_0ol00003ojG3
k`?o00001?nU`nl01?l0003oYL?_ojG3konU`nl8o`000003omWm^ol0003ofofj00;o000000?oj?^l
o`000?oZn[`00_l00002onkg_`03o`000?o`mL3o000000_o000000Gok=o4o`000?oZf/Coj][4o`00
0002onKD``03o`000?oSc/?ohlk300;ohlk30_l000000ooLa/?o0000omRo`P03omRo`P03o`000?o?
]l;ockO200;ockO200?o0000ol^a`?l000000oo6[/400ol0003o`ZRoo`000004okfT`0;o00001?ne
W;h01_l0003o[iRoojnH_ol0003o[I>lo`0000CoYi2m00Go0000oj6=__nQSKkoXHfno`000003oi^9
_`05o`000?nDQL7oU8G1oiB5`Ol000001?n=P/801?l0003oQGk4ohEna?l00003ogaja@05o`000?mc
M/OoLgK7og=faol000000_mZL/T5o`0000;oRNCi00?o0000ojG3konU`nl00onU`nl4o`0000?oYL?_
00Co0000ojG3konU`nooYL?_0ol00005ojG3k`04o`000?nU`nooYL?_ojG3k`?o00001?nU`nl00ol0
003oYL?_o`000002o`000003ojG3kol0003oYL?_00CoYL?_00?o0000ojG3kol000001?l0000Xoooo
o`03o`000?oooooooooo00gooooo000Zooooo`03o`000?oooooooooo03Gooooo0_l00002ojG3k`Co
000000?oYL?_o`000?nU`nl00ol00002ojG3k`03o`000?nU`nooYL?_00;oYL?_1?l00003ojG3k`07
o`000?o:olco0000o`000?oIoK_o0000om_m^P02o`000007onSk_?l0003oj_Zlo`000?o/nKgo0000
onkg_`04o`000004oo;`_ol0003ol^c0o`0000;olNS100Go0000oo3T`Oo`i<7o0000onkO`P03o`00
0005on[Ja?l0003oi]C3onKD`ol000000ooSc/<01?l0003oglO2omo7`_l00004omRo`P03o`000?oC
^L7o000000;ockO200Oo0000ol^a`?o;/L3obk70o`000?o6[/7o000000?o`ZRo00Co0000okfT`?nm
Y<3o00000_njWkd00ol0003o]IbnokFL_P02okFL_P;o00000on]Tk`01Ol0003oYi2mojN@_OnWT;go
000000?oXHfn00?o0000oi^9_onKRKl04_l00003og=fa`05o`000?mZL/WoJW;9o`000?mPKl/00_l0
00000om7Iloo0000o`000002o`000006ojG3kol0003o0000o`000?nU`noo00001OnU`nl4o`0000;o
YL?_00?o0000ojG3konU`nl00onU`nl4o`0000?oYL?_00?o0000ojG3konU`nl00ol00005ojG3k`04
o`000?nU`nooYL?_ojG3k`?o00001?nU`nl2o`0002Sooooo00?o0000ooooooooool03?ooool002[o
oooo00?o0000ooooooooool0<_ooool3o`0000;oYL?_1?l00002ojG3k`Co00001OnU`nl01?l0003o
YL?_o`000?l00002ojG3k`08o`000?nU`nooYL?_ojG3kol0003ob_o<o`000?oHo/42o`000005om_m
^_l0003oiOblo`000?oXnk`00_l000000oo/nKgo0000o`000002o`000006oo7b__l0003ol_2oo`00
0?obk<3o00000_oaj<401?l0003ol>C1oo3T`Ol00002onkO`P03o`000?o[f/;ojm[200;o000000?o
i]C3o`000?oSc/<00_oSc/<01Ol0003oglO2omo7`_oOal;o000000?of;o200Ko0000om>i`OoC^L7o
0000olng`_l00005ol^a`003o`000?o2Z;oo`ZRo00;o`ZRo00?o0000okfT`?l000000onjWkd01?l0
003o]IbnokFL__neW;h2o`0000Co[I>l00Go0000ojN@_OnWT;goYi2mo`000003oj6=_P?o00000_nK
Q[`01Ol0003oUH>moiF3_OnEPkgo000000?oSh2o00Go0000ohQm`?n8OL3oR7g0o`000002oh5j`PGo
00000omZL/T00ol0003oH6o;of1_b`02o`0000;oAfO?0ol00004ojG3k`03o`000?nU`noo000000;o
000000?oYL?_o`000?nU`nl01?nU`nl00ol0003oYL?_o`000002o`000003ojG3kol0003oYL?_00Co
YL?_0ol00003ojG3k`03o`000?nU`nooYL?_00;oYL?_1?l00003ojG3k`04o`000?nU`nooYL?_ojG3
k`?o0000:?ooool00ol0003oooooooooo`0;ooooo`00:Oooool00ol0003oooooooooo`0`ooooo`?o
00000_nU`nl3o`0000?oYL?_0ol00004ojG3k`04o`000?nU`nooYL?_ojG3k`?o00001OnU`nl00ol0
003oYL?_o`000002o`000003omSn`Ol0003ofOfk00;o000000?oiOblo`000?oXnk`01Ol000001_o`
mKgo0000oo7b__l0003ol_2oo`0000;ol^c000?o0000oo7X`Ol000000_o`i<401?l0003ok]o2onkO
`_l00003on_J`P03o`000?oXe<7o000000?ohlk300Wo0000omo7`_oOal;oglO2o`000?oK`/7o0000
omRo`_l000001?oC^L400ol0003obk70ol^a`003ol^a`0;o00001?o2Z;l2o`0000Co^Ynm00Ko0000
okFL__neW;ko0000ok:G_?l00004ojfC_003o`000?nWT;goYi2m00;oYi2m0ol000000onPRK_o0000
oi^6_002oi^6_003o`000?nEPkgoUH>m00;oUH>m00Go0000ohn0_on?P;ooSh2oo`000003ohQm`004
o`000?n1N/;oPG[2o`0000;oNWO30ol000001_mZL/Wo0000of1_bomPKl_o0000oeI/c@?o00000_lj
Hm000ol0003oYL?_ojG3k`03o`0000GoYL?_00Co0000ojG3konU`nooYL?_0ol00005ojG3k`03o`00
0?nU`noo000000;o000000?oYL?_o`000?nU`nl01?nU`nl01_l0003oYL?_o`000?l0003oYL?_o`00
00GoYL?_1?l000000onU`noo0000o`00000Xooooo`03o`000?oooooooooo00_ooooo000Yooooo`?o
0000;Oooool3o`0000;oYL?_0ol00002ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o0000ojG3
konU`nl00_nU`nl4o`0000?oYL?_00?o0000ojG3konU`nl00_nU`nl3o`000006ojG3kol0003o0000
omWm^ol0003ohobl0_l000002?oXnkco0000o`000?l0003okoNmo`000?o`mKgo00000_oal[h2o`00
00;ol^c000Ko0000oo7X`Ooaj<7o0000oo3T`Ol00002onkO`P05o`000?o[f/;ojm[2on_J`_l00000
0_oXe<42o`000003on?>`ol0003oglO200;oglO200Go0000om_2`OoK`/7ofl;1o`000004om>i`@03
o`000?o?/koo000000?obk7000Co0000olN[__o7Zkko00000_o2Z;l00ol0003o_Z:mo`000005okZO
_@;o00000onbUk`00ol0003o[I>lojfC_002ojfC_003o`000?nWT;go000000;o00000onPRK/00ol0
003oVhJloi^6_002oi^6_005o`000?nEPkgoUH>moiF3_Ol000000on?P;l01Ol0003oR7g0ohQm`?n8
OL3o000000?oPG[200Go0000ogYg`omjMl?o0000og9da@02o`0000?oH6o;00Co0000oeI/cOmFK<go
EVc=0_l000000oljHm3o0000o`000003oh;TmP03o`000?nU`nooYL?_00;oYL?_1?l00003ojG3k`04
o`000?nU`nooYL?_ojG3k`?o00001OnU`nl01?l0003oYL?_ojG3konU`nl3o`0000CoYL?_00?o0000
ojG3kol000000_l000000onU`noo0000ojG3k`03ojG3k`;o0000:?ooool00ol0003oooooooooo`0:
ooooo`00:Oooool00ol0003oooooooooo`0Zooooo`?o00000_nU`nl3o`000004ojG3kol0003oYL?_
ojG3k`Co00001?nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00?oYL?_00Co
0000ojG3kol0003o00000onU`nl01Ol0003of?k1o`000?l0003ohobl00;o00000_oXnk`2o`00000;
onog_Ol0003ol?Fmoo3e_Ol0003olO:no`000?obl;oo0000oo;/`?l000000_oaj<401?l0003ol>C1
oo3T`Ol00002onkO`P04o`000?o[f/;ojm[2o`0000;oj=C100?o0000onG?`OoUcl400_l00003omo7
`P05o`000?oK`/7ofl;1om_2`Ol000000ooC^L401ol0003ock>oolnc_oo?/koo0000ol^a`?l00000
0oo7Zkh00ol0003o`ZRoo`000003okjR_@04o`000?njWkgo^YnmokZO_@;o00001?nbUk`01?l0003o
[I>lojfC_?n]Tk`3o`0000;oYHfk00?o0000oj29^onPRK/00_nPRK/01Ol0003oVhJloi^6_?nKQ[co
000000?oUH>m00Go0000ohn0_on?P;ooSh2oo`000003ohQm`005o`000?n1N/;oPG[2oh5j`_l00000
0omjMl<00ol0003oLWC5og9da@02o`0000;oH6o;00Go0000oeI/cOmFK<go0000odaYc`02o`000003
obiOdOl0003o000000?o000000GoYL?_o`000?l0003oYL?_o`000005ojG3k`Co00000_nU`nl00ol0
003oYL?_ojG3k`03ojG3k`Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000GoYL?_00Co0000ojG3
konU`nooYL?_0ol0000Vooooo`?o00002oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo1Ol00006ooooo`03o`000?oo
oooooooo02Oooooo0ol00002ojG3k`?o00001?nU`nl3o`0000CoYL?_00?o0000ojG3konU`nl00ol0
0005ojG3k`04o`000?nU`nooYL?_ojG3k`Co00000onU`nl01?l0003of?k1o`000?oRoL<7o`0000;o
koNm00Oo0000oo3e_Ol0003olO:no`000?obl;oo000000;ol^c01?l000001Oo`i<7o0000onkO`_o^
gl;o000000;ojm[200Co0000onSD`OoXe<7o00000ooUcl401Ol0003ohLW0o`000?oOal;o000000?o
fl;100Go0000omJl_ol0003odkW1o`000005olnc_`03o`000?o7Zkkoaj^n00?oaj^n00?o0000okjR
_OnnX[d00_nnX[d01_l0003o^YnmokZO_Ol0003o]YZko`0000Co/YNl00Ko0000ojfC_?n]Tkco0000
ojZ@^_l00004ojF=^`05o`000?nPRK_oX8Vkoj29^ol000000onKQ[`00ol0003oUH>moiF3_@02oiF3
_@05o`000?n?P;ooSh2oohn0_ol000000on8OL001?l0003oPG[2oh5j`_l00003ogYg``05o`000?mb
M<GoLWC5o`000?m[LLL00ol00003oeI/c@03o`000?m<JLooC6W?00;o000000?o;UoAo`000?lSGM80
0_l00004ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl01?nU`nl00ol0003oYL?_
o`000002o`000003ojG3kol0003oYL?_00CoYL?_0ol00002ojG3k`03o`000?nU`nooYL?_00?oYL?_
1?l000001?nU`noo0000ojG3kol0000Rooooo`?o00000_ooool00ol0003oooooooooo`09ooooo`00
1_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool09Oooool2
o`0000;oYL?_0ol00002ojG3k`03o`000?nU`noo000000;o00000_nU`nl00ol0003oYL?_ojG3k`02
ojG3k`?o00000onU`nl00ol0003oYL?_ojG3k`02ojG3k`Co00001?nU`nl00ol0003oYL?_o`000002
o`000003on;m`ol0003o000000;o00000_o/nK`2o`000004onog_Ol0003ol?Fmo`0000;olO:n1_l0
00000oobikoo0000oo3S`005o`000003on_J`_l0003oj=C100;oj=C100Co0000onG?`OoUcl7o0000
0ooQbL001Ol0003ofl;1om_2`OoK`/7o000000?oe[bo00?o0000olnc_oo?/kl01?o?/kl00ol0003o
aj^nolN[_P03olN[_P03o`000?nnX[go_Z:m00;o_Z:m00?o0000okZO_Ol000000onfV[/00ol0003o
/YNlok:G_002ok:G_0;o00000_nZT;X00ol0003oYHfkojF=^`02ojF=^`05o`000?nPRK_oX8Vkoj29
^ol000001?nKQ[`00ol0003oUH>mo`00000<o`000005oh5j`_l0003oNWO3ogYg`ol000000ombM<D0
1?l0003oJg77of]aaom[LLL2o`000006oeI/cOl0003oC6W?odaYcol0003o@VOA0ol000000olSGM;o
0000o`000002ojG3k`?o00001OnU`nl01?l0003oYL?_ojG3konU`nl3o`0000GoYL?_00?o0000ojG3
kol000000_l000000onU`noo0000ojG3k`03ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`00
0?nU`nl00onU`nl3o`0001kooooo0ol00005ooooo`03o`000?oooooooooo00Wooooo0004o`0000;o
oooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41001?ooool0
0onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo02;ooooo1?l000000onU`noo0000o`000002
o`0000;oYL?_1?l00005ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o0000ojG3konU`nl00_nU
`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00?oYL?_1?l000001OoRoL?o0000
o`000?oZn[go000000;ok?Vl0_l000001?o_mkgo0000oo3e_Oo`mKd3o`000007oo?^__l0003ol^^o
oo;[_ol0003ol^Noo`000002oo3S`005o`000?o_gl3okmo0o`000?o/f/000ol000001OoXe<7o0000
onG?`OoUcl7o000000CohLW000Go0000om_2`OoK`/7ofl;1o`000003omJl_`03o`000?o?/koock>o
00?ock>o00?o0000ol^^_Ol000000oo7Zkh00ol0003o`jJlo`000003okjR_@;o00001?nfV[/01?l0
003o/YNlok:G_?nbUk`2o`0000CoZY2j00Go0000ojF=^onUSK_oYHfko`000004oj29^`03o`000?nK
Q[co000000?o00000_nFPK/01Ol0003oT7jloi1n_?n@O[co000000?oRgbm00?o0000ohEi__n5NKh0
1?l000001OmjMl?o0000og9daOmbM<Go000000?oJg7700Co0000of=_b_l0003o00000om<JLl01?l0
003o@VOAod9WdOl00002ob=MdP?o00000on;i?/00ol0003oYL?_ojG3k`02ojG3k`Co00000onU`nl0
1?l0003oYL?_ojG3konU`nl3o`0000GoYL?_00?o0000ojG3konU`nl01?l00004ojG3k`03o`000?nU
`noo000000Co00006_ooool4o`0000Sooooo00?o0000ooooooooool02Oooool000Kooooo00Go0000
ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000001Oooool00onHV9So8B4Q
onk^kP05ooooo`?o00008?ooool3o`0000;oYL?_0ol00002ojG3k`Co00001?nU`nl01?l0003oYL?_
ojG3konU`nl3o`0000GoYL?_00?o0000ojG3konU`nl01?l00004ojG3k`03o`000?nU`noo000000;o
00000_nU`nl01_l0003oh_g3o`000?l0003oj_Zmo`0000;ok?Vl0_l00002onog_@Co000000?ol_6m
o`000?l000000_objkl00ol0003ol^Noo`000002oo3S`004o`000?o_gl3okmo0o`0000;ok=[000Co
0000on[E`?oZeL3o00000ooUcl402Ol0003ohLW0on79`?oQbL3o0000omg4`?l0003ofl;1o`000003
omJl_`03o`000?oB][ko000000?ock>o00Co0000ol^^_Oo;[[go00000_o7Zkh01?l0003o`jJlol>V
_?l00002okjR_@03o`000?nkW[_o000000Co]YZk00Ko0000ok:G_?l0003o0000ojnC^_l00004ojZ@
^P03o`000?nUSK_oYHfk00;oYHfk00?o0000oj29^ol000000ol00002oi^4^P05o`000?nFPK_oUX6k
oiJ1^ol000000on@O[`01Ol0003oRgbmoh]l_On;O;go000000?oQGVn00?o0000ogmg`?moMl001Ol0
0004of]aa`03o`000?mSKl[oHfo:00;o000000?oC6W?o`000?m2Im400_m2Im43o`000003oaULdol0
003o000000Co000000GoYL?_o`000?l0003oYL?_o`000005ojG3k`Co00000_nU`nl00ol0003oYL?_
ojG3k`03ojG3k`?o00001?nU`nl00ol0003oYL?_ojG3k`03o`0000CoYL?_0_l0000Fooooo`?o0000
3?ooool00ol0003oooooooooo`09ooooo`001_ooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000ooooooooooooooooo`000006ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000oooooooo
ool07Oooool3o`0000;oYL?_0ol00002ojG3k`?o00000onU`nl00ol0003oYL?_ojG3k`02ojG3k`Co
00000onU`nl01?l0003oYL?_ojG3konU`nl4o`0000CoYL?_00?o0000ojG3konU`nl01?l00003ojG3
k`0:o`000?oRoL?o0000onOjcOl0003oj_Zmo`000?o/nKco0000onkh_0Co000000Kol_>mo`000?ob
lKgo0000oo?^__l00002oo;[_`;o00000oo`hl001_l0003okmo0onoO`?l0003ok=[0o`0000?oj]G0
0_l000000ooUcl7o0000on79`002on79`005o`000?oMa<3ogLC0omg4`?l000000ooF_;l01ol0003o
d[Jnom:f__oB][ko0000olnc_ol000000oo;[[d00ol0003oaj^no`000003ol>V_003o`000?nnX[go
000000?o^ijk00Co0000okJJ^onfV[_o]YZk0_l00004ojnC^P05o`000?nZT;[oZY2jojZ@^_l00000
0onUSK/3o`0000;oWhNi00Go0000oi^4^_nKQ;[oVhBjo`000004oiJ1^`05o`000?n@O[coT7jloi1n
_?l000000on;O;d01Ol0003oQGVnohEi__n5NKko000000;oOgO000?o0000ogYe`_mjML800ol00002
of]aa`05o`000?mSKl[oHfo:o`000?mKKL`00_l00003od9Wd@04o`000?liIM?o0000o`0000;o6EcC
1Ol00004ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl01?nU`nl00ol0003oYL?_
o`000002o`000003ojG3kol0003oYL?_00CoYL?_0ol00002ojG3k`03o`000?nU`nooYL?_00;oYL?_
0ol0000Booooo`?o00004?ooool00ol0003oooooooooo`08ooooo`001_ooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool06_ooool4o`000007ojG3kol0003o0000o`000?nU`noo0000ojG3k`02
o`0000;oYL?_00?o0000ojG3konU`nl00_nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU
`nooYL?_00;oYL?_1?l00003ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol00004ojG3k`03o`000?nU
`noo000000;o000000Coio[=o`000?oZn[go00000_o/nK`3o`000008oo7e_Ol0003ol_>mo`000?ob
lKgo0000oo?^__l00002oo;[_`03o`000?obikoo000000;ol>?000Co0000onoO`?o_gl3o00000_o/
f/001?l0003oj]G0on[E`?l00002onO@`0;o00000ooQbL001Ol0003ogLC0omg4`?oMa<3o000000?o
e[bo00?o0000om:f__oB][h00_oB][h00ol0003objjmol^^_@03ol^^_@03o`000?o3Y[co`jJl00?o
`jJl00?o0000ok^N^onkW[/00_nkW[/01_l0003o]YZkokJJ^ol0003o/iJio`0000Co[i>j00?o0000
ojZ@^_nZT;X00_nZT;X3o`000003ojB9^?l0003oWhNi00?oWhNi00Go0000oi^4^_nKQ;[oVhBjo`00
0003oiJ1^`05o`000?n@O[coT7jloi1n_?l000000on;O;d01Ol0003oQGVnohEi__n5NKko000000?o
OgO000Go0000ogYe`_mjML;o0000og=ca003o`0000?oHfo:00?o0000oe]]c?mKKL`00_l00002od9W
d@03o`000?liIM?o000000?o6EcC1Ol00002ojG3k`Co00001?nU`nl01?l0003oYL?_ojG3konU`nl3
o`0000GoYL?_00?o0000ojG3kol000000_l000000onU`noo0000ojG3k`03ojG3k`03o`000?nU`noo
000000Co00003_ooool4o`0001?ooooo00?o0000ooooooooool02?ooool000Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Ol0003o^[Zjoooo
oonHV9So410@00Gooooo00?o0000ooooooooool05oooool3o`0000;oYL?_0ol00003ojG3k`?o0000
1OnU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00Co0000ojG3kol0003o00000_nU`nl00ol0003o
YL?_ojG3k`03ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o0000ojG3konU`nl00_nU`nl3o`00
0003ojG3kol0003oio[=00;o00000_o/nK`02ol0003okoJmo`000?oamKgo0000oo;c_Ol0003ol_6m
o`000?ock[ko000000;ol^^o00?o0000oo;W_ol000000_o`hl001?l0003okmo0onoO`?l00002oncJ
`005o`000?oZeL3oj]G0on[E`?l000000_oWd<001Ol0003ohl_0o`000?oQbL3o000000?ogLC000Go
0000omVn_ol0003oe[boo`000005om:f_P03o`000?o;[[gobjjm00;objjm0_l00004ol>V_0;o0000
1?nkW[/00ol0003o]YZko`000003ok>F^@05o`000?n_Tk[o[i>jojnC^_l000000onZT;X2o`0000?o
Y8Vh00?o0000oin7^OnOQkT00_nOQkT01Ol0003oVhBjoi^4^_nKQ;[o000000?oUX6k00Go0000oi1n
_?n@O[coT7jlo`000003oh]l_@05o`000?n5NKkoQGVnohEi__l000000omoMl001Ol0003oNWG2ogYe
`_mjML;o000000?oLg?40_l000001_mSKl[o0000oe]]c?mKKLco0000oe=/c`?o00000_liIM<2o`00
0003oaULdol0003o4UcD00;o000000?o04?1o`000?l000001?nIgOh00ol0003oYL?_ojG3k`05o`00
00?oYL?_00Co0000ojG3konU`nooYL?_0ol00005ojG3k`03o`000?nU`nooYL?_00?o00001?nU`nl2
o`0000[ooooo0ol0000Gooooo`03o`000?oooooooooo00Sooooo0006ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c005ooooo`;o00005_ooool2o`0000;oYL?_0ol00002ojG3k`Co00000onU`nl00ol0003oYL?_
ojG3k`02ojG3k`?o00001?nU`nl00ol0003oYL?_ojG3k`03o`0000GoYL?_00Co0000ojG3konU`noo
YL?_1?l00004ojG3k`04o`000?nU`noo0000o`0000?oYL?_00Co0000onOjcOl0003oj_Zm0ol00000
1_o_m[go0000oo7e_Ol0003ol_>mo`0000;ol_6m00?o0000oo?^__l000000_objkl4o`000007oo3S
`?l0003okmo0onoO`?l0003ok=[0o`000003on[E`004o`000?oWd<3oim30o`0000?ohl_000Go0000
omg4`?oMa<3ogLC0o`000003omVn_`03o`000?oB][kod[Jn00?od[Jn00?o0000olja_Ol000000_o;
[[d01?l0003oaZVlolJY_?l00002ol>V_004o`000?noXK_o_j6ko`0000Co^ijk00?o0000ok>F^Onc
U[T00_ncU[T00ol0003o[i>jojnC^P02ojnC^P?o000000?oZ8bho`000?nTRKP00onTRKP01Ol0003o
WhNioin7^OnOQkWo000000?oVhBj00?o0000oiJ1^onFPK/00_nFPK/01Ol0003oT7jloi1n_?n@O[co
000000?oRgbm00Go0000ohEi__n5NKkoQGVno`000002ogmg`005o`000?mjML;oNWG2ogYe`_l00000
0omcLl@01?l0003oKG;7o`000?l00003oe]]c004o`000?mCK<ooDfc?oe=/c`?o000000Go<FGEo`00
0?l0003o0000oa9Le004o`0000?oVMgn1?l00002ojG3k`03o`000?nU`nooYL?_00?oYL?_1?l00003
ojG3k`04o`000?nU`nooYL?_ojG3k`Co00000onU`nl01?l0003oYL?_ojG3konU`nl3o`0000Kooooo
0ol0000Jooooo`03o`000?oooooooooo00Sooooo000Xooooo`03o`000?oooooooooo01;ooooo1ol0
00000onU`noo0000ojG3k`02o`0000;oYL?_00?o0000ojG3konU`nl00onU`nl01?l0003oYL?_o`00
0?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol00003ojG3k`03o`000?nU`nooYL?_00;oYL?_
1?l00004ojG3k`03o`000?nU`nooYL?_00?o00001?nU`nl00ol0003oio[=o`000003o`000005onkh
_Ol0003o0000oo7e_Ol000000_oblkd00ol0003ol_6mo`000005o`000004oo;W__l0003olN>ooo7S
_`Go000000Gok=[0o`000?oZeL3oj]G0o`000002onO@`003o`000?oSbl3ohl_000;ohl_000Go0000
omg4`?oMa<3ogLC0o`000003omVn_`;o00000ooB][h01_l0003oc[6molja_Ol0003objjmo`0000?o
aZVl00?o0000ol>V_?l000000onoXK/01?l0003o^ijkok^N^onkW[/2o`0000Co/iJi00Co0000ojnC
^_n_Tk[o[i>j0_l00004ojR<^005o`000?nTRKSoY8VhojB9^?l000001?nOQkT01_l0003oVhBjoi^4
^_nKQ;[o0000oiJ1^a7o000000?oOgO0o`000?mjML800_mjML801Ol0003oLg?4og=ca?mcLlCo0000
00;oKG;71?l00003oe=/c`04o`000?m<K=;o0000o`0000?o<FGE2Ol000000olo^nko0000ojG3k`03
ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl01?nU`nl4o`0000;oYL?_00?o0000
ojG3konU`nl00_nU`nl4o`000005ojG3kol0003oYL?_o`000?ooool01?l0000Mooooo`03o`000?oo
oooooooo00Sooooo000Xooooo`03o`000?oooooooooo00kooooo1?l00002ojG3k`?o00000_nU`nl4
o`0000CoYL?_00Co0000ojG3konU`nooYL?_1?l00004ojG3k`04o`000?nU`noo0000o`0000;oYL?_
00?o0000ojG3konU`nl00_nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00?o
YL?_0ol00003ojG3k`0:o`000?nU`nooYL?_ojG3kol0003oio[=o`000?oRkMSo0000onkh_@;o0000
0_oamKd00ol0003ol_>mo`000003o`000004oo?]__l0003olnZnoo?Z_P;o00000ooahkl01Ol0003o
kmnoonoO_ol0003okM^o00?o000000Goj]G0o`000?oWd<3oim30o`000003on?;`005o`000?oOa[oo
0000omg4`?l000000ooI_[l01_l0003oeKVnomFi__l0003od[Jno`0000Coc[6m00?o0000olJY_?o6
ZK`00oo6ZK`00ol0003o_j6koknQ^`02oknQ^`04o`000?nkW[_o^ijko`0000;o]iVi00?o0000ok>F
^OncU[T00_ncU[T3o`000003ojb?^?l0003oZ8bh00?oZ8bh00Go0000ojB9^?nTRKSoY8Vho`000003
oin7^@Oo00000_nFOkP01Ol0003oTWfioi9m^OnBOKWo000000?oSW^j00Go0000ohUi_?n9NKcoRGVl
o`000002ohAh_@Ko00000omcLl@01?l0003oKG;7ofebaol00002ofMab@?o00000_mCK<l00ol0003o
C6cBo`000003oc5Ue@04o`000?l[ImSo0000o`eOe`?o000000?o04W3o`000?l000000_l00002ojG3
k`?o00001OnU`nl00ol0003oYL?_o`000002o`000003ojG3kol0003oYL?_00CoYL?_1?l000000onU
`noo0000ojG3k`03ojG3k`?o00008Oooool00ol0003oooooooooo`08ooooo`009oooool00ol0003o
ooooooooo`0<ooooo`?o00000onU`nl3o`0000;oYL?_0ol00004ojG3k`03o`000?nU`nooYL?_00Go
00001?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00?o0000ojG3konU`nl01?l00004ojG3k`03
o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl01?nU`nl00ol0003oYL?_o`000002o`000007
on;]f?l0003ok_Rmo`000?o_m[go0000oo7e_@04o`000004oo?__Ol0003olnfno`0000;olnZn00?o
0000oo;W__l000000_oahkl01?l0003okmnoonoO_ol00002ongK_`03o`000?o[ekoojmNo00;o0000
00?oim30o`000?oSbl000_oSbl001Ol0003oglJoomo6_ooOa[oo000000?ofKjo00?o0000omFi__oE
^Kh00_oE^Kh00ol0003oc[6molja_@03olja_@03o`000?o6ZKcoaZVl00?oaZVl00?o0000oknQ^ono
XK/00onoXK/2o`0000?o]iVi00Co0000ok>F^OncU[Wo/iJi0_l00004ojb?^005o`000?nXS;SoZ8bh
ojR<^?l000001?nTRKP3o`000003oij4]ol0003oVh:h00;oVh:h00Go0000oiIo^?nFOkSoUWnho`00
0003oi9m^@05o`000?n>Nk[oSW^johik^_l000000on9NK`01Ol0003oQ7RmohAh_On4N;go000000?o
OgJo1Ol00003ofeba`05o`000?mWLLWoIg79o`000?mQLLd00ol00002oda/dP;o00000_laIMD00ol0
003o:fOHo`000002o`eOe`So00000onRd?P01?l0003oYL?_ojG3konU`nl3o`0000GoYL?_00?o0000
ojG3konU`nl00ol00005ojG3k`03o`000?nU`noo000000Co00008Oooool00ol0003oooooooooo`08
ooooo`009oooool2o`0000_ooooo0_l00002ojG3k`Co000000?oYL?_o`000?nU`nl00_l00002ojG3
k`03o`000?nU`nooYL?_00;oYL?_0ol00003ojG3k`03o`000?nU`nooYL?_00?oYL?_0ol00004ojG3
k`03o`000?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00Co0000ojG3
konU`nooYL?_1Ol000001OoRkMSo0000onkh_Ol0003okoJm00Co000000Col_6mo`000?ockkgo0000
0_ockKh01Ol0003olnZno`000?obikko000000?olN>o00?o0000onoO_ol000000_o]fkl01_l0003o
jmNoon_G_oo[ekoo0000onSB_`;o00000ooSbl001?l0003oglJoomo6_ooOa[l2o`000003omVn_ol0
003oeKVn00CoeKVn00?o0000olja_Oo>/Kd00_o>/Kd00ol0003obZblo`000003olJY_003o`000?o2
Y;_o000000Co_j6k00?o0000okNI^OngVKT00_ngVKT01_l0003o/iJiok>F^Ol0003o/9:ho`0000Co
[8nh00?o0000ojR<^?nXS;P00_nXS;P00ol0003oY8Vho`000002o`0000?oWXBg00Go0000oi^2^?nK
P[SoVh:ho`000004oiIo^005o`000?nBOKWoTWfioi9m^Ol000000on>NkX01Ol0003oRGVlohUi_?n9
NKco000000?oQ7Rm00Go0000ogmf_omoM[ooOgJoo`000002og]e`P?o000000?oKG;7o`000?mWLLT0
0_mWLLT01?l0003oHG7=of5acOl00002oda/dP03o`000?m5KMGo000000;o00000_l[ImP2o`000004
o`eOeol0003o0000o`1Hd@Co00000_nRd?P5o`0000;oYL?_00?o0000ojG3konU`nl00onU`nl3o`00
00?oYL?_00Co0000ojG3konU`nooYL?_0ol00004ojG3k`;o00008Oooool00ol0003oooooooooo`07
ooooo`009oooool00ol0003oooooooooo`07ooooo`Co000000?oYL?_o`000?l000000_l00002ojG3
k`Co00001?nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_00?o0000
ojG3kol000000_l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol00003ojG3k`03o`000?nU`noo
YL?_00;oYL?_0ol00004ojG3k`03o`000?nU`nooYL?_00Go00000onU`nl00ol0003oh^gHo`000002
onkh_@?o000000ColO>mo`000?oblKgo00000_ockkd01Ol0003olnfno`000?ocj[ko000000;ol^Nn
00Ko0000oo7S_ooahkoo0000onoO_ol00003ongK_`04o`000?o[ekoojmNoo`0000;oj=:o00Go0000
onG=_ol0003ohl_0o`000003omo6_`04o`000?oL`Koog<6oo`0000GoeKVn00?o0000om6d_Ol00000
0_o>/Kd01?l0003obZblolZ/_?l00002olJY_004o`000?o2Y;_o`ZBko`0000?o_j6k0_l00005okNI
^@;o00000_n`T[P00ol0003o[8nhojb?^002ojb?^004o`000?nXS;SoZ8bhojR<^0?o00000_nSQkL0
0ol0003oWXBgoij4]`02oij4]`05o`000?nKP[SoVh:hoi^2^?l000000onFOkP01Ol0003oTWfioi9m
^OnBOKWo000000?oSW^j00Go0000ohUi_?n9NKcoRGVlo`000003ohAh_@03o`000?moM[ooOgJo00;o
OgJo00Go0000og]e`_mkML;o0000ogIda002o`0000?oIg7900Co0000of5acOmQLLgoHG7=0_l00000
0om<K=;o0000odE]e@02odE]e@?o000000Co9V[Ko`000?l0003o36GJ0_l000000ol0H=Co0000o`00
0002o`0000;oM]Cn00?o0000ojG3konU`nl00onU`nl00ol0003oYL?_o`000002o`000003ojG3kol0
003oYL?_00?oYL?_1?l00003ojG3k`04o`000?nU`nooYL?_ojG3k`?o00008?ooool00ol0003ooooo
ooooo`07ooooo`009oooool00ol0003oooooooooo`04ooooo`?o00000_nU`nl3o`0000;oYL?_1?l0
0004ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_ojG3k`04o`0000GoYL?_00Co
0000ojG3kol0003o00000_nU`nl00ol0003oYL?_ojG3k`02ojG3k`04o`000?nU`noo0000o`0000;o
YL?_00?o0000ojG3konU`nl00_nU`nl3o`0000?oYL?_00Go0000ojG3konU`nooYL?_o`000002on;]
f007o`000?o^n;go0000oo3e_Ol0003olO>mo`000002oo;a_@05o`000?ockkgo0000oo?]__l00000
0_ocj[h00ol0003ol^Nno`000002oo7S_`04o`000?o_gkookmnoo`0000;okM^o00Co0000on_G_oo[
ekoo00000_oXd[l01Ol0003oiLfoonG=_ooUcKoo000000?oglJo00Go0000omc1_ooL`Koog<6oo`00
0004omFi_P06o`000?oA];godKBmo`000?o>/Kgo00000oo:[;`00ol0003oaZVlo`000003ol:T^`04
o`000?noXK_o_j6ko`0000;o^ifi00Co0000okNI^OngVKWo]iVi0_l00004ok2B^003o`000?n/SkSo
[8nh00;o[8nh0ol000000onVRKKo0000oj>7]`02oj>7]`03o`000?nNQ;OoWXBg00;oWXBg00Go0000
oi^2^?nKP[SoVh:ho`000003oiIo^005o`000?nBOKWoTWfioi9m^Ol000000on>NkX01Ol0003oRGVl
ohUi_?n9NKco000000CoQ7Rm00Go0000ogmf_omoM[ooOgJoo`000003og]e`P03o`000?mfM<CoMWC4
00;o00000_mWLLT01Ol0003oHG7=of5acOl0003oFg7@00;o00000om5KMD01?l0003o@6oIo`000?l0
0002obIZf`04o`000?l<IM[o36GJo`0000;o063D1_l00003ojG3k`?o00001OnU`nl01_l0003oYL?_
o`000?l0003oYL?_o`0000GoYL?_1?l000000onU`noo0000o`00000Pooooo`03o`000?oooooooooo
00Oooooo000Wooooo`03o`000?oooooooooo00;ooooo0_l00002ojG3k`?o00000_nU`nl3o`0000?o
YL?_00?o0000ojG3konU`nl00_nU`nl3o`0000CoYL?_00?o0000ojG3konU`nl01?l00004ojG3k`04
o`000?nU`nooYL?_ojG3k`Co00001?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00Co0000ojG3
kol0003o00000_nU`nl00ol0003oYL?_ojG3k`02ojG3k`03o`000?nU`noo000000;oh^gH0ol00000
2Oo`mKgo0000oo7c_Ooalkgo0000oo;a_Ol0003olnnmo`000002oo?]_P03o`000?ocj[ko000000;o
l^Nn00Ko0000oo7S_ooahkoo0000onoO_ol00002ongK_`04o`000?o[ekoojmNoo`0000?oj=:o00Go
0000onG=_ooUcKooiLfoo`000003omo6_`06o`000?oL`Koog<6oo`000?oH_;ko00000ooE^Kh01Ol0
003odKBmom6d_OoA];go000000GobZbl00?o0000ol:T^oo2Y;/00oo2Y;/2o`0000?o^ifi00Ko0000
okNI^OngVKWo0000okBF^?l00004ok2B^004o`000?n/SkSo[8nhojb?^0;o00000onVRKH00ol0003o
XhNgoj>7]`02oj>7]`05o`000?nNQ;OoWXBgoij4]ol000000onKP[P00ol0003oUWnhoiIo^002oiIo
^005o`000?nBOKWoTWfioi9m^Ol000000on>NkX01Ol0003oRGVlohUi_?n9NKco000000?oQ7Rm00Go
0000ogmf_omoM[ooOgJoo`000003og]e`P05o`000?mfM<CoMWC4o`000?maM<L00ol00003of5ac@03
o`000?mKLM3oFg7@00;o00000_m5KMD00ol0003o@6oIod1_f@02o`000004obIZfol0003o0000o`aU
fP;o000000Go063Do`000?l0003o0000obbQk`04o`0000?oYL?_00Co0000ojG3konU`nooYL?_0ol0
0004ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl00onU`nl2o`0001oooooo00?o
0000ooooooooool01oooool002Oooooo2Ol000000onU`noo0000ojG3k`02o`0000;oYL?_00?o0000
ojG3konU`nl00_nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol0
0003ojG3k`03o`000?nU`nooYL?_00;oYL?_1?l00004ojG3k`03o`000?nU`nooYL?_00Co00001?nU
`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00?o0000ojG3konU`nl01ol000002?o>d]go0000oo3e
_Ol0003olO>mo`000?oblKgo00000_ockkd?o`000005ongK_ol0003ojmNoon_G_ol000000_oXd[l0
2Ol0003oiLfoonG=_ooUcKoo0000on78_ol0003oglJoo`000002omc1_`07o`000?oH_;kof;bnomRl
__l0003oeKVno`000004om6d_@03o`000?o:[;cobZbl00;obZbl0_l00005ol:T^`03o`000?nkWKWo
^ifi00;o^ifi00?o0000okNI^Ol000000_ndU[P00ol0003o/9:hok2B^002ok2B^006o`000?n/SkSo
[8nho`000?nZS;Ko00001?nVRKH01Ol0003oXhNgoj>7]onSQkOo000000?oWXBg00?o0000oi^2^?nK
P[P00_nKP[P00ol0003oUWnho`00000Bo`0000CoOgJo00Co0000og]e`_mkML;o00000omfM<@01?l0
003oLGC7og5daomaM<L4o`0000;oFg7@00?o0000oeIcdol000000_l00002od1_f@05o`000?llL]co
0000o`000?lUKml02_l00005ojG3k`Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000GoYL?_00Co
0000ojG3konU`nooYL?_0ol0000Nooooo`03o`000?oooooooooo00Oooooo000Vooooo`?o000000?o
YL?_o`000?l000000_l00002ojG3k`Co00001?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00Co
0000ojG3kol0003o00000_nU`nl00ol0003oYL?_ojG3k`02ojG3k`04o`000?nU`noo0000o`0000;o
YL?_00?o0000ojG3konU`nl00onU`nl3o`0000?oYL?_00?o0000ojG3konU`nl00_nU`nl3o`0000Co
YL?_00?o0000ojG3konU`nl01?l00004ojG3k`08o`000?o>d]goc];Mo`000?o`mKgo0000oo7c_Ol0
0002oo;a_@Co000000Colnbno`000?ocj[ko00000_obikh01_l0003olNBooo7T_ol0003ol>2oo`00
00;ok]bo0_l000001Oo[ekoo0000onSB_ooXd[oo000000?oiLfo00Go0000on78_ooQb;oohLRoo`00
0003omc1_`03o`000?oH_;kof;bn00;of;bn00?o0000om6d_OoA];d00_oA];d00ol0003ocK2lo`00
0002olZ/_004o`000?o6Z;_oaZRko`0000?o`ZBk0_l00005ok^M^@03o`000?ndU[So]9Jh00;o]9Jh
00?o0000ok2B^?n`T[P00_n`T[P2o`0000;oZXbf00?o0000ojJ9]_nVRKH00_nVRKH01Ol0003oXhNg
oj>7]onSQkOo000000CoWXBg00?o0000oi^2^?l000000ol00002oiMn]P05o`000?nCOKOoTgfgoi=m
]ol000000on@NkP01Ol0003oS7Zjohaj^_n<N[[o000000?oR7Vk2?l000001OmkML;o0000ogIda?mf
M<Co000000?oLGC700?o0000ofaeb_m/MLX00ol000000omKLM3o0000oeIcd`02oeIcd`;o000000Go
@6oIo`000?llL]co?7;Lo`000003obE_g`;o000000?o3VgNo`000?l000000ol000001_nU`noo0000
o`000?l0003oV]cmo`0000GoYL?_0ol00003ojG3k`04o`000?nU`nooYL?_ojG3k`Go000000CoYL?_
o`000?nU`noo00007Oooool00ol0003oooooooooo`07ooooo`007?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo1?l00003ojG3k`?o00001?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00?o
0000ojG3konU`nl01?l00004ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_o`00
0002o`0000;oYL?_00?o0000ojG3konU`nl00_nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`00
0?nU`nooYL?_00;oYL?_0ol00003ojG3k`05o`000?nU`nooYL?_ojG3kol000000oo>d]d2o`0000;o
lO>m1?l000001_ockkko0000oo?/__l0003olnZno`0000;ol^Nn00Ko0000oo7T_ooai;oo0000oo3P
_ol00003onkL_`03o`000?o/f<3o000000;o000000Goj=:oo`000?oUcKooiLfoo`000004on78_`;o
000000?og<6oo`000?oH_;h01?oH_;h01Ol0003odKBmom6d_OoA];go000000;ocK2l00?o0000olZ/
_?l000000oo6Z;/01?l0003o`ZBkol:T^ol00002okjP^P04o`000?nkWKWo^ifiok^M^@;o00001?nd
U[P01?l0003o/9:hok2B^?n`T[P2o`0000CoZXbf00Go0000ojJ9]_nVRKKoYXVfo`000004oj>7]`03
o`000?nNQ;Oo000000?o00000_nKP;H01Ol0003oUgjfoiMn]_nGO[Ko000000?oTgfg00Go0000oi1k
^?n@NkSoT7^ho`000004ohaj^P05o`000?n8NK_oR7VkohQi^ol000000on5N;d00ol0003oPGNooh5g
_`03o`000003ogIda?l0003oLGC700?oLGC700Go0000ofaeb_m/ML[o0000ofQfcP02o`0000?oEW?C
00Co0000oe5ef?l0003o00000ollL]`2o`000003obE_gol0003o9WOS00So00001?nJg?d00ol0003o
YL?_o`000002o`000003ojG3kol0003oYL?_00?oYL?_1?l00002ojG3k`03o`000?nU`nooYL?_00;o
YL?_0ol0000Looooo`03o`000?oooooooooo00Oooooo000Looooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2o`000003ooooool0003oYL?_00;o00000_nU`nl00ol0003oYL?_ojG3k`02ojG3k`?o
00000onU`nl00ol0003oYL?_ojG3k`02ojG3k`?o00001?nU`nl00ol0003oYL?_ojG3k`04o`0000Co
YL?_00?o0000ojG3konU`nl01?l00005ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl01?l0003o
YL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_00?o0000ojG3kol000000oo>d]d00ol0
003ol?Fmo`000003o`000006oo;a__l0003olnnno`000?ock;ko00000_ocj[h01_l0003ol^Nnoo;W
__l0003olNBoo`0000;ol>2o00Co0000onkL_oo^g;oo00000_o/f<001?l0003ojMC0onWD`?l00003
onG=_`05o`000?oQb;oohLRoon78_ol000000_oNa;l00ol0003of;bnomRl_P03omRl_P05o`000?oD
]kgo0000om6d_Ol000001?o=/;`00ol0003oaZRkolJX^`02olJX^`03o`000?o2Y;_o000000?o_Z2j
00Ko0000ok^M^OnkWKWo0000okRI^?l00004okBF^006o`000?n`T[So/9:ho`000?n]SkKo00001?nZ
S;H01Ol0003oYXVfojJ9]_nVRKKo000000?oXhNg0ol00002oij3]@05o`000?nKP;KoVh2foi^0]_l0
00001?nGO[H01Ol0003oTgfgoi=m]onCOKOo000000?oT7^h00Go0000ohaj^_n<N[[oS7Zjo`000004
ohQi^`04o`000?n5N;goQGRmo`0000?oPGNo00?o0000ogeg`_l000000_l00003og5da`05o`000?m/
ML[oK7G:ofaeb_l000000_mXM/h2o`0000;oEW?C00?o0000oe5ef?mAMMP00_l000000ollL]co0000
oc]hh@03o`0000?o9WOS1?l000000ol7N^7o0000o`000004o`0000GoYL?_00Ko0000ojG3kol0003o
0000ojG3kol00005ojG3k`03o`000?nU`noo000000Co00007Oooool00ol0003oooooooooo`06oooo
o`007?ooool01Ol@413ooooooooooooooooo410@00Oooooo00Co0000ooooool0003o00001?nU`nl0
1?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_00Co0000ojG3kol0003o0000
0_nU`nl00ol0003oYL?_ojG3k`02ojG3k`?o00000onU`nl00ol0003oYL?_ojG3k`02ojG3k`?o0000
1?nU`nl01?l0003oYL?_ojG3konU`nl4o`0000CoYL?_00?o0000ojG3konU`nl01?l00004ojG3k`03
o`000?nU`nooYL?_00Co00000_o>d]d4o`000006onWXc_l0003ol_6no`000?ockkko00000_ock;h0
0ol0003olnZno`000002oo;W_P03o`000?oai;oo000000;ol>2o00Oo0000onkL_oo^g;ook]boo`00
0?o/f<3o000000?ojMC00_l000000ooUcKoo0000on78_`02on78_`04o`000?oNa;oog/Boomk4_`;o
00000ooH_;h01Ol0003oe;NmomBg_OoD]kgo000000GocK2l00?o0000olJX^oo6Z;/00oo6Z;/00ol0
003o_Z2jokjP^P02okjP^P03o`000?nkWKWo000000?o^9Vh00?o0000okBF^?ndU[P00_ndU[P2o`00
00;o[Hnf00?o0000ojZ<]_nZS;H00_nZS;H00ol0003oYXVfojJ9]P02ojJ9]P?o000000?oXHFeo`00
0?nNPkD00_nNPkD00ol0003oVh2foi^0]P02oi^0]P05o`000?nGO[KoUgjfoiMn]_l000000onCOKL0
1Ol0003oT7^hoi1k^?n@NkSo000000CoS7Zj00Go0000ohQi^on8NK_oR7Vko`000003ohEh_@04o`00
0?n1MkooPGNoo`0000?oOGO21Ol00003ofaebP05o`000?mXM/koJ7K>o`000?mTN=400ol00002oe5e
f003o`000?m?NMco000000;o00000olkN>42o`000003obIghol0003o:h3X00Go00001?m]`Oh01?l0
003oYL?_ojG3konU`nl3o`0000CoYL?_00Co0000ojG3konU`nooYL?_0ol00003ojG3k`03o`000?nU
`noo000001cooooo00?o0000ooooooooool01_ooool001cooooo00Go0000ooooooooooooooooo`00
0008ooooo`04o`000?ooooooooooo`0000;oYL?_1?l00004ojG3k`03o`000?nU`nooYL?_00Co0000
1?nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_00Co0000ojG3kol0
003o00000_nU`nl00ol0003oYL?_ojG3k`02ojG3k`Co00000_nU`nl00ol0003oYL?_ojG3k`03ojG3
k`?o00001?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00_o0000olkBgOl0003o/LKYo`000?oY
j<ko0000oo;a__l0003olnnno`000002oo?/_P03o`000?ocj[ko000000;ol^Nn00Ko0000oo7T_ooa
i;oo0000oo3P_ol00003onkL_`03o`000?o/f<3o000000?ojMC000?o0000onK?`?oVcl000_l00003
on78_`04o`000?oNa;oog/Boo`0000;of[nn00?o0000omRl__l000001?oD]kd00ol0003ocK2lolf`
_002olf`_003o`000?o9Zkco000000?oaZRk0_l00005okjP^P03o`000?nhVKSo^9Vh00;o^9Vh00Co
0000okBF^?ndU[So]9Jh0_l00004ojf?]P03o`000?nZS;KoZXbf00;oZXbf00?o0000ojJ9]_l00000
0_l00003oj65]@03o`000?nNPkGoWX>e00;oWX>e00Go0000oi^0]_nKP;KoVh2fo`000003oiMn]P05
o`000?nCOKOoTgfgoi=m]ol000000on@NkP00ol0003oS7Zjohaj^P02ohaj^P05o`000?n8NK_oR7Vk
ohQi^ol000000on5N;d01Ol0003oPGNooh5g_on1Mkoo000000;oOGO200Co0000ogUga?miMlCoNGO4
1Ol00003ofQfcP04o`000?mTN=7oI7SAofAhd@;o000000?oDGGHo`000?m?NM`00_m?NM`2o`000003
oc]hhOl0003o?7oV00?o00000_l[P>P;o`0000?oXlce00?o0000ojG3konU`nl01Ol00003ojG3k`03
o`000?nU`nooYL?_00?o00007?ooool00ol0003oooooooooo`06ooooo`007?ooool01Ol0003ooooo
oooooooooooo000000Wooooo00?o0000ooooooooool00_l00004ojG3k`03o`000?nU`nooYL?_00Co
00001?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00?o0000ojG3konU`nl01?l00004ojG3k`04
o`000?nU`noo0000o`0000;oYL?_00?o0000ojG3konU`nl00_nU`nl00ol0003oYL?_o`000002o`00
0003ojG3kol0003oYL?_00CoYL?_0ol00004ojG3k`03o`000?nU`nooYL?_00?o000000Ko/LKYo`00
0?oYj<ko0000oo;a__l00002oo?__P06o`000?ock;kolnbno`000?ocj[ko00000_obikh00ol0003o
lNBoo`000002oo3P_`04o`000?o^g;ook]boo`0000;ok=S000Go0000onWD`?oYe<3ojMC0o`000002
onK?`005o`000?oSbl3o0000on78_ol000000_oNa;l00ol0003of[nnomZo_P02omZo_P03o`000?oD
]kgoe;Nm00;oe;Nm00?o0000om2c_Ol000000_o=/;`01?l0003obJ^lolV[_?l00002olJX^`04o`00
0?o2Xk[o`Z>jo`0000?o_Z2j0_l00004okRI^006o`000?ndU[So]9Jho`000?naT[Oo00001?n]SkH0
1?l0003oZXbfojZ<]_nZS;H3o`0000;oYHNe00?o0000oj65]OnQQKD00_nQQKD01Ol0003oWX>eoij3
]OnNPkGo000000?oVh2f00?o0000oiMn]_nGO[H00_nGO[H01Ol0003oTgfgoi=m]onCOKOo000000?o
T7^h00Go0000ohaj^_n<N[[oS7Zjo`000004ohQi^`04o`000?n5N;goQGRmo`0000?oPGNo00Go0000
ogeg`_mmMl;oOGO2o`000003ogUga003o`000?mfN<OoMWS700?o00000_mXM/h01Ol0003oI7SAofAh
dOl0003oHG[F00;o00000om?NM`00ol0003oCWkQo`000002o`0000;o?7oV1Ol00002oc><kPKo0000
0onSc?D4o`0000;oYL?_00?o0000ojG3konU`nl00onU`nl3o`0000;oYL?_0_l0000Kooooo`03o`00
0?oooooooooo00Kooooo000Looooo`05oa0@4?ooooooooooooooool@41002_ooool2o`000003oooo
ool0003oYL?_00?oYL?_0ol00003ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol00004ojG3k`03o`00
0?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00?o0000ojG3konU`nl0
1?l00004ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl01?nU`nl3o`0000?o/LKY
00?o0000onWXc_l000000_oblKh00ol0003olnnno`000002oo?/_Pgo000000Cok]boo`000?o/f<3o
00000ooYe<001?l0003oi/o0onK?`?l00003on?;`005o`000?oNa;oog/Boomk4_ol000001?oJ_kh0
1Ol0003oe;NmomBg_OoD]kgo000000;od;>m00?o0000olf`_?l000000oo9Zk`00ol0003oaZRko`00
0003ol:S^P04o`000?nnX;[o_Z2jo`0000;o^ibi00?o0000okRI^?nhVKP00_nhVKP2o`0000?o/I:g
00Go0000ojf?]_n]SkKo[Hnfo`000002ojZ<]P03o`000?nXRKGo000000?oYHNe00?o0000oj65]OnQ
QKD00_nQQKD01Ol0003oWX>eoij3]OnNPkGo000000CoVh2f00?o0000oiMn]_l000005Ol000001On5
N;go0000oh5g_on1Mkoo000000?oOGO200?o0000ogUga?miMl@00_miMl@01Ol0003oMWS7ogIhaol0
003oLWW;00?o00000omTN=400ol0003oHG[Fof5jeP05o`0000?oCWkQ1?l00002od28j`Ko00000_ln
VO<4o`0000;oT/gl00?o0000ojG3konU`nl00_nU`nl00ol0003oYL?_o`000002o`000003ojG3kol0
003oYL?_00?oYL?_0_l0000Jooooo`03o`000?oooooooooo00Kooooo000Looooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool01?l0003oooooo`000?nU`nl2o`0000;oYL?_00?o0000ojG3konU`nl0
0_nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol00004ojG3k`03
o`000?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00?o0000ojG3konU
`nl01?l00004ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`000?naa^T00_naa^T01Ol0003o
jNS>onWXc_l0003ol_6n00Oo000000Ool^Zoo`000?obikool^Noo`000?oai;oo000000;ol>7000?o
0000onkM`?o^gL001?l00002onWD`004o`000?oVcl3oi/o0o`0000Cohl_00_l000000ooNa;oo0000
omZo_P03omZo_P05o`000?oF^kko0000omBg_Ol000001?o@/kd00ol0003obJ^lolV[_003olV[_003
o`000?o2Xk[o`Z>j00;o`Z>j00?o0000okjP^_l000000onkW;T01?l0003o^9VhokRI^?nhVKP2o`00
00Co/I:g00?o0000ojf?]_n]SkH00_n]SkH2o`0000;oZ8Ve00?o0000ojF7]OnUQkD00_nUQkD01Ol0
003oXHFeoj65]OnQQKGo000000CoWX>e00?o0000oi^0]_l000000ol00002oiQn]@05o`000?nEO;Ko
UGbfoiEl]_l000000onBNkL00ol0003oSgZhohmj^002ohmj^005o`000?n<NKWoS7Viohai^Ol00000
0_n9NK/4o`000005oh5g_ol0003oOGO2ogeg`_l000001?miMl@01Ol0003oMWS7ogIhaomfN<Oo0000
00?oLWW;1?l00002of5jeP04o`000?mNO][oGWkJoeinfP?o000000CoCWkQo`000?m>QNKoCXGV1_l0
0002odJBl0Ko00001?nBcO`00ol0003oYL?_ojG3k`03o`0000GoYL?_00?o0000ojG3kol000000ol0
000Jooooo`03o`000?oooooooooo00Kooooo000Looooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Ooo
ool01?l0003oooooo`000?l00004ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl01?l0003oYL?_
o`000?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol00003ojG3k`03o`000?nU`nooYL?_00;o
YL?_0ol00004ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_ojG3k`04o`0000Co
YL?_00?o0000ok76jOl000000_oYj<h4o`000007oo7^`Ol0003ol^booo;/_ol0003ol^Zoo`000002
oo;W_`03o`000?oai;oo000000;ol>7000_o0000onkM`?o^gL3ok]g0o`000?o/f/7o0000on[F`Ol0
003ojMC0o`000002onK?`005o`000?oSbl3ohl_0on?;`?l000000_oOa[l00ol0003of[nnomZo_P02
omZo_P05o`000?oF^kkoe[^nomJk__l000001Oo@/kd00ol0003obJ^lolV[_002olV[_0;o00001Oo2
XkX00ol0003o^ibiok^L^@02ok^L^@06o`000?nhVKSo^9Vho`000?ndUKOo00001?naT[L01?l0003o
[Hnfojf?]_n]SkH2o`0000CoZ8Ve00Go0000ojF7]OnUQkGoYHNeo`000004oj65]@03o`000?nNPkGo
000000?o00000_nKOk@01Ol0003oV7jeoiQn]OnHO[Go000000?oUGbf00?o0000oi9k]onBNkL00_nB
NkL01Ol0003oSgZhohmj^?n?N[So000000?oS7Vi00Go0000ohUi^on9NK_oRGVko`000002ohIi_@[o
00000omfN<L01Ol0003oLWW;og9ibombNL_o000000;oL7c?0ol000000omQN]Ko0000oeinfP02oein
fP03o`000?mMQ=oo000000;o00000_m>QNH01?l0003oDHk[oe6>jomAS^/3o`000003odJBl?l0003o
D9kd00;oD9kd2?l00003ojG3k`04o`000?nU`nooYL?_ojG3k`?o00000onU`nl2o`0001Wooooo00?o
0000ooooooooool01_ooool002oooooo00Co0000oooooooooooo00000_nU`nl4o`0000CoYL?_00?o
0000ojG3konU`nl01?l00004ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o0000ojG3konU`nl0
0_nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol00003ojG3k`03
o`000?nU`nooYL?_00;oYL?_0ol00004ojG3k`03o`000?nU`nooYL?_00Oo000000CoblWHo`000?oa
k/7o00000_obk;l00ol0003ol^Zoo`000002oo;W_`04o`000?oai;oolNBoo`0000;ol>7000Ko0000
onkM`?o^gL3o0000oncJ`Ol00003on[F`@;o000000?oi/o0o`000?oSbl000_oSbl001?l0003oglJo
omo6_ooOa[l2o`0000?of[nn00Go0000omJk__oF^kkoe[^no`000004om2c_@03o`000?o<[[co0000
00;obJ^l00Co0000olFW^oo5Yk_o00000oo2XkX2o`0000Go^ibi0_l00003okBE]`03o`000?naT[Oo
/I:g00;o/I:g0ol000000on[S;Go0000ojR9]@03ojR9]@05o`000?nUQkGoYHNeojF7]Ol000000onQ
QKD3o`0000;oWH6d00Go0000oi]o]?nKOkCoVgndo`000004oiQn]@05o`000?nEO;KoUGbfoiEl]_l0
00000onBNkL00ol0003oSgZhohmj^002ohmj^005o`000?n<NKWoS7Viohai^Ol000000_n9NK/01Ol0
003oQWVmohIi_On6NKgo000000?oPgVo00Co0000oh5j`_n1N/;oPG[21Ol00004og9ib`05o`000?m`
O<ooL7c?o`000?m]Om<00ol00003oeinfP04o`000?mMQ=ooGHCOoef4g`Co00000omAS^/00ol0003o
EiO`o`000002o`0000CoD9kd00Go0000og^lnomk_?_oNkcko`000003ojG3k`Go00000_nU`nl01?l0
003oYL?_ojG3konU`nl3o`0001Wooooo00?o0000ooooooooool01Oooool0033ooooo0_l000000ooo
oooo0000o`000004ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_ojG3k`04o`00
00CoYL?_00?o0000ojG3konU`nl01?l00004ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o0000
ojG3konU`nl00_nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol0
0004ojG3k`04o`000?o;bMSoblWHo`0000;olNk100?o0000oo;/_oobk;l00_l00002oo;W_`04o`00
0?oai;oolNBoo`0000;ol>7000Co0000onkM`?o^gL3o00000_o/f/401_l0003oj]K1on[F`OoZe/7o
0000onOB`@;o00000ooSbl001?l0003oglJoomo6_ol00002omc2_`03o`000?oJ_kko000000?oe[^n
00?o0000om:f__l000000_o@/kd01_l0003oc:jlolb^_?l0003obJ^lo`0000?oaJNk00Co0000ol:S
^_o2Xk[o00000_nnWkT01?l0003o^ibiok^L^OnkW;T2o`0000Co]9Fg00Co0000ok6B]onaT[Oo/I:g
0_l00003oj^<]@03o`000?nXRKGoZ8Ve00;oZ8Ve00?o0000ojF7]OnUQkD00_nUQkD3o`000003oj23
]?l0003oWH6d00;oWH6d00?o0000oi]o]?nKOk@00_nKOk@01Ol0003oV7jeoiQn]OnHO[Go000000?o
UGbf00?o0000oi9k]onBNkL00_nBNkL01Ol0003oSgZhohmj^?n?N[So000000?oS7Vi00Go0000ohUi
^on9NK_oRGVko`000003ohIi_@05o`000?n3NKooPgVooh=i_ol000000on1N/800ol0003oOW_5ogik
a@03o`0000;oLWW;00Go0000og1lcom`O<ooL7c?o`000003ofeod`Co00000omMQ=l00ol0003oGX[T
oej:i006o`0000?oEiO`3?l00002oj?<m@03o`000?nU`nooYL?_00;oYL?_1?l000001?nU`noo0000
ojG3kol0000Hooooo`03o`000?oooooooooo00Gooooo000booooo`03o`000?oooooo000000CoYL?_
0ol00004ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_
00?o0000ojG3konU`nl01?l00004ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl01?l0003oYL?_
o`000?l00002ojG3k`05o`000?nU`nooYL?_ojG3kol000000oo;bMP00ol0003olNk1o`000002oo;/
_`03o`000?obj[oo000000;ol^No00?o0000oo7T_ol000000_o`hL001?l0003ok]g0onkM`?l00002
oncJ`@05o`000?oZe/7oj]K1on[F`Ol000000_oWd/401Ol0003oi<k1o`000?oSbl3o000000;oglJo
00?o0000omc2_ooL`[l00_oL`[l01Ol0003oe[^nomJk__oF^kko000000;od[Jn00?o0000om2c_Ol0
00001?o<[[`00ol0003oaJNkolFW^`02olFW^`03o`000?o2Xk[o000000?o_Yni00Ko0000ok^L^Onk
W;Wo0000okNH^?l00004okBE]`06o`000?naT[Oo/I:go`000?n^SkKo00001?n[S;D01Ol0003oZ8Ve
ojR9]OnXRKGo000000?oYHNe0_l00003oj23]003o`000?nMPKCoWH6d00;oWH6d00Go0000oi]o]?nK
OkCoVgndo`000003oiQn]@05o`000?nEO;KoUGbfoiEl]_l000001?nBNkL01Ol0003oSgZhohmj^?n?
N[So000000?oS7Vi00Go0000ohUi^on9NK_oRGVko`000003ohIi_@05o`000?n3NKooPgVooh=i_ol0
00001?n1N/801Ol0003oOW_5ogikaOl0003oO7g900?o00000om`O<l01Ol0003oKGoCofeodom]Om?o
000000;oK8?H1_l00002oej:i004o`000?mQT^WoHI;Yof6Bj@Ko00000omOX_@01Ol0003oJjohof^_
n?m[[oSo000000GoXlce00Ko0000ojG3kol0003o0000ojG3kol00004ojG3k`?o00005oooool00ol0
003oooooooooo`05ooooo`00<oooool01?l0003oooooo`000?nU`nl2o`0000;oYL?_00?o0000ojG3
konU`nl00_nU`nl3o`0000?oYL?_00?o0000ojG3konU`nl00_nU`nl3o`0000CoYL?_00?o0000ojG3
konU`nl01?l00004ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_ojG3k`04o`00
00CoYL?_00?o0000ojG3kol000000oo;bMP02?l0003olNk1oo7^`Ol0003ol^boo`000?obj[oo0000
0_obikl01?l0003olNBooo7T_ol00002oo3Q`003o`000?o^gL3o000000;ok=[100Go0000on[F`OoZ
e/7oj]K1o`000002onOB`@05o`000?oTc/7oi<k1onC>`Ol000000ooOa[l00ol0003og<:oomc2_`02
omc2_`05o`000?oF^kkoe[^nomJk__l000000ooB][h00ol0003oc:jlolb^_003olb^_003o`000?o5
Yk_oaJNk00?oaJNk00?o0000okjO^OnnWkT00_nnWkT00ol0003o^ibio`000003okNH^003o`000?nd
UKOo]9Fg00;o]9Fg0_l00002ojj?]P03o`000?n[S;GoZhbe00;oZhbe00?o0000ojR9]OnXRKD00_nX
RKD3o`000003oj>5]?l0003oX8>d00?oX8>d00Go0000oif1]?nMPKCoWH6do`000003oi]o]005o`00
0?nHO[GoV7jeoiQn]Ol000000onEO;H00ol0003oTW^goi9k]`02oi9k]`03o`000?n?N[SoSgZh00;o
SgZh00Go0000ohai^On<NKWoS7Vio`000002ohUi^`05o`000?n6NKgoQWVmohIi_Ol000001?n3NKl0
1Ol0003oPG[2oh5j`_n1N/;o000000?oOW_500Co0000ogambOmlOLWoO7g91?l00004ofeod`04o`00
0?m/PmSoK8?Ho`0000?oJhSM1Ol00003of6Bj@04o`000?mUVnkoII_^ofFKkP[o00000onSc?D3o`00
00CoYL?_00?o0000ojG3kol000001?l0000Gooooo`03o`000?oooooooooo00Gooooo000dooooo`04
o`000?oooooo0000o`0000CoYL?_00Co0000ojG3kol0003o00000_nU`nl00ol0003oYL?_ojG3k`02
ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o0000ojG3konU`nl00_nU`nl3o`0000?oYL?_00?o
0000ojG3konU`nl00_nU`nl3o`0000CoYL?_00?o0000ojG3konU`nl01?l00004ojG3k`03o`000?nU
`nooYL?_00Co00000_o;bMP01?l0003olNk1oo7^`Ol00002oo;/_`oo000000?ok=[1o`000?oZe/40
0_oZe/400ol0003oim;1o`000004onC>`@;o000000?oglJoo`000?oL`[l00ooL`[l01Ol0003of;jo
o`000?oF^kko000000Cod[Jn00?o0000olb^_?o<[[`00_o<[[`00ol0003ob:Zlo`000003olFW^`;o
00001OnnWkT00ol0003o]iRhokNH^002okNH^004o`000?ndUKOo]9FgokBE]`;o00001?n^SkH01Ol0
003oZhbeoj^<]On[S;Go000000?oZ8Ve0_l00003oj>5]003o`000?nPPkCoX8>d00;oX8>d00Go0000
oif1]?nMPKCoWH6do`000003oi]o]003o`000?nHO[GoV7je00;oV7je00Go0000oiEl]_nEO;KoUGbf
o`000002oi9k]`go000000?oRGVko`000?n6NKd00_n6NKd01Ol0003oPgVooh=i_on3NKoo000000?o
PG[200Go0000ogikaOmnNlGoOW_5o`000003ogamb@03o`000?mjOlgoNWo=00Ko00000om/PmP01Ol0
003oJhSMof^8gOm[R=go000000;oK8kR1_l00004ofFKkP04o`000?m/YO?oK:Gco`0000?oLjkf1?l0
0003oiO5m`03o`000?nU`nooYL?_00?o00001?nU`nl2o`0001Kooooo00?o0000ooooooooool01Ooo
ool003Gooooo0_l000001?oooooo0000ojG3konU`nl4o`0000CoYL?_00?o0000ojG3konU`nl01?l0
0004ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o0000ojG3konU`nl00_nU`nl01?l0003oYL?_
o`000?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol00004ojG3k`03o`000?nU`nooYL?_00Co
00001?nU`nl00ol0003oblWHo`000002oo7^`@?o000000GolN_1o`000?oaj<7olNS1o`000002oo3V
`@06o`000?o_hl7okn?1o`000?o^gl;o00000_o/g<83o`000005on[F`Ol0003oim;1onOB`Ol00000
0ooTc/401?l0003ohLW1on79`Ol00004omc2_`05o`000?oH_[oof;joomRn_ol000001?oB][h00ol0
003oc[:mo`000002olb^_004o`000?o8Z[cob:Zlo`0000;oaJNk00Co0000ol6S^_o1Xk[o00001?nn
WkT00ol0003o]iRhokNH^002okNH^006o`000?ndUKOo]9Fgo`000?naT[Ko00001?n^SkH00ol0003o
Zhbeoj^<]@02oj^<]@?o000000?oYXNdo`000?nSQK@00onSQK@01Ol0003oX8>doj23]?nPPkCo0000
00?oWH6d00?o0000oi]o]?nKOk@00_nKOk@00ol0003oV7jeo`000008o`0000;oU7^e00Go0000oi9k
]_nBNkKoTW^fo`000003ohmj^003o`000?n=N[WoSGZi00[o00001?n1N/801?l0003oOW_5ogikaOl0
0004ogamb@04o`000?mjOlgoNWo=o`0000?oN8?A1Ol00004of^8g@04o`000?m/S^;oK8kRo`0000?o
KYKW2_l00004og>^mP04o`000?nGaOOoUlGgoiO5m`Co00000onU`nl01?l0003oYL?_ojG3konU`nl3
o`0001Gooooo00?o0000ooooooooool01Oooool003Oooooo00Co0000ooooool0003o00001?nU`nl0
0ol0003oYL?_ojG3k`04o`0000CoYL?_00?o0000ojG3konU`nl01?l00004ojG3k`03o`000?nU`noo
YL?_00Co00001?nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol0
0003ojG3k`03o`000?nU`nooYL?_00;oYL?_1_l000000ooHdM;o0000o`000002oo7X`@04o`000?o`
i/7ol>K1o`0000;okn?100?o0000onkO`_l000000oo/g<800ol0003oj]S2on[H`P02o`000003onOB
`Ol0003oi<k100;oi<k100Go0000on79`OoQbL7ohLW1o`000003omc2_`03o`000?oH_[oof;jo00;o
f;jo00Go0000om:f__oB][kod[Jno`000002oljb_@03o`000?o<[[co000000?ob:Zl00?o0000olFW
^ol000001?o1XkX01_l0003o_YniokjO^Ol0003o^Ybio`0000Co]iRh0_l00003ok6B]P05o`000?n^
SkKo[Xnfojj?]_l000000on[S;D2o`0000?oYXNd00?o0000oj>5]?nSQK@00_nSQK@01Ol0003oX8>d
oj23]?nPPkCo000000CoWH6d00?o0000oi]o]?l000000ol00002oiUm/`05o`000?nFO;CoUWbdoiIl
]?l000001?nDNkD01Ol0003oTW^foi9k]_nBNkKo000000?oSgZh00Go0000ohej^On=N[WoSGZio`00
0003oh]j^`04o`000?n9NkgoRG^mohUk_@So000000?oOW_5o`000?mlOLT00_mlOLT01Ol0003oNWo=
ogYocOmjOlgo000000?oN8?A00?o0000ogN7e_mgQmH02_l00003ofjFi`03o`000?mbW^coLYk/00;o
LYk/00?o0000ogNWl?mgYo002Ol00003ohjmmP03o`000?nU`nooYL?_00Go000000CoYL?_o`000?nU
`noo00005?ooool00ol0003oooooooooo`05ooooo`00>?ooool00ol0003oooooo`000004ojG3k`?o
00001?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00?o0000ojG3konU`nl01?l00004ojG3k`03
o`000?nU`nooYL?_00Co00001?nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_
00;oYL?_00Co0000ojG3kol0003o00000_nU`nl01ol0003of=7BomSAd_oHdM;o0000oo7[`Ol00000
0_oaj<401_l0003ol>K1oo3V`Ol0003okn?1o`0000;ok]o200Co0000oncL`_o/g<;o00000ooZf<80
1?l0003oj=C2o`000?l00003onC>`@08o`000?oQbL7ohLW1o`000?oMaL7o0000omc2_ol00004omRn
_`05o`000?oD^Koo0000om:f__l000001?o>/[d00ol0003ob:ZlolRZ_003olRZ_003o`000?o1Xk[o
`J>j00?o`J>j00?o0000okjO^Ol000000_njW;T00ol0003o]iRhokNH^002okNH^003o`000?naT[Ko
/I:f00;o/I:f00?o0000ojj?]_n^SkH00_n^SkH3o`000003ojR:]?l0003oYXNd00?oYXNd00Go0000
oj>5]?nSQKCoXhFdo`000004oj23]003o`000?nMPKCo000000?o00000_nKO[<00ol0003oVGfcoiUm
/`02oiUm/`05o`000?nFO;CoUWbdoiIl]?l000001?nDNkD01Ol0003oTW^foi9k]_nBNkKo000000?o
SgZh00Co0000ohej^On=N[Wo00001?n;N[/01Ol0003oRG^mohUk_On9Nkgo000000?oQgc000?o0000
ohEn`on5O/<01_l00003ogYoc@03o`000?mhPm7oN8?A00;oN8?A00Co0000ogN7e_mgQmKo00001?mg
S=/00ol0003oN9;PogRBh006o`0000CoLYk/00Go0000ogNWl?mgYo3oMjO`o`000004ogf`m004o`00
0?n>_OKoS[gfohjmmPCo00000_nSao800ol0003oYL?_ojG3k`02ojG3k`?o00005?ooool00ol0003o
ooooooooo`04ooooo`00>Oooool01?l0003oooooo`000?nU`nl2o`0000;oYL?_00?o0000ojG3konU
`nl00_nU`nl3o`0000CoYL?_00?o0000ojG3konU`nl01?l00004ojG3k`03o`000?nU`nooYL?_00Co
00001?nU`nl00ol0003oYL?_ojG3k`03o`0000GoYL?_00?o0000ojG3konU`nl00ol00003ojG3k`07
o`000?oHdM;of=7BomSAd_l0003olN_1o`000002oo7X`@06o`000?o`i/7ol>K1o`000?o_hl7o0000
0_o^gl801Ol0003ok=c2oncL`_o/g<;o000000;oj]S200So0000onSD`_oXe<;o0000onG@`_l0003o
i<k1o`0000;ohLW100Co0000omg5`OoMaL7ogLG10_l00003omRn_`05o`000?oD^Kooe;VoomBi_ol0
00001Oo>/[d00ol0003ob:ZlolRZ_003olRZ_003o`000?o1Xk[o`J>j00Co`J>j00?o0000okZL^Onj
W;T00_njW;T00ol0003o]iRhokNH^002o`0000Go/I:f00Go0000ojj?]_n^SkKo[Xnfo`000003ojR:
]003o`000?nVQkCoYXNd00;oYXNd00Go0000oj>5]?nSQKCoXhFdo`000003oj23]0?o00000_nMP;<0
0ol0003oVgjcoi]n/`02oi]n/`05o`000?nIOK?oVGfcoiUm/ol000000onFO;@00ol0003oU7^eoiAk
]@02oiAk]@05o`000?nBNkKoTW^foi9k]_l000000on?N[P01Ol0003oSGZiohej^On=N[Wo000000?o
RgZk00?o0000ohUk_On9Nkd00_n9Nkd01Ol0003oQgc0ohMl`?n7O<3o000000;oQGk300Co0000ohB0
aon4P<OoQ8372_l00003ogN7eP03o`000?mgS=_oMhcK00;oMhcK00Co0000ogRBh?mhT^3o00000omi
VNDBo`0000;oRkSd00?o0000oj?7l_nSao800_nSao800ol0003oYL?_o`000004o`0001Cooooo00?o
0000ooooooooool01?ooool003[ooooo1?l00004ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o
0000ojG3konU`nl00_nU`nl3o`0000?oYL?_00?o0000ojG3konU`nl00_nU`nl3o`0000CoYL?_00?o
0000ojG3konU`nl01?l00003ojG3k`04o`000?nU`nooYL?_ojG3k`Co00000onU`nl00ol0003oYL?_
o`000003omSAdP03o`000?oajl7o000000;olNS100Co0000oo3V`Oo`i/7o00000_o_hl400ol0003o
k]o2o`000003oncL`P04o`000?oZf<;oj]S2o`0000;oj=C200Go0000onG@`_oUd<;oiM32o`000003
on79`@09o`000?oMaL7ogLG1omg5`Ol0003of/71o`000?oH_[oo000000Coe;Vo00?o0000oljb_Oo>
/[d00_o>/[d00ol0003objjmo`000003olRZ_003o`000?o4Y[_o000000Co`J>j0_l00004okZL^@03
o`000?ngV;So000000;o]9Fg00?o0000ok6B]_naT[H00_naT[H00ol0003o[Xnfojj?]P02o`0000Co
Z8Zd00Go0000ojJ7]?nVQkCoYXNdo`000004oj>5]0?o000000?oWh6co`000?nMP;<00onMP;<01Ol0
003oVgjcoi]n/onKO[?o000000?oVGfc00Go0000oiIl]?nFO;CoUWbdo`000004oiAk]@05o`000?nB
NkKoTW^foi9k]_l000000on?N[P01Ol0003oSGZiohej^On=N[Wo000000CoRgZk00Go0000ohUk_On9
NkgoRG^mo`000003ohMl`005o`000?n5O/?oQGk3ohEn`ol000000on4P<L01Ol0003oPX?;oh:3bon2
Pl_o000000?oPHK?1Ol00004ogN<f`05o`000?mhT^3oN9;PogRBh?l000000omiVND00ol0003oO:7Y
ogbQj@02ogbQj@05o`000?n0Z>koP:S^oh2Xk_l000001On5/?400ol0003oRkSdoh^hm002oh^hm003
o`000?nSao;oXlOb00?o00000onU`nl00ol0003oYL?_o`00000Cooooo`03o`000?oooooooooo00Co
oooo000looooo`03o`000?oooooo000000;oYL?_1?l00004ojG3k`04o`000?nU`noo0000o`0000;o
YL?_00?o0000ojG3konU`nl00_nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_
00;oYL?_0ol00002ojG3k`03o`000?nU`nooYL?_00;oYL?_1?l00003ojG3k`03o`000?nU`nooYL?_
00Co00000ooHdM800ol0003olN_1o`000002oo7X`@06o`000?o`i/7ol>K1o`000?o_hl7o00000_o^
gl801?l0003ok=c2oncL`_l00002on[H`P05o`000?oXe<;oj=C2onSD`_l000000ooUd<82o`000003
on79`Ol0003ogLG100;ogLG100Go0000om[1`OoJ`L7of/71o`000004omBi_`03o`000?oA]Koo0000
00;oc[:m00Oo0000ol^^_Oo;[[gobjjmo`000?o8Z[co000000?oa:Jk00Co0000ol6S^_o1Xk[o0000
0_nmWkX00ol0003o^YbiokZL^@02okZL^@05o`000?ndUKOo]9FgokBE]ol000001?naT[H00ol0003o
[Xnfo`000002oj^<]@05o`000?nXR[CoZ8ZdojR:]?l000001?nVQk@00ol0003oXhFdo`000002o`00
00CoWh6c00Go0000oif0/onMP;?oWH2co`000003oi]n/`03o`000?nIOK?oVGfc00;oVGfc00Go0000
oiIl]?nFO;CoUWbdo`000003oiAk]@05o`000?nBNkKoTW^foi9k]_l000000on?N[P01Ol0003oSGZi
ohej^On=N[Wo000000CoRgZk00Go0000ohUk_On9NkgoRG^mo`000003ohMl`005o`000?n5O/?oQGk3
ohEn`ol000001?n4P<L01Ol0003oPX?;oh:3bon2Pl_o000000?oPHK?00?o0000oh6:don1R]<03ol0
0004ogbQj@05o`000?n0Z>koP:S^oh2Xk_l000000on5/?49o`0000?oW/;a00?o0000ojG3konU`nl0
0ol0000Cooooo`03o`000?oooooooooo00Cooooo000mooooo`04o`000?oooooo0000o`0000CoYL?_
00?o0000ojG3konU`nl01?l00004ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl01_l0003oYL?_
o`000?l0003oYL?_o`0000CoYL?_00Co0000ojG3kol0003o00000_nU`nl00ol0003oYL?_ojG3k`02
ojG3k`?o00001?nU`nl00ol0003of=7Bo`00000?o`000005oncL`_l0003oj]S2on[H`_l000000_oX
e<801Ol0003oiM32onG@`_oUd<;o000000;oh/g300Go0000omg5`OoMaL7ogLG1o`000004om[1`@05
o`000?oD^Kooe;VoomBi_ol000000_oA]Kl00ol0003oc[:mo`000004ol^^_@03o`000?o8Z[co0000
00?oa:Jk00?o0000ol6S^_l000000onmWkX01?l0003o^YbiokZL^OnjW;T2o`0000Co]9Fg00Co0000
ok6B]_naT[Ko/I:f0_l00003oj^<]@05o`000?nXR[CoZ8ZdojR:]?l000000onVQk@3o`0000;oXX>c
00?o0000oin1/onOPK<00_nOPK<01Ol0003oWH2coif0/onMP;?o000000CoVgjc00Go0000oiUm/onI
OK?oVGfco`000003oiIl]003o`000?nDNkGoU7^e00;oU7^e00Go0000oi9k]_nBNkKoTW^fo`000003
ohmj^005o`000?n=N[WoSGZiohej^Ol000000on;N[/00ol0003oRG^mohUk_@02ohUk_@05o`000?n7
O<3oQgc0ohMl`?l000000_n5O/<00ol0003oQ837ohB0a`02ohB0a`05o`000?n2Pl_oPX?;oh:3bol0
00001?n1Q/l01?l0003oPH[Coh6:dol00004oh6?f005o`000?n2UMgoPYGMoh:EgOl000000on3W>8=
o`0000;oSK7_00?o0000oi6hlOnA^?400_nA^?401?l0003oW/;aoik2lOnN`_44o`0000;oYL?_0_l0
000Booooo`03o`000?oooooooooo00Cooooo000nooooo`04o`000?ooooooooooo`0000;oYL?_1?l0
0004ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_ojG3k`03o`0000CoYL?_00?o
0000ojG3konU`nl01?l00004ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o0000ojG3konU`nl0
0_nU`nl3o`000005ok;6jOl0003ofm?@om_Cd?l000000_o`il<00ol0003oknG3o`000002onkRa003
o`000?o/g/Cok=k400;o000000Goj]S2o`000?oXe<;oj=C2o`000003onG@`P04o`000?oRcL?oh/g3
on;=``;o000000?ogLG1o`000?oJ`L400ooJ`L401Ol0003oe[g1o`000?oD^Koo000000CodKFo00?o
0000ol^^_Oo;[[d01?o;[[d00ol0003oa:JkolBV^`03olBV^`03o`000?nmWk[o_Inj00;o_Inj00Ko
0000okZL^OnjW;Wo0000okNH^?l00004okBE]`06o`000?naT[Ko/I:fo`000?n^SkKo00001?n[S;D0
1?l0003oZ8ZdojR:]?nXR[@3o`000003ojB5/ol0003oXX>c00?oXX>c00Go0000oin1/onOPK?oWh6c
o`000004oif0/`05o`000?nKO[?oVgjcoi]n/ol000000onIOK<01Ol0003oUWbdoiIl]?nFO;Co0000
00;oU7^e9?l00003oh:3b`03o`000?n1Q/ooPHK?00;oPHK?00Go0000oh6:don1R]?oPH[Co`000004
oh6?f005o`000?n2UMgoPYGMoh:EgOl000000on3W>801Ol0003oQJ?WohFSion5XnOo000000GoRJ[[
00?o0000ohfakon=/Nl00_n=/Nl00ol0003oTKSaoi6hl@05o`0000;oWKo`00Co0000ojG3konU`noo
YL?_0ol0000Aooooo`03o`000?oooooooooo00Cooooo000oooooo`03o`000?oooooooooo00;o0000
1?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`00
0?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00Co0000ojG3kol0003o
00000onba^T01?l0003ofm?@om_Cd?l00002oo3W``03o`000?o_iL?o000000;ok^;400Ko0000oncN
a?o/g/Cok=k4o`000?oZfl@3o`000005onSD`_l0003oiM32onG@`_l000000ooRcL<01?l0003oglS3
omo8`ol00004om[1`@05o`000?oF_L7oe[g1omJm`Ol000001OoA]Kl00ol0003objjmol^^_@03ol^^
_@;o00001?o4Y[/2o`0000Go_Inj0_l00003okNH^007o`000?ndUKOo]9FgokBE]ol0003o/I:fo`00
0002ojj?]P03o`000?n[S;GoZhbe00;oZhbe00?o0000ojR:]?nXR[@00_l00004ojB5/`05o`000?nR
Pk?oXX>coj:3/ol000001?nOPK<01Ol0003oWH2coif0/onMP;?o000000?oVgjc00?o0000oiUm/onI
OK<02?l00002oiIl]005o`000?nDNkGoU7^eoiAk]Ol000000onCNkH01Ol0003oTGbhoi5l^?nAO;So
000000CoT7bj00Go0000ohim_?n>OKcoSWflo`000003ohen_P05o`000?n<P<;oS832ohb0`_l00000
0on;PlD>o`0000CoPHoH00Go0000oh:EgOn2UMgoPYGMo`000004oh>LhP05o`000?n5XnOoQJ?WohFS
iol000000on9Z^/9o`0000?oUkS_00?o0000oifol?nM_o001Ol000001?nT`noo0000ojC3kol0000@
ooooo`03o`000?oooooooooo00Cooooo0010ooooo`;o000000?oooooo`000?nU`nl00onU`nl3o`00
00?oYL?_00?o0000ojG3konU`nl00_nU`nl3o`0000?oYL?_00?o0000ojG3konU`nl01?l00004ojG3
k`03o`000?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_ojG3k`04o`0000?o//KY00Co0000om_C
d?oKdm3o00000_o`il<00ol0003oknG3o`000003onkRa004o`000?o/g/Cok=k4o`0000;oj]_400?o
0000onSGa?oXel@00_l000000ooUd<;o0000on;=``02on;=``04o`000?oOb<?oglS3omo8``;o0000
0ooJ`L401Ol0003oe[g1omJm`OoF_L7o000000CodKFo00?o0000olfa_ol000000oo;[[d01?l0003o
aZZmolJZ_Ol00002olBV^`04o`000?o0Xk_o`:>ko`0000?o_Inj0_l00004okNH^004o`000?ndUKOo
]9FgokBE]`;o00001?n^SkH02Ol0003oZhbeoj^<]On[S;Go0000ojR:]?l0003oYXNdo`000004ojB5
/`05o`000?nRPk?oXX>coj:3/ol000001?nOPK<01Ol0003oWH2coif0/onMP;?o000000;oVgjc1?l0
0002oiUm/P05o`000?nHO;?oV7bcoiQl/ol000000onFO;@01Ol0003oU7^eoiAk]OnDNkGo000000?o
Tg^f00?o0000oi5l^?nAO;P00_nAO;P01Ol0003oT7bjoi1l^_n@O;[o000000CoSWfl00Go0000ohen
__n=O[koSGjno`000003ohb0`P05o`000?n;PlGoRh?5oh^3aOl000000on:Q/T00ol0003oRHW=ohV9
c@02ohV9c@03o`000?n9S]7oRHkA01Ko00000_n@[>T00ol0003oTk;/oi>bk002oi>bk004o`000?nG
^>ooUkS_oiNhk`Co00000_nN_^l00ol0003oY<?_ojC3k`02ojC3k`?o00004?ooool00ol0003ooooo
ooooo`03ooooo`00@_ooool01?l0003oooooo`000?nU`nl2o`0000;oYL?_00?o0000ojG3konU`nl0
0_nU`nl01_l0003oYL?_o`000?l0003oYL?_o`0000CoYL?_0ol00004ojG3k`03o`000?nU`nooYL?_
00Co00001?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00?o0000ok;6jOl000000_oKdm001?l0
003ol>O3oo3W`ol00002onoU``04o`000?o^h/Cok^;4o`0000;ok=k400Co0000on[Ka?oZflCo0000
0ooXel@01?l0003oiM?5o`000?l00003on;=``04o`000?oOb<?oglS3o`0000;oflG300?o0000om[1
`Ol000000ooF_L400ol0003odkW1o`000002om6e_`07o`000?o=/KoocK6oolfa_ol0003objjmo`00
0003olJZ_@03o`000?o4Y[_o000000?o`:>k00Ko0000okfO^_nmWk[o0000okVK^Ol00004okNH^006
o`000?ndUKOo]9Fgo`000?n`T[Oo00001?n^SkH01?l0003oZhbeoj^<]On[S;D2o`0000?oYXNd00Go
0000ojB5/onTQK?oY8Fco`000004oj:3/`05o`000?nOPK?oWh6coin1/ol000000_nMP;<4o`0000;o
Vgjb00Go0000oiUm/_nIOK;oVGfbo`000003oiQl/`03o`000?nFO;CoUWbd00;oUWbd00Go0000oiAk
]OnDNkGoU7^eo`000003oi=k]P05o`000?nAO;SoTGbhoi5l^?l000001?n@O;X01Ol0003oSWflohim
_?n>OKco000000?oSGjn00Go0000ohb0`_n<P<;oS832o`000004oh^3a@05o`000?n:Q/WoRXK9ohZ6
bOl000001?n9RLd01?l0003oRHkAohV>dOl00004ohVBeP05o`000?n:V=_oRYSKohZHfol000001?n<
W^001Ol0003oSZGUohjUiOn>YNGo000000GoT:cY00?o0000oi>bk?nC/^`01Ol00002oi^ik@03o`00
0?nN_^ooW[k_00;oW[k_00?o0000ojC3kol000001?l0000@ooooo`03o`000?oooooooooo00?ooooo
0013ooooo`04o`000?oooooo0000o`0000CoYL?_00?o0000ojG3konU`nl01?l00003ojG3k`04o`00
0?nU`noo0000o`0000;oYL?_00?o0000ojG3konU`nl00_nU`nl3o`0000?oYL?_00?o0000ojG3konU
`nl00_nU`nl3o`0000CoYL?_00?o0000ojG3konU`nl00ol00003om_Cd003o`000?o`il?o000000;o
knG300Co0000onkRa?o^h/Co00000_o/g/@01?l0003oj]_4on[Ka?l00003onSGa008o`000?oUdlGo
iM?5o`000?oSd<Go0000on;=`ol00002omo8``03o`000?oKaL?oflG300;oflG300Go0000omJm`OoF
_L7oe[g1o`000002om>i`@03o`000?oA]Koo000000GocK6o00?o0000olJZ_Oo6Z[d00oo6Z[d00ol0
003o`:>kol2S^`02ol2S^`03o`000?nmWk[o000000?o^I^i00?o0000okNH^?ngV;P00_ngV;P2o`00
00?o/9:g00Go0000ojj?]_n^SkKo[Xnfo`000002oj^<]@03o`000?nYR[Co000000?oYXNd00?o0000
ojB5/onTQK<00_nTQK<01Ol0003oXX>coj:3/onRPk?o000000?oWh6c0ol00002oieo/P05o`000?nK
O[;oVgjboi]n/_l000001?nIOK801Ol0003oV7bcoiQl/onHO;?o000000?oUWbd00Go0000oiAk]OnD
NkGoU7^eo`000003oi=k]P03o`000?nAO;SoTGbh00;oTGbh00Go0000oi1l^_n@O;[oT7bjo`000003
ohim_005o`000?n=O[koSGjnohen__l000001?n<P<801Ol0003oRh?5oh^3aOn;PlGo000000?oRXK9
00?o0000ohV9cOn9RLd00_n9RLd01Ol0003oRHkAohV>dOn9S]7o000000CoRI;F00Go0000ohZHfon:
V=_oRYSKo`000004ohbNh005o`000?n>YNGoSZGUohjUiOl000000on@[>T4o`0000;oVK?Z00?o0000
oi^ikOnK^Nd00onK^Nd00ol0003oW[k_oijnk`03o`0000?oY<;_00?o0000ojC2kol000003oooool0
0ol0003oooooooooo`03ooooo`00A?ooool01?l0003oooooooooool00002ojG3k`Co00001?nU`nl0
0ol0003oYL?_ojG3k`03o`0000CoYL?_00Co0000ojG3kol0003o00000_nU`nl00ol0003oYL?_ojG3
k`02ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o0000ojG3konU`nl00_nU`nl3o`0000?oYL?_
00?o0000om_Cd?l000001ol000001?o^h/Co0000oncNa?l00003on[Ka004o`000?oXelCoj=O4o`00
00;oiM?500Go0000on?@aOoSd<Gohm35o`000003omo8``03o`000?oKaL?oflG300;oflG300Go0000
omJm`OoF_L7oe[g1o`000003om>i`@03o`000?o=/KoocK6o00CocK6o00?o0000olJZ_Oo6Z[d00_o6
Z[d2o`0000Go`:>k00?o0000okVK^OniVkT00_niVkT01?l0003o]iRhokNH^?ngV;P2o`0000Co/9:g
00?o0000ojj?]_n^SkH00_n^SkH2o`0000;oZHZd00Go0000ojJ7]?nVQkCoYXNdo`000004ojB5/`06
o`000?nRPk?oXX>coj:3/ol0003oWh6c0_l000000onNP;;o0000oieo/P02oieo/P03o`000?nKO[;o
Vgjb00;oVgjb00Go0000oiUm/_nIOK;oVGfbo`000003oiQl/`05o`000?nFO;CoUWbdoiIl]?l00000
0onDNkD01Ol0003oTg^foi=k]_nCNkKo000000CoTGbh00Go0000oi1l^_n@O;[oT7bjo`000004ohim
_005o`000?n=O[koSGjnohen__l000000on<P<801Ol0003oRh?5oh^3aOn;PlGo000000?oRXK900?o
0000ohV9cOn9RLd00_n9RLd01Ol0003oRHkAohV>dOn9S]7o000000CoRI;F00?o0000ohZHfon:V=/0
3_l00002oiN]iP03o`000?nI/n[oVK?Z00;oVK?Z00Co0000oi^ikOnK^NgoVkW]1?l00003oj6nkP03
o`000?nT`^ooY<;_00?o00003oooool00ol0003oooooooooo`03ooooo`00AOooool2o`000003oooo
ool0003o000000CoYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co0000
1?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00Ko0000ojG3kol0003o0000ojG3kol00004ojG3
k`?o000000Go]/KWo`000?oIdM7ofM7Ao`000002ongTa`Go000000?oj]_4o`000?oXel@00_oXel@0
0ol0003oiM?5o`000004on?@a@;o000000?oglS3o`000?oKaL<00ooKaL<01Ol0003of<73o`000?oF
_L7o000000CodkW100?o0000olfa_oo=/Kl00oo=/Kl00ol0003obJjoo`000002olJZ_@04o`000?o2
Y[go`ZJmo`0000?o`:>k0_l00004okVK^@06o`000?ngV;So]iRho`000?ncUKSo00001?n`T[L01?l0
003o[Xnfojj?]_n^SkH2o`0000CoZHZd00Go0000ojJ7]?nVQkCoYXNdo`000003ojB5/`03o`000?nR
Pk?oXX>c00?o00000onNP;800ol0003oWGnboieo/P02oieo/P05o`000?nKO[;oVgjboi]n/_l00000
0onIOK801Ol0003oV7bcoiQl/onHO;?o000000?oUWbd00?o0000oiAk]OnDNkD00_nDNkD01Ol0003o
Tg^foi=k]_nCNkKo000000?oTGbh00?o0000oi1l^_n@O;X00_n@O;X00ol0003oSWflo`00000Ro`00
00;oTY_I00?o0000oi>Qg_nCXMh00_nCXMh01Ol0003oUJORoiFWh_nEYn;o000000GoUjgV00?o0000
oiVcj_nI/nX01Ol00002oinjj`04o`000?nQ_^koXKk^oj6nkPCo00000_nT`^h2o`0000kooooo00?o
0000ooooooooool00oooool004Oooooo00Co0000oooooooooooo00000_nU`nl4o`0000?oYL?_00?o
0000ojG3konU`nl01?l00004ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_ojG3
k`03o`0000CoYL?_00Co0000ojG3kol0003o00000onfa^L01?l0003ofM7AomWAdOl00003ongTa`03
o`000?o[hLOo000000;ojMk70ol000001OoXelCo0000onGCaOoUdlGo000000?ohm3500?o0000omo<
aOoOc<D00_l00003om_5``05o`000?oH`L?of<73omS1`ol000001?oC^L400ol0003ockG1o`000003
olfa_`06o`000?o9[[oobJjoo`000?o6Z[go00000oo2Y[d01?l0003o`:>kol2S^ol00002okbO^`03
o`000?niVkWo^I^i00;o^I^i0_l00003ok>E^003o`000?n`T[Oo/9:g00;o/9:g0ol000000on[S;Go
0000ojV:]003ojV:]005o`000?nVQkCoYXNdojJ7]?l000000onTQK<3o`0000;oX8:b00?o0000oij0
/_nNP;800_nNP;801Ol0003oWGnboieo/_nMOk;o000000?oVgjb00Go0000oiUm/_nIOK;oVGfbo`00
0003oiQl/`03o`000?nFO;CoUWbd00;oUWbd00?o0000oiAk]Ol000004?l00002oi=o^`05o`000?nB
PKgoTX6moi:1_Ol000001?nBPl001Ol0003oTHK3oi66`onAQ/?o000000?oTHW700?o0000oi6<bonA
S</00_nAS</01Ol0003oTI7?oi6AconATLoo000000CoTIKD00?o0000oi:KfOnBVmT00_nBVmT00ol0
003oTj7Noi>QgP02oi>QgP05o`000?nEYn;oUJORoiFWh_l000000onG[NH4o`0000?oW[GX00?o0000
oinjjonO^^/01Ol00003oj>ok@03o`000?nT`^koY<;^00?o00003Oooool00ol0003oooooooooo`03
ooooo`00B?ooool00ol0003oooooooooo`02o`0000?oYL?_00?o0000ojG3konU`nl01?l00004ojG3
k`03o`000?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3
konU`nl01?l00003okK6i`05o`000?oIdM7ofM7AomWAdOl000000_o]i<L00ol0003ojn77o`000003
onWNa`03o`000?oWflOoim_700;o000000?oiM?5o`000?oSd<D00_oSd<D02Ol0003oglc5omo<aOoO
c<Go0000omc8aOl0003oflG3o`000004omS1``05o`000?oC^L7odkW1om>i`Ol000000oo?]L400ol0
003ocK6oo`000004olV^_`03o`000?o2Y[go`ZJm00;o`ZJm00?o0000ol2S^ol000000onlWk/01?l0
003o^I^iokVK^OniVkT2o`0000Co/iFh00Co0000ok2B]on`T[Oo/9:g0_l00003oj^<]@03o`000?nY
R[CoZHZd00;oZHZd00Ko0000ojJ7]?nVQkCoYXNdo`000?nTQK<2o`000003oj:3/_l0003oX8:b00;o
X8:b00?o0000oij0/_nNP;800_nNP;801Ol0003oWGnboieo/_nMOk;o000000?oVgjb00?o0000oiUm
/_nIOK800_nIOK801_l0003oV7bcoiQl/onHO;?o0000oiIl]0Co00000_nGO;@01Ol0003oUWbeoiIl
]OnFO;Go000000CoU7fg00Go0000oiAn^OnDO[WoU7jio`000003oi=o^`05o`000?nBPKgoTX6moi:1
_Ol000001OnBPl001Ol0003oTHK3oi66`onAQ/?o000000?oTHW700?o0000oi6<bonAS</00_nAS</0
1Ol0003oTI7?oi6AconATLoo000000CoTIKD00Go0000oi:KfOnBVmWoTY_Io`000003oi>QgPWo0000
0_nL[nD00ol0003oW[GXoijej002oijej0?o00000_nS_>/00ol0003oXko]oj>ok@03oj>ok@?o0000
00CoYL?_o`000?nU`noo00003?ooool00ol0003oooooooooo`03ooooo`00BOooool01?l0003ooooo
ooooool00003ojG3k`?o00000onU`nl00ol0003oYL?_ojG3k`02ojG3k`?o00001?nU`nl00ol0003o
YL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00004ojG3k`03o`000?nfa^Oo000000?o
fM7A00Ko0000ongTaoo]i<Oo0000on_Qaol00003onWNa`06o`000?oWflOoim_7onOKaol0003oiMO8
0ol000000ooSd<Go0000omo<a@02omo<a@05o`000?oLb<Gog<S5omc8aOl000001?oH`L<01Ol0003o
e;g3o`000?oC^L7o000000GockG100?o0000olV^_oo9[[l00oo9[[l00ol0003o`ZJmol:V_@03ol:V
_@03o`000?nlWk_o_9nk00;o_9nk00Ko0000okVK^OniVkWo0000okJH^Ol00004ok>E^006o`000?n`
T[Oo/9:go`000?n]SkKo00001?n[S;D01Ol0003oZHZdojV:]?nYR[Co000000?oYXNd0_l00003oj:3
/P03o`000?nPP[;oX8:b00;oX8:b00Go0000oij0/_nNP;;oWX2bo`000003oieo/P03o`000?nKO[;o
Vgjb00;oVgjb00?o0000oiUm/_l000001ol00002oiQl/`05o`000?nGO;CoUgbdoiMl]?l000001?nF
O;D01Ol0003oU7fgoiAm]onDOKOo000000?oU7ji00?o0000oi=o^onCOk/00_nCOk/01Ol0003oTX6m
oi:1_OnBPKgo000000CoTX?000Go0000oi66`onAQ/?oTHK3o`000003oi69a`03o`000?nAS<_oTHc;
00;oTHc;00Go0000oi6AconATLooTI7?o`000004oi6Fe003o`000?nBVmWoTY_I00Go00000_nJXm`0
1Ol0003oVjWPoi^Yh?nKZN3o000000GoW:oU1?l000000onR^NWo0000oj>lj`03oj>lj`03o`000?nS
_ngo000000;o000000?oYL?_o`000?nU`nl00_nU`nl3o`0000cooooo00?o0000ooooooooool00_oo
ool004[ooooo0_l000001?oooooo0000ojG3kol00002ojG3k`03o`000?nU`nooYL?_00;oYL?_00Co
0000ojG3kol0003o00000_nU`nl00ol0003oYL?_ojG3k`02ojG3k`?o00000onU`nl00ol0003oYL?_
ojG3k`04o`0000CoYL?_00?o0000ojG3konU`nl01?l00002omWAd@04o`000?o]i<OokNC7o`0000;o
jn7700Co0000onWNaooYg/Oo00000ooWflL01?l0003oiMO8onGGb?l00002on?Cb005o`000?oOc<Go
glc5omo<aOl000001?oLb<D01Ol0003of<73omS1`ooH`L?o000000?oe;g300?o0000olne`Oo?]L40
0oo?]L42o`0000CobJjo00?o0000olFZ_ol000000oo2Y[d2o`0000Go_9nk0_l00003okJH^@03o`00
0?ncUKSo/iFh00;o/iFh0_l00002ojf?]P03o`000?n[S;GoZhbe00;oZhbe00?o0000ojV:]?nYR[@0
0_nYR[@3o`000003ojB5/ol0003oXX>b00?oXX>b00Go0000oj22/_nPP[;oX8:bo`000003oij0/P03
o`000?nMOk;oWGnb00;oWGnb00?o0000oi]n/_l000000ol00002oiYm/P05o`000?nIO;;oVGbboiUl
/_l000000onHO;<00ol0003oUgbdoiMl]002oiMl]005o`000?nFO;GoUWbeoiIl]Ol000001?nDOKL0
1Ol0003oU7jioiAn^OnDO[Wo000000?oTgnk00Go0000oi:1_OnBPKgoTX6mo`000004oi:3`005o`00
0?nAQ/?oTHK3oi66`ol000000onARLL00ol0003oTHc;oi6<b`02oi6<b`03o`000?nATLooTI7?00Wo
00000_nIW]L00ol0003oVZ?LoiZSg002oiZSg003o`000?nKZN3oVjWP00;oVjWP00?o0000oib_iOnL
[nD00ol00005oj:ij@03o`000?nS_>_oXkc[00?o00001OnU`nl6o`0000cooooo00?o0000oooooooo
ool00_ooool004cooooo00?o0000ooooool000001?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_
00Co0000ojG3kol0003o00000_nU`nl01?l0003oYL?_ojG3konU`nl3o`0000CoYL?_00?o0000ojG3
konU`nl01?l00004ojG3k`05o`000?oIdM7o0000ongTaol000000_o[hLL01Ol0003ojMk7onWNaooY
g/Oo000000;oim_700Co0000onGGb?oUelSo00000ooSdlP2o`000003omo<aOl0003og<S500?og<S5
00Go0000omW4aOl0003of<73o`000003omBm``03o`000?o@^L?o000000?ockG100Co0000ol^a`Oo;
/L7o00000_o9[[l01?l0003oaJZoolFZ_ol00002ol:V_@04o`000?nnXkgo_Z>mo`0000?o_9nk0_l0
0004okJH^@04o`000?ncUKSo/iFhok>E^0;o00001?n]SkH01Ol0003oZhbeoj^<]On[S;Go000000?o
ZHZd0_l00003ojB5/`03o`000?nRPk;oXX>b00;oXX>b00Go0000oj22/_nPP[;oX8:bo`000003oij0
/P04o`000?nMOk;oWGnboieo/P?o00000_nKOK401Ol0003oVWfboiYm/_nJOK;o000000?oVGbb00?o
0000oiQl/onHO;<00_nHO;<01Ol0003oUgbdoiMl]?nGO;Co000000?oUWbe00?o0000oiAm]onDOKL0
0_nDOKL01Ol0003oU7jioiAn^OnDO[Wo000000?oTgnk00Go0000oi:1_OnBPKgoTX6mo`000005oi:3
`006o`000?nAQ/?oTHK3oi66`ol0003oTHW72Ol00002oiRDcP03o`000?nIV=;oVISB00;oVISB00?o
0000oiVNeonIW]L00_nIW]L00ol0003oVZ?LoiZSg002oiZSg003o`000?nKZN3oVjWP00Co00000onR
]>H01?l0003oX[WYoj:ijOnR^NT4o`0000?oYL?_00?o0000ojG3konU`nl00ol00004ojG3k`;o0000
2oooool00ol0003oooooooooo`02ooooo`00COooool00ol0003oooooo`000002ojG3k`Co00001?nU
`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00?o0000ojG3kol000000_nU`nl00ol0003oYL?_ojG3
k`02ojG3k`?o00000onU`nl00ol0003oYL?_ojG3k`02ojG3k`Wo000000GojMk7o`000?oWflOoim_7
o`000002onGGb005o`000?oSdlSohm?8on?Cb?l000000_oPd<P2o`0000?og<S500Go0000omW4aOoI
a<GofLC5o`000003omBm``07o`000?o@^L?od;W3om2i`ol0003ockG1o`000003ol^a`@03o`000?o9
[[oo000000?oaJZo00?o0000ol:V_Ol000000onnXkd01_l0003o_9nkokbO^ol0003o^9bko`0000Co
]YRi00Ko0000ok>E^?ncUKSo0000ok2B^?l00004ojf?]P03o`000?n[S;GoZhbe00;oZhbe0ol00000
0onVQkCo0000ojB5/`03ojB5/`05o`000?nRPk;oXX>boj:3/_l000000onPP[800ol0003oWX2boij0
/P02oij0/P?o000000?oW7jao`000?nKOK400_nKOK400ol0003oVWfboiYm/P02oiYm/P05o`000?nI
O;;oVGbboiUl/_l000000onHO;<01Ol0003oUgbdoiMl]?nGO;Co000000CoUWbe00Go0000oiAm]onD
OKOoU7fgo`000003oiAn^@03o`000?nCOk_oTgnk00;oTgnk00Go0000oi:1_OnBPKgoTX6mo`000002
oi:3`0So00000_nGS<D00ol0003oV8o9oiR?b@02oiR?b@03o`000?nHU<koV9C>00;oV9C>00?o0000
oiVHd_nIV=800_nIV=801Ol0003oVIkGoiVNeonIW]Oo000000;oVZ?L1Ol00003oj6`hP03o`000?nR
]>KoX[CV00Go00000_nU`nl01?l0003oYL?_ojG3konU`nl4o`0000?oYL?_00Co0000ojG3konU`noo
YL?_0ol0000:ooooo`03o`000?oooooooooo00;ooooo001>ooooo`04o`000?oooooo0000o`0000Co
YL?_00?o0000ojG3konU`nl01?l00004ojG3k`03o`000?nU`nooYL?_00?o00001?nU`nl01?l0003o
YL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_00Co0000ojG3kol0003o00000_nca^P0
1Ol0003od/_Com;;dooBbm?o000000;oj>;;0_l000000ooWflOo0000onGGb002onGGb004o`000?oS
dlSohm?8o`0000?oh=3800Go0000omg<b?l0003og<S5o`000004omW4a@;o000000?oe;g3o`000?o@
^L<01?o@^L<00ol0003obk71ol^a`@03ol^a`@03o`000?o5Z[ooaJZo00?oaJZo00?o0000okjS_Onn
Xkd00_nnXkd00ol0003o_9nko`000003okRL^`03o`000?nfV;Wo]YRi00;o]YRi0_l00002ok2B^003
o`000?n]SkKo[Hnf00;o[Hnf00Co0000oj^<]On[S;GoZhbe0_l00003ojJ7]003o`000?nTQK?oY8Fc
00;oY8Fc00Go0000oj:3/_nRPk;oXX>bo`000004oj22/P03o`000?nNP;;o000000;o00000onLO[40
0ol0003oVgfaoi]m/@02oi]m/@05o`000?nJOK;oVWfboiYm/_l000000onIO;801Ol0003oV7bcoiQl
/onHO;?o000000?oUgbd00?o0000oiIl]OnFO;D00_nFO;D00ol0003oU7fgoiAm]`02oiAm]`06o`00
0?nDO[WoU7jioiAn^Ol0003oTgnk2Ol00002oiN6_`05o`000?nGR<;oUhS2oiN8`_l000001?nGS<D0
0ol0003oV8o9oiR?b@02oiR?b@05o`000?nHU<koV9C>oiRDc_l000001?nIV=800ol0003oVIkGoiVN
e`04o`0000;oXJ_N00?o0000oj6`h_nQ/>800onQ/>83o`0000?oYL?_00?o0000ojG3konU`nl01Ol0
0003ojG3k`03o`000?nU`nooYL?_00Go000000?oYL?_o`000?l000002_ooool00ol0003ooooooooo
o`02ooooo`00Coooool2o`000004ooooool0003oYL?_ojG3k`Co00001?nU`nl00ol0003oYL?_ojG3
k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00004ojG3k`03o`000?nU`nooYL?_00?o00000onc
a^P01Ol0003od/_Com;;dooBbm?o000000?oj>;;00?o0000onONbol000000_l000000ooUelSo0000
on?Cb002on?Cb004o`000?oPd<Soh=38o`0000?ogLc800?o0000omW4aOoIa<D00_oIa<D01?l0003o
e/76omK1a_l00006om2i``03o`000?o;/L7obk7100;obk710_l00004olFZ_`;o00001OnnXkd00ol0
003o^9bkokRL^`02okRL^`04o`000?nfV;Wo]YRiokJH^@;o00001?n`T[P00ol0003o[Hnfojf?]P02
ojf?]P?o000000?oZ8Zeo`000?nVQk@00onVQk@01Ol0003oY8FcojB5/onTQK?o000000CoXX>b00?o
0000oj22/_l000000ol00002oiio/@03o`000?nLO[7oW7ja00;oW7ja00Go0000oi]m/OnKOK7oVgfa
o`000003oiYm/P05o`000?nIO;;oVGbboiUl/_l000000onHO;<00ol0003oUgbdoiMl]002oiMl]005
o`000?nFO;GoUWbeoiIl]Ol000000_nDOKL8o`0000;oUh:j00Go0000oiN3_?nGPkcoUh>lo`000005
oiN6_`05o`000?nGR<;oUhS2oiN8`_l000001?nGS<D01Ol0003oV8o9oiR?bOnHSlWo000000;oV9C>
2Ol00002oj2VfP03o`000?nQZmkoXJ_N00;oXJ_N00?o0000oj6`h_l000000_l000000onU`noo0000
ojG3k`03ojG3k`?o00000onU`nl01?l0003oYL?_ojG3konU`nl4o`0000?oYL?_00?o0000ojG3konU
`nl00ol00009ooooo`03o`000?oooooooooo00;ooooo001Aooooo`04o`000?oooooo0000o`0000Co
YL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl00ol0003o
YL?_ojG3k`04o`0000?oYL?_00?o0000ok?6j?l000000ooBbm<01Ol0003oj>;;onSRbooXh/_o0000
00;oimk;00?o0000onGKbooUfl/00ol000001OoSdlSo0000on3@b?oPd<So000000CogLc800Go0000
omW4aOoIa<GofLC5o`000003omK1aP03o`000?o@^L?od;W300?od;W300?o0000olfe`ol000000_o;
/L401?l0003oajk1olN^`Ol00002olFZ_`04o`000?o1Y[oo`JJoo`0000?o_Z>m0_l00004okRL^`06
o`000?nfV;Wo]YRio`000?nbUKWo00001?n`T[P01?l0003o[Hnfojf?]_n]SkH2o`0000?oZ8Ze00?o
0000ojJ7]?nVQk@00_nVQk@01Ol0003oY8FcojB5/onTQK?o000000?oXX>b0ol00002oin1/P05o`00
0?nNOk7oWWnaoiio/Ol000001?nLO[401Ol0003oVgfaoi]m/OnKOK7o000000?oVWfb00Go0000oiUl
/_nIO;;oVGbbo`000004oiQl/`03o`000?nGO;Co000000So00000_nHOkH01Ol0003oV82hoiR0^?nH
P;So000000?oUh:j00?o0000oiN3_?nGPk`00_nGPk`00ol0003oUhJooiN6_`02oiN6_`05o`000?nG
R<;oUhS2oiN8`_l000001?nGS<D00ol0003oV8o9oiR?b@04o`0000;oWigB00?o0000oinRe_nOX]H0
0_nOX]H00ol0003oX:KJoj2VfP02oj2VfP03o`000?nQZmkoXJ_N00?o00001OnU`nl01_l0003oYL?_
o`000?l0003oYL?_o`0000CoYL?_1?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol000001?nU
`noo0000ojG3kol00008ooooo`03o`000?oooooooooo00;ooooo001Booooo`03o`000?oooooo0000
00CoYL?_0ol00003ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_ojG3k`04o`00
00?oYL?_00?o0000ojG3konU`nl01?l00003om;;d`04o`000?oXh/_oj>;;o`0000;oimk;00Go0000
onGKbooUfl_oiM_;o`000002on;Gc0;o000000?oh=38o`000?oMc<P00ooMc<P01Ol0003of/S8o`00
0?oIa<Go000000?oe/7600?o0000om:ma_l000000oo@^L<01_l0003ocKG3olfe`ol0003obk71o`00
00?oajk100?o0000olFZ_ol000000oo1Y[l01?l0003o_Z>mokjS_Ol00002okZO_@03o`000?nhW;_o
^9bk00;o^9bk0_l00003ok:E^@05o`000?n`T[So/9:hok2B^?l000000_n]SkH00ol0003oZXbfo`00
0004ojR:]@05o`000?nVQkCoYXNdojJ7]?l000001?nTQK<3o`000003oj62/_l0003oWh6b00;oWh6b
00?o0000oiio/OnNOk400_nNOk401Ol0003oW7jaoian/OnLO[7o000000?oVgfa00Go0000oiYm/_nJ
OK;oVWfbo`000004oiUl/P03o`000?nHO;?o000000?o00000_nIOK<00ol0003oV7jdoiQn]002oiQn
]005o`000?nHOkKoV7nfoiQo]_l000000onHP;P00ol0003oUh:joiN2^P02oiN2^P05o`000?nGPkco
Uh>loiN3_?l000001?nGQ[l01Ol0003oUhS2oiN8`_nGR<;o000000?oUhc51?l00002oijIcP03o`00
0?nOWM;oWigB00;oWigB00?o0000oinRe_nOX]H00_nOX]H00ol0003oX:KJoj2VfP04o`0000?oYL?_
00Co0000ojG3konU`nooYL?_0ol00004ojG3k`06o`000?nU`noo0000o`000?nU`noo00001OnU`nl4
o`000003ojG3kol0003oYL?_00;oYL?_0ol00008ooooo`03o`000?oooooooooo007ooooo001Coooo
o`04o`000?oooooo0000ojG3k`;o00000_nU`nl01?l0003oYL?_ojG3konU`nl3o`0000CoYL?_00?o
0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl00ol0003od/_Co`00
0002onSRb`04o`000?oWg/_oimk;o`0000?oiM_;00Co0000on;Gc?oRelco00000_oOe<`2o`0000?o
gLc800Go0000om[8b?oJb<Sof/S8o`000003omK1aP07o`000?oB_LKod[g6om:ma_l0003od;W3o`00
0004olfe``03o`000?o7[/7oajk100?oajk100?o0000ol6V_oo1Y[l00_o1Y[l00ol0003o_Z>mo`00
0003okZO_@04o`000?nhW;_o^9bkokRL^`;o00001?nbUKT00ol0003o/9:hok2B^002ok2B^0;o0000
0_nZS;H00ol0003oZ8ZeojR:]@02ojR:]@05o`000?nVQkCoYXNdojJ7]?l000000onTQK<2o`0000?o
XH:b00?o0000oin1/_nOPK800_nOPK801Ol0003oWWnaoiio/OnNOk7o000000?oW7ja00Go0000oi]m
/OnKOK7oVgfao`000004oiYm/P03o`000?nIO;;o000000?o00000_nIOK800ol0003oVGfcoiUm/`02
oiUm/`05o`000?nHO[CoV7jdoiQn]?l000001?nHOkH01Ol0003oV82hoiR0^?nHP;So000000?oUh:j
00?o0000oiN3_?nGPk`00_nGPk`00ol0003oUhJooiN6_`02oiN6_`03o`000?nGR<;o000000Co0000
0_nNUL/00ol0003oWYW>oijIcP02oijIcP05o`000?nOWM;oWigBoinMd_l000000onOX]H4o`0000?o
YL?_00?o0000ojG3konU`nl01Ol00002ojG3k`04o`000?nU`nooYL?_ojG3k`?o00001?nU`nl00ol0
003oYL?_ojG3k`03o`0000GoYL?_1_l00008ooooo`03o`000?oooooooooo007ooooo001Dooooo`Co
00001?nU`nl00ol0003oYL?_o`000002ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol00004ojG3k`03
o`000?nU`nooYL?_00?o00001?nU`nl00ol0003oYL?_ojG3k`07o`000003onONbol0003oiM_;00;o
iM_;00Co0000on;Gc?oRelco00000ooOe<`01Ol0003ogM3<o`000?oMc<So000000?of/S800Go0000
omK5bOl0003oe/76o`000005om:maP03o`000?o=]L?ocKG300;ocKG30_l00004olN^`@;o00001?o1
Y[l2o`0000Co^Ynm00Ko0000okRL^onhW;_o0000okBH^ol00004ok:E^@04o`000?n`T[So/9:hok2B
^0;o00001?nZS;H01Ol0003oZ8ZeojR:]OnXR[Go000000CoYXNd0ol000000onRQ;?o0000oj62/P03
oj62/P05o`000?nOPK;oWh6boin1/_l000000onNOk401Ol0003oW7jaoian/OnLO[7o000000CoVgfa
00?o0000oiYm/_l000000ol00002oiYm/P05o`000?nIOK;oVGfboiUm/_l000001?nIOK<00ol0003o
V7jdoiQn]002oiQn]005o`000?nHOkKoV7nfoiQo]_l000000onHP;P01Ol0003oUh:joiN2^_nGP[[o
000000CoUh>l00?o0000oiN6_onGQ[l01?l00002oifBb003o`000?nNUL_oWYG;00?oWYG;00Go0000
oijIc_nNVLkoWYW>o`000002oinMdPGo00000_nU`nl01?l0003oYL?_ojG3konU`nl4o`0000?oYL?_
00?o0000ojG3konU`nl01Ol00002ojG3k`04o`000?nU`nooYL?_ojG3k`Co00000onU`nl00ol0003o
YL?_ojG3k`03o`0000CoYL?_0_l00007ooooo`03o`000?oooooooooo007ooooo001Fooooo`03o`00
0?oooooo000000;oYL?_0ol00004ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o0000ojG3konU
`nl00_nU`nl3o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojW4k@04o`000?o9b=WobLSIolW8
f@?o000000GoiM_;o`000?oRelcoh]O<o`000003omoDc005o`000?oMd<cogM3<omg@c?l000000ooJ
b<P01Ol0003oe/G9omK5bOoFaLWo000000God[g60_l00003olfe``04o`000?o9//CobK;4o`0000;o
ajk100Co0000ol>Z`Oo3Z/7o00000_o1Y[l00ol0003o_J>oo`000005okZO_@;o00000ondV;/00ol0
003o/YFiok:E^@02ok:E^@?o000000?o[8nho`000?nZS;H00onZS;H01Ol0003oZ8ZeojR:]OnXR[Go
000000?oYXNd0_l00003oj:4/`03o`000?nQP[;oXH:b00;oXH:b00Go0000oin1/_nOPK;oWh6bo`00
0003oiio/@03o`000?nLO[7oW7ja00;oW7ja00?o0000oi]m/Ol000000ol00002oi]m/@05o`000?nJ
OK;oVWfboiYm/_l000001?nIOK801Ol0003oVGfcoiUm/onIOK?o000000CoV7jd00Go0000oiQo]_nH
OkKoV7nfo`000003oiR0^003o`000?nGP[[oUh:j00;oUh:j00?o0000oiN3_?nGPk`01?l00002oif?
a@03o`000?nMT/SoWI;800;oWI;800?o0000oijEbonNUL/00_nNUL/01?l0003oWYW>oijIc_nNVLh3
o`0000;oYL?_00?o0000ojG3konU`nl00_nU`nl4o`0000?oYL?_00?o0000ojG3konU`nl01?l00003
ojG3k`03o`000?nU`nooYL?_00Go00000_nU`nl01?l0003oYL?_ojG3konU`nl4o`0000?oYL?_00?o
0000ojG3konU`nl00ol00007ooooo`03o`000?oooooooooo007ooooo001Gooooo`04o`000?oooooo
0000o`0000?oYL?_00?o0000ojG3konU`nl01?l00004ojG3k`06o`000?nU`noo0000o`000?nU`noo
00001?nU`nl3o`0000CoYL?_00?o0000ojW4kOl000001?o9b=T00ol0003ogm_BomoKdP02o`000003
on;Gc?l0003ogmC<00;ogmC<00Wo0000omg@c?oMd<cogM3<o`000?oJcLco0000om[8b?l000000ooF
aLT00ol0003od/79o`000003om:maP06o`000?o>^LKoc[W6o`000?o=]L?o00000oo9//@00ol0003o
ajk1o`000003ol>Z`@03o`000?o1Y[oo000000?o_J>o00Co0000okZO_OnjWkgo^Ynm0_l00004okBH
^`04o`000?nbUKWo/YFiok:E^@;o00000on/SkP00ol0003oZXbfojZ<]P02ojZ<]P03o`000?nXR[Go
Z8Ze00;oZ8Ze0ol000000onTQKCo0000oj:4/`03oj:4/`05o`000?nQP[;oXH:boj62/_l000000onO
PK800ol0003oWWnaoiio/@02oiio/@03o`000?nLO[7o000000?o00000_nKOK401Ol0003oVgfaoi]m
/OnKOK7o000000CoVWfb00Go0000oiUm/_nIOK;oVGfbo`000004oiUm/`05o`000?nHO[CoV7jdoiQn
]?l000001?nHOkH01_l0003oV82hoiR0^?nHP;So0000oiN2^PGo00000_nMSL800ol0003oWHo5oif?
a@02oif?a@05o`000?nMT/SoWI;8oifBb?l000001?nNUL/01_l0003oWYW>o`000?l0003oYL?_o`00
00CoYL?_00Ko0000ojG3kol0003o0000ojG3kol00005ojG3k`?o00000onU`nl00ol0003oYL?_ojG3
k`04o`0000?oYL?_00?o0000ojG3konU`nl01Ol00003ojG3k`03o`000?nU`nooYL?_00Co00000_nU
`nl2o`0000Kooooo00?o0000ooooooooool00Oooool005Sooooo00?o0000ooooool000000_nU`nl4
o`0000CoYL?_00?o0000ojG3konU`nl00ol00004ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o
0000ojG3konU`nl00_nU`nl2o`0000CobLSI00Ko0000omoKd_oOfm;ogm_Bo`000?oQfm03o`000003
omoDc?l0003ogM3<00;ogM3<00Go0000om[=c?oJcLcof/g<o`000003omK5b@07o`000?oB`LWod/79
om;1bOl0003od[g6o`000004oljiaP03o`000?o9//CobK;400;obK;40_l00005ol>Z`@03o`000?nm
Xkoo_J>o00;o_J>o00Ko0000okZO_OnjWkgo0000okJL_Ol00004okBH^`06o`000?nbUKWo/YFio`00
0?n^T[Wo00001?n/SkP01Ol0003oZXbfojZ<]_nZS;Ko000000?oZ8Ze0_l00003ojB5]003o`000?nR
Q;?oXXBc00;oXXBc00Go0000oj62/_nQP[;oXH:bo`000004oin1/P03o`000?nNOk7o000000?o0000
0_nLO[401Ol0003oVgfaoi]m/OnKOK7o000000CoVgfa00Go0000oiYm/_nJOK;oVWfbo`000003oiUm
/P03o`000?nIOK?oVGfc00;oVGfc00?o0000oiQn]?nHO[@00_nHO[@00ol0003oV7nfo`000007o`00
00;oWH_000?o0000oif=`_nMSL800onMSL801Ol0003oWHo5oif?aOnMSlGo000000?oWI;800Co0000
oijEbonNUL_oWYG;0ol00004ojG3k`03o`000?nU`nooYL?_00?o00001?nU`nl00ol0003oYL?_o`00
0002o`000003ojG3kol0003oYL?_00?oYL?_0ol00003ojG3k`03o`000?nU`nooYL?_00Co00000onU
`nl01?l0003oYL?_ojG3konU`nl4o`0000?oYL?_00?o0000ojG3konU`nl00ol00005ooooo`03o`00
0?oooooooooo007ooooo001Iooooo`Co00001?nU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o
0000ojG3konU`nl01?l00004ojG3k`06o`000?nU`noo0000o`000?nU`noo00000oo9b=T01Ol0003o
gm_BomoKd_oOfm;o000000;ohM_@00Co0000omkHd?oNf=3o00000ooMd<`00ol0003of/g<om[=c002
om[=c0;o000000?oe/G9o`000?oB`LT01?oB`LT00ol0003oc[W6oljiaP02oljiaP;o00000oo9//@0
0ol0003oaJk4o`000004ol>Z`@;o00001?nmXkl00ol0003o^Ynmo`000003okJL_@03o`000?ndV;_o
]9Rk00;o]9Rk0_l00002ojjB^@03o`000?n/SkSo[8nh00;o[8nh00?o0000ojZ<]_nZS;H00_nZS;H3
o`000003ojF7]Ol0003oY8Fd00?oY8Fd00Go0000oj:4/onRQ;?oXXBco`000003oj62/P04o`000?nO
PK;oWh6boin1/P?o00000_nMO[401Ol0003oW7jaoian/OnLO[7o000000CoVgfa00Go0000oi]m/OnK
OK7oVgfao`000003oiYm/P05o`000?nIOK;oVGfboiUm/_l000001?nIOK<00ol0003oV7jdoiQn]004
o`0000;oW8Nl00Go0000oib9__nLRKkoW8Vno`000004oif;`003o`000?nMSL;oWHg200;oWHg200Go
0000oif?aOnMSlGoWHo5o`000002oifBb0Go00000_nU`nl01?l0003oYL?_ojG3konU`nl4o`0000?o
YL?_00?o0000ojG3konU`nl00ol00005ojG3k`Co000000?oYL?_o`000?nU`nl00onU`nl3o`0000?o
YL?_00?o0000ojG3konU`nl01Ol00002ojG3k`04o`000?nU`nooYL?_ojG3k`Co00000_nU`nl2o`00
00Cooooo00?o0000ooooooooool00Oooool005_ooooo00?o0000ooooool000000_nU`nl4o`0000?o
YL?_00?o0000ojG3konU`nl01?l00004ojG3k`03o`000?nU`nooYL?_00?o00001?nU`nl00ol0003o
bLSIo`000003omoKdP04o`000?oQfm3ohM_@o`0000?og]S@0_l000000ooMd<co0000om[=c003om[=
c004o`000?oFbLgoe/W=o`0000God/790_l00003oljiaP06o`000?o:]/Oob[K7o`000?o9//Co0000
0oo5[/@01?l0003o`j[1ol>Z`Ol00002okjW`P04o`000?nmXkoo_J>ookfS_`;o00001?nfW;d01?l0
003o]9RkokBH^ondV;/2o`0000Co[Y:i00Go0000ojb?^?n/SkSo[8nho`000003ojZ<]P;o00000onU
QkD00ol0003oY8FdojB5]002ojB5]005o`000?nRQ;?oXXBcoj:4/ol000001?nQP[83o`000003oiio
/Ol0003oWGja00;oWGja00?o0000oian/OnLO[400_nLO[401Ol0003oVgfaoi]m/OnKOK7o000000?o
Vgfa00Go0000oiYm/_nJOK;oVWfbo`000004oiUm/P03o`000?nIOK?oVGfc00Co00000_nLQ[/01Ol0
003oW8Nloib7_?nLQkco000000CoW8Vn00?o0000oif;`?nMRl000_nMRl001Ol0003oWHg2oif=`_nM
SL;o000000;oWHo51?l00003ojG3k`03o`000?nU`nooYL?_00Go00000onU`nl00ol0003oYL?_ojG3
k`04o`0000?oYL?_00?o0000ojG3konU`nl00ol00005ojG3k`Co000000?oYL?_o`000?nU`nl00onU
`nl3o`0000?oYL?_00?o0000ojG3konU`nl01Ol00002ojG3k`04o`000?nU`nooYL?_ojG3k`?o0000
1?ooool1o`00007ooooo0Oooool005cooooo00Co0000ooooool0003o00001?nU`nl00ol0003oYL?_
ojG3k`03o`0000CoYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Go0000
00Gogm_Bo`000?oQfm3ohM_@o`000003omkHd003o`000?oLe=7og=CA00;o00000ooJcL`01?l0003o
e/W=omK9cOoFbLd2o`0000?od/7900Ko0000olnnbOo?_/Wo0000oljia_l00004olZfa`03o`000?o5
[/CoaJk400;oaJk400?o0000ol>Z`Ol000000onnYl801_l0003o_J>ookfS_ol0003o^:2oo`0000Co
]Ybm00Ko0000okBH^ol0003o0000ok2E^ol00004ojjB^@03o`000?n/SkSo[8nh00;o[8nh0ol00000
0onWR[Ko0000ojF7]@03ojF7]@05o`000?nTQKCoY8FdojB5]?l000001?nRQ;<00ol0003oXH:bo`00
0002o`0000?oWWna00?o0000oien/OnMO[400_nMO[401Ol0003oW7jaoian/OnLO[7o000000?oVgfa
00Go0000oi]m/OnKOK7oVgfao`000004oiYm/P03o`000?nIOK;o000000Co00000_nMQKX01Ol0003o
W8Jkoib6^onLQ[_o000000CoW8Nl00Go0000oib9__nLRKkoW8Vno`000004oif;`003o`000?nMSL;o
WHg200Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00Co0000ojG3konU`nooYL?_1?l0
0003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000GoYL?_1?l0
00000onU`noo0000ojG3k`03ojG3k`?o00000onU`nl00ol0003oYL?_ojG3k`05o`000003ojG3kol0
003o000000Cooooo0Ol00001ooooo`7ooooo001Mooooo`04o`000?ooooooooooo`0000;oYL?_1?l0
0003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_0ol0
00000ooQfm3o0000omkHd002omkHd004o`000?oLe=7og=CAo`0000;ofM7A00?o0000om[=c?l00000
0ooFbLd01_l0003odlG=om?5cOl0003od/79o`0000Cockk900?o0000olZfaoo:]/L00_o:]/L2o`00
00CoaJk40_l00004okjW`P03o`000?nmXkoo000000?o^:2o00Co0000okJL_OnfW;go]Ybm0_l00004
ok2E^`05o`000?n^T[Wo[Y:iojjB^Ol000000on/SkP2o`0000?oYhZf00?o0000ojF7]OnUQkD00_nU
QkD01Ol0003oY8FdojB5]?nTQKCo000000?oXXBc0ol00002oin1/P03o`000?nNOk7oWWna00;oWWna
00Go0000oien/OnMO[7oWGjao`000003oian/@05o`000?nKOK7oVgfaoi]m/Ol000001?nKOK400ol0
003oVWfbo`000003o`0000;oWHBi00?o0000oif5^_nMQKX00_nMQKX00ol0003oW8Jkoib6^`02oib6
^`05o`000?nLQkcoW8Nloib7_?l000000onLRKh00ol0003oWH_0oif;`002oif;`0?o00000onU`nl0
0ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01Ol00002ojG3k`04o`000?nU`noo
YL?_ojG3k`Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl00ol0
0005ojG3k`Co000000?oYL?_o`000?nU`nl00onU`nl3o`0000?oYL?_00?o0000ojG3konU`nl00ol0
0003ooooo`7o00000Oooool1ooooo`00G_ooool2o`000003ooooool0003o000000?oYL?_00?o0000
ojG3konU`nl01?l00004ojG3k`03o`000?nU`nooYL?_00?o00001?nU`nl01?l0003oYL?_o`000?l0
0002okk7h@Co000000Gog]S@o`000?oLe=7og=CAo`000004omWAd@05o`000?oFbLgoe/W=omK9cOl0
00001?oCaLd00ol0003ockk9olnnb@02olnnb@;o00000oo:]/L01?l0003oa[?7olJcaol00002olF^
a003o`000?o0ZlGo000000Co_ZO20_l00004okRP_`06o`000?nfW;go]Ybmo`000?nbVKgo00001?n`
UK/00ol0003o[Y:iojjB^@02ojjB^@?o000000?oZHfho`000?nWR[H00onWR[H01Ol0003oYHNeojF7
]OnUQkGo000000CoY8Fd0ol000000onPP[?o0000oin1/P02oin1/P03o`000?nNOk7oWWna00;oWWna
00Go0000oien/OnMO[7oWGjao`000003oian/@03o`000?nKOK7oVgfa00;oVgfa00?o0000oi]m/Ol0
00000ol00002oif4^003o`000?nMQ;WoWHBi00;oWHBi00?o0000oif5^_nMQKX00_nMQKX01Ol0003o
W8Jkoib6^onLQ[_o000000?oW8Nl00?o0000oib9__nLRKh00_nLRKh4o`000003ojG3kol0003oYL?_
00?oYL?_0ol00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`05o`00
00;oYL?_00Co0000ojG3konU`nooYL?_1?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl0
0ol0003oYL?_ojG3k`03o`0000GoYL?_1?l000000onU`noo0000ojG3k`03ojG3k`?o00000_nU`nl2
o`0000;ooooo0Ol00001ooooo`7ooooo001Pooooo`03o`000?oooooo000000;oYL?_1?l00004ojG3
k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000?o_/OQ00?o0000om7@
f?oAd=P00_oAd=P2o`000003omcDdOl0003ofM7A00?ofM7A00Go0000omK=dOl0003oe/W=o`000004
om?5c@;o00000oo?_/T01_l0003obk[:ol^jb_l0003ob[K7o`0000?oa[?700?o0000olF^a?l00000
0oo0ZlD01_l0003o_ZO2okjW`_l0003o^ZC2o`0000Co^:2o00?o0000okJL_Ol000000onbVKd01Ol0
003o/9Fkok2E^on`UK_o000000?o[Y:i0_l00003ojV=^003o`000?nWR[KoYhZf00;oYhZf00?o0000
ojF7]OnUQkD00_nUQkD00ol0003oY8Fdo`000002o`0000?oX8:c00?o0000oin1/_nOPK800_nOPK80
1Ol0003oWWnaoiio/OnNOk7o000000?oWGja00Go0000oian/OnLO[7oW7jao`000003oi]m/@?o0000
0_nMQ;L00ol0003oWHBhoif4^002oif4^005o`000?nMQ;WoWHBioif4^Ol000001?nMQKX01Ol0003o
W8Jkoib6^onLQ[_o000000CoW8Nl00?o0000oib9__l000000_l00005ojG3k`Co000000?oYL?_o`00
0?nU`nl00onU`nl3o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_
00Go00000_nU`nl01?l0003oYL?_ojG3konU`nl4o`0000?oYL?_00?o0000ojG3konU`nl01?l00003
ojG3k`03o`000?nU`nooYL?_00?o00001OnU`nl4o`000003ojG3kol0003oYL?_00;oYL?_0ol00000
0ooooooo0000ooooo`01ooooo`00HOooool01?l0003oooooo`000?l00004ojG3k`03o`000?nU`noo
YL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000okk7hOl000001?oAd=P0
0ol0003of]WFom[IeP02o`0000?ofM7A00?o0000omK=dOoFcM400ol00003om?5c@06o`000?o?`/ko
cl;>o`000?o?_/Wo00000oo;^/X2o`0000Goa[?700?o0000ol2[aOo0ZlD00_o0ZlD00ol0003o_ZO2
o`000003okZT`P03o`000?nhX;oo^:2o00;o^:2o00?o0000ok:I_OnbVKd00_nbVKd00ol0003o/9Fk
ok2E^`02ok2E^`?o000000?oZXnjo`000?nYSKP00onYSKP01Ol0003oYhZfojN:]_nWR[Ko000000?o
YHNe0ol00002oj64]003o`000?nPP[?oX8:c00;oX8:c00Go0000oin1/_nOPK;oWh6bo`000003oiio
/@05o`000?nMO[7oWGjaoien/Ol000001?nLO[43o`000003oij4]ol0003oWHBg00;oWHBg00?o0000
oif4^?nMQ;P00_nMQ;P00ol0003oWHBioif4^@02oif4^@05o`000?nMQK[oWHFjoif5^_l000001?nL
Q[/00ol0003oW8Nlo`000003o`0000?oYL?_00?o0000ojG3konU`nl00ol00005ojG3k`06o`000?nU
`noo0000o`000?nU`noo00001?nU`nl3o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03
o`000?nU`nooYL?_00Go00000_nU`nl01?l0003oYL?_ojG3konU`nl4o`0000?oYL?_00?o0000ojG3
konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00?o00001?nU`nl4o`000005ojG3kol0003o0000
ooooool000000_ooool006;ooooo00?o0000ooooool000001?nU`nl3o`0000?oYL?_00?o0000ojG3
konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000ooAd=P01?l0003of]WFom[Ie_l00002
omOEeP03o`000?oIdM7o000000;oe/gA00Oo0000om;:d_oBb];od/[Bo`000?oCaLgo000000?ocl;>
0_l00003ol^jbP04o`000?o7]l_oakO;o`0000?oa[?70_l00005ol2[a@03o`000?njY<;o^ZC200?o
^ZC200?o0000okRP_onhX;l00_l00004ok:I_@04o`000?n`UK_o/9Fkok2E^`;o00001?nZSkX01Ol0
003oZHfhojV=^?nYSKSo000000CoYhZf0ol000000onSQKGo0000oj64]002oj64]003o`000?nPP[?o
X8:c00;oX8:c00Go0000oin1/_nOPK;oWh6bo`000003oiio/@03o`000?nMO[7oWGja00;oWGja00?o
0000oian/Ol000000_l00003oij4]`03o`000?nMQ;OoWHBg00;oWHBg00?o0000oif4^?nMQ;P00_nM
Q;P01Ol0003oWHBioif4^OnMQ;Wo000000CoWHFj00?o0000oib6^ol000000ol00003ojG3k`03o`00
0?nU`nooYL?_00Co00000onU`nl01?l0003oYL?_ojG3konU`nl3o`0000CoYL?_00Ko0000ojG3kol0
003o0000ojG3kol00004ojG3k`?o00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000
ojG3konU`nl01Ol00002ojG3k`04o`000?nU`nooYL?_ojG3k`Co00000onU`nl00ol0003oYL?_ojG3
k`04o`0000?oYL?_00Ko0000ojG3kol0003o0000ojG3kol00004ojG3k`?o00000_ooool006?ooooo
0ol000001OnU`noo0000o`000?nU`noo000000CoYL?_0ol00004ojG3k`03o`000?nU`nooYL?_00?o
00001?nU`nl00ol0003odM3Ho`000002om[IeP04o`000?oGeMKoemGFomOEeP?o000000?oe/gAo`00
0?oBb]800ooBb]82o`0000?ocl;>00Ko0000ol^oc_o;_lko0000ol^jb_l00004olNgb`03o`000?o6
/lOo000000;o`Zo800Co0000ol2[aOo0ZlGo`:_50_l00005okZT`P03o`000?nhX;oo000000;o]9g0
00?o0000ok:I_OnbVKd00_nbVKd3o`000003ojbB_?l0003oZXnj00?oZXnj00Go0000ojV=^?nYSKSo
ZHfho`000003ojN:]P;o00000onSQKD00ol0003oXHBdoj64]002oj64]005o`000?nPP[?oX8:coj22
/ol000000onOPK800ol0003oWWnaoiio/@02oiio/@03o`000?nMO[7o000000?o00000_nNQ;L00ol0
003oWXBgoij4]`02oij4]`05o`000?nMQ;OoWHBgoif4]ol000001?nMQ;P01Ol0003oWHBioif4^OnM
Q;Wo000000;oWHFj1?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3
k`05o`0000;oYL?_00Co0000ojG3konU`nooYL?_0ol00004ojG3k`06o`000?nU`noo0000o`000?nU
`noo00001?nU`nl3o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_
00Go00000_nU`nl01?l0003oYL?_ojG3konU`nl4o`0000?oYL?_00?o0000ojG3konU`nl00ol00004
ojG3k`03o`000?nU`noo000000?o00000Oooool1o`00007ooooo001Uooooo`?o00000onU`nl01?l0
003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol00003ojG3k`03o`000?nU`noo
YL?_00Co000000?of]WFo`000?oGeMH00_oGeMH01?l0003oe=;GomCBeooDd]L2o`0000?od/[B00Ko
0000olo6d_o?a];o0000olo2c_l00004ol^ocP03o`000?o7]l_oakO;00?oakO;0_l00004ol:_b003
o`000?o0ZlGo000000;o_:S500?o0000okZT`_njY<800_njY<82o`0000Co]9g000?o0000ok:I_Onb
VKd00_l00004ojbB_005o`000?nZSk[oZXnjojZ?^_l000001?nYSKP3o`000003ojB8]_l0003oXhFe
00?oXhFe00Go0000oj64]?nQQ;CoXHBdo`000003oj22/`03o`000?nOPK;oWh6b00;oWh6b00?o0000
oiio/Ol000000ol00002oij5]`05o`000?nNQ;OoWXBgoij4]ol000001?nNQ;L01Ol0003oWHBgoif4
]onMQ;Oo000000CoWHBh00?o0000oif4^OnMQ;T01?l00003ojG3k`03o`000?nU`nooYL?_00Co0000
0onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01Ol00002ojG3k`04o`00
0?nU`nooYL?_ojG3k`?o00001?nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_
00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01Ol00002ojG3
k`04o`000?nU`nooYL?_ojG3k`Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_0ol00001
ooooo`00I_ooool00ol0003oooooo`000002ojG3k`?o00001?nU`nl01_l0003oYL?_o`000?l0003o
YL?_o`0000CoYL?_0ol00003ok35j@Co000000?oemGFo`000?oDd]L00_oDd]L01_l0003odLkGom7>
eol0003od/[Bo`0000?oclKB0_l00004ol^ocP03o`000?o7^loo000000?oakO;00?o0000ol>dc?l0
00001?o2[lP2o`0000Co_:S500Ko0000okZT`_l0003o0000okJQ`ol00004okBM`005o`000?nbVKgo
0000ojjF__l000001?n/T[`00ol0003oZXnjojZ?^P02ojZ?^P03o`000?nYSKSo000000;o00000onT
R;H00ol0003oXhFeoj>5]@02oj>5]@05o`000?nQQ;CoXHBdoj64]?l000001?nPP[<00ol0003oWh6b
o`000003o`0000;oWhFh00Go0000oij5]onNQKOoWXFgo`000004oij4]`05o`000?nNQ;OoWXBgoij4
]ol000000onMQ;L00ol0003oWHBhoif4^002oif4^0?o00000onU`nl00ol0003oYL?_ojG3k`04o`00
00?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0
003oYL?_ojG3k`05o`0000;oYL?_00Co0000ojG3konU`nooYL?_0ol00004ojG3k`?o00000onU`nl0
0ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`noo
YL?_00Go00000_nU`nl01?l0003oYL?_ojG3konU`nl4o`0000?oYL?_00?o0000ojG3konU`nl00ol0
0001ooooo`00Ioooool01?l0003oooooo`000?l00003ojG3k`03o`000?nU`nooYL?_00?o00001?nU
`nl01?l0003oYL?_o`000?l00003ojG3k`03o`000?n`aNWo000000Co`/SN00Go0000omCBeooDd]Oo
e=;Go`000004om7>e`07o`000?o?a];oclKBolo6d_l0003obl?Co`000003ol^ocP07o`000?o7^loo
ak_?olNkcol0003oakO;o`000003ol>dc006o`000?o2[lSo`Zo8o`000?nm[LWo00001?nlZ<D2o`00
00Co]Z7300Co0000okBM`?ndWL3o]9g00_l00003ojjF_P05o`000?n/T[co[9:lojbB_?l000000onZ
SkX3o`0000;oYHZh00?o0000ojB8]_nTR;H00_nTR;H01Ol0003oXhFeoj>5]OnSQKGo000000?oXHBd
00Co0000oj22/onPP[?oX8:c0ol00002oj26^005o`000?nOQKSoWhFhoin5^?l000001?nNQKL01Ol0
003oWXBgoij4]onNQ;Oo000000?oWXBg00?o0000oif4]onMQ;L00_nMQ;L4o`0000;oYL?_00?o0000
ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04
o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Go00000_nU`nl0
0ol0003oYL?_o`000002o`000003ojG3kol0003oYL?_00?oYL?_0ol00003ojG3k`03o`000?nU`noo
YL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01Ol00002
ojG3k`04o`000?nU`nooYL?_ojG3k`Oo00000Oooool006Sooooo00?o0000ooooool000000_nU`nl4
o`0000?oYL?_00?o0000ojG3konU`nl01?l00004ojG3k`;o00001?o2b=h01Ol0003ocmCMo`000?oD
d]Oo000000CodLkG00Go0000olg;eol0003oclKBo`000003ol_3d`03o`000?o;_lko000000Coak_?
0_l00004ol>dc003o`000?o2[lSo000000?o_Jg900Ko0000okbXaOnlZ<Go0000okNUa_l00004okJQ
``06o`000?ndWL3o]9g0o`000?n_V/7o00000on^U[h00ol0003o[9:lojbB_002ojbB_0?o000000?o
YXfjo`000?nUR[P00_nUR[P00ol0003oY8RfojB8]P02ojB8]P05o`000?nSQKGoXhFeoj>5]Ol00000
1?nQQ;@3o`000003oj67^Ol0003oX8Jh00;oX8Jh00?o0000oin5^?nOQKP00_nOQKP01Ol0003oWXFg
oij5]onNQKOo000000?oWXBg00?o0000oij4]onNQ;L00_nNQ;L00ol0003oWHBgo`000002o`0000Go
YL?_0ol00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?o
YL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003o
YL?_ojG3k`03o`0000GoYL?_1?l000000onU`noo0000ojG3k`03ojG3k`?o00000onU`nl00ol0003o
YL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Wo
00001?ooool006Wooooo1?l00004ojG3k`03o`000?nU`nooYL?_00?o00001?nU`nl01_l0003oYL?_
o`000?l0003oYL?_o`0000?o`/SN00Co0000oloDgOo?e=gocmCM0_l00003om7>e`05o`000?o=bmOo
cL_Golg;eol000001Oo;`m<2o`0000?oak_?00?o0000ol>id?l000001?o3]<`2o`0000Co_Jg900?o
0000okbXaOl000000ongYLH01ol0003o]Z73okJQ`onfXL?o0000okBM`?l000000on_V/401Ol0003o
[YJnojjF__n^U[ko000000;o[9:l0_l00003ojJ=^P03o`000?nUR[SoYHZh00;oYHZh00Go0000ojB8
]_nTR;KoY8Rfo`000004oj>5]@03o`000?nQQ;Co000000;o00000onQQkT00ol0003oX8Jhoj26^002
oj26^005o`000?nOQKSoWhFhoin5^?l000000onNQKL00ol0003oWXBgoij4]`02oij4]`03o`000?nN
Q;Oo000000?o00000onU`nl00ol0003oYL?_o`000002o`000003ojG3kol0003oYL?_00?oYL?_0ol0
0003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o
0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3
k`03o`0000GoYL?_1?l000000onU`noo0000ojG3k`02ojG3k`Co00000_nU`nl01?l0003oYL?_ojG3
konU`nl4o`0000?oYL?_00?o0000ojG3konU`nl01?l00002ooooo`?o00002?ooool006_ooooo00?o
0000ooooool000000_nU`nl4o`0000?oYL?_00?o0000ojG3konU`nl00ol00004ojG3k`03o`000?o2
b=ko000000?ocmCM00Ko0000olkBgOo>d]go0000om7>eol00003olg;e`03o`000?o:amSo000000?o
bl?C00Ko0000olO0doo7`=?o0000olNkcol00003ol>id006o`000?o3]<co`kC<o`000?nn/Lgo0000
1?nm[LT2o`0000Co]jG600Co0000okJQ`onfXL?o]Z730_l00004ojnJ`@09o`000?n^U[ko[YJnojjF
__l0003o[9:lo`000?nXT;co000000CoYXfj00Go0000ojF:^?nUR[SoYHZho`000004ojB8]P03o`00
0?nSQKGo000000?o00000_nQRKX00ol0003oXHNioj67^@02oj67^@05o`000?nPQ[SoX8Jhoj26^?l0
00000onOQKP00ol0003oWXFgoij5]`02oij5]`03o`000?nNQ;Oo000000?o00000onU`nl00ol0003o
YL?_ojG3k`03o`0000GoYL?_1?l000000onU`noo0000ojG3k`03ojG3k`?o00000onU`nl00ol0003o
YL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co
00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl00ol00004ojG3k`Co
00000_nU`nl00ol0003oYL?_ojG3k`05o`0000;oYL?_00Co0000ojG3konU`nooYL?_1?l00002oooo
o`Co00002oooool006cooooo00Co0000ooooool0003o00000onU`nl00ol0003oYL?_ojG3k`04o`00
00?oYL?_00?o0000ojG3konU`nl01Ol000000oo?e=go0000olkBg@02olkBg@;o00000oo=bmL01ol0
003ob/OHol[7f?o:amSo0000ol_3dol000000oo7`=<2o`0000Co`kW@00?o0000ol>dc?l000000onn
/Ld01_l0003o_Jg9o`000?l0003o^JW:o`0000Co]jG600Ko0000okJQ`ol0003o0000ok6Na?l00004
ojnJ`@04o`000?n^U[ko[YJnojjF_P;o00000onXT;`01Ol0003oYXfjojJ=^_nVSK[o000000?oYHZh
00Co0000ojB8]_nTR;KoY8Rf0ol00002oj:;^`03o`000?nQRK[oXHVj00;oXHVj00Go0000oj67^OnQ
QkWoXHNio`000003oj26^003o`000?nOQKSoWhFh00;oWhFh00?o0000oij5]ol000000ol00003ojG3
k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000GoYL?_1?l00002ojG3
k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3
konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`00
00?oYL?_00Ko0000ojG3kol0003o0000ojG3kol00004ojG3k`?o00000onU`nl00ol0003oYL?_ojG3
k`05o`0000;ooooo1?l0000?ooooo`00KOooool00ol0003oooooo`000002ojG3k`Co00000onU`nl0
0ol0003oYL?_ojG3k`04o`0000CoYL?_0_l00003olkBg@06o`000?o;cmgobloMo`000?o=bmOo0000
1?o:amP2o`0000?oal3C00?o0000ol>me?l000001?o3^M02o`0000Co_[7=0_l00004okVYbP04o`00
0?ngYLKo]jG6okNUaP;o00001?naW/@00ol0003o[i[1ojnJ`@02ojnJ`@?o000000?oZI>oo`000?nX
T;`00_nXT;`01Ol0003oYXfjojJ=^_nVSK[o000000CoYHZh0ol000000onSSKgo0000oj:;^`03oj:;
^`05o`000?nQRK[oXHVjoj69^_l000000onQQkT00ol0003oX8Jhoj26^002oj26^003o`000?nOQKSo
000000?o00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003
ojG3k`03o`000?nU`nooYL?_00?o00001OnU`nl3o`0000;oYL?_00Co0000ojG3konU`nooYL?_1?l0
0003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o
0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00?o00001?nU`nl01?l0003oYL?_o`00
0?l00002ojG3k`03o`000?nU`nooYL?_00Co00000oooool4o`0001?ooooo001^ooooo`Co00001?nU
`nl00ol0003oYL?_ojG3k`03o`0000CoYL?_00Co0000ojG3kol0003o00000_nda^L00ol0003oc];M
o`000003ol_?g@?o00000oo:amP01_l0003oa/CHolK4f?l0003oal3Co`0000?o`kgD00Ko0000ol>i
d?l0003o0000oknfdOl00003okjac@03o`000?nj[/ko000000Co^JW:00Ko0000okNUa_l0003o0000
ok>Raol00004ok6Na004o`000?n_V/7o[i[1ojnJ`@;o00001?nYTkl01Ol0003oZ92lojR@_?nXT;co
000000?oYXfj00?o0000ojF:^?l000000_l00003oj>=_@03o`000?nRRk_oXX^k00;oXX^k00Go0000
oj69^_nQRK[oXHVjo`000004oj67^@03o`000?nPQ[So000000?o00000onU`nl00ol0003oYL?_ojG3
k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU
`nl00ol0003oYL?_o`000002o`000003ojG3kol0003oYL?_00;oYL?_1?l00002ojG3k`04o`000?nU
`nooYL?_ojG3k`Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl0
1?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000CoYL?_
0ol00004ooooo`?o00005oooool0073ooooo00?o0000ooooool000000_nU`nl4o`0000?oYL?_00?o
0000ojG3konU`nl00ol00004okC6i`?o000000?obloMo`000?l000000oo7c=d00ol0003ob/OHo`00
0003olK4f0;o00001?o3_M@2o`0000Co_kKA00?o0000okjacOl000000onj[/h01?l0003o^JW:okVY
b_niZLX2o`0000Co/j;700Ko0000ok6Na?naW/Co/Ik4o`000?n_V/42o`000003oj^G`_l0003oZI>o
00?oZI>o00Go0000ojR@_?nXT;coZ92lo`000002ojJ=^P?o00000_nTSkl00ol0003oXhfmoj>=_@02
oj>=_@05o`000?nRRk_oXX^koj:;^ol000001?nQRKX00ol0003oXHNio`000003o`0000?oYL?_00?o
0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3
k`04o`0000?oYL?_00?o0000ojG3konU`nl00ol00005ojG3k`?o00000_nU`nl00ol0003oYL?_ojG3
k`05o`0000;oYL?_00Co0000ojG3konU`nooYL?_1?l00002ojG3k`04o`000?nU`nooYL?_ojG3k`Co
00000_nU`nl01?l0003oYL?_ojG3konU`nl4o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3
k`04o`000?nU`noo0000o`0000?ooooo1?l0000Jooooo`00LOooool01?l0003oooooo`000?l00003
ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl01?l0003o]<KWo`000?l00003okk9h`;o00001?o7
c=d2o`0000?oa/CH00?o0000ol;1fOl000000oo3_M@00ol0003o_k[Eo`000004oknfd@;o00001?nj
[/h01_l0003o^JW:o`000?l0003o]:O;o`0000Co/j;700?o0000ok6Na?naW/@00ol00004oj^G`P05
o`000?nYTkooZI>oojVC_ol000000onXT;`3o`000003ojFA`Ol0003oY8no00?oY8no00Go0000oj>=
_OnSSKgoXhfmo`000004oj:;^`03o`000?nQRK[o000000?o00000onU`nl00ol0003oYL?_ojG3k`04
o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl0
0ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl00ol00004ojG3k`?o00000onU`nl0
0ol0003oYL?_ojG3k`05o`0000;oYL?_00?o0000ojG3konU`nl01Ol00002ojG3k`03o`000?nU`noo
YL?_00Go00000_nU`nl01?l0003oYL?_ojG3konU`nl4o`0000;oYL?_00Co0000ojG3konU`nooYL?_
0ol000000ooooooo0000o`000002o`0001kooooo001booooo`03o`000?oooooo000000;oYL?_1?l0
0003ojG3k`03o`000?nU`nooYL?_00Co00000onnbN<01Ol0003oa<oSolC?hol0003oalcM00;o0000
0_o4b=h00ol0003oa/CHo`000003ol;1f@03o`000?o3_MCo000000?o_k[E00Ko0000oknfdOl0003o
0000okZcd_l00004okZ^cP;o00001?ndYl/01?l0003o/j;7ok>RaoncX/L3o`0000;o[9_500?o0000
oj^G`_n[Ul800_n[Ul800ol0003oZI>oojVC_`02ojVC_`?o000000?oYYC3o`000?nUTL400_nUTL40
1Ol0003oY8noojB?_onTSkoo000000?oXhfm00Co0000oj:;^onRRk_oXX^k0ol00003ojG3k`03o`00
0?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl0
1?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_
00Co0000ojG3kol0003o00000_nU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU
`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`05o`0000;o
YL?_00?o0000ojG3konU`nl02Ol0000Rooooo`00Loooool4o`0000CoYL?_00?o0000ojG3konU`nl0
0ol00004ojG3k`03o`000?nnbN?o000000?oa<oS0_l00004olC8gP;o00001?o2`MT2o`0000Co_k[E
0_l00004okZcdP06o`000?nj[/ko0000o`000?ne[<oo00001?ndYl/01_l0003o/j;7o`000?l0003o
[Yo9o`0000Co[9_500Go0000oj^G`_n[Ul;oZiO2o`000002ojVC_`?o00001?nVU<<01?l0003oYI71
ojFA`Ol00003ojB?_`03o`000?nSSKgoXhfm00;oXhfm0ol00002ojG3k`03o`000?nU`nooYL?_00Co
00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03
o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU
`nl00ol00004ojG3k`?o00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU
`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`000003
ooooool0003o000000;o00009_ooool007Gooooo00?o0000ooooool000000_nU`nl4o`0000?oYL?_
00?o0000ojG3konU`nl01?l000000oo4cn?o0000o`000002ol3<h`04o`000?o4b=ko0000o`0000;o
`<GN00Co0000ol;1fOl0003o00000_nn_]X01?l0003o_k[Eo`000?l00002okZhe`04o`000?nj/m;o
^[?BokZcdP;o00001?ne[<l01?l0003o]:O;okBWbondYl/2o`0000Co[Yo900Go0000ojbKaOn/VlGo
[9_5o`000003oj^G`P?o00000_nWV<H00ol0003oYYC3ojJD``02ojJD``05o`000?nUTL7oYI71ojFA
`Ol000000onTSkl00ol0003oXhfmo`000002o`0000CoYL?_0ol00003ojG3k`03o`000?nU`nooYL?_
00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3
k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00Co0000ojG3
kol0003o00000_nU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003
ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000;ooooo0ol0000Z
ooooo`00M_ooool01?l0003oooooo`000?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onW`nh2
o`0000Co`<cS0ol00003ol35gP?o00000onn_]X2o`0000Go^[SG00Go0000okZcd_l0003o][3Do`00
0004okF/c`06o`000?ndYl_o0000o`000?n_Y<go00001?n^WlT01_l0003o[9_5ojbKaOn/VlGo0000
oj^G`P;o000000?oZ9_9o`000?nWV<H00onWV<H01Ol0003oYYC3ojJD`onVU<?o000000?oYI7100?o
0000ojB?_onTSkl00ol00003ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o0000ojG3konU`nl0
1?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_
00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_
ojG3k`03o`0000CoYL?_0ol00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_
ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00002ooooo`Co0000;Oooool007Oooooo00?o
0000ooooool000000_nU`nl4o`0000?oYL?_00Co0000ojO3k_l0003o00000_n`aNT01?l0003o`<cS
o`000?l00003okg9h`03o`000?o0aMko000000?o_<?O00?o0000okjnf_l000000_nj_=/00ol0003o
^[SGokZhe`02okZhe`;o00000onf/=@01?l0003o]Jc?okF/cone[<l2o`0000Co[jC=00Go0000ojjO
bOn^WlWo[Yo9o`000002ojbKa@?o00001?nXVlT01Ol0003oYiS6ojNHa_nWV<Ko000000CoYYC300?o
0000ojFA`Ol000000ol00003ojG3k`03o`000?nU`nooYL?_00?o00000onU`nl3o`0000?oYL?_00?o
0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3
k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU
`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_
ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00002ooooo`Co0000<Oooool007Sooooo1?l0
0004ojG3k`03o`000?nU`nooYL?_00?o00000on`aNT3o`0000Co_LWS0_l00004okc3g`;o00001?nj
_=/01_l0003o^[SGo`000?l0003o][GHo`0000Co][3D00Go0000okF/col0003o/:WAo`000004ojnT
c@03o`000?n^WlWo[Yo900Co00000_nXWl`00ol0003oZ9_9ojRKb@02ojRKb@05o`000?nWV<KoYiS6
ojNHa_l000000_nVU<<4o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`noo
000000;oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl0
0ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`noo
YL?_00Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000CoYL?_0ol00003ojG3k`03o`000?nU`noo
YL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000;ooooo1?l0000eooooo`00N_ooool00ol0
003oooooo`000002ojG3k`Co00000onU`nl00ol0003o/<GYo`000003okG8j004o`000?nmbN?o0000
o`0000;o^LKT00Ko0000okc3gol0003o0000okS0h?l00004okZlf`;o00001?nf]MP00ol0003o][3D
okJ`e003o`0000?o/:WA00Co0000ojnTcOn_Y<go[jC=0ol00002ojVSd003o`000?nXWlcoZ9o<00;o
Z9o<00Go0000ojRKbOnXVlWoZ9_9o`000002ojNHaPCo00000onU`nl00ol0003oYL?_ojG3k`04o`00
00?oYL?_00?o0000ojG3konU`nl00ol00003ojG3k`?o00000onU`nl00ol0003oYL?_ojG3k`04o`00
00?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0
003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`04o`000?nU`noo0000
o`0000;oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000oooool3
o`0003Wooooo001kooooo`04o`000?oooooo0000o`0000?oYL?_00?o0000ojG3konU`nl00ol00004
okG8j0;o00001?nia^@2o`0000Co^<3P00Ko0000okZlfol0003o0000okFjgOl00004okJef0?o0000
0_n`[]H00ol0003o/:WAok2Yd@02ok2Yd@05o`000?n_Y<go0000ojZWe?l000001?nYXm001Ol0003o
Z9o<ojROc?nXWlco000000;oZ9_91?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0
003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3kol000000onU`nl00ol0003oYL?_ojG3k`03o`00
00?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0
003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_
00?o00001?nU`nl3o`0000;oYL?_00Co0000ojG3konU`nooYL?_1?l00003ooooo`Co0000??ooool0
07cooooo00?o0000ooooool000000_nU`nl4o`0000?oYL?_00Co0000okG8j?l0003o00000_nfbNP0
1_l0003o^LKTo`000?l0003o]/CUo`0000Co^<3P0_l00004okFjg@06o`000?nf]MSo0000o`000?n`
/m[o00001?n`[]H00ol0003o/:WAok2Yd@03o`0000?oZZOD00Go0000ojVSd?nYXm3oZJ?@o`000002
ojROc0Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003
ojG3k`03o`000?nU`nooYL?_00?o00001?nU`nl3o`0000;oYL?_00?o0000ojG3konU`nl01?l00003
ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000
ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl01_l0003oYL?_o`000?l0
003oYL?_o`0000;oYL?_1Ol00003ooooo`Co0000@?ooool007gooooo1?l00003ojG3k`03o`000?nU
`nooYL?_00?o00001?nfbNP2o`0000Co]/CU00Co0000okS0h?l0003o00000_nd_^800ol0003o]K[M
okFjg@03o`0000Co/;?J00?o0000ok2^e_n`[]H01?l00002oj^/f005o`000?nZYmCoZZODojZWe?l0
00000_nYXm04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co
00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00Co0000ojG3kol0003o00000_nU`nl00ol0
003oYL?_ojG3k`03o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_
00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3
k`03o`000?nU`nooYL?_00?o00000_nU`nl4o`0000Cooooo1?l00014ooooo`00Ooooool00ol0003o
ooooo`000002ojG3k`?o00000onW`nh01?l0003o]/WXo`000?l00002ok;6j@03o`000?nfa>Go]/CU
00?o00001?nd_^83o`0000;o/;SO00?o0000ok2cf_n`/mX00_n`/mX3o`0000;oZk3L00?o0000oj^/
f?n[[=P00_n[[=P00ol0003oZZODojZWe003o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3
k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3
konU`nl01?l00002ojG3k`Co00000_nU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3
konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`00
00?oYL?_00?o0000ojG3konU`nl01?l00002ojG3k`?o00001Oooool3o`0004Sooooo0020ooooo`04
o`000?oooooo0000o`0000?oYL?_00?o0000ojO3k_nW`nh00ol00003ok;6j@?o00000onb`NH01_l0
003o];kRo`000?l0003o[kcSo`0000Co/;SO00Ko0000ok2cf_l0003o0000oj^dh?l00004oj^`g003
o`000?n[[=SoZjcH00Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_00?o0000ojG3konU
`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000;o
YL?_1?l00003ojG3k`03o`000?nU`nooYL?_00?o00000onU`nl00ol0003oYL?_ojG3k`04o`0000?o
YL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003o
YL?_ojG3k`04o`0000;oYL?_00Co0000ojG3kol0003o00001?ooool4o`0004_ooooo0021ooooo`03
o`000?oooooo000000;oYL?_1?l00003oj[4k003o`000?nba^Wo000000?o[lCY00?o0000ok;1i_nb
`NH00ol00003ojnlh`03o`000?n`^=oo/;SO00?o00001?n[]>000ol0003oZk3Loj^`g004o`0000?o
YL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00?o00000onU`nl00ol0003o
YL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`?o00000onU`nl00ol0003o
YL?_ojG3k`04o`0000;oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co
00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00002ojG3k`03
o`000?nU`nooYL?_00?o00000_ooool4o`0004oooooo0022ooooo`Co00000onU`nl00ol0003oZ/C/
oj[4k004o`0000;o[lCY1?l00003ojjoi`03o`000?n__>?o[kcS00?o00000on[^N<00ol0003oZkCP
oj^dh004o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co0000
0onU`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`04o`00
0?nU`noo0000o`0000;oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00?o
00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03
o`000?nU`nooYL?_00Co00000_nU`nl00ol0003oYL?_ojG3k`04o`000003ooooool0003o000000;o
0000Doooool008Cooooo0_l00002ojG3k`Co00000on[aN`3o`0000?o[<;Z00?o0000ojjoion^_nL0
1?l00003ojZli`03o`000?n[^N?oZkWS00?o00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_
00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000_nU`nl00ol0003oYL?_
ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00002ojG3k`Co00000onU`nl00ol0003oYL?_
ojG3k`04o`0000;oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co0000
0onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl00ol00002ooooo`?o0000
Eoooool008Gooooo0ol00003ojG3k`04o`000?n[aNco0000o`0000;oZLC]00?o0000ojc2j_n/`^X0
1?l00003ojVoj@03o`000?nZ_>OoZ[cW00Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_
00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_
ojG3k`03o`0000?oYL?_00?o0000ojG3konU`nl01?l00002ojG3k`Co00000onU`nl00ol0003oYL?_
ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl00ol00003ojG3k`03o`000?nU`nooYL?_00Co0000
0onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l000000ooooooo0000
o`000002o`0005[ooooo0026ooooo`03o`000?oooooo000000;oYL?_0ol00003ojW4k@?o00000onX
`N`00ol0003oZKoYojVoj@04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU
`nooYL?_00?o00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l0
0003ojG3k`03o`000?nU`nooYL?_00?o00000onU`nl3o`0000?oYL?_00?o0000ojG3konU`nl01?l0
0003ojG3k`03o`000?nU`nooYL?_00Co00000_nU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o
0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co000000?oooooo`000?l000000_l0
001Nooooo`00Qoooool4o`0000?oYL?^00?o0000ojW4kOl000000onW`nd00ol0003oZ<7/ojS1k003
o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000_nU`nl0
0ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`noo
YL?_00Co00000_nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00Co00000onU
`nl00ol0003oYL?_ojG3k`04o`0000;oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU
`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`000003ooooool0003o000000;o0000H_oo
ool008Wooooo0_l00002ojG3kPCo00000_nW`nd4o`0000?oYL?_00?o0000ojG3konU`nl00ol00003
ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_00?o0000
ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`03
o`0000;oYL?_1?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`03
o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co000000?ooooo
o`000?l000000_l0001Vooooo`00R_ooool3o`0000;oYL?^1?l00003ojG3k`03o`000?nU`nooYL?_
00Co00000_nU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3
k`03o`000?nU`nooYL?_00?o00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3
konU`nl01?l00002ojG3k`?o00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3
konU`nl01?l00002ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`00
00;ooooo0ol0001Zooooo`00Roooool01?l0003oooooo`000?l00003ojG3k`03o`000?nU`nooYL?_
00Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3
k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_00?o0000ojG3
konU`nl01?l00002ojG3k`Co00000_nU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3
konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00?o00000onU`nl00ol0003oYL?_ojG3k`04o`00
00;ooooo1?l0001]ooooo`00S?ooool2o`000004ooooool0003oYL?_ojG3k`?o00000onU`nl00ol0
003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl00ol00003ojG3k`03o`000?nU`nooYL?_
00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000;oYL?_00?o0000ojG3konU`nl01?l00002ojG3
k`Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3
k`03o`000?nU`nooYL?_00Co00000_nU`nl00ol0003oYL?_ojG3k`04o`0000;ooooo1?l0001aoooo
o`00S_ooool01?l0003oooooo`000?l00003ojG3k`03o`000?nU`nooYL?_00?o00000onU`nl00ol0
003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl00ol00003ojG3k`03o`000?nU`nooYL?_
00Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000;oYL?_1?l00003ojG3k`03o`000?nU`nooYL?_
00Co00000_nU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3
k`03o`000?nU`nooYL?_00?o00000_ooool4o`0007Gooooo002?ooooo`03o`000?oooooo000000;o
YL?_1?l00002ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000;o
YL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000_nU`nl3o`0000?o
YL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00?o00000onU`nl00ol0003o
YL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00002ooooo`?o0000NOooool0093ooooo
00Co0000ooooool0003o00000onU`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_00?o0000ojG3konU
`nl01?l00003ojG3k`03o`000?nU`nooYL?_00?o00000onU`nl00ol0003oYL?_ojG3k`04o`0000;o
YL?_1?l00003ojG3k`03o`000?nU`nooYL?_00?o00000onU`nl00ol0003oYL?_ojG3k`04o`0000;o
YL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000_ooool4o`0007co
oooo002Aooooo`03o`000?oooooo000000;oYL?_1?l00003ojG3k`03o`000?nU`nooYL?_00?o0000
0onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl00ol00002ojG3k`Co0000
0onU`nl00ol0003oYL?_ojG3k`04o`0000;oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`00
0?nU`nooYL?_00?o00000onU`nl00ol0003oYL?_ojG3k`04o`0000;ooooo1?l00020ooooo`00T_oo
ool4o`0000?oYL?_00?o0000ojG3konU`nl01?l00002ojG3k`03o`000?nU`nooYL?_00Co00000onU
`nl00ol0003oYL?_ojG3k`04o`0000;oYL?_0ol00003ojG3k`03o`000?nU`nooYL?_00Co00000onU
`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_00?o0000ojG3konU`nl01?l00002ojG3k`03o`000?nU
`nooYL?_00Co00000_ooool4o`0008Cooooo002Dooooo`;o00000_nU`nl4o`0000?oYL?_00?o0000
ojG3konU`nl01?l00002ojG3k`03o`000?nU`nooYL?_00Co00000_nU`nl4o`0000;oYL?_00?o0000
ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000_nU`nl00ol0003oYL?_ojG3k`04
o`0000?oYL?_00?o0000ojG3konU`nl00ol00003ooooo`?o0000R?ooool009Gooooo0ol00003ojG3
k`03o`000?nU`nooYL?_00Co00000_nU`nl7o`0000;oYL?_1?l00003ojG3k`03o`000?nU`nooYL?_
00?o00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl00ol00003ojG3
k`03o`000?nU`nooYL?_00Co00000_ooool4o`0008_ooooo002Fooooo`03o`000?oooooo000000;o
YL?_0ol00002ojG3k`Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_00?o0000ojG3konU
`nl01?l00003ojG3k`03o`000?nU`nooYL?_00?o00000onU`nl00ol0003oYL?_ojG3k`04o`0000;o
YL?_00?o0000ojG3konU`nl01?l00002ooooo`Co0000Soooool009Oooooo1?l00002ojG3k`?o0000
0onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl00ol00003ojG3k`03o`00
0?nU`nooYL?_00Co00000_nU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl0
0ol00002ooooo`Co0000Toooool009Wooooo00Co0000ooooool0003o00000onU`nl00ol0003oYL?_
ojG3k`03o`0000?oYL?_00?o0000ojG3konU`nl01?l00002ojG3k`03o`000?nU`nooYL?_00Co0000
0onU`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_00?o0000ojG3konU`nl01?l00002ooooo`?o0000
Uoooool009[ooooo00?o0000ooooool000000_nU`nl4o`0000;oYL?_00?o0000ojG3konU`nl01?l0
0003ojG3k`03o`000?nU`nooYL?_00?o00000onU`nl00ol0003oYL?_ojG3k`04o`0000;oYL?_00?o
0000ojG3konU`nl01?l00002ooooo`Co0000V_ooool009_ooooo00Co0000ooooool0003o00000onU
`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_00?o0000ojG3konU`nl01?l00002ojG3k`03o`000?nU
`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000;ooooo1?l0002Nooooo`00W?ooool3
o`0000;oYL?_1?l00002ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`03
o`0000;oYL?_2?l000000ooooooo0000o`000002o`000:;ooooo002Nooooo`?o00000onU`nl00ol0
003oYL?_ojG3k`03o`0000?oYL?_00?o0000ojG3konU`nl01?l00002ojG3k`?o00001Oooool4o`00
0:Kooooo002Oooooo`;o00000_nU`nl4o`0000?oYL?_00?o0000ojG3konU`nl00ol00002ojG3k`Co
00001Oooool3o`000:[ooooo002Pooooo`?o00000_nU`nl8o`0000;oYL?_0ol00005ooooo`Co0000
[Oooool00:7ooooo1?l00003ojG3k`03o`000?nU`nooYL?_00Co00001?ooool4o`000;7ooooo002S
ooooo`03o`000?oooooo000000;oYL?_0ol00004ooooo`Co0000]Oooool00:Cooooo00Co0000oooo
ool0003o00001?ooool3o`000;Wooooo002Uooooo`;o000000?oooooo`000?l000000_l0002loooo
o`00Y_ooool2o`000<3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo002nooooo`?o000000?o410@ooooooooool0Y?ooool009cooooo00?o^[Zjoc8b<_ooool0
3Oooool2o`0000_ooooo00?o0000okZj^_ooool01?ooool00ol@413o^[Zjooooo`05ooooo`;o0000
1Oooool00ol0003o^[Zjooooo`2Fooooo`00WOooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`;o<S8b1Oooool00onHV9So<S8b
ooooo`06ooooo`03o`000?oooooooooo00?ooooo0_lb<S:Gooooo`00Voooool01onHV9So410@o`00
0?l0003oZJVYooooool000000_ooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooooooo
o`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool00ooMgMgo0000okZj^P06oooo
o`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X02oooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1gooooo`00Voooool0
1ol0003oZJVYoeEEEOnHV9SoEEEEokZj^_l000000_ooool00ol0003oooooooooo`05ooooo`0:o`00
0?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?oo
ool00omEEEGoMgMgodA4A006ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41003?oo
ool01Ol0003ooooooooooooooooo000000;ooooo1_l000001_ooooooMgMgoiRHV?ooooooV9RHogMg
MgOooooo002Kooooo`06oc8b<_o^k^koV9RHoeEEEOoMgMgo410@0ol00008ooooo`03o`000?oooooo
oooo00;ooooo00CogMgMo`000?l@413oc<c<2_ooool01OoMgMgo410@oooooolQ8B7ogMgM00Gooooo
00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo000000Wooooo00Go410@oooooooo
oooooooooa0@401gooooo`00Voooool01onj^[[oA4A4olc<c?lQ8B7ooooooa0@4?o<c<`02_ooool0
0ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo00GoIVIVohN7QoooooooV9RH
oeEEE@05ooooo`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`000002ooooo`Ko
000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`1eooooo`00Voooool01oo^k^ko0000
ooooool0003oooooofIVI_n7QhL02_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMg
oc8b<PWooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`03ooooo`03o`000?oooooo
oooo01;ooooo00Go0000ohN7QoooooooZJVYo`000009ooooo`05o`000?ooooooooooooooool00000
Moooool009_ooooo00CoIVIVoiRHV?oooooo<S8b0_nj^[X00ol0003oooooooooo`08ooooo`04o`00
0?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00Co410@o`000?l0003ooooo0_l000000ol@
413oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o410@o`000?mgMgL00_l000000onH
V9Soooooooooo`07ooooo`05oa0@4?ooooooooooooooool@4100Moooool009kooooo00?oIVIVohN7
Qoooool02oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo023ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`1gooooo`00W_ooool00onYZJWoA4A4ooooo`0;ooooo`;o00006_ooool2o`00
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1gooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.875, 0}} -> {-0.115432, 0.0207698, \
0.00372262, 0.00372262}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.5 .82364 -37.6875 0 ]
[.5 .82364 37.6875 10.125 ]
[.03045 .24505 -12 -8.71092 ]
[.03045 .24505 0 .28908 ]
[.17875 .18668 -23.5791 -9 ]
[.17875 .18668 .42091 0 ]
[.33612 .12478 -5.58359 -9 ]
[.33612 .12478 .41641 0 ]
[.5034 .05901 -15.8172 -9 ]
[.5034 .05901 2.18278 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.29165 .07573 -9.31117 -9.8125 ]
[.29165 .07573 .68883 0 ]
[.70361 -0.00072 0 -6.25801 ]
[.70361 -0.00072 6 2.74199 ]
[.82501 .18517 0 -6.07699 ]
[.82501 .18517 18 2.92301 ]
[.92763 .34231 0 -5.92977 ]
[.92763 .34231 6 3.07023 ]
[.91861 .21225 0 -6.57576 ]
[.91861 .21225 10.0625 3.23674 ]
[.01787 .30422 -36 -2.77537 ]
[.01787 .30422 0 6.22463 ]
[.00698 .37251 -6 -2.83328 ]
[.00698 .37251 0 6.16672 ]
[-0.00441 .44387 -30 -2.89407 ]
[-0.00441 .44387 0 6.10593 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -98.6875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
74.312 11.250 moveto
(@) show
80.312 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
86.312 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
92.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
98.375 11.250 moveto
(D) show
104.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
116.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
122.375 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
128.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
134.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.04003 .25401 m
.04482 .2585 L
s
[(-1)] .03045 .24505 1 .93576 Mshowa
.18786 .19613 m
.19242 .20085 L
s
[(-0.5)] .17875 .18668 .96492 1 Mshowa
.34468 .13472 m
.34896 .13969 L
s
[(0)] .33612 .12478 .8612 1 Mshowa
.51132 .06947 m
.51528 .0747 L
s
[(0.5)] .5034 .05901 .75747 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06892 .2427 m
.07176 .24542 L
s
.09814 .23126 m
.10096 .23401 L
s
.1277 .21969 m
.13049 .22246 L
s
.1576 .20797 m
.16037 .21078 L
s
.21848 .18414 m
.22119 .187 L
s
.24947 .172 m
.25214 .1749 L
s
.28082 .15973 m
.28346 .16265 L
s
.31256 .1473 m
.31516 .15025 L
s
.37719 .12199 m
.37973 .125 L
s
.41011 .1091 m
.4126 .11215 L
s
.44343 .09606 m
.44588 .09913 L
s
.47716 .08285 m
.47958 .08595 L
s
.54591 .05593 m
.54824 .0591 L
s
.58094 .04221 m
.58323 .04541 L
s
.61641 .02832 m
.61866 .03155 L
s
.65234 .01425 m
.65454 .01752 L
s
gsave
.29165 .07573 -70.3112 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69139 .00406 m
.68528 .00644 L
s
[(0)] .70361 -0.00072 -1 .39067 Mshowa
.81263 .18951 m
.80643 .19168 L
s
[(0.5)] .82501 .18517 -1 .35044 Mshowa
.91512 .34629 m
.90887 .34827 L
s
[(1)] .92763 .34231 -1 .31773 Mshowa
.125 Mabswid
.71738 .04381 m
.7137 .04521 L
s
.74245 .08216 m
.73876 .08354 L
s
.76665 .11918 m
.76296 .12054 L
s
.79003 .15495 m
.78632 .15627 L
s
.83448 .22293 m
.83075 .22421 L
s
.85562 .25527 m
.85189 .25653 L
s
.87608 .28658 m
.87235 .28781 L
s
.89591 .3169 m
.89216 .31811 L
s
.93375 .37478 m
.92999 .37595 L
s
.95181 .40242 m
.94805 .40357 L
s
gsave
.91861 .21225 -61 -10.5758 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.062 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.062 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03013 .29952 m
.03625 .29717 L
s
[(-0.005)] .01787 .30422 1 -0.38325 Mshowa
.01928 .36795 m
.02543 .36568 L
s
[(0)] .00698 .37251 1 -0.37038 Mshowa
.00795 .43946 m
.01413 .43725 L
s
[(0.005)] -0.00441 .44387 1 -0.35687 Mshowa
.125 Mabswid
.028 .31297 m
.03167 .31157 L
s
.02585 .32654 m
.02953 .32515 L
s
.02368 .34022 m
.02736 .33884 L
s
.02149 .35403 m
.02518 .35265 L
s
.01706 .382 m
.02075 .38064 L
s
.01481 .39618 m
.01851 .39483 L
s
.01254 .41047 m
.01624 .40913 L
s
.01026 .4249 m
.01396 .42357 L
s
.03224 .28618 m
.03591 .28477 L
s
.03434 .27296 m
.03801 .27154 L
s
.03641 .25985 m
.04008 .25842 L
s
.00562 .45414 m
.00933 .45283 L
s
.00328 .46896 m
.00699 .46766 L
s
.00091 .48392 m
.00462 .48262 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.656 .751 .92 r
.39528 .69613 .4017 .70174 .41244 .69871 .40605 .69308 Metetra
.656 .751 .92 r
.40605 .69308 .41244 .69871 .42323 .69567 .41687 .69002 Metetra
.656 .751 .92 r
.41687 .69002 .42323 .69567 .43406 .69261 .42773 .68694 Metetra
.656 .751 .92 r
.42773 .68694 .43406 .69261 .44494 .68954 .43863 .68385 Metetra
.656 .751 .92 r
.43863 .68385 .44494 .68954 .45586 .68647 .44958 .68075 Metetra
.656 .751 .92 r
.44958 .68075 .45586 .68647 .46682 .68337 .46057 .67763 Metetra
.656 .751 .92 r
.46057 .67763 .46682 .68337 .47783 .68027 .47161 .67451 Metetra
.656 .751 .92 r
.47161 .67451 .47783 .68027 .48889 .67715 .48269 .67137 Metetra
.656 .751 .92 r
.48269 .67137 .48889 .67715 .49998 .67402 .49382 .66821 Metetra
.656 .751 .92 r
.49382 .66821 .49998 .67402 .51113 .67088 .50499 .66505 Metetra
.656 .751 .92 r
.50499 .66505 .51113 .67088 .52232 .66773 .51621 .66187 Metetra
.656 .751 .92 r
.51621 .66187 .52232 .66773 .53355 .66456 .52747 .65868 Metetra
.656 .751 .92 r
.52747 .65868 .53355 .66456 .54483 .66138 .53878 .65547 Metetra
.656 .751 .92 r
.53878 .65547 .54483 .66138 .55616 .65819 .55014 .65226 Metetra
.656 .751 .92 r
.55014 .65226 .55616 .65819 .56753 .65498 .56154 .64902 Metetra
.656 .751 .92 r
.56154 .64902 .56753 .65498 .57895 .65176 .573 .64578 Metetra
.656 .751 .92 r
.573 .64578 .57895 .65176 .59042 .64853 .5845 .64252 Metetra
.656 .751 .92 r
.5845 .64252 .59042 .64853 .60193 .64528 .59604 .63925 Metetra
.656 .751 .92 r
.59604 .63925 .60193 .64528 .6135 .64202 .60764 .63596 Metetra
.656 .751 .92 r
.60764 .63596 .6135 .64202 .62511 .63875 .61928 .63267 Metetra
.656 .751 .92 r
.61928 .63267 .62511 .63875 .63677 .63546 .63097 .62935 Metetra
.656 .751 .92 r
.63097 .62935 .63677 .63546 .64847 .63216 .64271 .62603 Metetra
.656 .751 .92 r
.64271 .62603 .64847 .63216 .66023 .62884 .6545 .62269 Metetra
.656 .751 .92 r
.6545 .62269 .66023 .62884 .67204 .62551 .66634 .61933 Metetra
.656 .751 .92 r
.66634 .61933 .67204 .62551 .68389 .62217 .67823 .61596 Metetra
.656 .751 .92 r
.67823 .61596 .68389 .62217 .6958 .61881 .69017 .61258 Metetra
.656 .751 .92 r
.69017 .61258 .6958 .61881 .70775 .61544 .70216 .60918 Metetra
.656 .751 .92 r
.70216 .60918 .70775 .61544 .71976 .61206 .7142 .60577 Metetra
.656 .751 .92 r
.7142 .60577 .71976 .61206 .73181 .60866 .72629 .60234 Metetra
.656 .751 .92 r
.72629 .60234 .73181 .60866 .74392 .60524 .73844 .5989 Metetra
.656 .751 .92 r
.73844 .5989 .74392 .60524 .75608 .60182 .75063 .59545 Metetra
.656 .751 .92 r
.75063 .59545 .75608 .60182 .76829 .59837 .76288 .59198 Metetra
.656 .751 .92 r
.76288 .59198 .76829 .59837 .78056 .59491 .77518 .58849 Metetra
.656 .751 .92 r
.77518 .58849 .78056 .59491 .79287 .59144 .78754 .58499 Metetra
.656 .751 .92 r
.78754 .58499 .79287 .59144 .80524 .58795 .79994 .58148 Metetra
.656 .751 .92 r
.79994 .58148 .80524 .58795 .81766 .58445 .8124 .57795 Metetra
.656 .751 .92 r
.8124 .57795 .81766 .58445 .83014 .58093 .82492 .5744 Metetra
.656 .751 .92 r
.82492 .5744 .83014 .58093 .84267 .5774 .83748 .57084 Metetra
.656 .751 .92 r
.83748 .57084 .84267 .5774 .85525 .57385 .85011 .56726 Metetra
.656 .751 .92 r
.85011 .56726 .85525 .57385 .86789 .57029 .86278 .56367 Metetra
.656 .751 .92 r
.86278 .56367 .86789 .57029 .88058 .56671 .87552 .56006 Metetra
.656 .751 .92 r
.87552 .56006 .88058 .56671 .89333 .56312 .88831 .55644 Metetra
.656 .751 .92 r
.88831 .55644 .89333 .56312 .90613 .55951 .90115 .5528 Metetra
.656 .751 .92 r
.90115 .5528 .90613 .55951 .91899 .55588 .91405 .54915 Metetra
.656 .751 .92 r
.91405 .54915 .91899 .55588 .93191 .55224 .92701 .54547 Metetra
.656 .751 .92 r
.92701 .54547 .93191 .55224 .94488 .54858 .94002 .54179 Metetra
.656 .751 .92 r
.94002 .54179 .94488 .54858 .95791 .54491 .9531 .53808 Metetra
.656 .751 .92 r
.9531 .53808 .95791 .54491 .971 .54122 .96623 .53436 Metetra
.656 .751 .92 r
.96623 .53436 .971 .54122 .98415 .53751 .97942 .53063 Metetra
.656 .751 .92 r
.38881 .69049 .39528 .69613 .40605 .69308 .39961 .68741 Metetra
.656 .751 .92 r
.39961 .68741 .40605 .69308 .41687 .69002 .41045 .68433 Metetra
.656 .751 .92 r
.41045 .68433 .41687 .69002 .42773 .68694 .42134 .68123 Metetra
.656 .751 .92 r
.42134 .68123 .42773 .68694 .43863 .68385 .43227 .67811 Metetra
.656 .751 .92 r
.43227 .67811 .43863 .68385 .44958 .68075 .44325 .67499 Metetra
.656 .751 .92 r
.44325 .67499 .44958 .68075 .46057 .67763 .45427 .67185 Metetra
.656 .751 .92 r
.45427 .67185 .46057 .67763 .47161 .67451 .46534 .6687 Metetra
.656 .751 .92 r
.46534 .6687 .47161 .67451 .48269 .67137 .47645 .66554 Metetra
.656 .751 .92 r
.47645 .66554 .48269 .67137 .49382 .66821 .4876 .66236 Metetra
.656 .751 .92 r
.4876 .66236 .49382 .66821 .50499 .66505 .4988 .65917 Metetra
.656 .751 .92 r
.4988 .65917 .50499 .66505 .51621 .66187 .51005 .65597 Metetra
.656 .751 .92 r
.51005 .65597 .51621 .66187 .52747 .65868 .52135 .65275 Metetra
.656 .751 .92 r
.52135 .65275 .52747 .65868 .53878 .65547 .53269 .64952 Metetra
.656 .751 .92 r
.53269 .64952 .53878 .65547 .55014 .65226 .54408 .64628 Metetra
.656 .751 .92 r
.54408 .64628 .55014 .65226 .56154 .64902 .55551 .64302 Metetra
.656 .751 .92 r
.55551 .64302 .56154 .64902 .573 .64578 .567 .63975 Metetra
.656 .751 .92 r
.567 .63975 .573 .64578 .5845 .64252 .57853 .63647 Metetra
.656 .751 .92 r
.57853 .63647 .5845 .64252 .59604 .63925 .5901 .63317 Metetra
.656 .751 .92 r
.5901 .63317 .59604 .63925 .60764 .63596 .60173 .62986 Metetra
.656 .751 .92 r
.60173 .62986 .60764 .63596 .61928 .63267 .61341 .62654 Metetra
.656 .751 .92 r
.61341 .62654 .61928 .63267 .63097 .62935 .62513 .6232 Metetra
.656 .751 .92 r
.62513 .6232 .63097 .62935 .64271 .62603 .63691 .61985 Metetra
.656 .751 .92 r
.63691 .61985 .64271 .62603 .6545 .62269 .64873 .61648 Metetra
.656 .751 .92 r
.64873 .61648 .6545 .62269 .66634 .61933 .6606 .6131 Metetra
.656 .751 .92 r
.6606 .6131 .66634 .61933 .67823 .61596 .67253 .60971 Metetra
.656 .751 .92 r
.67253 .60971 .67823 .61596 .69017 .61258 .6845 .6063 Metetra
.656 .751 .92 r
.6845 .6063 .69017 .61258 .70216 .60918 .69653 .60287 Metetra
.656 .751 .92 r
.69653 .60287 .70216 .60918 .7142 .60577 .7086 .59943 Metetra
.656 .751 .92 r
.7086 .59943 .7142 .60577 .72629 .60234 .72073 .59598 Metetra
.656 .751 .92 r
.72073 .59598 .72629 .60234 .73844 .5989 .73291 .59251 Metetra
.656 .751 .92 r
.73291 .59251 .73844 .5989 .75063 .59545 .74514 .58903 Metetra
.656 .751 .92 r
.74514 .58903 .75063 .59545 .76288 .59198 .75743 .58553 Metetra
.656 .751 .92 r
.75743 .58553 .76288 .59198 .77518 .58849 .76977 .58202 Metetra
.656 .751 .92 r
.76977 .58202 .77518 .58849 .78754 .58499 .78216 .57849 Metetra
.656 .751 .92 r
.78216 .57849 .78754 .58499 .79994 .58148 .7946 .57495 Metetra
.656 .751 .92 r
.7946 .57495 .79994 .58148 .8124 .57795 .8071 .57139 Metetra
.656 .751 .92 r
.8071 .57139 .8124 .57795 .82492 .5744 .81965 .56781 Metetra
.656 .751 .92 r
.81965 .56781 .82492 .5744 .83748 .57084 .83226 .56423 Metetra
.656 .751 .92 r
.83226 .56423 .83748 .57084 .85011 .56726 .84492 .56062 Metetra
.656 .751 .92 r
.84492 .56062 .85011 .56726 .86278 .56367 .85764 .557 Metetra
.656 .751 .92 r
.85764 .557 .86278 .56367 .87552 .56006 .87041 .55336 Metetra
.656 .751 .92 r
.87041 .55336 .87552 .56006 .88831 .55644 .88324 .54971 Metetra
.656 .751 .92 r
.88324 .54971 .88831 .55644 .90115 .5528 .89613 .54604 Metetra
.656 .751 .92 r
.89613 .54604 .90115 .5528 .91405 .54915 .90907 .54235 Metetra
.656 .751 .92 r
.90907 .54235 .91405 .54915 .92701 .54547 .92207 .53865 Metetra
.656 .751 .92 r
.92207 .53865 .92701 .54547 .94002 .54179 .93512 .53494 Metetra
.656 .751 .92 r
.93512 .53494 .94002 .54179 .9531 .53808 .94824 .5312 Metetra
.656 .751 .92 r
.94824 .5312 .9531 .53808 .96623 .53436 .96141 .52745 Metetra
.656 .751 .92 r
.96141 .52745 .96623 .53436 .97942 .53063 .97465 .52368 Metetra
.656 .751 .92 r
.38229 .6848 .38881 .69049 .39961 .68741 .39312 .6817 Metetra
.656 .751 .92 r
.39312 .6817 .39961 .68741 .41045 .68433 .40399 .67859 Metetra
.656 .751 .92 r
.40399 .67859 .41045 .68433 .42134 .68123 .41491 .67547 Metetra
.656 .751 .92 r
.41491 .67547 .42134 .68123 .43227 .67811 .42587 .67233 Metetra
.656 .751 .92 r
.42587 .67233 .43227 .67811 .44325 .67499 .43687 .66919 Metetra
.656 .751 .92 r
.43687 .66919 .44325 .67499 .45427 .67185 .44792 .66602 Metetra
.656 .751 .92 r
.44792 .66602 .45427 .67185 .46534 .6687 .45902 .66285 Metetra
.656 .751 .92 r
.45902 .66285 .46534 .6687 .47645 .66554 .47016 .65966 Metetra
.656 .751 .92 r
.47016 .65966 .47645 .66554 .4876 .66236 .48134 .65646 Metetra
.656 .751 .92 r
.48134 .65646 .4876 .66236 .4988 .65917 .49257 .65325 Metetra
.656 .751 .92 r
.49257 .65325 .4988 .65917 .51005 .65597 .50385 .65002 Metetra
.656 .751 .92 r
.50385 .65002 .51005 .65597 .52135 .65275 .51518 .64678 Metetra
.656 .751 .92 r
.51518 .64678 .52135 .65275 .53269 .64952 .52655 .64353 Metetra
.656 .751 .92 r
.52655 .64353 .53269 .64952 .54408 .64628 .53797 .64026 Metetra
.656 .751 .92 r
.53797 .64026 .54408 .64628 .55551 .64302 .54943 .63698 Metetra
.656 .751 .92 r
.54943 .63698 .55551 .64302 .567 .63975 .56095 .63368 Metetra
.656 .751 .92 r
.56095 .63368 .567 .63975 .57853 .63647 .57251 .63037 Metetra
.656 .751 .92 r
.57251 .63037 .57853 .63647 .5901 .63317 .58412 .62705 Metetra
.656 .751 .92 r
.58412 .62705 .5901 .63317 .60173 .62986 .59578 .62372 Metetra
.656 .751 .92 r
.59578 .62372 .60173 .62986 .61341 .62654 .60749 .62036 Metetra
.656 .751 .92 r
.60749 .62036 .61341 .62654 .62513 .6232 .61925 .617 Metetra
.656 .751 .92 r
.61925 .617 .62513 .6232 .63691 .61985 .63105 .61362 Metetra
.656 .751 .92 r
.63105 .61362 .63691 .61985 .64873 .61648 .64291 .61023 Metetra
.656 .751 .92 r
.64291 .61023 .64873 .61648 .6606 .6131 .65482 .60682 Metetra
.656 .751 .92 r
.65482 .60682 .6606 .6131 .67253 .60971 .66678 .6034 Metetra
.656 .751 .92 r
.66678 .6034 .67253 .60971 .6845 .6063 .67879 .59996 Metetra
.656 .751 .92 r
.67879 .59996 .6845 .6063 .69653 .60287 .69085 .59651 Metetra
.656 .751 .92 r
.69085 .59651 .69653 .60287 .7086 .59943 .70296 .59305 Metetra
.656 .751 .92 r
.70296 .59305 .7086 .59943 .72073 .59598 .71512 .58957 Metetra
.656 .751 .92 r
.71512 .58957 .72073 .59598 .73291 .59251 .72734 .58607 Metetra
.656 .751 .92 r
.72734 .58607 .73291 .59251 .74514 .58903 .73961 .58256 Metetra
.656 .751 .92 r
.73961 .58256 .74514 .58903 .75743 .58553 .75193 .57903 Metetra
.656 .751 .92 r
.75193 .57903 .75743 .58553 .76977 .58202 .7643 .57549 Metetra
.656 .751 .92 r
.7643 .57549 .76977 .58202 .78216 .57849 .77673 .57194 Metetra
.656 .751 .92 r
.77673 .57194 .78216 .57849 .7946 .57495 .78922 .56837 Metetra
.656 .751 .92 r
.78922 .56837 .7946 .57495 .8071 .57139 .80175 .56478 Metetra
.656 .751 .92 r
.80175 .56478 .8071 .57139 .81965 .56781 .81434 .56118 Metetra
.656 .751 .92 r
.81434 .56118 .81965 .56781 .83226 .56423 .82699 .55756 Metetra
.656 .751 .92 r
.82699 .55756 .83226 .56423 .84492 .56062 .83969 .55392 Metetra
.656 .751 .92 r
.83969 .55392 .84492 .56062 .85764 .557 .85245 .55027 Metetra
.656 .751 .92 r
.85245 .55027 .85764 .557 .87041 .55336 .86526 .54661 Metetra
.656 .751 .92 r
.86526 .54661 .87041 .55336 .88324 .54971 .87813 .54292 Metetra
.656 .751 .92 r
.87813 .54292 .88324 .54971 .89613 .54604 .89106 .53922 Metetra
.656 .751 .92 r
.89106 .53922 .89613 .54604 .90907 .54235 .90404 .53551 Metetra
.656 .751 .92 r
.90404 .53551 .90907 .54235 .92207 .53865 .91709 .53178 Metetra
.656 .751 .92 r
.91709 .53178 .92207 .53865 .93512 .53494 .93019 .52803 Metetra
.656 .751 .92 r
.93019 .52803 .93512 .53494 .94824 .5312 .94334 .52426 Metetra
.656 .751 .92 r
.94334 .52426 .94824 .5312 .96141 .52745 .95656 .52048 Metetra
.656 .751 .92 r
.95656 .52048 .96141 .52745 .97465 .52368 .96984 .51668 Metetra
.656 .751 .92 r
.37573 .67907 .38229 .6848 .39312 .6817 .38658 .67595 Metetra
.656 .751 .92 r
.38658 .67595 .39312 .6817 .40399 .67859 .39748 .67282 Metetra
.656 .751 .92 r
.39748 .67282 .40399 .67859 .41491 .67547 .40843 .66967 Metetra
.656 .751 .92 r
.40843 .66967 .41491 .67547 .42587 .67233 .41941 .66651 Metetra
.656 .751 .92 r
.41941 .66651 .42587 .67233 .43687 .66919 .43045 .66334 Metetra
.656 .751 .92 r
.43045 .66334 .43687 .66919 .44792 .66602 .44152 .66015 Metetra
.656 .751 .92 r
.44152 .66015 .44792 .66602 .45902 .66285 .45265 .65695 Metetra
.656 .751 .92 r
.45265 .65695 .45902 .66285 .47016 .65966 .46382 .65374 Metetra
.656 .751 .92 r
.46382 .65374 .47016 .65966 .48134 .65646 .47503 .65052 Metetra
.656 .751 .92 r
.47503 .65052 .48134 .65646 .49257 .65325 .48629 .64728 Metetra
.656 .751 .92 r
.48629 .64728 .49257 .65325 .50385 .65002 .4976 .64403 Metetra
.656 .751 .92 r
.4976 .64403 .50385 .65002 .51518 .64678 .50896 .64076 Metetra
.656 .751 .92 r
.50896 .64076 .51518 .64678 .52655 .64353 .52036 .63748 Metetra
.656 .751 .92 r
.52036 .63748 .52655 .64353 .53797 .64026 .53181 .63419 Metetra
.656 .751 .92 r
.53181 .63419 .53797 .64026 .54943 .63698 .54331 .63088 Metetra
.656 .751 .92 r
.54331 .63088 .54943 .63698 .56095 .63368 .55485 .62756 Metetra
.656 .751 .92 r
.55485 .62756 .56095 .63368 .57251 .63037 .56645 .62423 Metetra
.656 .751 .92 r
.56645 .62423 .57251 .63037 .58412 .62705 .57809 .62088 Metetra
.656 .751 .92 r
.57809 .62088 .58412 .62705 .59578 .62372 .58978 .61752 Metetra
.656 .751 .92 r
.58978 .61752 .59578 .62372 .60749 .62036 .60153 .61414 Metetra
.656 .751 .92 r
.60153 .61414 .60749 .62036 .61925 .617 .61332 .61075 Metetra
.656 .751 .92 r
.61332 .61075 .61925 .617 .63105 .61362 .62516 .60735 Metetra
.656 .751 .92 r
.62516 .60735 .63105 .61362 .64291 .61023 .63705 .60393 Metetra
.656 .751 .92 r
.63705 .60393 .64291 .61023 .65482 .60682 .64899 .60049 Metetra
.656 .751 .92 r
.64899 .60049 .65482 .60682 .66678 .6034 .66098 .59704 Metetra
.656 .751 .92 r
.66098 .59704 .66678 .6034 .67879 .59996 .67303 .59358 Metetra
.656 .751 .92 r
.67303 .59358 .67879 .59996 .69085 .59651 .68512 .5901 Metetra
.656 .751 .92 r
.68512 .5901 .69085 .59651 .70296 .59305 .69727 .58661 Metetra
.656 .751 .92 r
.69727 .58661 .70296 .59305 .71512 .58957 .70947 .5831 Metetra
.656 .751 .92 r
.70947 .5831 .71512 .58957 .72734 .58607 .72172 .57958 Metetra
.656 .751 .92 r
.72172 .57958 .72734 .58607 .73961 .58256 .73403 .57604 Metetra
.656 .751 .92 r
.73403 .57604 .73961 .58256 .75193 .57903 .74639 .57249 Metetra
.656 .751 .92 r
.74639 .57249 .75193 .57903 .7643 .57549 .7588 .56892 Metetra
.656 .751 .92 r
.7588 .56892 .7643 .57549 .77673 .57194 .77127 .56533 Metetra
.656 .751 .92 r
.77127 .56533 .77673 .57194 .78922 .56837 .78379 .56173 Metetra
.656 .751 .92 r
.78379 .56173 .78922 .56837 .80175 .56478 .79636 .55811 Metetra
.656 .751 .92 r
.79636 .55811 .80175 .56478 .81434 .56118 .80899 .55448 Metetra
.656 .751 .92 r
.80899 .55448 .81434 .56118 .82699 .55756 .82168 .55083 Metetra
.656 .751 .92 r
.82168 .55083 .82699 .55756 .83969 .55392 .83442 .54717 Metetra
.656 .751 .92 r
.83442 .54717 .83969 .55392 .85245 .55027 .84722 .54349 Metetra
.656 .751 .92 r
.84722 .54349 .85245 .55027 .86526 .54661 .86007 .53979 Metetra
.656 .751 .92 r
.86007 .53979 .86526 .54661 .87813 .54292 .87298 .53608 Metetra
.656 .751 .92 r
.87298 .53608 .87813 .54292 .89106 .53922 .88595 .53235 Metetra
.656 .751 .92 r
.88595 .53235 .89106 .53922 .90404 .53551 .89898 .52861 Metetra
.656 .751 .92 r
.89898 .52861 .90404 .53551 .91709 .53178 .91206 .52484 Metetra
.656 .751 .92 r
.91206 .52484 .91709 .53178 .93019 .52803 .9252 .52106 Metetra
.656 .751 .92 r
.9252 .52106 .93019 .52803 .94334 .52426 .93841 .51727 Metetra
.656 .751 .92 r
.93841 .51727 .94334 .52426 .95656 .52048 .95167 .51346 Metetra
.656 .751 .92 r
.95167 .51346 .95656 .52048 .96984 .51668 .96499 .50962 Metetra
.656 .751 .92 r
.36912 .6733 .37573 .67907 .38658 .67595 .38 .67016 Metetra
.656 .751 .92 r
.38 .67016 .38658 .67595 .39748 .67282 .39092 .667 Metetra
.656 .751 .92 r
.39092 .667 .39748 .67282 .40843 .66967 .40189 .66383 Metetra
.656 .751 .92 r
.40189 .66383 .40843 .66967 .41941 .66651 .41291 .66064 Metetra
.656 .751 .92 r
.41291 .66064 .41941 .66651 .43045 .66334 .42397 .65745 Metetra
.656 .751 .92 r
.42397 .65745 .43045 .66334 .44152 .66015 .43508 .65424 Metetra
.656 .751 .92 r
.43508 .65424 .44152 .66015 .45265 .65695 .44623 .65101 Metetra
.656 .751 .92 r
.44623 .65101 .45265 .65695 .46382 .65374 .45743 .64778 Metetra
.656 .751 .92 r
.45743 .64778 .46382 .65374 .47503 .65052 .46868 .64453 Metetra
.656 .751 .92 r
.46868 .64453 .47503 .65052 .48629 .64728 .47997 .64126 Metetra
.656 .751 .92 r
.47997 .64126 .48629 .64728 .4976 .64403 .49131 .63799 Metetra
.656 .751 .92 r
.49131 .63799 .4976 .64403 .50896 .64076 .50269 .6347 Metetra
.656 .751 .92 r
.50269 .6347 .50896 .64076 .52036 .63748 .51412 .63139 Metetra
.656 .751 .92 r
.51412 .63139 .52036 .63748 .53181 .63419 .52561 .62808 Metetra
.656 .751 .92 r
.52561 .62808 .53181 .63419 .54331 .63088 .53714 .62474 Metetra
.656 .751 .92 r
.53714 .62474 .54331 .63088 .55485 .62756 .54871 .6214 Metetra
.656 .751 .92 r
.54871 .6214 .55485 .62756 .56645 .62423 .56034 .61804 Metetra
.656 .751 .92 r
.56034 .61804 .56645 .62423 .57809 .62088 .57202 .61466 Metetra
.656 .751 .92 r
.57202 .61466 .57809 .62088 .58978 .61752 .58374 .61127 Metetra
.656 .751 .92 r
.58374 .61127 .58978 .61752 .60153 .61414 .59551 .60787 Metetra
.656 .751 .92 r
.59551 .60787 .60153 .61414 .61332 .61075 .60734 .60445 Metetra
.656 .751 .92 r
.60734 .60445 .61332 .61075 .62516 .60735 .61921 .60102 Metetra
.656 .751 .92 r
.61921 .60102 .62516 .60735 .63705 .60393 .63114 .59758 Metetra
.656 .751 .92 r
.63114 .59758 .63705 .60393 .64899 .60049 .64312 .59411 Metetra
.656 .751 .92 r
.64312 .59411 .64899 .60049 .66098 .59704 .65514 .59064 Metetra
.656 .751 .92 r
.65514 .59064 .66098 .59704 .67303 .59358 .66722 .58715 Metetra
.656 .751 .92 r
.66722 .58715 .67303 .59358 .68512 .5901 .67935 .58364 Metetra
.656 .751 .92 r
.67935 .58364 .68512 .5901 .69727 .58661 .69154 .58012 Metetra
.656 .751 .92 r
.69154 .58012 .69727 .58661 .70947 .5831 .70377 .57658 Metetra
.656 .751 .92 r
.70377 .57658 .70947 .5831 .72172 .57958 .71606 .57303 Metetra
.656 .751 .92 r
.71606 .57303 .72172 .57958 .73403 .57604 .72841 .56947 Metetra
.656 .751 .92 r
.72841 .56947 .73403 .57604 .74639 .57249 .7408 .56588 Metetra
.656 .751 .92 r
.7408 .56588 .74639 .57249 .7588 .56892 .75325 .56229 Metetra
.656 .751 .92 r
.75325 .56229 .7588 .56892 .77127 .56533 .76576 .55867 Metetra
.656 .751 .92 r
.76576 .55867 .77127 .56533 .78379 .56173 .77832 .55504 Metetra
.656 .751 .92 r
.77832 .55504 .78379 .56173 .79636 .55811 .79093 .5514 Metetra
.656 .751 .92 r
.79093 .5514 .79636 .55811 .80899 .55448 .8036 .54774 Metetra
.656 .751 .92 r
.8036 .54774 .80899 .55448 .82168 .55083 .81633 .54406 Metetra
.656 .751 .92 r
.81633 .54406 .82168 .55083 .83442 .54717 .82911 .54036 Metetra
.656 .751 .92 r
.82911 .54036 .83442 .54717 .84722 .54349 .84195 .53665 Metetra
.656 .751 .92 r
.84195 .53665 .84722 .54349 .86007 .53979 .85484 .53293 Metetra
.656 .751 .92 r
.85484 .53293 .86007 .53979 .87298 .53608 .86779 .52918 Metetra
.656 .751 .92 r
.86779 .52918 .87298 .53608 .88595 .53235 .8808 .52542 Metetra
.656 .751 .92 r
.8808 .52542 .88595 .53235 .89898 .52861 .89387 .52165 Metetra
.656 .751 .92 r
.89387 .52165 .89898 .52861 .91206 .52484 .907 .51785 Metetra
.656 .751 .92 r
.907 .51785 .91206 .52484 .9252 .52106 .92018 .51404 Metetra
.656 .751 .92 r
.92018 .51404 .9252 .52106 .93841 .51727 .93343 .51022 Metetra
.656 .751 .92 r
.93343 .51022 .93841 .51727 .95167 .51346 .94673 .50637 Metetra
.656 .751 .92 r
.94673 .50637 .95167 .51346 .96499 .50962 .9601 .50251 Metetra
.656 .751 .92 r
.36245 .66748 .36912 .6733 .38 .67016 .37336 .66432 Metetra
.656 .751 .92 r
.37336 .66432 .38 .67016 .39092 .667 .38432 .66113 Metetra
.656 .751 .92 r
.38432 .66113 .39092 .667 .40189 .66383 .39531 .65794 Metetra
.656 .751 .92 r
.39531 .65794 .40189 .66383 .41291 .66064 .40636 .65473 Metetra
.656 .751 .92 r
.40636 .65473 .41291 .66064 .42397 .65745 .41745 .65151 Metetra
.656 .751 .92 r
.41745 .65151 .42397 .65745 .43508 .65424 .42858 .64828 Metetra
.656 .751 .92 r
.42858 .64828 .43508 .65424 .44623 .65101 .43977 .64503 Metetra
.656 .751 .92 r
.43977 .64503 .44623 .65101 .45743 .64778 .45099 .64177 Metetra
.656 .751 .92 r
.45099 .64177 .45743 .64778 .46868 .64453 .46227 .63849 Metetra
.656 .751 .92 r
.46227 .63849 .46868 .64453 .47997 .64126 .47359 .6352 Metetra
.656 .751 .92 r
.47359 .6352 .47997 .64126 .49131 .63799 .48496 .6319 Metetra
.656 .751 .92 r
.48496 .6319 .49131 .63799 .50269 .6347 .49638 .62859 Metetra
.656 .751 .92 r
.49638 .62859 .50269 .6347 .51412 .63139 .50784 .62526 Metetra
.656 .751 .92 r
.50784 .62526 .51412 .63139 .52561 .62808 .51935 .62191 Metetra
.656 .751 .92 r
.51935 .62191 .52561 .62808 .53714 .62474 .53091 .61855 Metetra
.656 .751 .92 r
.53091 .61855 .53714 .62474 .54871 .6214 .54252 .61518 Metetra
.656 .751 .92 r
.54252 .61518 .54871 .6214 .56034 .61804 .55418 .6118 Metetra
.656 .751 .92 r
.55418 .6118 .56034 .61804 .57202 .61466 .56589 .6084 Metetra
.656 .751 .92 r
.56589 .6084 .57202 .61466 .58374 .61127 .57765 .60498 Metetra
.656 .751 .92 r
.57765 .60498 .58374 .61127 .59551 .60787 .58946 .60155 Metetra
.656 .751 .92 r
.58946 .60155 .59551 .60787 .60734 .60445 .60131 .59811 Metetra
.656 .751 .92 r
.60131 .59811 .60734 .60445 .61921 .60102 .61322 .59465 Metetra
.656 .751 .92 r
.61322 .59465 .61921 .60102 .63114 .59758 .62518 .59117 Metetra
.656 .751 .92 r
.62518 .59117 .63114 .59758 .64312 .59411 .63719 .58769 Metetra
.656 .751 .92 r
.63719 .58769 .64312 .59411 .65514 .59064 .64926 .58418 Metetra
.656 .751 .92 r
.64926 .58418 .65514 .59064 .66722 .58715 .66137 .58066 Metetra
.656 .751 .92 r
.66137 .58066 .66722 .58715 .67935 .58364 .67354 .57713 Metetra
.656 .751 .92 r
.67354 .57713 .67935 .58364 .69154 .58012 .68576 .57358 Metetra
.656 .751 .92 r
.68576 .57358 .69154 .58012 .70377 .57658 .69803 .57002 Metetra
.656 .751 .92 r
.69803 .57002 .70377 .57658 .71606 .57303 .71036 .56644 Metetra
.656 .751 .92 r
.71036 .56644 .71606 .57303 .72841 .56947 .72274 .56284 Metetra
.656 .751 .92 r
.72274 .56284 .72841 .56947 .7408 .56588 .73517 .55923 Metetra
.656 .751 .92 r
.73517 .55923 .7408 .56588 .75325 .56229 .74766 .5556 Metetra
.656 .751 .92 r
.74766 .5556 .75325 .56229 .76576 .55867 .7602 .55196 Metetra
.656 .751 .92 r
.7602 .55196 .76576 .55867 .77832 .55504 .7728 .5483 Metetra
.656 .751 .92 r
.7728 .5483 .77832 .55504 .79093 .5514 .78545 .54462 Metetra
.656 .751 .92 r
.78545 .54462 .79093 .5514 .8036 .54774 .79816 .54093 Metetra
.656 .751 .92 r
.79816 .54093 .8036 .54774 .81633 .54406 .81093 .53723 Metetra
.656 .751 .92 r
.81093 .53723 .81633 .54406 .82911 .54036 .82375 .5335 Metetra
.656 .751 .92 r
.82375 .5335 .82911 .54036 .84195 .53665 .83663 .52976 Metetra
.656 .751 .92 r
.83663 .52976 .84195 .53665 .85484 .53293 .84957 .526 Metetra
.656 .751 .92 r
.84957 .526 .85484 .53293 .86779 .52918 .86256 .52223 Metetra
.656 .751 .92 r
.86256 .52223 .86779 .52918 .8808 .52542 .87561 .51844 Metetra
.656 .751 .92 r
.87561 .51844 .8808 .52542 .89387 .52165 .88872 .51463 Metetra
.656 .751 .92 r
.88872 .51463 .89387 .52165 .907 .51785 .90189 .51081 Metetra
.656 .751 .92 r
.90189 .51081 .907 .51785 .92018 .51404 .91512 .50696 Metetra
.656 .751 .92 r
.91512 .50696 .92018 .51404 .93343 .51022 .92841 .5031 Metetra
.656 .751 .92 r
.92841 .5031 .93343 .51022 .94673 .50637 .94176 .49923 Metetra
.656 .751 .92 r
.94176 .49923 .94673 .50637 .9601 .50251 .95517 .49533 Metetra
.656 .751 .92 r
.35574 .66162 .36245 .66748 .37336 .66432 .36668 .65843 Metetra
.656 .751 .92 r
.36668 .65843 .37336 .66432 .38432 .66113 .37766 .65523 Metetra
.656 .751 .92 r
.37766 .65523 .38432 .66113 .39531 .65794 .38868 .65201 Metetra
.656 .751 .92 r
.38868 .65201 .39531 .65794 .40636 .65473 .39976 .64877 Metetra
.656 .751 .92 r
.39976 .64877 .40636 .65473 .41745 .65151 .41088 .64553 Metetra
.656 .751 .92 r
.41088 .64553 .41745 .65151 .42858 .64828 .42204 .64227 Metetra
.656 .751 .92 r
.42204 .64227 .42858 .64828 .43977 .64503 .43325 .639 Metetra
.656 .751 .92 r
.43325 .639 .43977 .64503 .45099 .64177 .44451 .63571 Metetra
.656 .751 .92 r
.44451 .63571 .45099 .64177 .46227 .63849 .45581 .63241 Metetra
.656 .751 .92 r
.45581 .63241 .46227 .63849 .47359 .6352 .46717 .6291 Metetra
.656 .751 .92 r
.46717 .6291 .47359 .6352 .48496 .6319 .47857 .62577 Metetra
.656 .751 .92 r
.47857 .62577 .48496 .6319 .49638 .62859 .49001 .62243 Metetra
.656 .751 .92 r
.49001 .62243 .49638 .62859 .50784 .62526 .50151 .61907 Metetra
.656 .751 .92 r
.50151 .61907 .50784 .62526 .51935 .62191 .51305 .6157 Metetra
.656 .751 .92 r
.51305 .6157 .51935 .62191 .53091 .61855 .52464 .61232 Metetra
.656 .751 .92 r
.52464 .61232 .53091 .61855 .54252 .61518 .53629 .60892 Metetra
.656 .751 .92 r
.53629 .60892 .54252 .61518 .55418 .6118 .54798 .60551 Metetra
.656 .751 .92 r
.54798 .60551 .55418 .6118 .56589 .6084 .55972 .60208 Metetra
.656 .751 .92 r
.55972 .60208 .56589 .6084 .57765 .60498 .57151 .59864 Metetra
.656 .751 .92 r
.57151 .59864 .57765 .60498 .58946 .60155 .58335 .59518 Metetra
.656 .751 .92 r
.58335 .59518 .58946 .60155 .60131 .59811 .59524 .59171 Metetra
.656 .751 .92 r
.59524 .59171 .60131 .59811 .61322 .59465 .60719 .58822 Metetra
.656 .751 .92 r
.60719 .58822 .61322 .59465 .62518 .59117 .61918 .58472 Metetra
.656 .751 .92 r
.61918 .58472 .62518 .59117 .63719 .58769 .63123 .58121 Metetra
.656 .751 .92 r
.63123 .58121 .63719 .58769 .64926 .58418 .64332 .57767 Metetra
.656 .751 .92 r
.64332 .57767 .64926 .58418 .66137 .58066 .65547 .57413 Metetra
.656 .751 .92 r
.65547 .57413 .66137 .58066 .67354 .57713 .66768 .57057 Metetra
.656 .751 .92 r
.66768 .57057 .67354 .57713 .68576 .57358 .67993 .56699 Metetra
.656 .751 .92 r
.67993 .56699 .68576 .57358 .69803 .57002 .69224 .56339 Metetra
.656 .751 .92 r
.69224 .56339 .69803 .57002 .71036 .56644 .70461 .55979 Metetra
.656 .751 .92 r
.70461 .55979 .71036 .56644 .72274 .56284 .71702 .55616 Metetra
.656 .751 .92 r
.71702 .55616 .72274 .56284 .73517 .55923 .72949 .55252 Metetra
.656 .751 .92 r
.72949 .55252 .73517 .55923 .74766 .5556 .74202 .54886 Metetra
.656 .751 .92 r
.74202 .54886 .74766 .5556 .7602 .55196 .7546 .54519 Metetra
.656 .751 .92 r
.7546 .54519 .7602 .55196 .7728 .5483 .76724 .5415 Metetra
.656 .751 .92 r
.76724 .5415 .7728 .5483 .78545 .54462 .77993 .5378 Metetra
.656 .751 .92 r
.77993 .5378 .78545 .54462 .79816 .54093 .79268 .53408 Metetra
.656 .751 .92 r
.79268 .53408 .79816 .54093 .81093 .53723 .80549 .53034 Metetra
.656 .751 .92 r
.80549 .53034 .81093 .53723 .82375 .5335 .81835 .52658 Metetra
.656 .751 .92 r
.81835 .52658 .82375 .5335 .83663 .52976 .83127 .52281 Metetra
.656 .751 .92 r
.83127 .52281 .83663 .52976 .84957 .526 .84425 .51902 Metetra
.656 .751 .92 r
.84425 .51902 .84957 .526 .86256 .52223 .85728 .51522 Metetra
.656 .751 .92 r
.85728 .51522 .86256 .52223 .87561 .51844 .87038 .51139 Metetra
.656 .751 .92 r
.87038 .51139 .87561 .51844 .88872 .51463 .88353 .50756 Metetra
.656 .751 .92 r
.88353 .50756 .88872 .51463 .90189 .51081 .89674 .5037 Metetra
.656 .751 .92 r
.89674 .5037 .90189 .51081 .91512 .50696 .91001 .49982 Metetra
.656 .751 .92 r
.91001 .49982 .91512 .50696 .92841 .5031 .92335 .49593 Metetra
.656 .751 .92 r
.92335 .49593 .92841 .5031 .94176 .49923 .93674 .49202 Metetra
.656 .751 .92 r
.93674 .49202 .94176 .49923 .95517 .49533 .95019 .48809 Metetra
.656 .751 .92 r
.34897 .65572 .35574 .66162 .36668 .65843 .35994 .6525 Metetra
.656 .751 .92 r
.35994 .6525 .36668 .65843 .37766 .65523 .37095 .64927 Metetra
.656 .751 .92 r
.37095 .64927 .37766 .65523 .38868 .65201 .382 .64603 Metetra
.656 .751 .92 r
.382 .64603 .38868 .65201 .39976 .64877 .3931 .64277 Metetra
.656 .751 .92 r
.3931 .64277 .39976 .64877 .41088 .64553 .40425 .6395 Metetra
.656 .751 .92 r
.40425 .6395 .41088 .64553 .42204 .64227 .41545 .63622 Metetra
.656 .751 .92 r
.41545 .63622 .42204 .64227 .43325 .639 .42669 .63292 Metetra
.656 .751 .92 r
.42669 .63292 .43325 .639 .44451 .63571 .43797 .62961 Metetra
.656 .751 .92 r
.43797 .62961 .44451 .63571 .45581 .63241 .44931 .62628 Metetra
.656 .751 .92 r
.44931 .62628 .45581 .63241 .46717 .6291 .46069 .62294 Metetra
.656 .751 .92 r
.46069 .62294 .46717 .6291 .47857 .62577 .47212 .61959 Metetra
.656 .751 .92 r
.47212 .61959 .47857 .62577 .49001 .62243 .4836 .61622 Metetra
.656 .751 .92 r
.4836 .61622 .49001 .62243 .50151 .61907 .49513 .61284 Metetra
.656 .751 .92 r
.49513 .61284 .50151 .61907 .51305 .6157 .5067 .60944 Metetra
.656 .751 .92 r
.5067 .60944 .51305 .6157 .52464 .61232 .51833 .60603 Metetra
.656 .751 .92 r
.51833 .60603 .52464 .61232 .53629 .60892 .53 .60261 Metetra
.656 .751 .92 r
.53 .60261 .53629 .60892 .54798 .60551 .54172 .59917 Metetra
.656 .751 .92 r
.54172 .59917 .54798 .60551 .55972 .60208 .5535 .59571 Metetra
.656 .751 .92 r
.5535 .59571 .55972 .60208 .57151 .59864 .56532 .59224 Metetra
.656 .751 .92 r
.56532 .59224 .57151 .59864 .58335 .59518 .5772 .58876 Metetra
.656 .751 .92 r
.5772 .58876 .58335 .59518 .59524 .59171 .58912 .58526 Metetra
.656 .751 .92 r
.58912 .58526 .59524 .59171 .60719 .58822 .6011 .58175 Metetra
.656 .751 .92 r
.6011 .58175 .60719 .58822 .61918 .58472 .61313 .57822 Metetra
.656 .751 .92 r
.61313 .57822 .61918 .58472 .63123 .58121 .62521 .57467 Metetra
.656 .751 .92 r
.62521 .57467 .63123 .58121 .64332 .57767 .63734 .57111 Metetra
.656 .751 .92 r
.63734 .57111 .64332 .57767 .65547 .57413 .64953 .56754 Metetra
.656 .751 .92 r
.64953 .56754 .65547 .57413 .66768 .57057 .66177 .56395 Metetra
.656 .751 .92 r
.66177 .56395 .66768 .57057 .67993 .56699 .67406 .56034 Metetra
.656 .751 .92 r
.67406 .56034 .67993 .56699 .69224 .56339 .68641 .55672 Metetra
.656 .751 .92 r
.68641 .55672 .69224 .56339 .70461 .55979 .69881 .55308 Metetra
.656 .751 .92 r
.69881 .55308 .70461 .55979 .71702 .55616 .71126 .54943 Metetra
.656 .751 .92 r
.71126 .54943 .71702 .55616 .72949 .55252 .72377 .54576 Metetra
.656 .751 .92 r
.72377 .54576 .72949 .55252 .74202 .54886 .73634 .54207 Metetra
.656 .751 .92 r
.73634 .54207 .74202 .54886 .7546 .54519 .74896 .53837 Metetra
.656 .751 .92 r
.74896 .53837 .7546 .54519 .76724 .5415 .76163 .53465 Metetra
.656 .751 .92 r
.76163 .53465 .76724 .5415 .77993 .5378 .77436 .53091 Metetra
.656 .751 .92 r
.77436 .53091 .77993 .5378 .79268 .53408 .78715 .52716 Metetra
.656 .751 .92 r
.78715 .52716 .79268 .53408 .80549 .53034 .8 .52339 Metetra
.656 .751 .92 r
.8 .52339 .80549 .53034 .81835 .52658 .8129 .51961 Metetra
.656 .751 .92 r
.8129 .51961 .81835 .52658 .83127 .52281 .82586 .5158 Metetra
.656 .751 .92 r
.82586 .5158 .83127 .52281 .84425 .51902 .83888 .51198 Metetra
.656 .751 .92 r
.83888 .51198 .84425 .51902 .85728 .51522 .85196 .50815 Metetra
.656 .751 .92 r
.85196 .50815 .85728 .51522 .87038 .51139 .8651 .50429 Metetra
.656 .751 .92 r
.8651 .50429 .87038 .51139 .88353 .50756 .87829 .50042 Metetra
.656 .751 .92 r
.87829 .50042 .88353 .50756 .89674 .5037 .89155 .49653 Metetra
.656 .751 .92 r
.89155 .49653 .89674 .5037 .91001 .49982 .90487 .49262 Metetra
.656 .751 .92 r
.90487 .49262 .91001 .49982 .92335 .49593 .91824 .4887 Metetra
.656 .751 .92 r
.91824 .4887 .92335 .49593 .93674 .49202 .93168 .48476 Metetra
.656 .751 .92 r
.93168 .48476 .93674 .49202 .95019 .48809 .94518 .4808 Metetra
.656 .751 .92 r
.34216 .64977 .34897 .65572 .35994 .6525 .35315 .64653 Metetra
.656 .751 .92 r
.35315 .64653 .35994 .6525 .37095 .64927 .36419 .64327 Metetra
.656 .751 .92 r
.36419 .64327 .37095 .64927 .382 .64603 .37527 .64001 Metetra
.656 .751 .92 r
.37527 .64001 .382 .64603 .3931 .64277 .3864 .63672 Metetra
.656 .751 .92 r
.3864 .63672 .3931 .64277 .40425 .6395 .39758 .63343 Metetra
.656 .751 .92 r
.39758 .63343 .40425 .6395 .41545 .63622 .4088 .63012 Metetra
.656 .751 .92 r
.4088 .63012 .41545 .63622 .42669 .63292 .42007 .6268 Metetra
.656 .751 .92 r
.42007 .6268 .42669 .63292 .43797 .62961 .43139 .62346 Metetra
.656 .751 .92 r
.43139 .62346 .43797 .62961 .44931 .62628 .44275 .62011 Metetra
.656 .751 .92 r
.44275 .62011 .44931 .62628 .46069 .62294 .45417 .61674 Metetra
.656 .751 .92 r
.45417 .61674 .46069 .62294 .47212 .61959 .46563 .61336 Metetra
.656 .751 .92 r
.46563 .61336 .47212 .61959 .4836 .61622 .47714 .60997 Metetra
.656 .751 .92 r
.47714 .60997 .4836 .61622 .49513 .61284 .48869 .60656 Metetra
.656 .751 .92 r
.48869 .60656 .49513 .61284 .5067 .60944 .5003 .60314 Metetra
.656 .751 .92 r
.5003 .60314 .5067 .60944 .51833 .60603 .51196 .5997 Metetra
.656 .751 .92 r
.51196 .5997 .51833 .60603 .53 .60261 .52366 .59625 Metetra
.656 .751 .92 r
.52366 .59625 .53 .60261 .54172 .59917 .53542 .59278 Metetra
.656 .751 .92 r
.53542 .59278 .54172 .59917 .5535 .59571 .54723 .5893 Metetra
.656 .751 .92 r
.54723 .5893 .5535 .59571 .56532 .59224 .55909 .5858 Metetra
.656 .751 .92 r
.55909 .5858 .56532 .59224 .5772 .58876 .57099 .58229 Metetra
.656 .751 .92 r
.57099 .58229 .5772 .58876 .58912 .58526 .58295 .57876 Metetra
.656 .751 .92 r
.58295 .57876 .58912 .58526 .6011 .58175 .59497 .57522 Metetra
.656 .751 .92 r
.59497 .57522 .6011 .58175 .61313 .57822 .60703 .57166 Metetra
.656 .751 .92 r
.60703 .57166 .61313 .57822 .62521 .57467 .61915 .56809 Metetra
.656 .751 .92 r
.61915 .56809 .62521 .57467 .63734 .57111 .63131 .5645 Metetra
.656 .751 .92 r
.63131 .5645 .63734 .57111 .64953 .56754 .64354 .5609 Metetra
.656 .751 .92 r
.64354 .5609 .64953 .56754 .66177 .56395 .65581 .55728 Metetra
.656 .751 .92 r
.65581 .55728 .66177 .56395 .67406 .56034 .66814 .55364 Metetra
.656 .751 .92 r
.66814 .55364 .67406 .56034 .68641 .55672 .68052 .54999 Metetra
.656 .751 .92 r
.68052 .54999 .68641 .55672 .69881 .55308 .69296 .54632 Metetra
.656 .751 .92 r
.69296 .54632 .69881 .55308 .71126 .54943 .70545 .54264 Metetra
.656 .751 .92 r
.70545 .54264 .71126 .54943 .72377 .54576 .718 .53894 Metetra
.656 .751 .92 r
.718 .53894 .72377 .54576 .73634 .54207 .7306 .53522 Metetra
.656 .751 .92 r
.7306 .53522 .73634 .54207 .74896 .53837 .74326 .53149 Metetra
.656 .751 .92 r
.74326 .53149 .74896 .53837 .76163 .53465 .75598 .52774 Metetra
.656 .751 .92 r
.75598 .52774 .76163 .53465 .77436 .53091 .76875 .52397 Metetra
.656 .751 .92 r
.76875 .52397 .77436 .53091 .78715 .52716 .78158 .52019 Metetra
.656 .751 .92 r
.78158 .52019 .78715 .52716 .8 .52339 .79447 .51639 Metetra
.656 .751 .92 r
.79447 .51639 .8 .52339 .8129 .51961 .80741 .51257 Metetra
.656 .751 .92 r
.80741 .51257 .8129 .51961 .82586 .5158 .82041 .50874 Metetra
.656 .751 .92 r
.82041 .50874 .82586 .5158 .83888 .51198 .83348 .50489 Metetra
.656 .751 .92 r
.83348 .50489 .83888 .51198 .85196 .50815 .8466 .50102 Metetra
.656 .751 .92 r
.8466 .50102 .85196 .50815 .8651 .50429 .85978 .49713 Metetra
.656 .751 .92 r
.85978 .49713 .8651 .50429 .87829 .50042 .87301 .49323 Metetra
.656 .751 .92 r
.87301 .49323 .87829 .50042 .89155 .49653 .88631 .48931 Metetra
.656 .751 .92 r
.88631 .48931 .89155 .49653 .90487 .49262 .89967 .48537 Metetra
.656 .751 .92 r
.89967 .48537 .90487 .49262 .91824 .4887 .9131 .48141 Metetra
.656 .751 .92 r
.9131 .48141 .91824 .4887 .93168 .48476 .92658 .47743 Metetra
.656 .751 .92 r
.92658 .47743 .93168 .48476 .94518 .4808 .94012 .47344 Metetra
.656 .751 .92 r
.33529 .64378 .34216 .64977 .35315 .64653 .34631 .64051 Metetra
.656 .751 .92 r
.34631 .64051 .35315 .64653 .36419 .64327 .35738 .63723 Metetra
.656 .751 .92 r
.35738 .63723 .36419 .64327 .37527 .64001 .36849 .63394 Metetra
.656 .751 .92 r
.36849 .63394 .37527 .64001 .3864 .63672 .37965 .63063 Metetra
.656 .751 .92 r
.37965 .63063 .3864 .63672 .39758 .63343 .39085 .62731 Metetra
.656 .751 .92 r
.39085 .62731 .39758 .63343 .4088 .63012 .4021 .62397 Metetra
.656 .751 .92 r
.4021 .62397 .4088 .63012 .42007 .6268 .4134 .62062 Metetra
.656 .751 .92 r
.4134 .62062 .42007 .6268 .43139 .62346 .42475 .61726 Metetra
.656 .751 .92 r
.42475 .61726 .43139 .62346 .44275 .62011 .43615 .61388 Metetra
.656 .751 .92 r
.43615 .61388 .44275 .62011 .45417 .61674 .44759 .61049 Metetra
.656 .751 .92 r
.44759 .61049 .45417 .61674 .46563 .61336 .45908 .60708 Metetra
.656 .751 .92 r
.45908 .60708 .46563 .61336 .47714 .60997 .47062 .60366 Metetra
.656 .751 .92 r
.47062 .60366 .47714 .60997 .48869 .60656 .48221 .60023 Metetra
.656 .751 .92 r
.48221 .60023 .48869 .60656 .5003 .60314 .49385 .59678 Metetra
.656 .751 .92 r
.49385 .59678 .5003 .60314 .51196 .5997 .50554 .59331 Metetra
.656 .751 .92 r
.50554 .59331 .51196 .5997 .52366 .59625 .51728 .58983 Metetra
.656 .751 .92 r
.51728 .58983 .52366 .59625 .53542 .59278 .52907 .58634 Metetra
.656 .751 .92 r
.52907 .58634 .53542 .59278 .54723 .5893 .54091 .58283 Metetra
.656 .751 .92 r
.54091 .58283 .54723 .5893 .55909 .5858 .5528 .57931 Metetra
.656 .751 .92 r
.5528 .57931 .55909 .5858 .57099 .58229 .56474 .57577 Metetra
.656 .751 .92 r
.56474 .57577 .57099 .58229 .58295 .57876 .57674 .57221 Metetra
.656 .751 .92 r
.57674 .57221 .58295 .57876 .59497 .57522 .58878 .56864 Metetra
.656 .751 .92 r
.58878 .56864 .59497 .57522 .60703 .57166 .60088 .56505 Metetra
.656 .751 .92 r
.60088 .56505 .60703 .57166 .61915 .56809 .61303 .56145 Metetra
.656 .751 .92 r
.61303 .56145 .61915 .56809 .63131 .5645 .62524 .55784 Metetra
.656 .751 .92 r
.62524 .55784 .63131 .5645 .64354 .5609 .6375 .5542 Metetra
.656 .751 .92 r
.6375 .5542 .64354 .5609 .65581 .55728 .64981 .55055 Metetra
.656 .751 .92 r
.64981 .55055 .65581 .55728 .66814 .55364 .66217 .54689 Metetra
.656 .751 .92 r
.66217 .54689 .66814 .55364 .68052 .54999 .67459 .54321 Metetra
.656 .751 .92 r
.67459 .54321 .68052 .54999 .69296 .54632 .68707 .53951 Metetra
.656 .751 .92 r
.68707 .53951 .69296 .54632 .70545 .54264 .6996 .5358 Metetra
.656 .751 .92 r
.6996 .5358 .70545 .54264 .718 .53894 .71219 .53206 Metetra
.656 .751 .92 r
.71219 .53206 .718 .53894 .7306 .53522 .72483 .52832 Metetra
.656 .751 .92 r
.72483 .52832 .7306 .53522 .74326 .53149 .73753 .52455 Metetra
.656 .751 .92 r
.73753 .52455 .74326 .53149 .75598 .52774 .75028 .52077 Metetra
.656 .751 .92 r
.75028 .52077 .75598 .52774 .76875 .52397 .76309 .51698 Metetra
.656 .751 .92 r
.76309 .51698 .76875 .52397 .78158 .52019 .77596 .51316 Metetra
.656 .751 .92 r
.77596 .51316 .78158 .52019 .79447 .51639 .78889 .50933 Metetra
.656 .751 .92 r
.78889 .50933 .79447 .51639 .80741 .51257 .80188 .50548 Metetra
.656 .751 .92 r
.80188 .50548 .80741 .51257 .82041 .50874 .81492 .50161 Metetra
.656 .751 .92 r
.81492 .50161 .82041 .50874 .83348 .50489 .82802 .49773 Metetra
.656 .751 .92 r
.82802 .49773 .83348 .50489 .8466 .50102 .84119 .49383 Metetra
.656 .751 .92 r
.84119 .49383 .8466 .50102 .85978 .49713 .85441 .48991 Metetra
.656 .751 .92 r
.85441 .48991 .85978 .49713 .87301 .49323 .86769 .48597 Metetra
.656 .751 .92 r
.86769 .48597 .87301 .49323 .88631 .48931 .88103 .48202 Metetra
.656 .751 .92 r
.88103 .48202 .88631 .48931 .89967 .48537 .89444 .47804 Metetra
.656 .751 .92 r
.89444 .47804 .89967 .48537 .9131 .48141 .90791 .47405 Metetra
.656 .751 .92 r
.90791 .47405 .9131 .48141 .92658 .47743 .92143 .47004 Metetra
.656 .751 .92 r
.92143 .47004 .92658 .47743 .94012 .47344 .93502 .46602 Metetra
.656 .751 .92 r
.32837 .63774 .33529 .64378 .34631 .64051 .33942 .63444 Metetra
.656 .751 .92 r
.33942 .63444 .34631 .64051 .35738 .63723 .35051 .63114 Metetra
.656 .751 .92 r
.35051 .63114 .35738 .63723 .36849 .63394 .36165 .62782 Metetra
.656 .751 .92 r
.36165 .62782 .36849 .63394 .37965 .63063 .37284 .62449 Metetra
.656 .751 .92 r
.37284 .62449 .37965 .63063 .39085 .62731 .38407 .62114 Metetra
.656 .751 .92 r
.38407 .62114 .39085 .62731 .4021 .62397 .39536 .61778 Metetra
.656 .751 .92 r
.39536 .61778 .4021 .62397 .4134 .62062 .40668 .6144 Metetra
.656 .751 .92 r
.40668 .6144 .4134 .62062 .42475 .61726 .41806 .61101 Metetra
.656 .751 .92 r
.41806 .61101 .42475 .61726 .43615 .61388 .42949 .60761 Metetra
.656 .751 .92 r
.42949 .60761 .43615 .61388 .44759 .61049 .44096 .60419 Metetra
.656 .751 .92 r
.44096 .60419 .44759 .61049 .45908 .60708 .45248 .60076 Metetra
.656 .751 .92 r
.45248 .60076 .45908 .60708 .47062 .60366 .46406 .59731 Metetra
.656 .751 .92 r
.46406 .59731 .47062 .60366 .48221 .60023 .47568 .59385 Metetra
.656 .751 .92 r
.47568 .59385 .48221 .60023 .49385 .59678 .48735 .59037 Metetra
.656 .751 .92 r
.48735 .59037 .49385 .59678 .50554 .59331 .49907 .58688 Metetra
.656 .751 .92 r
.49907 .58688 .50554 .59331 .51728 .58983 .51084 .58337 Metetra
.656 .751 .92 r
.51084 .58337 .51728 .58983 .52907 .58634 .52266 .57985 Metetra
.656 .751 .92 r
.52266 .57985 .52907 .58634 .54091 .58283 .53454 .57631 Metetra
.656 .751 .92 r
.53454 .57631 .54091 .58283 .5528 .57931 .54646 .57276 Metetra
.656 .751 .92 r
.54646 .57276 .5528 .57931 .56474 .57577 .55844 .56919 Metetra
.656 .751 .92 r
.55844 .56919 .56474 .57577 .57674 .57221 .57047 .56561 Metetra
.656 .751 .92 r
.57047 .56561 .57674 .57221 .58878 .56864 .58255 .56201 Metetra
.656 .751 .92 r
.58255 .56201 .58878 .56864 .60088 .56505 .59468 .55839 Metetra
.656 .751 .92 r
.59468 .55839 .60088 .56505 .61303 .56145 .60687 .55476 Metetra
.656 .751 .92 r
.60687 .55476 .61303 .56145 .62524 .55784 .61911 .55112 Metetra
.656 .751 .92 r
.61911 .55112 .62524 .55784 .6375 .5542 .6314 .54745 Metetra
.656 .751 .92 r
.6314 .54745 .6375 .5542 .64981 .55055 .64375 .54377 Metetra
.656 .751 .92 r
.64375 .54377 .64981 .55055 .66217 .54689 .65616 .54008 Metetra
.656 .751 .92 r
.65616 .54008 .66217 .54689 .67459 .54321 .66861 .53637 Metetra
.656 .751 .92 r
.66861 .53637 .67459 .54321 .68707 .53951 .68113 .53264 Metetra
.656 .751 .92 r
.68113 .53264 .68707 .53951 .6996 .5358 .6937 .5289 Metetra
.656 .751 .92 r
.6937 .5289 .6996 .5358 .71219 .53206 .70632 .52513 Metetra
.656 .751 .92 r
.70632 .52513 .71219 .53206 .72483 .52832 .719 .52136 Metetra
.656 .751 .92 r
.719 .52136 .72483 .52832 .73753 .52455 .73174 .51756 Metetra
.656 .751 .92 r
.73174 .51756 .73753 .52455 .75028 .52077 .74453 .51375 Metetra
.656 .751 .92 r
.74453 .51375 .75028 .52077 .76309 .51698 .75739 .50992 Metetra
.656 .751 .92 r
.75739 .50992 .76309 .51698 .77596 .51316 .7703 .50607 Metetra
.656 .751 .92 r
.7703 .50607 .77596 .51316 .78889 .50933 .78327 .50221 Metetra
.656 .751 .92 r
.78327 .50221 .78889 .50933 .80188 .50548 .79629 .49833 Metetra
.656 .751 .92 r
.79629 .49833 .80188 .50548 .81492 .50161 .80938 .49443 Metetra
.656 .751 .92 r
.80938 .49443 .81492 .50161 .82802 .49773 .82252 .49051 Metetra
.656 .751 .92 r
.82252 .49051 .82802 .49773 .84119 .49383 .83573 .48658 Metetra
.656 .751 .92 r
.83573 .48658 .84119 .49383 .85441 .48991 .849 .48263 Metetra
.656 .751 .92 r
.849 .48263 .85441 .48991 .86769 .48597 .86232 .47866 Metetra
.656 .751 .92 r
.86232 .47866 .86769 .48597 .88103 .48202 .87571 .47467 Metetra
.656 .751 .92 r
.87571 .47467 .88103 .48202 .89444 .47804 .88916 .47066 Metetra
.656 .751 .92 r
.88916 .47066 .89444 .47804 .90791 .47405 .90267 .46664 Metetra
.656 .751 .92 r
.90267 .46664 .90791 .47405 .92143 .47004 .91624 .46259 Metetra
.656 .751 .92 r
.91624 .46259 .92143 .47004 .93502 .46602 .92988 .45853 Metetra
.652 .75 .922 r
.32139 .63165 .32837 .63774 .33942 .63444 .33246 .62844 Metetra
.645 .752 .927 r
.33246 .62844 .33942 .63444 .35051 .63114 .34357 .6254 Metetra
.638 .76 .937 r
.34357 .6254 .35051 .63114 .36165 .62782 .35472 .62248 Metetra
.628 .772 .949 r
.35472 .62248 .36165 .62782 .37284 .62449 .36591 .6197 Metetra
.615 .789 .965 r
.36591 .6197 .37284 .62449 .38407 .62114 .37715 .61704 Metetra
.596 .81 .982 r
.37715 .61704 .38407 .62114 .39536 .61778 .38844 .61449 Metetra
.567 .833 .995 r
.38844 .61449 .39536 .61778 .40668 .6144 .39977 .61201 Metetra
.524 .852 .997 r
.39977 .61201 .40668 .6144 .41806 .61101 .41116 .60957 Metetra
.462 .855 .975 r
.41116 .60957 .41806 .61101 .42949 .60761 .4226 .6071 Metetra
.383 .836 .922 r
.4226 .6071 .42949 .60761 .44096 .60419 .4341 .60458 Metetra
.296 .793 .84 r
.4341 .60458 .44096 .60419 .45248 .60076 .44566 .60196 Metetra
.216 .738 .747 r
.44566 .60196 .45248 .60076 .46406 .59731 .45728 .59918 Metetra
.45728 .59918 .46406 .59731 .47568 .59385 .46895 .59623 Metetra
.46895 .59623 .47568 .59385 .48735 .59037 .48068 .59306 Metetra
.48068 .59306 .48735 .59037 .49907 .58688 .49246 .58966 Metetra
.49246 .58966 .49907 .58688 .51084 .58337 .5043 .58601 Metetra
.5043 .58601 .51084 .58337 .52266 .57985 .51619 .58211 Metetra
.51619 .58211 .52266 .57985 .53454 .57631 .52812 .57797 Metetra
.325 .805 .754 r
.52812 .57797 .53454 .57631 .54646 .57276 .54011 .57358 Metetra
.435 .875 .851 r
.54011 .57358 .54646 .57276 .55844 .56919 .55214 .56898 Metetra
.543 .921 .931 r
.55214 .56898 .55844 .56919 .57047 .56561 .56421 .56418 Metetra
.627 .926 .973 r
.56421 .56418 .57047 .56561 .58255 .56201 .57633 .55923 Metetra
.677 .896 .976 r
.57633 .55923 .58255 .56201 .59468 .55839 .58848 .55414 Metetra
.699 .848 .954 r
.58848 .55414 .59468 .55839 .60687 .55476 .60068 .54897 Metetra
.704 .796 .922 r
.60068 .54897 .60687 .55476 .61911 .55112 .61292 .54376 Metetra
.7 .748 .889 r
.61292 .54376 .61911 .55112 .6314 .54745 .6252 .53854 Metetra
.692 .707 .859 r
.6252 .53854 .6314 .54745 .64375 .54377 .63753 .53337 Metetra
.683 .673 .834 r
.63753 .53337 .64375 .54377 .65616 .54008 .64991 .52827 Metetra
.673 .645 .814 r
.64991 .52827 .65616 .54008 .66861 .53637 .66233 .52329 Metetra
.665 .623 .798 r
.66233 .52329 .66861 .53637 .68113 .53264 .67481 .51846 Metetra
.657 .606 .785 r
.67481 .51846 .68113 .53264 .6937 .5289 .68735 .51381 Metetra
.65 .592 .776 r
.68735 .51381 .6937 .5289 .70632 .52513 .69995 .50936 Metetra
.644 .582 .77 r
.69995 .50936 .70632 .52513 .719 .52136 .71261 .50513 Metetra
.639 .575 .766 r
.71261 .50513 .719 .52136 .73174 .51756 .72534 .50111 Metetra
.635 .571 .765 r
.72534 .50111 .73174 .51756 .74453 .51375 .73814 .49731 Metetra
.632 .57 .767 r
.73814 .49731 .74453 .51375 .75739 .50992 .75101 .49372 Metetra
.629 .571 .77 r
.75101 .49372 .75739 .50992 .7703 .50607 .76396 .49032 Metetra
.627 .575 .776 r
.76396 .49032 .7703 .50607 .78327 .50221 .77699 .48708 Metetra
.626 .582 .785 r
.77699 .48708 .78327 .50221 .79629 .49833 .79009 .48397 Metetra
.625 .591 .795 r
.79009 .48397 .79629 .49833 .80938 .49443 .80327 .48095 Metetra
.626 .604 .808 r
.80327 .48095 .80938 .49443 .82252 .49051 .81651 .47798 Metetra
.627 .62 .823 r
.81651 .47798 .82252 .49051 .83573 .48658 .82983 .475 Metetra
.629 .638 .84 r
.82983 .475 .83573 .48658 .849 .48263 .84322 .47198 Metetra
.632 .657 .857 r
.84322 .47198 .849 .48263 .86232 .47866 .85667 .46887 Metetra
.635 .678 .873 r
.85667 .46887 .86232 .47866 .87571 .47467 .87017 .46562 Metetra
.639 .699 .889 r
.87017 .46562 .87571 .47467 .88916 .47066 .88373 .46222 Metetra
.643 .717 .902 r
.88373 .46222 .88916 .47066 .90267 .46664 .89733 .45864 Metetra
.647 .732 .911 r
.89733 .45864 .90267 .46664 .91624 .46259 .91099 .4549 Metetra
.651 .744 .918 r
.91099 .4549 .91624 .46259 .92988 .45853 .92469 .45098 Metetra
.652 .75 .922 r
.31437 .62551 .32139 .63165 .33246 .62844 .32546 .62227 Metetra
.628 .744 .931 r
.32546 .62227 .33246 .62844 .34357 .6254 .33658 .61963 Metetra
.613 .754 .945 r
.33658 .61963 .34357 .6254 .35472 .62248 .34773 .61726 Metetra
.59 .767 .964 r
.34773 .61726 .35472 .62248 .36591 .6197 .35891 .6152 Metetra
.556 .784 .984 r
.35891 .6152 .36591 .6197 .37715 .61704 .37014 .61344 Metetra
.506 .801 .998 r
.37014 .61344 .37715 .61704 .38844 .61449 .38142 .61193 Metetra
.43 .807 .992 r
.38142 .61193 .38844 .61449 .39977 .61201 .39275 .61061 Metetra
.321 .785 .94 r
.39275 .61061 .39977 .61201 .41116 .60957 .40414 .60938 Metetra
.188 .719 .827 r
.40414 .60938 .41116 .60957 .4226 .6071 .41559 .60814 Metetra
.41559 .60814 .4226 .6071 .4341 .60458 .42711 .60678 Metetra
.042 0 0 r
.42711 .60678 .4341 .60458 .44566 .60196 .4387 .6052 Metetra
.107 0 0 r
.4387 .6052 .44566 .60196 .45728 .59918 .45036 .60331 Metetra
.141 0 0 r
.45036 .60331 .45728 .59918 .46895 .59623 .46209 .60103 Metetra
.149 0 0 r
.46209 .60103 .46895 .59623 .48068 .59306 .47388 .59827 Metetra
.135 0 0 r
.47388 .59827 .48068 .59306 .49246 .58966 .48573 .59501 Metetra
.1 0 0 r
.48573 .59501 .49246 .58966 .5043 .58601 .49765 .5912 Metetra
.04 0 0 r
.49765 .5912 .5043 .58601 .51619 .58211 .50961 .58683 Metetra
.50961 .58683 .51619 .58211 .52812 .57797 .52163 .5819 Metetra
.52163 .5819 .52812 .57797 .54011 .57358 .53368 .57646 Metetra
.343 .799 .669 r
.53368 .57646 .54011 .57358 .55214 .56898 .54577 .57053 Metetra
.52 .916 .824 r
.54577 .57053 .55214 .56898 .56421 .56418 .5579 .56418 Metetra
.66 .965 .923 r
.5579 .56418 .56421 .56418 .57633 .55923 .57005 .55749 Metetra
.736 .941 .951 r
.57005 .55749 .57633 .55923 .58848 .55414 .58223 .55053 Metetra
.76 .881 .933 r
.58223 .55053 .58848 .55414 .60068 .54897 .59444 .5434 Metetra
.757 .815 .898 r
.59444 .5434 .60068 .54897 .61292 .54376 .60668 .53619 Metetra
.743 .755 .863 r
.60668 .53619 .61292 .54376 .6252 .53854 .61894 .52899 Metetra
.726 .706 .832 r
.61894 .52899 .6252 .53854 .63753 .53337 .63124 .52192 Metetra
.709 .667 .806 r
.63124 .52192 .63753 .53337 .64991 .52827 .64357 .51505 Metetra
.693 .635 .786 r
.64357 .51505 .64991 .52827 .66233 .52329 .65596 .50848 Metetra
.679 .609 .77 r
.65596 .50848 .66233 .52329 .67481 .51846 .66839 .50227 Metetra
.666 .589 .759 r
.66839 .50227 .67481 .51846 .68735 .51381 .68088 .49648 Metetra
.655 .573 .75 r
.68088 .49648 .68735 .51381 .69995 .50936 .69343 .49117 Metetra
.645 .56 .745 r
.69343 .49117 .69995 .50936 .71261 .50513 .70606 .48637 Metetra
.636 .551 .742 r
.70606 .48637 .71261 .50513 .72534 .50111 .71877 .48209 Metetra
.628 .545 .742 r
.71877 .48209 .72534 .50111 .73814 .49731 .73157 .47832 Metetra
.62 .541 .744 r
.73157 .47832 .73814 .49731 .75101 .49372 .74446 .47504 Metetra
.614 .541 .748 r
.74446 .47504 .75101 .49372 .76396 .49032 .75745 .47222 Metetra
.609 .543 .755 r
.75745 .47222 .76396 .49032 .77699 .48708 .77053 .46978 Metetra
.604 .548 .764 r
.77053 .46978 .77699 .48708 .79009 .48397 .78371 .46766 Metetra
.601 .557 .776 r
.78371 .46766 .79009 .48397 .80327 .48095 .79699 .46577 Metetra
.599 .569 .791 r
.79699 .46577 .80327 .48095 .81651 .47798 .81035 .464 Metetra
.599 .585 .808 r
.81035 .464 .81651 .47798 .82983 .475 .8238 .46226 Metetra
.601 .604 .827 r
.8238 .46226 .82983 .475 .84322 .47198 .83732 .46042 Metetra
.604 .627 .847 r
.83732 .46042 .84322 .47198 .85667 .46887 .85091 .45841 Metetra
.61 .652 .867 r
.85091 .45841 .85667 .46887 .87017 .46562 .86455 .45612 Metetra
.617 .678 .886 r
.86455 .45612 .87017 .46562 .88373 .46222 .87823 .4535 Metetra
.625 .703 .902 r
.87823 .4535 .88373 .46222 .89733 .45864 .89195 .45053 Metetra
.632 .724 .914 r
.89195 .45053 .89733 .45864 .91099 .4549 .9057 .44723 Metetra
.648 .745 .921 r
.9057 .44723 .91099 .4549 .92469 .45098 .91946 .44336 Metetra
.656 .751 .92 r
.30728 .61933 .31437 .62551 .32546 .62227 .31842 .61596 Metetra
.616 .738 .933 r
.31842 .61596 .32546 .62227 .33658 .61963 .32954 .6136 Metetra
.587 .738 .948 r
.32954 .6136 .33658 .61963 .34773 .61726 .34068 .6118 Metetra
.552 .748 .968 r
.34068 .6118 .34773 .61726 .35891 .6152 .35186 .61047 Metetra
.5 .757 .987 r
.35186 .61047 .35891 .6152 .37014 .61344 .36308 .6096 Metetra
.426 .76 .996 r
.36308 .6096 .37014 .61344 .38142 .61193 .37434 .60914 Metetra
.323 .747 .974 r
.37434 .60914 .38142 .61193 .39275 .61061 .38566 .60896 Metetra
.192 .701 .899 r
.38566 .60896 .39275 .61061 .40414 .60938 .39705 .60894 Metetra
.054 .619 .768 r
.39705 .60894 .40414 .60938 .41559 .60814 .4085 .60891 Metetra
.06 0 0 r
.4085 .60891 .41559 .60814 .42711 .60678 .42004 .60872 Metetra
.135 0 0 r
.42004 .60872 .42711 .60678 .4387 .6052 .43165 .6082 Metetra
.173 0 0 r
.43165 .6082 .4387 .6052 .45036 .60331 .44335 .6072 Metetra
.182 0 0 r
.44335 .6072 .45036 .60331 .46209 .60103 .45513 .60559 Metetra
.166 0 0 r
.45513 .60559 .46209 .60103 .47388 .59827 .46698 .60327 Metetra
.128 0 0 r
.46698 .60327 .47388 .59827 .48573 .59501 .47891 .60015 Metetra
.066 0 0 r
.47891 .60015 .48573 .59501 .49765 .5912 .4909 .59619 Metetra
.4909 .59619 .49765 .5912 .50961 .58683 .50294 .59136 Metetra
.50294 .59136 .50961 .58683 .52163 .5819 .51503 .58567 Metetra
.51503 .58567 .52163 .5819 .53368 .57646 .52716 .57918 Metetra
.487 .887 .738 r
.52716 .57918 .53368 .57646 .54577 .57053 .53932 .57194 Metetra
.648 .969 .855 r
.53932 .57194 .54577 .57053 .5579 .56418 .5515 .56405 Metetra
.754 .981 .913 r
.5515 .56405 .5579 .56418 .57005 .55749 .5637 .55564 Metetra
.8 .94 .92 r
.5637 .55564 .57005 .55749 .58223 .55053 .57592 .54682 Metetra
.807 .88 .899 r
.57592 .54682 .58223 .55053 .59444 .5434 .58814 .53775 Metetra
.796 .818 .869 r
.58814 .53775 .59444 .5434 .60668 .53619 .60038 .52857 Metetra
.777 .763 .84 r
.60038 .52857 .60668 .53619 .61894 .52899 .61264 .51943 Metetra
.756 .717 .815 r
.61264 .51943 .61894 .52899 .63124 .52192 .62492 .5105 Metetra
.736 .678 .795 r
.62492 .5105 .63124 .52192 .64357 .51505 .63722 .5019 Metetra
.717 .647 .778 r
.63722 .5019 .64357 .51505 .65596 .50848 .64956 .49376 Metetra
.699 .62 .766 r
.64956 .49376 .65596 .50848 .66839 .50227 .66195 .48621 Metetra
.682 .599 .756 r
.66195 .48621 .66839 .50227 .68088 .49648 .6744 .47933 Metetra
.667 .581 .749 r
.6744 .47933 .68088 .49648 .69343 .49117 .68692 .47319 Metetra
.653 .567 .745 r
.68692 .47319 .69343 .49117 .70606 .48637 .69952 .46785 Metetra
.639 .555 .744 r
.69952 .46785 .70606 .48637 .71877 .48209 .71221 .46332 Metetra
.627 .547 .744 r
.71221 .46332 .71877 .48209 .73157 .47832 .72501 .4596 Metetra
.615 .541 .747 r
.72501 .4596 .73157 .47832 .74446 .47504 .73792 .45664 Metetra
.605 .538 .753 r
.73792 .45664 .74446 .47504 .75745 .47222 .75094 .45439 Metetra
.595 .538 .76 r
.75094 .45439 .75745 .47222 .77053 .46978 .76408 .45275 Metetra
.587 .541 .77 r
.76408 .45275 .77053 .46978 .78371 .46766 .77734 .4516 Metetra
.58 .548 .783 r
.77734 .4516 .78371 .46766 .79699 .46577 .79071 .45081 Metetra
.574 .558 .799 r
.79071 .45081 .79699 .46577 .81035 .464 .80419 .45023 Metetra
.571 .573 .816 r
.80419 .45023 .81035 .464 .8238 .46226 .81776 .44968 Metetra
.571 .593 .836 r
.81776 .44968 .8238 .46226 .83732 .46042 .83141 .44902 Metetra
.575 .616 .856 r
.83141 .44902 .83732 .46042 .85091 .45841 .84513 .44808 Metetra
.581 .643 .877 r
.84513 .44808 .85091 .45841 .86455 .45612 .8589 .44674 Metetra
.591 .671 .895 r
.8589 .44674 .86455 .45612 .87823 .4535 .8727 .44491 Metetra
.603 .699 .911 r
.8727 .44491 .87823 .4535 .89195 .45053 .88654 .44257 Metetra
.614 .723 .923 r
.88654 .44257 .89195 .45053 .9057 .44723 .9004 .43976 Metetra
.653 .755 .925 r
.9004 .43976 .9057 .44723 .91946 .44336 .91418 .43568 Metetra
.656 .751 .92 r
.30014 .6131 .30728 .61933 .31842 .61596 .31131 .60971 Metetra
.621 .742 .933 r
.31131 .60971 .31842 .61596 .32954 .6136 .32246 .6072 Metetra
.56 .719 .947 r
.32246 .6072 .32954 .6136 .34068 .6118 .3336 .606 Metetra
.512 .722 .968 r
.3336 .606 .34068 .6118 .35186 .61047 .34476 .6054 Metetra
.443 .722 .985 r
.34476 .6054 .35186 .61047 .36308 .6096 .35596 .60542 Metetra
.345 .71 .985 r
.35596 .60542 .36308 .6096 .37434 .60914 .36721 .60598 Metetra
.218 .676 .947 r
.36721 .60598 .37434 .60914 .38566 .60896 .37851 .60693 Metetra
.073 .611 .855 r
.37851 .60693 .38566 .60896 .39705 .60894 .38989 .6081 Metetra
0 .525 .718 r
.38989 .6081 .39705 .60894 .4085 .60891 .40134 .60927 Metetra
.157 0 0 r
.40134 .60927 .4085 .60891 .42004 .60872 .41289 .61024 Metetra
.21 0 0 r
.41289 .61024 .42004 .60872 .43165 .6082 .42452 .61077 Metetra
.226 0 0 r
.42452 .61077 .43165 .6082 .44335 .6072 .43626 .61067 Metetra
.212 0 0 r
.43626 .61067 .44335 .6072 .45513 .60559 .44808 .60975 Metetra
.174 0 0 r
.44808 .60975 .45513 .60559 .46698 .60327 .45999 .60788 Metetra
.111 0 0 r
.45999 .60788 .46698 .60327 .47891 .60015 .47199 .60493 Metetra
.02 0 0 r
.47199 .60493 .47891 .60015 .4909 .59619 .48405 .60083 Metetra
.48405 .60083 .4909 .59619 .50294 .59136 .49618 .59556 Metetra
.49618 .59556 .50294 .59136 .51503 .58567 .50835 .58914 Metetra
.44 .85 .676 r
.50835 .58914 .51503 .58567 .52716 .57918 .52056 .58162 Metetra
.615 .951 .792 r
.52056 .58162 .52716 .57918 .53932 .57194 .53279 .5731 Metetra
.745 .992 .867 r
.53279 .5731 .53932 .57194 .5515 .56405 .54503 .56371 Metetra
.817 .977 .893 r
.54503 .56371 .5515 .56405 .5637 .55564 .55729 .55361 Metetra
.842 .93 .887 r
.55729 .55361 .5637 .55564 .57592 .54682 .56954 .54298 Metetra
.84 .873 .867 r
.56954 .54298 .57592 .54682 .58814 .53775 .58179 .53201 Metetra
.825 .817 .843 r
.58179 .53201 .58814 .53775 .60038 .52857 .59404 .52091 Metetra
.804 .768 .82 r
.59404 .52091 .60038 .52857 .61264 .51943 .6063 .50989 Metetra
.781 .725 .8 r
.6063 .50989 .61264 .51943 .62492 .5105 .61856 .49915 Metetra
.759 .689 .784 r
.61856 .49915 .62492 .5105 .63722 .5019 .63084 .48887 Metetra
.738 .658 .771 r
.63084 .48887 .63722 .5019 .64956 .49376 .64315 .47924 Metetra
.717 .632 .761 r
.64315 .47924 .64956 .49376 .66195 .48621 .65551 .4704 Metetra
.697 .609 .754 r
.65551 .4704 .66195 .48621 .6744 .47933 .66793 .46247 Metetra
.678 .59 .749 r
.66793 .46247 .6744 .47933 .68692 .47319 .68041 .45555 Metetra
.66 .574 .747 r
.68041 .45555 .68692 .47319 .69952 .46785 .69299 .44971 Metetra
.643 .561 .747 r
.69299 .44971 .69952 .46785 .71221 .46332 .70567 .44496 Metetra
.626 .55 .748 r
.70567 .44496 .71221 .46332 .72501 .4596 .71847 .4413 Metetra
.61 .542 .752 r
.71847 .4413 .72501 .4596 .73792 .45664 .73139 .43867 Metetra
.595 .536 .759 r
.73139 .43867 .73792 .45664 .75094 .45439 .74445 .43699 Metetra
.58 .534 .767 r
.74445 .43699 .75094 .45439 .76408 .45275 .75765 .43613 Metetra
.567 .534 .778 r
.75765 .43613 .76408 .45275 .77734 .4516 .77098 .43594 Metetra
.555 .539 .792 r
.77098 .43594 .77734 .4516 .79071 .45081 .78444 .43623 Metetra
.546 .548 .808 r
.78444 .43623 .79071 .45081 .80419 .45023 .79803 .4368 Metetra
.54 .562 .826 r
.79803 .4368 .80419 .45023 .81776 .44968 .81172 .43742 Metetra
.538 .582 .846 r
.81172 .43742 .81776 .44968 .83141 .44902 .8255 .43789 Metetra
.541 .606 .867 r
.8255 .43789 .83141 .44902 .84513 .44808 .83935 .43801 Metetra
.55 .634 .888 r
.83935 .43801 .84513 .44808 .8589 .44674 .85324 .4376 Metetra
.563 .665 .906 r
.85324 .4376 .8589 .44674 .8727 .44491 .86717 .43656 Metetra
.578 .695 .922 r
.86717 .43656 .8727 .44491 .88654 .44257 .88112 .43487 Metetra
.609 .73 .931 r
.88112 .43487 .88654 .44257 .9004 .43976 .89504 .43214 Metetra
.656 .754 .922 r
.89504 .43214 .9004 .43976 .91418 .43568 .90886 .42794 Metetra
.656 .751 .92 r
.29295 .60682 .30014 .6131 .31131 .60971 .30414 .6034 Metetra
.642 .748 .926 r
.30414 .6034 .31131 .60971 .32246 .6072 .31535 .60033 Metetra
.532 .695 .943 r
.31535 .60033 .32246 .6072 .3336 .606 .32647 .59976 Metetra
.473 .693 .963 r
.32647 .59976 .3336 .606 .34476 .6054 .33762 .5999 Metetra
.387 .681 .976 r
.33762 .5999 .34476 .6054 .35596 .60542 .3488 .60078 Metetra
.269 .654 .967 r
.3488 .60078 .35596 .60542 .36721 .60598 .36003 .60233 Metetra
.123 .602 .916 r
.36003 .60233 .36721 .60598 .37851 .60693 .37131 .60439 Metetra
0 .525 .814 r
.37131 .60439 .37851 .60693 .38989 .6081 .38267 .60672 Metetra
.154 0 0 r
.38267 .60672 .38989 .6081 .40134 .60927 .39412 .60908 Metetra
.234 0 0 r
.39412 .60908 .40134 .60927 .41289 .61024 .40567 .61118 Metetra
.269 0 0 r
.40567 .61118 .41289 .61024 .42452 .61077 .41732 .61276 Metetra
.267 0 0 r
.41732 .61276 .42452 .61077 .43626 .61067 .42908 .61356 Metetra
.234 0 0 r
.42908 .61356 .43626 .61067 .44808 .60975 .44095 .61335 Metetra
.173 0 0 r
.44095 .61335 .44808 .60975 .45999 .60788 .45291 .61194 Metetra
.082 0 0 r
.45291 .61194 .45999 .60788 .47199 .60493 .46497 .60917 Metetra
.46497 .60917 .47199 .60493 .48405 .60083 .47711 .60498 Metetra
.47711 .60498 .48405 .60083 .49618 .59556 .48932 .59931 Metetra
.381 .811 .639 r
.48932 .59931 .49618 .59556 .50835 .58914 .50157 .59219 Metetra
.566 .924 .749 r
.50157 .59219 .50835 .58914 .52056 .58162 .51386 .58369 Metetra
.717 .987 .828 r
.51386 .58369 .52056 .58162 .53279 .5731 .52617 .57393 Metetra
.813 .994 .865 r
.52617 .57393 .53279 .5731 .54503 .56371 .53848 .56309 Metetra
.858 .963 .87 r
.53848 .56309 .54503 .56371 .55729 .55361 .5508 .55135 Metetra
.87 .915 .857 r
.5508 .55135 .55729 .55361 .56954 .54298 .5631 .53897 Metetra
.863 .863 .838 r
.5631 .53897 .56954 .54298 .58179 .53201 .57538 .52617 Metetra
.846 .815 .819 r
.57538 .52617 .58179 .53201 .59404 .52091 .58765 .51323 Metetra
.825 .771 .801 r
.58765 .51323 .59404 .52091 .6063 .50989 .59992 .50039 Metetra
.802 .732 .787 r
.59992 .50039 .6063 .50989 .61856 .49915 .61217 .48792 Metetra
.779 .698 .774 r
.61217 .48792 .61856 .49915 .63084 .48887 .62444 .47604 Metetra
.756 .669 .765 r
.62444 .47604 .63084 .48887 .64315 .47924 .63673 .46498 Metetra
.734 .643 .758 r
.63673 .46498 .64315 .47924 .65551 .4704 .64906 .45492 Metetra
.712 .62 .753 r
.64906 .45492 .65551 .4704 .66793 .46247 .66145 .44601 Metetra
.69 .6 .751 r
.66145 .44601 .66793 .46247 .68041 .45555 .67392 .43837 Metetra
.668 .582 .75 r
.67392 .43837 .68041 .45555 .69299 .44971 .68648 .43207 Metetra
.647 .567 .751 r
.68648 .43207 .69299 .44971 .70567 .44496 .69915 .42714 Metetra
.626 .554 .754 r
.69915 .42714 .70567 .44496 .71847 .4413 .71195 .42355 Metetra
.605 .544 .759 r
.71195 .42355 .71847 .4413 .73139 .43867 .72489 .42126 Metetra
.584 .536 .767 r
.72489 .42126 .73139 .43867 .74445 .43699 .73799 .42015 Metetra
.564 .53 .776 r
.73799 .42015 .74445 .43699 .75765 .43613 .75124 .42006 Metetra
.545 .529 .788 r
.75124 .42006 .75765 .43613 .77098 .43594 .76464 .42081 Metetra
.528 .531 .802 r
.76464 .42081 .77098 .43594 .78444 .43623 .7782 .42215 Metetra
.514 .538 .819 r
.7782 .42215 .78444 .43623 .79803 .4368 .79188 .42383 Metetra
.504 .551 .837 r
.79188 .42383 .79803 .4368 .81172 .43742 .80569 .4256 Metetra
.5 .57 .858 r
.80569 .4256 .81172 .43742 .8255 .43789 .81959 .42717 Metetra
.503 .595 .879 r
.81959 .42717 .8255 .43789 .83935 .43801 .83357 .4283 Metetra
.513 .626 .9 r
.83357 .4283 .83935 .43801 .85324 .4376 .84759 .4288 Metetra
.529 .659 .919 r
.84759 .4288 .85324 .4376 .86717 .43656 .86163 .42855 Metetra
.548 .693 .934 r
.86163 .42855 .86717 .43656 .88112 .43487 .8757 .42753 Metetra
.62 .748 .938 r
.8757 .42753 .88112 .43487 .89504 .43214 .88962 .42436 Metetra
.656 .751 .92 r
.88962 .42436 .89504 .43214 .90886 .42794 .90349 .42012 Metetra
.656 .751 .92 r
.2857 .60049 .29295 .60682 .30414 .6034 .29692 .59704 Metetra
.656 .751 .92 r
.29692 .59704 .30414 .6034 .31535 .60033 .30818 .59358 Metetra
.529 .699 .947 r
.30818 .59358 .31535 .60033 .32647 .59976 .31933 .59298 Metetra
.436 .66 .955 r
.31933 .59298 .32647 .59976 .33762 .5999 .33045 .59385 Metetra
.336 .638 .964 r
.33045 .59385 .33762 .5999 .3488 .60078 .3416 .59558 Metetra
.202 .596 .946 r
.3416 .59558 .3488 .60078 .36003 .60233 .3528 .5981 Metetra
.044 .53 .885 r
.3528 .5981 .36003 .60233 .37131 .60439 .36406 .60122 Metetra
0 .448 .78 r
.36406 .60122 .37131 .60439 .38267 .60672 .3754 .60468 Metetra
.226 0 0 r
.3754 .60468 .38267 .60672 .39412 .60908 .38684 .60819 Metetra
.294 0 0 r
.38684 .60819 .39412 .60908 .40567 .61118 .39838 .61141 Metetra
.315 0 0 r
.39838 .61141 .40567 .61118 .41732 .61276 .41004 .61403 Metetra
.298 0 0 r
.41004 .61403 .41732 .61276 .42908 .61356 .42183 .61573 Metetra
.246 0 0 r
.42183 .61573 .42908 .61356 .44095 .61335 .43373 .61622 Metetra
.161 0 0 r
.43373 .61622 .44095 .61335 .45291 .61194 .44575 .61529 Metetra
.041 0 0 r
.44575 .61529 .45291 .61194 .46497 .60917 .45787 .61274 Metetra
.45787 .61274 .46497 .60917 .47711 .60498 .47008 .60848 Metetra
.47008 .60848 .47711 .60498 .48932 .59931 .48237 .60245 Metetra
.503 .893 .73 r
.48237 .60245 .48932 .59931 .50157 .59219 .49471 .59468 Metetra
.674 .973 .806 r
.49471 .59468 .50157 .59219 .51386 .58369 .50708 .58525 Metetra
.792 .998 .846 r
.50708 .58525 .51386 .58369 .52617 .57393 .51947 .57433 Metetra
.858 .982 .855 r
.51947 .57433 .52617 .57393 .53848 .56309 .53185 .5621 Metetra
.885 .944 .846 r
.53185 .5621 .53848 .56309 .5508 .55135 .54423 .54882 Metetra
.888 .899 .831 r
.54423 .54882 .5508 .55135 .5631 .53897 .55659 .53475 Metetra
.878 .853 .814 r
.55659 .53475 .5631 .53897 .57538 .52617 .56891 .52022 Metetra
.862 .811 .798 r
.56891 .52022 .57538 .52617 .58765 .51323 .58121 .50552 Metetra
.842 .772 .785 r
.58121 .50552 .58765 .51323 .59992 .50039 .59349 .49096 Metetra
.82 .738 .774 r
.59349 .49096 .59992 .50039 .61217 .48792 .60576 .47685 Metetra
.797 .707 .766 r
.60576 .47685 .61217 .48792 .62444 .47604 .61802 .46347 Metetra
.773 .679 .76 r
.61802 .46347 .62444 .47604 .63673 .46498 .6303 .45108 Metetra
.75 .654 .755 r
.6303 .45108 .63673 .46498 .64906 .45492 .64262 .43988 Metetra
.726 .632 .753 r
.64262 .43988 .64906 .45492 .66145 .44601 .65499 .43006 Metetra
.701 .611 .753 r
.65499 .43006 .66145 .44601 .67392 .43837 .66743 .42176 Metetra
.676 .592 .754 r
.66743 .42176 .67392 .43837 .68648 .43207 .67998 .41505 Metetra
.651 .575 .757 r
.67998 .41505 .68648 .43207 .69915 .42714 .69265 .40997 Metetra
.625 .56 .762 r
.69265 .40997 .69915 .42714 .71195 .42355 .70546 .4065 Metetra
.599 .547 .768 r
.70546 .4065 .71195 .42355 .72489 .42126 .71843 .40456 Metetra
.572 .536 .776 r
.71843 .40456 .72489 .42126 .73799 .42015 .73156 .40401 Metetra
.546 .528 .787 r
.73156 .40401 .73799 .42015 .75124 .42006 .74486 .40468 Metetra
.52 .523 .799 r
.74486 .40468 .75124 .42006 .76464 .42081 .75833 .40633 Metetra
.497 .523 .814 r
.75833 .40633 .76464 .42081 .7782 .42215 .77197 .40869 Metetra
.477 .528 .831 r
.77197 .40869 .7782 .42215 .79188 .42383 .78576 .41146 Metetra
.463 .539 .85 r
.78576 .41146 .79188 .42383 .80569 .4256 .79968 .41432 Metetra
.456 .558 .87 r
.79968 .41432 .80569 .4256 .81959 .42717 .8137 .41695 Metetra
.458 .584 .892 r
.8137 .41695 .81959 .42717 .83357 .4283 .82779 .41907 Metetra
.47 .617 .913 r
.82779 .41907 .83357 .4283 .84759 .4288 .84193 .42045 Metetra
.489 .653 .932 r
.84193 .42045 .84759 .4288 .86163 .42855 .8561 .42098 Metetra
.511 .689 .948 r
.8561 .42098 .86163 .42855 .8757 .42753 .87029 .42064 Metetra
.648 .777 .942 r
.87029 .42064 .8757 .42753 .88962 .42436 .88416 .41652 Metetra
.656 .751 .92 r
.88416 .41652 .88962 .42436 .90349 .42012 .89808 .41224 Metetra
.656 .751 .92 r
.27839 .59411 .2857 .60049 .29692 .59704 .28964 .59064 Metetra
.656 .751 .92 r
.28964 .59064 .29692 .59704 .30818 .59358 .30093 .58715 Metetra
.573 .727 .947 r
.30093 .58715 .30818 .59358 .31933 .59298 .31216 .58559 Metetra
.401 .625 .943 r
.31216 .58559 .31933 .59298 .33045 .59385 .32325 .58719 Metetra
.291 .594 .947 r
.32325 .58719 .33045 .59385 .3416 .59558 .33438 .58974 Metetra
.146 .54 .923 r
.33438 .58974 .3416 .59558 .3528 .5981 .34555 .59318 Metetra
0 .465 .857 r
.34555 .59318 .3528 .5981 .36406 .60122 .35678 .59731 Metetra
0 .381 .754 r
.35678 .59731 .36406 .60122 .3754 .60468 .36809 .60186 Metetra
.278 0 0 r
.36809 .60186 .3754 .60468 .38684 .60819 .3795 .60648 Metetra
.337 0 0 r
.3795 .60648 .38684 .60819 .39838 .61141 .39104 .6108 Metetra
.349 0 0 r
.39104 .6108 .39838 .61141 .41004 .61403 .4027 .61443 Metetra
.319 0 0 r
.4027 .61443 .41004 .61403 .42183 .61573 .4145 .61701 Metetra
.249 0 0 r
.4145 .61701 .42183 .61573 .43373 .61622 .42644 .61822 Metetra
.139 0 0 r
.42644 .61822 .43373 .61622 .44575 .61529 .43851 .61778 Metetra
.43851 .61778 .44575 .61529 .45787 .61274 .45069 .61548 Metetra
.45069 .61548 .45787 .61274 .47008 .60848 .46297 .61119 Metetra
.421 .854 .735 r
.46297 .61119 .47008 .60848 .48237 .60245 .47533 .60485 Metetra
.614 .953 .807 r
.47533 .60485 .48237 .60245 .49471 .59468 .48775 .5965 Metetra
.756 .995 .844 r
.48775 .5965 .49471 .59468 .50708 .58525 .50021 .58622 Metetra
.842 .992 .851 r
.50021 .58622 .50708 .58525 .51947 .57433 .51268 .5742 Metetra
.885 .963 .841 r
.51268 .5742 .51947 .57433 .53185 .5621 .52515 .56068 Metetra
.9 .924 .825 r
.52515 .56068 .53185 .5621 .54423 .54882 .53759 .54594 Metetra
.899 .882 .808 r
.53759 .54594 .54423 .54882 .55659 .53475 .55001 .53031 Metetra
.889 .843 .793 r
.55001 .53031 .55659 .53475 .56891 .52022 .56239 .51414 Metetra
.874 .807 .781 r
.56239 .51414 .56891 .52022 .58121 .50552 .57472 .49779 Metetra
.855 .773 .771 r
.57472 .49779 .58121 .50552 .59349 .49096 .58703 .48163 Metetra
.834 .743 .763 r
.58703 .48163 .59349 .49096 .60576 .47685 .59931 .466 Metetra
.812 .715 .758 r
.59931 .466 .60576 .47685 .61802 .46347 .61158 .45122 Metetra
.789 .69 .755 r
.61158 .45122 .61802 .46347 .6303 .45108 .62386 .43759 Metetra
.765 .666 .754 r
.62386 .43759 .6303 .45108 .64262 .43988 .63616 .42535 Metetra
.739 .644 .754 r
.63616 .42535 .64262 .43988 .65499 .43006 .64852 .41471 Metetra
.712 .623 .756 r
.64852 .41471 .65499 .43006 .66743 .42176 .66096 .40581 Metetra
.684 .603 .759 r
.66096 .40581 .66743 .42176 .67998 .41505 .67351 .39876 Metetra
.655 .585 .764 r
.67351 .39876 .67998 .41505 .69265 .40997 .68618 .39358 Metetra
.624 .568 .771 r
.68618 .39358 .69265 .40997 .70546 .4065 .699 .39025 Metetra
.591 .552 .779 r
.699 .39025 .70546 .4065 .71843 .40456 .71199 .38867 Metetra
.558 .538 .789 r
.71199 .38867 .71843 .40456 .73156 .40401 .72516 .38869 Metetra
.524 .526 .8 r
.72516 .38869 .73156 .40401 .74486 .40468 .73852 .3901 Metetra
.491 .518 .813 r
.73852 .3901 .74486 .40468 .75833 .40633 .75206 .39263 Metetra
.459 .514 .827 r
.75206 .39263 .75833 .40633 .77197 .40869 .76578 .39597 Metetra
.432 .516 .844 r
.76578 .39597 .77197 .40869 .78576 .41146 .77966 .39978 Metetra
.413 .525 .862 r
.77966 .39978 .78576 .41146 .79968 .41432 .79368 .40368 Metetra
.403 .543 .882 r
.79368 .40368 .79968 .41432 .8137 .41695 .80782 .40732 Metetra
.404 .57 .904 r
.80782 .40732 .8137 .41695 .82779 .41907 .82203 .41039 Metetra
.418 .605 .925 r
.82203 .41039 .82779 .41907 .84193 .42045 .83629 .41263 Metetra
.441 .645 .944 r
.83629 .41263 .84193 .42045 .8561 .42098 .85058 .41392 Metetra
.529 .718 .959 r
.85058 .41392 .8561 .42098 .87029 .42064 .86474 .4129 Metetra
.656 .755 .923 r
.86474 .4129 .87029 .42064 .88416 .41652 .87864 .4086 Metetra
.656 .751 .92 r
.87864 .4086 .88416 .41652 .89808 .41224 .89261 .40428 Metetra
.656 .751 .92 r
.27103 .58769 .27839 .59411 .28964 .59064 .2823 .58418 Metetra
.656 .751 .92 r
.2823 .58418 .28964 .59064 .30093 .58715 .29363 .58066 Metetra
.641 .748 .926 r
.29363 .58066 .30093 .58715 .31216 .58559 .30497 .57752 Metetra
.37 .589 .929 r
.30497 .57752 .31216 .58559 .32325 .58719 .31604 .57983 Metetra
.253 .551 .929 r
.31604 .57983 .32325 .58719 .33438 .58974 .32713 .58317 Metetra
.102 .489 .9 r
.32713 .58317 .33438 .58974 .34555 .59318 .33826 .58748 Metetra
0 .408 .833 r
.33826 .58748 .34555 .59318 .35678 .59731 .34946 .59259 Metetra
0 .325 .736 r
.34946 .59259 .35678 .59731 .36809 .60186 .36074 .59817 Metetra
0 .261 .636 r
.36074 .59817 .36809 .60186 .3795 .60648 .37213 .60385 Metetra
.365 0 0 r
.37213 .60385 .3795 .60648 .39104 .6108 .38365 .60921 Metetra
.37 0 0 r
.38365 .60921 .39104 .6108 .4027 .61443 .39531 .61382 Metetra
.328 0 0 r
.39531 .61382 .4027 .61443 .4145 .61701 .40712 .61728 Metetra
.241 0 0 r
.40712 .61728 .4145 .61701 .42644 .61822 .41909 .6192 Metetra
.104 0 0 r
.41909 .6192 .42644 .61822 .43851 .61778 .43119 .61927 Metetra
.43119 .61927 .43851 .61778 .45069 .61548 .44343 .61725 Metetra
.31 .797 .756 r
.44343 .61725 .45069 .61548 .46297 .61119 .45577 .61298 Metetra
.529 .921 .829 r
.45577 .61298 .46297 .61119 .47533 .60485 .46821 .6064 Metetra
.702 .984 .863 r
.46821 .6064 .47533 .60485 .48775 .5965 .48071 .59753 Metetra
.812 .995 .864 r
.48071 .59753 .48775 .5965 .50021 .58622 .49326 .58648 Metetra
.873 .974 .848 r
.49326 .58648 .50021 .58622 .51268 .5742 .50581 .57347 Metetra
.901 .94 .827 r
.50581 .57347 .51268 .5742 .52515 .56068 .51836 .55876 Metetra
.909 .903 .807 r
.51836 .55876 .52515 .56068 .53759 .54594 .53088 .54268 Metetra
.906 .867 .789 r
.53088 .54268 .53759 .54594 .55001 .53031 .54336 .5256 Metetra
.896 .833 .776 r
.54336 .5256 .55001 .53031 .56239 .51414 .5558 .50792 Metetra
.882 .802 .766 r
.5558 .50792 .56239 .51414 .57472 .49779 .56818 .49006 Metetra
.866 .774 .758 r
.56818 .49006 .57472 .49779 .58703 .48163 .58052 .47241 Metetra
.847 .748 .754 r
.58052 .47241 .58703 .48163 .59931 .466 .59283 .45538 Metetra
.826 .723 .751 r
.59283 .45538 .59931 .466 .61158 .45122 .60511 .43933 Metetra
.803 .7 .751 r
.60511 .43933 .61158 .45122 .62386 .43759 .6174 .42458 Metetra
.778 .678 .753 r
.6174 .42458 .62386 .43759 .63616 .42535 .62971 .41141 Metetra
.752 .656 .756 r
.62971 .41141 .63616 .42535 .64852 .41471 .64207 .40004 Metetra
.723 .636 .76 r
.64207 .40004 .64852 .41471 .66096 .40581 .6545 .39063 Metetra
.692 .616 .766 r
.6545 .39063 .66096 .40581 .67351 .39876 .66705 .3833 Metetra
.658 .596 .774 r
.66705 .3833 .67351 .39876 .68618 .39358 .67973 .37806 Metetra
.622 .577 .782 r
.67973 .37806 .68618 .39358 .699 .39025 .69257 .3749 Metetra
.583 .558 .792 r
.69257 .3749 .699 .39025 .71199 .38867 .70559 .37369 Metetra
.541 .541 .803 r
.70559 .37369 .71199 .38867 .72516 .38869 .7188 .37428 Metetra
.498 .525 .815 r
.7188 .37428 .72516 .38869 .73852 .3901 .73221 .37642 Metetra
.455 .512 .828 r
.73221 .37642 .73852 .3901 .75206 .39263 .74582 .3798 Metetra
.414 .503 .842 r
.74582 .3798 .75206 .39263 .76578 .39597 .75962 .38408 Metetra
.379 .501 .857 r
.75962 .38408 .76578 .39597 .77966 .39978 .77359 .38887 Metetra
.352 .508 .873 r
.77359 .38887 .77966 .39978 .79368 .40368 .78772 .39377 Metetra
.338 .525 .892 r
.78772 .39377 .79368 .40368 .80782 .40732 .80196 .39837 Metetra
.34 .553 .913 r
.80196 .39837 .80782 .40732 .82203 .41039 .81628 .40234 Metetra
.355 .59 .934 r
.81628 .40234 .82203 .41039 .83629 .41263 .83066 .4054 Metetra
.38 .633 .954 r
.83066 .4054 .83629 .41263 .85058 .41392 .84507 .40745 Metetra
.58 .765 .966 r
.84507 .40745 .85058 .41392 .86474 .4129 .85913 .40495 Metetra
.656 .751 .92 r
.85913 .40495 .86474 .4129 .87864 .4086 .87308 .40061 Metetra
.656 .751 .92 r
.87308 .40061 .87864 .4086 .89261 .40428 .8871 .39626 Metetra
.656 .751 .92 r
.2636 .58121 .27103 .58769 .2823 .58418 .27491 .57767 Metetra
.656 .751 .92 r
.27491 .57767 .2823 .58418 .29363 .58066 .28626 .57413 Metetra
.656 .751 .92 r
.28626 .57413 .29363 .58066 .30497 .57752 .29766 .57057 Metetra
.411 .647 .954 r
.29766 .57057 .30497 .57752 .31604 .57983 .30881 .57173 Metetra
.222 .51 .909 r
.30881 .57173 .31604 .57983 .32713 .58317 .31987 .57582 Metetra
.07 .443 .878 r
.31987 .57582 .32713 .58317 .33826 .58748 .33096 .58096 Metetra
0 .36 .812 r
.33096 .58096 .33826 .58748 .34946 .59259 .34212 .58696 Metetra
0 .28 .725 r
.34212 .58696 .34946 .59259 .36074 .59817 .35337 .59351 Metetra
0 .223 .639 r
.35337 .59351 .36074 .59817 .37213 .60385 .36473 .60019 Metetra
.379 0 0 r
.36473 .60019 .37213 .60385 .38365 .60921 .37623 .60655 Metetra
.377 0 0 r
.37623 .60655 .38365 .60921 .39531 .61382 .38788 .61212 Metetra
.326 0 0 r
.38788 .61212 .39531 .61382 .40712 .61728 .39969 .61642 Metetra
.221 0 0 r
.39969 .61642 .40712 .61728 .41909 .6192 .41167 .61905 Metetra
.056 0 0 r
.41167 .61905 .41909 .6192 .43119 .61927 .42381 .61965 Metetra
.166 .705 .779 r
.42381 .61965 .43119 .61927 .44343 .61725 .4361 .61793 Metetra
.41 .861 .862 r
.4361 .61793 .44343 .61725 .45577 .61298 .44851 .61373 Metetra
.619 .957 .9 r
.44851 .61373 .45577 .61298 .46821 .6064 .46102 .60697 Metetra
.763 .988 .896 r
.46102 .60697 .46821 .6064 .48071 .59753 .4736 .59767 Metetra
.846 .978 .87 r
.4736 .59767 .48071 .59753 .49326 .58648 .48623 .58595 Metetra
.889 .95 .84 r
.48623 .58595 .49326 .58648 .50581 .57347 .49887 .57206 Metetra
.908 .917 .813 r
.49887 .57206 .50581 .57347 .51836 .55876 .5115 .55628 Metetra
.913 .884 .791 r
.5115 .55628 .51836 .55876 .53088 .54268 .5241 .53898 Metetra
.91 .853 .774 r
.5241 .53898 .53088 .54268 .54336 .5256 .53665 .52059 Metetra
.901 .824 .762 r
.53665 .52059 .54336 .5256 .5558 .50792 .54915 .50155 Metetra
.889 .798 .753 r
.54915 .50155 .5558 .50792 .56818 .49006 .56159 .48231 Metetra
.874 .774 .748 r
.56159 .48231 .56818 .49006 .58052 .47241 .57397 .46334 Metetra
.857 .752 .746 r
.57397 .46334 .58052 .47241 .59283 .45538 .58631 .44505 Metetra
.838 .73 .746 r
.58631 .44505 .59283 .45538 .60511 .43933 .59862 .42786 Metetra
.816 .71 .748 r
.59862 .42786 .60511 .43933 .6174 .42458 .61092 .41211 Metetra
.791 .69 .752 r
.61092 .41211 .6174 .42458 .62971 .41141 .62324 .39812 Metetra
.764 .67 .758 r
.62324 .39812 .62971 .41141 .64207 .40004 .63561 .38612 Metetra
.734 .65 .766 r
.63561 .38612 .64207 .40004 .6545 .39063 .64806 .37629 Metetra
.7 .63 .775 r
.64806 .37629 .6545 .39063 .66705 .3833 .66061 .36874 Metetra
.662 .609 .785 r
.66061 .36874 .66705 .3833 .67973 .37806 .67331 .3635 Metetra
.619 .588 .796 r
.67331 .3635 .67973 .37806 .69257 .3749 .68617 .36053 Metetra
.572 .566 .808 r
.68617 .36053 .69257 .3749 .70559 .37369 .69922 .35972 Metetra
.521 .544 .82 r
.69922 .35972 .70559 .37369 .7188 .37428 .71247 .36087 Metetra
.466 .523 .832 r
.71247 .36087 .7188 .37428 .73221 .37642 .72593 .36371 Metetra
.411 .504 .844 r
.72593 .36371 .73221 .37642 .74582 .3798 .73961 .36792 Metetra
.358 .49 .855 r
.73961 .36792 .74582 .3798 .75962 .38408 .75349 .37309 Metetra
.312 .483 .867 r
.75349 .37309 .75962 .38408 .77359 .38887 .76755 .37882 Metetra
.278 .486 .88 r
.76755 .37882 .77359 .38887 .78772 .39377 .78177 .38465 Metetra
.261 .501 .896 r
.78177 .38465 .78772 .39377 .80196 .39837 .79612 .39016 Metetra
.262 .529 .915 r
.79612 .39016 .80196 .39837 .81628 .40234 .81055 .39498 Metetra
.279 .569 .936 r
.81055 .39498 .81628 .40234 .83066 .4054 .82505 .39883 Metetra
.327 .627 .959 r
.82505 .39883 .83066 .4054 .84507 .40745 .83954 .40128 Metetra
.648 .806 .959 r
.83954 .40128 .84507 .40745 .85913 .40495 .85347 .39693 Metetra
.656 .751 .92 r
.85347 .39693 .85913 .40495 .87308 .40061 .86747 .39256 Metetra
.656 .751 .92 r
.86747 .39256 .87308 .40061 .8871 .39626 .88154 .38816 Metetra
.656 .751 .92 r
.25612 .57467 .2636 .58121 .27491 .57767 .26745 .57111 Metetra
.656 .751 .92 r
.26745 .57111 .27491 .57767 .28626 .57413 .27884 .56754 Metetra
.656 .751 .92 r
.27884 .56754 .28626 .57413 .29766 .57057 .29027 .56395 Metetra
.545 .717 .952 r
.29027 .56395 .29766 .57057 .30881 .57173 .30158 .56286 Metetra
.198 .473 .89 r
.30158 .56286 .30881 .57173 .31987 .57582 .3126 .56765 Metetra
.049 .403 .857 r
.3126 .56765 .31987 .57582 .33096 .58096 .32365 .57355 Metetra
0 .32 .795 r
.32365 .57355 .33096 .58096 .34212 .58696 .33477 .58039 Metetra
0 .244 .718 r
.33477 .58039 .34212 .58696 .35337 .59351 .34598 .58784 Metetra
0 .193 .646 r
.34598 .58784 .35337 .59351 .36473 .60019 .3573 .59545 Metetra
0 .178 .598 r
.3573 .59545 .36473 .60019 .37623 .60655 .36878 .60275 Metetra
.371 0 0 r
.36878 .60275 .37623 .60655 .38788 .61212 .38041 .60922 Metetra
.31 0 0 r
.38041 .60922 .38788 .61212 .39969 .61642 .39222 .61434 Metetra
0 .403 .682 r
.39222 .61434 .39969 .61642 .41167 .61905 .40421 .61767 Metetra
.003 .571 .783 r
.40421 .61767 .41167 .61905 .42381 .61965 .41638 .6188 Metetra
.248 .754 .883 r
.41638 .6188 .42381 .61965 .4361 .61793 .42871 .61743 Metetra
.494 .894 .94 r
.42871 .61743 .4361 .61793 .44851 .61373 .44117 .61335 Metetra
.682 .961 .941 r
.44117 .61335 .44851 .61373 .46102 .60697 .45375 .60647 Metetra
.799 .971 .909 r
.45375 .60647 .46102 .60697 .4736 .59767 .46641 .59683 Metetra
.863 .952 .868 r
.46641 .59683 .4736 .59767 .48623 .58595 .47912 .58456 Metetra
.896 .924 .831 r
.47912 .58456 .48623 .58595 .49887 .57206 .49185 .5699 Metetra
.91 .894 .801 r
.49185 .5699 .49887 .57206 .5115 .55628 .50456 .55318 Metetra
.914 .865 .778 r
.50456 .55318 .5115 .55628 .5241 .53898 .51725 .53482 Metetra
.911 .839 .761 r
.51725 .53482 .5241 .53898 .53665 .52059 .52988 .51527 Metetra
.904 .816 .75 r
.52988 .51527 .53665 .52059 .54915 .50155 .54245 .49502 Metetra
.894 .794 .743 r
.54245 .49502 .54915 .50155 .56159 .48231 .55494 .47457 Metetra
.881 .774 .74 r
.55494 .47457 .56159 .48231 .57397 .46334 .56738 .45442 Metetra
.866 .756 .739 r
.56738 .45442 .57397 .46334 .58631 .44505 .57976 .43502 Metetra
.848 .737 .741 r
.57976 .43502 .58631 .44505 .59862 .42786 .5921 .41683 Metetra
.827 .72 .746 r
.5921 .41683 .59862 .42786 .61092 .41211 .60443 .40023 Metetra
.804 .702 .753 r
.60443 .40023 .61092 .41211 .62324 .39812 .61677 .38553 Metetra
.776 .684 .762 r
.61677 .38553 .62324 .39812 .63561 .38612 .62916 .373 Metetra
.745 .665 .773 r
.62916 .373 .63561 .38612 .64806 .37629 .64162 .36284 Metetra
.708 .645 .785 r
.64162 .36284 .64806 .37629 .66061 .36874 .65419 .35515 Metetra
.665 .624 .799 r
.65419 .35515 .66061 .36874 .67331 .3635 .66691 .34996 Metetra
.615 .601 .813 r
.66691 .34996 .67331 .3635 .68617 .36053 .6798 .34723 Metetra
.559 .575 .827 r
.6798 .34723 .68617 .36053 .69922 .35972 .69288 .34682 Metetra
.495 .548 .84 r
.69288 .34682 .69922 .35972 .71247 .36087 .70618 .34853 Metetra
.427 .521 .851 r
.70618 .34853 .71247 .36087 .72593 .36371 .71969 .35205 Metetra
.356 .494 .86 r
.71969 .35205 .72593 .36371 .73961 .36792 .73344 .35704 Metetra
.289 .472 .866 r
.73344 .35704 .73961 .36792 .75349 .37309 .74739 .36307 Metetra
.231 .458 .872 r
.74739 .36307 .75349 .37309 .76755 .37882 .76154 .36967 Metetra
.19 .456 .879 r
.76154 .36967 .76755 .37882 .78177 .38465 .77585 .37638 Metetra
.169 .469 .891 r
.77585 .37638 .78177 .38465 .79612 .39016 .7903 .38273 Metetra
.17 .497 .907 r
.7903 .38273 .79612 .39016 .81055 .39498 .80484 .38835 Metetra
.189 .539 .926 r
.80484 .38835 .81055 .39498 .82505 .39883 .81945 .39296 Metetra
.422 .709 .983 r
.81945 .39296 .82505 .39883 .83954 .40128 .83379 .39323 Metetra
.656 .751 .92 r
.83379 .39323 .83954 .40128 .85347 .39693 .84777 .38884 Metetra
.656 .751 .92 r
.84777 .38884 .85347 .39693 .86747 .39256 .86181 .38443 Metetra
.656 .751 .92 r
.86181 .38443 .86747 .39256 .88154 .38816 .87592 .38 Metetra
.656 .751 .92 r
.24858 .56809 .25612 .57467 .26745 .57111 .25994 .5645 Metetra
.656 .751 .92 r
.25994 .5645 .26745 .57111 .27884 .56754 .27135 .5609 Metetra
.656 .751 .92 r
.27135 .5609 .27884 .56754 .29027 .56395 .28281 .55728 Metetra
.656 .751 .92 r
.28281 .55728 .29027 .56395 .30158 .56286 .29433 .55364 Metetra
.194 .462 .883 r
.29433 .55364 .30158 .56286 .3126 .56765 .30533 .55863 Metetra
.035 .369 .838 r
.30533 .55863 .3126 .56765 .32365 .57355 .31634 .56524 Metetra
0 .289 .781 r
.31634 .56524 .32365 .57355 .33477 .58039 .32741 .57284 Metetra
0 .217 .713 r
.32741 .57284 .33477 .58039 .34598 .58784 .33858 .5811 Metetra
0 .171 .654 r
.33858 .5811 .34598 .58784 .3573 .59545 .34986 .58957 Metetra
0 .162 .621 r
.34986 .58957 .3573 .59545 .36878 .60275 .3613 .59774 Metetra
0 .197 .625 r
.3613 .59774 .36878 .60275 .38041 .60922 .37292 .60506 Metetra
0 .281 .67 r
.37292 .60506 .38041 .60922 .39222 .61434 .38472 .61097 Metetra
0 .417 .757 r
.38472 .61097 .39222 .61434 .40421 .61767 .39672 .61497 Metetra
.066 .596 .866 r
.39672 .61497 .40421 .61767 .41638 .6188 .4089 .61665 Metetra
.321 .773 .955 r
.4089 .61665 .41638 .6188 .42871 .61743 .42126 .61564 Metetra
.555 .893 .983 r
.42126 .61564 .42871 .61743 .44117 .61335 .43378 .61174 Metetra
.719 .941 .957 r
.43378 .61174 .44117 .61335 .45375 .60647 .44642 .60483 Metetra
.816 .942 .908 r
.44642 .60483 .45375 .60647 .46641 .59683 .45915 .59494 Metetra
.869 .922 .86 r
.45915 .59494 .46641 .59683 .47912 .58456 .47194 .58222 Metetra
.896 .897 .82 r
.47194 .58222 .47912 .58456 .49185 .5699 .48476 .56693 Metetra
.908 .872 .79 r
.48476 .56693 .49185 .5699 .50456 .55318 .49756 .54943 Metetra
.912 .849 .767 r
.49756 .54943 .50456 .55318 .51725 .53482 .51033 .53016 Metetra
.911 .827 .751 r
.51033 .53016 .51725 .53482 .52988 .51527 .52304 .50962 Metetra
.905 .808 .741 r
.52304 .50962 .52988 .51527 .54245 .49502 .53568 .48833 Metetra
.897 .791 .735 r
.53568 .48833 .54245 .49502 .55494 .47457 .54824 .46683 Metetra
.886 .775 .733 r
.54824 .46683 .55494 .47457 .56738 .45442 .56074 .44566 Metetra
.873 .759 .734 r
.56074 .44566 .56738 .45442 .57976 .43502 .57317 .42533 Metetra
.857 .745 .738 r
.57317 .42533 .57976 .43502 .5921 .41683 .58555 .40629 Metetra
.838 .73 .745 r
.58555 .40629 .5921 .41683 .60443 .40023 .59791 .38896 Metetra
.815 .715 .754 r
.59791 .38896 .60443 .40023 .61677 .38553 .61029 .37369 Metetra
.788 .699 .766 r
.61029 .37369 .61677 .38553 .62916 .373 .6227 .36075 Metetra
.755 .682 .781 r
.6227 .36075 .62916 .373 .64162 .36284 .63519 .35034 Metetra
.715 .663 .797 r
.63519 .35034 .64162 .36284 .65419 .35515 .64779 .34258 Metetra
.667 .641 .815 r
.64779 .34258 .65419 .35515 .66691 .34996 .66053 .33749 Metetra
.61 .616 .832 r
.66053 .33749 .66691 .34996 .6798 .34723 .67345 .33502 Metetra
.541 .586 .849 r
.67345 .33502 .6798 .34723 .69288 .34682 .68657 .33503 Metetra
.462 .553 .862 r
.68657 .33503 .69288 .34682 .70618 .34853 .69991 .33729 Metetra
.376 .516 .87 r
.69991 .33729 .70618 .34853 .71969 .35205 .71349 .34148 Metetra
.287 .479 .873 r
.71349 .34148 .71969 .35205 .73344 .35704 .72729 .34721 Metetra
.203 .446 .87 r
.72729 .34721 .73344 .35704 .74739 .36307 .74132 .35404 Metetra
.134 .423 .866 r
.74132 .35404 .74739 .36307 .76154 .36967 .75555 .36146 Metetra
.085 .415 .864 r
.75555 .36146 .76154 .36967 .77585 .37638 .76996 .36898 Metetra
.062 .426 .869 r
.76996 .36898 .77585 .37638 .7903 .38273 .7845 .37611 Metetra
.065 .455 .882 r
.7845 .37611 .7903 .38273 .80484 .38835 .79915 .38247 Metetra
.087 .497 .9 r
.79915 .38247 .80484 .38835 .81945 .39296 .81386 .3878 Metetra
.556 .806 .992 r
.81386 .3878 .81945 .39296 .83379 .39323 .82798 .38511 Metetra
.656 .751 .92 r
.82798 .38511 .83379 .39323 .84777 .38884 .842 .38068 Metetra
.656 .751 .92 r
.842 .38068 .84777 .38884 .86181 .38443 .8561 .37623 Metetra
.656 .751 .92 r
.8561 .37623 .86181 .38443 .87592 .38 .87026 .37176 Metetra
.656 .751 .92 r
.24097 .56145 .24858 .56809 .25994 .5645 .25236 .55784 Metetra
.656 .751 .92 r
.25236 .55784 .25994 .5645 .27135 .5609 .26381 .5542 Metetra
.656 .751 .92 r
.26381 .5542 .27135 .5609 .28281 .55728 .2753 .55055 Metetra
.656 .751 .92 r
.2753 .55055 .28281 .55728 .29433 .55364 .28684 .54689 Metetra
.334 .622 .956 r
.28684 .54689 .29433 .55364 .30533 .55863 .29806 .54877 Metetra
.028 .342 .821 r
.29806 .54877 .30533 .55863 .31634 .56524 .30902 .55601 Metetra
0 .264 .769 r
.30902 .55601 .31634 .56524 .32741 .57284 .32005 .56429 Metetra
0 .196 .71 r
.32005 .56429 .32741 .57284 .33858 .5811 .33117 .57328 Metetra
0 .155 .662 r
.33117 .57328 .33858 .5811 .34986 .58957 .34242 .58253 Metetra
0 .151 .642 r
.34242 .58253 .34986 .58957 .3613 .59774 .35382 .5915 Metetra
0 .191 .658 r
.35382 .5915 .3613 .59774 .37292 .60506 .36541 .59959 Metetra
0 .281 .716 r
.36541 .59959 .37292 .60506 .38472 .61097 .3772 .60625 Metetra
0 .422 .811 r
.3772 .60625 .38472 .61097 .39672 .61497 .38919 .61091 Metetra
.125 .6 .918 r
.38919 .61091 .39672 .61497 .4089 .61665 .40139 .61313 Metetra
.376 .765 .988 r
.40139 .61313 .4089 .61665 .42126 .61564 .41378 .61252 Metetra
.59 .868 .994 r
.41378 .61252 .42126 .61564 .43378 .61174 .42634 .60884 Metetra
.735 .906 .954 r
.42634 .60884 .43378 .61174 .44642 .60483 .43903 .60197 Metetra
.82 .907 .9 r
.43903 .60197 .44642 .60483 .45915 .59494 .45183 .59194 Metetra
.867 .891 .851 r
.45183 .59194 .45915 .59494 .47194 .58222 .4647 .5789 Metetra
.892 .872 .811 r
.4647 .5789 .47194 .58222 .48476 .56693 .4776 .56312 Metetra
.904 .852 .781 r
.4776 .56312 .48476 .56693 .49756 .54943 .49049 .54499 Metetra
.909 .833 .759 r
.49049 .54499 .49756 .54943 .51033 .53016 .50334 .52498 Metetra
.909 .816 .743 r
.50334 .52498 .51033 .53016 .52304 .50962 .51613 .50361 Metetra
.906 .801 .734 r
.51613 .50361 .52304 .50962 .53568 .48833 .52885 .48146 Metetra
.9 .788 .728 r
.52885 .48146 .53568 .48833 .54824 .46683 .54149 .4591 Metetra
.891 .775 .727 r
.54149 .4591 .54824 .46683 .56074 .44566 .55405 .43709 Metetra
.879 .763 .73 r
.55405 .43709 .56074 .44566 .57317 .42533 .56653 .41598 Metetra
.865 .751 .735 r
.56653 .41598 .57317 .42533 .58555 .40629 .57897 .39625 Metetra
.848 .74 .744 r
.57897 .39625 .58555 .40629 .59791 .38896 .59137 .37835 Metetra
.826 .728 .757 r
.59137 .37835 .59791 .38896 .61029 .37369 .60379 .36263 Metetra
.799 .715 .772 r
.60379 .36263 .61029 .37369 .6227 .36075 .61623 .34938 Metetra
.765 .7 .79 r
.61623 .34938 .6227 .36075 .63519 .35034 .62875 .33882 Metetra
.722 .683 .811 r
.62875 .33882 .63519 .35034 .64779 .34258 .64138 .33106 Metetra
.668 .661 .833 r
.64138 .33106 .64779 .34258 .66053 .33749 .65416 .32613 Metetra
.601 .633 .855 r
.65416 .32613 .66053 .33749 .67345 .33502 .66712 .32396 Metetra
.518 .598 .874 r
.66712 .32396 .67345 .33502 .68657 .33503 .68028 .3244 Metetra
.42 .556 .885 r
.68028 .3244 .68657 .33503 .69991 .33729 .69367 .3272 Metetra
.311 .507 .887 r
.69367 .3272 .69991 .33729 .71349 .34148 .7073 .33202 Metetra
.201 .456 .877 r
.7073 .33202 .71349 .34148 .72729 .34721 .72117 .33846 Metetra
.1 .41 .86 r
.72117 .33846 .72729 .34721 .74132 .35404 .73528 .34602 Metetra
.02 .378 .842 r
.73528 .34602 .74132 .35404 .75555 .36146 .74959 .3542 Metetra
0 .364 .83 r
.74959 .3542 .75555 .36146 .76996 .36898 .76408 .36246 Metetra
0 .372 .828 r
.76408 .36246 .76996 .36898 .7845 .37611 .77872 .37032 Metetra
0 .401 .838 r
.77872 .37032 .7845 .37611 .79915 .38247 .79346 .37736 Metetra
.121 .551 .919 r
.79346 .37736 .79915 .38247 .81386 .3878 .80811 .38136 Metetra
.649 .802 .956 r
.80811 .38136 .81386 .3878 .82798 .38511 .82212 .37692 Metetra
.656 .751 .92 r
.82212 .37692 .82798 .38511 .842 .38068 .83619 .37245 Metetra
.656 .751 .92 r
.83619 .37245 .842 .38068 .8561 .37623 .85034 .36795 Metetra
.656 .751 .92 r
.85034 .36795 .8561 .37623 .87026 .37176 .86455 .36344 Metetra
.656 .751 .92 r
.23331 .55476 .24097 .56145 .25236 .55784 .24473 .55112 Metetra
.656 .751 .92 r
.24473 .55112 .25236 .55784 .26381 .5542 .2562 .54745 Metetra
.656 .751 .92 r
.2562 .54745 .26381 .5542 .2753 .55055 .26772 .54377 Metetra
.656 .751 .92 r
.26772 .54377 .2753 .55055 .28684 .54689 .27929 .54008 Metetra
.586 .731 .943 r
.27929 .54008 .28684 .54689 .29806 .54877 .2908 .53808 Metetra
.026 .319 .806 r
.2908 .53808 .29806 .54877 .30902 .55601 .30172 .54588 Metetra
0 .245 .759 r
.30172 .54588 .30902 .55601 .32005 .56429 .3127 .55475 Metetra
0 .182 .707 r
.3127 .55475 .32005 .56429 .33117 .57328 .32377 .56439 Metetra
0 .145 .669 r
.32377 .56439 .33117 .57328 .34242 .58253 .33497 .57432 Metetra
0 .144 .658 r
.33497 .57432 .34242 .58253 .35382 .5915 .34634 .584 Metetra
0 .187 .683 r
.34634 .584 .35382 .5915 .36541 .59959 .35789 .59281 Metetra
0 .279 .747 r
.35789 .59281 .36541 .59959 .3772 .60625 .36966 .60015 Metetra
0 .419 .842 r
.36966 .60015 .3772 .60625 .38919 .61091 .38164 .60545 Metetra
.175 .587 .939 r
.38164 .60545 .38919 .61091 .40139 .61313 .39385 .6082 Metetra
.411 .736 .992 r
.39385 .6082 .40139 .61313 .41378 .61252 .40626 .60801 Metetra
.606 .829 .985 r
.40626 .60801 .41378 .61252 .42634 .60884 .41885 .60461 Metetra
.737 .866 .941 r
.41885 .60461 .42634 .60884 .43903 .60197 .4316 .59787 Metetra
.815 .87 .888 r
.4316 .59787 .43903 .60197 .45183 .59194 .44446 .5878 Metetra
.86 .861 .84 r
.44446 .5878 .45183 .59194 .4647 .5789 .4574 .57455 Metetra
.885 .847 .802 r
.4574 .57455 .4647 .5789 .4776 .56312 .47038 .55843 Metetra
.898 .833 .773 r
.47038 .55843 .4776 .56312 .49049 .54499 .48335 .53983 Metetra
.905 .819 .752 r
.48335 .53983 .49049 .54499 .50334 .52498 .49629 .51925 Metetra
.907 .806 .737 r
.49629 .51925 .50334 .52498 .51613 .50361 .50917 .49724 Metetra
.905 .795 .728 r
.50917 .49724 .51613 .50361 .52885 .48146 .52197 .47441 Metetra
.901 .785 .724 r
.52197 .47441 .52885 .48146 .54149 .4591 .53468 .45137 Metetra
.894 .775 .723 r
.53468 .45137 .54149 .4591 .55405 .43709 .54731 .4287 Metetra
.885 .767 .727 r
.54731 .4287 .55405 .43709 .56653 .41598 .55986 .40698 Metetra
.872 .758 .734 r
.55986 .40698 .56653 .41598 .57897 .39625 .57235 .38673 Metetra
.856 .75 .745 r
.57235 .38673 .57897 .39625 .59137 .37835 .58481 .36839 Metetra
.836 .741 .76 r
.58481 .36839 .59137 .37835 .60379 .36263 .59726 .35236 Metetra
.809 .732 .779 r
.59726 .35236 .60379 .36263 .61623 .34938 .60975 .33892 Metetra
.774 .72 .801 r
.60975 .33892 .61623 .34938 .62875 .33882 .62231 .3283 Metetra
.728 .704 .827 r
.62231 .3283 .62875 .33882 .64138 .33106 .63498 .32061 Metetra
.668 .683 .855 r
.63498 .32061 .64138 .33106 .65416 .32613 .6478 .31589 Metetra
.588 .652 .881 r
.6478 .31589 .65416 .32613 .66712 .32396 .6608 .31405 Metetra
.486 .61 .9 r
.6608 .31405 .66712 .32396 .68028 .3244 .67401 .31492 Metetra
.364 .555 .907 r
.67401 .31492 .68028 .3244 .69367 .3272 .68745 .31826 Metetra
.228 .49 .895 r
.68745 .31826 .69367 .3272 .7073 .33202 .70114 .32369 Metetra
.095 .421 .867 r
.70114 .32369 .7073 .33202 .72117 .33846 .71508 .33078 Metetra
0 .362 .831 r
.71508 .33078 .72117 .33846 .73528 .34602 .72925 .33903 Metetra
0 .32 .797 r
.72925 .33903 .73528 .34602 .74959 .3542 .74364 .3479 Metetra
0 .303 .774 r
.74364 .3479 .74959 .3542 .76408 .36246 .75821 .35683 Metetra
0 .31 .767 r
.75821 .35683 .76408 .36246 .77872 .37032 .77294 .36534 Metetra
0 .339 .775 r
.77294 .36534 .77872 .37032 .79346 .37736 .78778 .37301 Metetra
.349 .729 .986 r
.78778 .37301 .79346 .37736 .80811 .38136 .80215 .37313 Metetra
.656 .751 .92 r
.80215 .37313 .80811 .38136 .82212 .37692 .8162 .36865 Metetra
.656 .751 .92 r
.8162 .36865 .82212 .37692 .83619 .37245 .83033 .36414 Metetra
.656 .751 .92 r
.83033 .36414 .83619 .37245 .85034 .36795 .84452 .35961 Metetra
.656 .751 .92 r
.84452 .35961 .85034 .36795 .86455 .36344 .85879 .35505 Metetra
.656 .751 .92 r
.22558 .54802 .23331 .55476 .24473 .55112 .23703 .54434 Metetra
.656 .751 .92 r
.23703 .54434 .24473 .55112 .2562 .54745 .24853 .54065 Metetra
.656 .751 .92 r
.24853 .54065 .2562 .54745 .26772 .54377 .26008 .53694 Metetra
.656 .751 .92 r
.26008 .53694 .26772 .54377 .27929 .54008 .27169 .53321 Metetra
.656 .751 .92 r
.27169 .53321 .27929 .54008 .2908 .53808 .28334 .52947 Metetra
.103 .431 .873 r
.28334 .52947 .2908 .53808 .30172 .54588 .29442 .53489 Metetra
0 .231 .75 r
.29442 .53489 .30172 .54588 .3127 .55475 .30535 .54426 Metetra
0 .172 .706 r
.30535 .54426 .3127 .55475 .32377 .56439 .31638 .55444 Metetra
0 .138 .675 r
.31638 .55444 .32377 .56439 .33497 .57432 .32753 .56496 Metetra
0 .14 .67 r
.32753 .56496 .33497 .57432 .34634 .584 .33886 .57527 Metetra
0 .184 .7 r
.33886 .57527 .34634 .584 .35789 .59281 .35037 .58472 Metetra
0 .275 .765 r
.35037 .58472 .35789 .59281 .36966 .60015 .36211 .5927 Metetra
.003 .408 .854 r
.36211 .5927 .36966 .60015 .38164 .60545 .37408 .59859 Metetra
.213 .563 .937 r
.37408 .59859 .38164 .60545 .39385 .6082 .38629 .60187 Metetra
.431 .699 .977 r
.38629 .60187 .39385 .6082 .40626 .60801 .39871 .60212 Metetra
.609 .785 .965 r
.39871 .60212 .40626 .60801 .41885 .60461 .41134 .59904 Metetra
.73 .824 .923 r
.41134 .59904 .41885 .60461 .4316 .59787 .42412 .59249 Metetra
.805 .835 .874 r
.42412 .59249 .4316 .59787 .44446 .5878 .43704 .58248 Metetra
.849 .833 .83 r
.43704 .58248 .44446 .5878 .4574 .57455 .45005 .56917 Metetra
.876 .825 .794 r
.45005 .56917 .4574 .57455 .47038 .55843 .4631 .55285 Metetra
.891 .815 .767 r
.4631 .55285 .47038 .55843 .48335 .53983 .47615 .53394 Metetra
.9 .806 .747 r
.47615 .53394 .48335 .53983 .49629 .51925 .48917 .51297 Metetra
.903 .797 .733 r
.48917 .51297 .49629 .51925 .50917 .49724 .50214 .49051 Metetra
.904 .789 .724 r
.50214 .49051 .50917 .49724 .52197 .47441 .51502 .46719 Metetra
.901 .782 .72 r
.51502 .46719 .52197 .47441 .53468 .45137 .52781 .44364 Metetra
.896 .776 .721 r
.52781 .44364 .53468 .45137 .54731 .4287 .54051 .4205 Metetra
.889 .771 .725 r
.54051 .4205 .54731 .4287 .55986 .40698 .55313 .39835 Metetra
.878 .765 .734 r
.55313 .39835 .55986 .40698 .57235 .38673 .56569 .37773 Metetra
.864 .761 .747 r
.56569 .37773 .57235 .38673 .58481 .36839 .5782 .35911 Metetra
.845 .755 .764 r
.5782 .35911 .58481 .36839 .59726 .35236 .59071 .34289 Metetra
.819 .749 .787 r
.59071 .34289 .59726 .35236 .60975 .33892 .60325 .32938 Metetra
.783 .741 .814 r
.60325 .32938 .60975 .33892 .62231 .3283 .61586 .31879 Metetra
.733 .728 .846 r
.61586 .31879 .62231 .3283 .63498 .32061 .62858 .31125 Metetra
.664 .707 .879 r
.62858 .31125 .63498 .32061 .6478 .31589 .64144 .30677 Metetra
.569 .673 .909 r
.64144 .30677 .6478 .31589 .6608 .31405 .65449 .30528 Metetra
.443 .621 .927 r
.65449 .30528 .6608 .31405 .67401 .31492 .66775 .30661 Metetra
.29 .548 .922 r
.66775 .30661 .67401 .31492 .68745 .31826 .68124 .31046 Metetra
.126 .461 .889 r
.68124 .31046 .68745 .31826 .70114 .32369 .69499 .31647 Metetra
0 .373 .835 r
.69499 .31647 .70114 .32369 .71508 .33078 .70899 .32417 Metetra
0 .301 .777 r
.70899 .32417 .71508 .33078 .72925 .33903 .72323 .33304 Metetra
0 .254 .729 r
.72323 .33304 .72925 .33903 .74364 .3479 .73769 .34253 Metetra
0 .236 .7 r
.73769 .34253 .74364 .3479 .75821 .35683 .75235 .35206 Metetra
0 .244 .691 r
.75235 .35206 .75821 .35683 .77294 .36534 .76717 .36114 Metetra
0 .277 .701 r
.76717 .36114 .77294 .36534 .78778 .37301 .7821 .36934 Metetra
.6 .881 .992 r
.7821 .36934 .78778 .37301 .80215 .37313 .79613 .36483 Metetra
.656 .751 .92 r
.79613 .36483 .80215 .37313 .8162 .36865 .81024 .3603 Metetra
.656 .751 .92 r
.81024 .3603 .8162 .36865 .83033 .36414 .82441 .35575 Metetra
.656 .751 .92 r
.82441 .35575 .83033 .36414 .84452 .35961 .83866 .35118 Metetra
.656 .751 .92 r
.83866 .35118 .84452 .35961 .85879 .35505 .85297 .34658 Metetra
.656 .751 .92 r
.21779 .54122 .22558 .54802 .23703 .54434 .22927 .53751 Metetra
.656 .751 .92 r
.22927 .53751 .23703 .54434 .24853 .54065 .2408 .53379 Metetra
.656 .751 .92 r
.2408 .53379 .24853 .54065 .26008 .53694 .25238 .53005 Metetra
.656 .751 .92 r
.25238 .53005 .26008 .53694 .27169 .53321 .26402 .52629 Metetra
.656 .751 .92 r
.26402 .52629 .27169 .53321 .28334 .52947 .2757 .52252 Metetra
.434 .67 .962 r
.2757 .52252 .28334 .52947 .29442 .53489 .28713 .52308 Metetra
0 .221 .743 r
.28713 .52308 .29442 .53489 .30535 .54426 .29802 .53287 Metetra
0 .166 .704 r
.29802 .53287 .30535 .54426 .31638 .55444 .309 .5435 Metetra
0 .136 .679 r
.309 .5435 .31638 .55444 .32753 .56496 .32011 .55451 Metetra
0 .139 .679 r
.32011 .55451 .32753 .56496 .33886 .57527 .33138 .56534 Metetra
0 .183 .71 r
.33138 .56534 .33886 .57527 .35037 .58472 .34286 .57535 Metetra
0 .27 .772 r
.34286 .57535 .35037 .58472 .36211 .5927 .35457 .58389 Metetra
.042 .394 .852 r
.35457 .58389 .36211 .5927 .37408 .59859 .36652 .59034 Metetra
.24 .536 .922 r
.36652 .59034 .37408 .59859 .38629 .60187 .37872 .59414 Metetra
.441 .66 .954 r
.37872 .59414 .38629 .60187 .39871 .60212 .39115 .59483 Metetra
.605 .742 .942 r
.39115 .59483 .39871 .60212 .41134 .59904 .40379 .59212 Metetra
.719 .785 .904 r
.40379 .59212 .41134 .59904 .42412 .59249 .41662 .58584 Metetra
.792 .802 .861 r
.41662 .58584 .42412 .59249 .43704 .58248 .42958 .57599 Metetra
.837 .806 .821 r
.42958 .57599 .43704 .58248 .45005 .56917 .44265 .56273 Metetra
.866 .804 .788 r
.44265 .56273 .45005 .56917 .4631 .55285 .45577 .54636 Metetra
.883 .799 .762 r
.45577 .54636 .4631 .55285 .47615 .53394 .4689 .52732 Metetra
.894 .794 .743 r
.4689 .52732 .47615 .53394 .48917 .51297 .482 .50613 Metetra
.899 .789 .73 r
.482 .50613 .48917 .51297 .50214 .49051 .49504 .4834 Metetra
.902 .784 .722 r
.49504 .4834 .50214 .49051 .51502 .46719 .50801 .45978 Metetra
.901 .78 .718 r
.50801 .45978 .51502 .46719 .52781 .44364 .52088 .43593 Metetra
.898 .777 .719 r
.52088 .43593 .52781 .44364 .54051 .4205 .53366 .41249 Metetra
.892 .774 .725 r
.53366 .41249 .54051 .4205 .55313 .39835 .54636 .39008 Metetra
.883 .772 .735 r
.54636 .39008 .55313 .39835 .56569 .37773 .55898 .36926 Metetra
.871 .771 .749 r
.55898 .36926 .56569 .37773 .5782 .35911 .57156 .3505 Metetra
.853 .77 .77 r
.57156 .3505 .5782 .35911 .59071 .34289 .58413 .33423 Metetra
.827 .767 .796 r
.58413 .33423 .59071 .34289 .60325 .32938 .59673 .32074 Metetra
.79 .763 .828 r
.59673 .32074 .60325 .32938 .61586 .31879 .60939 .31027 Metetra
.736 .753 .866 r
.60939 .31027 .61586 .31879 .62858 .31125 .62216 .30294 Metetra
.656 .733 .906 r
.62216 .30294 .62858 .31125 .64144 .30677 .63507 .29876 Metetra
.541 .694 .939 r
.63507 .29876 .64144 .30677 .65449 .30528 .64817 .29766 Metetra
.385 .627 .949 r
.64817 .29766 .65449 .30528 .66775 .30661 .66148 .29943 Metetra
.197 .53 .922 r
.66148 .29943 .66775 .30661 .68124 .31046 .67504 .30378 Metetra
.007 .417 .858 r
.67504 .30378 .68124 .31046 .69499 .31647 .68884 .31033 Metetra
0 .312 .776 r
.68884 .31033 .69499 .31647 .70899 .32417 .70291 .31859 Metetra
0 .233 .701 r
.70291 .31859 .70899 .32417 .72323 .33304 .71721 .32802 Metetra
0 .186 .646 r
.71721 .32802 .72323 .33304 .73769 .34253 .73175 .33805 Metetra
0 .17 .616 r
.73175 .33805 .73769 .34253 .75235 .35206 .74649 .34811 Metetra
0 .182 .609 r
.74649 .34811 .75235 .35206 .76717 .36114 .76138 .35769 Metetra
.028 .543 .868 r
.76138 .35769 .76717 .36114 .7821 .36934 .77598 .361 Metetra
.656 .751 .92 r
.77598 .361 .7821 .36934 .79613 .36483 .79006 .35645 Metetra
.656 .751 .92 r
.79006 .35645 .79613 .36483 .81024 .3603 .80422 .35189 Metetra
.656 .751 .92 r
.80422 .35189 .81024 .3603 .82441 .35575 .81844 .34729 Metetra
.656 .751 .92 r
.81844 .34729 .82441 .35575 .83866 .35118 .83273 .34268 Metetra
.656 .751 .92 r
.83273 .34268 .83866 .35118 .85297 .34658 .8471 .33804 Metetra
.656 .751 .92 r
.20993 .53436 .21779 .54122 .22927 .53751 .22144 .53063 Metetra
.656 .751 .92 r
.22144 .53063 .22927 .53751 .2408 .53379 .233 .52687 Metetra
.656 .751 .92 r
.233 .52687 .2408 .53379 .25238 .53005 .24462 .5231 Metetra
.656 .751 .92 r
.24462 .5231 .25238 .53005 .26402 .52629 .25628 .51931 Metetra
.656 .751 .92 r
.25628 .51931 .26402 .52629 .2757 .52252 .268 .51551 Metetra
.656 .751 .92 r
.268 .51551 .2757 .52252 .28713 .52308 .27977 .51169 Metetra
0 .257 .767 r
.27977 .51169 .28713 .52308 .29802 .53287 .29069 .52065 Metetra
0 .164 .703 r
.29069 .52065 .29802 .53287 .309 .5435 .30163 .53162 Metetra
0 .136 .682 r
.30163 .53162 .309 .5435 .32011 .55451 .31269 .54302 Metetra
0 .14 .684 r
.31269 .54302 .32011 .55451 .33138 .56534 .32392 .55428 Metetra
0 .183 .715 r
.32392 .55428 .33138 .56534 .34286 .57535 .33536 .56476 Metetra
0 .265 .773 r
.33536 .56476 .34286 .57535 .35457 .58389 .34704 .5738 Metetra
.074 .38 .843 r
.34704 .5738 .35457 .58389 .36652 .59034 .35896 .58075 Metetra
.259 .509 .902 r
.35896 .58075 .36652 .59034 .37872 .59414 .37114 .58504 Metetra
.443 .622 .928 r
.37114 .58504 .37872 .59414 .39115 .59483 .38357 .5862 Metetra
.595 .702 .918 r
.38357 .5862 .39115 .59483 .40379 .59212 .39623 .58389 Metetra
.704 .749 .886 r
.39623 .58389 .40379 .59212 .41662 .58584 .40908 .57794 Metetra
.777 .772 .848 r
.40908 .57794 .41662 .58584 .42958 .57599 .42209 .56835 Metetra
.824 .782 .812 r
.42209 .56835 .42958 .57599 .44265 .56273 .4352 .55526 Metetra
.855 .785 .782 r
.4352 .55526 .44265 .56273 .45577 .54636 .44839 .53899 Metetra
.874 .784 .758 r
.44839 .53899 .45577 .54636 .4689 .52732 .46159 .51996 Metetra
.887 .783 .741 r
.46159 .51996 .4689 .52732 .482 .50613 .47477 .49873 Metetra
.895 .781 .728 r
.47477 .49873 .482 .50613 .49504 .4834 .48789 .47592 Metetra
.899 .779 .721 r
.48789 .47592 .49504 .4834 .50801 .45978 .50094 .45219 Metetra
.9 .778 .718 r
.50094 .45219 .50801 .45978 .52088 .43593 .5139 .42821 Metetra
.899 .778 .719 r
.5139 .42821 .52088 .43593 .53366 .41249 .52676 .40466 Metetra
.895 .778 .725 r
.52676 .40466 .53366 .41249 .54636 .39008 .53953 .38217 Metetra
.888 .78 .737 r
.53953 .38217 .54636 .39008 .55898 .36926 .55223 .3613 Metetra
.876 .782 .753 r
.55223 .3613 .55898 .36926 .57156 .3505 .56488 .34255 Metetra
.859 .784 .776 r
.56488 .34255 .57156 .3505 .58413 .33423 .57751 .32634 Metetra
.834 .786 .806 r
.57751 .32634 .58413 .33423 .59673 .32074 .59017 .31299 Metetra
.795 .786 .844 r
.59017 .31299 .59673 .32074 .60939 .31027 .60289 .30273 Metetra
.736 .78 .889 r
.60289 .30273 .60939 .31027 .62216 .30294 .61572 .29567 Metetra
.642 .76 .934 r
.61572 .29567 .62216 .30294 .63507 .29876 .62869 .29184 Metetra
.501 .712 .966 r
.62869 .29184 .63507 .29876 .64817 .29766 .64184 .29113 Metetra
.308 .623 .959 r
.64184 .29113 .64817 .29766 .66148 .29943 .65521 .29335 Metetra
.086 .496 .899 r
.65521 .29335 .66148 .29943 .67504 .30378 .66882 .29818 Metetra
0 .359 .8 r
.66882 .29818 .67504 .30378 .68884 .31033 .68269 .30523 Metetra
0 .244 .695 r
.68269 .30523 .68884 .31033 .70291 .31859 .69681 .31399 Metetra
0 .165 .611 r
.69681 .31399 .70291 .31859 .71721 .32802 .71119 .32392 Metetra
.428 0 0 r
.71119 .32392 .71721 .32802 .73175 .33805 .7258 .33441 Metetra
.448 0 0 r
.7258 .33441 .73175 .33805 .74649 .34811 .7406 .34491 Metetra
.441 0 0 r
.7406 .34491 .74649 .34811 .76138 .35769 .75558 .35492 Metetra
.42 .825 .978 r
.75558 .35492 .76138 .35769 .77598 .361 .76981 .35259 Metetra
.656 .751 .92 r
.76981 .35259 .77598 .361 .79006 .35645 .78394 .348 Metetra
.656 .751 .92 r
.78394 .348 .79006 .35645 .80422 .35189 .79814 .34339 Metetra
.656 .751 .92 r
.79814 .34339 .80422 .35189 .81844 .34729 .81242 .33876 Metetra
.656 .751 .92 r
.81242 .33876 .81844 .34729 .83273 .34268 .82676 .3341 Metetra
.656 .751 .92 r
.82676 .3341 .83273 .34268 .8471 .33804 .84117 .32942 Metetra
.656 .751 .92 r
.20202 .52745 .20993 .53436 .22144 .53063 .21355 .52368 Metetra
.656 .751 .92 r
.21355 .52368 .22144 .53063 .233 .52687 .22515 .5199 Metetra
.656 .751 .92 r
.22515 .5199 .233 .52687 .24462 .5231 .23679 .5161 Metetra
.656 .751 .92 r
.23679 .5161 .24462 .5231 .25628 .51931 .24848 .51228 Metetra
.656 .751 .92 r
.24848 .51228 .25628 .51931 .268 .51551 .26023 .50844 Metetra
.656 .751 .92 r
.26023 .50844 .268 .51551 .27977 .51169 .27203 .50459 Metetra
.22 .558 .935 r
.27203 .50459 .27977 .51169 .29069 .52065 .28338 .50768 Metetra
0 .164 .703 r
.28338 .50768 .29069 .52065 .30163 .53162 .29427 .51889 Metetra
0 .138 .685 r
.29427 .51889 .30163 .53162 .31269 .54302 .30529 .53057 Metetra
0 .143 .688 r
.30529 .53057 .31269 .54302 .32392 .55428 .31648 .54217 Metetra
0 .183 .717 r
.31648 .54217 .32392 .55428 .33536 .56476 .32788 .55303 Metetra
0 .26 .769 r
.32788 .55303 .33536 .56476 .34704 .5738 .33951 .56249 Metetra
.1 .366 .831 r
.33951 .56249 .34704 .5738 .35896 .58075 .35141 .56989 Metetra
.271 .484 .881 r
.35141 .56989 .35896 .58075 .37114 .58504 .36357 .57464 Metetra
.441 .589 .903 r
.36357 .57464 .37114 .58504 .38357 .5862 .37599 .57626 Metetra
.584 .667 .896 r
.37599 .57626 .38357 .5862 .39623 .58389 .38865 .57438 Metetra
.689 .716 .87 r
.38865 .57438 .39623 .58389 .40908 .57794 .40152 .56883 Metetra
.762 .744 .837 r
.40152 .56883 .40908 .57794 .42209 .56835 .41456 .55959 Metetra
.81 .759 .805 r
.41456 .55959 .42209 .56835 .4352 .55526 .42772 .54679 Metetra
.843 .767 .778 r
.42772 .54679 .4352 .55526 .44839 .53899 .44096 .53074 Metetra
.865 .771 .756 r
.44096 .53074 .44839 .53899 .46159 .51996 .45423 .51189 Metetra
.88 .773 .739 r
.45423 .51189 .46159 .51996 .47477 .49873 .46748 .4908 Metetra
.89 .774 .728 r
.46748 .4908 .47477 .49873 .48789 .47592 .48068 .46808 Metetra
.896 .775 .721 r
.48068 .46808 .48789 .47592 .50094 .45219 .49381 .44441 Metetra
.899 .777 .718 r
.49381 .44441 .50094 .45219 .5139 .42821 .50685 .4205 Metetra
.899 .779 .72 r
.50685 .4205 .5139 .42821 .52676 .40466 .51979 .39702 Metetra
.896 .782 .727 r
.51979 .39702 .52676 .40466 .53953 .38217 .53264 .3746 Metetra
.891 .787 .74 r
.53264 .3746 .53953 .38217 .55223 .3613 .54542 .35384 Metetra
.881 .792 .758 r
.54542 .35384 .55223 .3613 .56488 .34255 .55814 .33524 Metetra
.865 .799 .784 r
.55814 .33524 .56488 .34255 .57751 .32634 .57085 .31921 Metetra
.84 .806 .818 r
.57085 .31921 .57751 .32634 .59017 .31299 .58357 .3061 Metetra
.798 .811 .861 r
.58357 .3061 .59017 .31299 .60289 .30273 .59636 .29613 Metetra
.731 .808 .912 r
.59636 .29613 .60289 .30273 .61572 .29567 .60924 .2894 Metetra
.62 .786 .961 r
.60924 .2894 .61572 .29567 .62869 .29184 .62227 .28595 Metetra
.446 .723 .985 r
.62227 .28595 .62869 .29184 .64184 .29113 .63549 .28565 Metetra
.211 .604 .949 r
.63549 .28565 .64184 .29113 .65521 .29335 .64892 .28831 Metetra
0 .445 .847 r
.64892 .28831 .65521 .29335 .66882 .29818 .66259 .2936 Metetra
0 .291 .717 r
.66259 .2936 .66882 .29818 .68269 .30523 .67652 .3011 Metetra
0 .176 .603 r
.67652 .3011 .68269 .30523 .69681 .31399 .69071 .31031 Metetra
.457 0 0 r
.69071 .31031 .69681 .31399 .71119 .32392 .70515 .32065 Metetra
.496 0 0 r
.70515 .32065 .71119 .32392 .7258 .33441 .71982 .33154 Metetra
.506 0 0 r
.71982 .33154 .7258 .33441 .7406 .34491 .7347 .3424 Metetra
.279 0 0 r
.7347 .3424 .7406 .34491 .75558 .35492 .74946 .34871 Metetra
.646 .816 .965 r
.74946 .34871 .75558 .35492 .76981 .35259 .76358 .3441 Metetra
.656 .751 .92 r
.76358 .3441 .76981 .35259 .78394 .348 .77776 .33947 Metetra
.656 .751 .92 r
.77776 .33947 .78394 .348 .79814 .34339 .79201 .33482 Metetra
.656 .751 .92 r
.79201 .33482 .79814 .34339 .81242 .33876 .80634 .33014 Metetra
.656 .751 .92 r
.80634 .33014 .81242 .33876 .82676 .3341 .82073 .32544 Metetra
.656 .751 .92 r
.82073 .32544 .82676 .3341 .84117 .32942 .8352 .32072 Metetra
.656 .751 .92 r
.19403 .52048 .20202 .52745 .21355 .52368 .2056 .51668 Metetra
.656 .751 .92 r
.2056 .51668 .21355 .52368 .22515 .5199 .21722 .51287 Metetra
.656 .751 .92 r
.21722 .51287 .22515 .5199 .23679 .5161 .2289 .50903 Metetra
.656 .751 .92 r
.2289 .50903 .23679 .5161 .24848 .51228 .24062 .50518 Metetra
.656 .751 .92 r
.24062 .50518 .24848 .51228 .26023 .50844 .2524 .50132 Metetra
.656 .751 .92 r
.2524 .50132 .26023 .50844 .27203 .50459 .26423 .49743 Metetra
.636 .746 .928 r
.26423 .49743 .27203 .50459 .28338 .50768 .27608 .49407 Metetra
0 .166 .703 r
.27608 .49407 .28338 .50768 .29427 .51889 .28693 .50543 Metetra
0 .142 .687 r
.28693 .50543 .29427 .51889 .30529 .53057 .29791 .51728 Metetra
0 .147 .691 r
.29791 .51728 .30529 .53057 .31648 .54217 .30905 .5291 Metetra
0 .185 .718 r
.30905 .5291 .31648 .54217 .32788 .55303 .32041 .54025 Metetra
0 .256 .764 r
.32041 .54025 .32788 .55303 .33951 .56249 .332 .55006 Metetra
.12 .354 .817 r
.332 .55006 .33951 .56249 .35141 .56989 .34386 .55785 Metetra
.279 .461 .861 r
.34386 .55785 .35141 .56989 .36357 .57464 .356 .56303 Metetra
.437 .56 .881 r
.356 .56303 .36357 .57464 .37599 .57626 .36841 .56509 Metetra
.571 .636 .877 r
.36841 .56509 .37599 .57626 .38865 .57438 .38107 .56367 Metetra
.673 .687 .855 r
.38107 .56367 .38865 .57438 .40152 .56883 .39395 .55857 Metetra
.746 .719 .827 r
.39395 .55857 .40152 .56883 .41456 .55959 .40701 .54975 Metetra
.796 .739 .799 r
.40701 .54975 .41456 .55959 .42772 .54679 .42021 .53734 Metetra
.831 .751 .775 r
.42021 .53734 .42772 .54679 .44096 .53074 .43349 .52166 Metetra
.856 .758 .754 r
.43349 .52166 .44096 .53074 .45423 .51189 .44682 .50314 Metetra
.872 .763 .739 r
.44682 .50314 .45423 .51189 .46748 .4908 .46014 .48234 Metetra
.884 .767 .728 r
.46014 .48234 .46748 .4908 .48068 .46808 .47342 .45988 Metetra
.892 .771 .722 r
.47342 .45988 .48068 .46808 .49381 .44441 .48662 .43647 Metetra
.896 .776 .72 r
.48662 .43647 .49381 .44441 .50685 .4205 .49974 .41279 Metetra
.898 .781 .723 r
.49974 .41279 .50685 .4205 .51979 .39702 .51276 .38954 Metetra
.897 .787 .731 r
.51276 .38954 .51979 .39702 .53264 .3746 .52569 .36736 Metetra
.893 .794 .744 r
.52569 .36736 .53264 .3746 .54542 .35384 .53855 .34685 Metetra
.884 .803 .764 r
.53855 .34685 .54542 .35384 .55814 .33524 .55135 .32852 Metetra
.869 .814 .793 r
.55135 .32852 .55814 .33524 .57085 .31921 .56413 .31281 Metetra
.843 .826 .831 r
.56413 .31281 .57085 .31921 .58357 .3061 .57693 .30003 Metetra
.798 .835 .88 r
.57693 .30003 .58357 .3061 .59636 .29613 .58978 .29041 Metetra
.72 .835 .936 r
.58978 .29041 .59636 .29613 .60924 .2894 .60273 .28408 Metetra
.585 .807 .984 r
.60273 .28408 .60924 .2894 .62227 .28595 .61583 .28103 Metetra
.372 .722 .988 r
.61583 .28103 .62227 .28595 .63549 .28565 .62911 .28116 Metetra
.1 .566 .911 r
.62911 .28116 .63549 .28565 .64892 .28831 .6426 .28425 Metetra
0 .381 .769 r
.6426 .28425 .64892 .28831 .66259 .2936 .65633 .28996 Metetra
0 .223 .624 r
.65633 .28996 .66259 .2936 .67652 .3011 .67032 .29787 Metetra
.455 0 0 r
.67032 .29787 .67652 .3011 .69071 .31031 .68457 .30746 Metetra
.518 0 0 r
.68457 .30746 .69071 .31031 .70515 .32065 .69907 .31814 Metetra
.545 0 0 r
.69907 .31814 .70515 .32065 .71982 .33154 .71381 .32934 Metetra
.547 0 0 r
.71381 .32934 .71982 .33154 .7347 .3424 .72876 .34047 Metetra
.191 .703 .893 r
.72876 .34047 .7347 .3424 .74946 .34871 .74313 .34018 Metetra
.656 .751 .92 r
.74313 .34018 .74946 .34871 .76358 .3441 .75729 .33553 Metetra
.656 .751 .92 r
.75729 .33553 .76358 .3441 .77776 .33947 .77152 .33086 Metetra
.656 .751 .92 r
.77152 .33086 .77776 .33947 .79201 .33482 .78582 .32617 Metetra
.656 .751 .92 r
.78582 .32617 .79201 .33482 .80634 .33014 .8002 .32145 Metetra
.656 .751 .92 r
.8002 .32145 .80634 .33014 .82073 .32544 .81464 .3167 Metetra
.656 .751 .92 r
.81464 .3167 .82073 .32544 .8352 .32072 .82916 .31194 Metetra
.656 .751 .92 r
.18598 .51346 .19403 .52048 .2056 .51668 .19758 .50962 Metetra
.656 .751 .92 r
.19758 .50962 .2056 .51668 .21722 .51287 .20923 .50578 Metetra
.656 .751 .92 r
.20923 .50578 .21722 .51287 .2289 .50903 .22094 .50191 Metetra
.656 .751 .92 r
.22094 .50191 .2289 .50903 .24062 .50518 .23269 .49803 Metetra
.656 .751 .92 r
.23269 .49803 .24062 .50518 .2524 .50132 .2445 .49413 Metetra
.656 .751 .92 r
.2445 .49413 .2524 .50132 .26423 .49743 .25637 .49021 Metetra
.656 .751 .92 r
.25637 .49021 .26423 .49743 .27608 .49407 .26829 .48628 Metetra
.059 .439 .875 r
.26829 .48628 .27608 .49407 .28693 .50543 .27959 .49133 Metetra
0 .148 .69 r
.27959 .49133 .28693 .50543 .29791 .51728 .29053 .50326 Metetra
0 .153 .694 r
.29053 .50326 .29791 .51728 .30905 .5291 .30164 .51521 Metetra
0 .188 .717 r
.30164 .51521 .30905 .5291 .32041 .54025 .31295 .52655 Metetra
.01 .254 .758 r
.31295 .52655 .32041 .54025 .332 .55006 .32451 .53661 Metetra
.136 .343 .805 r
.32451 .53661 .332 .55006 .34386 .55785 .33633 .54473 Metetra
.284 .442 .843 r
.33633 .54473 .34386 .55785 .356 .56303 .34844 .5503 Metetra
.431 .535 .862 r
.34844 .5503 .356 .56303 .36841 .56509 .36083 .55279 Metetra
.558 .609 .86 r
.36083 .55279 .36841 .56509 .38107 .56367 .37348 .55184 Metetra
.657 .661 .843 r
.37348 .55184 .38107 .56367 .39395 .55857 .38636 .54723 Metetra
.73 .697 .819 r
.38636 .54723 .39395 .55857 .40701 .54975 .39944 .5389 Metetra
.782 .72 .795 r
.39944 .5389 .40701 .54975 .42021 .53734 .41266 .52699 Metetra
.819 .736 .772 r
.41266 .52699 .42021 .53734 .43349 .52166 .42599 .51179 Metetra
.846 .746 .754 r
.42599 .51179 .43349 .52166 .44682 .50314 .43937 .49374 Metetra
.864 .755 .74 r
.43937 .49374 .44682 .50314 .46014 .48234 .45275 .47338 Metetra
.878 .761 .73 r
.45275 .47338 .46014 .48234 .47342 .45988 .46609 .45135 Metetra
.887 .768 .724 r
.46609 .45135 .47342 .45988 .48662 .43647 .47937 .42835 Metetra
.894 .775 .723 r
.47937 .42835 .48662 .43647 .49974 .41279 .49257 .40507 Metetra
.897 .782 .726 r
.49257 .40507 .49974 .41279 .51276 .38954 .50567 .38221 Metetra
.897 .791 .735 r
.50567 .38221 .51276 .38954 .52569 .36736 .51868 .36042 Metetra
.894 .802 .75 r
.51868 .36042 .52569 .36736 .53855 .34685 .53162 .34031 Metetra
.886 .814 .772 r
.53162 .34031 .53855 .34685 .55135 .32852 .5445 .32238 Metetra
.871 .829 .803 r
.5445 .32238 .55135 .32852 .56413 .31281 .55735 .30707 Metetra
.844 .846 .845 r
.55735 .30707 .56413 .31281 .57693 .30003 .57022 .29471 Metetra
.794 .86 .899 r
.57022 .29471 .57693 .30003 .58978 .29041 .58315 .28553 Metetra
.701 .86 .958 r
.58315 .28553 .58978 .29041 .60273 .28408 .59617 .27963 Metetra
.536 .82 .998 r
.59617 .27963 .60273 .28408 .61583 .28103 .60934 .27702 Metetra
.281 .702 .97 r
.60934 .27702 .61583 .28103 .62911 .28116 .62268 .27758 Metetra
0 .51 .845 r
.62268 .27758 .62911 .28116 .6426 .28425 .63624 .28108 Metetra
0 .312 .677 r
.63624 .28108 .6426 .28425 .65633 .28996 .65003 .28718 Metetra
.419 0 0 r
.65003 .28718 .65633 .28996 .67032 .29787 .66408 .29545 Metetra
.512 0 0 r
.66408 .29545 .67032 .29787 .68457 .30746 .6784 .30534 Metetra
.56 0 0 r
.6784 .30534 .68457 .30746 .69907 .31814 .69296 .31629 Metetra
.578 .006 0 r
.69296 .31629 .69907 .31814 .71381 .32934 .70776 .3277 Metetra
.463 0 0 r
.70776 .3277 .71381 .32934 .72876 .34047 .7226 .33625 Metetra
.615 .873 .99 r
.7226 .33625 .72876 .34047 .74313 .34018 .73674 .33158 Metetra
.656 .751 .92 r
.73674 .33158 .74313 .34018 .75729 .33553 .75095 .32689 Metetra
.656 .751 .92 r
.75095 .32689 .75729 .33553 .77152 .33086 .76523 .32217 Metetra
.656 .751 .92 r
.76523 .32217 .77152 .33086 .78582 .32617 .77958 .31743 Metetra
.656 .751 .92 r
.77958 .31743 .78582 .32617 .8002 .32145 .794 .31267 Metetra
.656 .751 .92 r
.794 .31267 .8002 .32145 .81464 .3167 .8085 .30788 Metetra
.656 .751 .92 r
.8085 .30788 .81464 .3167 .82916 .31194 .82307 .30307 Metetra
.656 .751 .92 r
.17786 .50637 .18598 .51346 .19758 .50962 .18949 .50251 Metetra
.656 .751 .92 r
.18949 .50251 .19758 .50962 .20923 .50578 .20118 .49863 Metetra
.656 .751 .92 r
.20118 .49863 .20923 .50578 .22094 .50191 .21291 .49473 Metetra
.656 .751 .92 r
.21291 .49473 .22094 .50191 .23269 .49803 .2247 .49082 Metetra
.656 .751 .92 r
.2247 .49082 .23269 .49803 .2445 .49413 .23654 .48688 Metetra
.656 .751 .92 r
.23654 .48688 .2445 .49413 .25637 .49021 .24844 .48293 Metetra
.656 .751 .92 r
.24844 .48293 .25637 .49021 .26829 .48628 .26039 .47896 Metetra
.586 .73 .943 r
.26039 .47896 .26829 .48628 .27959 .49133 .27226 .47674 Metetra
0 .155 .694 r
.27226 .47674 .27959 .49133 .29053 .50326 .28316 .48864 Metetra
0 .159 .696 r
.28316 .48864 .29053 .50326 .30164 .51521 .29423 .50061 Metetra
0 .192 .717 r
.29423 .50061 .30164 .51521 .31295 .52655 .30551 .51204 Metetra
.03 .252 .753 r
.30551 .51204 .31295 .52655 .32451 .53661 .31702 .52228 Metetra
.148 .334 .794 r
.31702 .52228 .32451 .53661 .33633 .54473 .32881 .53066 Metetra
.286 .426 .828 r
.32881 .53066 .33633 .54473 .34844 .5503 .34089 .53656 Metetra
.423 .513 .846 r
.34089 .53656 .34844 .5503 .36083 .55279 .35325 .53947 Metetra
.544 .585 .846 r
.35325 .53947 .36083 .55279 .37348 .55184 .36588 .53899 Metetra
.641 .639 .832 r
.36588 .53899 .37348 .55184 .38636 .54723 .37876 .5349 Metetra
.714 .677 .812 r
.37876 .5349 .38636 .54723 .39944 .5389 .39185 .52713 Metetra
.768 .703 .791 r
.39185 .52713 .39944 .5389 .41266 .52699 .40509 .5158 Metetra
.807 .722 .771 r
.40509 .5158 .41266 .52699 .42599 .51179 .41845 .50118 Metetra
.835 .736 .754 r
.41845 .50118 .42599 .51179 .43937 .49374 .43187 .48372 Metetra
.856 .746 .741 r
.43187 .48372 .43937 .49374 .45275 .47338 .4453 .46395 Metetra
.871 .756 .732 r
.4453 .46395 .45275 .47338 .46609 .45135 .45871 .4425 Metetra
.882 .765 .728 r
.45871 .4425 .46609 .45135 .47937 .42835 .47206 .42006 Metetra
.89 .774 .727 r
.47206 .42006 .47937 .42835 .49257 .40507 .48533 .39734 Metetra
.895 .784 .731 r
.48533 .39734 .49257 .40507 .50567 .38221 .49851 .37502 Metetra
.896 .795 .741 r
.49851 .37502 .50567 .38221 .51868 .36042 .5116 .35377 Metetra
.894 .809 .757 r
.5116 .35377 .51868 .36042 .53162 .34031 .52462 .33418 Metetra
.887 .825 .781 r
.52462 .33418 .53162 .34031 .5445 .32238 .53758 .31676 Metetra
.872 .844 .814 r
.53758 .31676 .5445 .32238 .55735 .30707 .55051 .30196 Metetra
.842 .865 .86 r
.55051 .30196 .55735 .30707 .57022 .29471 .56346 .2901 Metetra
.784 .882 .917 r
.56346 .2901 .57022 .29471 .58315 .28553 .57646 .28141 Metetra
.673 .88 .975 r
.57646 .28141 .58315 .28553 .59617 .27963 .58956 .27598 Metetra
.472 .82 .998 r
.58956 .27598 .59617 .27963 .60934 .27702 .60279 .27382 Metetra
.179 .664 .926 r
.60279 .27382 .60934 .27702 .62268 .27758 .6162 .27481 Metetra
0 .445 .762 r
.6162 .27481 .62268 .27758 .63624 .28108 .62983 .27871 Metetra
.341 0 0 r
.62983 .27871 .63624 .28108 .65003 .28718 .64369 .28516 Metetra
.475 0 0 r
.64369 .28516 .65003 .28718 .66408 .29545 .6578 .29372 Metetra
.55 0 0 r
.6578 .29372 .66408 .29545 .6784 .30534 .67217 .30385 Metetra
.587 .014 0 r
.67217 .30385 .6784 .30534 .69296 .31629 .68679 .31498 Metetra
.598 .027 0 r
.68679 .31498 .69296 .31629 .70776 .3277 .70165 .32652 Metetra
.006 .576 .776 r
.70165 .32652 .70776 .3277 .7226 .33625 .71609 .32761 Metetra
.656 .751 .92 r
.71609 .32761 .7226 .33625 .73674 .33158 .73028 .3229 Metetra
.656 .751 .92 r
.73028 .3229 .73674 .33158 .75095 .32689 .74454 .31816 Metetra
.656 .751 .92 r
.74454 .31816 .75095 .32689 .76523 .32217 .75887 .3134 Metetra
.656 .751 .92 r
.75887 .3134 .76523 .32217 .77958 .31743 .77328 .30862 Metetra
.656 .751 .92 r
.77328 .30862 .77958 .31743 .794 .31267 .78775 .30381 Metetra
.656 .751 .92 r
.78775 .30381 .794 .31267 .8085 .30788 .8023 .29898 Metetra
.656 .751 .92 r
.8023 .29898 .8085 .30788 .82307 .30307 .81693 .29412 Metetra
.656 .751 .92 r
.16968 .49923 .17786 .50637 .18949 .50251 .18134 .49533 Metetra
.656 .751 .92 r
.18134 .49533 .18949 .50251 .20118 .49863 .19305 .49142 Metetra
.656 .751 .92 r
.19305 .49142 .20118 .49863 .21291 .49473 .20482 .48749 Metetra
.656 .751 .92 r
.20482 .48749 .21291 .49473 .2247 .49082 .21664 .48354 Metetra
.656 .751 .92 r
.21664 .48354 .2247 .49082 .23654 .48688 .22851 .47957 Metetra
.656 .751 .92 r
.22851 .47957 .23654 .48688 .24844 .48293 .24044 .47559 Metetra
.656 .751 .92 r
.24044 .47559 .24844 .48293 .26039 .47896 .25242 .47159 Metetra
.656 .751 .92 r
.25242 .47159 .26039 .47896 .27226 .47674 .26446 .46757 Metetra
.051 .395 .853 r
.26446 .46757 .27226 .47674 .28316 .48864 .27579 .47355 Metetra
0 .167 .7 r
.27579 .47355 .28316 .48864 .29423 .50061 .28683 .48544 Metetra
0 .197 .718 r
.28683 .48544 .29423 .50061 .30551 .51204 .29807 .49688 Metetra
.047 .252 .749 r
.29807 .49688 .30551 .51204 .31702 .52228 .30955 .5072 Metetra
.158 .328 .785 r
.30955 .5072 .31702 .52228 .32881 .53066 .3213 .51577 Metetra
.286 .413 .816 r
.3213 .51577 .32881 .53066 .34089 .53656 .33335 .52196 Metetra
.416 .495 .832 r
.33335 .52196 .34089 .53656 .35325 .53947 .34568 .52525 Metetra
.531 .564 .834 r
.34568 .52525 .35325 .53947 .36588 .53899 .35829 .52524 Metetra
.626 .619 .824 r
.35829 .52524 .36588 .53899 .37876 .5349 .37116 .52168 Metetra
.698 .659 .807 r
.37116 .52168 .37876 .5349 .39185 .52713 .38424 .51451 Metetra
.753 .688 .788 r
.38424 .51451 .39185 .52713 .40509 .5158 .3975 .50383 Metetra
.794 .709 .771 r
.3975 .50383 .40509 .5158 .41845 .50118 .41088 .48991 Metetra
.824 .726 .756 r
.41088 .48991 .41845 .50118 .43187 .48372 .42433 .47314 Metetra
.847 .739 .744 r
.42433 .47314 .43187 .48372 .4453 .46395 .43781 .45408 Metetra
.864 .751 .736 r
.43781 .45408 .4453 .46395 .45871 .4425 .45127 .43335 Metetra
.877 .762 .732 r
.45127 .43335 .45871 .4425 .47206 .42006 .46469 .41162 Metetra
.886 .773 .732 r
.46469 .41162 .47206 .42006 .48533 .39734 .47803 .38959 Metetra
.892 .786 .737 r
.47803 .38959 .48533 .39734 .49851 .37502 .49128 .36795 Metetra
.895 .8 .748 r
.49128 .36795 .49851 .37502 .5116 .35377 .50445 .34736 Metetra
.893 .816 .765 r
.50445 .34736 .5116 .35377 .52462 .33418 .51755 .32841 Metetra
.886 .836 .791 r
.51755 .32841 .52462 .33418 .53758 .31676 .53059 .31162 Metetra
.87 .859 .827 r
.53059 .31162 .53758 .31676 .55051 .30196 .5436 .29741 Metetra
.836 .884 .876 r
.5436 .29741 .55051 .30196 .56346 .2901 .55663 .28612 Metetra
.768 .902 .935 r
.55663 .28612 .56346 .2901 .57646 .28141 .56971 .27796 Metetra
.633 .891 .986 r
.56971 .27796 .57646 .28141 .58956 .27598 .58288 .27305 Metetra
.395 .803 .98 r
.58288 .27305 .58956 .27598 .60279 .27382 .59619 .27136 Metetra
.077 .611 .863 r
.59619 .27136 .60279 .27382 .6162 .27481 .60967 .27276 Metetra
0 .381 .677 r
.60967 .27276 .6162 .27481 .62983 .27871 .62336 .27702 Metetra
.401 0 0 r
.62336 .27702 .62983 .27871 .64369 .28516 .63728 .28378 Metetra
.513 0 0 r
.63728 .28378 .64369 .28516 .6578 .29372 .65145 .29257 Metetra
.574 0 0 r
.65145 .29257 .6578 .29372 .67217 .30385 .66588 .30286 Metetra
.602 .032 0 r
.66588 .30286 .67217 .30385 .68679 .31498 .68056 .31409 Metetra
.54 0 0 r
.68056 .31409 .68679 .31498 .70165 .32652 .69537 .32363 Metetra
.572 .897 .985 r
.69537 .32363 .70165 .32652 .71609 .32761 .70953 .31889 Metetra
.656 .751 .92 r
.70953 .31889 .71609 .32761 .73028 .3229 .72377 .31414 Metetra
.656 .751 .92 r
.72377 .31414 .73028 .3229 .74454 .31816 .73808 .30936 Metetra
.656 .751 .92 r
.73808 .30936 .74454 .31816 .75887 .3134 .75246 .30455 Metetra
.656 .751 .92 r
.75246 .30455 .75887 .3134 .77328 .30862 .76692 .29973 Metetra
.656 .751 .92 r
.76692 .29973 .77328 .30862 .78775 .30381 .78144 .29487 Metetra
.656 .751 .92 r
.78144 .29487 .78775 .30381 .8023 .29898 .79605 .29 Metetra
.656 .751 .92 r
.79605 .29 .8023 .29898 .81693 .29412 .81072 .28509 Metetra
.656 .751 .92 r
.16143 .49202 .16968 .49923 .18134 .49533 .17312 .48809 Metetra
.656 .751 .92 r
.17312 .48809 .18134 .49533 .19305 .49142 .18486 .48415 Metetra
.656 .751 .92 r
.18486 .48415 .19305 .49142 .20482 .48749 .19665 .48019 Metetra
.656 .751 .92 r
.19665 .48019 .20482 .48749 .21664 .48354 .20851 .4762 Metetra
.656 .751 .92 r
.20851 .4762 .21664 .48354 .22851 .47957 .22041 .4722 Metetra
.656 .751 .92 r
.22041 .4722 .22851 .47957 .24044 .47559 .23237 .46819 Metetra
.656 .751 .92 r
.23237 .46819 .24044 .47559 .25242 .47159 .24439 .46415 Metetra
.656 .751 .92 r
.24439 .46415 .25242 .47159 .26446 .46757 .25646 .46009 Metetra
.57 .724 .946 r
.25646 .46009 .26446 .46757 .27579 .47355 .26842 .45815 Metetra
0 .176 .704 r
.26842 .45815 .27579 .47355 .28683 .48544 .27943 .46986 Metetra
0 .203 .72 r
.27943 .46986 .28683 .48544 .29807 .49688 .29064 .4812 Metetra
.061 .254 .747 r
.29064 .4812 .29807 .49688 .30955 .5072 .30209 .49153 Metetra
.165 .323 .779 r
.30209 .49153 .30955 .5072 .3213 .51577 .3138 .50021 Metetra
.286 .402 .806 r
.3138 .50021 .3213 .51577 .33335 .52196 .32581 .50662 Metetra
.408 .479 .822 r
.32581 .50662 .33335 .52196 .34568 .52525 .33811 .51025 Metetra
.518 .547 .825 r
.33811 .51025 .34568 .52525 .35829 .52524 .35069 .5107 Metetra
.61 .601 .817 r
.35069 .5107 .35829 .52524 .37116 .52168 .36354 .50769 Metetra
.683 .642 .803 r
.36354 .50769 .37116 .52168 .38424 .51451 .37662 .50116 Metetra
.739 .674 .787 r
.37662 .50116 .38424 .51451 .3975 .50383 .38988 .49119 Metetra
.781 .697 .772 r
.38988 .49119 .3975 .50383 .41088 .48991 .40327 .47802 Metetra
.813 .716 .758 r
.40327 .47802 .41088 .48991 .42433 .47314 .41675 .46206 Metetra
.838 .732 .748 r
.41675 .46206 .42433 .47314 .43781 .45408 .43027 .44383 Metetra
.856 .746 .74 r
.43027 .44383 .43781 .45408 .45127 .43335 .44378 .42393 Metetra
.87 .759 .737 r
.44378 .42393 .45127 .43335 .46469 .41162 .45725 .40303 Metetra
.881 .773 .738 r
.45725 .40303 .46469 .41162 .47803 .38959 .47066 .38182 Metetra
.888 .788 .744 r
.47066 .38182 .47803 .38959 .49128 .36795 .48398 .36098 Metetra
.892 .804 .756 r
.48398 .36098 .49128 .36795 .50445 .34736 .49723 .34117 Metetra
.891 .824 .775 r
.49723 .34117 .50445 .34736 .51755 .32841 .5104 .32296 Metetra
.884 .847 .802 r
.5104 .32296 .51755 .32841 .53059 .31162 .52352 .30688 Metetra
.866 .873 .841 r
.52352 .30688 .53059 .31162 .5436 .29741 .53662 .29335 Metetra
.826 .9 .893 r
.53662 .29335 .5436 .29741 .55663 .28612 .54973 .28269 Metetra
.744 .917 .95 r
.54973 .28269 .55663 .28612 .56971 .27796 .56288 .27512 Metetra
.582 .892 .989 r
.56288 .27512 .56971 .27796 .58288 .27305 .57613 .27073 Metetra
.309 .771 .946 r
.57613 .27073 .58288 .27305 .59619 .27136 .58951 .26951 Metetra
0 .551 .792 r
.58951 .26951 .59619 .27136 .60967 .27276 .60306 .27132 Metetra
.277 0 0 r
.60306 .27132 .60967 .27276 .62336 .27702 .61682 .2759 Metetra
.442 0 0 r
.61682 .2759 .62336 .27702 .63728 .28378 .6308 .28291 Metetra
.537 0 0 r
.6308 .28291 .63728 .28378 .65145 .29257 .64504 .29186 Metetra
.588 .013 0 r
.64504 .29186 .65145 .29257 .66588 .30286 .65952 .30224 Metetra
.61 .04 0 r
.65952 .30224 .66588 .30286 .68056 .31409 .67426 .31347 Metetra
0 .519 .704 r
.67426 .31347 .68056 .31409 .69537 .32363 .6887 .31487 Metetra
.656 .751 .92 r
.6887 .31487 .69537 .32363 .70953 .31889 .70291 .3101 Metetra
.656 .751 .92 r
.70291 .3101 .70953 .31889 .72377 .31414 .7172 .3053 Metetra
.656 .751 .92 r
.7172 .3053 .72377 .31414 .73808 .30936 .73156 .30047 Metetra
.656 .751 .92 r
.73156 .30047 .73808 .30936 .75246 .30455 .74599 .29562 Metetra
.656 .751 .92 r
.74599 .29562 .75246 .30455 .76692 .29973 .7605 .29075 Metetra
.656 .751 .92 r
.7605 .29075 .76692 .29973 .78144 .29487 .77508 .28585 Metetra
.656 .751 .92 r
.77508 .28585 .78144 .29487 .79605 .29 .78973 .28093 Metetra
.656 .751 .92 r
.78973 .28093 .79605 .29 .81072 .28509 .80446 .27598 Metetra
.656 .751 .92 r
.1531 .48476 .16143 .49202 .17312 .48809 .16482 .4808 Metetra
.656 .751 .92 r
.16482 .4808 .17312 .48809 .18486 .48415 .1766 .47682 Metetra
.656 .751 .92 r
.1766 .47682 .18486 .48415 .19665 .48019 .18842 .47282 Metetra
.656 .751 .92 r
.18842 .47282 .19665 .48019 .20851 .4762 .20031 .46881 Metetra
.656 .751 .92 r
.20031 .46881 .20851 .4762 .22041 .4722 .21224 .46477 Metetra
.656 .751 .92 r
.21224 .46477 .22041 .4722 .23237 .46819 .22423 .46072 Metetra
.656 .751 .92 r
.22423 .46072 .23237 .46819 .24439 .46415 .23628 .45665 Metetra
.656 .751 .92 r
.23628 .45665 .24439 .46415 .25646 .46009 .24839 .45256 Metetra
.656 .751 .92 r
.24839 .45256 .25646 .46009 .26842 .45815 .26055 .44845 Metetra
.111 .423 .868 r
.26055 .44845 .26842 .45815 .27943 .46986 .27201 .45401 Metetra
.002 .21 .723 r
.27201 .45401 .27943 .46986 .29064 .4812 .2832 .46516 Metetra
.073 .256 .746 r
.2832 .46516 .29064 .4812 .30209 .49153 .29462 .47541 Metetra
.171 .32 .774 r
.29462 .47541 .30209 .49153 .3138 .50021 .3063 .48412 Metetra
.284 .394 .799 r
.3063 .48412 .3138 .50021 .32581 .50662 .31827 .4907 Metetra
.4 .467 .814 r
.31827 .4907 .32581 .50662 .33811 .51025 .33054 .49463 Metetra
.506 .532 .817 r
.33054 .49463 .33811 .51025 .35069 .5107 .34309 .4955 Metetra
.595 .585 .812 r
.34309 .4955 .35069 .5107 .36354 .50769 .35592 .49305 Metetra
.668 .628 .8 r
.35592 .49305 .36354 .50769 .37662 .50116 .36898 .48718 Metetra
.724 .661 .787 r
.36898 .48718 .37662 .50116 .38988 .49119 .38223 .47796 Metetra
.768 .687 .773 r
.38223 .47796 .38988 .49119 .40327 .47802 .39564 .46562 Metetra
.802 .708 .761 r
.39564 .46562 .40327 .47802 .41675 .46206 .40914 .45054 Metetra
.828 .725 .752 r
.40914 .45054 .41675 .46206 .43027 .44383 .42268 .43322 Metetra
.848 .741 .746 r
.42268 .43322 .43027 .44383 .44378 .42393 .43623 .41425 Metetra
.863 .757 .743 r
.43623 .41425 .44378 .42393 .45725 .40303 .44975 .39429 Metetra
.875 .773 .745 r
.44975 .39429 .45725 .40303 .47066 .38182 .46322 .37401 Metetra
.883 .79 .752 r
.46322 .37401 .47066 .38182 .48398 .36098 .47661 .35409 Metetra
.888 .809 .765 r
.47661 .35409 .48398 .36098 .49723 .34117 .48993 .33515 Metetra
.887 .831 .786 r
.48993 .33515 .49723 .34117 .5104 .32296 .50318 .31778 Metetra
.879 .857 .815 r
.50318 .31778 .5104 .32296 .52352 .30688 .51638 .3025 Metetra
.858 .886 .857 r
.51638 .3025 .52352 .30688 .53662 .29335 .52955 .2897 Metetra
.811 .915 .909 r
.52955 .2897 .53662 .29335 .54973 .28269 .54274 .27972 Metetra
.713 .927 .963 r
.54274 .27972 .54973 .28269 .56288 .27512 .55597 .27276 Metetra
.521 .881 .981 r
.55597 .27276 .56288 .27512 .57613 .27073 .5693 .26892 Metetra
.224 .728 .901 r
.5693 .26892 .57613 .27073 .58951 .26951 .58275 .26816 Metetra
0 .494 .723 r
.58275 .26816 .58951 .26951 .60306 .27132 .59637 .27035 Metetra
.326 0 0 r
.59637 .27035 .60306 .27132 .61682 .2759 .6102 .27523 Metetra
.469 0 0 r
.6102 .27523 .61682 .2759 .6308 .28291 .62425 .28242 Metetra
.55 0 0 r
.62425 .28242 .6308 .28291 .64504 .29186 .63854 .29147 Metetra
.593 .019 0 r
.63854 .29147 .64504 .29186 .65952 .30224 .65308 .30185 Metetra
.537 0 0 r
.65308 .30185 .65952 .30224 .67426 .31347 .66777 .31083 Metetra
.563 .9 .98 r
.66777 .31083 .67426 .31347 .6887 .31487 .68196 .30604 Metetra
.656 .751 .92 r
.68196 .30604 .6887 .31487 .70291 .3101 .69623 .30121 Metetra
.656 .751 .92 r
.69623 .30121 .70291 .3101 .7172 .3053 .71057 .29637 Metetra
.656 .751 .92 r
.71057 .29637 .7172 .3053 .73156 .30047 .72498 .2915 Metetra
.656 .751 .92 r
.72498 .2915 .73156 .30047 .74599 .29562 .73946 .28661 Metetra
.656 .751 .92 r
.73946 .28661 .74599 .29562 .7605 .29075 .75402 .28169 Metetra
.656 .751 .92 r
.75402 .28169 .7605 .29075 .77508 .28585 .76865 .27674 Metetra
.656 .751 .92 r
.76865 .27674 .77508 .28585 .78973 .28093 .78335 .27177 Metetra
.656 .751 .92 r
.78335 .27177 .78973 .28093 .80446 .27598 .79814 .26678 Metetra
.656 .751 .92 r
.14471 .47743 .1531 .48476 .16482 .4808 .15646 .47344 Metetra
.656 .751 .92 r
.15646 .47344 .16482 .4808 .1766 .47682 .16826 .46942 Metetra
.656 .751 .92 r
.16826 .46942 .1766 .47682 .18842 .47282 .18012 .46539 Metetra
.656 .751 .92 r
.18012 .46539 .18842 .47282 .20031 .46881 .19204 .46134 Metetra
.656 .751 .92 r
.19204 .46134 .20031 .46881 .21224 .46477 .204 .45728 Metetra
.656 .751 .92 r
.204 .45728 .21224 .46477 .22423 .46072 .21603 .45319 Metetra
.656 .751 .92 r
.21603 .45319 .22423 .46072 .23628 .45665 .22811 .44908 Metetra
.656 .751 .92 r
.22811 .44908 .23628 .45665 .24839 .45256 .24025 .44496 Metetra
.656 .751 .92 r
.24025 .44496 .24839 .45256 .26055 .44845 .25244 .44081 Metetra
.603 .736 .938 r
.25244 .44081 .26055 .44845 .27201 .45401 .26458 .43805 Metetra
.017 .219 .727 r
.26458 .43805 .27201 .45401 .2832 .46516 .27574 .44892 Metetra
.084 .261 .747 r
.27574 .44892 .2832 .46516 .29462 .47541 .28714 .45899 Metetra
.176 .32 .772 r
.28714 .45899 .29462 .47541 .3063 .48412 .29879 .46767 Metetra
.282 .388 .794 r
.29879 .46767 .3063 .48412 .31827 .4907 .31073 .47435 Metetra
.392 .456 .808 r
.31073 .47435 .31827 .4907 .33054 .49463 .32296 .47853 Metetra
.493 .519 .812 r
.32296 .47853 .33054 .49463 .34309 .4955 .33548 .4798 Metetra
.581 .572 .808 r
.33548 .4798 .34309 .4955 .35592 .49305 .34828 .47789 Metetra
.653 .615 .799 r
.34828 .47789 .35592 .49305 .36898 .48718 .36132 .47268 Metetra
.71 .649 .787 r
.36132 .47268 .36898 .48718 .38223 .47796 .37457 .46424 Metetra
.755 .677 .775 r
.37457 .46424 .38223 .47796 .39564 .46562 .38797 .45277 Metetra
.79 .7 .765 r
.38797 .45277 .39564 .46562 .40914 .45054 .40148 .43863 Metetra
.817 .719 .757 r
.40148 .43863 .40914 .45054 .42268 .43322 .41505 .4223 Metetra
.839 .737 .752 r
.41505 .4223 .42268 .43322 .43623 .41425 .42863 .40436 Metetra
.856 .755 .751 r
.42863 .40436 .43623 .41425 .44975 .39429 .44219 .38543 Metetra
.868 .772 .754 r
.44219 .38543 .44975 .39429 .46322 .37401 .45571 .36617 Metetra
.877 .792 .762 r
.45571 .36617 .46322 .37401 .47661 .35409 .46916 .34725 Metetra
.882 .813 .776 r
.46916 .34725 .47661 .35409 .48993 .33515 .48255 .32927 Metetra
.881 .838 .798 r
.48255 .32927 .48993 .33515 .50318 .31778 .49587 .31282 Metetra
.872 .866 .83 r
.49587 .31282 .50318 .31778 .51638 .3025 .50915 .29839 Metetra
.847 .897 .873 r
.50915 .29839 .51638 .3025 .52955 .2897 .5224 .28639 Metetra
.791 .925 .925 r
.5224 .28639 .52955 .2897 .54274 .27972 .53567 .27713 Metetra
.674 .929 .971 r
.53567 .27713 .54274 .27972 .55597 .27276 .54898 .2708 Metetra
.456 .86 .965 r
.54898 .2708 .55597 .27276 .5693 .26892 .56238 .26751 Metetra
.146 .68 .853 r
.56238 .26751 .5693 .26892 .58275 .26816 .57591 .2672 Metetra
.151 0 0 r
.57591 .2672 .58275 .26816 .59637 .27035 .5896 .26974 Metetra
.359 0 0 r
.5896 .26974 .59637 .27035 .6102 .27523 .60349 .27485 Metetra
.485 0 0 r
.60349 .27485 .6102 .27523 .62425 .28242 .6176 .28217 Metetra
.555 0 0 r
.6176 .28217 .62425 .28242 .63854 .29147 .63195 .29124 Metetra
.592 .018 0 r
.63195 .29124 .63854 .29147 .65308 .30185 .64655 .30153 Metetra
0 .567 .719 r
.64655 .30153 .65308 .30185 .66777 .31083 .66092 .30196 Metetra
.656 .751 .92 r
.66092 .30196 .66777 .31083 .68196 .30604 .67517 .29712 Metetra
.656 .751 .92 r
.67517 .29712 .68196 .30604 .69623 .30121 .68948 .29225 Metetra
.656 .751 .92 r
.68948 .29225 .69623 .30121 .71057 .29637 .70387 .28736 Metetra
.656 .751 .92 r
.70387 .28736 .71057 .29637 .72498 .2915 .71833 .28244 Metetra
.656 .751 .92 r
.71833 .28244 .72498 .2915 .73946 .28661 .73286 .2775 Metetra
.656 .751 .92 r
.73286 .2775 .73946 .28661 .75402 .28169 .74747 .27254 Metetra
.656 .751 .92 r
.74747 .27254 .75402 .28169 .76865 .27674 .76216 .26755 Metetra
.656 .751 .92 r
.76216 .26755 .76865 .27674 .78335 .27177 .77692 .26253 Metetra
.656 .751 .92 r
.77692 .26253 .78335 .27177 .79814 .26678 .79175 .25749 Metetra
.656 .751 .92 r
.13624 .47004 .14471 .47743 .15646 .47344 .14803 .46602 Metetra
.656 .751 .92 r
.14803 .46602 .15646 .47344 .16826 .46942 .15986 .46197 Metetra
.656 .751 .92 r
.15986 .46197 .16826 .46942 .18012 .46539 .17175 .4579 Metetra
.656 .751 .92 r
.17175 .4579 .18012 .46539 .19204 .46134 .1837 .45382 Metetra
.656 .751 .92 r
.1837 .45382 .19204 .46134 .204 .45728 .1957 .44971 Metetra
.656 .751 .92 r
.1957 .44971 .204 .45728 .21603 .45319 .20775 .44559 Metetra
.656 .751 .92 r
.20775 .44559 .21603 .45319 .22811 .44908 .21987 .44145 Metetra
.656 .751 .92 r
.21987 .44145 .22811 .44908 .24025 .44496 .23204 .43729 Metetra
.656 .751 .92 r
.23204 .43729 .24025 .44496 .25244 .44081 .24426 .43311 Metetra
.656 .751 .92 r
.24426 .43311 .25244 .44081 .26458 .43805 .25655 .42891 Metetra
.232 .518 .913 r
.25655 .42891 .26458 .43805 .27574 .44892 .26826 .43262 Metetra
.094 .268 .75 r
.26826 .43262 .27574 .44892 .28714 .45899 .27964 .44244 Metetra
.18 .321 .771 r
.27964 .44244 .28714 .45899 .29879 .46767 .29127 .451 Metetra
.28 .384 .791 r
.29127 .451 .29879 .46767 .31073 .47435 .30317 .45772 Metetra
.384 .448 .804 r
.30317 .45772 .31073 .47435 .32296 .47853 .31537 .46209 Metetra
.481 .508 .809 r
.31537 .46209 .32296 .47853 .33548 .4798 .32786 .46372 Metetra
.567 .56 .806 r
.32786 .46372 .33548 .4798 .34828 .47789 .34063 .46232 Metetra
.638 .604 .799 r
.34063 .46232 .34828 .47789 .36132 .47268 .35365 .45778 Metetra
.695 .639 .789 r
.35365 .45778 .36132 .47268 .37457 .46424 .36687 .45012 Metetra
.741 .668 .779 r
.36687 .45012 .37457 .46424 .38797 .45277 .38027 .43955 Metetra
.777 .692 .77 r
.38027 .43955 .38797 .45277 .40148 .43863 .39378 .4264 Metetra
.806 .714 .763 r
.39378 .4264 .40148 .43863 .41505 .4223 .40736 .41113 Metetra
.829 .733 .759 r
.40736 .41113 .41505 .4223 .42863 .40436 .42097 .39427 Metetra
.847 .753 .759 r
.42097 .39427 .42863 .40436 .44219 .38543 .43457 .37644 Metetra
.861 .772 .763 r
.43457 .37644 .44219 .38543 .45571 .36617 .44813 .35829 Metetra
.87 .793 .772 r
.44813 .35829 .45571 .36617 .46916 .34725 .46164 .34043 Metetra
.875 .817 .788 r
.46164 .34043 .46916 .34725 .48255 .32927 .47509 .32349 Metetra
.874 .844 .812 r
.47509 .32349 .48255 .32927 .49587 .31282 .48848 .30802 Metetra
.863 .874 .845 r
.48848 .30802 .49587 .31282 .50915 .29839 .50183 .2945 Metetra
.833 .907 .889 r
.50183 .2945 .50915 .29839 .5224 .28639 .51516 .28333 Metetra
.766 .932 .94 r
.51516 .28333 .5224 .28639 .53567 .27713 .5285 .27481 Metetra
.63 .924 .975 r
.5285 .27481 .53567 .27713 .54898 .2708 .54189 .26913 Metetra
.39 .832 .944 r
.54189 .26913 .54898 .2708 .56238 .26751 .55537 .26637 Metetra
.08 .635 .808 r
.55537 .26637 .56238 .26751 .57591 .2672 .56897 .2665 Metetra
.194 0 0 r
.56897 .2665 .57591 .2672 .5896 .26974 .58274 .26934 Metetra
.38 0 0 r
.58274 .26934 .5896 .26974 .60349 .27485 .59669 .27464 Metetra
.491 0 0 r
.59669 .27464 .60349 .27485 .6176 .28217 .61087 .28202 Metetra
.553 0 0 r
.61087 .28202 .6176 .28217 .63195 .29124 .62527 .29102 Metetra
.453 0 0 r
.62527 .29102 .63195 .29124 .64655 .30153 .6398 .29786 Metetra
.6 .888 .99 r
.6398 .29786 .64655 .30153 .66092 .30196 .65402 .293 Metetra
.656 .751 .92 r
.65402 .293 .66092 .30196 .67517 .29712 .66831 .28811 Metetra
.656 .751 .92 r
.66831 .28811 .67517 .29712 .68948 .29225 .68267 .2832 Metetra
.656 .751 .92 r
.68267 .2832 .68948 .29225 .70387 .28736 .69711 .27827 Metetra
.656 .751 .92 r
.69711 .27827 .70387 .28736 .71833 .28244 .71162 .2733 Metetra
.656 .751 .92 r
.71162 .2733 .71833 .28244 .73286 .2775 .72621 .26832 Metetra
.656 .751 .92 r
.72621 .26832 .73286 .2775 .74747 .27254 .74087 .2633 Metetra
.656 .751 .92 r
.74087 .2633 .74747 .27254 .76216 .26755 .75561 .25826 Metetra
.656 .751 .92 r
.75561 .25826 .76216 .26755 .77692 .26253 .77042 .2532 Metetra
.656 .751 .92 r
.77042 .2532 .77692 .26253 .79175 .25749 .78531 .24811 Metetra
.656 .751 .92 r
.12771 .46259 .13624 .47004 .14803 .46602 .13952 .45853 Metetra
.656 .751 .92 r
.13952 .45853 .14803 .46602 .15986 .46197 .15139 .45445 Metetra
.656 .751 .92 r
.15139 .45445 .15986 .46197 .17175 .4579 .16331 .45035 Metetra
.656 .751 .92 r
.16331 .45035 .17175 .4579 .1837 .45382 .17528 .44623 Metetra
.656 .751 .92 r
.17528 .44623 .1837 .45382 .1957 .44971 .18732 .44209 Metetra
.656 .751 .92 r
.18732 .44209 .1957 .44971 .20775 .44559 .19941 .43793 Metetra
.656 .751 .92 r
.19941 .43793 .20775 .44559 .21987 .44145 .21155 .43375 Metetra
.656 .751 .92 r
.21155 .43375 .21987 .44145 .23204 .43729 .22375 .42956 Metetra
.656 .751 .92 r
.22375 .42956 .23204 .43729 .24426 .43311 .23602 .42534 Metetra
.656 .751 .92 r
.23602 .42534 .24426 .43311 .25655 .42891 .24833 .4211 Metetra
.656 .751 .92 r
.24833 .4211 .25655 .42891 .26826 .43262 .26071 .41684 Metetra
.114 .291 .765 r
.26071 .41684 .26826 .43262 .27964 .44244 .27211 .4259 Metetra
.184 .324 .773 r
.27211 .4259 .27964 .44244 .29127 .451 .28372 .43426 Metetra
.278 .382 .79 r
.28372 .43426 .29127 .451 .30317 .45772 .2956 .44095 Metetra
.376 .443 .802 r
.2956 .44095 .30317 .45772 .31537 .46209 .30777 .44546 Metetra
.47 .5 .807 r
.30777 .44546 .31537 .46209 .32786 .46372 .32022 .44739 Metetra
.553 .551 .806 r
.32022 .44739 .32786 .46372 .34063 .46232 .33296 .44648 Metetra
.623 .594 .8 r
.33296 .44648 .34063 .46232 .35365 .45778 .34594 .44258 Metetra
.681 .63 .792 r
.34594 .44258 .35365 .45778 .36687 .45012 .35915 .43572 Metetra
.727 .66 .783 r
.35915 .43572 .36687 .45012 .38027 .43955 .37253 .42606 Metetra
.765 .686 .775 r
.37253 .42606 .38027 .43955 .39378 .4264 .38604 .41393 Metetra
.795 .709 .77 r
.38604 .41393 .39378 .4264 .40736 .41113 .39962 .39974 Metetra
.818 .73 .767 r
.39962 .39974 .40736 .41113 .42097 .39427 .41325 .38402 Metetra
.837 .751 .768 r
.41325 .38402 .42097 .39427 .43457 .37644 .42688 .36735 Metetra
.852 .772 .773 r
.42688 .36735 .43457 .37644 .44813 .35829 .44048 .35035 Metetra
.862 .795 .784 r
.44048 .35035 .44813 .35829 .46164 .34043 .45404 .33362 Metetra
.867 .82 .801 r
.45404 .33362 .46164 .34043 .47509 .32349 .46755 .31777 Metetra
.864 .849 .826 r
.46755 .31777 .47509 .32349 .48848 .30802 .481 .30332 Metetra
.85 .881 .862 r
.481 .30332 .48848 .30802 .50183 .2945 .49442 .29074 Metetra
.814 .913 .906 r
.49442 .29074 .50183 .2945 .51516 .28333 .50783 .28043 Metetra
.736 .934 .953 r
.50783 .28043 .51516 .28333 .5285 .27481 .52125 .27267 Metetra
.582 .912 .975 r
.52125 .27267 .5285 .27481 .54189 .26913 .53471 .26764 Metetra
.329 .8 .921 r
.53471 .26764 .54189 .26913 .55537 .26637 .54826 .2654 Metetra
.028 .596 .773 r
.54826 .2654 .55537 .26637 .56897 .2665 .56194 .26592 Metetra
.223 0 0 r
.56194 .26592 .56897 .2665 .58274 .26934 .57577 .26903 Metetra
.389 0 0 r
.57577 .26903 .58274 .26934 .59669 .27464 .58979 .27445 Metetra
.488 0 0 r
.58979 .27445 .59669 .27464 .61087 .28202 .60403 .28182 Metetra
.544 0 0 r
.60403 .28182 .61087 .28202 .62527 .29102 .61849 .29068 Metetra
.184 .717 .813 r
.61849 .29068 .62527 .29102 .6398 .29786 .63277 .28887 Metetra
.656 .751 .92 r
.63277 .28887 .6398 .29786 .65402 .293 .64704 .28396 Metetra
.656 .751 .92 r
.64704 .28396 .65402 .293 .66831 .28811 .66138 .27903 Metetra
.656 .751 .92 r
.66138 .27903 .66831 .28811 .68267 .2832 .6758 .27407 Metetra
.656 .751 .92 r
.6758 .27407 .68267 .2832 .69711 .27827 .69029 .26909 Metetra
.656 .751 .92 r
.69029 .26909 .69711 .27827 .71162 .2733 .70485 .26408 Metetra
.656 .751 .92 r
.70485 .26408 .71162 .2733 .72621 .26832 .71949 .25904 Metetra
.656 .751 .92 r
.71949 .25904 .72621 .26832 .74087 .2633 .7342 .25398 Metetra
.656 .751 .92 r
.7342 .25398 .74087 .2633 .75561 .25826 .74899 .24889 Metetra
.656 .751 .92 r
.74899 .24889 .75561 .25826 .77042 .2532 .76386 .24378 Metetra
.656 .751 .92 r
.76386 .24378 .77042 .2532 .78531 .24811 .7788 .23864 Metetra
.656 .751 .92 r
.1191 .45508 .12771 .46259 .13952 .45853 .13094 .45098 Metetra
.656 .751 .92 r
.13094 .45098 .13952 .45853 .15139 .45445 .14284 .44686 Metetra
.656 .751 .92 r
.14284 .44686 .15139 .45445 .16331 .45035 .15479 .44273 Metetra
.656 .751 .92 r
.15479 .44273 .16331 .45035 .17528 .44623 .1668 .43857 Metetra
.656 .751 .92 r
.1668 .43857 .17528 .44623 .18732 .44209 .17886 .4344 Metetra
.656 .751 .92 r
.17886 .4344 .18732 .44209 .19941 .43793 .19099 .4302 Metetra
.656 .751 .92 r
.19099 .4302 .19941 .43793 .21155 .43375 .20316 .42599 Metetra
.656 .751 .92 r
.20316 .42599 .21155 .43375 .22375 .42956 .2154 .42175 Metetra
.656 .751 .92 r
.2154 .42175 .22375 .42956 .23602 .42534 .2277 .4175 Metetra
.656 .751 .92 r
.2277 .4175 .23602 .42534 .24833 .4211 .24005 .41323 Metetra
.656 .751 .92 r
.24005 .41323 .24833 .4211 .26071 .41684 .25246 .40893 Metetra
.417 .658 .959 r
.25246 .40893 .26071 .41684 .27211 .4259 .26454 .40951 Metetra
.187 .33 .777 r
.26454 .40951 .27211 .4259 .28372 .43426 .27613 .41761 Metetra
.276 .383 .792 r
.27613 .41761 .28372 .43426 .2956 .44095 .28799 .42419 Metetra
.369 .44 .803 r
.28799 .42419 .2956 .44095 .30777 .44546 .30013 .42877 Metetra
.459 .494 .808 r
.30013 .42877 .30777 .44546 .32022 .44739 .31256 .43096 Metetra
.539 .543 .807 r
.31256 .43096 .32022 .44739 .33296 .44648 .32526 .43049 Metetra
.609 .586 .802 r
.32526 .43049 .33296 .44648 .34594 .44258 .33821 .42721 Metetra
.666 .622 .795 r
.33821 .42721 .34594 .44258 .35915 .43572 .35139 .42112 Metetra
.713 .653 .788 r
.35139 .42112 .35915 .43572 .37253 .42606 .36475 .41238 Metetra
.751 .68 .782 r
.36475 .41238 .37253 .42606 .38604 .41393 .37825 .40127 Metetra
.782 .704 .777 r
.37825 .40127 .38604 .41393 .39962 .39974 .39184 .38819 Metetra
.807 .726 .776 r
.39184 .38819 .39962 .39974 .41325 .38402 .40548 .37363 Metetra
.826 .749 .778 r
.40548 .37363 .41325 .38402 .42688 .36735 .41913 .35816 Metetra
.841 .772 .784 r
.41913 .35816 .42688 .36735 .44048 .35035 .43276 .34234 Metetra
.852 .796 .796 r
.43276 .34234 .44048 .35035 .45404 .33362 .44637 .32679 Metetra
.856 .823 .815 r
.44637 .32679 .45404 .33362 .46755 .31777 .45992 .31205 Metetra
.852 .853 .842 r
.45992 .31205 .46755 .31777 .481 .30332 .47344 .29865 Metetra
.835 .886 .878 r
.47344 .29865 .481 .30332 .49442 .29074 .48692 .28705 Metetra
.792 .917 .923 r
.48692 .28705 .49442 .29074 .50783 .28043 .5004 .27761 Metetra
.703 .931 .964 r
.5004 .27761 .50783 .28043 .52125 .27267 .51389 .2706 Metetra
.534 .895 .973 r
.51389 .2706 .52125 .27267 .53471 .26764 .52743 .2662 Metetra
.276 .768 .902 r
.52743 .2662 .53471 .26764 .54826 .2654 .54106 .26447 Metetra
0 .567 .75 r
.54106 .26447 .54826 .2654 .56194 .26592 .5548 .26534 Metetra
.237 0 0 r
.5548 .26534 .56194 .26592 .57577 .26903 .5687 .26866 Metetra
.388 0 0 r
.5687 .26866 .57577 .26903 .58979 .27445 .58279 .27414 Metetra
.478 0 0 r
.58279 .27414 .58979 .27445 .60403 .28182 .59708 .28142 Metetra
.235 0 0 r
.59708 .28142 .60403 .28182 .61849 .29068 .61144 .28472 Metetra
.643 .836 .975 r
.61144 .28472 .61849 .29068 .63277 .28887 .62569 .27979 Metetra
.656 .751 .92 r
.62569 .27979 .63277 .28887 .64704 .28396 .64 .27483 Metetra
.656 .751 .92 r
.64 .27483 .64704 .28396 .66138 .27903 .65439 .26985 Metetra
.656 .751 .92 r
.65439 .26985 .66138 .27903 .6758 .27407 .66886 .26485 Metetra
.656 .751 .92 r
.66886 .26485 .6758 .27407 .69029 .26909 .6834 .25982 Metetra
.656 .751 .92 r
.6834 .25982 .69029 .26909 .70485 .26408 .69801 .25476 Metetra
.656 .751 .92 r
.69801 .25476 .70485 .26408 .71949 .25904 .7127 .24968 Metetra
.656 .751 .92 r
.7127 .24968 .71949 .25904 .7342 .25398 .72747 .24457 Metetra
.656 .751 .92 r
.72747 .24457 .7342 .25398 .74899 .24889 .74231 .23943 Metetra
.656 .751 .92 r
.74231 .23943 .74899 .24889 .76386 .24378 .75724 .23427 Metetra
.656 .751 .92 r
.75724 .23427 .76386 .24378 .7788 .23864 .77223 .22908 Metetra
.656 .751 .92 r
.11041 .4475 .1191 .45508 .13094 .45098 .12229 .44336 Metetra
.656 .751 .92 r
.12229 .44336 .13094 .45098 .14284 .44686 .13421 .43921 Metetra
.656 .751 .92 r
.13421 .43921 .14284 .44686 .15479 .44273 .1462 .43504 Metetra
.656 .751 .92 r
.1462 .43504 .15479 .44273 .1668 .43857 .15824 .43085 Metetra
.656 .751 .92 r
.15824 .43085 .1668 .43857 .17886 .4344 .17034 .42664 Metetra
.656 .751 .92 r
.17034 .42664 .17886 .4344 .19099 .4302 .18249 .42241 Metetra
.656 .751 .92 r
.18249 .42241 .19099 .4302 .20316 .42599 .1947 .41816 Metetra
.656 .751 .92 r
.1947 .41816 .20316 .42599 .2154 .42175 .20697 .41388 Metetra
.656 .751 .92 r
.20697 .41388 .2154 .42175 .2277 .4175 .2193 .40959 Metetra
.656 .751 .92 r
.2193 .40959 .2277 .4175 .24005 .41323 .23169 .40528 Metetra
.656 .751 .92 r
.23169 .40528 .24005 .41323 .25246 .40893 .24414 .40095 Metetra
.656 .751 .92 r
.24414 .40095 .25246 .40893 .26454 .40951 .25664 .3966 Metetra
.289 .46 .857 r
.25664 .3966 .26454 .40951 .27613 .41761 .2685 .40116 Metetra
.274 .387 .796 r
.2685 .40116 .27613 .41761 .28799 .42419 .28034 .40757 Metetra
.363 .439 .805 r
.28034 .40757 .28799 .42419 .30013 .42877 .29246 .41216 Metetra
.448 .49 .81 r
.29246 .41216 .30013 .42877 .31256 .43096 .30485 .41456 Metetra
.526 .537 .81 r
.30485 .41456 .31256 .43096 .32526 .43049 .31752 .41448 Metetra
.594 .579 .806 r
.31752 .41448 .32526 .43049 .33821 .42721 .33045 .41177 Metetra
.652 .615 .8 r
.33045 .41177 .33821 .42721 .35139 .42112 .3436 .40643 Metetra
.699 .647 .794 r
.3436 .40643 .35139 .42112 .36475 .41238 .35693 .39859 Metetra
.738 .674 .789 r
.35693 .39859 .36475 .41238 .37825 .40127 .37041 .38849 Metetra
.769 .7 .786 r
.37041 .38849 .37825 .40127 .39184 .38819 .384 .37653 Metetra
.795 .723 .785 r
.384 .37653 .39184 .38819 .40548 .37363 .39764 .36314 Metetra
.815 .747 .789 r
.39764 .36314 .40548 .37363 .41913 .35816 .41131 .34887 Metetra
.83 .771 .796 r
.41131 .34887 .41913 .35816 .43276 .34234 .42497 .33427 Metetra
.84 .797 .81 r
.42497 .33427 .43276 .34234 .44637 .32679 .43861 .3199 Metetra
.843 .825 .83 r
.43861 .3199 .44637 .32679 .45992 .31205 .45221 .3063 Metetra
.838 .856 .858 r
.45221 .3063 .45992 .31205 .47344 .29865 .46579 .29397 Metetra
.817 .889 .895 r
.46579 .29397 .47344 .29865 .48692 .28705 .47933 .28334 Metetra
.767 .917 .938 r
.47933 .28334 .48692 .28705 .5004 .27761 .49287 .27477 Metetra
.667 .923 .974 r
.49287 .27477 .5004 .27761 .51389 .2706 .50644 .26851 Metetra
.488 .875 .97 r
.50644 .26851 .51389 .2706 .52743 .2662 .52005 .26472 Metetra
.234 .741 .888 r
.52005 .26472 .52743 .2662 .54106 .26447 .53374 .26345 Metetra
0 .548 .741 r
.53374 .26345 .54106 .26447 .5548 .26534 .54756 .26463 Metetra
.24 0 0 r
.54756 .26463 .5548 .26534 .5687 .26866 .56153 .2681 Metetra
.377 0 0 r
.56153 .2681 .5687 .26866 .58279 .27414 .57567 .27357 Metetra
.452 0 0 r
.57567 .27357 .58279 .27414 .59708 .28142 .59002 .28055 Metetra
.477 .891 .92 r
.59002 .28055 .59708 .28142 .61144 .28472 .60424 .2756 Metetra
.656 .751 .92 r
.60424 .2756 .61144 .28472 .62569 .27979 .61853 .27062 Metetra
.656 .751 .92 r
.61853 .27062 .62569 .27979 .64 .27483 .6329 .26562 Metetra
.656 .751 .92 r
.6329 .26562 .64 .27483 .65439 .26985 .64734 .26059 Metetra
.656 .751 .92 r
.64734 .26059 .65439 .26985 .66886 .26485 .66185 .25554 Metetra
.656 .751 .92 r
.66185 .25554 .66886 .26485 .6834 .25982 .67645 .25046 Metetra
.656 .751 .92 r
.67645 .25046 .6834 .25982 .69801 .25476 .69111 .24536 Metetra
.656 .751 .92 r
.69111 .24536 .69801 .25476 .7127 .24968 .70585 .24022 Metetra
.656 .751 .92 r
.70585 .24022 .7127 .24968 .72747 .24457 .72067 .23506 Metetra
.656 .751 .92 r
.72067 .23506 .72747 .24457 .74231 .23943 .73557 .22988 Metetra
.656 .751 .92 r
.73557 .22988 .74231 .23943 .75724 .23427 .75055 .22467 Metetra
.656 .751 .92 r
.75055 .22467 .75724 .23427 .77223 .22908 .7656 .21943 Metetra
.656 .751 .92 r
.10165 .43985 .11041 .4475 .12229 .44336 .11356 .43568 Metetra
.656 .751 .92 r
.11356 .43568 .12229 .44336 .13421 .43921 .12552 .4315 Metetra
.656 .751 .92 r
.12552 .4315 .13421 .43921 .1462 .43504 .13753 .42729 Metetra
.656 .751 .92 r
.13753 .42729 .1462 .43504 .15824 .43085 .14961 .42306 Metetra
.656 .751 .92 r
.14961 .42306 .15824 .43085 .17034 .42664 .16174 .41881 Metetra
.656 .751 .92 r
.16174 .41881 .17034 .42664 .18249 .42241 .17392 .41454 Metetra
.656 .751 .92 r
.17392 .41454 .18249 .42241 .1947 .41816 .18617 .41025 Metetra
.656 .751 .92 r
.18617 .41025 .1947 .41816 .20697 .41388 .19847 .40595 Metetra
.656 .751 .92 r
.19847 .40595 .20697 .41388 .2193 .40959 .21084 .40162 Metetra
.656 .751 .92 r
.21084 .40162 .2193 .40959 .23169 .40528 .22326 .39727 Metetra
.656 .751 .92 r
.22326 .39727 .23169 .40528 .24414 .40095 .23574 .3929 Metetra
.656 .751 .92 r
.23574 .3929 .24414 .40095 .25664 .3966 .24828 .3885 Metetra
.622 .741 .932 r
.24828 .3885 .25664 .3966 .2685 .40116 .2608 .38505 Metetra
.274 .392 .802 r
.2608 .38505 .2685 .40116 .28034 .40757 .27264 .39122 Metetra
.357 .44 .81 r
.27264 .39122 .28034 .40757 .29246 .41216 .28473 .39576 Metetra
.439 .488 .814 r
.28473 .39576 .29246 .41216 .30485 .41456 .29711 .39829 Metetra
.514 .533 .814 r
.29711 .39829 .30485 .41456 .31752 .41448 .30974 .39855 Metetra
.58 .574 .811 r
.30974 .39855 .31752 .41448 .33045 .41177 .32264 .39637 Metetra
.637 .61 .806 r
.32264 .39637 .33045 .41177 .3436 .40643 .33575 .39174 Metetra
.684 .641 .801 r
.33575 .39174 .3436 .40643 .35693 .39859 .34906 .38476 Metetra
.723 .67 .797 r
.34906 .38476 .35693 .39859 .37041 .38849 .36253 .37566 Metetra
.755 .696 .795 r
.36253 .37566 .37041 .38849 .384 .37653 .3761 .36479 Metetra
.781 .72 .796 r
.3761 .36479 .384 .37653 .39764 .36314 .38974 .35258 Metetra
.802 .745 .8 r
.38974 .35258 .39764 .36314 .41131 .34887 .40342 .33951 Metetra
.817 .77 .809 r
.40342 .33951 .41131 .34887 .42497 .33427 .4171 .32612 Metetra
.826 .797 .824 r
.4171 .32612 .42497 .33427 .43861 .3199 .43077 .31294 Metetra
.829 .826 .845 r
.43077 .31294 .43861 .3199 .45221 .3063 .44442 .30048 Metetra
.821 .857 .875 r
.44442 .30048 .45221 .3063 .46579 .29397 .45804 .28921 Metetra
.795 .888 .912 r
.45804 .28921 .46579 .29397 .47933 .28334 .47165 .27955 Metetra
.739 .913 .953 r
.47165 .27955 .47933 .28334 .49287 .27477 .48525 .27183 Metetra
.63 .911 .982 r
.48525 .27183 .49287 .27477 .50644 .26851 .49888 .26629 Metetra
.448 .853 .968 r
.49888 .26629 .50644 .26851 .52005 .26472 .51256 .26308 Metetra
.204 .719 .882 r
.51256 .26308 .52005 .26472 .53374 .26345 .52633 .26222 Metetra
0 .539 .744 r
.52633 .26222 .53374 .26345 .54756 .26463 .54021 .26366 Metetra
.23 0 0 r
.54021 .26366 .54756 .26463 .56153 .2681 .55424 .26722 Metetra
.356 0 0 r
.55424 .26722 .56153 .2681 .57567 .27357 .56844 .27261 Metetra
.179 .71 .842 r
.56844 .27261 .57567 .27357 .59002 .28055 .58269 .27139 Metetra
.656 .751 .92 r
.58269 .27139 .59002 .28055 .60424 .2756 .59696 .26639 Metetra
.656 .751 .92 r
.59696 .26639 .60424 .2756 .61853 .27062 .61131 .26137 Metetra
.656 .751 .92 r
.61131 .26137 .61853 .27062 .6329 .26562 .62572 .25632 Metetra
.656 .751 .92 r
.62572 .25632 .6329 .26562 .64734 .26059 .64021 .25124 Metetra
.656 .751 .92 r
.64021 .25124 .64734 .26059 .66185 .25554 .65478 .24614 Metetra
.656 .751 .92 r
.65478 .24614 .66185 .25554 .67645 .25046 .66942 .24101 Metetra
.656 .751 .92 r
.66942 .24101 .67645 .25046 .69111 .24536 .68414 .23586 Metetra
.656 .751 .92 r
.68414 .23586 .69111 .24536 .70585 .24022 .69894 .23068 Metetra
.656 .751 .92 r
.69894 .23068 .70585 .24022 .72067 .23506 .71381 .22547 Metetra
.656 .751 .92 r
.71381 .22547 .72067 .23506 .73557 .22988 .72876 .22023 Metetra
.656 .751 .92 r
.72876 .22023 .73557 .22988 .75055 .22467 .74379 .21497 Metetra
.656 .751 .92 r
.74379 .21497 .75055 .22467 .7656 .21943 .7589 .20968 Metetra
.656 .751 .92 r
.09282 .43214 .10165 .43985 .11356 .43568 .10475 .42794 Metetra
.656 .751 .92 r
.10475 .42794 .11356 .43568 .12552 .4315 .11675 .42371 Metetra
.656 .751 .92 r
.11675 .42371 .12552 .4315 .13753 .42729 .12879 .41947 Metetra
.656 .751 .92 r
.12879 .41947 .13753 .42729 .14961 .42306 .1409 .4152 Metetra
.656 .751 .92 r
.1409 .4152 .14961 .42306 .16174 .41881 .15306 .41092 Metetra
.656 .751 .92 r
.15306 .41092 .16174 .41881 .17392 .41454 .16528 .40661 Metetra
.656 .751 .92 r
.16528 .40661 .17392 .41454 .18617 .41025 .17756 .40228 Metetra
.656 .751 .92 r
.17756 .40228 .18617 .41025 .19847 .40595 .1899 .39794 Metetra
.656 .751 .92 r
.1899 .39794 .19847 .40595 .21084 .40162 .20229 .39357 Metetra
.656 .751 .92 r
.20229 .39357 .21084 .40162 .22326 .39727 .21475 .38918 Metetra
.656 .751 .92 r
.21475 .38918 .22326 .39727 .23574 .3929 .22727 .38477 Metetra
.656 .751 .92 r
.22727 .38477 .23574 .3929 .24828 .3885 .23984 .38034 Metetra
.656 .751 .92 r
.23984 .38034 .24828 .3885 .2608 .38505 .25248 .37589 Metetra
.502 .668 .938 r
.25248 .37589 .2608 .38505 .27264 .39122 .26487 .37525 Metetra
.352 .445 .816 r
.26487 .37525 .27264 .39122 .28473 .39576 .27695 .37967 Metetra
.43 .489 .819 r
.27695 .37967 .28473 .39576 .29711 .39829 .2893 .38228 Metetra
.502 .532 .819 r
.2893 .38228 .29711 .39829 .30974 .39855 .30192 .38281 Metetra
.567 .571 .817 r
.30192 .38281 .30974 .39855 .32264 .39637 .31478 .38111 Metetra
.623 .606 .813 r
.31478 .38111 .32264 .39637 .33575 .39174 .32786 .37713 Metetra
.67 .637 .809 r
.32786 .37713 .33575 .39174 .34906 .38476 .34115 .37097 Metetra
.709 .666 .806 r
.34115 .37097 .34906 .38476 .36253 .37566 .35458 .36283 Metetra
.741 .692 .805 r
.35458 .36283 .36253 .37566 .3761 .36479 .36814 .35303 Metetra
.767 .718 .806 r
.36814 .35303 .3761 .36479 .38974 .35258 .38178 .34196 Metetra
.787 .743 .812 r
.38178 .34196 .38974 .35258 .40342 .33951 .39546 .33008 Metetra
.802 .769 .822 r
.39546 .33008 .40342 .33951 .4171 .32612 .40916 .31789 Metetra
.811 .796 .838 r
.40916 .31789 .4171 .32612 .43077 .31294 .42286 .30588 Metetra
.812 .825 .861 r
.42286 .30588 .43077 .31294 .44442 .30048 .43654 .29454 Metetra
.801 .856 .891 r
.43654 .29454 .44442 .30048 .45804 .28921 .45021 .28432 Metetra
.771 .885 .927 r
.45021 .28432 .45804 .28921 .47165 .27955 .46387 .27561 Metetra
.709 .904 .965 r
.46387 .27561 .47165 .27955 .48525 .27183 .47753 .26871 Metetra
.595 .896 .988 r
.47753 .26871 .48525 .27183 .49888 .26629 .49122 .26385 Metetra
.415 .832 .967 r
.49122 .26385 .49888 .26629 .51256 .26308 .50497 .26117 Metetra
.186 .703 .884 r
.50497 .26117 .51256 .26308 .52633 .26222 .5188 .26068 Metetra
0 .54 .759 r
.5188 .26068 .52633 .26222 .54021 .26366 .53275 .26232 Metetra
.208 0 0 r
.53275 .26232 .54021 .26366 .55424 .26722 .54684 .26589 Metetra
0 .558 .762 r
.54684 .26589 .55424 .26722 .56844 .27261 .56106 .26716 Metetra
.637 .852 .982 r
.56106 .26716 .56844 .27261 .58269 .27139 .5753 .26214 Metetra
.656 .751 .92 r
.5753 .26214 .58269 .27139 .59696 .26639 .58962 .2571 Metetra
.656 .751 .92 r
.58962 .2571 .59696 .26639 .61131 .26137 .60401 .25203 Metetra
.656 .751 .92 r
.60401 .25203 .61131 .26137 .62572 .25632 .61848 .24693 Metetra
.656 .751 .92 r
.61848 .24693 .62572 .25632 .64021 .25124 .63302 .24181 Metetra
.656 .751 .92 r
.63302 .24181 .64021 .25124 .65478 .24614 .64764 .23665 Metetra
.656 .751 .92 r
.64764 .23665 .65478 .24614 .66942 .24101 .66234 .23148 Metetra
.656 .751 .92 r
.66234 .23148 .66942 .24101 .68414 .23586 .67711 .22627 Metetra
.656 .751 .92 r
.67711 .22627 .68414 .23586 .69894 .23068 .69196 .22104 Metetra
.656 .751 .92 r
.69196 .22104 .69894 .23068 .71381 .22547 .70688 .21578 Metetra
.656 .751 .92 r
.70688 .21578 .71381 .22547 .72876 .22023 .72189 .21049 Metetra
.656 .751 .92 r
.72189 .21049 .72876 .22023 .74379 .21497 .73698 .20518 Metetra
.656 .751 .92 r
.73698 .20518 .74379 .21497 .7589 .20968 .75214 .19983 Metetra
.656 .751 .92 r
.08391 .42436 .09282 .43214 .10475 .42794 .09587 .42012 Metetra
.656 .751 .92 r
.09587 .42012 .10475 .42794 .11675 .42371 .1079 .41586 Metetra
.656 .751 .92 r
.1079 .41586 .11675 .42371 .12879 .41947 .11998 .41158 Metetra
.656 .751 .92 r
.11998 .41158 .12879 .41947 .1409 .4152 .13211 .40727 Metetra
.656 .751 .92 r
.13211 .40727 .1409 .4152 .15306 .41092 .14431 .40295 Metetra
.656 .751 .92 r
.14431 .40295 .15306 .41092 .16528 .40661 .15656 .39861 Metetra
.656 .751 .92 r
.15656 .39861 .16528 .40661 .17756 .40228 .16887 .39424 Metetra
.656 .751 .92 r
.16887 .39424 .17756 .40228 .1899 .39794 .18124 .38986 Metetra
.656 .751 .92 r
.18124 .38986 .1899 .39794 .20229 .39357 .19368 .38545 Metetra
.656 .751 .92 r
.19368 .38545 .20229 .39357 .21475 .38918 .20617 .38102 Metetra
.656 .751 .92 r
.20617 .38102 .21475 .38918 .22727 .38477 .21872 .37657 Metetra
.656 .751 .92 r
.21872 .37657 .22727 .38477 .23984 .38034 .23133 .3721 Metetra
.656 .751 .92 r
.23133 .3721 .23984 .38034 .25248 .37589 .244 .36761 Metetra
.656 .751 .92 r
.244 .36761 .25248 .37589 .26487 .37525 .25674 .36309 Metetra
.459 .577 .886 r
.25674 .36309 .26487 .37525 .27695 .37967 .2691 .364 Metetra
.422 .492 .827 r
.2691 .364 .27695 .37967 .2893 .38228 .28144 .36662 Metetra
.491 .532 .826 r
.28144 .36662 .2893 .38228 .30192 .38281 .29402 .36736 Metetra
.554 .569 .824 r
.29402 .36736 .30192 .38281 .31478 .38111 .30686 .36607 Metetra
.608 .603 .821 r
.30686 .36607 .31478 .38111 .32786 .37713 .31992 .36269 Metetra
.655 .634 .817 r
.31992 .36269 .32786 .37713 .34115 .37097 .33317 .35729 Metetra
.694 .663 .815 r
.33317 .35729 .34115 .37097 .35458 .36283 .34658 .35007 Metetra
.726 .689 .815 r
.34658 .35007 .35458 .36283 .36814 .35303 .36012 .34129 Metetra
.752 .715 .818 r
.36012 .34129 .36814 .35303 .38178 .34196 .37375 .33132 Metetra
.772 .741 .824 r
.37375 .33132 .38178 .34196 .39546 .33008 .38743 .32059 Metetra
.786 .767 .836 r
.38743 .32059 .39546 .33008 .40916 .31789 .40114 .30956 Metetra
.794 .794 .852 r
.40114 .30956 .40916 .31789 .42286 .30588 .41486 .2987 Metetra
.793 .823 .876 r
.41486 .2987 .42286 .30588 .43654 .29454 .42858 .28845 Metetra
.779 .852 .906 r
.42858 .28845 .43654 .29454 .45021 .28432 .44229 .27924 Metetra
.745 .879 .941 r
.44229 .27924 .45021 .28432 .46387 .27561 .45599 .27144 Metetra
.678 .893 .975 r
.45599 .27144 .46387 .27561 .47753 .26871 .46971 .26532 Metetra
.562 .878 .992 r
.46971 .26532 .47753 .26871 .49122 .26385 .48346 .2611 Metetra
.39 .813 .969 r
.48346 .2611 .49122 .26385 .50497 .26117 .49727 .2589 Metetra
.181 .694 .893 r
.49727 .2589 .50497 .26117 .5188 .26068 .51117 .25872 Metetra
0 .55 .785 r
.51117 .25872 .5188 .26068 .53275 .26232 .52518 .26048 Metetra
0 .497 .741 r
.52518 .26048 .53275 .26232 .54684 .26589 .53933 .26292 Metetra
.58 .901 .984 r
.53933 .26292 .54684 .26589 .56106 .26716 .55355 .25788 Metetra
.656 .751 .92 r
.55355 .25788 .56106 .26716 .5753 .26214 .56784 .25281 Metetra
.656 .751 .92 r
.56784 .25281 .5753 .26214 .58962 .2571 .58221 .24771 Metetra
.656 .751 .92 r
.58221 .24771 .58962 .2571 .60401 .25203 .59665 .2426 Metetra
.656 .751 .92 r
.59665 .2426 .60401 .25203 .61848 .24693 .61117 .23745 Metetra
.656 .751 .92 r
.61117 .23745 .61848 .24693 .63302 .24181 .62576 .23228 Metetra
.656 .751 .92 r
.62576 .23228 .63302 .24181 .64764 .23665 .64043 .22707 Metetra
.656 .751 .92 r
.64043 .22707 .64764 .23665 .66234 .23148 .65518 .22185 Metetra
.656 .751 .92 r
.65518 .22185 .66234 .23148 .67711 .22627 .67 .21659 Metetra
.656 .751 .92 r
.67 .21659 .67711 .22627 .69196 .22104 .68491 .21131 Metetra
.656 .751 .92 r
.68491 .21131 .69196 .22104 .70688 .21578 .69989 .206 Metetra
.656 .751 .92 r
.69989 .206 .70688 .21578 .72189 .21049 .71495 .20066 Metetra
.656 .751 .92 r
.71495 .20066 .72189 .21049 .73698 .20518 .73009 .19529 Metetra
.656 .751 .92 r
.73009 .19529 .73698 .20518 .75214 .19983 .74531 .18989 Metetra
.656 .751 .92 r
.07492 .41652 .08391 .42436 .09587 .42012 .08691 .41224 Metetra
.656 .751 .92 r
.08691 .41224 .09587 .42012 .1079 .41586 .09897 .40794 Metetra
.656 .751 .92 r
.09897 .40794 .1079 .41586 .11998 .41158 .11108 .40362 Metetra
.656 .751 .92 r
.11108 .40362 .11998 .41158 .13211 .40727 .12325 .39928 Metetra
.656 .751 .92 r
.12325 .39928 .13211 .40727 .14431 .40295 .13548 .39492 Metetra
.656 .751 .92 r
.13548 .39492 .14431 .40295 .15656 .39861 .14776 .39053 Metetra
.656 .751 .92 r
.14776 .39053 .15656 .39861 .16887 .39424 .16011 .38613 Metetra
.656 .751 .92 r
.16011 .38613 .16887 .39424 .18124 .38986 .17251 .3817 Metetra
.656 .751 .92 r
.17251 .3817 .18124 .38986 .19368 .38545 .18498 .37726 Metetra
.656 .751 .92 r
.18498 .37726 .19368 .38545 .20617 .38102 .19751 .37279 Metetra
.656 .751 .92 r
.19751 .37279 .20617 .38102 .21872 .37657 .21009 .3683 Metetra
.656 .751 .92 r
.21009 .3683 .21872 .37657 .23133 .3721 .22274 .36379 Metetra
.656 .751 .92 r
.22274 .36379 .23133 .3721 .244 .36761 .23545 .35926 Metetra
.656 .751 .92 r
.23545 .35926 .244 .36761 .25674 .36309 .24822 .3547 Metetra
.656 .751 .92 r
.24822 .3547 .25674 .36309 .2691 .364 .26106 .35012 Metetra
.457 .544 .857 r
.26106 .35012 .2691 .364 .28144 .36662 .27349 .35139 Metetra
.481 .535 .835 r
.27349 .35139 .28144 .36662 .29402 .36736 .28606 .35228 Metetra
.542 .57 .832 r
.28606 .35228 .29402 .36736 .30686 .36607 .29887 .35133 Metetra
.595 .602 .829 r
.29887 .35133 .30686 .36607 .31992 .36269 .3119 .34848 Metetra
.64 .632 .827 r
.3119 .34848 .31992 .36269 .33317 .35729 .32513 .34379 Metetra
.678 .66 .825 r
.32513 .34379 .33317 .35729 .34658 .35007 .33852 .33741 Metetra
.71 .687 .826 r
.33852 .33741 .34658 .35007 .36012 .34129 .35204 .3296 Metetra
.736 .713 .83 r
.35204 .3296 .36012 .34129 .37375 .33132 .36565 .32068 Metetra
.755 .738 .837 r
.36565 .32068 .37375 .33132 .38743 .32059 .37933 .31105 Metetra
.769 .765 .849 r
.37933 .31105 .38743 .32059 .40114 .30956 .39305 .30114 Metetra
.775 .792 .867 r
.39305 .30114 .40114 .30956 .41486 .2987 .40679 .29137 Metetra
.772 .819 .89 r
.40679 .29137 .41486 .2987 .42858 .28845 .42053 .28217 Metetra
.755 .846 .92 r
.42053 .28217 .42858 .28845 .44229 .27924 .43427 .27393 Metetra
.717 .869 .953 r
.43427 .27393 .44229 .27924 .45599 .27144 .44803 .26698 Metetra
.648 .878 .983 r
.44803 .26698 .45599 .27144 .46971 .26532 .4618 .26159 Metetra
.534 .859 .996 r
.4618 .26159 .46971 .26532 .48346 .2611 .47561 .25796 Metetra
.373 .796 .973 r
.47561 .25796 .48346 .2611 .49727 .2589 .48948 .25617 Metetra
.186 .69 .907 r
.48948 .25617 .49727 .2589 .51117 .25872 .50343 .25623 Metetra
.01 .566 .818 r
.50343 .25623 .51117 .25872 .52518 .26048 .5175 .25806 Metetra
.524 .889 .974 r
.5175 .25806 .52518 .26048 .53933 .26292 .5317 .25359 Metetra
.656 .751 .92 r
.5317 .25359 .53933 .26292 .55355 .25788 .54597 .2485 Metetra
.656 .751 .92 r
.54597 .2485 .55355 .25788 .56784 .25281 .56031 .24338 Metetra
.656 .751 .92 r
.56031 .24338 .56784 .25281 .58221 .24771 .57473 .23824 Metetra
.656 .751 .92 r
.57473 .23824 .58221 .24771 .59665 .2426 .58922 .23307 Metetra
.656 .751 .92 r
.58922 .23307 .59665 .2426 .61117 .23745 .60379 .22788 Metetra
.656 .751 .92 r
.60379 .22788 .61117 .23745 .62576 .23228 .61843 .22265 Metetra
.656 .751 .92 r
.61843 .22265 .62576 .23228 .64043 .22707 .63315 .2174 Metetra
.656 .751 .92 r
.63315 .2174 .64043 .22707 .65518 .22185 .64795 .21212 Metetra
.656 .751 .92 r
.64795 .21212 .65518 .22185 .67 .21659 .66283 .20682 Metetra
.656 .751 .92 r
.66283 .20682 .67 .21659 .68491 .21131 .67779 .20148 Metetra
.656 .751 .92 r
.67779 .20148 .68491 .21131 .69989 .206 .69282 .19612 Metetra
.656 .751 .92 r
.69282 .19612 .69989 .206 .71495 .20066 .70794 .19073 Metetra
.656 .751 .92 r
.70794 .19073 .71495 .20066 .73009 .19529 .72314 .18531 Metetra
.656 .751 .92 r
.72314 .18531 .73009 .19529 .74531 .18989 .73842 .17986 Metetra
.656 .751 .92 r
.06585 .4086 .07492 .41652 .08691 .41224 .07788 .40428 Metetra
.656 .751 .92 r
.07788 .40428 .08691 .41224 .09897 .40794 .08996 .39995 Metetra
.656 .751 .92 r
.08996 .39995 .09897 .40794 .11108 .40362 .10211 .39559 Metetra
.656 .751 .92 r
.10211 .39559 .11108 .40362 .12325 .39928 .11431 .39121 Metetra
.656 .751 .92 r
.11431 .39121 .12325 .39928 .13548 .39492 .12657 .38681 Metetra
.656 .751 .92 r
.12657 .38681 .13548 .39492 .14776 .39053 .13889 .38239 Metetra
.656 .751 .92 r
.13889 .38239 .14776 .39053 .16011 .38613 .15127 .37794 Metetra
.656 .751 .92 r
.15127 .37794 .16011 .38613 .17251 .3817 .16371 .37348 Metetra
.656 .751 .92 r
.16371 .37348 .17251 .3817 .18498 .37726 .17621 .36899 Metetra
.656 .751 .92 r
.17621 .36899 .18498 .37726 .19751 .37279 .18877 .36448 Metetra
.656 .751 .92 r
.18877 .36448 .19751 .37279 .21009 .3683 .20139 .35995 Metetra
.656 .751 .92 r
.20139 .35995 .21009 .3683 .22274 .36379 .21407 .3554 Metetra
.656 .751 .92 r
.21407 .3554 .22274 .36379 .23545 .35926 .22682 .35083 Metetra
.656 .751 .92 r
.22682 .35083 .23545 .35926 .24822 .3547 .23963 .34623 Metetra
.656 .751 .92 r
.23963 .34623 .24822 .3547 .26106 .35012 .2525 .34161 Metetra
.656 .751 .92 r
.2525 .34161 .26106 .35012 .27349 .35139 .26544 .33697 Metetra
.482 .55 .849 r
.26544 .33697 .27349 .35139 .28606 .35228 .27802 .33763 Metetra
.53 .572 .842 r
.27802 .33763 .28606 .35228 .29887 .35133 .29081 .33695 Metetra
.581 .603 .839 r
.29081 .33695 .29887 .35133 .3119 .34848 .30382 .33456 Metetra
.625 .632 .837 r
.30382 .33456 .3119 .34848 .32513 .34379 .31702 .3305 Metetra
.663 .659 .836 r
.31702 .3305 .32513 .34379 .33852 .33741 .33038 .3249 Metetra
.694 .685 .837 r
.33038 .3249 .33852 .33741 .35204 .3296 .34388 .31799 Metetra
.719 .711 .842 r
.34388 .31799 .35204 .3296 .36565 .32068 .35748 .31006 Metetra
.737 .736 .85 r
.35748 .31006 .36565 .32068 .37933 .31105 .37116 .30147 Metetra
.75 .761 .862 r
.37116 .30147 .37933 .31105 .39305 .30114 .38488 .29261 Metetra
.754 .788 .88 r
.38488 .29261 .39305 .30114 .40679 .29137 .39863 .28388 Metetra
.749 .814 .903 r
.39863 .28388 .40679 .29137 .42053 .28217 .4124 .27566 Metetra
.73 .838 .932 r
.4124 .27566 .42053 .28217 .43427 .27393 .42618 .26833 Metetra
.689 .857 .962 r
.42618 .26833 .43427 .27393 .44803 .26698 .43997 .26218 Metetra
.619 .861 .989 r
.43997 .26218 .44803 .26698 .4618 .26159 .45379 .25746 Metetra
.511 .84 .998 r
.45379 .25746 .4618 .26159 .47561 .25796 .46765 .25434 Metetra
.366 .782 .978 r
.46765 .25434 .47561 .25796 .48948 .25617 .48158 .2529 Metetra
.202 .691 .925 r
.48158 .2529 .48948 .25617 .50343 .25623 .49559 .25314 Metetra
.512 .87 .987 r
.49559 .25314 .50343 .25623 .5175 .25806 .50975 .24928 Metetra
.656 .767 .931 r
.50975 .24928 .5175 .25806 .5317 .25359 .52399 .24417 Metetra
.656 .751 .92 r
.52399 .24417 .5317 .25359 .54597 .2485 .53831 .23904 Metetra
.656 .751 .92 r
.53831 .23904 .54597 .2485 .56031 .24338 .5527 .23387 Metetra
.656 .751 .92 r
.5527 .23387 .56031 .24338 .57473 .23824 .56717 .22868 Metetra
.656 .751 .92 r
.56717 .22868 .57473 .23824 .58922 .23307 .58171 .22346 Metetra
.656 .751 .92 r
.58171 .22346 .58922 .23307 .60379 .22788 .59633 .21821 Metetra
.656 .751 .92 r
.59633 .21821 .60379 .22788 .61843 .22265 .61103 .21294 Metetra
.656 .751 .92 r
.61103 .21294 .61843 .22265 .63315 .2174 .6258 .20763 Metetra
.656 .751 .92 r
.6258 .20763 .63315 .2174 .64795 .21212 .64065 .2023 Metetra
.656 .751 .92 r
.64065 .2023 .64795 .21212 .66283 .20682 .65559 .19695 Metetra
.656 .751 .92 r
.65559 .19695 .66283 .20682 .67779 .20148 .6706 .19156 Metetra
.656 .751 .92 r
.6706 .19156 .67779 .20148 .69282 .19612 .68569 .18614 Metetra
.656 .751 .92 r
.68569 .18614 .69282 .19612 .70794 .19073 .70086 .1807 Metetra
.656 .751 .92 r
.70086 .1807 .70794 .19073 .72314 .18531 .71611 .17522 Metetra
.656 .751 .92 r
.71611 .17522 .72314 .18531 .73842 .17986 .73145 .16972 Metetra
.656 .751 .92 r
.0567 .40061 .06585 .4086 .07788 .40428 .06876 .39626 Metetra
.656 .751 .92 r
.06876 .39626 .07788 .40428 .08996 .39995 .08088 .39188 Metetra
.656 .751 .92 r
.08088 .39188 .08996 .39995 .10211 .39559 .09305 .38749 Metetra
.656 .751 .92 r
.09305 .38749 .10211 .39559 .11431 .39121 .10529 .38307 Metetra
.656 .751 .92 r
.10529 .38307 .11431 .39121 .12657 .38681 .11758 .37863 Metetra
.656 .751 .92 r
.11758 .37863 .12657 .38681 .13889 .38239 .12993 .37417 Metetra
.656 .751 .92 r
.12993 .37417 .13889 .38239 .15127 .37794 .14235 .36968 Metetra
.656 .751 .92 r
.14235 .36968 .15127 .37794 .16371 .37348 .15482 .36518 Metetra
.656 .751 .92 r
.15482 .36518 .16371 .37348 .17621 .36899 .16735 .36065 Metetra
.656 .751 .92 r
.16735 .36065 .17621 .36899 .18877 .36448 .17995 .3561 Metetra
.656 .751 .92 r
.17995 .3561 .18877 .36448 .20139 .35995 .19261 .35153 Metetra
.656 .751 .92 r
.19261 .35153 .20139 .35995 .21407 .3554 .20533 .34694 Metetra
.656 .751 .92 r
.20533 .34694 .21407 .3554 .22682 .35083 .21811 .34232 Metetra
.656 .751 .92 r
.21811 .34232 .22682 .35083 .23963 .34623 .23096 .33768 Metetra
.656 .751 .92 r
.23096 .33768 .23963 .34623 .2525 .34161 .24387 .33302 Metetra
.656 .751 .92 r
.24387 .33302 .2525 .34161 .26544 .33697 .25684 .32834 Metetra
.656 .751 .92 r
.25684 .32834 .26544 .33697 .27802 .33763 .26988 .32363 Metetra
.524 .582 .855 r
.26988 .32363 .27802 .33763 .29081 .33695 .28267 .323 Metetra
.568 .605 .85 r
.28267 .323 .29081 .33695 .30382 .33456 .29566 .32099 Metetra
.611 .633 .848 r
.29566 .32099 .30382 .33456 .31702 .3305 .30883 .31748 Metetra
.647 .659 .847 r
.30883 .31748 .31702 .3305 .33038 .3249 .32217 .31258 Metetra
.677 .684 .849 r
.32217 .31258 .33038 .3249 .34388 .31799 .33565 .30649 Metetra
.701 .709 .854 r
.33565 .30649 .34388 .31799 .35748 .31006 .34924 .29947 Metetra
.719 .733 .862 r
.34924 .29947 .35748 .31006 .37116 .30147 .36291 .29184 Metetra
.73 .758 .875 r
.36291 .29184 .37116 .30147 .38488 .29261 .37663 .28397 Metetra
.733 .782 .893 r
.37663 .28397 .38488 .29261 .39863 .28388 .3904 .2762 Metetra
.725 .806 .915 r
.3904 .2762 .39863 .28388 .4124 .27566 .40418 .2689 Metetra
.703 .828 .942 r
.40418 .2689 .4124 .27566 .42618 .26833 .41799 .26241 Metetra
.662 .842 .969 r
.41799 .26241 .42618 .26833 .43997 .26218 .43182 .25699 Metetra
.594 .843 .992 r
.43182 .25699 .43997 .26218 .45379 .25746 .44569 .25287 Metetra
.494 .821 1 r
.44569 .25287 .45379 .25746 .46765 .25434 .4596 .25019 Metetra
.366 .769 .984 r
.4596 .25019 .46765 .25434 .48158 .2529 .47358 .24904 Metetra
.552 .868 .995 r
.47358 .24904 .48158 .2529 .49559 .25314 .48771 .24496 Metetra
.655 .783 .942 r
.48771 .24496 .49559 .25314 .50975 .24928 .50193 .23983 Metetra
.656 .751 .92 r
.50193 .23983 .50975 .24928 .52399 .24417 .51622 .23467 Metetra
.656 .751 .92 r
.51622 .23467 .52399 .24417 .53831 .23904 .53058 .22948 Metetra
.656 .751 .92 r
.53058 .22948 .53831 .23904 .5527 .23387 .54502 .22426 Metetra
.656 .751 .92 r
.54502 .22426 .5527 .23387 .56717 .22868 .55954 .21902 Metetra
.656 .751 .92 r
.55954 .21902 .56717 .22868 .58171 .22346 .57413 .21375 Metetra
.656 .751 .92 r
.57413 .21375 .58171 .22346 .59633 .21821 .5888 .20845 Metetra
.656 .751 .92 r
.5888 .20845 .59633 .21821 .61103 .21294 .60355 .20313 Metetra
.656 .751 .92 r
.60355 .20313 .61103 .21294 .6258 .20763 .61838 .19777 Metetra
.656 .751 .92 r
.61838 .19777 .6258 .20763 .64065 .2023 .63328 .19239 Metetra
.656 .751 .92 r
.63328 .19239 .64065 .2023 .65559 .19695 .64827 .18698 Metetra
.656 .751 .92 r
.64827 .18698 .65559 .19695 .6706 .19156 .66334 .18154 Metetra
.656 .751 .92 r
.66334 .18154 .6706 .19156 .68569 .18614 .67848 .17607 Metetra
.656 .751 .92 r
.67848 .17607 .68569 .18614 .70086 .1807 .69371 .17057 Metetra
.656 .751 .92 r
.69371 .17057 .70086 .1807 .71611 .17522 .70902 .16504 Metetra
.656 .751 .92 r
.70902 .16504 .71611 .17522 .73145 .16972 .72441 .15948 Metetra
.656 .751 .92 r
.04747 .39256 .0567 .40061 .06876 .39626 .05956 .38816 Metetra
.656 .751 .92 r
.05956 .38816 .06876 .39626 .08088 .39188 .07171 .38375 Metetra
.656 .751 .92 r
.07171 .38375 .08088 .39188 .09305 .38749 .08392 .37931 Metetra
.656 .751 .92 r
.08392 .37931 .09305 .38749 .10529 .38307 .09618 .37486 Metetra
.656 .751 .92 r
.09618 .37486 .10529 .38307 .11758 .37863 .10851 .37038 Metetra
.656 .751 .92 r
.10851 .37038 .11758 .37863 .12993 .37417 .1209 .36587 Metetra
.656 .751 .92 r
.1209 .36587 .12993 .37417 .14235 .36968 .13334 .36135 Metetra
.656 .751 .92 r
.13334 .36135 .14235 .36968 .15482 .36518 .14585 .35681 Metetra
.656 .751 .92 r
.14585 .35681 .15482 .36518 .16735 .36065 .15842 .35224 Metetra
.656 .751 .92 r
.15842 .35224 .16735 .36065 .17995 .3561 .17105 .34765 Metetra
.656 .751 .92 r
.17105 .34765 .17995 .3561 .19261 .35153 .18375 .34303 Metetra
.656 .751 .92 r
.18375 .34303 .19261 .35153 .20533 .34694 .1965 .3384 Metetra
.656 .751 .92 r
.1965 .3384 .20533 .34694 .21811 .34232 .20932 .33374 Metetra
.656 .751 .92 r
.20932 .33374 .21811 .34232 .23096 .33768 .22221 .32906 Metetra
.656 .751 .92 r
.22221 .32906 .23096 .33768 .24387 .33302 .23515 .32435 Metetra
.656 .751 .92 r
.23515 .32435 .24387 .33302 .25684 .32834 .24817 .31962 Metetra
.656 .751 .92 r
.24817 .31962 .25684 .32834 .26988 .32363 .26124 .31487 Metetra
.656 .751 .92 r
.26124 .31487 .26988 .32363 .28267 .323 .27439 .3101 Metetra
.575 .629 .868 r
.27439 .3101 .28267 .323 .29566 .32099 .28741 .30781 Metetra
.597 .635 .859 r
.28741 .30781 .29566 .32099 .30883 .31748 .30056 .30477 Metetra
.632 .659 .859 r
.30056 .30477 .30883 .31748 .32217 .31258 .31389 .30049 Metetra
.661 .683 .861 r
.31389 .30049 .32217 .31258 .33565 .30649 .32735 .29513 Metetra
.683 .707 .866 r
.32735 .29513 .33565 .30649 .34924 .29947 .34092 .28893 Metetra
.7 .73 .874 r
.34092 .28893 .34924 .29947 .36291 .29184 .35458 .28219 Metetra
.709 .753 .887 r
.35458 .28219 .36291 .29184 .37663 .28397 .36831 .27521 Metetra
.71 .776 .904 r
.36831 .27521 .37663 .28397 .3904 .2762 .38208 .26833 Metetra
.701 .798 .925 r
.38208 .26833 .3904 .2762 .40418 .2689 .39589 .26187 Metetra
.678 .816 .949 r
.39589 .26187 .40418 .2689 .41799 .26241 .40972 .25613 Metetra
.636 .826 .974 r
.40972 .25613 .41799 .26241 .43182 .25699 .42359 .25136 Metetra
.572 .824 .993 r
.42359 .25136 .43182 .25699 .44569 .25287 .4375 .24776 Metetra
.482 .803 1 r
.4375 .24776 .44569 .25287 .4596 .25019 .45146 .24546 Metetra
.614 .867 .99 r
.45146 .24546 .4596 .25019 .47358 .24904 .46557 .24062 Metetra
.655 .778 .939 r
.46557 .24062 .47358 .24904 .48771 .24496 .47976 .23546 Metetra
.656 .751 .92 r
.47976 .23546 .48771 .24496 .50193 .23983 .49402 .23028 Metetra
.656 .751 .92 r
.49402 .23028 .50193 .23983 .51622 .23467 .50836 .22507 Metetra
.656 .751 .92 r
.50836 .22507 .51622 .23467 .53058 .22948 .52278 .21983 Metetra
.656 .751 .92 r
.52278 .21983 .53058 .22948 .54502 .22426 .53727 .21456 Metetra
.656 .751 .92 r
.53727 .21456 .54502 .22426 .55954 .21902 .55184 .20927 Metetra
.656 .751 .92 r
.55184 .20927 .55954 .21902 .57413 .21375 .56648 .20395 Metetra
.656 .751 .92 r
.56648 .20395 .57413 .21375 .5888 .20845 .5812 .1986 Metetra
.656 .751 .92 r
.5812 .1986 .5888 .20845 .60355 .20313 .596 .19322 Metetra
.656 .751 .92 r
.596 .19322 .60355 .20313 .61838 .19777 .61088 .18781 Metetra
.656 .751 .92 r
.61088 .18781 .61838 .19777 .63328 .19239 .62584 .18238 Metetra
.656 .751 .92 r
.62584 .18238 .63328 .19239 .64827 .18698 .64088 .17691 Metetra
.656 .751 .92 r
.64088 .17691 .64827 .18698 .66334 .18154 .656 .17141 Metetra
.656 .751 .92 r
.656 .17141 .66334 .18154 .67848 .17607 .67121 .16589 Metetra
.656 .751 .92 r
.67121 .16589 .67848 .17607 .69371 .17057 .68649 .16034 Metetra
.656 .751 .92 r
.68649 .16034 .69371 .17057 .70902 .16504 .70186 .15475 Metetra
.656 .751 .92 r
.70186 .15475 .70902 .16504 .72441 .15948 .71731 .14914 Metetra
.656 .751 .92 r
.03816 .38443 .04747 .39256 .05956 .38816 .05028 .38 Metetra
.656 .751 .92 r
.05028 .38 .05956 .38816 .07171 .38375 .06246 .37554 Metetra
.656 .751 .92 r
.06246 .37554 .07171 .38375 .08392 .37931 .0747 .37107 Metetra
.656 .751 .92 r
.0747 .37107 .08392 .37931 .09618 .37486 .087 .36657 Metetra
.656 .751 .92 r
.087 .36657 .09618 .37486 .10851 .37038 .09936 .36205 Metetra
.656 .751 .92 r
.09936 .36205 .10851 .37038 .1209 .36587 .11178 .35751 Metetra
.656 .751 .92 r
.11178 .35751 .1209 .36587 .13334 .36135 .12426 .35294 Metetra
.656 .751 .92 r
.12426 .35294 .13334 .36135 .14585 .35681 .1368 .34836 Metetra
.656 .751 .92 r
.1368 .34836 .14585 .35681 .15842 .35224 .14941 .34375 Metetra
.656 .751 .92 r
.14941 .34375 .15842 .35224 .17105 .34765 .16207 .33911 Metetra
.656 .751 .92 r
.16207 .33911 .17105 .34765 .18375 .34303 .1748 .33446 Metetra
.656 .751 .92 r
.1748 .33446 .18375 .34303 .1965 .3384 .1876 .32978 Metetra
.656 .751 .92 r
.1876 .32978 .1965 .3384 .20932 .33374 .20045 .32508 Metetra
.656 .751 .92 r
.20045 .32508 .20932 .33374 .22221 .32906 .21337 .32035 Metetra
.656 .751 .92 r
.21337 .32035 .22221 .32906 .23515 .32435 .22636 .3156 Metetra
.656 .751 .92 r
.22636 .3156 .23515 .32435 .24817 .31962 .23941 .31083 Metetra
.656 .751 .92 r
.23941 .31083 .24817 .31962 .26124 .31487 .25253 .30604 Metetra
.656 .751 .92 r
.25253 .30604 .26124 .31487 .27439 .3101 .26571 .30121 Metetra
.656 .751 .92 r
.26571 .30121 .27439 .3101 .28741 .30781 .27896 .29637 Metetra
.626 .683 .884 r
.27896 .29637 .28741 .30781 .30056 .30477 .29221 .29238 Metetra
.617 .661 .87 r
.29221 .29238 .30056 .30477 .31389 .30049 .30551 .28863 Metetra
.644 .683 .872 r
.30551 .28863 .31389 .30049 .32735 .29513 .31896 .28392 Metetra
.665 .706 .877 r
.31896 .28392 .32735 .29513 .34092 .28893 .33252 .27846 Metetra
.68 .727 .886 r
.33252 .27846 .34092 .28893 .35458 .28219 .34618 .2725 Metetra
.688 .749 .898 r
.34618 .2725 .35458 .28219 .36831 .27521 .3599 .26633 Metetra
.688 .769 .914 r
.3599 .26633 .36831 .27521 .38208 .26833 .37368 .26024 Metetra
.677 .788 .933 r
.37368 .26024 .38208 .26833 .39589 .26187 .38751 .25454 Metetra
.653 .802 .955 r
.38751 .25454 .39589 .26187 .40972 .25613 .40137 .24947 Metetra
.613 .81 .976 r
.40137 .24947 .40972 .25613 .42359 .25136 .41527 .24527 Metetra
.589 .819 .987 r
.41527 .24527 .42359 .25136 .4375 .24776 .42924 .24141 Metetra
.647 .832 .972 r
.42924 .24141 .4375 .24776 .45146 .24546 .44333 .23626 Metetra
.656 .759 .925 r
.44333 .23626 .45146 .24546 .46557 .24062 .4575 .23108 Metetra
.656 .751 .92 r
.4575 .23108 .46557 .24062 .47976 .23546 .47173 .22587 Metetra
.656 .751 .92 r
.47173 .22587 .47976 .23546 .49402 .23028 .48605 .22064 Metetra
.656 .751 .92 r
.48605 .22064 .49402 .23028 .50836 .22507 .50043 .21538 Metetra
.656 .751 .92 r
.50043 .21538 .50836 .22507 .52278 .21983 .5149 .21009 Metetra
.656 .751 .92 r
.5149 .21009 .52278 .21983 .53727 .21456 .52944 .20477 Metetra
.656 .751 .92 r
.52944 .20477 .53727 .21456 .55184 .20927 .54406 .19942 Metetra
.656 .751 .92 r
.54406 .19942 .55184 .20927 .56648 .20395 .55875 .19405 Metetra
.656 .751 .92 r
.55875 .19405 .56648 .20395 .5812 .1986 .57353 .18865 Metetra
.656 .751 .92 r
.57353 .18865 .5812 .1986 .596 .19322 .58838 .18321 Metetra
.656 .751 .92 r
.58838 .18321 .596 .19322 .61088 .18781 .60331 .17775 Metetra
.656 .751 .92 r
.60331 .17775 .61088 .18781 .62584 .18238 .61833 .17226 Metetra
.656 .751 .92 r
.61833 .17226 .62584 .18238 .64088 .17691 .63342 .16674 Metetra
.656 .751 .92 r
.63342 .16674 .64088 .17691 .656 .17141 .6486 .16119 Metetra
.656 .751 .92 r
.6486 .16119 .656 .17141 .67121 .16589 .66386 .15561 Metetra
.656 .751 .92 r
.66386 .15561 .67121 .16589 .68649 .16034 .6792 .15 Metetra
.656 .751 .92 r
.6792 .15 .68649 .16034 .70186 .15475 .69462 .14436 Metetra
.656 .751 .92 r
.69462 .14436 .70186 .15475 .71731 .14914 .71013 .13869 Metetra
.656 .751 .92 r
.02876 .37623 .03816 .38443 .05028 .38 .04092 .37176 Metetra
.656 .751 .92 r
.04092 .37176 .05028 .38 .06246 .37554 .05313 .36726 Metetra
.656 .751 .92 r
.05313 .36726 .06246 .37554 .0747 .37107 .0654 .36275 Metetra
.656 .751 .92 r
.0654 .36275 .0747 .37107 .087 .36657 .07773 .35821 Metetra
.656 .751 .92 r
.07773 .35821 .087 .36657 .09936 .36205 .09013 .35365 Metetra
.656 .751 .92 r
.09013 .35365 .09936 .36205 .11178 .35751 .10258 .34906 Metetra
.656 .751 .92 r
.10258 .34906 .11178 .35751 .12426 .35294 .1151 .34446 Metetra
.656 .751 .92 r
.1151 .34446 .12426 .35294 .1368 .34836 .12767 .33983 Metetra
.656 .751 .92 r
.12767 .33983 .1368 .34836 .14941 .34375 .14031 .33518 Metetra
.656 .751 .92 r
.14031 .33518 .14941 .34375 .16207 .33911 .15301 .3305 Metetra
.656 .751 .92 r
.15301 .3305 .16207 .33911 .1748 .33446 .16578 .3258 Metetra
.656 .751 .92 r
.16578 .3258 .1748 .33446 .1876 .32978 .17861 .32108 Metetra
.656 .751 .92 r
.17861 .32108 .1876 .32978 .20045 .32508 .1915 .31634 Metetra
.656 .751 .92 r
.1915 .31634 .20045 .32508 .21337 .32035 .20446 .31157 Metetra
.656 .751 .92 r
.20446 .31157 .21337 .32035 .22636 .3156 .21748 .30677 Metetra
.656 .751 .92 r
.21748 .30677 .22636 .3156 .23941 .31083 .23057 .30196 Metetra
.656 .751 .92 r
.23057 .30196 .23941 .31083 .25253 .30604 .24373 .29712 Metetra
.656 .751 .92 r
.24373 .29712 .25253 .30604 .26571 .30121 .25695 .29225 Metetra
.656 .751 .92 r
.25695 .29225 .26571 .30121 .27896 .29637 .27024 .28736 Metetra
.656 .751 .92 r
.27024 .28736 .27896 .29637 .29221 .29238 .28359 .28244 Metetra
.655 .73 .904 r
.28359 .28244 .29221 .29238 .30551 .28863 .29702 .2775 Metetra
.642 .7 .888 r
.29702 .2775 .30551 .28863 .31896 .28392 .31049 .27288 Metetra
.648 .705 .888 r
.31049 .27288 .31896 .28392 .33252 .27846 .32404 .26805 Metetra
.661 .724 .896 r
.32404 .26805 .33252 .27846 .34618 .2725 .33769 .26278 Metetra
.667 .744 .907 r
.33769 .26278 .34618 .2725 .3599 .26633 .35142 .25733 Metetra
.666 .762 .922 r
.35142 .25733 .3599 .26633 .37368 .26024 .36521 .25194 Metetra
.654 .777 .939 r
.36521 .25194 .37368 .26024 .38751 .25454 .37905 .24689 Metetra
.639 .791 .956 r
.37905 .24689 .38751 .25454 .40137 .24947 .39295 .2422 Metetra
.653 .808 .958 r
.39295 .2422 .40137 .24947 .41527 .24527 .40693 .23705 Metetra
.655 .784 .943 r
.40693 .23705 .41527 .24527 .42924 .24141 .421 .23188 Metetra
.656 .751 .92 r
.421 .23188 .42924 .24141 .44333 .23626 .43513 .22667 Metetra
.656 .751 .92 r
.43513 .22667 .44333 .23626 .4575 .23108 .44934 .22144 Metetra
.656 .751 .92 r
.44934 .22144 .4575 .23108 .47173 .22587 .46363 .21619 Metetra
.656 .751 .92 r
.46363 .21619 .47173 .22587 .48605 .22064 .47799 .2109 Metetra
.656 .751 .92 r
.47799 .2109 .48605 .22064 .50043 .21538 .49243 .20559 Metetra
.656 .751 .92 r
.49243 .20559 .50043 .21538 .5149 .21009 .50694 .20025 Metetra
.656 .751 .92 r
.50694 .20025 .5149 .21009 .52944 .20477 .52153 .19488 Metetra
.656 .751 .92 r
.52153 .19488 .52944 .20477 .54406 .19942 .5362 .18948 Metetra
.656 .751 .92 r
.5362 .18948 .54406 .19942 .55875 .19405 .55095 .18405 Metetra
.656 .751 .92 r
.55095 .18405 .55875 .19405 .57353 .18865 .56577 .17859 Metetra
.656 .751 .92 r
.56577 .17859 .57353 .18865 .58838 .18321 .58068 .17311 Metetra
.656 .751 .92 r
.58068 .17311 .58838 .18321 .60331 .17775 .59567 .16759 Metetra
.656 .751 .92 r
.59567 .16759 .60331 .17775 .61833 .17226 .61073 .16205 Metetra
.656 .751 .92 r
.61073 .16205 .61833 .17226 .63342 .16674 .62588 .15647 Metetra
.656 .751 .92 r
.62588 .15647 .63342 .16674 .6486 .16119 .64112 .15087 Metetra
.656 .751 .92 r
.64112 .15087 .6486 .16119 .66386 .15561 .65643 .14523 Metetra
.656 .751 .92 r
.65643 .14523 .66386 .15561 .6792 .15 .67183 .13956 Metetra
.656 .751 .92 r
.67183 .13956 .6792 .15 .69462 .14436 .68731 .13387 Metetra
.656 .751 .92 r
.68731 .13387 .69462 .14436 .71013 .13869 .70288 .12814 Metetra
.656 .751 .92 r
.01928 .36795 .02876 .37623 .04092 .37176 .03147 .36344 Metetra
.656 .751 .92 r
.03147 .36344 .04092 .37176 .05313 .36726 .04371 .35891 Metetra
.656 .751 .92 r
.04371 .35891 .05313 .36726 .0654 .36275 .05602 .35435 Metetra
.656 .751 .92 r
.05602 .35435 .0654 .36275 .07773 .35821 .06838 .34977 Metetra
.656 .751 .92 r
.06838 .34977 .07773 .35821 .09013 .35365 .08081 .34517 Metetra
.656 .751 .92 r
.08081 .34517 .09013 .35365 .10258 .34906 .0933 .34054 Metetra
.656 .751 .92 r
.0933 .34054 .10258 .34906 .1151 .34446 .10585 .33589 Metetra
.656 .751 .92 r
.10585 .33589 .1151 .34446 .12767 .33983 .11846 .33122 Metetra
.656 .751 .92 r
.11846 .33122 .12767 .33983 .14031 .33518 .13113 .32653 Metetra
.656 .751 .92 r
.13113 .32653 .14031 .33518 .15301 .3305 .14387 .32181 Metetra
.656 .751 .92 r
.14387 .32181 .15301 .3305 .16578 .3258 .15667 .31707 Metetra
.656 .751 .92 r
.15667 .31707 .16578 .3258 .17861 .32108 .16954 .3123 Metetra
.656 .751 .92 r
.16954 .3123 .17861 .32108 .1915 .31634 .18247 .30751 Metetra
.656 .751 .92 r
.18247 .30751 .1915 .31634 .20446 .31157 .19546 .3027 Metetra
.656 .751 .92 r
.19546 .3027 .20446 .31157 .21748 .30677 .20852 .29786 Metetra
.656 .751 .92 r
.20852 .29786 .21748 .30677 .23057 .30196 .22165 .293 Metetra
.656 .751 .92 r
.22165 .293 .23057 .30196 .24373 .29712 .23485 .28811 Metetra
.656 .751 .92 r
.23485 .28811 .24373 .29712 .25695 .29225 .24811 .2832 Metetra
.656 .751 .92 r
.24811 .2832 .25695 .29225 .27024 .28736 .26144 .27827 Metetra
.656 .751 .92 r
.26144 .27827 .27024 .28736 .28359 .28244 .27483 .2733 Metetra
.656 .751 .92 r
.27483 .2733 .28359 .28244 .29702 .2775 .2883 .26832 Metetra
.656 .751 .92 r
.2883 .26832 .29702 .2775 .31049 .27288 .30183 .2633 Metetra
.655 .743 .914 r
.30183 .2633 .31049 .27288 .32404 .26805 .31544 .25826 Metetra
.655 .739 .911 r
.31544 .25826 .32404 .26805 .33769 .26278 .32911 .2532 Metetra
.656 .745 .916 r
.32911 .2532 .33769 .26278 .35142 .25733 .34286 .24811 Metetra
.656 .755 .923 r
.34286 .24811 .35142 .25733 .36521 .25194 .35668 .24299 Metetra
.656 .763 .929 r
.35668 .24299 .36521 .25194 .37905 .24689 .37057 .23785 Metetra
.656 .762 .928 r
.37057 .23785 .37905 .24689 .39295 .2422 .38453 .23267 Metetra
.656 .751 .92 r
.38453 .23267 .39295 .2422 .40693 .23705 .39856 .22748 Metetra
.656 .751 .92 r
.39856 .22748 .40693 .23705 .421 .23188 .41267 .22225 Metetra
.656 .751 .92 r
.41267 .22225 .421 .23188 .43513 .22667 .42686 .217 Metetra
.656 .751 .92 r
.42686 .217 .43513 .22667 .44934 .22144 .44111 .21172 Metetra
.656 .751 .92 r
.44111 .21172 .44934 .22144 .46363 .21619 .45545 .20641 Metetra
.656 .751 .92 r
.45545 .20641 .46363 .21619 .47799 .2109 .46986 .20107 Metetra
.656 .751 .92 r
.46986 .20107 .47799 .2109 .49243 .20559 .48434 .1957 Metetra
.656 .751 .92 r
.48434 .1957 .49243 .20559 .50694 .20025 .49891 .19031 Metetra
.656 .751 .92 r
.49891 .19031 .50694 .20025 .52153 .19488 .51355 .18489 Metetra
.656 .751 .92 r
.51355 .18489 .52153 .19488 .5362 .18948 .52827 .17944 Metetra
.656 .751 .92 r
.52827 .17944 .5362 .18948 .55095 .18405 .54307 .17395 Metetra
.656 .751 .92 r
.54307 .17395 .55095 .18405 .56577 .17859 .55795 .16844 Metetra
.656 .751 .92 r
.55795 .16844 .56577 .17859 .58068 .17311 .5729 .1629 Metetra
.656 .751 .92 r
.5729 .1629 .58068 .17311 .59567 .16759 .58795 .15733 Metetra
.656 .751 .92 r
.58795 .15733 .59567 .16759 .61073 .16205 .60307 .15173 Metetra
.656 .751 .92 r
.60307 .15173 .61073 .16205 .62588 .15647 .61827 .1461 Metetra
.656 .751 .92 r
.61827 .1461 .62588 .15647 .64112 .15087 .63356 .14044 Metetra
.656 .751 .92 r
.63356 .14044 .64112 .15087 .65643 .14523 .64893 .13474 Metetra
.656 .751 .92 r
.64893 .13474 .65643 .14523 .67183 .13956 .66439 .12902 Metetra
.656 .751 .92 r
.66439 .12902 .67183 .13956 .68731 .13387 .67993 .12326 Metetra
.656 .751 .92 r
.67993 .12326 .68731 .13387 .70288 .12814 .69556 .11748 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.04003 .25401 m
.04482 .2585 L
s
[(-1)] .03045 .24505 1 .93576 Mshowa
.18786 .19613 m
.19242 .20085 L
s
[(-0.5)] .17875 .18668 .96492 1 Mshowa
.34468 .13472 m
.34896 .13969 L
s
[(0)] .33612 .12478 .8612 1 Mshowa
.51132 .06947 m
.51528 .0747 L
s
[(0.5)] .5034 .05901 .75747 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06892 .2427 m
.07176 .24542 L
s
.09814 .23126 m
.10096 .23401 L
s
.1277 .21969 m
.13049 .22246 L
s
.1576 .20797 m
.16037 .21078 L
s
.21848 .18414 m
.22119 .187 L
s
.24947 .172 m
.25214 .1749 L
s
.28082 .15973 m
.28346 .16265 L
s
.31256 .1473 m
.31516 .15025 L
s
.37719 .12199 m
.37973 .125 L
s
.41011 .1091 m
.4126 .11215 L
s
.44343 .09606 m
.44588 .09913 L
s
.47716 .08285 m
.47958 .08595 L
s
.54591 .05593 m
.54824 .0591 L
s
.58094 .04221 m
.58323 .04541 L
s
.61641 .02832 m
.61866 .03155 L
s
.65234 .01425 m
.65454 .01752 L
s
gsave
.29165 .07573 -70.3112 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00o?ooool4o`000003oa0@4?oooooooooo06Gooooo003nooooo`03o`00
0?oooooooooo06Oooooo003nooooo`03o`000?oooooooooo06Oooooo003nooooo`03o`000?oooooo
oooo06Oooooo003nooooo`03o`000?oooooooooo06Oooooo003nooooo`03o`000?oooooooooo06Oo
oooo003nooooo`03o`000?oooooooooo06Oooooo003looooo`03oeEEEOmVIVKo000000[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP1Jooooo`00ooooool:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
F_ooool00?oooooo2_ooool01Ol@413ooooooooooooooooo410@05[ooooo003oooooo`[ooooo00Go
0000ooooooooooooooooo`00001Jooooo`00ooooool:ooooo`05o`000?ooooooooooooooool00000
F_ooool00?oooooo0oooool2o`0000Gooooo00Go410@oooooooooooooooooa0@401Jooooo`00oooo
ool3o`000003ooooool0003ooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Jooooo`00oOoo
ool2o`0000Cooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0F_ooool00?[ooooo0ol0
0005ooooo`;o000000?oooooo`000?ooool0HOooool00?Sooooo0_l00009ooooo`03o`000?oooooo
000006;ooooo003eooooo`?o00002oooool01?l0003oooooooooool0001Qooooo`00loooool2o`00
00?ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo0000063ooooo003`oooo
o`?o00004?ooool01Ol0003ooooooooooooooooo0000063ooooo003]ooooo`?o00004oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo05gooooo003[ooooo`;o00005oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo05cooooo002dooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Nooooo`?o000000?oooooo`00
0?ooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05cooooo002dooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06oooool2o`00
00Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
05_ooooo002dooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Goooo
o`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05[ooooo002dooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Fooooo`;o00008Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo05[ooooo002dooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo1?l0000Rooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0FOooool00;Cooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo01Cooooo0_l00003ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool01?ooool2o`0005_ooooo002dooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`0Aooooo`?o0000:?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo05Sooooo001looooo`;o00000_ooool2o`0003;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co00003_ooool2o`0002_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1G
ooooo`00O?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgE;ooooo0ol0000]ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0Eoooool007gooooo00CogMgMo`000?l@413oc<c<DOoo
ool2o`0000;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo05Kooooo001mooooo`04onk^k_lQ8B7o410@onk^kTkooooo0ol0000booooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0EOooool007gooooo00Co8B4QogMgMomgMgOo<S8bBooo
ool3o`0003Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Eooooo`00O?ooool2
o`0000;ooooo0_l00018ooooo`;o0000>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo05Cooooo0037ooooo`Go0000>?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
05?ooooo0035ooooo`;o00001Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0Doooool00<;ooooo0ol00010ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0D_ooool00<3ooooo0_l00013ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0DOooool00;gooooo0ol00015ooooo`03o`000?oooooooooo00_ooooo0_l0001C
ooooo`00^oooool2o`0000?ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo053ooooo002hooooo`?o0000B_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo04oooooo002fooooo`;o0000COooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo04oooooo002<ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0004oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`1>ooooo`00S?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg023ooooo0_l00002ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`1=ooooo`00S?ooool01Ol@413ooooooooooooooooo410@01gooooo
0ol0001Dooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0COooool008cooooo00Go
0000ooooooooooooooooo`00000Jooooo`?o0000Eoooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo04cooooo002<ooooo`05o`000?ooooooooooooooool000006?ooool2o`0005[ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`1;ooooo`00S?ooool01Ol@413ooooooooo
oooooooo410@01Gooooo0ol00002ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`1;ooooo`00S?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo
0_l0001Oooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0B_ooool008cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0@ooooo`?o0000H?ooool2o`0001Gooooo00?o0000ooooooooool0
B_ooool009oooooo0_l0001Pooooo`?o000000?oYl3[o`000?l000005?ooool2o`0004_ooooo002L
ooooo`?o000000?oooooo`000?ooool0GOooool2o`0000GoYl3[0_l0000Eooooo`03o`000?oooooo
oooo04Sooooo002Jooooo`;o0000H?ooool3o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`00
01Cooooo00?o0000ooooooooool0B?ooool009Oooooo0ol0001Pooooo`;o00001_nW`>/00ol0003o
Yl3[o`000002o`000003ojO0jol0003ooooo01Cooooo00?o0000ooooooooool0Aoooool009Gooooo
0_l0001Pooooo`?o00000_nW`>/00ol0003oYl3[ojO0j`03ojO0j`;o00000_nW`>/01?l0003oYl3[
ojO0jol0000Eooooo`03o`000?oooooooooo04Kooooo002Booooo`Co0000G_ooool3o`0000KoYl3[
00?o0000ojO0jol000000_l000001OnW`>_o0000ojO0jonW`>_o000000;oYl3[00?o0000oooooooo
ool04oooool00ol0003oooooooooo`16ooooo`00T?ooool2o`0000Cooooo00?o0000ooooooooool0
Eoooool4o`0000?oYl3[00?o0000ojO0jonW`>/00onW`>/2o`0000GoYl3[00?o0000ojO0jol00000
0_nW`>/2o`0001Gooooo00?o0000ooooooooool0AOooool008gooooo0ol0001Mooooo`?o000000?o
Yl3[o`000?nW`>/01OnW`>/00ol0003oYl3[o`000002o`000003ojO0jol0003oYl3[00CoYl3[00?o
0000ojO0jol000000_l000000onW`>_o0000ooooo`0Eooooo`03o`000?oooooooooo04Cooooo002;
ooooo`;o0000G_ooool2o`0000GoYl3[00?o0000ojO0jonW`>/00onW`>/2o`0000GoYl3[00Co0000
ojO0jonW`>_oYl3[1?l00004ojO0j`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0A?oo
ool008Sooooo1Ol0001Looooo`;o00000_nW`>/00ol0003oYl3[ojO0j`03ojO0j`03o`000?nW`>_o
000000;o000000?oYl3[o`000?nW`>/01?nW`>/4o`0000;oYl3[0_l00004ojO0j`;o00005Oooool0
0ol0003oooooooooo`13ooooo`00QOooool3o`0005oooooo0_l00005ojO0j`04o`000?nW`>_oYl3[
ojO0j`?o00001OnW`>/00ol0003oYl3[o`000002o`000003ojO0jol0003oYl3[00CoYl3[00?o0000
ojO0jol000000_l000000onW`>_o0000ooooo`0Eooooo`03o`000?oooooooooo04;ooooo0023oooo
o`;o0000Goooool3o`000003ojO0jol0003oYl3[00CoYl3[1?l00002ojO0j`03o`000?nW`>_oYl3[
00?oYl3[0_l00005ojO0j`03o`000?nW`>_oYl3[00;oYl3[0_l00005ojO0j`03o`000?oooooooooo
01;ooooo0_l00014ooooo`00B_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd08?ooool3o`0005oooooo0_l00005ojO0j`03o`000?nW`>_o
000000;o000000?oYl3[o`000?nW`>/01?nW`>/00ol0003oYl3[o`000002o`000003ojO0jol0003o
Yl3[00CoYl3[00?o0000ojO0jol000001?l00005ojO0j`;o00005Oooool00ol0003oooooooooo`11
ooooo`00B_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01gooooo0_l000000ooooooo0000ooooo`1Looooo`?o000000?oYl3[o`000?nW`>/01?nW`>/2
o`0000GoYl3[00?o0000ojO0jonW`>/00_nW`>/2o`0000GoYl3[00Co0000ojO0jonW`>_oYl3[0ol0
0003ojO0j`04o`000?nW`>_o0000ojO0j`?o000000?oYl3[o`000?ooool05Oooool00ol0003ooooo
ooooo`10ooooo`00@_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo01Wooooo0ol0001Nooooo`?o00001OnW`>/00ol0003oYl3[o`000002o`000003ojO0
jol0003oYl3[00CoYl3[00?o0000ojO0jol000000_l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[
1?l00003ojO0j`05o`000?nW`>_oYl3[o`000?nW`>/00_l00005ojO0j`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0@?ooool004[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo01Sooooo0_l0001Mooooo`Co00000_nW`>/00ol0003oYl3[ojO0j`03ojO0j`;o
00001OnW`>/00ol0003oYl3[ojO0j`02ojO0j`;o00001_nW`>/01_l0003oYl3[o`000?l0003oYl3[
o`0000KoYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`03ojO0j`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0?oooool004[ooooo00Go0000ooooooooooooooooo`00
000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool3o`0005cooooo0ol000000onW`>_o0000
ojO0j`04ojO0j`03o`000?nW`>_o000000;o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`03o`00
0?nW`>_o000000;o00000_nW`>/00ol0003oYl3[ojO0j`03ojO0j`;o00001?nW`>/00ol0003oYl3[
ojO0j`03ojO0j`?o00001?nW`>/01?l0003oYl3[ojO0jonW`>/3o`0001Gooooo00?o0000oooooooo
ool01_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd08_ooool004[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo
oooo01Kooooo0_l000000ooooooo0000ooooo`1Jooooo`;o00001OnW`>/00ol0003oYl3[ojO0j`02
ojO0j`;o00001_nW`>/00ol0003oYl3[ojO0j`03o`0000KoYl3[00?o0000ojO0jol000000_l00000
0onW`>_o0000ojO0j`04ojO0j`03o`000?nW`>_o000000;o000000CoYl3[o`000?nW`>_o00000onW
`>/4o`0000;oYl3[00?o0000ooooooooool04oooool00ol0003oooooooooo`06ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool08Oooool004[ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo01?ooooo0ol0001Mooooo`;o0000
0_nW`>/00ol0003oYl3[ojO0j`03ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW
`>/00onW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/00onW`>/2o`0000GoYl3[00Co0000ojO0jonW
`>_oYl3[0ol00005ojO0j`Go000000?oYl3[o`000?nW`>/01?nW`>/00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo023ooooo001:ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo0_l0001N
ooooo`;o00001OnW`>/01?l0003oYl3[ojO0jonW`>/3o`0000GoYl3[00?o0000ojO0jol000000_l0
00000onW`>_o0000ojO0j`04ojO0j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/01?nW
`>/4o`0000;oYl3[00?o0000ojO0jonW`>/00onW`>/2o`0000GoYl3[00?o0000ojO0jonW`>/00_nW
`>/2o`0001Gooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool08Oooool006cooooo0ol0001Mooooo`?o000000?oYl3[o`000?nW`>/01?nW
`>/4o`0000;oYl3[00?o0000ojO0jonW`>/00onW`>/2o`0000GoYl3[00Co0000ojO0jonW`>_oYl3[
0ol00005ojO0j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/01?nW`>/00ol0003oYl3[
o`000002o`000003ojO0jol0003oYl3[00CoYl3[00?o0000ojO0jol000000_l000000onW`>_o0000
ooooo`0Dooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`08_ooool006[ooooo0_l00002ooooo`03o`000?oooooooooo05So
oooo0ol00005ojO0j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/01?nW`>/00ol0003o
Yl3[o`000002o`000003ojO0jol0003oYl3[00CoYl3[1?l00002ojO0j`03o`000?nW`>_oYl3[00?o
Yl3[0_l00005ojO0j`03o`000?nW`>_oYl3[00;oYl3[0_l00004ojO0j`;o00000onW`>/3o`0000Go
Yl3[00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`0Tooooo`00Ioooool3o`0005_ooooo1?l00003ojO0j`03
o`000?nW`>_oYl3[00;oYl3[0_l00005ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00001OnW`>/00ol0
003oYl3[o`000002o`000003ojO0jol0003oYl3[00CoYl3[00?o0000ojO0jol000000_l000000onW
`>_o0000ojO0j`04ojO0j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/00onW`>/5o`00
00;oYl3[00?o0000ojO0jonW`>/00onW`>/2o`0001Cooooo0_l00004ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`0;ooooo`?o000000?o410@ooooooooool04oooool0
06Cooooo0ol0001Looooo`;o00000_nW`>/00ol0003oYl3[ojO0j`03ojO0j`04o`000?nW`>_o0000
o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/4o`0000?oYl3[00?o0000ojO0jonW`>/00_nW`>/2
o`0000GoYl3[00?o0000ojO0jonW`>/00_nW`>/2o`0000GoYl3[00Co0000ojO0jonW`>_oYl3[0ol0
0005ojO0j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/01?nW`>/00ol0003oYl3[o`00
0002o`000003ojO0jol0003ooooo01;ooooo00?o0000ooooool000001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo1?l0000<ooooo`03oa0@4?nj^[[ooooo01Cooooo001Rooooo`;o0000GOoo
ool2o`0000GoYl3[00Co0000ojO0jonW`>_oYl3[0ol00005ojO0j`06o`000?nW`>_o0000o`000?nW
`>_o00001_nW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[00?o0000
ojO0jol000000_l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[1?l00002ojO0j`03o`000?nW`>_o
Yl3[00?oYl3[0_l00002ojO0j`04o`000?nW`>_oYl3[o`0000CoYl3[0_l00005ojO0j`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool08_ooool00onHV9So<S8booooo`0Dooooo`00Goooool3
o`000003ooooool0003ooooo05Wooooo0ol000000onW`>_o0000ojO0j`04ojO0j`Co00000_nW`>/0
0ol0003oYl3[ojO0j`03ojO0j`;o00001?nW`>/00ol0003oYl3[ojO0j`03ojO0j`;o00001OnW`>/0
0ol0003oYl3[ojO0j`03o`0000KoYl3[00Ko0000ojO0jol0003o0000ojO0jol00005ojO0j`03o`00
0?nW`>_o000000;o00000_nW`>/00ol0003oYl3[o`000002ojO0j`03o`000?nW`>_o000000;o0000
00?oYl3[o`000?nW`>/01?nW`>/2o`0001Cooooo00?o0000ooooooooool08_ooool00ooMgMgo0000
okZj^P0Dooooo`00GOooool2o`0000Gooooo00?o0000ooooooooool0E?ooool3o`0000GoYl3[00?o
0000ojO0jol000000_l000000onW`>_o0000ojO0j`04ojO0j`03o`000?nW`>_o000000;o000000?o
Yl3[o`000?nW`>/01?nW`>/00ol0003oYl3[o`000002o`000003ojO0jol0003oYl3[00CoYl3[0ol0
0003ojO0j`03o`000?nW`>_oYl3[00?oYl3[0_l00004ojO0j`03o`000?nW`>_oYl3[00;oYl3[0_l0
0006ojO0j`;o000000CoYl3[o`000?l0003o00001OnW`>/00ol0003oYl3[o`000002o`000003ojO0
jol0003ooooo01Cooooo00?o0000ooooooooool08Oooool00omEEEGoMgMgodA4A00Dooooo`00F_oo
ool3o`0005[ooooo1?l00003ojO0j`03o`000?nW`>_oYl3[00;oYl3[0_l00005ojO0j`03o`000?nW
`>_oYl3[00;oYl3[0_l00005ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00001OnW`>/00ol0003oYl3[
o`000002o`000003ojO0jol0003oYl3[00CoYl3[00?o0000ojO0jol000000_l000000onW`>_o0000
ojO0j`04ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00onW`>/3o`0000?o
Yl3[00?o0000ojO0jonW`>/00_nW`>/2o`0000GoYl3[00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Oooooo`05omgMgOl@413oooooob4Q8OoMgMd04oooool005Sooooo0_l0001Kooooo`;o
000000?oYl3[o`000?nW`>/01OnW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`000?nW`>_oYl3[
00;oYl3[00?o0000ojO0jol000000_l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[1?l00002ojO0
j`03o`000?nW`>_oYl3[00?oYl3[0_l00005ojO0j`03o`000?nW`>_oYl3[00;oYl3[0_l00005ojO0
j`04o`000?nW`>_oYl3[ojO0j`?o00001OnW`>/00ol0003oYl3[o`000002o`000003ojO0jol0003o
Yl3[00CoYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`;o00005?oo
ool00ol0003oooooooooo`0Oooooo`05ofIVI_n7QhOooooooiRHV?mEEED04oooool005Gooooo0ol0
0002ooooo`03o`000?oooooooooo05Kooooo0_l00004ojO0j`03o`000?nW`>_oYl3[00?oYl3[0_l0
0005ojO0j`03o`000?nW`>_oYl3[00?o00001_nW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`00
0?nW`>_oYl3[00;oYl3[00?o0000ojO0jol000000_l000000onW`>_o0000ojO0j`04ojO0j`03o`00
0?nW`>_o000000;o000000?oYl3[o`000?nW`>/01?nW`>/4o`0000;oYl3[00?o0000ojO0jonW`>/0
0onW`>/2o`0000CoYl3[0_l00003ojO0j`?o00001OnW`>/01_l0003oYl3[o`000?l0003oYl3[o`00
01Gooooo00?o0000ooooooooool07Oooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo
017ooooo001Cooooo`;o0000Foooool3o`000003ojO0jol0003oYl3[00CoYl3[00?o0000ojO0jol0
00000_l000000onW`>_o0000ojO0j`04ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`03ojO0j`;o
00001OnW`>/00ol0003oYl3[ojO0j`03o`0000GoYl3[00Co0000ojO0jonW`>_oYl3[0ol00005ojO0
j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/01?nW`>/00ol0003oYl3[o`000002o`00
0003ojO0jol0003oYl3[00?oYl3[1Ol00002ojO0j`03o`000?nW`>_oYl3[00?oYl3[0_l00004ojO0
j`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07?ooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo013ooooo000[ooooo`Co000000?o410@ooooooooool07_ooool3o`00
05_ooooo0_l00005ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00001OnW`>/00ol0003oYl3[o`000002
o`000003ojO0jol0003oYl3[00CoYl3[00?o0000ojO0jol000000_l000000onW`>_o0000ojO0j`04
ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`02ojO0j`Co00000onW`>/00ol0003oYl3[ojO0j`02
ojO0j`;o00001OnW`>/01?l0003oYl3[ojO0jonW`>/3o`0000GoYl3[00?o0000ojO0jol000000_l0
00000onW`>_o0000ojO0j`04ojO0j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/01?nW
`>/00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03Gooooo000]ooooo`03o`000?oooooo
oooo01kooooo0ol0001Kooooo`;o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`Co00000onW`>/0
0ol0003oYl3[ojO0j`02ojO0j`;o00001OnW`>/01?l0003oYl3[ojO0jonW`>/3o`0000GoYl3[00?o
0000ojO0jol000000_l000000onW`>_o0000ojO0j`04ojO0j`04o`000?nW`>_o0000o`0000;oYl3[
00?o0000ojO0jonW`>/00onW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`000?nW`>_oYl3[00;o
Yl3[1?l00002ojO0j`03o`000?nW`>_oYl3[00?oYl3[0_l00002ojO0j`04o`000?nW`>_oYl3[o`00
00CoYl3[0_l00005ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00005?ooool00ol0003oooooooooo`0d
ooooo`008_ooool6o`0000Gooooo00?o0000ooooooooool06oooool3o`0000?ooooo00?o0000oooo
ooooool0EOooool3o`0000GoYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`03
ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/4o`0000;oYl3[00?o
0000ojO0jonW`>/00onW`>/2o`0000GoYl3[00?o0000ojO0jonW`>/00_nW`>/2o`0000GoYl3[00Co
0000ojO0jonW`>_oYl3[0ol00005ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW
`>/00_nW`>/00ol0003oYl3[o`000002o`000003ojO0jol0003oYl3[00;oYl3[00Co0000ojO0jol0
003oYl3[0ol000000onW`>_o0000ojO0j`04ojO0j`Co00000_nW`>/00ol0003oooooooooo`0Aoooo
o`?o0000=Oooool002gooooo00?o0000ooooooooool06Oooool2o`0005[ooooo1?l00002ojO0j`03
o`000?nW`>_oYl3[00?oYl3[0_l00005ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00001OnW`>/01?l0
003oYl3[o`000?l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[00?o0000ojO0jol000000_l00000
0onW`>_o0000ojO0j`04ojO0j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/01?nW`>/4
o`0000;oYl3[00?o0000ojO0jonW`>/00onW`>/2o`0000GoYl3[00?o0000ojO0jonW`>/00ol00005
ojO0j`03o`000?nW`>_oYl3[00Co00001OnW`>/00ol0003oYl3[o`000002o`000003ojO0jol0003o
Yl3[00CoYl3[00?o0000ooooooooool04_ooool00ol0003oooooooooo`0cooooo`00;Oooool00ol0
003oooooooooo`0Fooooo`?o0000F_ooool2o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/00ol0
003oYl3[o`000002o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/4o`0000;oYl3[00?o0000ojO0
jonW`>/00onW`>/2o`0000GoYl3[00?o0000ojO0jonW`>/00ol00005ojO0j`04o`000?nW`>_oYl3[
ojO0j`?o00001OnW`>/00ol0003oYl3[o`000002o`000003ojO0jol0003oYl3[00CoYl3[00?o0000
ojO0jol000000_l000000onW`>_o0000ojO0j`04ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`02
ojO0j`Co00000_nW`>/00ol0003oYl3[ojO0j`03ojO0j`;o00001OnW`>/01?l0003oYl3[ojO0jonW
`>/3o`0001Cooooo00?o0000ooooooooool0<_ooool002gooooo00?o0000ooooooooool04oooool3
o`000003ooooool0003ooooo05Oooooo0ol00005ojO0j`03o`000?nW`>_oYl3[00?o00001_nW`>/0
1?l0003oYl3[o`000?l00002ojO2k003o`000?nW`>_oYl3[00;oYl3[00?o0000ojO0jol000000_l0
00000onW`>_o0000ojO0j`04ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`02ojO0j`Co00000onW
`>/00ol0003oYl3[ojO0j`02ojO0j`;o00001OnW`>/01?l0003oYl3[ojO0jonW`>/3o`0000GoYl3[
00?o0000ojO0jol000000_l000000onW`>_o0000ojO0j`04ojO0j`08o`000?nW`>_o0000o`000?nW
`>_o0000ojO0jol00003ojO0j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/01?nW`>/4
o`0000;oYl3[00?o0000ooooooooool04oooool00ol0003oooooooooo`0aooooo`00;Oooool00ol0
003oooooooooo`0Aooooo`;o0000FOooool4o`0000;oYl?]00?o0000ojO0jonW`>/00onW`>/3o`00
00?oYlSa00?o0000ojO0jonW`>/00onW`>/2o`0000GoYl;/00?o0000ojO0jonW`>/00ol00005ojO0
j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/01?nW`>/01?l0003oYl3[o`000?l00002
ojO0j`03o`000?nW`>_oYl3[00?oYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0
j`02ojO0j`Co00000_nW`>/00ol0003oYl3[ojO0j`03ojO0j`;o00001OnW`>/00ol0003oYl3[ojO0
j`02ojO0j`;o00001?nW`>/2o`0000;oYl3[0ol00005ojO0j`03o`000?nW`>_o000000;o000000?o
Yl3[o`000?nW`>/01?nW`>/00ol0003oooooooooo`0Booooo`03o`000?oooooooooo037ooooo000[
ooooo`03oeEEEOmVIVKo0000013ooooo0ol0001Iooooo`;o00000_nW`nd00ol0003oYl?]ojO3k@02
ojO3k@03o`000?nW`>_o000000;o00000_nWc_D00ol0003oYlSaojO8l@02ojO8l@03o`000?nW`>_o
000000;o000000?oYMCho`000?nW`^`01?nW`^`3o`0000?oYlO`00?o0000ojO0jonW`>/00_nW`>/2
o`0000GoYl3[00?o0000ojO0jonW`>/00_nW`>/2o`0000GoYl3[00Co0000ojO0jonW`>_oYl3[0ol0
0005ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/00ol0003oYl3[
o`000002o`000003ojO0jol0003oYl3[00CoYl3[00?o0000ojO0jol000000_l000000onW`>_o0000
ojO0j`03ojO0j`Co00000_nW`>/00ol0003oYl3[ojO0j`03ojO0j`;o00001OnW`>/01?l0003oYl3[
ojO0jonW`>/3o`0001Cooooo00?o0000ooooooooool0<?ooool003cooooo0_l0001Jooooo`;o0000
1OnW`nd00ol0003oYl?]ojO3k@04o`0000GoYlke00?o0000ojO8lOnWb?401?l00004ojGDn003o`00
0?nW`^co000000;o000000?oWMgmo`000?nWao001?nWao001?l0003oYl3[o`000?l00002ojO8l@03
o`000?nW`>_oYl3[00;oYl3[00?o0000ojO0jol000000_l000000onW`>_o0000ojO0j`04ojO0j`Co
00000_nW`>/00ol0003oYl3[ojO0j`03ojO0j`;o00001OnW`>/00ol0003oYl3[ojO0j`03o`0000Go
Yl3[00Co0000ojO0jonW`>_oYl3[0ol00005ojO0j`05o`000?nW`>_o0000o`000?nW`>/00_l00004
ojO0j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/01?nW`>/4o`0000;oYl3[00?o0000
ooooooooool04oooool00ol0003oooooooooo`0_ooooo`00>Oooool3o`0000;ooooo00?o0000oooo
ooooool0E?ooool3o`0000;oYl7/00?o0000ojO3kOnW`nd00_nW`nd3o`0000CoXl[d00Co0000ojO>
mOnWc_GoYlke1?l00004oiKAo003o`000?nUe?SoYMCh00Go00000onMgOd01?l0003oYlO`ojO7l?nW
ao03o`0000GoYlSa00?o0000ojO0jonW`>/00ol00005ojO0j`03o`000?nW`>_o000000;o000000?o
Yl3[o`000?nW`>/01?nW`>/00ol0003oYl3[o`000002o`000003ojO0jol0003oYl3[00CoYl3[0ol0
0002ojO0j`03o`000?nW`>_oYl3[00?oYl3[1?l00002ojO0j`03o`000?nW`>_oYl3[00?oYl3[0_l0
0002ojO0j`;o000000CoYl3[o`000?nW`>_oYl3[0ol00005ojO0j`03o`000?nW`>_o000000;o0000
00?oYl3[o`000?nW`>/01?nW`>/00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02oooooo
000gooooo`;o0000FOooool3o`0000KoYl7/00Co0000ojO3kOl0003o00000_nWa_000ol0003oXl[d
oj?:m002oj?:m0Co00000onLcoT01?l0003oU]7loiKAo?nFdO`4o`0000?oNlgo2Ol00003ohgNoP04
o`000?nWb?7oYlSaojO8l@Co00000onWa>h00ol0003oYl3[ojO0j`02ojO0j`;o00001OnW`>/01?l0
003oYl3[ojO0jonW`>/3o`0000GoYl3[00?o0000ojO0jol000000_l000000onW`>_o0000ojO0j`03
ojO0j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/01?nW`>/00ol0003oYl3[o`000002
o`000007ojO0jol0003o0000o`000?nW`>_o0000ojO0j`03o`0000?oYl3[00?o0000ojO0jonW`>/0
0_nW`>/2o`0000GoYl3[00Co0000ojO0jonW`>_oYl3[0ol0000Dooooo`03o`000?oooooooooo02ko
oooo000dooooo`?o0000F?ooool3o`0000?oYkkZ00?o0000ojO1k?nW`N`00onW`N`2o`0000GoYlK`
00Co0000oj?:m?l0003o00000onWcO@00ol0003oW<oioic?n@05o`0000?oT];n1?l00003ogkBo`04
o`000?mMa?_oGLCkoeg4n`Wo00000_n3g_`00ol0003oYlC^ojO4kP03ojO4kP04o`000?nW`>_o0000
o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/4o`0000;oYl3[00?o0000ojO0jonW`>/00onW`>/2
o`0000GoYl3[00?o0000ojO0jonW`>/00ol00005ojO0j`04o`000?nW`>_oYl3[ojO0j`?o000000Oo
Yl3[o`000?l0003o0000ojO0jol0003oYl3[00?o000000?oYl3[o`000?nW`>/01?nW`>/01_l0003o
Yl3[o`000?l0003oYl3[o`0000GoYl3[1?l00002ojO0j`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0;Oooool003?ooooo0_l0001Hooooo`;o00000_nW_NT00ol0003oYkkZojNnjP02ojNn
jP03o`000?nW`Nco000000;o000000?oZ/?/o`000?nWa_001?nWa_02o`0000GoYlgd0ol00004oj;C
n@04o`000?nBd_ko0000o`0000?oV=Om00?o0000ogkBoomnd_l01Ol00002oeg8nP_o00000onWa>h3
o`0000GoYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`03o`000?nW
`>_o000000;o000000?oYl3[o`000?nW`>/01?nW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/00_nW
`>/4o`000004ojO0jol0003o0000o`0000CoYl3[0_l00003ojO0j`03o`000?nW`>_o000000?oYl3[
0ol00004ojO0j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/01?nW`>/00ol0003ooooo
ooooo`0Aooooo`;o0000;oooool003?ooooo0ol0001Eooooo`;o00001OnW_NT00ol0003oYkkZojNn
jP03o`0000GoZ/?/00?o0000ojO6l?l000000_l00002ojg9kP03o`000?nWcOCo000000;o00000_n]
d?801?l0003oX]?ioj;CnOnRdoT4o`0000?oV=Om1?l00003oh;Go`Co00000omOboT;o`0000;oQ^?i
00?o0000ojO0jonW`>/00onW`>/2o`0000GoYl3[00?o0000ojO0jonW`>/00ol00005ojO0j`03o`00
0?nW`>_o000000;o000000?oYl3[o`000?nW`>/01?nW`>/01?l0003oYl3[o`000?l00002ojO0j`?o
00000_nW`>/00ol0003oYl3[o`000002o`000003ojO0jol0003oYl3[00?oYl3[1Ol00002ojO0j`03
o`000?nW`>_oYl3[00;oYl3[0_l00005ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00005?ooool00ol0
003oooooooooo`0/ooooo`00<_ooool2o`0000;ooooo00?o0000ooooooooool0Coooool3o`000003
ojNnjOl0003oYkgY00CoYkgY0ol00003ojZnj003o`000?nZ`ncoZ/?/00;oZ/?/0ol00004ojg9kP?o
00001?n]d?84o`0000?oZMOh1?l00003oikLo@Co00000_n8foh5o`0000;oHm3h3Ol000001_nW`>_o
0000o`000?l0003oU>Kko`0000GoYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00;oYl3[0_l00005
ojO0j`04o`000?nW`>_oYl3[ojO0j`?o000000KoYl3[o`000?l0003o0000ojO0jol00002ojO0j`?o
00001OnW`>/00ol0003oYl3[o`000002o`000003ojO0jol0003oYl3[00CoYl3[00Ko0000ojO0jol0
003o0000ojO0jol00005ojO0j`Co00000_nW`>/00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo02cooooo000cooooo`05o`000?ooooooooooooooool00000COooool3o`0000GoYkkY00?o0000
ojNmjOl000000_l000000onY^NGo0000ojZnj004ojZnj004o`000?nZ`nco0000o`0000?o/<CY00Co
0000ojg9k_l0003o00000oncc>`01?l0003o[M3bo`000?l00003ok?Cl@04o`000?nYeoSo0000o`00
00?o/=_f00Co0000oikLoOl0003o00000onUh?/3o`0000?oSn3m1?l00003of[Dma7o000000KoYl3[
o`000?l0003o0000oj?Jnol00005ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW
`>/00_nW`>/4o`000004ojO0jol0003o0000o`0000CoYl3[0ol00003ojO0j`04o`000?nW`>_oYl3[
ojO0j`?o00000onW`>/00ol0003oYl3[o`000003ojO0j`?o00001?nW`>/00ol0003oYl3[o`000002
o`000003ojO0jol0003oYl3[00CoYl3[00?o0000ooooooooool04_ooool00ol0003oooooooooo`0[
ooooo`00<_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Oooooo0ol00003ojO0
j`03o`000?nW_^WoYkkY00;oYkkY0_l00005ojVii@03o`000?nZ_^SoZ[kX00;oZ[kX0ol00004ok34
j@;o00001Oncc>`2o`0000Go/m?a0ol00004ok3KmPCo000000?oYN3ko`000?l000000_n]i?T4o`00
00;oV>Gl1ol00002ogcOn0oo00001?nSf_/01?l0003oYl3[ojO0jonW`>/3o`0000GoYl3[00Go0000
ojO0jol0003o0000ojO0j`04o`0000;oYl3[00?o0000ojO0jol000000_l000000onW`>_o0000ojO0
j`03ojO0j`Co00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`Go00000_nW`>/00ol0003oYl3[ojO0
j`02ojO0j`;o00001OnW`>/01?l0003oYl3[ojO0jonW`>/3o`0001Cooooo00?o0000ooooooooool0
:_ooool003;ooooo0_l00005ooooo`03o`000?oooooooooo04Cooooo0_l00002ojO0j`03o`000?nW
`>_oYl3[00;oYl3[00Co0000ojNnjOl0003o00000_nU]><00ol0003oZKWUojVii@02ojVii@03o`00
0?nZ_^So000000;o00000on`_nD01?l0003o/<CYo`000?l00002okG6i`05o`000?ncc>co/lc/ok?<
k?l000000_nic^X01Ol0003o/m?aok?ClOncdo7o000000?o^]K^00Co0000ok3Km_l0003o00000ong
g_<2o`0000?o[NCi00Co0000okGWmoneioOo]NOg0ol000001?nQjO_o0000o`000?l00002oj[/n@?o
000000?oR>Gio`000?l000000ol00002oj7/n@Co000000CoM=cgo`000?l0003o00000_nSf_/5o`00
00;oYl3[00?o0000ojO0jonW`>/00onW`>/2o`000003ojO0jol0003o000000;o00000onW`>/3o`00
00GoYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`03o`000?nW`>_o
000000;o000000?oYl3[o`000?nW`>/01?nW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`000?nW
`>_oYl3[00;oYl3[1?l00002ojO0j`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:_oo
ool003;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`10ooooo`?o00001OnW`>/0
0ol0003oYl3[ojO0j`03o`0000GoYKCS00?o0000ojViiOnY^ND00ol00006ok2oi@;o00001Onea^L0
0ol0003o/lc/o`000004okW>jP03o`000?ncdo7o000000Co^]K^0_l00003okONl`;o00000_nnhO00
0ol0003o[NCio`000003okGWm`03o`000?nmjO?o_NWc00Co000000?oZ^cio`000?l000000_nck_H6
o`000003oj7/nOl0003o000000?o[>gh2_l00005ojO0j`03o`000?nW`>_o000000;o000000?oYl3[
o`000?l000000onW`>/4o`0000;oYl3[00?o0000ojO0jonW`>/00onW`>/2o`0000GoYl3[00?o0000
ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_o000000?oYl3[0ol00005ojO0j`06o`000?nW`>_o
0000o`000?nW`>_o00001OnW`>/00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Wooooo
000booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>oooool4o`0000;oYl3[00?o
0000ojO0jonW`>/00onW`>/3o`0000?oY;?S00?o0000ojFdhonU]><00_nU]><3o`0000?o[[[R00Co
0000ok2oiOn`_nGo/;oU0_l000000one`>?o0000okG6i`04okG6i`;o00001Onic^X2o`0000?o^]K^
0_l00002ol7Hj`03o`000?ngg_?o000000Co_^7`1?l000001OneioOo0000okgYlonmjO?o000000?o
a>[`0ol000001?nck_Ko0000o`000?nlko<2o`0000;oa>k`0ol000001_n/kOSo0000o`000?l0003o
]^gfo`0000;o_^[c0ol00002oj;To0;o00000onW`>/3o`000007ojO0jol0003o0000o`000?nW`>_o
0000ojO0j`02o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/00ol0003oYl3[o`000002o`000003
ojO0jol0003oYl3[00CoYl3[0ol00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[1Ol00002ojO0j`03
o`000?nW`>_oYl3[00?oYl3[0_l00004ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00005?ooool00ol0
003oooooooooo`0Xooooo`00<_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03So
oooo0_l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[00?o0000ojO0jol000000_l000000onW^^Oo
0000ojBch`04ojBch`06o`000?nU]>?o0000o`000?nZ]>3o00001On^^^800ol0003o/;oUo`000004
okG0h`03o`000?nea^Oo000000;o00000_nkb>@00ol0003o^LkZo`000002o`0000;o_m3W00?o0000
ok[Fk_l000001?o1f>/4o`000003okkQl?l0003o000000?oaN;]0ol000001?nmjO?o0000olCZl?o4
j_02o`0000;ob^[/0ol000000onlko?o0000olC^l002olC^l003o`000?o:k>cob^c/00Co000000Go
]^gfo`000?nnj_?o_^[co`000002olCVk`?o00000_n/hOT7o`0000?oYl3[0ol00005ojO0j`03o`00
0?nW`>_oYl3[00?o00001OnW`>/00ol0003oYl3[o`000002o`000003ojO0jol0003oYl3[00?oYl3[
00?o0000ojO0jol000001?l00005ojO0j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/0
0onW`>/4o`0000;oYl3[00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Xooooo`00<_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Gooooo0_l00005ojO0j`03o`000?nW
`>_oYl3[00?o00001OnW^^L00ol0003oY;?SojBch`02ojBch`;o00001?nZ]>000ol0003o[[[Rojjj
hP02ojjjhP;o00001One`><2o`0000Go^lST0_l00005oko@i`?o00000oo1f>/01?l0003oam[WolOJ
ioo7f^L2o`0000?oaN;]0_l00002ol_Sj@?o000000?oa>[`o`000?o:j^`00_o:j^`01?l0003od>WW
om3Yioo@jNL3o`000005olC^l?l0003ob^c/ol[/k?l000000oo?j^P3o`000005okkZlol0003oa>K_
olCVkol000000_o8hNX00ol0003o[>7io`00000:o`0000;oY=Ki00?o0000ojO0jonW`>/00onW`>/3
o`0000;oYl3[00?o0000ojO0jonW`>/00onW`>/2o`0000GoYl3[00?o0000ojO0jonW`>/00ol00003
ojO0j`03o`000?nW`>_o000000?oYl3[0ol00005ojO0j`06o`000?nW`>_o0000o`000?nW`>_o0000
1OnW`>/00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Oooooo000aooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0<_ooool2o`0000;oYl3[00?o0000ojO0jonW`>/00_nW
`>/3o`0000?oYl3[00?o0000ojNjionW^^L00_nW^^L00ol0003oY;?So`000002o`000003ojB^gol0
003oZ[CP00CoZ[CP00Co0000ojjjh_l0003o00000_nc^]l01Ol0003o]L3SokG0hone`>?o000000;o
^/;O00Go0000ok_8i?nkb>Co^lSTo`000002ol79h@05o`000?nod>Oo_m3Woko@iol000000oo5dN<0
0ol0003o`MS[o`000003olOJi`06o`000?o=fnCocM_To`000?o5h^go00000oo;hnT01?l0003odN?U
om7SiOoAhnD3o`000003ol[Zk?l0003od>WW00;od>WW00Co0000omGXhooEj>?oeNSS0_l000001?o:
k>co0000oloZj?o?j^P2o`0000?odnKT0_l000000oo4i^oo0000olSQjP02olSQjPKo00000onheNl4
o`0000?oY=Ki00?o0000ojO0jol000000_l000000onW`>_o0000ojO0j`03ojO0j`03o`000?nW`>_o
000000;o000000?oYl3[o`000?nW`>/01?nW`>/3o`0000?oYl3[00Co0000ojO0jonW`>_oYl3[1Ol0
0003ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00001?nW`>/01?l0003oYl3[ojO0jonW`>/3o`0001?o
oooo0_l0000Xooooo`00<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02kooooo
1?l00004ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/00ol0003o
Yk[WojNji`03o`0000GoY:kO00?o0000ojZdh?nZ]>000_nZ]>02o`0000Go/k[O00?o0000okG0hol0
00001?nj`]l00ol0003o^lSTo`000004ol79h@03o`000?nod>Oo000000CoaM7S0_l00003olOJi`03
o`000?o=fnCocM_T00;ocM_T0ol000000oo;hnWo0000om7Si@02om7Si@05o`000?oEh^3oeN;PomGR
h?l000000oo@jNL01Ol0003oeNSSomGXhooEj>?o000000;of>GO0_l000000oo?j^So0000om?Vi003
om?Vi004o`000?oFh^3oe^;Po`0000;ob>7Z0ol000000oo;g>Ko0000o`000005okSEk`?o000000?o
W/Wfo`000?l000000ol00005ojO0j`03o`000?nW`>_oYl3[00Co00001?nW`>/00ol0003oYl3[o`00
0002o`000003ojO0jol0003oYl3[00CoYl3[00?o0000ojO0jol000000ol00005ojO0j`Co00000_nW
`>/00ol0003oYl3[ojO0j`02ojO0j`Co00000onW`>/00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo02Kooooo000aooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:_ooool3
o`0000CoYl3[00?o0000ojO0jonW`>/00ol00005ojO0j`03o`000?nW`>_oYl3[00Co00000_nMZMh0
0ol0003oY:kOojB^g`03ojB^g`03o`000?nZ]>3o000000;o000000?o[[CMo`000?nc^]l01?nc^]l2
o`0000Go^/;O0_l00005ol79h@;o00000oo5dN<2o`0000;obm;P00?o0000olOJiol000001?o=fn@0
0ol0003od]_Oom;Kg`02o`0000?odN?U00Wo0000omGRh?oEh^3oeN;Po`000?oIhMco0000om3Yiol0
00000ooEj><01?l0003of>GOomSUgol00002om_Rf`;o00000ooCi^@00ol0003oe^;PomKRh005o`00
00;obmcV00Go0000olcEhOo<eN7o0000okSEk`03o`0000;o^lkY00?o0000oik9m_nNbOH01?l00005
ojO0j`?o00001?nW`>/00ol0003oYl3[ojO0j`03o`0000GoYl3[00Co0000ojO0jonW`>_oYl3[0ol0
0003ojO0j`;o000000KoYl3[o`000?l0003o0000ojO0jol00005ojO0j`06o`000?nW`>_o0000o`00
0?nW`>_o00001OnW`>/2o`0001?ooooo00?o0000ooooooooool09Oooool0037ooooo0_l0000>oooo
o`03o`000?oooooooooo02Kooooo0ol00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[0ol00003ojO0
j`03o`000?nW`>_oYl3[00;oYl3[0ol00002oj2^hP03o`000?nMZMkoWJWN00;oWJWN00?o0000ojB^
gonT[]l00_nT[]l2o`0000Go[[CM00?o0000ok>jgol000000_l000000onh^mco0000ok[2g`02ok[2
g`;o000000?o_l;Lo`000?o1bN400_o1bN42o`0000;oa/[M00?o0000olGAhol000001?o;d^03o`00
00?ocM_T00Co0000om;KgooBfmoo00000_oFfm/00ol0003odN?Uo`000003omGRh004o`000?oIhMco
fN7LomWQg0?o000000GoeNSSo`000?oHiMoof>GOo`000003om_Rf`06o`000?oMgmOo0000om?Vi?l0
003oe^;P0ol00002omOMg0;o000000?obmcVo`000?o<eN400_o<eN43o`0000Co^lkY0ol00003ojC2
k`;o000000KoYl3[o`000?l0003o0000oiWSoOl00005ojO0j`?o00000_nW`>/00ol0003oYl3[ojO0
j`03ojO0j`Co00000_nW`>/01?l0003oYl3[ojO0jonW`>/3o`0000GoYl3[00Co0000ojO0jonW`>_o
Yl3[0ol00004ojO0j`03o`000?nW`>_o000000;o000000?oYl3[o`000?ooool04oooool00ol0003o
ooooooooo`0Tooooo`00<?ooool2o`00013ooooo00?o0000ooooooooool08_ooool3o`0000KoYl3[
00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`06o`000?nW`>_o0000o`00
0?nW`>_o00001?nP[^800ol0003oWJWNoifYgP02oifYgP04o`000?nT[]oo0000o`0000;oZJkL00?o
0000ojjdgOn^]=d00_n^]=d2o`0000Go^;_L00?o0000ok[2gol000001?no`]`00ol0003o`LWQo`00
0004olK:g@?o00000oo;d^001ol0003ocm?LoloCg?o?dmco0000olgKi?l000000_oBfml00ol0003o
e]_KomKKf`02omKKf`?o000000?oeN;Po`000?oIhM`00_oIhM`00ol0003og=oHomcOf003o`000003
omSUgol0003ofn;K00;ofn;K00?o0000omgOeooMgmL01Ol00003omOMg004o`000?oHf=Sof=SHo`00
00?oc=GQ00Ko0000olc?g?o<cmcoc<oLo`000?nkc^T2o`0000;o_<OS00?o0000ojC2konT`^l01Ol0
0004oiWSo@03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/00onW`>/00ol0003oYl3[o`00
0002o`000003ojO0jol0003oYl3[00CoYl3[00?o0000ojO0jol000000ol00005ojO0j`Co00000_nW
`>/00ol0003oYl3[ojO0j`02ojO0j`;o00001OnW`>/00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo02Cooooo000aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07_ooool3
o`0000?oYl3[00?o0000ojO0jonW`>/00onW`>/2o`0000GoYl3[00?o0000ojO0jonW`>/00ol00004
ojO0j`03o`000?nP[^;oX:kR00;oX:kR00?o0000oifYg_nMZMh00ol00005ojV^g006o`000?n^]=go
0000o`000?nc]M[o00001Onh^m`2o`0000Go_l;L0ol00003olK:g@07o`000?o;bm[obl_Jol_;f_l0
003obm;Po`000004oloCg0?o000000?od]_Oo`000?oFfm/00ooFfm/01Ol0003of][Gom[JeooJf]Oo
000000?ofN7L00Co0000omcOf?oLgmSo00000ooOgM@01Ol0003ofn;Kom_RfooKh]_o000000;ogMoG
0ol000000ooNfm?o0000omOMg002omOMg008o`000?oHf=Sof=SHo`000?oGdmCo0000olcEhOl00004
olc?g0;o00001?nlan<3o`0000;oYk_W00?o0000ohZal?n:/O001_l00005ojO0j`03o`000?nW`>_o
Yl3[00?o00001OnW`>/01?l0003oYl3[ojO0jonW`>/3o`0000?oYl3[0_l000001_nW`>_o0000o`00
0?l0003oYl3[o`0000GoYl3[00Ko0000ojO0jol0003o0000ojO0jol00005ojO0j`;o00004oooool0
0ol0003oooooooooo`0Sooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo013ooooo0_l0000Looooo`;o
00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW
`>/01?nW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/00_nW`>/00ol0003oX:kRoj2^hP04o`0000?o
XJSK00?o0000ojV^g?nY[]`00_nY[]`2o`0000Co/kGJ00Go0000okRkg?nh^mco^;_Lo`000002okbl
f@05o`000?no`]co_l;Loko2g?l000000oo4`mT00ol0003oa/[Mo`000005ol_;fP;o00000oo?dm`0
1?l0003oe=?HomCCf?oDdmP2o`0000?oe]_K00Wo0000om[JeooJf]Oof][Go`000?oMfM?o0000omWQ
g?l000000_oLgmP00ol0003ogmgDomoMe002omoMe0;o000000?ofn;Ko`000?l000000_l00004omkK
d`;o000000GoemgLo`000?oHf=Sof=SHo`000003omOCe003o`000?o<cmcoc<oL00;oc<oL00?o0000
ol_9f?l000000onlan<00ol0003o_<3Mo`000004ojNki`03o`000?n:/O3oR[7`00Go00001OnW`>/3
o`0000?oYl3[00?o0000ojO0jonW`>/00_nW`>/4o`0000?oYl3[00?o0000ojO0jonW`>/00ol00005
ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00001?nW`>/00ol0003oYl3[o`000002o`000003ojO0jol0
003ooooo01?ooooo00?o0000ooooooooool08_ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Fooooo`?o00001OnW`>/00ol0003oYl3[ojO0j`04o`0000CoYl3[00?o0000ojO0jol0
00000_l000000onW`>_o0000ojO0j`04ojO0j`03o`000?nW`>_oYl3[00Co00000_nHX]/00ol0003o
XJSKoj6Xf`03oj6Xf`06o`000?nY[]co0000o`000?n][mWo00001Onc]MX00ol0003o^;_Lo`000004
okblf@03o`000?no`]co000000Goa<?I00?o0000ol_;f_o;bmX00oo;bmX01_l0003ocl_Folo;e_l0
003ocm?Lo`0000Coe=?H00Go0000omOCe?l0003oe]_Ko`000003om[Je`04o`000?oMfM?ogMWComgI
d`;o000000?og=oHo`000?oOgM@00ooOgM@00ol0003ohM_@o`000002o`000003omgOeol0003og]_C
00?og]_C00?o0000omoHd?oOf=000_l000000ooHf=So0000omOCe003omOCe005o`000?o<cmcoc<oL
olc?g?l000000oo;bMP00ol0003o_<OSo`000003okc0g@03o`000?nW^nOoYk_W00Co00000_nA[>P0
1Ol0003oLIk]og6NkOl0003oYl3[00?o000000?oT>Kjo`000?nW`>/01?nW`>/01_l0003oYl3[o`00
0?l0003oYl3[o`0000GoYl3[0ol000000onW`>_o0000o`000005ojO0j`Co00000onW`>/00ol0003o
Yl3[ojO0j`03o`0000GoYl3[00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Rooooo`00
1?l00002ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo00;ooooo0_l0000E
ooooo`03o`000?oooooooooo01;ooooo0ol00003ojO0j`03o`000?nW`>_oYl3[00;oYl3[0ol00004
ojO0j`03o`000?nW`>_oYl3[00?o00001OnW`>/01?l0003oYl3[ojO0jonW`>/4o`0000;oTj7N00?o
0000oiRRfonHX]/00_nHX]/00ol0003oXJSKoj6Xf`02oj6Xf`;o00001?n][mT00ol0003o/kGJok>e
fP02ok>efP;o00001Onl_=T2o`0000Goa<?I00?o0000olW4e_l000000oo;bmX00ol0003ocl_Folo;
eP02olo;eP03o`000?oDdmSoe=?H00;oe=?H00Go0000omOCe?oGdmCoem?Do`000003om[Je`03o`00
0?oMfM?ogMWC00;ogMWC00Co0000omoHcol0003o00000ooOgM@3o`000003on7Kd?l0003oh]S=00;o
00000ooNfm<01ol0003ogmS@omoHd?oOf=3o0000omkDcOl000001?oGdm@01Ol0003oelkAo`000?o<
cmco000000CoblWH0_l00004okc0g@?o00000onY]>401Ol0003oTJcXoi6/j?nA[>So000000;oLIk]
0_l00004oi3VnP04o`000?nW`>_oYl3[ojO0j`?o00001?nW`>/00ol0003oYl3[o`000002o`000003
ojO0jol0003oYl3[00;oYl3[0_l000001_nW`>_o0000o`000?l0003oYl3[o`0000GoYl3[0ol00002
ojO0j`03o`000?nW`>_oYl3[00?oYl3[0_l0000Cooooo`03o`000?oooooooooo027ooooo0006oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000007ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0?ooooo`;o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`04o`00
0?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000?oYl3[00?o0000ojO0jonW
`>/00_nW`>/4o`0000;oYl3[00?o0000oi>Qg_nCXMh00_nCXMh00ol0003oV:;KoiRRf`02oiRRf`06
o`000?nQZ=_o0000o`000?nUZ=So00001On][mT01?l0003o/kGJo`000?l00002okRfe`05o`000?nl
_=Wo_;cIokblfOl000000_o1_=H01Ol0003oa<?IolC3fOo4`mWo000000?obLCF00?o0000ol_;f_l0
00001?o?bmH2o`0000?oe=?H00Wo0000omOCe?oGdmCoem?Do`000?oKd]3o0000om[Jeol000001?oM
fM<01Ol0003ogmS?omoHcol0003ohMK<00?o00000ooQfm002?l0003oh]S=on;HcOl0003oh]K:o`00
0?oNfm?o00000ooOf=001?l0003og]C=omkDcOl00003omOCe004o`000?oGc]7oelkAomO>d@;o0000
0oo;bMP01Ol0003ob/?Col[3dol0003o_<3M00;o000000?o^k[Ho`000?nY]>400onY]>4Ao`0000?o
Yl3[00?o0000ojO0jonW`>/00ol00005ojO0j`03o`000?nW`>_oYl3[00?o00001OnW`>/00ol0003o
Yl3[o`000002o`000003ojO0jol0003oYl3[00?oYl3[00?o0000ojO0jol000000_l000000onW`>_o
0000ooooo`0Cooooo`03o`000?oooooooooo023ooooo0006ooooo`05o`000?ooooooooooooooool0
00002oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00_ooooo0ol00005ojO0j`03o`000?nW`>_oYl3[00Co00001?nW`>/01?l0003oYl3[o`00
0?l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003o
Yl3[ojO0j`02ojO0j`05o`000?nCXMkoTj7Noi>Qg_l000000onHX]/3o`0000CoYJSH00?o0000ojf_
fOn][mT00_n][mT2o`0000Go^;KG00?o0000okblfOl000001?o1_=H00ol0003oa<?Io`000004olW4
eP;o00001?o?bmH01_l0003odlcBom?<d_l0003oe=?Ho`0000?oem?D00Co0000om_Bd?oKd]3ofm;@
0_l00003omgId`03o`000?oOf<oogmS?00?o000000?ohMK<o`000?oQfm000_oQfm001?l0003oh]S=
on;HcOl00003on;FbP05o`000?oOf=3ogmS@omoHd?l000000_oNe<d01Ol0003og]3;o`000?oGdmCo
000000?oelkA00Ko0000omG9c_oEbLko0000ol_9f?l00004ol[3d`03o`000?nk^]So^k[H00;o^k[H
00Ko0000ojVdhOl0003o0000oj^^f_l00003oiJVh@05o`000?mlW>KoO9cVogbLi_l000000omMS^P2
o`0000GoYl3[0ol00002ojO0j`03o`000?nW`>_oYl3[00?oYl3[0ol000001?nW`>_o0000ojO0jol0
0003ojO0j`?o00001OnW`>/00ol0003oYl3[ojO0j`03o`0000GoYl3[00?o0000ooooooooool04?oo
ool2o`0002;ooooo0006ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4004ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`07ooooo`?o00000onW`>/00ol0003o
Yl3[ojO0j`02ojO0j`?o00001?nW`>/00ol0003oYl3[ojO0j`03o`0000GoYl3[00?o0000ojO0jonW
`>/01?l00004ojO0j`05o`000?nW`>_oYl3[ojO0jol000000_nCXMh5o`0000;oW:;I00?o0000ojFX
f?nUZ=P00_nUZ=P00ol0003o[JoIo`000002o`000003ok6_e_l0003o^;KG00Co^;KG0_l00005ol6l
eP;o00001?o9a=H00ol0003ocLCBo`000003olo;eP03o`000?oCc=;odlcB00;odlcB00Go0000omOC
e?oGdmCoem?Do`000004om_Bd004o`000?oMdLgo0000omgId`Co00001?oQe/`2o`000005on7Kd?l0
003oh]S=on;HcOl000001?oRe/X2o`000005omoHd?l0003og]C=omkDcOl000000ooNd</01Ol0003o
elkAomO>dOoGc]7o000000CoeLW>00?o0000ol[3doo:`m<00_o:`m<2o`0000Co^k[H0_l00004oj^^
fP05o`000?nFY^7oUZKQoiJVhOl000000omlW>H01?l0003oGHkXoef>j?mMS^P2o`000006ojO0jol0
003o0000o`000?nBiOco00001?nW`>/00ol0003oYl3[o`000002o`000003ojO0jol0003oYl3[00;o
Yl3[1Ol00002ojO0j`03o`000?nW`>_oYl3[00?oYl3[0ol00003ojO0j`04o`000?nW`>_oYl3[ojO0
j`?o00004oooool00ol0003oooooooooo`0Oooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01?oo
ool2o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`00
0?nW`>_oYl3[00;oYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00;oYl3[0ol00004ojO0j`03o`00
0?nW`>_oYl3[00So00000_nAV]T00ol0003oW:;IoibRf@03oibRf@04o`000?nUZ=SoYJSHojFXf0;o
00001Ona[mH00ol0003o^;KGokRfe`02o`000003okbfe?l0003o`KcF00;o`KcF0_l000000oo5_M;o
0000olW4eP02olW4eP07o`000?o=a=;ocLCBolg4d_l0003ocl_Fo`000004om?<dP05o`000?oGc<oo
0000omOCe?l000001?oKd]000ol0003ogM7=omgAc@03o`0000;ogmS?00Go0000on7Fc?oQe/cohMK<
o`000002on?Db@;o000000?oh]S=o`000?oRe/X00ooRe/X00ol0003ohm?7on?Ca`02o`000003omkD
cOl0003og]3;00?og]3;0_l000000ooGc]7o0000omG9cP03omG9cP;o00000oo:`m<01Ol0003ob;g@
olRmd?l0003o^k[H00;o000000?o^[CCo`000?n[[]X00on[[]X00ol0003oUZKQoiJVh@0=o`0000Co
T^Gl00?o0000ojO0jonW`>/00ol00005ojO0j`03o`000?nW`>_o000000?o00001OnW`>/00ol0003o
Yl3[o`000002o`000003ojO0jol0003oYl3[00?oYl3[1?l00002ojO0j`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool07_ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l00004
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00ol00005ojO0j`03o`000?nW`>_o
Yl3[00Co00001?nW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[00Co
0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`?o00000_nW`>/01Ol0003oQYCJ
ohJDf_n6U=[o000000CoTI[I00?o0000oibRfOnLX]T00_nLX]T01_l0003oYJSHo`000?l0003oZJSF
o`0000Go/JoF00?o0000okRfeol000001?nl]]@00ol0003o`KcFo`000004olFmdP03o`000?o9a=Ko
000000GocLCB0_l00003om?<dP04o`000?oGc<ooelc?omO<c`;o00000ooKd]000ol0003ogM7=o`00
0002o`000004omoAbOl0003ogmS?o`0000?ohMK<00Ko0000on?DbOoSe<WohmC9o`000?oTd/H2o`00
00?oh]K:00Oo0000on?CaooSdlOohm?7o`000?oRd<Go000000Cog]3;00?o0000omg<b?oMc<P00_l0
0003omG9cP06o`000?oCa<_odlC;o`000?o:`m?o00001?o8_M000ol0003o^[CCokZdd`02okZdd`03
o`000?n[[][oZjkJ00Co00000_nIX]X01Ol0003oQ9WOohBIgon4VMoo000000?oJhkR2_l00003ojO0
j`04o`000?nW`>_oYl3[ojO0j`?o00000onW`>/2o`0000?oYl3[0ol00005ojO0j`06o`000?nW`>_o
0000o`000?nW`>_o00001OnW`>/00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo
1?l000000ol@413oooooooooo`0@ooooo`00;oooool00ol0003oooooooooo`0Jooooo`?o00000onW
`>/00ol0003oYl3[ojO0j`02ojO0j`?o00001?nW`>/00ol0003oYl3[ojO0j`03o`0000GoYl3[00?o
0000ojO0jonW`>/01?l00004ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00Go0000ojO0jonW`>_o
Yl3[o`000003ohJDfP03o`000?nAV]WoTI[I00;oTI[I00?o0000oibRfOnLX]T00ol00004ojVXeP03
o`000?na[mKo/JoF00;o/JoF0_l00006okbfe003o`000?o5_M;oaKgB00CoaKgB00?o0000olg4d_o=
a=800oo=a=801_l0003odLG?om75col0003odlcBo`0000Coelc?00Co0000om[;bol0003ofm;@0ol0
00000ooMdLgo0000omoAb@02omoAb@05o`000?oQe/cohMK<on7Fc?l000000ooSe<T02?l0003oi=;6
onCBa_l0003oi=33o`000?oRe/[o00000ooSdlL01?l0003oh]35on;@aOl00003omk@b`09o`000?oM
c<SogLc8omg<b?l0003oflS6o`000?oEbLko000000CodlC;00?o0000olRmd?o8_M000_o8_M02o`00
00Co^[CC0ol00002oj^Ye@03o`000?nIX][oVJ;J00;oVJ;J00Go0000ohBIgon4VMooQ9WOo`000003
of^>hP04o`000?m?PN?o0000o`0000;o66_M0_l00004ojO0j`Co00000_nW`>/01?l0003oYl3[ojO0
jonW`>/5o`0000?oYl3[00Co0000ojO0jonW`>_oYl3[0ol00004ojO0j`04o`000?nW`>_oYl3[ojO0
j`?o00004oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01;ooooo000_ooooo`03
o`000?oooooooooo01Sooooo0_l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[00Co0000ojO0jol0
003o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`02ojO0
j`?o00001?nW`>/00ol0003oYl3[ojO0j`03o`0000GoYl3[00Go0000ojO0jonW`>_oYl3[o`000003
ohJDfP03o`000?nAV]WoTI[I00Co00000_nOXMH00ol0003oZJSFojVXeP03ojVXeP06o`000?na[mKo
0000o`000?ne[m?o00001Onl]]@2o`0000GoaKgB00?o0000olVncol000000oo=a=800ol0003odLG?
om75c`02om75c`03o`000?oGc<ooelc?00;oelc?00?o0000om[;bol000000_l00003omgAc@03o`00
0?oOdLWogm7900;ogm790_l000000ooQe/co0000on?Db@02on?Db@04o`000?oTd/Koi=;6o`0000?o
i=3300Go0000on?CaooSdlOohm?7o`000002on;@a@05o`000?oRcL?o0000omk@bol000000ooMc<P0
1Ol0003oflS6om_8a_oKb<Ko000000CodlC;0_l00003olRmd004o`000?o6^<goa[S=o`0000;o^[CC
00?o0000okR^col000001?n[ZMD01Ol0003oVJ;JoiVRf_nIX][o000000?oQ9WO00?o0000of^>h_m[
S^800_m[S^800ol0003oCh7Sodn1h`03o`000003o`1Le?l0003oYl3[00;o000000?oWMomo`000?nW
`>/01?nW`>/00ol0003oYl3[o`000003o`0000GoYl3[1?l00002ojO0j`03o`000?nW`>_oYl3[00;o
Yl3[1?l00002ojO0j`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Booooo`00;oooool00ol0003oooooooooo`0Eooooo`?o00001OnW`>/00ol0003oYl3[
ojO0j`04o`0000CoYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`04
o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000?oYl3[00?o0000ojO0
jonW`>/00_nW`>/;o`0000;oU9[F00?o0000oinQe_nOXMH00_nOXMH00ol0003oZJSFojVXeP02ojVX
eP;o00001?ne[m<01Ol0003o_;KDokbfe?nl]]Co000000;o`;OA00Go0000olFmd_o5_M;oaKgBo`00
0003olVnc`03o`000?o=a=;o000000CodLG?0_l00003omO<c`?o00000_oJbl/2o`000003omgAcOl0
003ogm7900?ogm7900?o0000on7@a_oQd<H00_l00003on?Db@04o`000?oTd/Koi=;6o`0000?oi=33
0_l000001OoSdlOo0000on;@aOoRd<Go000000?oh/g300Go0000omg<b?oMc<SogLc8o`000004om_8
aP05o`000?oCa<_odlC;om?4bol000000_oA_lT00ol0003ob;g@o`000003olJhc@03o`000?nj]=?o
000000?o^:k?00Co0000oj^YeOn[ZMGoZjWE4Ol000001?lcM>3o0000o`000?l0G=@2o`0000?oWMom
00Co0000ojO0jonW`>_oYl3[0ol00003ojO0j`;o000000KoYl3[o`000?l0003o0000ojO0jol00005
ojO0j`06o`000?nW`>_o0000o`000?nW`>_o00001OnW`>/00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool04_ooool002kooooo0ol0000Cooooo`?o00000onW
`>/00ol0003oYl3[ojO0j`02ojO0j`?o00001?nW`>/00ol0003oYl3[ojO0j`03o`0000GoYl3[00?o
0000ojO0jonW`>/00ol00005ojO0j`06o`000?nW`>_o0000o`000?nW`>_o00001OnW`>/01_l0003o
Yl3[o`000?l0003oYl3[o`0000?oNhcI00Go0000ohNBeon7T]OoQi;Go`000004oiBJeP03o`000?nO
XMKoWj7F00;oWj7F00Ko0000ojVXe_l0003o0000ojfXdol00005okF_d`03o`000?nl]]Co000000Co
`;OA00?o0000olFmd_l000001?o9_/l2o`0000CodLG?00?o0000omC5booDaL/00ol00004om[;b`03
o`000?oLblSog<_800;o00000ooOdLT02Ol0003ohM36on7@a_oQd<Ko0000on??`ol0003ohmC9o`00
0002onCBaP05o`000?oTd<?oi=33onC@`ol000000_oTcl401Ol0003oh]35on;@aOoRd<Go000000?o
h/g30_l000000ooMc<So0000om_8aP03om_8aP05o`000?oJaLGo0000om?4bol000001?oA_lT00ol0
003oa[S=olJhc@02olJhc@;o00001?nh[/l01_l0003oZjWEo`000?l0003oZZC@o`0000?oW9gD00Go
0000ohZFfOn:U]WoRYKIo`000004ogJ=g004o`000?mPQ=ko0000o`0000;o<gCP0_l000000ol0G=Co
0000o`000005o`0000?oYl3[00?o0000ojO0jonW`>/00ol00005ojO0j`04o`000?nW`>_oYl3[ojO0
j`?o00001?nW`>/01?l0003oYl3[ojO0jonW`>/3o`0001?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Booooo`00;oooool00ol0003oooooooooo`0@ooooo`;o00000_nW`>/00ol0
003oYl3[ojO0j`02ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/3
o`0000;oYl3[00?o0000ojO0jonW`>/00onW`>/3o`0000?oYl3[00Co0000ojO0jonW`>_oYl3[0ol0
0004ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00001?nW`>/01Ol0003oNhcIog^<fOmkS=Wo000000?o
Qi;G00?o0000oiBJe_nDV]H00_nDV]H01?l0003oWj7FoinQe_nOXMH2o`0000Co[JSC00?o0000okF_
done[m<00_ne[m<2o`0000Go`;OA0_l00004olVnc`03o`000?o=_/co000000?odLG?1?l000000ooD
aL_o0000o`000003om[;b`09o`000?oLblSog<_8omc;b?l0003og/_5o`000?oOdLWo000000?ohM36
00Go0000on??`ooScl?ohlo3o`000002onCBaP05o`000?oTd<?oi=33onC@`ol000000ooTcl42o`00
0003on;@aOl0003oh/g300;oh/g300Co0000on7:`_oQb/;o00001?oKb<H01Ol0003of/G5om[5aOoJ
aLGo000000CodKo90_l00003olJhc@03o`000?o3/l[o000000Co^:k?0_l00004ojZTd005o`000?nL
WMCoW9gDoibMe?l000000on:U]T00ol0003oMXgLogJ=g002ogJ=g003o`000?mPQ=koH8CN00[o0000
1OnW`>/3o`000003ojO0jol0003o000000GoYl3[1?l00002ojO0j`04o`000?nW`>_oYl3[ojO0j`Go
00000_nW`>/00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool04_ooool002kooooo00?o0000ooooooooool03_ooool3o`0000GoYl3[00?o0000ojO0jonW`>/0
1?l00004ojO0j`06o`000?nW`>_o0000o`000?nW`>_o00001?nW`>/00ol0003oYl3[o`000002o`00
0003ojO0jol0003oYl3[00?oYl3[1?l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[1?l00003ojO0
j`05o`000?nW`>_oYl3[ojO0jol000000omkS=T01Ol0003oQi;GohNBeon7T]Oo000000CoU9[F00Ko
0000oinQe_l0003o0000oj>Qdol00005ojfXd`06o`000?ne[m?o0000o`000?ni/=3o00000oo0]m42
o`000003olBgc_l0003obKk?00;obKk?00Co0000olfnc?o=_/cocKk<1?l00004omC5b`05o`000?oG
aLSo0000om[;bol000000ooLblP01Ol0003og/_5omk;aOoNblGo000000?ohM3600?o0000on??`ooS
cl<00_oScl<2o`000005onCBa_l0003oi=33onC@`ol000000ooTcl401?l0003oi<foonC=_ol00003
on;=``04o`000?oQb/;ohL[2on7:`P;o00000ooKb<H01Ol0003of/G5om[5aOoJaLGo000000?odKo9
00Ko0000olnkaoo?^lOo0000olJhcOl00003ol>cbP06o`000?nh[/oo0000o`000?ngZLco00001?nZ
Y=000ol0003oW9gDoibMe00;o`0000;oH8CN00?o0000odUjgom9N]l00ol000000olIJ=co0000o`00
0002o`000006ojO0jol0003o0000o`000?nUd?Oo00000onW`>/2o`000006ojO0jol0003o0000o`00
0?nW`>_o00001?nW`>/4o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/2o`0001;ooooo0_l00007
ooooo`03o`000?oooooooooo01;ooooo000^ooooo`03o`000?oooooooooo00_ooooo0ol00003ojO0
j`03o`000?nW`>_oYl3[00;oYl3[0ol00004ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/00ol0
003oYl3[ojO0j`04o`0000CoYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02
ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/5o`0000?oNhcI00Go
0000ohNBeon7T]OoQi;Go`000003oiBJeP?o00001?nSXM<00ol0003o[JSCojfXd`02ojfXd`;o0000
1?ni/=000ol0003o`;OAo`000004olBgcP03o`000?o9_/oo000000;ocKk<1?l00005omC5b`05o`00
0?oGaLSoelG8omO5b?l000000ooLblP00ol0003og/_5omk;a@02omk;a@05o`000?oQd<KohM36on7@
a_l000000ooScl<01?l0003oi<g1onC=`Ol00003onC@``05o`000?oTcl7oi<o1onC?`Ol000000_oT
cKl01Ol0003oh/g3on;=`ooRcL?o000000;ohL[200Ko0000on38`?oPb<3o0000om_8a_l00003om[5
a@05o`000?oH`L?o0000om6obOl000001?o?^lL00ol0003o`k?:ol>cbP03ol>cbP03o`000?ngZLco
]jW<00;o]jW<00Co0000ojZTd?nZY=3oZZC@0ol00002oifId005o`000?n?Tm?oSi?CohnCdol00000
0omnS=L5o`0000;oBG[O00Go0000oc=bg_l0003o0000o`EPe`03o`0000GoYM3g00?o0000ojO0jonW
`>/00ol00005ojO0j`06o`000?nW`>_o0000o`000?nW`>_o00001OnW`>/01_l0003oYl3[o`000?l0
003oYl3[o`00017ooooo00Co0000oooooooooooo00001?ooool00omEEEGoIVIVo`00000Dooooo`00
;_ooool2o`0000[ooooo0_l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[00Co0000ojO0jol0003o
00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`?o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`?o
00001?nW`>/00ol0003oYl3[ojO0j`03o`0000GoYl3[00?o0000ojO0jonW`>/01?l00004ojO0j`06
o`000?nW`>_o0000o`000?nW`>_o00000_mdRm/<o`0000;oV9[D00?o0000oj>QdonSXM<00_nSXM<0
0ol0003o[JSCojfXd`02o`000003ok6Yd?l0003o^K3@00?o^K3@0_l00006olBgcPCo00000oo=_/`2
o`0000?oe<G;00?o0000omO5b?oGaLP00_oGaLP01Ol0003og<_8omc;b?oLblSo000000?og/_500Go
0000on3:`ol0003ohM36o`000003on??``04o`000?oTcL7oi<g1onC=`@;o000000?oi=33o`000?oT
cl400_oTcl402?l0003oi<foonC=_ol0003oi<^no`000?oRcL?o00000_oQb/800ol0003oh<S0on38
`002on38`005o`000?oJaLGof/G5om[5aOl000000ooH`L<00ol0003ock_7olnka`02olnka`;o0000
1?o3/lX2o`0000Co]jW<00Ko0000ojZTd?l0003o0000ojZOc?l00004oifId005o`000?n?Tm?oSi?C
ohnCdol000000omnS=L00ol0003oKHGIoff5f@03o`000009odUjgol0003o<g;Noc=bg_l0003o1F3G
o`000?l0CLKo000000?oYM3g1?l000001?nW`>_o0000ojO0jol00003ojO0j`?o00001?nW`>/01?l0
003oYl3[ojO0jonW`>/3o`0000CoYl3[00?o0000ooooooooool04Oooool00ol0003oooooooooo`0I
ooooo`00;_ooool00ol0003oooooooooo`06ooooo`Co00001?nW`>/00ol0003oYl3[ojO0j`04o`00
00CoYl3[00Ko0000ojO0jol0003o0000ojO0jol00004ojO0j`04o`000?nW`>_o0000o`0000;oYl3[
00?o0000ojO0jonW`>/00_nW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000CoYl3[
00?o0000ojO0jonW`>/00ol00004ojO0j`04o`000?mdRm_oM8_Ko`0000?oNhSE00Go0000ohZAe?n:
TMCoRY7Do`000005oiRJe007o`000?nSXM?oXj7Coj>Qdol0003o[JSCo`000004ok6Yd006o`000?ni
/=3o^K3@o`000?nm/Lko00001Oo4]lh2o`0000GocKk<00Ko0000om2obOo@_lWo0000omC5bol00004
omO5b005o`000?oJaLGo0000omc;b?l000000ooNblD01?l0003oh<[3on3:`ooPb/<2o`0000?ohlo3
00Co0000onC=`OoTcL7o00000_oUc;l2o`0000;oi<o100Go0000onC=_ooTcKooi<foo`000002onC;
_P05o`000?oQb/;ohL[2on7:`_l000001?oPb<02o`000003om[5aOl0003of<7300?of<7300Go0000
olnkaoo?^lOock_7o`000002olbga@04o`000?o3/l[o`k?:o`0000;o`Jk700Co0000okNYc?ngZLco
]jW<0_l00004ojZOc005o`000?nMVM3oWIW@oifId?l000000on?Tm<00ol0003oOXcGogj<e`02ogj<
e`05o`000?m]QMWoKHGIo`000?mKO]`00_l00003oc=bgPOo00000_m[doX01?l0003oYl3[ojO0jonW
`>/5o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/4o`0000?oYl3[00?o0000ojO0jonW`>/00ol0
000Cooooo`03o`000?oooooooooo01Sooooo000^ooooo`03o`000?oooooooooo00?ooooo0ol00004
ojO0j`03o`000?nW`>_oYl3[00Co00001?nW`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[00?o0000
ojO0jonW`>/01?l00004ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW
`>/01?l0003oYl3[o`000?l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[0ol00003ojO0j`03o`00
0?nW`>_oYl3[00;oYl3[00Co0000ogB;fomdRm_o00000omkR=D01Ol0003oRY7DohZAe?n:TMCo0000
00CoV9[D00?o0000oj>QdonSXM<00ol00005ok6Yd003o`000?ni/=3o000000?o_K7>00?o0000olBg
c_l000000_l00002olNhb`05o`000?o=_/cocKk<olfnc?l000001?o@_lT00ol0003oelG8omO5b002
omO5b005o`000?oJaLGof/G5om[5aOl000000ooNblD00ol0003oh<[3on3:``02on3:``05o`000?oR
b/3o0000on??`ol000000_oTcL402Ol0003oiLboonG<_ooUc;oo0000onG;_Ol0003oi<o1o`000002
onC=_`04o`000?oTbkkoi<^nonC;_P;o000000?ohL[2o`000?oPb<000ooPb<001?l0003og/Foomk5
_ol00004omS1``05o`000?oF_L;o0000olnkaol000000oo<]lD00ol0003o`k?:o`000003ol6^a`06
o`000?ngZLco0000o`000?neYLSo00001?nZWl`01Ol0003oWIW@oifId?nMVM3o000000;oSi?C1ol0
0003off5f@03o`000?mKO]coFgkL00;o000000?o<g;No`000?lRK=d02Ol000000onW`>_o0000o`00
0002o`0000GoYl3[00Ko0000ojO0jol0003o0000ojO0jol00005ojO0j`?o00000_nW`>/00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01Oooooo000^ooooo`04o`000?ooooooooooooooo`;o
00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`02ojO0j`?o
00000onW`>/00ol0003oYl3[ojO0j`04o`0000CoYl3[00?o0000ojO0jonW`>/01?l00004ojO0j`03
o`000?nW`>_oYl3[00Co00001?nW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`000?nW`>_oYl3[
00;oYl3[00Go0000ojO0jonW`>_oYl3[o`000003ogB;f`05o`000?mkR=GoNhSEog^8eOl000000on:
TM@00ol0003oV9[DoiRJe004o`0000;oYj;A00?o0000ok6Yd?naZM000onaZM02o`0000?o_K7>0ol0
00000oo4]lko0000olNhb`03olNhb`03o`000?o=_/co000000Cod;o90_l00003omO5b003o`000?oJ
aLGof/G500;of/G500Go0000omk;aOoNblGog/_5o`000003on3:``05o`000?oRb/3oh/[0on;:`?l0
00000ooTcL401?l0003oiLboonG<_ol00003onG;_@04o`000?oTcKooi<foo`0000?oi<^n00Co0000
onC9_OoTbKgo00001?oPb<001Ol0003og/Foomk5_ooNaKoo000000?of<7300Go0000omJm`_oF_L;o
e[g2o`000005olbga@03o`000?o1[/Oo`Jk700?o`Jk700?o0000okFUb?neYLP00_neYLP01Ol0003o
ZYo<ojZOc?nZWlco000000;oWIW@1?l00002oi:@cP04o`000?n5Rm7oQH_AohF;d@Go00000_mKO]`0
0ol0003oBGSMo`000002o`0000;o8VcM0_l000000ol0GMCo0000o`000003o`0000?oYl3[0_l00003
ojO0j`?o00001?nW`>/00ol0003oYl3[o`000002o`000003ojO0jol0003oYl3[00?oYl3[00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Gooooo`00;Oooool6o`0000CoYl3[00Co0000ojO0
jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`06o`000?nW`>_o0000o`000?nW`>_o0000
1?nW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000CoYl3[00?o0000ojO0jonW`>/0
1?l00004ojO0j`03o`000?nW`>_oYl3[00Co00001?nW`>/00ol0003oYl3[ojO0j`0:o`0000?oNhSE
00?o0000ohZAe?n:TM@01?l00002oi^JdP03o`000?nWX]7oYj;A00;oYj;A00Ko0000ok6Yd?naZM3o
/JW@o`000?neZ/h4o`0000?o_K7>00?o0000olNhboo7^</01?o7^</00ol0003od;o9om2ob@02om2o
b@06o`000?oC_lOodko7o`000?oGaLSo00001?oJaLD01Ol0003og<G3o`000?oNblGo000000?oh<[3
00?o0000on;:`?oRb/000_oRb/02o`000005onC=`Ol0003oiLboonG<_ol000001?oUbkd2o`000005
onC=_ol0003oi<^nonC;__l000000ooTbKd2o`0000?oh<S000So0000omk5_ooNaKoo0000omg2_ol0
003of<73o`0000Coe[g200?o0000olbgaOo<]lD00_o<]lD2o`0000Co`Jk70_l00004okFUb003o`00
0?nZWlcoZYo<00Co00000_nNU//00ol0003oTY3>oi:@cP02oi:@cP05o`000?n5Rm7oQH_AohF;dOl0
00000_mgQM@5o`0000?oBGSM0ol000000olEJ]go0000o`000004o`0000?oYl3[1Ol00003ojO0j`03
o`000?nW`>_oYl3[00?o00001OnW`>/00ol0003oYl3[ojO0j`03o`0001?ooooo00?o0000oooooooo
ool05_ooool002gooooo0_l00004ojO0j`03o`000?nW`>_oYl3[00?o00001OnW`>/00ol0003oYl3[
ojO0j`04o`0000?oYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`04
o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000?oYl3[00?o0000ojO0
jonW`>/00_nW`>/3o`0000CoYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`05o`000?meTn;oMI?R
ogFCh_l000000_m/OM<7o`0000;oSI7B00?o0000oi^Jd_nKV]800_nKV]800ol0003oYj;AojNRd@02
ojNRd@03o`000?naZM3o000000Co00001?nm/Lh2o`0000GoakS;0_l00003om2ob@03o`000?oC_lOo
dko700;odko700?o0000om[5aOoJaLD00_oJaLD01?l0003og<G3omc5`ooLaL<2o`0000?oh<[300Go
0000on;:`?oRb/3oh/[0o`000002on?9_P05o`000?oUc;ooiLboonG<_ol000000ooUbkd01?l0003o
iLZlonG:_?l00003onC;_P04o`000?oTbKgoi<Vmo`0000;ohlNl00?o0000on38`?l000000_oNaKl0
1Ol0003ogL:oomg2_ooM`[oo000000Coe[g200?o0000om>j`Ol000000_o<]lD01?l0003obK;4olVb
a?l00002ol6^a`04o`000?nnZ/Go_Z[5o`0000?o]JG80ol00002ojVKb003o`000?nNU/_oWYK;00;o
WYK;00Go0000oi:@c_nBT<koTY3>o`000004ohF;d@04o`000?mgQMCoMhGDo`0000;oJH7H0ol00000
0om9N=go0000oc]eg`02o`0000?o5F[M1?l000000onW`>_o0000o`000002o`0000GoYl3[0ol00002
ojO0j`03o`000?nW`>_oYl3[00?oYl3[0ol00003ojO0j`03o`000?oooooooooo017ooooo00?o0000
ooooooooool05Oooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`;o00001?nW`>/3
o`0000?oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000CoYl3[00?o0000ojO0jonW`>/00_l00005
ojO0j`03o`000?nW`>_oYl3[00Co00001?nW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`000?nW
`>_oYl3[00;oYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`?o0000
0onW`>/01Ol0003oYl3[ojO0jonW`>_o000000?oMI?R00Co0000ofamdom/OM?o00000ommR=<00ol0
003oSI7BohfAdP02ohfAdP03o`000?nKV];oVi[B00;oVi[B00Co0000ojNRdOnWX]7oYj;A0ol00004
okFZcP04o`000?nm/Lko_K7>o`0000;o`K;;00Go0000olNhboo7^<_oakS;o`000002ol^ib003o`00
0?o@_lWo000000Godko70_l00003om[5a@09o`000?oLaL?og<G3omc5`ol0003og/G1o`000?oPb/?o
000000?oh/[000Co0000on?9__oSbKkohlVn0_l000000ooUc;oo0000onG;_@02onG;_@04o`000?oU
b[coiLZlonG:_0;o000000?oi<^no`000?oTbKd00_oTbKd01Ol0003ohlNlon?7_?oSakco000000?o
g/Fo00Go0000omg2_ooM`[oogL:oo`000003omJm`P06o`000?oC^/7odk[1o`000?o<]lGo00000oo9
//@00ol0003o`Jk7o`000003okjZa@06o`000?neYLSo]JG8o`000?ncXLKo00001?nYVlP01Ol0003o
WYK;oijFbonNU/_o000000?oTY3>00?o0000ohF;dOn5Rm400_n5Rm401Ol0003oMhGDogN5e?mgQMCo
000000;oJH7H00?o0000oe]mf_l000000_l00002oc]eg`;o000000?o5F[Mo`000?l?KMh01?l00002
oiWQo@;o000000KoYl3[o`000?l0003o0000ojO0jol00004ojO0j`03o`000?nW`>_o000000;o0000
00?oYl3[o`000?nW`>/00onW`>/2o`0001;ooooo00?o0000ooooooooool05Oooool002;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`04o`000?oooooo0000ojO0j`;o00000_nW`>/00ol0003o
Yl3[ojO0j`02ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`00
00;oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000CoYl3[00?o0000ojO0jonW`>/01?l00004ojO0
j`03o`000?nW`>_oYl3[00Co00001?nW`>/01_l0003oYl3[o`000?l0003oYl3[o`0000GoYl3[00?o
0000ojO0jonW`>/00ol000000omeTn;o0000ofamd`02ofamd`05o`000?mmR=?oOHSCogf8dol00000
0on=TM800ol0003oVi[Boi^JdP02oi^JdPCo000000?oZj??o`000?neZ/h01?neZ/h00ol0003o_K7>
o`000004ol6bb`03o`000?o7^<_o000000CobkW800?o0000om>oaooC_lL00ooC_lL01_l0003oe/34
omK0a?l0003of/G5o`0000?og<G300Go0000omk5`OoNaL7og/G1o`000003on;:`005o`000?oSbKko
hlVnon?9__l000000_oTbK`01Ol0003oiL^monG;_OoUbkgo000000?oiLZl00Co0000onG9^ooUbK_o
00000ooTbKd00ol0003ohlNlon?7_002on?7_0;o000000?og/Foo`000?oM`[l00_oM`[l01Ol0003o
fknno`000?oF_L;o000000Codk[100?o0000olVba?o9//@00oo9//@00ol0003o_Z[5okjZa@02okjZ
a@03o`000?neYLSo000000?o/j7600Go0000ojVKb?nYVlSoZI_8o`000002oijFb`oo00000omYPMP0
1?l0003oFggJoe]mf_mKOMX3o`000004oc1dhOl0003o0000o`0000;o3fgN1ol00005ojO0j`03o`00
0?nW`>_oYl3[00?o00001OnW`>/4o`000003ojO0jol0003ooooo01;ooooo00?o0000ooooooooool0
5?ooool002;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00;o0000
1?nW`>/00ol0003oYl3[ojO0j`04o`0000CoYl3[00Ko0000ojO0jol0003o0000ojO0jol00004ojO0
j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000CoYl3[00?o0000
ojO0jonW`>/01?l00004ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/01?l0003oYl3[ojO0jonW
`>/4o`000003oh2[l?l0003oFW7@00;o00000om/OM<01Ol0003oOHSCogf8dommR=?o000000?oSI7B
00?o0000oi^Jd_nKV]801?l00004oj^Sc`03o`000?neZ/ko]J[>00;o]J[>0_l00005ol6bb`;o0000
1Oo;^LP2o`0000?odko700?o0000omK0a?oF`<@00_oF`<@01Ol0003og<G3omc5`ooLaL?o000000Co
g/G100Go0000on;:`?oRb/3oh/[0o`000003on?9_P04o`000?oTbKcoi<Vlo`0000?oiL^m00Go0000
onG:_?oUb[coiLZlo`000002onG9^`04o`000?oTbKgoi<Vmo`0000CohlNl00Co0000on;5_?oRaKco
00000ooM`[l01Ol0003ofknnom^o__oK_kko000000Godk[100?o0000olVba?o9//@00_o9//@2o`00
00Co_Z[50_l00004ok>QaP04o`000?nYVlSoZI_8ojVKb0?o00000_nOTlP01Ol0003oUHk:oiF>b_nE
S/[o000000CoRX[=00?o0000ogn6d?moQ]001Ol00003oe]mfP04o`000?m?Nmgo0000o`0000?o<7CQ
0_l000000ol?KMko0000o`000005o`0000?oYl3[1?l00003ojO0j`03o`000?nW`>_oYl3[00?o0000
1OnW`>/00ol0003oooooooooo`0?ooooo`03o`000?oooooo000001Gooooo000Rooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?nW`>_oYl3[00Co0000
1?nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00004ojO0j`04o`00
0?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000?oYl3[00?o0000ojO0jonW
`>/00_nW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01Ol00002ojO0j`05o`000?n0Zo3oP:_`oh2[
l?l000000_mJLM04o`0000?oOHSC00?o0000ohfAd_n=TM801Ol00002oinKd003o`000?n[XlooZj??
00;oZj??00?o0000okFZc_l000000_l000000oniZlco0000ol6bb`03ol6bb`03o`000?o4/lWo0000
00CobkW800Ko0000oljia_o>^LKo0000om>oaol00005omK0a005o`000?oLaL?og<G3omc5`ol00000
0ooNaL401Ol0003oglFno`000?oRb/3o000000?ohlVn00So0000onC9_?oTbKco0000onG8^ol0003o
iL^mo`0000?oiLZl00So0000onG9^ooUbK_o0000onG8^_l0003oi<Vmo`0000?ohlNl00Go0000on;5
_?oRaKcoh/Flo`000003omg2_`05o`000?oK_kkofknnom^o__l000001?oC^/400ol0003od;O1o`00
0002olVba004o`000?o6[l?oaZo3o`0000;o_Z[500?o0000ok^Va?l000001?ncXLH01_l0003oZI_8
o`000?l0003oZ9S6o`0000CoWi?800Go0000oiF>b_nES/[oUHk:o`000004ohZ:c@04o`000?moQ]3o
OhK@o`0000;oM8?C1_l00002odmkg@Oo000000Co47CQo`000?l0003o7Xg[1Ol00002ojK=m003o`00
0?nW`>_oYl3[00;oYl3[0ol00003ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00004_ooool00ol0003o
ooooooooo`0Cooooo`008_ooool01Ol0003ooooooooooooooooo000000Gooooo0_l00005ooooo`;o
00000onW`>/00ol0003oYl3[ojO0j`02ojO0j`?o00001?nW`>/00ol0003oYl3[ojO0j`03o`0000Co
Yl3[00?o0000ojO0jonW`>/01?l00004ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0
jonW`>/00_nW`>/01_l0003oYl3[o`000?l0003oYl3[o`0000CoYl3[0ol00003ojO0j`03o`000?nW
`>_oYl3[00;oYl3[00Co0000oh2[l?n0Zo3o00000_mJLM000ol0003oKWgAofimd@0:o`0000GoWi_@
00Co0000oj^Scon[XlooZj??0_l00005okV[c004o`000?o1//_o`K;;o`0000?oa;?900Co0000ol^i
b?o;^LSo00001?o>^LH00ol0003oe/34omK0a003omK0a005o`000?oH`<;o0000omc5`ol000001?oN
aL400ol0003oglFnomo5_P02o`0000;ohlVn00Go0000onC9_?oTbKcoi<Vlo`000002onG8^`;o0000
0_oUb[`01Ol0003oiLVkonG9^ooUbK_o000000;oiLRj00Go0000on?7_?oSakcohlNlo`000003on;5
_005o`000?oP`k_o0000omg2_ol000000ooK_kh00ol0003ofKfno`000002om>j`@06o`000?o@]l7o
d;O1o`000?o9//Co00000oo6[l<00ol0003o_Z[5o`000003ok^Va004o`000?ncXLKo/j76ok>QaP;o
00001?nXV<H01Ol0003oWi?8oinCb?nOTlSo000000?oUHk:00?o0000ohZ:cOn:R/d00_n:R/d01Ol0
003oOhK@ogn6d?moQ]3o000000;oM8?C00Co0000ofV0eomYP=OoJH3G1?l00003odMlh@Go000000?o
47CQo`000?l000000ol00004ojK=m006o`000?nW`>_o0000o`000?nW`>_o00001?nW`>/4o`0000;o
Yl3[00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`008_ooool01Ol@413ooooo
oooooooooooo410@00Gooooo00?o0000ooooooooool01Oooool00ol0003oYl3[ojO0j`02ojO0j`04
o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000;oYl3[00?o0000ojO0
jonW`>/00_nW`>/3o`0000CoYl3[00?o0000ojO0jonW`>/01?l00004ojO0j`03o`000?nW`>_oYl3[
00?o00001?nW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[00?o0000
ojO0jonW`>/01?l000001On0Zo3o0000oeYad?mJLM3o000000;oKWgA00?o0000oh28dOl000000_l0
0004oi6Bd@03o`000?nOVm3oWi_@00;oWi_@00Ko0000oj^Scon[Xloo0000ojnTcOl00005okV[c003
o`000?o1//_o000000Coa;?900?o0000ol^ib?l000001Oo>^LH00ol0003oe/34omK0a002omK0a005
o`000?oH`<;of<32omS0`_l000001?oNaL402Ol0003oglFnomo5__oOaKko0000on75_?l0003ohlVn
o`000002onC9_009o`000?oUb;_oiLRkonG8^ol0003oiLRio`000?oUb[co000000;oiLVk00Co0000
onG8^_oUb;[oiLRj0_l000000ooSakco0000on;5_003on;5_004o`000?oP`k_oh<>ko`0000?ofknn
00Ko0000omVm__oI_Kko0000om>j`Ol00004om2g`@03o`000?o6[l?oaZo300?oaZo300?o0000ok^V
a?nkY/@00_nkY/@01_l0003o/j76o`000?l0003o/Ig4o`0000CoZ9S600Go0000oinCb?nOTlSoWi?8
o`000003oiF>bP03o`000?n:R/goRX[=00;oRX[=00Go0000ogn6d?moQ]3oOhK@o`000003ogB3d`06
o`000?mYP=OoJH3GofV0eol0003oHH3K0_l00003odMlh@03o`000?m2P>Go000000Co000000?o5WoV
o`000?l000001_l00004ojO0j`06o`000?nW`>_o0000o`000?nW`>_o00001OnW`>/00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo017ooooo000Rooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?nW`>_oYl3[00Co00001?nW`>/01_l0003oYl3[
o`000?l0003oYl3[o`0000CoYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02
ojO0j`?o00001?nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00004
ojO0j`03o`000?nW`>_oYl3[00Co00000_nO_Nh01?l0003oAVC=o`000?l00003oeYad0Co00000on0
R=400ol0003oTI;Aoi6Bd@02oi6Bd@07o`000?nOVm3oWi_@oinKd?l0003oZj??o`000003ojnTc@03
o`000?niZlco^J_<00;o^J_<0_l00006olBcb@03o`000?o>^LKoc[W600?oc[W600?o0000om6ja?l0
00000_oF`<@00ol0003of<32omS0`P02omS0`P;o00000_oNaL401Ol0003oglFnomo5__oOaKko0000
00?ohLFl00Co0000onC9_?oTbKco00000ooUb;/01Ol0003oiLRionG8^OoUb;Wo000000;oiLVk00Go
0000onG8^_oUb;[oiLRjo`000002onG7^@03o`000?oRaKcoh/Fl00;oh/Fl00Go0000on33^ooP`k_o
h<>ko`000003om^o_P05o`000?oI_KkofKfnomVm__l000001?o@]l42o`0000CoaZo30_l00004ok^V
a0;o00001?naWL@01Ol0003oZ9S6ojRHa_nXV<Ko000000;oWi?84ol00004ofV0e`03o`000?mQP=_o
HH3K00Go00000_m2P>D2o`000003ob]oj?l0003o000000?o00000on>c_d01?l0003oYl3[ojO0jonW
`>/3o`0000CoYl3[00Co0000ojO0jonW`>_oYl3[0ol0000Booooo`03o`000?oooooooooo017ooooo
000Rooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`07ooooo`;o0000
1?nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00004ojO0j`04o`00
0?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000?oYl3[00Co0000ojO0jonW
`>_oYl3[0ol00004ojO0j`03o`000?nW`>_oYl3[00Co00001?nW`>/01?l0003oWkg^oinmk_l00002
odITc@Co00000om^OM401Ol0003oP8SAoh28dOn0R=7o000000?oTI;A00?o0000oinKd?nOVm000ol0
0005ojnTc@06o`000?niZlco^J_<o`000?nl[<Wo00001Oo4/lT00ol0003ob;C6o`000003oljiaP06
o`000?oA^/CodK[4o`000?oF`<Co00001?oH`<801_l0003ofl70om_1`?l0003og/G1o`0000;oglFn
00?o0000on75_?oQaK`00_oQaK`2o`000003onC9_?l0003oiLRk00;oiLRk00Co0000onG8^OoUb;Wo
iLRi0_l000000ooUbK_o0000onG8^P02onG8^P03o`000?oUakWoiLNi00;o00000_oRaK`02Ol0003o
h<>kon33^ooP`k_o0000omo2^ol0003ofknno`000004omVm_P05o`000?o@]l7od;O1om2g`Ol00000
0_o=/l001?l0003oaZo3olJ_`ol00002ol>[`P06o`000?nkY/Co^jK4o`000?niX/;o00001?naWL@0
1?l0003oZ9S6ojRHa_nXV<H3o`0000;oWi7500Go0000oiN=aonGSLOoUhg7o`000004ohj9b@05o`00
0?n6Q/coQXK<ohJ6c?l000000_mmQ=06o`0000;oHH3K00Co0000oeZ2gomJP]ooFX;O1?l000000om3
Qn[o0000o`000002o`000003oc29kOl0003o000000Ko00000onW`>/00ol0003oYl3[ojO0j`05o`00
00;oYl3[00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`00;?ooool2o`0000Wo
oooo00?o0000ojO0jonW`>/00_nW`>/3o`0000CoYl3[00?o0000ojO0jonW`>/00ol00004ojO0j`03
o`000?nW`>_oYl3[00Co00001?nW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`000?nW`>_oYl3[
00;oYl3[00?o0000ojO0jol000000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`?o00000onW`>/00ol0
003oYl3[ojO0j`02ojO0j`?o000000CoWkg^o`000?l0003o00000_mKL<l5o`0000?oP8SA00?o0000
oi6BdOnAT]401?l00002oj>LcP03o`000?n_Y<go[jC=00?o[jC=00?o0000okV[c?l000000onl[<T0
1Ol0003oa;?9olBcbOo4/lWo000000?ob;C600?o0000oljia_l000001?oA^/@00ol0003of<32omS0
`P02omS0`P03o`000?oK`L3ofl7000;ofl7000Go0000omo5__oOaKkoglFno`000003on75_004o`00
0?oRaK_oh/Fko`0000?oiLRk00Go0000onG8^OoUb;WoiLRio`000002onG7^@05o`000?oUb;[oiLRj
onG8^_l000000_oUakT01_l0003oi<JionC6^Ol0003oh/Flo`0000?oh<>k00Co0000omo2^ooO`[_o
00001?oI_Kh01Ol0003oe[Zno`000?o@]l7o000000?ocK?000?o0000olJ_`ol000000oo3Zl800ol0
003o^jK4o`000003okVR`P06o`000?naWLCo/Ig4ok6Ma?l0003oZ9S60_l000000onWUL?o0000oinA
a@03oinAa@05o`000?nGSLOoUhg7oiN=aol000001?n>RLT01Ol0003oQXK<ohJ6c?n6Q/co000000;o
OHC@00Co0000ogF3domePm?oMH?C1Ol00003oeZ2g`04o`000?mFQ^Co0000o`0000?o@hOZ1Ol00002
ofben`03o`000?nW`>_oYl3[00?oYl3[0ol00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[0_l0000C
ooooo`03o`000?oooooooooo00oooooo000/ooooo`03o`000?oooooooooo00Wooooo00Co0000ojO0
jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`04
o`0000CoYl3[00?o0000ojO0jonW`>/01?l00004ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/0
1?l0003oYl3[o`000?l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[00Go0000ojO0jol0003o0000
ojO0j`04o`0000;oAVC=00Co0000oe]`comKL<oo00000_m`O=07o`0000;oU9;?00?o0000oj>Lc_nS
W<h00_nSW<h00ol0003o[jC=ojnTc@02ojnTc@;o00001Onl[<T00ol0003oa;?9o`000005olRdaP03
o`000?oA^/CodK[400?odK[40_l00003omS0`P03o`000?oK`L3ofl7000;ofl700_l000000ooOaKko
0000on75_002on75_005o`000?oRaK_oh/Fkon;5^ol000000_oUb;/00ol0003oiLRionG8^@02onG8
^@04o`000?oUakWoiLNio`0000;oiLRj00Go0000onG7^OoUakWoiLNio`000003onC6^@05o`000?oP
`k_oh<>kon33^ol000000ooO`[/01Ol0003ofKfnomVm__oI_Kko000000?oe[Zn00?o0000olfc`?o=
/l000oo=/l000ol0003o`j_2ol>[`P03ol>[`P03o`000?niX/;o^J;200;o^J;200Co0000ok6Ma?na
WLCo/Ig40_l00004ojNE``05o`000?nOTLGoWi75oinAaOl000000onGSLL00ol0003oSXW9ohj9b@02
ohj9b@05o`000?n6Q/coQXK<ohJ6c?l000000ommQ=001Ol0003oMH?CogF3domePm?o000000;oKXCH
0ol00002oeZ2g`03o`000?mFQ^CoEXKT00Go00000_m7TNl5o`000006ojO0jol0003o0000o`000?nU
c_Go00001?nW`>/01_l0003oYl3[o`000?l0003oYl3[o`0001?ooooo00?o0000ooooooooool03ooo
ool002cooooo00?o0000ooooooooool02_ooool2o`0000CoYl3[00Ko0000ojO0jol0003o0000ojO0
jol00004ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`02ojO0j`?o00001?nW`>/00ol0003oYl3[
ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00004ojO0j`03o`000?nW`>_oYl3[00Ko0000
00CoYl3[o`000?m9MM_oBGGK0ol00003oe]`c`04o`000?m`O=3oL7c@o`0000?oPhS@00?o0000oiBB
conDT/l00_nDT/l00ol0003oXic>oj>LcP02oj>LcP06o`000?n_Y<go0000o`000?nbYL_o00001Onl
[<T2o`0000Gob;C60_l00004om6ja006o`000?oD^l;oe;_2o`000?oH`<;o00001?oK`L001?l0003o
g<6nomc1__l00003on75_009o`000?oRaK_oh/Fkon;5^ol0003ohlJjo`000?oUb;_o000000?oiLRi
00So0000onG7^OoUakWo0000onK7^?l0003oiLRjo`0000;oiLNi00?o0000onC6^OoTa[T00_oTa[T0
1?l0003oh<>kon33^ol00003omo2^`05o`000?oM`;co0000omVm__l000001?oF^[h00ol0003ocK?0
olfc`002olfc`0;o00001?o3Zl82o`0000Co^J;200Ko0000ok6Ma?l0003o0000ojnJ`_l00004ojNE
``05o`000?nOTLGoWi75oinAaOl000000onGSLL00ol0003oSXW9ohj9b@02ohj9b@05o`000?n6Q/co
QXK<ohJ6c?l000000ommQ=000ol0003oMH?CogF3d`02ogF3d`05o`000?m^Q=SoKXCHo`000?mYQ]`0
0ol00002oeJ6i004o`000?mGSNWoEhgYoeN=j@Go00000_mCX?D2o`0000GoYLke00?o0000ojO0jonW
`>/00ol00004ojO0j`03o`000?oooooooooo013ooooo0_l0000@ooooo`00:oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?nW`>_oYl3[00Co00000onW`>/01?l0003oYl3[o`000?l00002ojO0j`03
o`000?nW`>_oYl3[00;oYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0
j`?o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`?o00001?nW`>/00ol0003oYl3[ojO0j`07o`00
0005ojO0jol0003oYl3[ojO0jol000000_m9MM/00ol0003oAV?;o`000003oe]`c`05o`000?m`O=3o
L7c@og1ld?l000000on3R=001Ol0003oU9;?oiBBconDT/oo000000CoXic>0_l00004ok:Ub`03o`00
0?nl[<Wo_:c900;o000000?o`:k8o`000?o8]<H00oo8]<H01?l0003obkG5ol^eaOl00002om6ja003
o`000?oD^l;oe;_200;oe;_200?o0000om_1`?oK`L000_oK`L001Ol0003og<6nomc1__oL`Kko0000
00?ohLFl00Go0000on;5^ooRaK_oh/Fko`000002on?6^P;o00000_oUb;T01Ol0003oiLNionG7^OoU
akWo000000;oi/Nh00Co0000onG7^OoUakWo00001?oTa[T01Ol0003ohlFio`000?oP`k_o000000;o
gl:k00Go0000omg0_?oM`;cogL2lo`000004omJj_P03o`000?oC^;ko000000;ocK?000Co0000olZ`
`?o:/<3o00000_o3Zl801?l0003o`:O1ol2W`Ol00003okVR`P;o00001?n_V/801Ol0003oYiG3ojNE
`onWUL?o000000?oWi755ol00003ofj4f004o`000?mYQ]coJHKLofV6g0Co00000omGSNT2o`000003
oeZGkol0003o000000Co00000_nUc_D5o`0000?oYl3[00?o0000ojO0jonW`>/00ol0000Booooo`03
o`000?oooooooooo00kooooo000[ooooo`;o00003oooool2o`0000CoYl3[00?o0000ojO0jonW`>/0
0ol00004ojO0j`03o`000?nW`>_oYl3[00Co00001?nW`>/01_l0003oYl3[o`000?l0003oYl3[o`00
00CoYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`?o00000_nW`>/2
o`0000CoYl3[1_l000000om9MM_o0000odISb`04o`0000?oL7c@00Go0000oh>8d?n3R=3oPhS@o`00
0003oiBBc`03o`000?nSW<ko000000;o000000?oYYg<o`000?nbYL/00onbYL/00ol0003o_:c9o`00
0004ol2^b004o`000?o8]<Kob;C6o`0000?obkG500?o0000om6ja?l000001?oD^l82o`0000?ofl70
00Wo0000omc1__oL`Kkog<6no`000?oN`[co0000on75_?l000000ooRaK/02Ol0003ohlJjon?6^_oS
a[[o0000onC6^Ol0003oiLRio`000002onG7^@04o`000?oVakSoi/NhonK7^0;o000000?oiLNio`00
0?oTa[T00ooTa[T01?l0003ohlFion?5^Ol00003omo2^`05o`000?oM`;cogL2lomg0_?l000000ooF
^[h01_l0003odkRnom>h__l0003ocK?0o`0000?ob[3000?o0000ol>[`_l000000oo0Yl401_l0003o
^J;2okVR`_l0003o]Yo1o`0000Co[i[200?o0000ojNE`onWUL<00_nWUL<3o`000003oin?`ol0003o
VHc400;oVHc400?o0000oi:9a_nBRLH00_nBRLH01Ol0003oRhO9oh^7bOn;QlWo000000?oQHG<00Co
0000ogn5d?moQM3oOhG@1Ol00003ofV6g003o`000?mWRn7oIh_Q00Oo00000_mJUnl00ol0003oHJ;d
of6Rm003o`0000?oU<?g00Co0000ojO0jonW`>_oYl3[1?l00003ojO0j`03o`000?oooooooooo013o
oooo00?o0000ooooooooool03Oooool002_ooooo00?o0000ooooooooool03oooool00ol0003oYl3[
ojO0j`02ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`04o`0000CoYl3[00?o0000ojO0jonW`>/0
1?l00003ojO0j`03o`000?nW`>_oYl3[00Co00001?nW`>/01?l0003oYl3[o`000?l00002ojO0j`?o
00000_nW`>/01_l0003oYl3[o`000?l0003oYl3[o`0000;oJZSe00Ko0000obmDa_l0003o0000odIS
bol00002oea`cPGo00000on3R=000ol0003oU9;?oiBBc`03o`0000GoYYg<00Co0000ok:UbonbYL_o
/ZG;0_l00005ol2^b003o`000?o8]<Ko000000GobkG500?o0000omBk`_oD^l800_oD^l801_l0003o
e[c0omJl`?l0003ofl70o`0000Cog<6n00Co0000omk2_?oN`[co00001?oRaK/01?l0003ohlJjon?6
^_l00003onC6^@05o`000?oUakWoiLNionG7^Ol000000_oVakP01?l0003oi/NhonK7^?l00004onC6
^@04o`000?oSaKWohlFion?5^@;o000000?ogl:ko`000?oM`;`00_oM`;`00ol0003ofkjlo`000002
omJj_P05o`000?oC^;kodkRnom>h__l000001Oo:/<000ol0003o`:O1ol2W`@02ol2W`@03o`000?ni
X/;o000000?o]Yo100Go0000ojnJ`_n_V/;o[i[2o`000002ojNE``?o00001?nOSl<01Ol0003oVHc4
oiV<a?nIS<Co000000CoTXW600Go0000oh^7bOn;QlWoRhO9o`000003ohF5c005o`000?moQM3oOhG@
ogn5d?l000000_mjQm@4o`000005ofV6g?l0003oIh_QofN;hOl000000omWTNL:o`0000;oU<?g1Ol0
0002ojO1k003o`000?nW`>_oYl3[00;oYl3[0_l0000Booooo`03o`000?oooooooooo00cooooo000[
ooooo`03o`000?oooooooooo013ooooo00Ko0000ojO0jol0003o0000ojO0jol00004ojO0j`?o0000
0onW`>/00ol0003oYl3[ojO0j`02ojO0j`?o00001?nW`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[
00?o0000ojO0jonW`>/01ol000001?nW`>_o0000ojO0jonW`>/3o`0000CoYl3[00Ko0000ofZXmOmZ
Z?Go0000obmDa_l00002odISb`04o`000?mLL<koG73>o`0000;oLWg?1ol00002oiRDcP03o`000?nV
WLcoYYg<00?oYYg<00Ko0000ok:UbonbYL_o0000okJWbOl00006ol2^b003o`000?o;]LGobkG500Co
bkG500Go0000omBk`_oD^l;oe;_2o`000004omJl`003o`000?oL`Kkog<6n00;og<6n00Co0000omk2
_?oN`[cog/:l0_l00002on;5^`05o`000?oSa[[ohlJjon?6^_l000000ooTa[T01?l0003oiLNionG7
^Ol00003onK7^003o`000?oVakSoi/Nh00;o00000_oTa[T01Ol0003ohlFion?5^OoSaKWo000000;o
h/Bj00Go0000omg0_?oM`;cogL2lo`000002om^n_003o`000?oF^[ko000000CodkRn00?o0000olZ`
`?o:/<000_o:/<02o`0000Co`:O10_l00004okJO`@04o`000?n_V/;o[i[2ojnJ`P?o00000_nVTl40
0ol0003oWho3oin?``02oin?``03o`000?nIS<CoVHc400;oVHc400Go0000oi:9a_nBRLKoTXW6o`00
0003oh^7b@05o`000?n5QLcoQHG<ohF5c?l000001?moQM001?l0003oNXODogZ7e?l00002ogJ9f@Ko
00000omWTNL2o`0000;oJi[/00Co0000og2UlOm`YO7oL:Ga0ol00002ohNgm@03o`000?nW`NcoYl7/
00?oYl7/1?l000000onW`>_o0000ooooo`0Aooooo`03o`000?oooooooooo00cooooo000[ooooo`03
o`000?oooooooooo017ooooo0_l00003ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0
jonW`>/00_nW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[0ol00003
ojO0j`03o`000?nW`>_oYl3[00Co000000?oYl3[o`000?l000000_l00002ojO0j`Co00000onW`>/0
0ol0003oYl3[ojO0j`05o`0000;o;eC60_l000001Om6Hl_o0000oea`c_mLL<ko000000;oLWg?00Go
0000ohJ9con6RLooQXW?o`000004oiRDcP03o`000?nVWLcoYYg<00;oYYg<00?o0000ok:Ubol00000
0onfYlT00ol0003o`:k8ol2^b002ol2^b0;o00001Oo;]LD01Ol0003oc[K3o`000?oD^l;o000000Go
e[c00_l00002omc1_P05o`000?oN`[cog/:lomk2_?l000000_oP`k/00ol0003oh/Fko`000002on?6
^P09o`000?oTa[Woi<JionC6^Ol0003oiLJho`000?oUakWo000000;oi/Nh00Co0000onK7^?oVakSo
00000_oUa[P00ol0003oi<Jio`000003on?5^@04o`000?oRa;[oh/Bjo`0000?ogL2l00Go0000om^n
_?oK_[cofkjlo`000004om>h_P03o`000?o@]Koo000000;ob[3000Co0000olN]`?o7[L3o00000_o0
Yl400ol0003o_JC1o`000004okJO`@06o`000?n_V/;o0000o`000?n]Ul7o00001?nVTl401Ol0003o
Who3oin?`onOSl?o000000CoVHc400Go0000oi:9a_nBRLKoTXW6o`000003oh^7b@05o`000?n5QLco
QHG<ohF5c?l000001?moQM001Ol0003oNXODogZ7e?mjQmCo000000;oMXWI00Co0000ogB>g_mdS]ko
M8kN2_l00003og2Ul@03o`000?n7]oGoQkOe00;oQkOe00?o0000ojO1k?nW`N`00ol00005ojO0j`03
o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool002_ooooo00?o0000ooooooooool0
4oooool00ol0003oYl3[ojO0j`03o`0000CoYl3[00?o0000ojO0jonW`>/01?l00004ojO0j`06o`00
0?nW`>_o0000o`000?nW`>_o00001?nW`>/3o`0000;oYl3[0ol00003ojO0j`?o00000onW`>/00ol0
003oYl3[ojO0j`04o`0000;oYl3[00Oo0000oae:`ol0003o0000obmDa_l0003oAV;:00;o00000_mL
L<h01Ol0003oLWg?og9mcombOLoo000000?oQXW?00?o0000oiRDc_nHU<h00_nHU<h01?l0003oYYg<
ojJMc?nVWL`2o`0000Go]ZO900Co0000ol2^b?o0[/So00000_o3[lH01Ol0003obkG5ol^eaOo;]LGo
000000?oc[K300?o0000omJl`?oF_<000ooF_<001_l0003ofKfnomVm__l0003og<6no`0000?og/:l
00Go0000on33^ooP`k_oh<>ko`000002on?6^P05o`000?oTa[Woi<JionC6^Ol000000ooUa[P01?l0
003oi/NhonK7^?l00003onK7^005o`000?oUa[SoiLJhonG6^?l000000ooSaKT02?l0003oh/Bjon;4
^_l0003ohL>jo`000?oM`;co00001?oK_[`01Ol0003odkRnom>h__oC^;ko000000;od;Fo00?o0000
olZ``?l000000oo7[L000ol0003o`:O1o`000003okfT`@04o`000?nfWl7o]Yo1okJO`@;o00001?n]
Ul401Ol0003oYY?1ojJC`OnVTl7o000000CoWho300?o0000oiV<a?nIS<@05ol00003ogJ9f@05o`00
0?mdS]koM8kNogB>g_l000000omeUN@01?l0003oN9gYo`000?mhWNT<o`0000?oYLKa00Co0000ojO0
jonW`>_oYl3[0ol0000Booooo`03o`000?oooooooooo00[ooooo000Zooooo`;o00005_ooool2o`00
00?oYl3[00?o0000ojO0jonW`>/01?l00004ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/01?l0
003oYl3[o`000?l00002ojO0j`?o00000_nW`>/01_l0003oYl3[o`000?l0003oYl3[o`0000CoYl3[
0ol00003ojO0j`07o`000?nW`>_oYl3[ojO0jol0003o7D[3o`000002obmDaP03o`000?m6H/[oAV;:
00;o000000?oG73>o`000?mbOLl00_mbOLl01Ol0003oQXW?ohJ9con6RLoo000000?oV9C>00Ko0000
ojJMc?l0003o0000ojZObol00005okJWb@03o`000?o0[/So000000Co`jo600?o0000ol^eaOl00000
1?o>]/<00ol0003oe[c0omJl`002omJl`003o`000?oI_KkofKfn00;ofKfn00Go0000omk2_?oN`[co
g/:lo`000004on33^`;o000000?ohlJjo`000?oTa[T00_oTa[T01?l0003oiLJhonG6^?oUa[P2o`00
0005onK7^?l0003oi/NhonK7^?l000001?oUa[P01?l0003ohlFion?5^Ol00003on;4^P04o`000?oQ
`k[ohL>jo`0000Cofkjl00Go0000omVl_Ol0003odkRno`000004om2e_`03o`000?o7[L3oajg000?o
ajg000?o0000okfT`OnmY<400_nmY<401_l0003o]Yo1okJO`Ol0003o/ic0o`0000Co[IO100Go0000
ojJC`OnVTl7oYY?1o`000002oin?``Go00000_nJRl801Ol0003oUHW4oiF9a?nERLCo000000?oT8O6
00Go0000oh^7bOn;QlWoRhO9o`000004ohN7c@03o`000?n3RM7oPhWA00Go00001?mdS]h01?l0003o
MIGTogFEi?meUN@2o`0000;oN9gY00?o0000ogfWk_mmYnh00_mmYnh00ol0003oP[3boh:`lP02oh:`
lP03o`000?nUa_7oYLKa00Go00000_nW`>/00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00[ooooo000Zooooo`03o`000?oooooooooo01Gooooo00?o0000ojO0jonW`>/00_nW`>/3o`0000Co
Yl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Oo000000CoYl3[o`000?nW
`>_oYl3[0ol00004ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/0
1_l0003oYl3[ojO0jonW`>_o0000oae:``?o00000_m6H/X01?l0003oGW3=o`000?l00003og9mc`05
o`000?n6RLooQXW?ohJ9col000000_nHU<h3o`0000CoZYo;00?o0000okJWbOnfYlT00_nfYlT2o`00
00Go`jo60_l00004oljf``03o`000?oA^<7o000000?oe[c000?o0000omVm__oI_Kh00_oI_Kh01?l0
003og/:lomk2_?l00004on33^`04o`000?oQ`k[ohL>jo`0000?oi<Ji00Go0000onG6^?oUa[SoiLJh
o`000002onK6]`05o`000?oVakSoi/NhonK7^?l000000ooUa[P01Ol0003oiLJho`000?oSaKWo0000
00;oh/Bj00Go0000on73^_oQ`k[ohL>jo`000003om^n_005o`000?oI_;gofKbmomVl_Ol000001Oo@
]Kl00ol0003oajg0olN]`002olN]`0;o00001?nmY<400ol0003o]Yo1o`000003ok>L`005o`000?n]
Ul7o[IO1ojfG`Ol000000onVTl43o`0000;oX8g100?o0000oiZ;`_nJRl800onJRl801Ol0003oUHW4
oiF9a?nERLCo000000?oT8O600Go0000oh^7bOn;QlWoRhO9o`000004ohN7c@04o`000?n3RM7oPhWA
o`0000;oPHgF3ol00002ogfWkPWo00000_nN_o000ol0003oYl3[ojO0j`02ojO0j`;o00004_ooool0
0ol0003oooooooooo`09ooooo`00:_ooool00ol0003oooooooooo`0Fooooo`04o`000?nW`>_o0000
o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000?oYl3[00Co0000ojO0jonW`>_oYl3[0ol0
00000onW`>_o0000o`000002o`0000;oYl3[1?l00003ojO0j`03o`000?nW`>_oYl3[00Co00001?nW
`>/00ol0003oYl3[ojO0j`06o`000004oae:`ol0003o;e;5o`0000?oAV;:00?o0000oei`cOmNL<d0
2_l00002oi^Fc@03o`000?nZWl_oZYo;00?oZYo;00Ko0000okJWbOnfYlWo0000okZXb?l00004ol>_
aP03o`000?o6/LGo000000?oc[K300Oo0000om6h`OoA^<7odKS1o`000?oF_<3o000000CofKfn00Go
0000om^n_Ol0003og/:lo`000003on33^`05o`000?oQ`k[ohL>jon73^_l000000ooTa[T01Ol0003o
iLJhonG6^?oUa[So000000;oi/Jg00Co0000onK7^?oVakSo00001?oUa[P01?l0003oiLJhonG6^?l0
0002on;4^P07o`000?oQ`k[ohL>jon73^_l0003ogl:ko`000002om^n_005o`000?oI_;gofKbmomVl
_Ol000001?o@]Kl00ol0003ocK?0o`000002olN]`004o`000?o3Z/7o`j[1o`0000?o_JC10_l00004
ok>L`003o`000?n]Ul7o[IO100;o[IO10ol000000onUTL3o0000oj2=`@03oj2=`@03o`000?nJRl;o
VX_200;oVX_200Go0000oiF9a?nERLCoUHW4o`000003oi27aP05o`000?n;QlWoRhO9oh^7bOl00000
1?n7Qld01Ol0003oPhWAoh>9dOn3RM7o000000;oPHgF00?o0000ognAfomoTM/00_moTM/02?l0003o
P9SQoh2HhOn0V>7o0000oh>Pi_l0003oPj3V0ol00002ohNXj`03o`000?n</NooS;7_00;oS;7_00?o
0000oijol?nN_o000_nN_o001_l0003oYl3[o`000?l0003oYl7/o`00017ooooo0ol0000:ooooo`00
:_ooool00ol0003oooooooooo`0Gooooo`;o00001?nW`>/01?l0003oYl3[o`000?l00002ojO0j`03
o`000?nW`>_oYl3[00;oYl3[00Co0000ojO0jol0003oYl3[0ol00003ojO0j`?o00001?nW`>/00ol0
003oYl3[ojO0j`03o`0000CoYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`07o`000?lkQ>Wo0000
o`000?lMB/?o0000obmBa@02o`000005odIRb_l0003oGW3=oei`cOl000000omeO/h01Ol0003oRH_>
ohV;c_n9Rlko000000CoViK=00?o0000ojZObonZWl/00_nZWl/00ol0003o]ZO9o`000003okZXb004
o`000?o3[lKo`jo6o`0000?oa[7500Co0000oljf`oo>]/?o00001?oA^<400ol0003ofKfnomVm_P02
omVm_P05o`000?oK_[gofkjmom^n_Ol000000ooP`k/02Ol0003ohL>jon73^_oQ`k[o0000on?4^Ol0
003oi<Jio`000003onG6^008o`000?oVa[Ooi/Jgo`000?oVakOo0000onK7^?l00003onG6^004o`00
0?oUa[SoiLJhonG6^0;o000000?oh/Bjo`000?oQ`kX00_oQ`kX01Ol0003ogl:ko`000?oK_[co0000
00?ofKbm00?o0000omJj__l000000_o@]Kl01_l0003ocK?0olfc`?l0003oajg0o`0000?o`j[100Ko
0000okfT`OnmY<7o0000okVQ`?l00004ok>L`004o`000?n]Ul7o[IO1ojfG`@;o00001?nUTL001Ol0
003oX8g1oj2=`OnPSL7o000000CoVX_200Go0000oiF9a?nERLCoUHW4o`000003oi27aP05o`000?n;
QlWoRhO9oh^7bOl000001?n7Qld01Ol0003oPhWAoh>9dOn3RM7o000000?oPHgF00?o0000ognAfomo
TM/00_moTM/01?l0003oP9SQoh2HhOn0V>42o`0000?oPj3V00Go0000ohNXjon7Z>_oQjS[o`000002
ohbak`So00001?nW`N`00ol0003oooooooooo`0;ooooo`?o00000_ooool00ol0003oooooooooo`08
ooooo`00:_ooool2o`0001[ooooo00?o0000ojO0jonW`>/01?l00004ojO0j`03o`000?nW`>_oYl3[
00Go00000_nW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[0ol00002
ojO0j`03o`000?nW`>_oYl3[00;oYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00?o000000Oo>hCY
o`000?l0003o0000obmBaOl0003oAf7:00;o00000omNL<d01Ol0003oMGk>ogEnc_meO/ko000000?o
RH_>00Go0000oi^FcOnKU/goViK=o`000004ojZOb`;o00001?njZ<P00ol0003o`jo6o`000004olJa
a@03o`000?o>]/?o000000GodKS100Go0000omVm__oI_KkofKfno`000004om^n_@05o`000?oP`k_o
h<>kon33^ol000000ooQ`kX01?l0003ohlBion?4^Ol00004onG6^004o`000?oVa[Ooi/Jgo`0000;o
i/Ng0_l00002onG6^005o`000?oUa[SoiLJhonG6^?l000000_oTa[T01Ol0003ohL>jon73^_oQ`k[o
000000?ogl:k00Go0000omVl_OoI_;gofKbmo`000002omJj_P03o`000?o@]Koo000000CocK?000?o
0000ol>Z`Oo3Z/400_o3Z/400ol0003o_JC1o`000003okVQ`003o`000?ncW<3o/ic000;o/ic00ol0
00000on[U;oo0000ojFA`003ojFA`005o`000?nPSL7oX8g1oj2=`Ol000001OnJRl800ol0003oUHW4
o`00000Zo`0000;oTk7/00?o0000oi^jk_nK^^h00onK^^h00ol0003oYl7/ojO1k003o`0000Wooooo
0ol00005ooooo`03o`000?oooooooooo00Sooooo000Yooooo`;o00007?ooool2o`0000CoYl3[00?o
0000ojO0jonW`>/02?l00002ojO0j`Co00001?nW`>/01_l0003oYl3[o`000?l0003oYl3[o`0000Co
Yl3[00Co0000ojO0jol0003o00000_nW`>/01?l0003oYl3[ojO0jonW`>/3o`0000;oV[c`0_l00000
0olkQ>Wo0000o`000002obmBa@03o`000?m7HL[oAf7:00;o000000?oGW3=o`000?meO/h00_meO/h0
1Ol0003oRH_>ohV;c_n9Rlko000000?oViK=00?o0000ojZObol000000_l000000on^XL[o0000okZX
b003okZXb0;o00001_o6/LD00ol0003odKS1om6h`@03om6h`@05o`000?oC^L3o0000omVm__l00000
1?oK_[d01Ol0003ogL2lo`000?oP`k_o000000?ohL>j00Co0000on?4^OoSa;WohlBi0_l00002onG6
^004o`000?oVa[Ooi/Jgo`0000?oi/Ng00Go0000onK7]ol0003oiLJho`000003onG6^004o`000?oT
a[Woi<Jio`0000;ohL>j00?o0000omo2^ooO`[/00_oO`[/01Ol0003ofKbmomVl_OoI_;go000000?o
e[Zn00?o0000olfc`?o=/l000oo=/l000ol0003o`j[1ol>Z`@03ol>Z`@03o`000?niXL3o^J7000;o
^J7000Co0000ok>L`?ncW<3o/ic00_l00004oj^D_`05o`000?nUTL3oYI70ojFA`?l000001?nPSL40
0ol0003oVX_2oiZ;`P04o`0000;oV8W200Go0000oiB8a?nDR<CoU8S4o`000003oi68a`03o`000?n>
RL[oSXW:00;oSXW:00Go0000oh^<c_n;S<koRhc>o`000003ohZ?d`03o`000?n9U=SoRICH00;oRICH
00Oo0000ohZKgOn:VmgoRY_Mo`000?n<X^?o000000;oS:;S00Go0000oi2Zion@Z^OoT:[Wo`000004
oi>ak004o`000?nK^^koVk[^oi^jkPCo00000onW`N`00ol0003oooooooooo`02ooooo`Co00002?oo
ool00ol0003oooooooooo`08ooooo`0000?o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool07?ooool00ol0003oYl3[ojO0j`02ojO0j`?o
000000CoYl3[o`000?l0003o00000_nW`>/4o`0000CoYl3[00?o0000ojO0jonW`>/00ol00004ojO0
j`03o`000?nW`>_oYl3[00Co00001?nW`>/00ol0003oYl3[o`000002ojO0j`04o`000?nJ_?3oV[c`
oiZll0?o000000Co64Boo`000?l0003o00000_m7HLX01?l0003oH77=o`000?l00003ogEncP05o`00
0?n9RlkoRH_>ohV;c_l000000_nKU/d3o`0000Go[Z7:00Ko0000okZXb?njZ<So0000okf[aol00005
olJaa@03o`000?o:/l?o000000?odKS100Go0000om>i`?oC^L3odkW0o`000005om^n_@04o`000?oM
`;cogL2lo`0000CohL>j00Co0000on?4^OoSa;Wo00000_oTaKP00ol0003oiLJho`000002onK6]`04
o`000?oVakOoi/Ngo`0000?oi/Ng00Go0000onG6^?oUa[SoiLJho`000002onC6^@05o`000?oTa[[o
0000on73^_l000000ooO`[/01Ol0003ogL6mo`000?oI_;go000000Coe[Zn00?o0000olfc`?o=/l00
0_o=/l000ol0003obK31o`000003ol>Z`@;o00001?niXL001_l0003o/ic0o`000?l0003o/9W0o`00
00CoZiBo00?o0000ojFA`?nUTL000_nUTL000ol0003oX8g1o`000004o`0000;oW8[000?o0000oiR9
`_nHRL800_nHRL801Ol0003oU8S4oiB8a?nDR<Co000000?oTHS700?o0000ohj9b_n>RLX00_n>RLX0
1Ol0003oRhc>oh^<c_n;S<ko000000?oRXoC00?o0000ohVDf?n9U=P00_n9U=P01ol0003oRY_MohZK
gOn:Vmgo0000ohbRhol000000_n<X^<01Ol0003oT:[Woi2Zion@Z^Oo000000;oTk7/1Ol00002oifi
k004o`000?nW`NcoYl7/ojO1k0Ko00003?ooool00ol0003oooooooooo`08ooooo`0000?ooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01gooooo00Go
0000ojO0jol0003o0000ojO0j`03o`0000;oYl3[0ol00004ojO0j`03o`000?nW`>_oYl3[00Co0000
0onW`>/00ol0003oYl3[ojO0j`04o`0000CoYl3[00?o0000ojO0jonW`>/00ol00004ojO0j`09o`00
0?nJ_?3oV[c`o`000?l4>;[o0000oaQ4_ol0003o;U;500;o00000_m7HLX00ol0003oH77=of1ac@0:
o`0000;oWiS<00?o0000ojjQb_n^XLX00on^XLX00ol0003o^ZS8o`000003okf[a`05o`000?o6/LGo
a[75olJaaOl000000oo:/l<00ol0003odKS1o`000004om>i`003o`000?oK_[gofkjm00;ofkjm00Co
0000omg0_?oM`;cogL2l0_l00002on73^P05o`000?oSa;WohlBion?4^Ol000000ooTaKP01?l0003o
i/JgonK6]ol00003onK7]`05o`000?oVakOoi/NgonK7]ol000000_oUa[P01Ol0003oi<JionC6^OoT
a[Wo000000;oi<Jj00Go0000omo2^ooO`[_ogl:ko`000003omg1_@03o`000?oF^[koe[Zn00;oe[Zn
00?o0000om>i`?l000000_o=/l001?l0003obK31olV``Ol00002ol>Z`@04o`000?noYl7o_jO1o`00
00?o^J700_l00004ok2I`005o`000?n[U;ooZiBooj^D_ol000000_nUTL04o`0000;oX8bo00?o0000
oib:`?nLR/000onLR/001Ol0003oV8W2oiR9`_nHRL;o000000?oU8S400Go0000oi68aonAR<OoTHS7
o`000004ohj9bP05o`000?n;S<koRhc>oh^<c_l000000on:Sm<00ol0003oRICHohVDf002ohVDf006
o`000?n:VmgoRY_MohZKgOl0003oS:;S2_l00003oiZbj@03o`000?nM^NcoWKW/00Go00000_nU_^/0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo0002ooooo`03oa0@4?oooooooooo
00Wooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01kooooo1?l00002ojO0j`03o`000?nW
`>_o000000;oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000?oYl3[00Co0000ojO0jonW`>_oYl3[
0ol00004ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04o`000003oiZl
l?l0003o13Rj00?o000000Go;U;5o`000?m7HL[oAf7:o`000002of1ac@05o`000?mhOlkoN7o>ogQo
c_l000000on=SLh00ol0003oWiS<oinHc002oinHc003o`000?n^XL[o[Z7:00;o[Z7:0_l00005okf[
a`03o`000?o6/LGo000000Gob[?300?o0000om>i`?oC^L000_oC^L000ol0003oe[^oo`000002om^n
_@05o`000?oM`;cogL2lomg0_?l000000_oN`K/00ol0003ohL>jo`000002on?4^@03o`000?oTaKSo
i<Fh00;oi<Fh0_l000001OoVa[Oo0000onK7]ooVakOo000000?oi/Ng00Go0000onK8^?l0003oiLJh
o`000002onC6^@05o`000?oTa[[oi<JjonC6^_l000000ooO`[/01Ol0003ogL6momg1_OoM`Kgo0000
00?oe[Zn00Ko0000om>i`?oC^L3o0000olfc`?l00003olV``@03o`000?o3Z/7o000000?o_jO100Ko
0000okVQ`?niXL3o0000okJN`?l00004ok2I`004o`000?n[U;ooZiBooj^D_`?o00000_nTSkl00ol0
003oX8booj2<_`02oj2<_`03o`000?nLR/3oW8[000;oW8[000Go0000oiR9`_nHRL;oV8W2o`000003
oiB8a005o`000?nAR<OoTHS7oi68aol000001?n>RLX00ol0003oRhc>oh^<cP0Bo`000003oiBTh?l0
003oUj_U00CoUj_U00?o0000oiZbjOnJ/^T01?l00002oj6ij@03o`000?nU_^_oYKk[00?oYKk[00?o
0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`000_ooool00ol0003oooooooooo`09
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Oooooo
00?oMgMgoc8b<_ooool01?ooool2o`0001gooooo0ol000001?oooooo0000ojO0jonW`>/3o`0000Co
Yl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`03o`000?nW`>_o0000
00;oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0
j`?o000000?o13Rjo`000?lE@[l00_l000001Ol^D/Go0000o`000?m7HL[o000000;oH77=00Go0000
ogQoc_mhOlkoN7o>o`000003ohf=cP03o`000?nOV<coWiS<00;oWiS<00Ko0000ojjQb_n^XL[o0000
ok6SbOl00006okf[a`03o`000?o:/l?ob[?300?ob[?30_l00003om>i`007o`000?oF^kooe[^oomJk
_ol0003ofkjmo`000003omg0_005o`000?oN`K_og/6komk1^ol000000_oSa;T00ol0003oi<FhonC5
^002onC5^004o`000?oUa[SoiLJho`0000;oi/Ng00Go0000onK7]ooVakOoi/Ngo`000003onK8^004
o`000?oTa[Woi<Jio`0000?oi<Jj00Go0000on;6^ol0003ogl:ko`000003omg1_@05o`000?oK`;ko
0000omJj__l000001?oC^L000ol0003obK31olV``@03olV``@03o`000?noYl7o_jO100;o_jO100?o
0000okVQ`?l000000onfW/001_l0003o/9W0ok2I`?n`VL3o0000oj^D_`;o000000?oZ9:oo`000?nT
Skl00onTSkl00ol0003oX8booj2<_`02oj2<_`05o`000?nLR/3oW8[0oib:`?l000001?nHRL800ol0
003oU8S4o`00000<o`0000;oTXk<00Go0000oi:Bd?nBT]3oTY;@o`000004oi:GeP05o`000?nCWM_o
TigKoi>Mfol000000_nDY>000ol0003oU:CPo`000003oiN[i@Co00000_nO/nH00ol0003oXKWYoj6i
j@02oj6ij@03o`000?nU_^_oYKk[00?o00003oooool00ol0003oooooooooo`07ooooo`000_ooool0
0ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01Wo
oooo0ol00005ooooo`;o00000onW`>/00ol0003oYl3[ojO0j`04o`0000CoYl3[00?o0000ojO0jonW
`>/00ol00004ojO0j`06o`000?nW`>_o0000o`000?nW`>_o00001?nW`>/3o`0000?oYl3[00?o0000
ojO0jonW`>/00_nW`>/02_l0003o76cNo`000?l4>;[o0000oaE2_ol0003o;U;5o`000?m7H/X2o`00
00?oH77=00Co0000ogQoc_mhOlko00001?n=SLh01ol0003oWiS<oinHc?nOV<co0000ojjQb_l00000
0onaXlT00ol0003o_J_7okf[a`02okf[a`;o00001?o:/l<01?l0003ocKG2olfe`_l00002om>i`003
o`000?oF^kooe[^o00;oe[^o00Go0000omg0_?oM`;cogL2lo`000004omk1^`;o000000?ohlBio`00
0?oTaKP00_oTaKP01?l0003oiLJhonG6^?oUa[P2o`000003onK7]ol0003oi/Ng00;oi/Ng00Co0000
onK8^?oVb;Soi/Rh0_l000000ooTa[Wo0000onC6^P02onC6^P04o`000?oRa[_oh/Jko`0000?ogL6m
00Go0000om_0__oK`;kofl2no`000004om>i`0;o00001?o9/<42o`0000Co_jO10_l00004okJN`004
o`000?n`VL3o/9W0ok2I`0;o00001?nXT[l01Ol0003oY8noojB?_onTSkoo000000CoX8bo00?o0000
oib:`?nLR/002?l00002oiR9`P05o`000?nFR/GoUX[5oiJ:aOl000001?nDS<P00ol0003oTXk<oi:>
c002oi:>c005o`000?nBT]3oTY;@oi:Bd?l000000onBUmH00ol0003oTigKoi>Mf`02oi>Mf`03o`00
0?nDY>3oU:CP00Go00000_nM[N800ol0003oWk?VoinciP02oinciP03o`000?nQ^NWoXKWY00Co0000
0onV_^/00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo0002ooooo`03oa0@4?oo
oooooooo00Wooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo0ol0000:ooooo`03
o`000?nW`>_oYl3[00?o00001?nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW
`>/01?l00003ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/00ol0
003oYl3[ojO0j`06o`0000;o5D:o00?o0000obiBaOl000000_m7H/X4o`0000?oN7o>00Go0000ohf=
c_n=SLkoSHg>o`000002oinHc0?o00001OnaXlT01?l0003o_J_7okf[aol00002ol6]aP04o`000?o:
/l?ob[?3o`0000?ocKG200?o0000om>i`?l000001OoF^kl01?l0003ogL2lomg0_?l00004omk1^`04
o`000?oP`[[oh<:jo`0000?oi<Fh00Go0000onG6^?oUa[SoiLJho`000002onK7^005o`000?oVakOo
i/NgonK7]ol000000ooVb;P01?l0003oi/RionK8^Ol00003onC6^P05o`000?oRa[_oh/Jkon;6^ol0
00000ooM`Kd01Ol0003ofl2nom_0__oK`;ko000000?odkW000Co0000olng`_o?]l;o00000_o9/<40
1?l0003oaJg2olF]`_l00002oknW`@03o`000?nkY<;o000000Co]Yk000Ko0000ok2I`?l0003o0000
ojfG_ol00004ojRB_`05o`000?nTSkooY8noojB?_ol000001?nPS;l3o`0000;oWHZo00Go0000oiZ9
`?nJRL3oVXW0o`000004oiR9`P05o`000?nFR/GoUX[5oiJ:aOl000001?nDS<P01Ol0003oTXk<oi:>
c?nBS/co000000?oTY;@00?o0000oi:Ge_nBUmH00_nBUmH00ol0003oTigKoi>Mf`05o`000003oibV
gOl0003oWJgR00CoWJgR00?o0000oinci_nO/nH01?l00003ojFkj@03o`000?nV_^_oY[k[00?o0000
3Oooool00ol0003oooooooooo`07ooooo`0000?ooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool05?ooool2o`0000kooooo0_l00003ojO0j`03o`000?nW`>_oYl3[00Co
00000onW`>/00ol0003oYl3[ojO0j`04o`0000CoYl3[00?o0000ojO0jonW`>/00ol00004ojO0j`03
o`000?nW`>_oYl3[00Co00000_nA^O801?l0003o76cNo`000?l00002oaE2_`?o00000_m7H/X00ol0
003oHW;=of9bc@05o`0000;oSHg>1?l00002oj>Jc003o`000?naXlWo/J?900?o/J?900?o0000okf[
aol000000oo1[LH00ol0003ob[?3o`000005olfe`P03o`000?oF^kooe[^o00?oe[^o00Go0000omRm
__l0003ogL2lo`000004omk1^`04o`000?oP`[[oh<:jo`0000?oi<Fh00Go0000onG6^?oUa[SoiLJh
o`000002onK7^005o`000?oVakOoi/NgonK7]ol000000ooVb;P01?l0003oi/RionK8^Ol00002onC6
^P09o`000?oRa[_oh/Jkon;6^ol0003ohLJmo`000?oM`Kgo000000?ofl2n00Go0000omRo`Ol0003o
dkW0o`000003olng`P03o`000?o9/<7o000000?oaJg200?o0000oknW`Ol000000onkY<801?l0003o
]Yk0okJN`?nfW/02o`0000Co[INo00Go0000ojRB_onXT[ooZ9:oo`000004ojB?_`Co000000?oX8bn
o`000?nMR[l00onMR[l01Ol0003oVXW0oiZ9`?nJRL3o000000?oV8W200Go0000oiJ:aOnFR/GoUX[5
o`000004oiB<b005o`000?nBS/coTXk<oi:>c?l000000_nBT]09o`0000;oVZ3H00Ko0000oibVgOnL
Y]go0000oibVgOl00002oif]hPGo00000_nT]nH00ol0003oYK_YojFkj@02ojFkj@?o00000onW`>/0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00000ol0003o<S8bonk^kP0;oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l0
0005ooooo`03o`000?oooooooooo01;ooooo0ol0000@ooooo`03o`000?nW`>_oYl3[00;oYl3[0ol0
0003ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00001?nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[
00?o0000ojO0jonW`>/01?l00003ojO0j`04o`000?nA^O;oTKWboi6ilP;o000000Co03Fio`000?l0
003o5D:o0_l00003odMRbP04o`000?mRL/goHW;=o`0000;oNh;?0ol00002oi6?cP03o`000?nSV/co
Xi[<00;oXi[<00?o0000ok6SbOnaXlT00_naXlT2o`0000Go`Jg600?o0000olfe`_o=]L801?o=]L80
0ol0003oe[^oomJk_`02omJk_`05o`000?oH_Kkof;fnomRm__l000001?oN`K/02?l0003oh<:jon32
^_l0003oh/Bjo`000?oTaKSo00000ooUa[P02?l0003oi/NhonK7^?l0003oi/Rho`000?oVakOo0000
0ooVb;P02?l0003oi/RionK8^Ol0003oi/Vjo`000?oTa[[o00000_oRa[/01Ol0003ohLJmon76_OoQ
a[go000000?ofl2n00Go0000omRo`OoH_l7of;o1o`000005olng`P03o`000?o5[L;oaJg200?oaJg2
00?o0000ok^T`_nkY<800_nkY<801_l0003o]Yk0okJN`?l0003o/Y_1o`0000Co[INo00?o0000ojRB
_onXT[l00_nXT[l00ol0003oY8noo`000002o`0000GoX8bn00Go0000oif:_onMR[ooWHZoo`000003
oiZ9`005o`000?nHRL;oV8W2oiR9`_l000000onFR/D01?l0003oU8c8oiB<b?nDS<P8o`0000;oVIG>
00Go0000oiVJdonIV]?oVI[Co`000005oiZPf003o`000?nLY]goW:KM00Co00000_nS/^<00ol0003o
Y;OVojBgiP03ojBgiPCo000000?oYl3[o`000?nW`>/00onW`>/2o`0000_ooooo00?o0000oooooooo
ool01oooool002Sooooo0_l0000@ooooo`?o00005?ooool01?l0003oYl3[o`000?l00002ojO0j`03
o`000?nW`>_oYl3[00;oYl3[00?o0000ojO0jol000000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`?o
00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l000001_nA^O;o
0000o`000?l0=KWo0000oa91_P;o000000Go;E75o`000?l0003oAf;:o`000003of9bc@04o`000?mk
P/ooNh;?o`0000CoTHo>00Go0000oj>Jc?nSV/coXi[<o`000002ok6Sb@;o000000?o]JK9o`000?o1
[LH00oo1[LH2o`0000GocKG200?o0000om2g`_l000000_oF^kl00ol0003of;fnomRm_P02omRm_P;o
00000_oN`K/01Ol0003oh<:jon32^_oP`[[o000000;oh/Bj00?o0000onG6^?oUa[P00_oUa[P01?l0
003oi/NhonK7^?l00002onK8^0;o00000_oVb;P01Ol0003oi/RionK8^OoVb;Wo000000;oi/Vj00Go
0000on;6^ooRa[_oh/Jko`000003on76_@;o000000?ofl2no`000?oH_l400ooH_l400ol0003ockO2
olng`P02olng`P;o00001?o5[L82o`0000Co^jC200?o0000okJN`?l000000onbVl401Ol0003o[INo
ojfG_on]Ukoo000000?oZ9:o0ol00002oj>>_P03o`000?nPS;koX8bn00?oX8bn00Go0000oif:_onM
R[ooWHZoo`000003oiZ9`003o`000?nHRL;oV8W200;oV8W200?o0000oiJ:aOl000001?l00002oiV>
aP05o`000?nITL[oVI7:oiVAb_l000001?nIULh01Ol0003oVI[CoiVJdonIV]?o000000?oVZ3H1?l0
00000onR[Moo0000o`000004oj>bh`03o`000?nT]nKoY;OV00?o00001OnW`>/4o`000003ojO0jol0
003ooooo00_ooooo00?o0000ooooooooool01_ooool002Sooooo00?o0000ooooooooool03?ooool3
o`0001Sooooo0_l00004ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/01_l0003oYl3[o`000?l0
003oYl3[o`0000CoYl3[0ol00003ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00000onW`>/3o`000009
o`0]]?l0003o0000o`000?lB@Kko0000obeAaOl0003oB6?;00;o00000omRL/d01Ol0003oNh;?og^2
comkP/oo000000?oTHo>00Oo0000oj>Jc?nSV/coXi[<o`000?naXlWo000000Co]JK900Co0000ol6]
a_o1[LKo00000_o4[lD01Ol0003ocKG2olfe`_o=]L;o000000;od;O200?o0000omJk_ol000001?oH
_Kh01_l0003ofkjmom^n_Ol0003og/6ko`0000;oh<:j00Co0000on;4^_oRa;[oh/Bj0_l00002onG6
^004o`000?oVakSoi/Nho`0000?oi/Rh00Go0000onO9^Ol0003oi/Rho`000002onK8^@04o`000?oV
bK[oi/VjonK9^P;o000000?oh/Jko`000?oQa[d00_oQa[d01?l0003oglJoomo6_ol00004omRo`@03
o`000?oE_/?o000000;ockO200Co0000olbda?o<]<Co00000_o5[L801?l0003o`J_3ol6[`ol00003
ok^T`P;o00001?nbVl400ol0003o[INoojfG_`02ojfG_`?o000000?oYi6no`000?nSS[h00onSS[h0
0ol0003oX8bnoj2<_P02oj2<_P03o`000?nMR[ooWHZo00;oWHZo00?o0000oiZ9`?l000001ol00002
oiZ<``03o`000?nIS/KoVHk600?oVHk600Go0000oiVAb_nITL[oVI7:o`000003oiVEcP03o`000?nI
V]?oVI[C00Go00000_nQZ=/01_l0003oXZgOoj:]gol0003oXZgOo`0000;oXk;S1?l00003ojO0j`03
o`000?nW`>_oYl3[00?o00001OnW`>/00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Ko
oooo000Xooooo`03o`000?oooooooooo00Wooooo0ol0000Mooooo`03o`000?nW`>_oYl3[00Co0000
0onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003o
Yl3[ojO0j`02ojO0j`03o`000?nW`>_o000000;oYl3[00?o0000ojO0jonW`>/00_nW`>/01Ol0003o
3FGJo`000?l0003o03>h00;o000000Co4T6no`000?l0003o00000_m8Hl/4o`0000?oNh;?00Go0000
oi6?c_nASlkoTHo>o`000002oj>Jc0?o00001OneY/T00ol0003o`Jg6o`000004olB_a@03o`000?o=
]L;o000000Cod;O200?o0000omRm__oH_Kh00_oH_Kh00ol0003ofkjmom^n_@02om^n_@05o`000?oP
`[[oh<:jon32^_l000000_oRa;X01_l0003ohlJjon?6^_l0003oiLJho`0000;oi/Nh00Co0000onK8
^?oVb;So00000ooWbKT01?l0003oi/RionK8^Ol00003onK9^P04o`000?oUb[coiLZlo`0000?ohLJm
00Go0000omo6_ooOa[ooglJoo`000003omRo`@06o`000?oE_/?oeKk3o`000?o?]l;o00000oo<]<@0
0ol0003oaJg2o`000003ol6[``06o`000?nkY<;o^jC2o`000?ngXL;o00001?nbVl401?l0003o[INo
ojfG_on]Ukl2o`0000CoYi6n00Go0000oj>>__nSS[koXhjno`000005oj2<_P03o`000?nMR[oo0000
00?o00000_nMR[l01Ol0003oVh_1oi^;`OnKRl7o000000CoVXc300?o0000oiV>a_nIS/H00_nIS/H0
1Ol0003oVI7:oiVAb_nITL[o000000;oVIG>1?l00002oj6Se`03o`000?nQZ=_oXJSK00?oXJSK00?o
0000oj:]gonR[Ml01?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0
j`03o`0000_ooooo00?o0000ooooooooool01_ooool002Sooooo00?o0000ooooooooool01_ooool3
o`00027ooooo0_l00003ojO0j`03o`000?nW`>_oYl3[00Co00001?nW`>/00ol0003oYl3[ojO0j`03
o`0000CoYl3[00?o0000ojO0jonW`>/00ol00004ojO0j`03o`000?nW`>_oYl3[00Co000000Oo02fd
o`000?l0<kSo0000oa91__l0003o:e7600;o000000CoB6?;o`000?mTM<koI7C>1Ol00002oi6?cPCo
00000_nWWL`00ol0003o]JK9okFVb@03okFVb@;o00001Oo4[lD2o`0000God;O20_l00003omRm_P03
o`000?oK_[gofkjm00;ofkjm00Co0000on32^_oP`[[o00000ooRa;X01Ol0003ohlJjon?6^_oSa[[o
000000;oi/Nh00Go0000onK8^?oVb;Soi/Rho`000003onO9^@;o000000?oi/Rio`000?oVbKX00_oV
bKX01?l0003oiLZlonG:_?l00003on76_@08o`000?oOa[ooglJoo`000?oMa/;o0000omRo`Ol00004
omFn``03o`000?o<]<Coc;C400?oc;C400?o0000ol6[`oo1Zl<00_o1Zl<00ol0003o^jC2o`000003
okNQ`P03o`000?nbVl7o/Y_100;o/Y_10ol000000onZU;oo0000ojNA_P03ojNA_P03o`000?nSS[ko
Xhjn00;oXhjn00Co0000oj2<__nPS;koX8bn0ol00002oij:_P03o`000?nMR[ooWHZo00;oWHZo00Go
0000oi^;`OnKRl7oVh_1o`000003oiZ<``03o`000?nIS/KoVHk600;oVHk600?o0000oiVAb_nITLX0
1?l00002oj2NdP03o`000?nQXmOoXJ?G00;oXJ?G00Co0000oj6XfonQZ=_oXJSK1?l000000onW`>_o
0000o`000004ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`06ooooo`00:?ooool00ol0003oooooooooo`03ooooo`?o0000
9_ooool00ol0003oYl3[ojO0j`03o`0000CoYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`00
0?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04o`0000;oU[[a00Co0000o`eUf_l0003o
00000_l0<kP01Ol0003o4T6no`000?l[DLKo000000;oB6?;00Co0000ofAdc_mTM<ko00000_mnQ<l3
o`0000;oU9;>00?o0000ojNMc?nWWL`00_nWWL`01ol0003o]JK9okFVbOneY/Wo0000okVYbOl00000
1?o4[lD00ol0003oak;5o`000004om2g`P06o`000?oB^L7od[W1o`000?oH_Kko00001?oK_[d01Ol0
003ogL6mo`000?oP`[[o000000;oh/Bj00?o0000on?6^_oSa[X00_oSa[X2o`000005onK7^?l0003o
i/RhonK8^?l000000ooWbKT01?l0003oil^jonO;^_l00003onK9^P08o`000?oUb[coiLZlo`000?oT
bkko0000on76_Ol00002omo6_`05o`000?oMa/;ogLK2omg6`_l000001OoE_/<2o`0000?oc;C40_l0
0004ol6[``;o00001?ngXL801?l0003o/Y_1ok:K`OnbVl42o`0000CoZYBo00?o0000ojNA__nWTKh0
0_nWTKh01_l0003oXhjnoj>>__nSS[ko0000oj2<_P;o000000?oX8^mo`000?nNR[h00onNR[h01Ol0
003oWHZooif:_onMR[oo000000?oVh_100Go0000oiZ<`onJS<?oVXc3o`000003oiV>aPCo00000_nP
V/h00ol0003oX9kBoj2NdP02oj2NdP06o`000?nQXmOoXJ?Goj6Seol0003oXJSK0_l000000onW`>_o
0000ojO0j`02ojO0j`03o`000?nW`>_o000000?o000000?oYl3[o`000?nW`>/00onW`>/3o`0000?o
Yl3[00?o0000ojO0jonW`>/00ol00009ooooo`03o`000?oooooooooo00Kooooo000Wooooo`;o0000
0_ooool3o`0002[ooooo0_l00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[
ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00004ojO0j`03o`000?nF^_7oU[[a00?o0000
0_l0<kP00ol0003o4T6no`000002ob]AaP;o000000GoB6?;o`000?mTM<koI7C>o`000002ogj4c`03
o`000?nDT/koU9;>00;oU9;>00?o0000ojNMc?nWWL`00_nWWL`00ol0003o]JK9o`000003okVYb@04
o`000?o4[lGoa:o5o`0000?oak;500Co0000om2g`_o@]l;o00001?oB^L400ol0003ofkjmom^n_@02
om^n_@05o`000?oM`KgogL6momg1_Ol000000_oRa;X00ol0003ohlJjon?6^P02on?6^P04o`000?oU
ak[oiLNjo`0000;oi/Rh00?o0000onO9^OoWbKT00_oWbKT01?l0003oil^jonO;^_l00002onK9^P05
o`000?oUb[coiLZlonG:_?l000000_oTbkh01Ol0003oglJoomo6_ooOa[oo000000?ogLK20_l00003
omFn``06o`000?oA_<KodKc6o`000?o<]<Co00000_o7//H01_l0003o`J_3ol6[`ol0003o_:S5o`00
00Co]j7200Ko0000ok:K`Ol0003o0000ojjI`Ol00004ojZD_`03o`000?nWTKkoYi6n00;oYi6n00?o
0000oj>>__nSS[h00ol00004oj2;_@05o`000?nNR[koWXZnoij:__l000000onMR[l01Ol0003oVh_1
oi^;`OnKRl7o000000;oVXc31Ol00002oinGb`03o`000?nPV/koX9[>00;oX9[>00Go0000oj2Nd_nP
W];oX9kBo`000002oj6Se`?o00001?nW`>/00ol0003oYl3[ojO0j`03o`0000GoYl3[1?l000000onW
`>_o0000ojO0j`03ojO0j`?o00000onW`>/00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo000Wooooo`Co0000;Oooool00ol0003oYl3[ojO0j`02ojO0j`?o00000onW`>/01?l0003o
Yl3[ojO0jonW`>/3o`0000CoYl3[00?o0000ojO0jonW`>/00ol00004ojO0j`03o`000?nW`>_oYl3[
00Ko000000Co02Zco`000?l0003o03>h0_l00002ob]AaP04o`000?m8I<co0000o`0000;oI7C>00Go
0000ogj4comnQ<ooOXC?o`000004oiBBcP04o`000?nWWLcoYig<ojNMc0;o00001?niZLT00ol0003o
a:o5o`000004olNba@03o`000?o@]l;o000000God[W100Go0000om^n_OoK_[gofkjmo`000004omg1
_@;o000000?oh/Bjo`000?oSa[X00ooSa[X00ol0003oiLNjonG7^P02o`000003onK8^?l0003oilVi
00;oilVi00So0000onO;^_oWbk[o0000onO=^ol0003oi/Vjo`0000;oiLZl00Co0000onC;__oTbkko
i<^n0_l000000ooOa[oo0000omg6`P02omg6`P06o`000?oJaLGof/G5o`000?oE_/?o00001?oA_<H0
1ol0003oak;6olNba_o7//Ko0000ol6[`ol000000onlZ<D01?l0003o]j72okNQ`_ngXL82o`0000Co
[YW100Go0000ojZD_onZU;ooZYBoo`000003ojNA_PCo00000_nRSKd00ol0003oX8^moj2;_@02oj2;
_@05o`000?nNR[koWXZnoij:__l000001?nMR[l00ol0003oVh_1o`000003o`0000;oX9C800?o0000
oinGbonOUl/00onOUl/01Ol0003oX9[>oj2Jc_nPV/ko000000;oX9kB1?l00003ojO0j`03o`000?nW
`>_oYl3[00Co00000_nW`>/2o`0000;oYl3[0ol00005ojO0j`Co000000?oYl3[o`000?nW`>/00onW
`>/2o`0000Oooooo00?o0000ooooooooool01_ooool002Oooooo0_l0000`ooooo`04o`000?nW`>_o
0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/00ol0003oYl3[o`000002ojO0j`03o`000?nW
`>_oYl3[00;oYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/2o`000004o`0W/Ol0
003o0000o`0b]`Co00000_l[DLH00ol0003oB6C<odQTc003o`0000?oOXC?00?o0000oiBBc_nDT/h0
0_nDT/h01_l0003oYig<o`000?l0003oZj3<o`0000Go^JW900?o0000olNbaOo7//D01?o7//D00ol0
003od[W1om:i`@03om:i`@05o`000?oE_<7o0000om^n_Ol000001?oM`Kd01?l0003ogl>momo3_Ol0
0004on?6^P04o`000?oUak[oiLNjo`0000;oi/Vj0_l00002onO9^@05o`000?oWbk[oil^jonO;^_l0
00000_oWcK/01?l0003oiLZlonG:_?l00003onC;_P04o`000?oSc<3ohlc0o`0000CogLK200Go0000
om[5aOoJaLGof/G5o`000004om6laP;o00001?o7//H00ol0003o_:S5okbXa@02okbXa@06o`000?ng
XL;o0000o`000?nbW/Co00001?n^VL401?l0003oZYBoojZD_onZU;l4o`0000;oYHnn00?o0000oj:=
_OnRSKd00_nRSKd01Ol0003oX8^moj2;_OnPRkgo000000CoWXZn00?o0000oif:_ol000000ol00002
oj2CaP03o`000?nPU<SoX9C800;oX9C800?o0000oinGbonOUl/00_nOUl/01?l0003oX9[>oj2Jc_nP
V/h3o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW
`>/00ol0003oYl3[ojO0j`03o`0000GoYl3[1?l000000onW`>_o0000ooooo`07ooooo`03o`000?oo
oooooooo00Gooooo000Yooooo`03o`000?oooooooooo02kooooo0_l00004ojO0j`03o`000?nW`>_o
Yl3[00?o00001?nW`>/01_l0003oYl3[o`000?l0003oYl3[o`0000CoYl3[0ol00003ojO0j`03o`00
0?nW`>_oYl3[00Go000000Go02Rbo`000?l0<[Oo0000o`m1_`02o`000006ob]Aa_l0003oB6C<odQT
c?l0003oIWO@0_l00002ogj4c`04o`000?nDT/koU9;>oiBBcP?o00001?n[X<`01?l0003o^JW9okVY
bOniZLT2o`0000Koak;500?o0000om:i`OoB^L400_oB^L401Ol0003oeKc1omFl`OoE_<7o000000Co
gL6m00Co0000omo3_OoO`kgogl>m0_l00002on?6^P05o`000?oUak[oiLNjonG7^_l000000_oVbKX0
1Ol0003oilbko`000?oWbKWo000000;oil^j00Co0000onO=^ooWcK_oilfk0_l000001OoUb[co0000
onC;__oTbkko000000?ohlc00_l00002omg6`P03o`000?oJaLGof/G500;of/G500Go0000om6la_oA
_<KodKc6o`000002olfkb@03o`000?o7//Koak;600;o00001OnlZ<D00ol0003o/Yk4ok:Na002ok:N
a006o`000?n^VL7o[YW1ojjI`Ol0003oZYBo0_l000000onWT[oo0000ojF?_P04ojF?_P05o`000?nR
SKgoXXfmoj:=_Ol000001?nPRkd00ol0003oWXZno`000003o`0000;oXI;500?o0000oj2Ca_nPTlH0
0_nPTlH01Ol0003oX9C8oj2Db?nPU<So000000CoWiO;00Ko0000oj2Jc_l0003o0000ojO0jol00004
ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`04o`000004ojO0jol0003oYl3[o`0000;oYl3[1?l0
0003ojO0j`03o`000?nW`>_oYl3[00?o00001OnW`>/00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo000Zooooo`03o`000?oooooooooo02oooooo00?o0000ojO0jonW`>/01?l00003
ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/01_l0003oYl3[o`000?l0003oYl3[o`0000CoYl3[
0ol00002oj:nk@;o000000Go02F`o`000?l0:;;o0000o`0b]`02o`000003obYBaol0003o000000?o
B6C<00?o0000ofIgd?l000001_l00002oiREc`03o`000?n[X<coZj3<00;oZj3<00Co0000okVYbOni
ZLWo00000_nm[<T00ol0003oak;5olNba@02olNba@03o`000?o;]LGo000000?od[W100Co0000omFl
`OoE_<7oeKc10_l00003omg1_@04o`000?oO`kgogl>mo`0000;ohLFm00?o0000on?6^_l000000_oU
akX01?l0003oi/VjonK9^_l00003onO<^`04o`000?oWbk[oil^jo`0000?oilfk00Co0000onO>_OoW
c[go00000ooTbkh01?l0003ohlc0on?<`?l00002on7=a003o`000?oMa/;o000000?of/G500Go0000
omO5b?l0003odKc6o`000003olfkb@03o`000?o7//Ko000000;o`[3800Co0000okbXaOnlZ<Go_:S5
0_l00004ok:Na004o`000?n^VL7o[YW1ojjI`@;o00001?nWT[l00ol0003oYHnnojF?_P02ojF?_P05
o`000?nRSKgoXXfmoj:=_Ol000000onPRkd3o`0000;oXI7400?o0000oj6BaOnQT/D00_nQT/D01Ol0
003oX9?6oj2Ca_nPTlKo000000?oX9C800Co0000oinGbonOUl_oWiO;0ol00004ojO0j`06o`000?nW
`>_o0000o`000?nW`>_o00001?nW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03
o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`03o`0000Oooooo00?o0000oooooooo
ool01Oooool002_ooooo00?o0000ooooooooool0;oooool2o`0000?oYl3[00?o0000ojO0jonW`>/0
1?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/01?l0003oYl3[o`000?l00002ojO0j`04
o`000?nR_^goX[k]oj:nk@;o000000?o02F`o`000?l0:;801?l00002obYBa`;o000000CoB6C<o`00
0?mVMm3o00000on1R=400ol0003oV9G?oiREc`03oiREc`07o`000?n[X<coZj3<oj^Pc?l0003o^JW9
o`000004okf/b@04o`000?o7//Goak;5o`0000?obkG500?o0000om:i`Ol000000ooE_<401_l0003o
f;k1omRn`Ol0003ogL6mo`0000?ogl>m00Go0000on75_OoQaKgohLFmo`000002onG7^P05o`000?oV
bK[oi/VjonK9^_l000000ooWc;/2o`000005onO;^_l0003oilfkonO=^ol000000ooWc[d2o`000005
onC;__l0003ohlc0on?<`?l000001?oQcL@01Ol0003of/G5om[5aOoJaLGo000000?oelG800?o0000
olfkbOo=^lT00_o=^lT2o`0000Co`[3800?o0000okbXaOl000000_ngYLL01_l0003o/Yk4ok:Na?nb
W/Co0000ojjI`@;o000000?oZYK2o`000?nWT[l00onWT[l00ol0003oYHnnojF?_P02ojF?_P03o`00
0?nRSKgoXXfm00;oXXfm0ol000000onRT/?o0000oj6Aa003oj6Aa005o`000?nQT/GoXI;5oj6BaOl0
00000onPTlH00ol0003oX9C8oj2Db005o`0000;oYl3[00Co0000ojO0jonW`>_oYl3[0ol00004ojO0
j`Co000000?oYl3[o`000?nW`>/00onW`>/3o`000003ojO0jol0003o000000?oYl3[1?l00003ojO0
j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo000/ooooo`;o0000<Oooool00ol0003oYl3[ojO0j`03o`0000CoYl3[00?o0000ojO0jonW
`>/00ol00004ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/01ol0003oX[k]oj:nkOl0003o02Zc
o`000?l09K000_l000001ol0<[Oo0000o`000?l0003o:U;7o`000?m9I/h00_l00002ofIgd005o`00
0?n1R=7oPHSAoh68dOl000001?nHULl01?l0003oZj3<oj^Pc?n[X<`2o`0000Go_Jc900?o0000olNb
aOl000001?o;]LD2o`0000?oeKc100?o0000omRn`OoH_/400_oH_/401Ol0003ogl>momo3_OoO`kgo
000000CohLFm0_l000001OoUak[o0000onK9^_oVbK[o000000?oilbk00Co0000onS>_?oXc[co0000
0ooWcK/01?l0003oiljmonO>_Ol00002onO@_`05o`000?oSc<3ohlc0on?<`?l000001?oQcL@2o`00
0003om[5aOl0003oelG800?oelG800Oo0000olfkbOo=^lWocK_9o`000?o7^Lco000000Co`[380_l0
0004okNUa`03o`000?nbW/Co/Yk400;o00001?nZU/800ol0003oYi:oojNB_`02ojNB_`03o`000?nU
SkkoYHnn00;oYHnn00?o0000oj:=_Ol000000_l00004oj:B``05o`000?nQTLCoXI74oj6Aa?l00000
0onQT/D00ol0003oX9?6oj2CaP04o`0000?oYl3[00?o0000ojO0jonW`>/01Ol00002ojO0j`03o`00
0?nW`>_oYl3[00?o00001OnW`>/4o`000003ojO0jol0003oYl3[00;oYl3[1?l00002ojO0j`03o`00
0?nW`>_oYl3[00;oYl3[0ol00002ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00001Oooool00ol0003o
ooooooooo`05ooooo`00;_ooool00ol0003oooooooooo`0_ooooo`;o00000onW`>/00ol0003oYl3[
ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Go0000
0_l0:[<2o`000005o`0X/_l0003o0000o`a0_ol000000_lZD/L00ol0003oBFK>odUVcP02o`000003
ofIgd?l0003oPHSA00;oPHSA00Ko0000oiREconHULooV9G?o`000?n[X<`2o`000003ojjTcOl0003o
_Jc900Co_Jc90_l00004ol^ea@03o`000?o>^<Go000000?oeKc100?o0000omRn`OoH_/400_oH_/40
1?l0003ogl>momo3_Ol00004on75_@04o`000?oSb;gohlRmo`0000;oi/Vj00Go0000onO<^ooWc;_o
ilbko`000003onS>_0;o000000Goilfko`000?oWc[goiljmo`000003onO@_`;o000000?ohlc0o`00
0?oQcL@00ooQcL@01?l0003oglk7omo>aol00004omO5b005o`000?oCaLgo0000olfkbOl000000oo7
^L`01_l0003o`[38ol:`b?l0003o_:g;o`0000Co]jG700Go0000ok:Na?l0003o[I_5o`000004ojZF
`P03o`000?nWT[ooYi:o00;oYi:o00?o0000ojF?__nUSkh01?l00002oj>Ca003o`000?nRT/?oXY;3
00;oXY;300Go0000oj6Aa?nQTLCoXI74o`000002oj6Ba@Co00000onW`>/00ol0003oYl3[ojO0j`04
o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00?o00001OnW`>/5
o`0000GoYl3[1?l000000onW`>_o0000ojO0j`02ojO0j`Co00000_nW`>/00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Gooooo000_ooooo`03o`000?oooooooooo02kooooo00?o0000ojO0
jonW`>/00_nW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[
00Co00000onW`>/00ol0003o>8k_o`000002o`000004o`0U/?l0003o0000o`0000;o342o0_l00000
1OlZD/Oo0000odUVc_l0003oJ7[B00;o00000on1R=400ol0003oV9G?oiREc`03o`0000Co[ZC=00Oo
0000okf/bOnm[<Wo_Jc9o`000?o0/<Wo000000?obkG500Oo0000oljhaOo>^<Goc[S5o`000?oE_<7o
000000Cof;k100Go0000om_2`Ol0003ogl>mo`000003on75_@04o`000?oSb;gohlRmon?8_@;o0000
00Goi/Vjo`000?oWc;_oilbko`000003onS>_004o`000?oXd;koj=2no`0000?oiljm00Co0000onO@
_ooWd;oo00000_oVd/<2o`0000?ohLg400Go0000omo>aooOc/Ooglk7o`000003omO5b005o`000?oC
aLgodlG=om?5cOl000001?o7^L`00ol0003o`[38o`000003okb]b`04o`000?ngYLOo]jG7okNUa`;o
00000on]VlD00ol0003oZYK2ojZF`P02ojZF`P04o`000?nWT[ooYi:oojNB_`?o00000_nTU<D00ol0
003oXi?4oj>Ca002oj>Ca005o`000?nRT/?oXY;3oj:B`ol000000onQTL@3o`0000;oYl3[00?o0000
ojO0jonW`>/00_nW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_o
Yl3[00Co00000onW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[0_l00002ojO0j`?o00001OnW`>/3
o`000003ojO0jol0003oYl3[00?oYl3[0_l00004ooooo`03o`000?oooooooooo00Gooooo000`oooo
o`03o`000?oooooooooo02kooooo00Co0000ojO0jol0003o00000_nW`>/01?l0003oYl3[ojO0jonW
`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co000000?o
02Vco`000?l000000_l000001Ol0<KOo0000o`000?l0003o:5?800;o00000_m9I/h00ol0003oJ7[B
ofQjdP06o`0000;oW9WA00?o0000ojjTcOn^Y<d00on^Y<d00ol0003o_Jc9o`000003ol2`b@03o`00
0?o;]LGo000000Goc[S500?o0000omRn`OoH_/400_oH_/401Ol0003ofl;1om_2`OoK`/7o000000?o
hLFm00Go0000on?8_OoSb;gohlRmo`000002onC;_P05o`000?oWc;_oilbkonO<^ol000000ooXc[`0
0ol0003oj=2nonS@_P02o`000005onO>_Ol0003oim2oonO@_ol000000ooVd/<01Ol0003oiMG6o`00
0?oQcLCo000000?oglk700Go0000omc?c?l0003oelG8o`000003om?5c@;o00001?o7^L`2o`0000Co
_:g;00Ko0000okNUaol0003o0000ok6RbOl00004ojfKa@06o`000?nZU/;oZYK2ojZF`_l0003oYi:o
0_l000000onVUlKo0000ojBDa@03ojBDa@05o`000?nSTlCoXi?4oj>Ca?l000001?nRT/<3o`000003
ojO0jol0003oYl3[00?oYl3[00Ko0000ojO0jol0003o0000ojO0jol00004ojO0j`?o00000onW`>/0
0ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_o
Yl3[00Co00000onW`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[00Ko0000ojO0jol0003o0000ojO0
jol00005ooooo`03o`000?oooooooooo00Cooooo000aooooo`03o`000?oooooooooo02kooooo0_l0
0004ojO0j`03o`000?nW`>_o000000;oYl3[00Co0000ojO0jonW`>_oYl3[0ol00004ojO0j`03o`00
0?nW`>_oYl3[00?o00000_nW`>/01?l0003o0474o`000?l0:K<2o`000004o`0W/Ol0003o0000o`M0
`0;o00000_lXDlP3o`0000;oJ7[B00Go0000ohB<don4S=?oQ8cCo`000004oibId@03o`000?n^Y<go
[ZC=00;o[ZC=0_l00005ol2`b@03o`000?o>^<Goc[S500Coc[S500Go0000omRn`OoH_/7of;k1o`00
0004om_2`@05o`000?oQaKgohLFmon75_Ol000000ooSb;d00ol0003oi<^nonC;_P02o`000003onO<
^ol0003oj<jl00;oj<jl00Co0000onS@__oXd;ko00000_oYdl001Ol0003oim2oonO@_ooWd;oo0000
00;oi];300Go0000onGEa_oUeLKoiMG6o`000003omo>a`05o`000?oLclcog<o<omc?c?l000000ooC
aLd01?l0003ocLCAolg4dOl00002olNic003o`000?o1]m3o000000Co_:g;0_l00004ok6Rb@05o`00
0?n]VlGo[I_5ojfKaOl000000_nZU/83o`0000CoYYO600Go0000ojBDaOnTU<GoY9C5o`000003oj>C
a003o`000?nRT/?oXY;300?o00001?nW`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[00Ko0000ojO0
jol0003o0000ojO0jol00004ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o
0000ojO0jonW`>/01?l000001?nW`>_o0000ojO0jol00002ojO0j`Co00000onW`>/00ol0003oYl3[
ojO0j`03o`0000CoYl3[00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`00<_oo
ool2o`00033ooooo00?o0000ojO0jonW`>/00ol00004ojO0j`03o`000?nW`>_o000000;oYl3[00?o
0000ojO0jonW`>/00_nW`>/3o`0000;oYl3[00So0000ojO0jonW`>_oYl3[o`000?l0@LCo0000o`0Y
/`Go000000Oo1d30o`000?lXDlSo:5?8o`000?m9JM3o000000?oJ7[B00Go0000ohB<don4S=?oQ8cC
o`000003oibId@03o`000?n^Y<go000000;o000000?o/ZS>o`000?o0/<T00oo0/<T2o`0000Goc[S5
00Go0000om6laOl0003of;k1o`000004om_2`@05o`000?oMaL7o0000on75_Ol000000ooSb;d01?l0
003oi<^nonC;__l00002onK>_`;o00000_oXc[`01Ol0003oj=2nonS@__oXd;ko000000;ojM?00_l0
00001OoWd;oo0000onKB`ooVd/?o000000CoiMG60_l000000ooOc/Oo0000omc?c002omc?c005o`00
0?oHd=7o0000om?5cOl000000oo=a=400ol0003oakW<o`000003ol6gd006o`000?nl[L_o0000o`00
0?neZ/ko00001?naX/T01?l0003o[I_5ojfKaOn]VlD3o`0000;oZ9_800?o0000ojJGa_nVUlH00_nV
UlH01Ol0003oY9C5ojBDaOnTU<Go000000;oXi?41?l00003ojO0j`03o`000?nW`>_oYl3[00Co0000
0onW`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[00Ko0000ojO0jol0003o0000ojO0jol00004ojO0
j`?o00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0
j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`03o`0000?ooooo00?o0000oooo
ooooool01?ooool003Cooooo00?o0000ooooooooool0;_ooool2o`0000?oYl3[00?o0000ojO0jonW
`>/00ol00004ojO0j`06o`000?nW`>_o0000o`000?nW`>_o00001?nW`>/01_l0003oYl3[ojO0jonW
`>_o0000o`11a0Oo000000Ko1d30o`000?l0003o:5?8o`000?m9JM04o`0000?oQ8cC00?o0000oibI
dOnLVM400ol00005ok:XcP04o`000?o0/<Wo`;39o`0000;oa;?:00Go0000oljhaOo>^<Goc[S5o`00
0003om6la@03o`000?oK`/7ofl;100;ofl;100Co0000omg5`OoMaL7ogLG10_l00002on?8_@05o`00
0?oTbkkoi<^nonC;__l000000_oVc[l01Ol0003oim70o`000?oXc[co000000;oj=2n00Co0000onWC
`?oYdl3o00000_oYe/83o`000003onKB`ol0003oiMG600;oiMG600Co0000on?GbooSel_o00000ooL
cl`01Ol0003of=3AomS@dOoHd=7o000000CocLCA0_l00004ol6gd0;o00001?neZ/h01_l0003o/J;9
ok6RbOnaX/Wo0000ojfKa@;o000000?oZYo<o`000?nXVlP00onXVlP01Ol0003oYYO6ojJGa_nVUlKo
000000;oY9C51?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04
o`0000?oYl3[00?o0000ojO0jonW`>/00ol00004ojO0j`06o`000?nW`>_o0000o`000?nW`>_o0000
1?nW`>/3o`0000;oYl3[00Co0000ojO0jonW`>_oYl3[1?l000000onW`>_o0000o`000003ojO0j`Co
00000_nW`>/01?l0003oYl3[ojO0jonW`>/4o`0000;oYl3[00Go0000ooooooooooooooooo`000006
ooooo`00=Oooool00ol0003oooooooooo`0^ooooo`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0
003oYl3[ojO0j`03o`0000CoYl3[00?o0000ojO0jonW`>/03_l000000ol7@<3o0000obEEb`02o`00
0004odUYd?l0003oJWkDofYne0Oo00000_nPW]800ol0003o/ZS>ok:XcP03ok:XcP03o`000?o0/<Wo
000000Coa;?:00?o0000oljhaOl000001?oA_<D2o`0000?ofl;100Wo0000omg5`OoMaL7ogLG1o`00
0?oOb<;o0000on?8_Ol000000_oTbkh01?l0003oi/joonK>_ol00003onOA`004o`000?oXd;koj=2n
o`0000;ojM?000Go0000onWF`_oYe/;ojMK2o`000002onSJaP05o`000?oUeLKoiMG6onGEa_l00000
0_oSel/01Ol0003oh=[@o`000?oLclco000000?of=3A00Co0000om?Aeol0003ocLCA0_l000000oo6
`mOo0000ol6gd002ol6gd003o`000?ni]=Co000000Co]J[>00?o0000ok6RbOnaX/T00ol00004ojZO
c005o`000?nXVlSoZ9_8ojRKb?l000000onVUlH3o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002
ojO0j`04o`000?nW`>_oYl3[ojO0j`Co00000_nW`>/01?l0003oYl3[ojO0jonW`>/4o`0000;oYl3[
00Co0000ojO0jonW`>_oYl3[0ol00004ojO0j`Co000000?oYl3[o`000?nW`>/00_nW`>/4o`0000;o
Yl3[00?o0000ojO0jonW`>/01Ol00002ojO0j`03o`000?nW`>_oYl3[00Go00000_nW`>/00ol0003o
Yl3[ojO0j`03o`0000;ooooo00?o0000ooooooooool01?ooool003Kooooo00?o0000ooooooooool0
;_ooool2o`0000CoYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00Co0000
0onW`>/00ol0003oKj_fofn[mP05o`000003o`0U/?l0003o032g00?o000000Go9EG;o`000?m9JM3o
BFW@o`000002ofYne005o`000?n7T=GoQi3EohN@eOl000001?nPW]800ol0003o/ZS>ok:XcP02ok:X
cP;o00001Oo4/lX2o`0000CodKc500Ko0000omC0a_oD`<Ko0000om_2`Ol00003omg5`@05o`000?oO
b<;oglS2omo8`_l000000_oTbkh01Ol0003oi/joonK>_ooVc[oo000000?oim700_l000001OoXd;ko
0000onWC`?oYdl3o000000;ojMK200Co0000onSJa_oXf/Koj=[60_l000001OoUeLKo0000on?GbooS
el_o000000?oh=[@00Go0000omS@dOoHd=7of=3Ao`000002om?Ae`;o00001?o6`mL00ol0003o`KO@
o`000003okVde004o`000?neZ/ko]J[>okFZcP?o00000_n/YM000ol0003oZYo<ojZOc002ojZOc006
o`000?nXVlSoZ9_8ojRKb?l0003oYYO60_l000000onW`>_o0000ojO0j`03ojO0j`?o00000_nW`>/0
0ol0003oYl3[ojO0j`05o`0000;oYl3[00?o0000ojO0jonW`>/01Ol00002ojO0j`03o`000?nW`>_o
Yl3[00Go00000_nW`>/00ol0003oYl3[ojO0j`03o`0000GoYl3[0ol000000onW`>_o0000ojO0j`03
ojO0j`?o000000CoYl3[o`000?nW`>_o00000_nW`>/4o`0000?oYl3[00?o0000ojO0jonW`>/01?l0
0003ojO0j`03o`000?oooooo000000Kooooo000gooooo`;o0000<?ooool00ol0003oYl3[ojO0j`04
o`0000?oYl3[00?o0000ojO0jonW`>/00ol00004ojO0j`03o`000?nW`>_oYl3[00Ko000000Co02Vc
o`000?l0003o02F`0_l000001?l2@L;o0000o`000?lUEL/2o`000005odUYd?l0003oJWkDofYne?l0
00000on7T=D00ol0003oX9kBoj2NdP02oj2NdP06o`000?nbZ<ko0000o`000?nf[Loo00001?o4/lX0
0ol0003ob;S;o`000003om6la@03o`000?oD`<Koe<3600;oe<3600Go0000omg5`OoMaL7ogLG1o`00
0004omo8`P;o000000Goi<^no`000?oVc[ooi/joo`000003onOA`003o`000?oXeL;oj=G200;o0000
00GojM?0o`000?oYe/;ojMK2o`000003onSJaP03o`000?oWgLWoimg900;o000000?ohmO;o`000?oP
f]000_oPf]001Ol0003og=cFo`000?oHd=7o000000;odm7G00?o0000ol_Ag_l000001?o6`mL2o`00
00Co^KCD00Ko0000okFZc_l0003o0000ojj/eOl00004ojbUd005o`000?nZWlcoZYo<ojZOc?l00000
0_nXVlP3o`0000CoYl3[1?l000000onW`>_o0000ojO0j`02ojO0j`?o00000onW`>/00ol0003oYl3[
ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co0000
0onW`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[00Ko0000ojO0jol0003o0000ojO0jol00003ojO0
j`Co00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00006oooo
o`00>Oooool00ol0003oooooooooo`0^ooooo`;o00000onW`>/00ol0003oYl3[ojO0j`04o`0000?o
Yl3[00?o0000ojO0jonW`>/01?l00003ojO0j`[o000000Go0T72o`000?lUEL_o0000odU]d`02o`00
00?oJWkD00Go0000ohN@eOn7T=GoQi3Eo`000003oj2NdP;o00001?nf[Ll01?l0003oa;?:olBcb_l0
0003olRhb`03o`000?oA_<Go000000Goe<3600Go0000omg5`OoMaL7ogLG1o`000003omo8`P04o`00
0?oRc<?oh/c3o`0000;oi/jo00?o0000onOA`?oWdL000_oWdL001_l0003oj=G2onSE`_l0003ojMW4
o`0000?ojMK200Co0000onSJa_oXf/Ko00000ooWgLT00ol0003oi^7>o`000003on3Jd003o`000?oL
g=Kog=cF00?o000000?odm7Go`000?o;dMh00_o;dMh01_l0003oa/?Go`000?l0003o_/7Lo`0000Co
^KCD0_l00004ojj/e@05o`000?n/YM3o[:G@ojbUd?l000000_nZWl`4o`0000;oYl3[00?o0000ojO0
jonW`>/00ol00005ojO0j`?o000000?oYl3[o`000?nW`>/00onW`>/3o`0000?oYl3[00?o0000ojO0
jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04o`00
00?oYl3[00?o0000ojO0jonW`>/00ol00004ojO0j`03o`000?nW`>_o000000?o00001?nW`>/3o`00
00?oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`03o`000?oooooo000000Gooooo000jooooo`03
o`000?oooooooooo02kooooo00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co
00000onW`>/00ol0003oYl3[ojO0j`05o`000003o`0Z]?l0003o000000?o00000_l2@L800ol0003o
9EG;o`000002odU]d`Co00000on7T=D01_l0003oX9kBo`000?l0003oY:?Do`0000Co]Zg?00?o0000
olBcb_l000001Oo8^</00ol0003oe<36omC0aP03omC0aP05o`000?oGa<Oo0000omg5`Ol000000ooO
b<801?l0003oh/c3on;<`ooRc<<2o`000003onK>_ol0003oim7000;oim7000Co0000onSE`_oXeL;o
00000_oYfL@2o`000003onWF`_l0003oj=[600;oj=[600Co0000onOMbOoWgLWo00000_oVhLh2o`00
0005on3Jd?l0003og=cFomcLe_l000000_oGgmd2o`0000Cobm7N0_l00004okk1g006o`000?ni]=Co
0000o`000?na]=_o00001?n^[=D00ol0003o[:G@ojbUd004o`0000;oYl3[00?o0000ojO0jonW`>/0
1?l00003ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/01_l0003oYl3[o`000?l0003oYl3[o`00
00CoYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04o`00
00?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/2o`00
0005ojO0jol0003o0000ojO0jol000001?nW`>/3o`0000;oYl3[00?o0000ojO0jonW`>/01?l00005
ooooo`00>oooool00ol0003oooooooooo`0^ooooo`;o00001?nW`>/00ol0003oYl3[ojO0j`03o`00
00?oYl3[00?o0000ojO0jonW`>/01?l00002oiJkl@Co000000Go02Zdo`000?l0003o0000o`0_]`05
o`0000;oBFgC00?o0000ofb3f?m/PmP01_l00004ojBSe004o`000?nf[Loo]Zg?okJ]c`;o00001Oo8
^</00ol0003obkg<o`000003omC0aP04o`000?oGa<OoelC7omO4a`;o00000ooOb<801?l0003oh/c3
on;<`ol00002onC@a0;o00000_oWdL001?l0003oj=G2onSE`_l00002onWIa003o`000?oYgLOojMg7
00?o000000Goj=[6o`000?oWgLWoimg9o`000002onKQcP03o`000?oSi]CohnKD00;o000000Gog=cF
o`000?oGgmgoemoMo`000002olkQiP04o`000?o;dMko0000o`0000;o`M3U00?o0000okk1g?nn`M`0
0ol00004ok6df`03o`000?n^[=Go[ZcE00Co00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[
00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/01_l0003oYl3[
o`000?l0003oYl3[o`0000CoYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0
003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`04o`000?nW`>_oYl3[
ojO0j`?o00001?nW`>/4o`000003ojO0jol0003oYl3[00;oYl3[0ol00003ooooo`03o`000?oooooo
oooo00?ooooo000looooo`;o0000;oooool00ol0003oYl3[ojO0j`02ojO0j`?o00000onW`>/00ol0
003oYl3[ojO0j`03o`0000?oYl3[00Co0000oiJklOnF^o7oU[_a0_l000000ol0>koo0000o`0Z]004
o`000004o`11`ol0003o0000o`0000?oBFgC00Co0000ofb3f?m/PmSo00000on;UMP00ol0003oY:?D
ojBSe002ojBSe004o`000?nf[Loo0000o`0000;o^[;A00Go0000olRhboo8^<_ob;S;o`000003ol^m
c003o`000?oD`<Ko000000CoelC700Go0000om[8b?l0003oglS2o`000002on;<``09o`000?oTd<Co
i=34onC@a?l0003oiMG5o`000?oWdL3o000000;oj=G200?o0000onWIa?l000000ooYgLL00ol0003o
jN;:onWRbP02o`000005onOMbOl0003oi^7>onKQc_l000000_oSi]@00ol0003og^[Ko`000002o`00
0003omOOgOl0003oc^7V00;oc^7V0_l00004ol7@i@?o00000onc_n<00ol0003o/KCKok6df`04o`00
00;oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0
003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/00ol00004ojO0j`06o`000?nW`>_o0000
o`000?nW`>_o00001?nW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`04o`000?nW
`>_oYl3[ojO0j`Co00000_nW`>/00ol0003oYl3[ojO0j`05o`000003ojO0jol0003o000000;oYl3[
0ol00005ojO0j`?o00001_ooool00ol0003oooooooooo`03ooooo`00?_ooool00ol0003ooooooooo
o`0]ooooo`06o`000?nW`>_o0000o`000?nW`>_o00001?nW`>/3o`0000?oYl3[00?o0000ojO0jonW
`>/01Ol000000ol6DLko0000o`000004o`000005o`0^]ol0003o0473o`000?lRElh01?l00003ofb3
f005o`000?n;UMSoRiGHoh^Ef?l000000onTXm@2o`0000Go^[;A00?o0000olRhbol000001?o;_L`2
o`0000CoelC700Go0000om[8b?oJb<Sof/S8o`000003on;<``04o`000?oTd<Coi=34o`0000?oiMG5
0_l000001OoXeL;o0000onWIa?oYfLCo000000;ojMg700Ko0000onWRb_oYh/[ojN;:o`000?oXilh2
o`000007onKQc_l0003ohnKDon?Ve?l0003og^[Ko`000002omO^h`?o000000?oc^7Vo`000?l00000
0_o2hNh01_l0003o`M3Uo`000?l0003o]<_/o`0000Co/koS0ol00003ojO0j`03o`000?nW`>_oYl3[
00?o00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0
j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[00Ko0000ojO0
jol0003o0000ojO0jol00004ojO0j`?o00000_nW`>/00ol0003oYl3[ojO0j`05o`0000;oYl3[00?o
0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0
j`03o`0000Sooooo00?o0000ooooooooool00oooool003oooooo00?o0000ooooooooool0;Oooool0
0ol0003oYl3[ojO0j`02ojO0j`06o`000?nW`>_o0000o`000?nW`>_o00001?nW`>/3o`0000?oYl3[
2_l000000ol0;[Oo0000o`11``02o`0000;oB77G1Ol00003oh^Ef006o`000?nTXmCo0000o`000?nX
ZMOo00001Onj/]42o`0000Cobkg<00?o0000olo2c_l000000ooGa<L02Ol0003of/S8om[8b?oJb<So
0000omg=bOl0003oh/c3o`000002onC@a005o`000?oUeLGoiMG5onGEaOl000000_oWf/L2o`000005
onWIa?l0003ojMg7onWMaol000000ooYh/X01Ol0003oj>O>onSWc_l0003oi^cC00;o000000CohnKD
o`000?oNj]_o00000_oGk^<00ol0003oc?3[olc`j`02o`0000Co`^7^0_l00004okC;k006o`000?nc
_n?o0000o`000?nW`>_o00001?nW`>/3o`0000;oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03
o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW
`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/4o`000003ojO0jol0003oYl3[00;o
Yl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04o`0000;o
Yl3[0_l00002ojO0j`Co00002oooool00ol0003oooooooooo`03ooooo`00@?ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?nW`>_oYl3[00?o00001?nW`>/01_l0003oYl3[o`000?l0003oYl3[o`00
00CoYl3[0ol000000ol7Em;o0000o`000004o`0000;o02jg0_l000001OlNF]7o0000odQaeom8LMOo
000000;oKXSL1_l00004ojRYe`07o`000?nj/]7o^[;AokZbdOl0003o_[SCo`000003ol^mc007o`00
0?o?`/kocl;>olo2c_l0003oelC7o`000003om[8b005o`000?oMcLWogLg9omg=bOl000000ooTd<@0
1?l0003oiMG5onGEaOl00003onOJa`06o`000?oXgl[o0000o`000?oYgLOo00000ooYh/X01ol0003o
j>O>onSWc_l0003oi^cCo`000?oRlMP01Ol000001OoGk^?o0000olc`joo<l>_o000000;o_?3c00Co
0000ol;Qk_l0003o00000_nbfO@00ol0003o]<_/okC;k003o`0000CoYl3[00Ko0000ojO0jol0003o
0000ojO0jol00003ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0
jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04o`00
00;oYl3[00?o0000ojO0jonW`>/00ol00005ojO0j`?o000000?oYl3[o`000?nW`>/00onW`>/3o`00
00?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co00003oooool00ol0
003oooooooooo`03ooooo`00@Oooool2o`0002kooooo0_l00003ojO0j`03o`000?nW`>_oYl3[00Co
00000onW`>/02?l0003oYl3[o`000?l0003oYl3[o`000?laM^;o00000_l7Em89o`000005oaiJdOl0
003oB77GodQaeol000000_m^R=`01Ol0003oSY_LohjKg?n>Vmco000000GoZ:WG00?o0000okZbdOl0
00000onn^=<00ol0003obkg<o`000005olo2cP05o`000?oJb<Sof/S8om[8b?l000001?oMcLT2o`00
0005onC@a?l0003oiMG5onGEaOl000000ooWf/L01Ol0003oj=o:onSOb_l0003oj>C=00?o000000Wo
jN;:o`000?oXilkoj>O>o`000?oVk=?o0000on;af?l000000_oKm]h00ol0003odO[To`000002o`00
0004olc`jol0003o_?3cokc`l`Co00000_nbfO@4o`0000?oYl3[00?o0000ojO0jonW`>/00ol00004
ojO0j`?o000000?oYl3[o`000?nW`>/00onW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003
ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[00?o0000
ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/01_l0003oYl3[o`000?l0
003oYl3[o`0000CoYl3[0ol00002ojO0j`04o`000?nW`>_oYl3[ojO0j`Co000000?oooooo`000?oo
ool04Oooool00ol0003oooooooooo`02ooooo`00@oooool00ol0003oooooooooo`0]ooooo`03o`00
0?nW`>_oYl3[00?o00001?nW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[00?o0000oc5fh_l00000
1?l000000ol08jco0000o`000003o`0000;o7U[A1?l00002ofj8g005o`000?n>VmcoSY_LohjKg?l0
00001?nXZML2o`0000Co_[SC0_l00005olo2cP05o`000?oBb<oo0000om[8b?l000001?oMcLT00ol0
003oh=?;on3Cb`02o`000003onGEaOl0003oim[700;oim[700Co0000onSOb_oXgl[o00000_oXi<d0
0ol0003oj>[@onSZd002o`000006onSWc_l0003oi^cCo`000?oRlMSo00000_oKm]h00ol0003odO[T
o`000002ol7kj@Go00000_n]iOT4o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`00
0?nW`>_oYl3[00;o00001?nW`>/01_l0003oYl3[o`000?l0003oYl3[o`0000CoYl3[0ol00003ojO0
j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[00?o0000ojO0
jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`03o`00
00CoYl3[00Ko0000ojO0jol0003o0000ojO0jol00002ojO0j`Go00001_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00;ooooo0014ooooo`03o`000?oooooooooo02gooooo0_l00003
ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`08o`000005o`0S[?l0003o
0000o`000?l0@/@00ol00002odMfg0Go00000on>Vm`01_l0003oZ:WGo`000?l0003o[:oJo`0000?o
_[SC00Co0000ol>ne_o3_]Ko00000oo?`/h01?l0003od/S?om;8cooBb<l2o`0000?ogLg900Ko0000
on3CbooPdl_oh=?;o`000?oRf<d2o`0000?oim[700?o0000onSOb_l000000_oXi<d01_l0003oj>[@
onSZd?oXj]3o0000onK`d`Ko000000GofoKNo`000?oAn^Co0000ol7kj@04o`000003oj3]nOl0003o
000000;o00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002
ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/01_l0003oYl3[o`000?l0003oYl3[o`0000CoYl3[
0ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[
00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[
ojO0j`03o`0000?oYl3[0ol0000;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
0_ooool004Gooooo00?o0000ooooooooool0;Oooool00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o
0000ojO0jonW`>/01?l00002oh^gl`?o000000?o25kFo`000?l000001_l000000olIGMCo0000o`00
0002odMfg003o`000?m_Sn7oKhoQ00Ko00001?n/[mX00ol0003o_[SCo`000004ol>neP03o`000?o?
`/ko000000Cod/S?00Go0000omK>d_l0003ogLg9o`000003on3Cb`08o`000?oRf<goh]S=o`000?oT
gloo0000onOJaol00002onSObP03o`000?oXi<go000000?oj>[@00So0000onK`dol0003oh_KGo`00
0?oKnm[o0000om3ng@_o00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW
`>/01?l00002ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`03o`0000Co
Yl3[00Ko0000ojO0jol0003o0000ojO0jol00004ojO0j`?o00000_nW`>/00ol0003oYl3[ojO0j`04
o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/0
0ol0003oYl3[ojO0j`04o`0000;oYl3[00Co0000ojO0jol0003o00003oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00;ooooo0016ooooo`03o`000?oooooooooo02gooooo0_l00003
ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/01_l0003oRkOcoh^glon;]o?o0000oc9ih`?o0000
00?o03:eo`000?l000000_l000001?l0@lGo0000oaUMe?l00003odMfg004o`000?m_Sn7oKhoQo`00
00?oTZ;P00?o0000ojb_f_n/[mX00_n/[mX2o`0000Go`kkF0_l00004om;8c`05o`000?oFc];oe/kB
omK>d_l000000ooPdl/01?l0003oh]S=on;HcOl00003onCOc`;o000000Coj=o:o`000?oXi<go0000
0ooXj]002?l0003oi_3Co`000?oRm]Oo0000om_kf_l0003od?kM2?l00003ojO0j`03o`000?nW`>_o
Yl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003
ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[00Ko0000
ojO0jol0003o0000ojO0jol00002ojO0j`Co00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[
00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/00ol0003oYl3[
ojO0j`03o`0001;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00Aooo
ool2o`0002oooooo00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00So000000Co
36OKo`000?l0003o03:e1?l000000ol0@lGo0000oaUMe004o`0000?oKhoQ00Ko0000oi:Rh?nBX^3o
TZ;Po`000?n/[mX2o`0000;o/;ON00Oo0000ol>ne_o3_]Ko`kkFo`000?o6aMWo000000?od/S?00?o
0000omK>d_oFc]800_oFc]82o`000005on3Cbol0003oh]S=on;HcOl000001?oTgll00ol0003oiNGA
o`000004o`000009onSZd?l0003oi_3Co`000?oRm]Oo0000om_kf_l0003od?kM00Ko000000?oYl3[
o`000?nW`>/00onW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_o
Yl3[00Co00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003
ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003
ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[00?o0000
ojO0jonW`>/01?l0000Fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool0
04Wooooo00?o0000ooooooooool0;Oooool2o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0
j`07o`000?mYYOCoJJGdo`000?lhP^So0000o`aWf`0;o`000003odEkhOl0003o000000?o00000_nB
X^03o`0000Go/;ON00?o0000ol>ne_l000000oo6aMT00ol0003od/S?o`000004omK>dP04o`000?oI
eMCofMGDo`0000?oh]S=00Oo0000onCOcooTglooi=o?o`000?oUiM7o000000;oiNcD00?o0000on?c
eol000003_l00003ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/01?l00003
ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000
ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/01_l0003oYl3[o`000?l0
003oYl3[o`0000CoYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[
ojO0j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l0000Jooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool00_ooool004[ooooo00?o0000ooooooooool0;Oooool00ol0003oYl3[ojO0
j`04o`0000?oYl3[00?o0000ojO0jonW`>/01Ol000000olhP^So0000o`000004o`000005o`0TZ?l0
003o0000o`000?lBHML00_l000001?m5Nn7o0000og2Fiom`U^L3o`0000;oUJ[U00?o0000ok2gg_n`
]mh00on`]mh2o`0000Coa/GI0ol00003omK>dP08o`000?oIeMCofMGDo`000?oLg=Oo0000on;HcOl0
0003onCOc`03o`000?oUiM7o000000;oiNcD00?o0000on?ceol000000_oOnMT00ol0003oeogIo`00
0007o`0000?oYl3[00?o0000ojO0jonW`>/00_l00004ojO0j`?o00000onW`>/00ol0003oYl3[ojO0
j`04o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW
`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/00_l00004ojO0j`06o`000?nW
`>_o0000o`000?nW`>_o00001?nW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`03
o`000?nW`>_oYl3[00Co00007oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo007o
oooo001;ooooo`03o`000?oooooooooo02gooooo0_l00003ojO0j`03o`000?nW`>_oYl3[00Co0000
0_nT_nd00ol0003oGYK]o`000003o`000003oa5ah?l0003o000000;o000000Co02BXo`000?l0003o
00000_lBHML3o`0000;oL9KW00?o0000oiFZiOnEZ^D00_nEZ^D00ol0003o/;ONo`000002o`000003
okBoh_l0003oa/GI00;oa/GI00Oo0000ol[=g?o:cMcob/gLo`000?oFc];o000000;ofMGD00Co0000
omcLeooLg=Oog=cG0ol000001?oTgloo0000onGUdOl00002onG/e003o`000?oSlmOo000000;ogoWI
00?o0000omOmfOl000001?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/01_l0003oYl3[
o`000?l0003oYl3[o`0000CoYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/00ol0
003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[
00Co00000_nW`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[00Co0000ojO0jol0003o00000_nW`>/0
0ol0003oYl3[ojO0j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l0000Tooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00Oooool004cooooo0_l0000^ooooo`03o`000?nW`>_oYl3[
00Co00000onW`>/01Ol0003oY;o]ojBokOnT_ngo000000;oGYK]00?o0000od2=kOl000002ol00002
od:2iPCo00000_nEZ^D3o`0000Go];oR00?o0000olK5fOl000001?o:cM`3o`000003omWEe?l0003o
g=cG00;og=cG00Co0000omgTfOoMi=WogNCI1?l000001?oUk=Co0000on?ceol00002omoif@03o`00
0?oGoMWo000000?o000000CoYl3[o`000?nW`>_oYl3[1?l00003ojO0j`03o`000?nW`>_oYl3[00;o
00001?nW`>/01_l0003oYl3[o`000?l0003oYl3[o`0000CoYl3[0ol00003ojO0j`03o`000?nW`>_o
Yl3[00?o00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002
ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[0ol00002
ojO0j`03o`000?nW`>_oYl3[00Co0000:Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo007ooooo001>ooooo`03o`000?oooooooooo02cooooo0_l00003ojO0j`03o`000?nW`>_oYl3[
01?o000000Co04K3o`000?l0003o00000_m2P^H00ol0003oLIo]o`000002o`0000?oV;?[00?o0000
okBoh_nd_n800_nd_n82o`0000?ob/gL0_l00003olkEg`05o`000?oLg=Oog=cGomcLeol000000ooM
i=T00ol0003og^cLo`000002omccgP[o00000_nW`>/4o`0000?oYl3[00?o0000ojO0jonW`>/01?l0
0002ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`00
0?nW`>_oYl3[00Co00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/0
1?l00002ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[
00Ko0000ojO0jol0003o0000ojO0jol00003ojO0j`?o0000;Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo007ooooo001?ooooo`03o`000?oooooooooo02gooooo00?o0000ojO0jonW
`>/00ol00003ojO0j`05o`000?nB^_;oT[[boi:jl_l000000_mVWo400ol0003oBYSbo`000007o`00
0003o`16`ol0003o2VCJ00Co00000_maWnd00ol0003oV;?[oiRcj`02oiRcj`04o`000?nd_n;o0000
o`0000;o^<SW00?o0000ol[=g?l000001?o>eMl01Ol0003od=kSo`000?oLg=Oo000000?ogNCI00?o
0000omk/g?l000000_oLlmh2o`0000;ocokM00?o0000ol7nf?l000001_l00003ojO0j`03o`000?nW
`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[00?o0000ojO0jonW`>/00ol0
0004ojO0j`?o00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l0
0003ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o
0000ojO0jonW`>/00ol00004ojO0j`?o0000<Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo007ooooo001@ooooo`03o`000?oooooooooo02gooooo0_l00003ojO0j`03o`000?nW`>_o
Yl3[00co000000?o9H[/o`000?l000001_l00002ocf9k0Go00000_nH/n/3o`0000Co^<SW0ol00003
olkEg`03o`000?o@g^?od=kS00Co000000CogNCIo`000?oNk=co00000_oLlmh2o`0000;ocokM00?o
0000ol7nf?l000000ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0
j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`06o`000?nW`>_o0000o`000?nW`>_o
00000onW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co
00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`03
o`000?nW`>_oYl3[00?o0000=?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo007o
oooo001Aooooo`;o0000;_ooool00ol0003oYl3[ojO0j`04o`0000?oYl3[00Co0000ohNbl_n7/_;o
00000om_Z?@<o`0000;o?HW/00?o0000og2Xm?m`Z?@00ol00003oiZml@04o`000?nhb>Oo0000o`00
00?o^];/00?o0000olkEgol000000_o@g^<01?l0003odNSVom7Xi_oAj>H5o`000003omccg_l0003o
000000Ko00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003
ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[00?o0000
ojO0jol000000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002
ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[00?o0000
ojO0jonW`>/01?l0000gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool0
05?ooooo00?o0000ooooooooool0;?ooool2o`0000?oYl3[00?o0000ojO0jonW`>/03?l000000olc
V?;o0000o`000009o`0000?oL:Sd00?o0000oiZmlOnJ_O401?l00004ok[Bk0?o000000?od=kSo`00
0?oAj>H00_oAj>H00ol0003od?7Xo`000002olchj0;o00000_ncnm`3o`0000;oYl3[00?o0000ojO0
jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04o`00
00;oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/3o`00
00?oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0
003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/00ol0000looooo`03o`000?oooooooooo
00Sooooo0Ol00001ooooo`7ooooo001Dooooo`03o`000?oooooooooo02cooooo00?o0000ojO0jonW
`>/01?l00002ojBok@05o`000?n8/O7oR;7aohRalOl000000omi/OH00ol0003oHjkio`00000Ao`00
00CoVlSg00Co0000ok[Bk?l0003o00000_nlgO04o`000004om7Xi_l0003od?7Xo`0000;oc?SX0_l0
0002ok?kg0?o00000_nW`>/4o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW
`>_oYl3[00Co00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l0
0002ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`00
0?nW`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/0
1?l00010ooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7ooooo001Eooooo`03o`000?oo
oooooooo02cooooo0_l00003ojO0j`05o`000?nT_ngoY;o]ojBokOl000000_n8/O4Eo`0000?oK[;j
00?o0000oi_8monKb?L01?l000000onlgO3o0000o`000003okcWm0Go000000?oc?SXo`000?l00000
2?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[
00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[
ojO0j`02o`0000CoYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/00ol0003oYl3[
ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00015ooooo`03o`000?oooooooooo00Kooooo
0Ol00001ooooo`7ooooo001Fooooo`03o`000?oooooooooo02gooooo00?o0000ojO0jonW`>/01ol0
0003ohnhlP04o`000?n3^?OoPkSgo`0000;oLKSl2_l000000ol/U_3o0000o`000005o`0000;oVmCl
1?l000001_nlioCo0000o`000?l0003o^?3do`0000;o[_K`0_l000000on7jmCo0000o`000003o`00
00?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0
003oYl3[ojO0j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[
00Co00000_nW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/0
0ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00019ooooo`03o`000?oooooo
oooo00Kooooo0Ol00001ooooo`7ooooo001Gooooo`;o0000;_ooool2o`0000?oYl3[00Co0000oijm
k_nN_Nko00000_n?^?88o`0000;oOl7l00?o0000ofg2o_m]`_h03_l00002oiONoPGo000000?o^?3d
o`000?n^m_001Ol000001OnW`>_o0000ojO0jonW`>_o000000;oYl3[1?l00003ojO0j`03o`000?nW
`>_oYl3[00Co00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/00ol0
0003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`02o`0000CoYl3[0ol0
0003ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`04o`0004kooooo00?o
0000ooooooooool01Oooool1o`00007ooooo0Oooool005Wooooo00?o0000ooooooooool0;?ooool0
0ol0003oYl3[ojO0j`07o`0000?oU[cb00?o0000ohfomon=_oL01ol00002oh7=o`Wo00000_mP`o`4
o`0000;oS^Ck1ol000001?nW`>_o0000o`000?l00003ojO0j`?o00000onW`>/00ol0003oYl3[ojO0
j`04o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW
`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`04o`000?nW
`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`03o`000?nW`>_oYl3[00Co0000
Doooool00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00F_ooool00ol0003ooooooooo
o`0/ooooo`;o00000onW`>/01?l0003oWKc^oiflk_l00002oiJllPCo00000onGa?H00ol0003oS/Sk
ohk8n`04o`0000;oV<ok5_l00003ojO0j`03o`000?nW`>_o000000;oYl3[00?o0000ojO0jonW`>/0
1?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[
00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/00ol0003oYl3[
ojO0j`03o`0000CoYl3[0ol00002ojO0j`03o`000?nW`>_oYl3[00Co0000F?ooool00ol0003ooooo
ooooo`03ooooo`7o00000Oooool1ooooo`00Foooool00ol0003oooooooooo`0/ooooo`03o`000?nW
`>_oYl3[00So00000_nL`O47o`0000;oWLWg1?l00002ojO0j`03o`000?nW`>_oYl3[00So00000_nW
`>/3o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`?o00000onW`>/00ol0003oYl3[ojO0
j`04o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW
`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`04o`000?nW
`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00ol0001Looooo`03o`000?oooooooooo00Cooooo
0Ol00001ooooo`00G?ooool2o`0002gooooo0_l00003ojJok003o`000?nP_^koX;k^00Co00000_nS
`^l00ol0003oX<Gboj35lP04o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW
`>_oYl3[00Co00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jol000000_nW
`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`03o`000?nW
`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[00?o0000ojO0jonW`>/01?l0
0002ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/4o`00063ooooo00?o0000ooooooooool00ooo
ool1o`00007ooooo001Nooooo`03o`000?oooooooooo02cooooo00?o0000ojJok?nV_n`00ol00003
ojG0k@03o`000?nS`^ooXl;_00?o00000onW`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[00?o0000
ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`04
o`0000;oYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/00ol0003oYl3[ojO0j`04
o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/0
0ol0003oYl3[ojO0j`03o`0000?oYl3[0ol0001Uooooo`03o`000?oooooooooo00;ooooo0Ol00001
ooooo`00Goooool00ol0003oooooooooo`0/ooooo`;o00000_nV_n`00ol0003oYL3]ojG0k@04o`00
00?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0
003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`?o00000onW`>/00ol0
003oYl3[ojO0j`03o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[
00Co00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002ojO0
j`04o`000?nW`>_o0000o`0006Wooooo00Go0000ooooooooooooooooo`000001ooooo`00H?ooool0
0ol0003oooooooooo`0/ooooo`03o`000?nV_ncoY[o/00?o00000onW`>/00ol0003oYl3[ojO0j`04
o`0000;oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/0
0ol0003oYl3[ojO0j`04o`0000;oYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0
j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`03o`000?nW`>_oYl3[00Co00000onW
`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`03o`000?nW
`>_oYl3[00?o0000Joooool01Ol0003ooooooooooooooooo0000007ooooo001Qooooo`;o0000;Ooo
ool2o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00?o00000onW
`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW
`>_oYl3[00?o00000_nW`>/4o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW
`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l0
0003ojO0j`03o`000?nW`>_oYl3[00?o0000Koooool01?l0003oooooooooool00001ooooo`00Hooo
ool00ol0003oooooooooo`0[ooooo`03o`000?nW`>_oYl3[00Co00000_nW`>/00ol0003oYl3[ojO0
j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00?o00000onW
`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW
`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW
`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`04o`0007?ooooo00?o0000ooooool000000Ooo
ool006Cooooo00?o0000ooooooooool0:oooool2o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003
ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[00?o0000
ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_o000000;oYl3[00?o0000ojO0jonW`>/01?l00002
ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[00?o0000
ojO0jonW`>/01?l00002ojO0j`03o`000?nW`>_oYl3[00Co0000Moooool00ol0003oooooooooo`01
o`000000IOooool00ol0003oooooooooo`0[ooooo`03o`000?nW`>_oYl3[00Co00000_nW`>/00ol0
003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[
00?o00000onW`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[
00?o00000onW`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l00003ojO0
j`03o`000?nW`>_oYl3[00?o0000O?ooool1o`00007ooooo0Ol0000006Kooooo0_l0000/ooooo`;o
00000onW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`03
o`000?nW`>_oYl3[00Co00000_nW`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[1?l00002ojO0j`03
o`000?nW`>_oYl3[00Co00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW
`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00Co0000P?ooool2o`000000J?ooool00ol0003ooooo
ooooo`0Zooooo`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[
00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/3o`0000?oYl3[
00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0003oYl3[
ojO0j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l00023ooooo`?o0000001Yooooo`03o`000?oo
oooooooo02[ooooo0_l00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/00ol0003oYl3[ojO0
j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`?o00000_nW`>/00ol0003oYl3[ojO0
j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`03o`000?nW`>_oYl3[00Co00000onW
`>/00ol0003oYl3[ojO0j`03o`0008?ooooo1?l00003ooooo`00J_ooool00ol0003oooooooooo`0[
ooooo`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[00?o0000
ojO0jonW`>/00ol00003ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00ol0
0003ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[00?o
0000ojO0jonW`>/01?l00023ooooo`?o00001oooool006_ooooo00?o0000ooooooooool0:oooool2
o`0000;oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/0
0ol0003oYl3[ojO0j`04o`0000;oYl3[1?l00002ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/0
0ol0003oYl3[ojO0j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l00023ooooo`Co00002_ooool0
06cooooo0_l0000/ooooo`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`03o`00
00?oYl3[00?o0000ojO0jonW`>/00ol00002ojO0j`Co00000onW`>/00ol0003oYl3[ojO0j`03o`00
00?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00?o0000Poooool4o`00
00kooooo001^ooooo`03o`000?oooooooooo02[ooooo0_l00002ojO0j`03o`000?nW`>_oYl3[00Co
00000_nW`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00Co
00000_nW`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l00022ooooo`Co
00004_ooool006oooooo00?o0000ooooooooool0:_ooool00ol0003oYl3[ojO0j`03o`0000?oYl3[
00?o0000ojO0jonW`>/00ol00002ojO0j`Co00000onW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[
00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00?o0000P_ooool4o`0001Kooooo
001`ooooo`03o`000?oooooooooo02[ooooo0_l00002ojO0j`03o`000?nW`>_oYl3[00Co00000_nW
`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`03o`000?nW`>_oYl3[00Co00000_nW
`>/00ol0003oYl3[ojO0j`04o`0008;ooooo0ol0000Jooooo`00LOooool2o`0002_ooooo00?o0000
ojO0jonW`>/00ol00002ojO0j`Co00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000
ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00?o0000P_ooool4o`0001gooooo001coooo
o`03o`000?oooooooooo02Wooooo0_l00002ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`03o`00
00?oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`03o`000?nW`>_oYl3[00Co0000POooool4o`00
027ooooo001dooooo`03o`000?oooooooooo02[ooooo0_l00003ojO0j`03o`000?nW`>_oYl3[00?o
00000onW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[00?o0000ojO0jonW`>/00ol00021ooooo`Co
00009Oooool007Gooooo00?o0000ooooooooool0:_ooool00ol0003oYl3[ojO0j`04o`0000;oYl3[
00?o0000ojO0jonW`>/01?l00002ojO0j`03o`000?nW`>_oYl3[00Co0000P?ooool4o`0002Wooooo
001fooooo`;o0000:oooool2o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW
`>_oYl3[00?o0000POooool3o`0002gooooo001hooooo`03o`000?oooooooooo02Wooooo00?o0000
ojO0jonW`>/01?l00002ojO0j`03o`000?nW`>_oYl3[00Co0000P?ooool4o`00033ooooo001ioooo
o`03o`000?oooooooooo02Wooooo0_l00003ojO0j`03o`000?nW`>_oYl3[00?o0000P?ooool4o`00
03Cooooo001jooooo`03o`000?oooooooooo02Wooooo00?o0000ojO0jonW`>/01?l0001oooooo`Co
0000>?ooool007_ooooo00?o0000ooooooooool0:Oooool2o`00083ooooo0ol0000looooo`00O?oo
ool2o`0002Wooooo00?o0000ooooooooool0Noooool4o`0003oooooo001nooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool0Moooool4o`0004?ooooo001oooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0Loooool4o`0004Oooooo0020ooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0Koooool4o`0004_ooooo0021ooooo`;o00009?ooool00ol0003ooooo
ooooo`1/ooooo`?o0000Coooool008?ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`1Xooooo`Co0000D_ooool008Cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1T
ooooo`Co0000E_ooool008Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Poooo
o`Co0000F_ooool008Kooooo0_l0000Oooooo`03o`000?oooooooooo05cooooo1?l0001Nooooo`00
R?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05Wooooo0ol0001Rooooo`00ROoo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Gooooo1?l0001Uooooo`00R_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo057ooooo1?l0001Yooooo`00Roooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo04gooooo1?l0001]ooooo`00S?ooool2o`0001Wo
oooo00?o0000ooooooooool0B_ooool3o`00077ooooo002>ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0A_ooool4o`0007Cooooo002?ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0@_ooool4o`0007Sooooo002@ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0?_ooool4o`0007cooooo002Aooooo`;o00005?ooool00ol0003oooooooooo`0joooo
o`Co0000P?ooool009?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0hooooo`?o
0000Q?ooool009Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0dooooo`Co0000
Qoooool009Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0`ooooo`Co0000Rooo
ool009Kooooo0_l0000>ooooo`03o`000?oooooooooo02cooooo1?l0002?ooooo`00V?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo0ol0002Cooooo`00VOooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo1?l0002Fooooo`00V_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo027ooooo1?l0002Jooooo`00Voooool2o`0000Wooooo00?o
0000ooooooooool07Oooool4o`0009kooooo002Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool06Oooool4o`000:;ooooo002Nooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool05_ooool3o`000:Kooooo002Oooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool04_ooool4o`000:Wooooo002Pooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
3_ooool4o`000:gooooo002Qooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000/Ooo
ool00:?ooooo00Co0000oooooooooooo00002?ooool4o`000;Gooooo002Tooooo`03o`000?oooooo
000000Gooooo0ol0002iooooo`00YOooool2o`000003ooooool0003o000000;o0000_?ooool00:Ko
oooo0_l00030ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00_oooool3o`000003oa0@4?oooooooooo0:?ooooo002Looooo`03okZj^_lb<S;ooooo00gooooo
0_l0000;ooooo`03o`000?nj^[[ooooo00Gooooo00?o410@okZj^_ooool01?ooool2o`0000Kooooo
00?o0000okZj^_ooool0UOooool009gooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00006ooooo`03o`000?oooooooooo00[ooooo0_lb<S86ooooo`03oiRHV?lb<S;ooooo00Gooooo
00?o0000ooooooooool01?ooool2oc8b<YKooooo002Kooooo`05oiRHV?l@413o0000o`000?nYZJT0
0_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o
00000_ooool00on7QhOo0000okZj^P05ooooo`03omgMgOl0003o^[Zj00Gooooo00?o0000oooooooo
ool01?ooool00on7QhOo0000okZj^P0;ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooo
ooooool01oooool4o`000003oa0@4?oooooooooo07?ooooo002Kooooo`08o`000?nYZJWoEEEEoiRH
V?mEEEGo^[Zjooooool00002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41001Oooool00omEEEGo
MgMgodA4A005ooooo`03o`000?oooooooooo00Cooooo00?oc<c<o`000?l@41003?ooool01_l0003o
oooooooooooooooo0000ooooo`Ko00001Oooool00ol0003oooooooooo`1eooooo`00Voooool01olb
<S;ok^k^oiRHV?mEEEGogMgMoa0@4?ooool00ol00007ooooo`03o`000?oooooooooo00?ooooo00Co
gMgMo`000?l@413oc<c<2_ooool01OoMgMgo410@oooooolQ8B7ogMgM00Cooooo00?o0000oooooooo
ool04oooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool0MOooool009_o
oooo00Oo^[ZjodA4A?o<c<co8B4Qooooool@413oc<c<00[ooooo00?o0000ooooooooool00oooool0
1?o^k^ko8B4Qoa0@4?o^k^h:ooooo`05ofIVI_n7QhOooooooiRHV?mEEED01?ooool00ol0003ooooo
ooooo`0Cooooo`06o`000?ooooooooooooooool0003ooooo1_l00005ooooo`03o`000?oooooooooo
07Gooooo002Kooooo`07onk^k_l0003oooooo`000?ooooooIVIVohN7Q`0:ooooo`03o`000?oooooo
oooo00?ooooo00Co8B4QogMgMomgMgOo<S8b2Oooool00oo^k^ko0000onk^kP02ooooo`03o`000?oM
gMgooooo00;ooooo00?o0000ooooooooool04oooool01Ol0003oQhN7oooooonYZJWo000000cooooo
00?o0000ooooooooool0MOooool009_ooooo00CoIVIVoiRHV?oooooo<S8b0_nj^[X00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00002?ooool01?l@413o0000
o`000?ooool2o`000005oa0@4?ooooooooooooooool000005?ooool00ol@413o0000ogMgM`02o`00
0003oiRHV?oooooooooo00[ooooo00?o0000ooooooooool0MOooool009kooooo00?oIVIVohN7Qooo
ool02oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0MOooool009kooooo00?oZJVYodA4A?ooool02oooool2o`0001[ooooo0_l0000Tooooo`03oeEE
EOmVIVKo000007Oooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.875, 0}} -> {-0.117061, 0.0205603, \
0.00372443, 0.00372443}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -37.6875 0 ]
[.5 .82364 37.6875 10.125 ]
[.03045 .24505 -12 -8.71092 ]
[.03045 .24505 0 .28908 ]
[.17875 .18668 -23.5791 -9 ]
[.17875 .18668 .42091 0 ]
[.33612 .12478 -5.58359 -9 ]
[.33612 .12478 .41641 0 ]
[.5034 .05901 -15.8172 -9 ]
[.5034 .05901 2.18278 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.29165 .07573 -9.31117 -9.8125 ]
[.29165 .07573 .68883 0 ]
[.70361 -0.00072 0 -6.25801 ]
[.70361 -0.00072 6 2.74199 ]
[.82501 .18517 0 -6.07699 ]
[.82501 .18517 18 2.92301 ]
[.92763 .34231 0 -5.92977 ]
[.92763 .34231 6 3.07023 ]
[.91861 .21225 0 -6.57576 ]
[.91861 .21225 10.0625 3.23674 ]
[.02388 .26659 -36 -2.74357 ]
[.02388 .26659 0 6.25643 ]
[.01027 .35187 -6 -2.81576 ]
[.01027 .35187 0 6.18424 ]
[-0.00411 .44201 -30 -2.89248 ]
[-0.00411 .44201 0 6.10752 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -98.6875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
74.312 11.250 moveto
(@) show
80.312 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
86.312 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
92.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
98.375 11.250 moveto
(D) show
104.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
116.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
122.375 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
128.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
134.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.04003 .25401 m
.04482 .2585 L
s
[(-1)] .03045 .24505 1 .93576 Mshowa
.18786 .19613 m
.19242 .20085 L
s
[(-0.5)] .17875 .18668 .96492 1 Mshowa
.34468 .13472 m
.34896 .13969 L
s
[(0)] .33612 .12478 .8612 1 Mshowa
.51132 .06947 m
.51528 .0747 L
s
[(0.5)] .5034 .05901 .75747 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06892 .2427 m
.07176 .24542 L
s
.09814 .23126 m
.10096 .23401 L
s
.1277 .21969 m
.13049 .22246 L
s
.1576 .20797 m
.16037 .21078 L
s
.21848 .18414 m
.22119 .187 L
s
.24947 .172 m
.25214 .1749 L
s
.28082 .15973 m
.28346 .16265 L
s
.31256 .1473 m
.31516 .15025 L
s
.37719 .12199 m
.37973 .125 L
s
.41011 .1091 m
.4126 .11215 L
s
.44343 .09606 m
.44588 .09913 L
s
.47716 .08285 m
.47958 .08595 L
s
.54591 .05593 m
.54824 .0591 L
s
.58094 .04221 m
.58323 .04541 L
s
.61641 .02832 m
.61866 .03155 L
s
.65234 .01425 m
.65454 .01752 L
s
gsave
.29165 .07573 -70.3112 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69139 .00406 m
.68528 .00644 L
s
[(0)] .70361 -0.00072 -1 .39067 Mshowa
.81263 .18951 m
.80643 .19168 L
s
[(0.5)] .82501 .18517 -1 .35044 Mshowa
.91512 .34629 m
.90887 .34827 L
s
[(1)] .92763 .34231 -1 .31773 Mshowa
.125 Mabswid
.71738 .04381 m
.7137 .04521 L
s
.74245 .08216 m
.73876 .08354 L
s
.76665 .11918 m
.76296 .12054 L
s
.79003 .15495 m
.78632 .15627 L
s
.83448 .22293 m
.83075 .22421 L
s
.85562 .25527 m
.85189 .25653 L
s
.87608 .28658 m
.87235 .28781 L
s
.89591 .3169 m
.89216 .31811 L
s
.93375 .37478 m
.92999 .37595 L
s
.95181 .40242 m
.94805 .40357 L
s
gsave
.91861 .21225 -61 -10.5758 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.062 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.062 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.0361 .26182 m
.04221 .25944 L
s
[(-0.002)] .02388 .26659 1 -0.39032 Mshowa
.02256 .34727 m
.0287 .34497 L
s
[(0)] .01027 .35187 1 -0.37428 Mshowa
.00825 .4376 m
.01442 .43539 L
s
[(0.002)] -0.00411 .44201 1 -0.35723 Mshowa
.125 Mabswid
.03278 .28275 m
.03646 .28133 L
s
.02942 .30396 m
.0331 .30256 L
s
.02601 .32547 m
.0297 .32408 L
s
.01906 .36938 m
.02275 .36802 L
s
.0155 .3918 m
.0192 .39045 L
s
.0119 .41454 m
.0156 .4132 L
s
.00454 .46099 m
.00825 .45968 L
s
.00078 .48472 m
.0045 .48342 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.657 .749 .918 r
.39597 .67735 .40235 .68299 .41304 .67994 .40668 .67428 Metetra
.657 .749 .918 r
.40668 .67428 .41304 .67994 .42377 .67688 .41744 .67119 Metetra
.657 .749 .918 r
.41744 .67119 .42377 .67688 .43455 .6738 .42825 .66809 Metetra
.657 .749 .918 r
.42825 .66809 .43455 .6738 .44537 .67072 .43909 .66498 Metetra
.657 .749 .918 r
.43909 .66498 .44537 .67072 .45623 .66762 .44998 .66186 Metetra
.657 .749 .918 r
.44998 .66186 .45623 .66762 .46714 .6645 .46092 .65872 Metetra
.657 .749 .918 r
.46092 .65872 .46714 .6645 .47809 .66138 .4719 .65558 Metetra
.657 .749 .918 r
.4719 .65558 .47809 .66138 .48908 .65824 .48292 .65241 Metetra
.657 .749 .918 r
.48292 .65241 .48908 .65824 .50012 .65509 .49399 .64924 Metetra
.657 .749 .918 r
.49399 .64924 .50012 .65509 .5112 .65193 .5051 .64605 Metetra
.657 .749 .918 r
.5051 .64605 .5112 .65193 .52233 .64875 .51626 .64285 Metetra
.657 .749 .918 r
.51626 .64285 .52233 .64875 .5335 .64556 .52746 .63964 Metetra
.657 .749 .918 r
.52746 .63964 .5335 .64556 .54472 .64236 .53871 .63641 Metetra
.657 .749 .918 r
.53871 .63641 .54472 .64236 .55599 .63915 .55 .63318 Metetra
.657 .749 .918 r
.55 .63318 .55599 .63915 .5673 .63592 .56134 .62992 Metetra
.657 .749 .918 r
.56134 .62992 .5673 .63592 .57865 .63268 .57273 .62666 Metetra
.657 .749 .918 r
.57273 .62666 .57865 .63268 .59006 .62942 .58417 .62338 Metetra
.657 .749 .918 r
.58417 .62338 .59006 .62942 .60151 .62615 .59565 .62008 Metetra
.657 .749 .918 r
.59565 .62008 .60151 .62615 .61301 .62287 .60718 .61678 Metetra
.657 .749 .918 r
.60718 .61678 .61301 .62287 .62455 .61958 .61875 .61346 Metetra
.657 .749 .918 r
.61875 .61346 .62455 .61958 .63614 .61627 .63038 .61012 Metetra
.657 .749 .918 r
.63038 .61012 .63614 .61627 .64779 .61294 .64205 .60677 Metetra
.657 .749 .918 r
.64205 .60677 .64779 .61294 .65948 .60961 .65378 .60341 Metetra
.657 .749 .918 r
.65378 .60341 .65948 .60961 .67121 .60626 .66555 .60004 Metetra
.657 .749 .918 r
.66555 .60004 .67121 .60626 .683 .60289 .67737 .59665 Metetra
.657 .749 .918 r
.67737 .59665 .683 .60289 .69484 .59952 .68924 .59324 Metetra
.657 .749 .918 r
.68924 .59324 .69484 .59952 .70672 .59612 .70116 .58982 Metetra
.657 .749 .918 r
.70116 .58982 .70672 .59612 .71866 .59272 .71313 .58639 Metetra
.657 .749 .918 r
.71313 .58639 .71866 .59272 .73065 .5893 .72515 .58294 Metetra
.657 .749 .918 r
.72515 .58294 .73065 .5893 .74268 .58586 .73723 .57948 Metetra
.657 .749 .918 r
.73723 .57948 .74268 .58586 .75477 .58241 .74935 .576 Metetra
.657 .749 .918 r
.74935 .576 .75477 .58241 .76691 .57895 .76153 .57251 Metetra
.657 .749 .918 r
.76153 .57251 .76691 .57895 .7791 .57547 .77375 .569 Metetra
.657 .749 .918 r
.77375 .569 .7791 .57547 .79134 .57197 .78603 .56548 Metetra
.657 .749 .918 r
.78603 .56548 .79134 .57197 .80364 .56846 .79836 .56195 Metetra
.657 .749 .918 r
.79836 .56195 .80364 .56846 .81599 .56494 .81075 .55839 Metetra
.657 .749 .918 r
.81075 .55839 .81599 .56494 .82839 .5614 .82319 .55483 Metetra
.657 .749 .918 r
.82319 .55483 .82839 .5614 .84084 .55785 .83568 .55124 Metetra
.657 .749 .918 r
.83568 .55124 .84084 .55785 .85335 .55428 .84822 .54765 Metetra
.657 .749 .918 r
.84822 .54765 .85335 .55428 .86591 .55069 .86082 .54403 Metetra
.657 .749 .918 r
.86082 .54403 .86591 .55069 .87852 .54709 .87348 .5404 Metetra
.657 .749 .918 r
.87348 .5404 .87852 .54709 .89119 .54347 .88619 .53676 Metetra
.657 .749 .918 r
.88619 .53676 .89119 .54347 .90392 .53984 .89895 .5331 Metetra
.657 .749 .918 r
.89895 .5331 .90392 .53984 .9167 .53619 .91177 .52942 Metetra
.657 .749 .918 r
.91177 .52942 .9167 .53619 .92953 .53253 .92465 .52573 Metetra
.657 .749 .918 r
.92465 .52573 .92953 .53253 .94243 .52885 .93758 .52202 Metetra
.657 .749 .918 r
.93758 .52202 .94243 .52885 .95537 .52516 .95057 .51829 Metetra
.657 .749 .918 r
.95057 .51829 .95537 .52516 .96838 .52144 .96362 .51455 Metetra
.657 .749 .918 r
.96362 .51455 .96838 .52144 .98144 .51772 .97673 .51079 Metetra
.657 .749 .918 r
.38954 .67167 .39597 .67735 .40668 .67428 .40028 .66857 Metetra
.657 .749 .918 r
.40028 .66857 .40668 .67428 .41744 .67119 .41107 .66546 Metetra
.657 .749 .918 r
.41107 .66546 .41744 .67119 .42825 .66809 .4219 .66234 Metetra
.657 .749 .918 r
.4219 .66234 .42825 .66809 .43909 .66498 .43277 .65921 Metetra
.657 .749 .918 r
.43277 .65921 .43909 .66498 .44998 .66186 .44369 .65606 Metetra
.657 .749 .918 r
.44369 .65606 .44998 .66186 .46092 .65872 .45465 .6529 Metetra
.657 .749 .918 r
.45465 .6529 .46092 .65872 .4719 .65558 .46566 .64973 Metetra
.657 .749 .918 r
.46566 .64973 .4719 .65558 .48292 .65241 .47671 .64654 Metetra
.657 .749 .918 r
.47671 .64654 .48292 .65241 .49399 .64924 .48781 .64335 Metetra
.657 .749 .918 r
.48781 .64335 .49399 .64924 .5051 .64605 .49895 .64014 Metetra
.657 .749 .918 r
.49895 .64014 .5051 .64605 .51626 .64285 .51013 .63691 Metetra
.657 .749 .918 r
.51013 .63691 .51626 .64285 .52746 .63964 .52137 .63367 Metetra
.657 .749 .918 r
.52137 .63367 .52746 .63964 .53871 .63641 .53265 .63042 Metetra
.657 .749 .918 r
.53265 .63042 .53871 .63641 .55 .63318 .54397 .62716 Metetra
.657 .749 .918 r
.54397 .62716 .55 .63318 .56134 .62992 .55534 .62388 Metetra
.657 .749 .918 r
.55534 .62388 .56134 .62992 .57273 .62666 .56676 .62059 Metetra
.657 .749 .918 r
.56676 .62059 .57273 .62666 .58417 .62338 .57823 .61729 Metetra
.657 .749 .918 r
.57823 .61729 .58417 .62338 .59565 .62008 .58974 .61397 Metetra
.657 .749 .918 r
.58974 .61397 .59565 .62008 .60718 .61678 .6013 .61064 Metetra
.657 .749 .918 r
.6013 .61064 .60718 .61678 .61875 .61346 .61291 .60729 Metetra
.657 .749 .918 r
.61291 .60729 .61875 .61346 .63038 .61012 .62457 .60393 Metetra
.657 .749 .918 r
.62457 .60393 .63038 .61012 .64205 .60677 .63628 .60056 Metetra
.657 .749 .918 r
.63628 .60056 .64205 .60677 .65378 .60341 .64803 .59717 Metetra
.657 .749 .918 r
.64803 .59717 .65378 .60341 .66555 .60004 .65984 .59377 Metetra
.657 .749 .918 r
.65984 .59377 .66555 .60004 .67737 .59665 .67169 .59035 Metetra
.657 .749 .918 r
.67169 .59035 .67737 .59665 .68924 .59324 .6836 .58692 Metetra
.657 .749 .918 r
.6836 .58692 .68924 .59324 .70116 .58982 .69555 .58347 Metetra
.657 .749 .918 r
.69555 .58347 .70116 .58982 .71313 .58639 .70756 .58001 Metetra
.657 .749 .918 r
.70756 .58001 .71313 .58639 .72515 .58294 .71962 .57654 Metetra
.657 .749 .918 r
.71962 .57654 .72515 .58294 .73723 .57948 .73173 .57305 Metetra
.657 .749 .918 r
.73173 .57305 .73723 .57948 .74935 .576 .74389 .56954 Metetra
.657 .749 .918 r
.74389 .56954 .74935 .576 .76153 .57251 .7561 .56602 Metetra
.657 .749 .918 r
.7561 .56602 .76153 .57251 .77375 .569 .76836 .56249 Metetra
.657 .749 .918 r
.76836 .56249 .77375 .569 .78603 .56548 .78068 .55894 Metetra
.657 .749 .918 r
.78068 .55894 .78603 .56548 .79836 .56195 .79305 .55538 Metetra
.657 .749 .918 r
.79305 .55538 .79836 .56195 .81075 .55839 .80547 .5518 Metetra
.657 .749 .918 r
.80547 .5518 .81075 .55839 .82319 .55483 .81795 .5482 Metetra
.657 .749 .918 r
.81795 .5482 .82319 .55483 .83568 .55124 .83048 .54459 Metetra
.657 .749 .918 r
.83048 .54459 .83568 .55124 .84822 .54765 .84306 .54096 Metetra
.657 .749 .918 r
.84306 .54096 .84822 .54765 .86082 .54403 .8557 .53732 Metetra
.657 .749 .918 r
.8557 .53732 .86082 .54403 .87348 .5404 .86839 .53366 Metetra
.657 .749 .918 r
.86839 .53366 .87348 .5404 .88619 .53676 .88114 .52999 Metetra
.657 .749 .918 r
.88114 .52999 .88619 .53676 .89895 .5331 .89395 .5263 Metetra
.657 .749 .918 r
.89395 .5263 .89895 .5331 .91177 .52942 .90681 .52259 Metetra
.657 .749 .918 r
.90681 .52259 .91177 .52942 .92465 .52573 .91973 .51887 Metetra
.657 .749 .918 r
.91973 .51887 .92465 .52573 .93758 .52202 .9327 .51513 Metetra
.657 .749 .918 r
.9327 .51513 .93758 .52202 .95057 .51829 .94574 .51137 Metetra
.657 .749 .918 r
.94574 .51137 .95057 .51829 .96362 .51455 .95883 .5076 Metetra
.657 .749 .918 r
.95883 .5076 .96362 .51455 .97673 .51079 .97197 .50381 Metetra
.657 .749 .918 r
.38306 .66594 .38954 .67167 .40028 .66857 .39383 .66282 Metetra
.657 .749 .918 r
.39383 .66282 .40028 .66857 .41107 .66546 .40464 .65969 Metetra
.657 .749 .918 r
.40464 .65969 .41107 .66546 .4219 .66234 .4155 .65655 Metetra
.657 .749 .918 r
.4155 .65655 .4219 .66234 .43277 .65921 .4264 .65339 Metetra
.657 .749 .918 r
.4264 .65339 .43277 .65921 .44369 .65606 .43735 .65022 Metetra
.657 .749 .918 r
.43735 .65022 .44369 .65606 .45465 .6529 .44834 .64704 Metetra
.657 .749 .918 r
.44834 .64704 .45465 .6529 .46566 .64973 .45937 .64384 Metetra
.657 .749 .918 r
.45937 .64384 .46566 .64973 .47671 .64654 .47045 .64063 Metetra
.657 .749 .918 r
.47045 .64063 .47671 .64654 .48781 .64335 .48158 .63741 Metetra
.657 .749 .918 r
.48158 .63741 .48781 .64335 .49895 .64014 .49275 .63417 Metetra
.657 .749 .918 r
.49275 .63417 .49895 .64014 .51013 .63691 .50397 .63092 Metetra
.657 .749 .918 r
.50397 .63092 .51013 .63691 .52137 .63367 .51523 .62766 Metetra
.657 .749 .918 r
.51523 .62766 .52137 .63367 .53265 .63042 .52654 .62439 Metetra
.657 .749 .918 r
.52654 .62439 .53265 .63042 .54397 .62716 .53789 .6211 Metetra
.657 .749 .918 r
.53789 .6211 .54397 .62716 .55534 .62388 .5493 .6178 Metetra
.657 .749 .918 r
.5493 .6178 .55534 .62388 .56676 .62059 .56075 .61448 Metetra
.657 .749 .918 r
.56075 .61448 .56676 .62059 .57823 .61729 .57225 .61115 Metetra
.657 .749 .918 r
.57225 .61115 .57823 .61729 .58974 .61397 .58379 .60781 Metetra
.657 .749 .918 r
.58379 .60781 .58974 .61397 .6013 .61064 .59538 .60445 Metetra
.657 .749 .918 r
.59538 .60445 .6013 .61064 .61291 .60729 .60703 .60108 Metetra
.657 .749 .918 r
.60703 .60108 .61291 .60729 .62457 .60393 .61872 .59769 Metetra
.657 .749 .918 r
.61872 .59769 .62457 .60393 .63628 .60056 .63046 .59429 Metetra
.657 .749 .918 r
.63046 .59429 .63628 .60056 .64803 .59717 .64225 .59088 Metetra
.657 .749 .918 r
.64225 .59088 .64803 .59717 .65984 .59377 .65409 .58745 Metetra
.657 .749 .918 r
.65409 .58745 .65984 .59377 .67169 .59035 .66597 .584 Metetra
.657 .749 .918 r
.66597 .584 .67169 .59035 .6836 .58692 .67791 .58055 Metetra
.657 .749 .918 r
.67791 .58055 .6836 .58692 .69555 .58347 .6899 .57707 Metetra
.657 .749 .918 r
.6899 .57707 .69555 .58347 .70756 .58001 .70195 .57359 Metetra
.657 .749 .918 r
.70195 .57359 .70756 .58001 .71962 .57654 .71404 .57008 Metetra
.657 .749 .918 r
.71404 .57008 .71962 .57654 .73173 .57305 .72618 .56657 Metetra
.657 .749 .918 r
.72618 .56657 .73173 .57305 .74389 .56954 .73838 .56304 Metetra
.657 .749 .918 r
.73838 .56304 .74389 .56954 .7561 .56602 .75063 .55949 Metetra
.657 .749 .918 r
.75063 .55949 .7561 .56602 .76836 .56249 .76293 .55593 Metetra
.657 .749 .918 r
.76293 .55593 .76836 .56249 .78068 .55894 .77528 .55235 Metetra
.657 .749 .918 r
.77528 .55235 .78068 .55894 .79305 .55538 .78769 .54875 Metetra
.657 .749 .918 r
.78769 .54875 .79305 .55538 .80547 .5518 .80015 .54515 Metetra
.657 .749 .918 r
.80015 .54515 .80547 .5518 .81795 .5482 .81266 .54152 Metetra
.657 .749 .918 r
.81266 .54152 .81795 .5482 .83048 .54459 .82523 .53788 Metetra
.657 .749 .918 r
.82523 .53788 .83048 .54459 .84306 .54096 .83786 .53422 Metetra
.657 .749 .918 r
.83786 .53422 .84306 .54096 .8557 .53732 .85053 .53055 Metetra
.657 .749 .918 r
.85053 .53055 .8557 .53732 .86839 .53366 .86327 .52686 Metetra
.657 .749 .918 r
.86327 .52686 .86839 .53366 .88114 .52999 .87606 .52316 Metetra
.657 .749 .918 r
.87606 .52316 .88114 .52999 .89395 .5263 .8889 .51944 Metetra
.657 .749 .918 r
.8889 .51944 .89395 .5263 .90681 .52259 .90181 .5157 Metetra
.657 .749 .918 r
.90181 .5157 .90681 .52259 .91973 .51887 .91477 .51195 Metetra
.657 .749 .918 r
.91477 .51195 .91973 .51887 .9327 .51513 .92778 .50818 Metetra
.657 .749 .918 r
.92778 .50818 .9327 .51513 .94574 .51137 .94086 .50439 Metetra
.657 .749 .918 r
.94086 .50439 .94574 .51137 .95883 .5076 .95399 .50059 Metetra
.657 .749 .918 r
.95399 .50059 .95883 .5076 .97197 .50381 .96718 .49677 Metetra
.657 .749 .918 r
.37653 .66017 .38306 .66594 .39383 .66282 .38733 .65703 Metetra
.657 .749 .918 r
.38733 .65703 .39383 .66282 .40464 .65969 .39817 .65388 Metetra
.657 .749 .918 r
.39817 .65388 .40464 .65969 .4155 .65655 .40906 .65071 Metetra
.657 .749 .918 r
.40906 .65071 .4155 .65655 .4264 .65339 .41999 .64753 Metetra
.657 .749 .918 r
.41999 .64753 .4264 .65339 .43735 .65022 .43096 .64433 Metetra
.657 .749 .918 r
.43096 .64433 .43735 .65022 .44834 .64704 .44198 .64113 Metetra
.657 .749 .918 r
.44198 .64113 .44834 .64704 .45937 .64384 .45304 .63791 Metetra
.657 .749 .918 r
.45304 .63791 .45937 .64384 .47045 .64063 .46415 .63467 Metetra
.657 .749 .918 r
.46415 .63467 .47045 .64063 .48158 .63741 .47531 .63143 Metetra
.657 .749 .918 r
.47531 .63143 .48158 .63741 .49275 .63417 .48651 .62817 Metetra
.657 .749 .918 r
.48651 .62817 .49275 .63417 .50397 .63092 .49775 .62489 Metetra
.657 .749 .918 r
.49775 .62489 .50397 .63092 .51523 .62766 .50905 .62161 Metetra
.657 .749 .918 r
.50905 .62161 .51523 .62766 .52654 .62439 .52039 .61831 Metetra
.657 .749 .918 r
.52039 .61831 .52654 .62439 .53789 .6211 .53177 .61499 Metetra
.657 .749 .918 r
.53177 .61499 .53789 .6211 .5493 .6178 .54321 .61166 Metetra
.657 .749 .918 r
.54321 .61166 .5493 .6178 .56075 .61448 .55469 .60832 Metetra
.657 .749 .918 r
.55469 .60832 .56075 .61448 .57225 .61115 .56622 .60497 Metetra
.657 .749 .918 r
.56622 .60497 .57225 .61115 .58379 .60781 .57779 .6016 Metetra
.657 .749 .918 r
.57779 .6016 .58379 .60781 .59538 .60445 .58942 .59821 Metetra
.657 .749 .918 r
.58942 .59821 .59538 .60445 .60703 .60108 .60109 .59481 Metetra
.657 .749 .918 r
.60109 .59481 .60703 .60108 .61872 .59769 .61282 .5914 Metetra
.657 .749 .918 r
.61282 .5914 .61872 .59769 .63046 .59429 .62459 .58798 Metetra
.657 .749 .918 r
.62459 .58798 .63046 .59429 .64225 .59088 .63641 .58453 Metetra
.657 .749 .918 r
.63641 .58453 .64225 .59088 .65409 .58745 .64829 .58108 Metetra
.657 .749 .918 r
.64829 .58108 .65409 .58745 .66597 .584 .66021 .57761 Metetra
.657 .749 .918 r
.66021 .57761 .66597 .584 .67791 .58055 .67218 .57412 Metetra
.657 .749 .918 r
.67218 .57412 .67791 .58055 .6899 .57707 .68421 .57062 Metetra
.657 .749 .918 r
.68421 .57062 .6899 .57707 .70195 .57359 .69629 .56711 Metetra
.657 .749 .918 r
.69629 .56711 .70195 .57359 .71404 .57008 .70841 .56358 Metetra
.657 .749 .918 r
.70841 .56358 .71404 .57008 .72618 .56657 .72059 .56003 Metetra
.657 .749 .918 r
.72059 .56003 .72618 .56657 .73838 .56304 .73283 .55647 Metetra
.657 .749 .918 r
.73283 .55647 .73838 .56304 .75063 .55949 .74511 .5529 Metetra
.657 .749 .918 r
.74511 .5529 .75063 .55949 .76293 .55593 .75745 .54931 Metetra
.657 .749 .918 r
.75745 .54931 .76293 .55593 .77528 .55235 .76984 .5457 Metetra
.657 .749 .918 r
.76984 .5457 .77528 .55235 .78769 .54875 .78228 .54208 Metetra
.657 .749 .918 r
.78228 .54208 .78769 .54875 .80015 .54515 .79478 .53844 Metetra
.657 .749 .918 r
.79478 .53844 .80015 .54515 .81266 .54152 .80734 .53479 Metetra
.657 .749 .918 r
.80734 .53479 .81266 .54152 .82523 .53788 .81994 .53112 Metetra
.657 .749 .918 r
.81994 .53112 .82523 .53788 .83786 .53422 .83261 .52743 Metetra
.657 .749 .918 r
.83261 .52743 .83786 .53422 .85053 .53055 .84533 .52373 Metetra
.657 .749 .918 r
.84533 .52373 .85053 .53055 .86327 .52686 .8581 .52001 Metetra
.657 .749 .918 r
.8581 .52001 .86327 .52686 .87606 .52316 .87093 .51628 Metetra
.657 .749 .918 r
.87093 .51628 .87606 .52316 .8889 .51944 .88382 .51253 Metetra
.657 .749 .918 r
.88382 .51253 .8889 .51944 .90181 .5157 .89676 .50876 Metetra
.657 .749 .918 r
.89676 .50876 .90181 .5157 .91477 .51195 .90976 .50498 Metetra
.657 .749 .918 r
.90976 .50498 .91477 .51195 .92778 .50818 .92282 .50118 Metetra
.657 .749 .918 r
.92282 .50118 .92778 .50818 .94086 .50439 .93594 .49736 Metetra
.657 .749 .918 r
.93594 .49736 .94086 .50439 .95399 .50059 .94912 .49352 Metetra
.657 .749 .918 r
.94912 .49352 .95399 .50059 .96718 .49677 .96235 .48967 Metetra
.657 .749 .918 r
.36996 .65436 .37653 .66017 .38733 .65703 .38078 .6512 Metetra
.657 .749 .918 r
.38078 .6512 .38733 .65703 .39817 .65388 .39165 .64802 Metetra
.657 .749 .918 r
.39165 .64802 .39817 .65388 .40906 .65071 .40257 .64482 Metetra
.657 .749 .918 r
.40257 .64482 .40906 .65071 .41999 .64753 .41352 .64162 Metetra
.657 .749 .918 r
.41352 .64162 .41999 .64753 .43096 .64433 .42452 .6384 Metetra
.657 .749 .918 r
.42452 .6384 .43096 .64433 .44198 .64113 .43557 .63517 Metetra
.657 .749 .918 r
.43557 .63517 .44198 .64113 .45304 .63791 .44666 .63193 Metetra
.657 .749 .918 r
.44666 .63193 .45304 .63791 .46415 .63467 .4578 .62867 Metetra
.657 .749 .918 r
.4578 .62867 .46415 .63467 .47531 .63143 .46899 .6254 Metetra
.657 .749 .918 r
.46899 .6254 .47531 .63143 .48651 .62817 .48022 .62211 Metetra
.657 .749 .918 r
.48022 .62211 .48651 .62817 .49775 .62489 .49149 .61881 Metetra
.657 .749 .918 r
.49149 .61881 .49775 .62489 .50905 .62161 .50281 .6155 Metetra
.657 .749 .918 r
.50281 .6155 .50905 .62161 .52039 .61831 .51418 .61218 Metetra
.657 .749 .918 r
.51418 .61218 .52039 .61831 .53177 .61499 .5256 .60884 Metetra
.657 .749 .918 r
.5256 .60884 .53177 .61499 .54321 .61166 .53707 .60548 Metetra
.657 .749 .918 r
.53707 .60548 .54321 .61166 .55469 .60832 .54858 .60212 Metetra
.657 .749 .918 r
.54858 .60212 .55469 .60832 .56622 .60497 .56014 .59873 Metetra
.657 .749 .918 r
.56014 .59873 .56622 .60497 .57779 .6016 .57175 .59534 Metetra
.657 .749 .918 r
.57175 .59534 .57779 .6016 .58942 .59821 .58341 .59193 Metetra
.657 .749 .918 r
.58341 .59193 .58942 .59821 .60109 .59481 .59512 .5885 Metetra
.657 .749 .918 r
.59512 .5885 .60109 .59481 .61282 .5914 .60687 .58507 Metetra
.657 .749 .918 r
.60687 .58507 .61282 .5914 .62459 .58798 .61868 .58161 Metetra
.657 .749 .918 r
.61868 .58161 .62459 .58798 .63641 .58453 .63054 .57814 Metetra
.657 .749 .918 r
.63054 .57814 .63641 .58453 .64829 .58108 .64244 .57466 Metetra
.657 .749 .918 r
.64244 .57466 .64829 .58108 .66021 .57761 .6544 .57116 Metetra
.657 .749 .918 r
.6544 .57116 .66021 .57761 .67218 .57412 .66641 .56765 Metetra
.657 .749 .918 r
.66641 .56765 .67218 .57412 .68421 .57062 .67847 .56412 Metetra
.657 .749 .918 r
.67847 .56412 .68421 .57062 .69629 .56711 .69058 .56058 Metetra
.657 .749 .918 r
.69058 .56058 .69629 .56711 .70841 .56358 .70274 .55702 Metetra
.657 .749 .918 r
.70274 .55702 .70841 .56358 .72059 .56003 .71496 .55345 Metetra
.657 .749 .918 r
.71496 .55345 .72059 .56003 .73283 .55647 .72723 .54986 Metetra
.657 .749 .918 r
.72723 .54986 .73283 .55647 .74511 .5529 .73955 .54626 Metetra
.657 .749 .918 r
.73955 .54626 .74511 .5529 .75745 .54931 .75193 .54264 Metetra
.657 .749 .918 r
.75193 .54264 .75745 .54931 .76984 .5457 .76436 .539 Metetra
.657 .749 .918 r
.76436 .539 .76984 .5457 .78228 .54208 .77684 .53535 Metetra
.657 .749 .918 r
.77684 .53535 .78228 .54208 .79478 .53844 .78938 .53168 Metetra
.657 .749 .918 r
.78938 .53168 .79478 .53844 .80734 .53479 .80197 .528 Metetra
.657 .749 .918 r
.80197 .528 .80734 .53479 .81994 .53112 .81462 .5243 Metetra
.657 .749 .918 r
.81462 .5243 .81994 .53112 .83261 .52743 .82732 .52059 Metetra
.657 .749 .918 r
.82732 .52059 .83261 .52743 .84533 .52373 .84008 .51685 Metetra
.657 .749 .918 r
.84008 .51685 .84533 .52373 .8581 .52001 .85289 .51311 Metetra
.657 .749 .918 r
.85289 .51311 .8581 .52001 .87093 .51628 .86576 .50934 Metetra
.657 .749 .918 r
.86576 .50934 .87093 .51628 .88382 .51253 .87869 .50556 Metetra
.657 .749 .918 r
.87869 .50556 .88382 .51253 .89676 .50876 .89168 .50176 Metetra
.657 .749 .918 r
.89168 .50176 .89676 .50876 .90976 .50498 .90472 .49795 Metetra
.657 .749 .918 r
.90472 .49795 .90976 .50498 .92282 .50118 .91782 .49411 Metetra
.657 .749 .918 r
.91782 .49411 .92282 .50118 .93594 .49736 .93098 .49026 Metetra
.657 .749 .918 r
.93098 .49026 .93594 .49736 .94912 .49352 .9442 .4864 Metetra
.657 .749 .918 r
.9442 .4864 .94912 .49352 .96235 .48967 .95748 .48251 Metetra
.657 .749 .918 r
.36334 .64851 .36996 .65436 .38078 .6512 .37419 .64532 Metetra
.657 .749 .918 r
.37419 .64532 .38078 .6512 .39165 .64802 .38508 .64211 Metetra
.657 .749 .918 r
.38508 .64211 .39165 .64802 .40257 .64482 .39602 .6389 Metetra
.657 .749 .918 r
.39602 .6389 .40257 .64482 .41352 .64162 .40701 .63567 Metetra
.657 .749 .918 r
.40701 .63567 .41352 .64162 .42452 .6384 .41804 .63243 Metetra
.657 .749 .918 r
.41804 .63243 .42452 .6384 .43557 .63517 .42911 .62917 Metetra
.657 .749 .918 r
.42911 .62917 .43557 .63517 .44666 .63193 .44024 .6259 Metetra
.657 .749 .918 r
.44024 .6259 .44666 .63193 .4578 .62867 .4514 .62262 Metetra
.657 .749 .918 r
.4514 .62262 .4578 .62867 .46899 .6254 .46262 .61932 Metetra
.657 .749 .918 r
.46262 .61932 .46899 .6254 .48022 .62211 .47388 .61601 Metetra
.657 .749 .918 r
.47388 .61601 .48022 .62211 .49149 .61881 .48518 .61269 Metetra
.657 .749 .918 r
.48518 .61269 .49149 .61881 .50281 .6155 .49654 .60935 Metetra
.657 .749 .918 r
.49654 .60935 .50281 .6155 .51418 .61218 .50794 .606 Metetra
.657 .749 .918 r
.50794 .606 .51418 .61218 .5256 .60884 .51938 .60263 Metetra
.657 .749 .918 r
.51938 .60263 .5256 .60884 .53707 .60548 .53088 .59926 Metetra
.657 .749 .918 r
.53088 .59926 .53707 .60548 .54858 .60212 .54242 .59586 Metetra
.657 .749 .918 r
.54242 .59586 .54858 .60212 .56014 .59873 .55402 .59245 Metetra
.657 .749 .918 r
.55402 .59245 .56014 .59873 .57175 .59534 .56566 .58903 Metetra
.657 .749 .918 r
.56566 .58903 .57175 .59534 .58341 .59193 .57735 .5856 Metetra
.657 .749 .918 r
.57735 .5856 .58341 .59193 .59512 .5885 .58909 .58214 Metetra
.657 .749 .918 r
.58909 .58214 .59512 .5885 .60687 .58507 .60088 .57868 Metetra
.657 .749 .918 r
.60088 .57868 .60687 .58507 .61868 .58161 .61272 .5752 Metetra
.657 .749 .918 r
.61272 .5752 .61868 .58161 .63054 .57814 .62461 .5717 Metetra
.657 .749 .918 r
.62461 .5717 .63054 .57814 .64244 .57466 .63655 .56819 Metetra
.657 .749 .918 r
.63655 .56819 .64244 .57466 .6544 .57116 .64855 .56467 Metetra
.657 .749 .918 r
.64855 .56467 .6544 .57116 .66641 .56765 .66059 .56113 Metetra
.657 .749 .918 r
.66059 .56113 .66641 .56765 .67847 .56412 .67268 .55757 Metetra
.657 .749 .918 r
.67268 .55757 .67847 .56412 .69058 .56058 .68483 .554 Metetra
.657 .749 .918 r
.68483 .554 .69058 .56058 .70274 .55702 .69703 .55041 Metetra
.657 .749 .918 r
.69703 .55041 .70274 .55702 .71496 .55345 .70928 .54681 Metetra
.657 .749 .918 r
.70928 .54681 .71496 .55345 .72723 .54986 .72159 .5432 Metetra
.657 .749 .918 r
.72159 .5432 .72723 .54986 .73955 .54626 .73395 .53956 Metetra
.657 .749 .918 r
.73395 .53956 .73955 .54626 .75193 .54264 .74636 .53591 Metetra
.657 .749 .918 r
.74636 .53591 .75193 .54264 .76436 .539 .75883 .53225 Metetra
.657 .749 .918 r
.75883 .53225 .76436 .539 .77684 .53535 .77135 .52857 Metetra
.657 .749 .918 r
.77135 .52857 .77684 .53535 .78938 .53168 .78392 .52487 Metetra
.657 .749 .918 r
.78392 .52487 .78938 .53168 .80197 .528 .79656 .52116 Metetra
.657 .749 .918 r
.79656 .52116 .80197 .528 .81462 .5243 .80924 .51743 Metetra
.657 .749 .918 r
.80924 .51743 .81462 .5243 .82732 .52059 .82199 .51368 Metetra
.657 .749 .918 r
.82199 .51368 .82732 .52059 .84008 .51685 .83478 .50992 Metetra
.657 .749 .918 r
.83478 .50992 .84008 .51685 .85289 .51311 .84764 .50614 Metetra
.657 .749 .918 r
.84764 .50614 .85289 .51311 .86576 .50934 .86055 .50235 Metetra
.657 .749 .918 r
.86055 .50235 .86576 .50934 .87869 .50556 .87352 .49853 Metetra
.657 .749 .918 r
.87352 .49853 .87869 .50556 .89168 .50176 .88655 .4947 Metetra
.657 .749 .918 r
.88655 .4947 .89168 .50176 .90472 .49795 .89964 .49086 Metetra
.657 .749 .918 r
.89964 .49086 .90472 .49795 .91782 .49411 .91278 .48699 Metetra
.657 .749 .918 r
.91278 .48699 .91782 .49411 .93098 .49026 .92598 .48311 Metetra
.657 .749 .918 r
.92598 .48311 .93098 .49026 .9442 .4864 .93925 .47921 Metetra
.657 .749 .918 r
.93925 .47921 .9442 .4864 .95748 .48251 .95257 .4753 Metetra
.657 .749 .918 r
.35666 .64261 .36334 .64851 .37419 .64532 .36754 .63939 Metetra
.657 .749 .918 r
.36754 .63939 .37419 .64532 .38508 .64211 .37846 .63617 Metetra
.657 .749 .918 r
.37846 .63617 .38508 .64211 .39602 .6389 .38943 .63293 Metetra
.657 .749 .918 r
.38943 .63293 .39602 .6389 .40701 .63567 .40045 .62967 Metetra
.657 .749 .918 r
.40045 .62967 .40701 .63567 .41804 .63243 .4115 .6264 Metetra
.657 .749 .918 r
.4115 .6264 .41804 .63243 .42911 .62917 .42261 .62312 Metetra
.657 .749 .918 r
.42261 .62312 .42911 .62917 .44024 .6259 .43376 .61983 Metetra
.657 .749 .918 r
.43376 .61983 .44024 .6259 .4514 .62262 .44496 .61652 Metetra
.657 .749 .918 r
.44496 .61652 .4514 .62262 .46262 .61932 .4562 .6132 Metetra
.657 .749 .918 r
.4562 .6132 .46262 .61932 .47388 .61601 .46749 .60987 Metetra
.657 .749 .918 r
.46749 .60987 .47388 .61601 .48518 .61269 .47882 .60652 Metetra
.657 .749 .918 r
.47882 .60652 .48518 .61269 .49654 .60935 .49021 .60315 Metetra
.657 .749 .918 r
.49021 .60315 .49654 .60935 .50794 .606 .50164 .59978 Metetra
.657 .749 .918 r
.50164 .59978 .50794 .606 .51938 .60263 .51312 .59638 Metetra
.657 .749 .918 r
.51312 .59638 .51938 .60263 .53088 .59926 .52465 .59298 Metetra
.657 .749 .918 r
.52465 .59298 .53088 .59926 .54242 .59586 .53622 .58956 Metetra
.657 .749 .918 r
.53622 .58956 .54242 .59586 .55402 .59245 .54785 .58612 Metetra
.657 .749 .918 r
.54785 .58612 .55402 .59245 .56566 .58903 .55952 .58268 Metetra
.657 .749 .918 r
.55952 .58268 .56566 .58903 .57735 .5856 .57125 .57921 Metetra
.657 .749 .918 r
.57125 .57921 .57735 .5856 .58909 .58214 .58302 .57573 Metetra
.657 .749 .918 r
.58302 .57573 .58909 .58214 .60088 .57868 .59484 .57224 Metetra
.657 .749 .918 r
.59484 .57224 .60088 .57868 .61272 .5752 .60672 .56873 Metetra
.657 .749 .918 r
.60672 .56873 .61272 .5752 .62461 .5717 .61864 .56521 Metetra
.657 .749 .918 r
.61864 .56521 .62461 .5717 .63655 .56819 .63062 .56167 Metetra
.657 .749 .918 r
.63062 .56167 .63655 .56819 .64855 .56467 .64264 .55812 Metetra
.657 .749 .918 r
.64264 .55812 .64855 .56467 .66059 .56113 .65472 .55455 Metetra
.657 .749 .918 r
.65472 .55455 .66059 .56113 .67268 .55757 .66685 .55097 Metetra
.657 .749 .918 r
.66685 .55097 .67268 .55757 .68483 .554 .67904 .54737 Metetra
.657 .749 .918 r
.67904 .54737 .68483 .554 .69703 .55041 .69127 .54375 Metetra
.657 .749 .918 r
.69127 .54375 .69703 .55041 .70928 .54681 .70356 .54012 Metetra
.657 .749 .918 r
.70356 .54012 .70928 .54681 .72159 .5432 .7159 .53648 Metetra
.657 .749 .918 r
.7159 .53648 .72159 .5432 .73395 .53956 .7283 .53281 Metetra
.657 .749 .918 r
.7283 .53281 .73395 .53956 .74636 .53591 .74075 .52914 Metetra
.657 .749 .918 r
.74075 .52914 .74636 .53591 .75883 .53225 .75325 .52544 Metetra
.657 .749 .918 r
.75325 .52544 .75883 .53225 .77135 .52857 .76581 .52173 Metetra
.657 .749 .918 r
.76581 .52173 .77135 .52857 .78392 .52487 .77843 .518 Metetra
.657 .749 .918 r
.77843 .518 .78392 .52487 .79656 .52116 .7911 .51426 Metetra
.657 .749 .918 r
.7911 .51426 .79656 .52116 .80924 .51743 .80383 .5105 Metetra
.657 .749 .918 r
.80383 .5105 .80924 .51743 .82199 .51368 .81661 .50672 Metetra
.657 .749 .918 r
.81661 .50672 .82199 .51368 .83478 .50992 .82945 .50293 Metetra
.657 .749 .918 r
.82945 .50293 .83478 .50992 .84764 .50614 .84234 .49912 Metetra
.657 .749 .918 r
.84234 .49912 .84764 .50614 .86055 .50235 .8553 .49529 Metetra
.657 .749 .918 r
.8553 .49529 .86055 .50235 .87352 .49853 .86831 .49145 Metetra
.657 .749 .918 r
.86831 .49145 .87352 .49853 .88655 .4947 .88138 .48759 Metetra
.657 .749 .918 r
.88138 .48759 .88655 .4947 .89964 .49086 .89451 .48371 Metetra
.657 .749 .918 r
.89451 .48371 .89964 .49086 .91278 .48699 .9077 .47981 Metetra
.657 .749 .918 r
.9077 .47981 .91278 .48699 .92598 .48311 .92094 .4759 Metetra
.657 .749 .918 r
.92094 .4759 .92598 .48311 .93925 .47921 .93425 .47197 Metetra
.657 .749 .918 r
.93425 .47197 .93925 .47921 .95257 .4753 .94762 .46802 Metetra
.657 .749 .918 r
.34994 .63666 .35666 .64261 .36754 .63939 .36084 .63342 Metetra
.657 .749 .918 r
.36084 .63342 .36754 .63939 .37846 .63617 .37179 .63017 Metetra
.657 .749 .918 r
.37179 .63017 .37846 .63617 .38943 .63293 .38279 .62691 Metetra
.657 .749 .918 r
.38279 .62691 .38943 .63293 .40045 .62967 .39383 .62363 Metetra
.657 .749 .918 r
.39383 .62363 .40045 .62967 .4115 .6264 .40492 .62034 Metetra
.657 .749 .918 r
.40492 .62034 .4115 .6264 .42261 .62312 .41605 .61703 Metetra
.657 .749 .918 r
.41605 .61703 .42261 .62312 .43376 .61983 .42723 .61371 Metetra
.657 .749 .918 r
.42723 .61371 .43376 .61983 .44496 .61652 .43846 .61038 Metetra
.657 .749 .918 r
.43846 .61038 .44496 .61652 .4562 .6132 .44973 .60703 Metetra
.657 .749 .918 r
.44973 .60703 .4562 .6132 .46749 .60987 .46105 .60367 Metetra
.657 .749 .918 r
.46105 .60367 .46749 .60987 .47882 .60652 .47242 .6003 Metetra
.657 .749 .918 r
.47242 .6003 .47882 .60652 .49021 .60315 .48383 .59691 Metetra
.657 .749 .918 r
.48383 .59691 .49021 .60315 .50164 .59978 .49529 .5935 Metetra
.657 .749 .918 r
.49529 .5935 .50164 .59978 .51312 .59638 .5068 .59009 Metetra
.657 .749 .918 r
.5068 .59009 .51312 .59638 .52465 .59298 .51836 .58665 Metetra
.657 .749 .918 r
.51836 .58665 .52465 .59298 .53622 .58956 .52997 .58321 Metetra
.657 .749 .918 r
.52997 .58321 .53622 .58956 .54785 .58612 .54163 .57975 Metetra
.657 .749 .918 r
.54163 .57975 .54785 .58612 .55952 .58268 .55334 .57627 Metetra
.657 .749 .918 r
.55334 .57627 .55952 .58268 .57125 .57921 .56509 .57278 Metetra
.657 .749 .918 r
.56509 .57278 .57125 .57921 .58302 .57573 .5769 .56927 Metetra
.657 .749 .918 r
.5769 .56927 .58302 .57573 .59484 .57224 .58876 .56575 Metetra
.657 .749 .918 r
.58876 .56575 .59484 .57224 .60672 .56873 .60066 .56222 Metetra
.657 .749 .918 r
.60066 .56222 .60672 .56873 .61864 .56521 .61262 .55867 Metetra
.657 .749 .918 r
.61262 .55867 .61864 .56521 .63062 .56167 .62463 .5551 Metetra
.657 .749 .918 r
.62463 .5551 .63062 .56167 .64264 .55812 .63669 .55152 Metetra
.657 .749 .918 r
.63669 .55152 .64264 .55812 .65472 .55455 .64881 .54792 Metetra
.657 .749 .918 r
.64881 .54792 .65472 .55455 .66685 .55097 .66097 .54431 Metetra
.657 .749 .918 r
.66097 .54431 .66685 .55097 .67904 .54737 .67319 .54068 Metetra
.657 .749 .918 r
.67319 .54068 .67904 .54737 .69127 .54375 .68547 .53704 Metetra
.657 .749 .918 r
.68547 .53704 .69127 .54375 .70356 .54012 .69779 .53338 Metetra
.657 .749 .918 r
.69779 .53338 .70356 .54012 .7159 .53648 .71017 .5297 Metetra
.657 .749 .918 r
.71017 .5297 .7159 .53648 .7283 .53281 .72261 .52601 Metetra
.657 .749 .918 r
.72261 .52601 .7283 .53281 .74075 .52914 .73509 .5223 Metetra
.657 .749 .918 r
.73509 .5223 .74075 .52914 .75325 .52544 .74764 .51858 Metetra
.657 .749 .918 r
.74764 .51858 .75325 .52544 .76581 .52173 .76024 .51484 Metetra
.657 .749 .918 r
.76024 .51484 .76581 .52173 .77843 .518 .77289 .51108 Metetra
.657 .749 .918 r
.77289 .51108 .77843 .518 .7911 .51426 .7856 .50731 Metetra
.657 .749 .918 r
.7856 .50731 .7911 .51426 .80383 .5105 .79837 .50352 Metetra
.657 .749 .918 r
.79837 .50352 .80383 .5105 .81661 .50672 .81119 .49971 Metetra
.657 .749 .918 r
.81119 .49971 .81661 .50672 .82945 .50293 .82407 .49588 Metetra
.657 .749 .918 r
.82407 .49588 .82945 .50293 .84234 .49912 .83701 .49204 Metetra
.657 .749 .918 r
.83701 .49204 .84234 .49912 .8553 .49529 .85 .48818 Metetra
.657 .749 .918 r
.85 .48818 .8553 .49529 .86831 .49145 .86305 .48431 Metetra
.657 .749 .918 r
.86305 .48431 .86831 .49145 .88138 .48759 .87617 .48042 Metetra
.657 .749 .918 r
.87617 .48042 .88138 .48759 .89451 .48371 .88934 .4765 Metetra
.657 .749 .918 r
.88934 .4765 .89451 .48371 .9077 .47981 .90257 .47258 Metetra
.657 .749 .918 r
.90257 .47258 .9077 .47981 .92094 .4759 .91586 .46863 Metetra
.657 .749 .918 r
.91586 .46863 .92094 .4759 .93425 .47197 .92921 .46467 Metetra
.657 .749 .918 r
.92921 .46467 .93425 .47197 .94762 .46802 .94262 .46068 Metetra
.657 .749 .918 r
.34316 .63067 .34994 .63666 .36084 .63342 .3541 .62741 Metetra
.657 .749 .918 r
.3541 .62741 .36084 .63342 .37179 .63017 .36508 .62413 Metetra
.657 .749 .918 r
.36508 .62413 .37179 .63017 .38279 .62691 .3761 .62085 Metetra
.657 .749 .918 r
.3761 .62085 .38279 .62691 .39383 .62363 .38717 .61754 Metetra
.657 .749 .918 r
.38717 .61754 .39383 .62363 .40492 .62034 .39829 .61422 Metetra
.657 .749 .918 r
.39829 .61422 .40492 .62034 .41605 .61703 .40945 .61089 Metetra
.657 .749 .918 r
.40945 .61089 .41605 .61703 .42723 .61371 .42066 .60755 Metetra
.657 .749 .918 r
.42066 .60755 .42723 .61371 .43846 .61038 .43191 .60419 Metetra
.657 .749 .918 r
.43191 .60419 .43846 .61038 .44973 .60703 .44321 .60082 Metetra
.657 .749 .918 r
.44321 .60082 .44973 .60703 .46105 .60367 .45456 .59743 Metetra
.657 .749 .918 r
.45456 .59743 .46105 .60367 .47242 .6003 .46596 .59403 Metetra
.657 .749 .918 r
.46596 .59403 .47242 .6003 .48383 .59691 .47741 .59061 Metetra
.657 .749 .918 r
.47741 .59061 .48383 .59691 .49529 .5935 .4889 .58718 Metetra
.657 .749 .918 r
.4889 .58718 .49529 .5935 .5068 .59009 .50044 .58374 Metetra
.657 .749 .918 r
.50044 .58374 .5068 .59009 .51836 .58665 .51203 .58028 Metetra
.657 .749 .918 r
.51203 .58028 .51836 .58665 .52997 .58321 .52367 .57681 Metetra
.657 .749 .918 r
.52367 .57681 .52997 .58321 .54163 .57975 .53536 .57332 Metetra
.657 .749 .918 r
.53536 .57332 .54163 .57975 .55334 .57627 .5471 .56981 Metetra
.657 .749 .918 r
.5471 .56981 .55334 .57627 .56509 .57278 .55889 .5663 Metetra
.657 .749 .918 r
.55889 .5663 .56509 .57278 .5769 .56927 .57073 .56276 Metetra
.657 .749 .918 r
.57073 .56276 .5769 .56927 .58876 .56575 .58262 .55921 Metetra
.657 .749 .918 r
.58262 .55921 .58876 .56575 .60066 .56222 .59456 .55565 Metetra
.657 .749 .918 r
.59456 .55565 .60066 .56222 .61262 .55867 .60656 .55207 Metetra
.657 .749 .918 r
.60656 .55207 .61262 .55867 .62463 .5551 .6186 .54848 Metetra
.657 .749 .918 r
.6186 .54848 .62463 .5551 .63669 .55152 .6307 .54487 Metetra
.657 .749 .918 r
.6307 .54487 .63669 .55152 .64881 .54792 .64285 .54124 Metetra
.657 .749 .918 r
.64285 .54124 .64881 .54792 .66097 .54431 .65505 .5376 Metetra
.657 .749 .918 r
.65505 .5376 .66097 .54431 .67319 .54068 .66731 .53394 Metetra
.657 .749 .918 r
.66731 .53394 .67319 .54068 .68547 .53704 .67961 .53027 Metetra
.657 .749 .918 r
.67961 .53027 .68547 .53704 .69779 .53338 .69198 .52658 Metetra
.657 .749 .918 r
.69198 .52658 .69779 .53338 .71017 .5297 .70439 .52287 Metetra
.657 .749 .918 r
.70439 .52287 .71017 .5297 .72261 .52601 .71687 .51915 Metetra
.657 .749 .918 r
.71687 .51915 .72261 .52601 .73509 .5223 .72939 .51541 Metetra
.657 .749 .918 r
.72939 .51541 .73509 .5223 .74764 .51858 .74197 .51166 Metetra
.657 .749 .918 r
.74197 .51166 .74764 .51858 .76024 .51484 .75461 .50789 Metetra
.657 .749 .918 r
.75461 .50789 .76024 .51484 .77289 .51108 .7673 .5041 Metetra
.657 .749 .918 r
.7673 .5041 .77289 .51108 .7856 .50731 .78005 .5003 Metetra
.657 .749 .918 r
.78005 .5003 .7856 .50731 .79837 .50352 .79286 .49647 Metetra
.657 .749 .918 r
.79286 .49647 .79837 .50352 .81119 .49971 .80572 .49264 Metetra
.657 .749 .918 r
.80572 .49264 .81119 .49971 .82407 .49588 .81864 .48878 Metetra
.657 .749 .918 r
.81864 .48878 .82407 .49588 .83701 .49204 .83162 .48491 Metetra
.657 .749 .918 r
.83162 .48491 .83701 .49204 .85 .48818 .84466 .48102 Metetra
.657 .749 .918 r
.84466 .48102 .85 .48818 .86305 .48431 .85776 .47711 Metetra
.657 .749 .918 r
.85776 .47711 .86305 .48431 .87617 .48042 .87091 .47318 Metetra
.657 .749 .918 r
.87091 .47318 .87617 .48042 .88934 .4765 .88412 .46924 Metetra
.657 .749 .918 r
.88412 .46924 .88934 .4765 .90257 .47258 .8974 .46528 Metetra
.657 .749 .918 r
.8974 .46528 .90257 .47258 .91586 .46863 .91073 .4613 Metetra
.657 .749 .918 r
.91073 .4613 .91586 .46863 .92921 .46467 .92413 .4573 Metetra
.657 .749 .918 r
.92413 .4573 .92921 .46467 .94262 .46068 .93758 .45328 Metetra
.657 .749 .918 r
.33634 .62464 .34316 .63067 .3541 .62741 .3473 .62135 Metetra
.657 .749 .918 r
.3473 .62135 .3541 .62741 .36508 .62413 .3583 .61805 Metetra
.657 .749 .918 r
.3583 .61805 .36508 .62413 .3761 .62085 .36936 .61474 Metetra
.657 .749 .918 r
.36936 .61474 .3761 .62085 .38717 .61754 .38045 .61141 Metetra
.657 .749 .918 r
.38045 .61141 .38717 .61754 .39829 .61422 .3916 .60806 Metetra
.657 .749 .918 r
.3916 .60806 .39829 .61422 .40945 .61089 .40279 .60471 Metetra
.657 .749 .918 r
.40279 .60471 .40945 .61089 .42066 .60755 .41403 .60134 Metetra
.657 .749 .918 r
.41403 .60134 .42066 .60755 .43191 .60419 .42531 .59795 Metetra
.657 .749 .918 r
.42531 .59795 .43191 .60419 .44321 .60082 .43665 .59455 Metetra
.657 .749 .918 r
.43665 .59455 .44321 .60082 .45456 .59743 .44803 .59114 Metetra
.657 .749 .918 r
.44803 .59114 .45456 .59743 .46596 .59403 .45945 .58771 Metetra
.657 .749 .918 r
.45945 .58771 .46596 .59403 .47741 .59061 .47093 .58427 Metetra
.657 .749 .918 r
.47093 .58427 .47741 .59061 .4889 .58718 .48245 .58081 Metetra
.657 .749 .918 r
.48245 .58081 .4889 .58718 .50044 .58374 .49403 .57734 Metetra
.657 .749 .918 r
.49403 .57734 .50044 .58374 .51203 .58028 .50565 .57386 Metetra
.657 .749 .918 r
.50565 .57386 .51203 .58028 .52367 .57681 .51732 .57035 Metetra
.657 .749 .918 r
.51732 .57035 .52367 .57681 .53536 .57332 .52904 .56684 Metetra
.657 .749 .918 r
.52904 .56684 .53536 .57332 .5471 .56981 .54082 .56331 Metetra
.657 .749 .918 r
.54082 .56331 .5471 .56981 .55889 .5663 .55264 .55976 Metetra
.657 .749 .918 r
.55264 .55976 .55889 .5663 .57073 .56276 .56451 .5562 Metetra
.657 .749 .918 r
.56451 .5562 .57073 .56276 .58262 .55921 .57644 .55262 Metetra
.657 .749 .918 r
.57644 .55262 .58262 .55921 .59456 .55565 .58841 .54903 Metetra
.657 .749 .918 r
.58841 .54903 .59456 .55565 .60656 .55207 .60044 .54542 Metetra
.657 .749 .918 r
.60044 .54542 .60656 .55207 .6186 .54848 .61252 .5418 Metetra
.657 .749 .918 r
.61252 .5418 .6186 .54848 .6307 .54487 .62465 .53816 Metetra
.657 .749 .918 r
.62465 .53816 .6307 .54487 .64285 .54124 .63684 .53451 Metetra
.657 .749 .918 r
.63684 .53451 .64285 .54124 .65505 .5376 .64908 .53084 Metetra
.657 .749 .918 r
.64908 .53084 .65505 .5376 .66731 .53394 .66137 .52715 Metetra
.657 .749 .918 r
.66137 .52715 .66731 .53394 .67961 .53027 .67371 .52345 Metetra
.657 .749 .918 r
.67371 .52345 .67961 .53027 .69198 .52658 .68611 .51973 Metetra
.657 .749 .918 r
.68611 .51973 .69198 .52658 .70439 .52287 .69857 .51599 Metetra
.657 .749 .918 r
.69857 .51599 .70439 .52287 .71687 .51915 .71108 .51224 Metetra
.657 .749 .918 r
.71108 .51224 .71687 .51915 .72939 .51541 .72364 .50847 Metetra
.657 .749 .918 r
.72364 .50847 .72939 .51541 .74197 .51166 .73626 .50468 Metetra
.657 .749 .918 r
.73626 .50468 .74197 .51166 .75461 .50789 .74894 .50088 Metetra
.657 .749 .918 r
.74894 .50088 .75461 .50789 .7673 .5041 .76167 .49706 Metetra
.657 .749 .918 r
.76167 .49706 .7673 .5041 .78005 .5003 .77446 .49323 Metetra
.657 .749 .918 r
.77446 .49323 .78005 .5003 .79286 .49647 .78731 .48937 Metetra
.657 .749 .918 r
.78731 .48937 .79286 .49647 .80572 .49264 .80021 .4855 Metetra
.657 .749 .918 r
.80021 .4855 .80572 .49264 .81864 .48878 .81317 .48162 Metetra
.657 .749 .918 r
.81317 .48162 .81864 .48878 .83162 .48491 .82619 .47771 Metetra
.657 .749 .918 r
.82619 .47771 .83162 .48491 .84466 .48102 .83927 .47379 Metetra
.657 .749 .918 r
.83927 .47379 .84466 .48102 .85776 .47711 .85241 .46985 Metetra
.657 .749 .918 r
.85241 .46985 .85776 .47711 .87091 .47318 .86561 .46589 Metetra
.657 .749 .918 r
.86561 .46589 .87091 .47318 .88412 .46924 .87887 .46191 Metetra
.657 .749 .918 r
.87887 .46191 .88412 .46924 .8974 .46528 .89219 .45792 Metetra
.657 .749 .918 r
.89219 .45792 .8974 .46528 .91073 .4613 .90556 .4539 Metetra
.657 .749 .918 r
.90556 .4539 .91073 .4613 .92413 .4573 .919 .44987 Metetra
.657 .749 .918 r
.919 .44987 .92413 .4573 .93758 .45328 .93251 .44582 Metetra
.657 .749 .918 r
.32946 .61856 .33634 .62464 .3473 .62135 .34045 .61525 Metetra
.657 .749 .918 r
.34045 .61525 .3473 .62135 .3583 .61805 .35148 .61192 Metetra
.657 .749 .918 r
.35148 .61192 .3583 .61805 .36936 .61474 .36256 .60858 Metetra
.657 .749 .918 r
.36256 .60858 .36936 .61474 .38045 .61141 .37369 .60522 Metetra
.657 .749 .918 r
.37369 .60522 .38045 .61141 .3916 .60806 .38486 .60186 Metetra
.657 .749 .918 r
.38486 .60186 .3916 .60806 .40279 .60471 .39608 .59847 Metetra
.657 .749 .918 r
.39608 .59847 .40279 .60471 .41403 .60134 .40735 .59508 Metetra
.657 .749 .918 r
.40735 .59508 .41403 .60134 .42531 .59795 .41866 .59167 Metetra
.657 .749 .918 r
.41866 .59167 .42531 .59795 .43665 .59455 .43003 .58824 Metetra
.657 .749 .918 r
.43003 .58824 .43665 .59455 .44803 .59114 .44144 .5848 Metetra
.657 .749 .918 r
.44144 .5848 .44803 .59114 .45945 .58771 .45289 .58135 Metetra
.657 .749 .918 r
.45289 .58135 .45945 .58771 .47093 .58427 .4644 .57788 Metetra
.657 .749 .918 r
.4644 .57788 .47093 .58427 .48245 .58081 .47596 .57439 Metetra
.657 .749 .918 r
.47596 .57439 .48245 .58081 .49403 .57734 .48756 .57089 Metetra
.657 .749 .918 r
.48756 .57089 .49403 .57734 .50565 .57386 .49922 .56738 Metetra
.657 .749 .918 r
.49922 .56738 .50565 .57386 .51732 .57035 .51092 .56385 Metetra
.657 .749 .918 r
.51092 .56385 .51732 .57035 .52904 .56684 .52268 .56031 Metetra
.657 .749 .918 r
.52268 .56031 .52904 .56684 .54082 .56331 .53448 .55675 Metetra
.657 .749 .918 r
.53448 .55675 .54082 .56331 .55264 .55976 .54634 .55317 Metetra
.657 .749 .918 r
.54634 .55317 .55264 .55976 .56451 .5562 .55825 .54958 Metetra
.657 .749 .918 r
.55825 .54958 .56451 .5562 .57644 .55262 .5702 .54598 Metetra
.657 .749 .918 r
.5702 .54598 .57644 .55262 .58841 .54903 .58221 .54236 Metetra
.657 .749 .918 r
.58221 .54236 .58841 .54903 .60044 .54542 .59428 .53872 Metetra
.657 .749 .918 r
.59428 .53872 .60044 .54542 .61252 .5418 .60639 .53507 Metetra
.657 .749 .918 r
.60639 .53507 .61252 .5418 .62465 .53816 .61856 .5314 Metetra
.657 .749 .918 r
.61856 .5314 .62465 .53816 .63684 .53451 .63078 .52772 Metetra
.657 .749 .918 r
.63078 .52772 .63684 .53451 .64908 .53084 .64306 .52402 Metetra
.657 .749 .918 r
.64306 .52402 .64908 .53084 .66137 .52715 .65538 .5203 Metetra
.657 .749 .918 r
.65538 .5203 .66137 .52715 .67371 .52345 .66777 .51657 Metetra
.657 .749 .918 r
.66777 .51657 .67371 .52345 .68611 .51973 .6802 .51282 Metetra
.657 .749 .918 r
.6802 .51282 .68611 .51973 .69857 .51599 .6927 .50905 Metetra
.657 .749 .918 r
.6927 .50905 .69857 .51599 .71108 .51224 .70524 .50527 Metetra
.657 .749 .918 r
.70524 .50527 .71108 .51224 .72364 .50847 .71785 .50147 Metetra
.657 .749 .918 r
.71785 .50147 .72364 .50847 .73626 .50468 .73051 .49765 Metetra
.657 .749 .918 r
.73051 .49765 .73626 .50468 .74894 .50088 .74322 .49382 Metetra
.657 .749 .918 r
.74322 .49382 .74894 .50088 .76167 .49706 .75599 .48997 Metetra
.657 .749 .918 r
.75599 .48997 .76167 .49706 .77446 .49323 .76882 .4861 Metetra
.657 .749 .918 r
.76882 .4861 .77446 .49323 .78731 .48937 .78171 .48221 Metetra
.657 .749 .918 r
.78171 .48221 .78731 .48937 .80021 .4855 .79466 .47831 Metetra
.657 .749 .918 r
.79466 .47831 .80021 .4855 .81317 .48162 .80766 .47439 Metetra
.657 .749 .918 r
.80766 .47439 .81317 .48162 .82619 .47771 .82072 .47045 Metetra
.657 .749 .918 r
.82072 .47045 .82619 .47771 .83927 .47379 .83384 .4665 Metetra
.657 .749 .918 r
.83384 .4665 .83927 .47379 .85241 .46985 .84702 .46252 Metetra
.657 .749 .918 r
.84702 .46252 .85241 .46985 .86561 .46589 .86027 .45853 Metetra
.657 .749 .918 r
.86027 .45853 .86561 .46589 .87887 .46191 .87357 .45452 Metetra
.657 .749 .918 r
.87357 .45452 .87887 .46191 .89219 .45792 .88693 .45049 Metetra
.657 .749 .918 r
.88693 .45049 .89219 .45792 .90556 .4539 .90035 .44645 Metetra
.657 .749 .918 r
.90035 .44645 .90556 .4539 .919 .44987 .91384 .44238 Metetra
.657 .749 .918 r
.91384 .44238 .919 .44987 .93251 .44582 .92738 .4383 Metetra
.652 .748 .92 r
.32253 .61243 .32946 .61856 .34045 .61525 .33353 .60924 Metetra
.665 .756 .918 r
.33353 .60924 .34045 .61525 .35148 .61192 .34461 .60566 Metetra
.682 .753 .905 r
.34461 .60566 .35148 .61192 .36256 .60858 .35575 .60157 Metetra
.689 .733 .884 r
.35575 .60157 .36256 .60858 .37369 .60522 .36696 .59714 Metetra
.689 .706 .861 r
.36696 .59714 .37369 .60522 .38486 .60186 .3782 .59251 Metetra
.685 .678 .838 r
.3782 .59251 .38486 .60186 .39608 .59847 .3895 .58782 Metetra
.678 .652 .817 r
.3895 .58782 .39608 .59847 .40735 .59508 .40082 .58314 Metetra
.67 .629 .8 r
.40082 .58314 .40735 .59508 .41866 .59167 .41219 .57855 Metetra
.662 .61 .785 r
.41219 .57855 .41866 .59167 .43003 .58824 .42359 .57408 Metetra
.655 .594 .774 r
.42359 .57408 .43003 .58824 .44144 .5848 .43503 .56977 Metetra
.649 .582 .766 r
.43503 .56977 .44144 .5848 .45289 .58135 .4465 .56564 Metetra
.644 .573 .76 r
.4465 .56564 .45289 .58135 .4644 .57788 .45802 .56168 Metetra
.639 .566 .756 r
.45802 .56168 .4644 .57788 .47596 .57439 .46958 .55788 Metetra
.636 .562 .754 r
.46958 .55788 .47596 .57439 .48756 .57089 .48118 .55423 Metetra
.633 .559 .754 r
.48118 .55423 .48756 .57089 .49922 .56738 .49283 .55071 Metetra
.631 .559 .754 r
.49283 .55071 .49922 .56738 .51092 .56385 .50453 .54728 Metetra
.63 .559 .756 r
.50453 .54728 .51092 .56385 .52268 .56031 .51628 .54393 Metetra
.63 .561 .759 r
.51628 .54393 .52268 .56031 .53448 .55675 .52809 .54061 Metetra
.63 .564 .762 r
.52809 .54061 .53448 .55675 .54634 .55317 .53995 .53731 Metetra
.631 .568 .765 r
.53995 .53731 .54634 .55317 .55825 .54958 .55186 .53399 Metetra
.632 .571 .768 r
.55186 .53399 .55825 .54958 .5702 .54598 .56382 .53063 Metetra
.634 .575 .771 r
.56382 .53063 .5702 .54598 .58221 .54236 .57584 .5272 Metetra
.636 .579 .773 r
.57584 .5272 .58221 .54236 .59428 .53872 .58791 .52369 Metetra
.638 .581 .775 r
.58791 .52369 .59428 .53872 .60639 .53507 .60003 .5201 Metetra
.639 .583 .776 r
.60003 .5201 .60639 .53507 .61856 .5314 .6122 .5164 Metetra
.641 .584 .775 r
.6122 .5164 .61856 .5314 .63078 .52772 .62443 .5126 Metetra
.642 .584 .774 r
.62443 .5126 .63078 .52772 .64306 .52402 .6367 .50871 Metetra
.643 .583 .772 r
.6367 .50871 .64306 .52402 .65538 .5203 .64903 .50473 Metetra
.643 .581 .77 r
.64903 .50473 .65538 .5203 .66777 .51657 .6614 .50069 Metetra
.642 .578 .767 r
.6614 .50069 .66777 .51657 .6802 .51282 .67383 .49659 Metetra
.642 .574 .763 r
.67383 .49659 .6802 .51282 .6927 .50905 .68631 .49247 Metetra
.64 .57 .76 r
.68631 .49247 .6927 .50905 .70524 .50527 .69884 .48835 Metetra
.639 .567 .757 r
.69884 .48835 .70524 .50527 .71785 .50147 .71143 .48426 Metetra
.637 .563 .755 r
.71143 .48426 .71785 .50147 .73051 .49765 .72408 .48023 Metetra
.635 .561 .754 r
.72408 .48023 .73051 .49765 .74322 .49382 .73679 .47629 Metetra
.632 .559 .754 r
.73679 .47629 .74322 .49382 .75599 .48997 .74956 .47248 Metetra
.63 .558 .755 r
.74956 .47248 .75599 .48997 .76882 .4861 .76241 .46881 Metetra
.628 .559 .758 r
.76241 .46881 .76882 .4861 .78171 .48221 .77533 .4653 Metetra
.626 .562 .763 r
.77533 .4653 .78171 .48221 .79466 .47831 .78832 .46197 Metetra
.624 .567 .77 r
.78832 .46197 .79466 .47831 .80766 .47439 .8014 .45882 Metetra
.622 .575 .78 r
.8014 .45882 .80766 .47439 .82072 .47045 .81456 .45584 Metetra
.621 .586 .793 r
.81456 .45584 .82072 .47045 .83384 .4665 .8278 .453 Metetra
.621 .601 .809 r
.8278 .453 .83384 .4665 .84702 .46252 .84112 .45027 Metetra
.621 .621 .829 r
.84112 .45027 .84702 .46252 .86027 .45853 .85452 .44757 Metetra
.623 .646 .852 r
.85452 .44757 .86027 .45853 .87357 .45452 .86799 .44483 Metetra
.627 .676 .877 r
.86799 .44483 .87357 .45452 .88693 .45049 .88151 .44192 Metetra
.634 .708 .9 r
.88151 .44192 .88693 .45049 .90035 .44645 .89507 .4387 Metetra
.646 .738 .916 r
.89507 .4387 .90035 .44645 .91384 .44238 .90864 .43498 Metetra
.662 .756 .92 r
.90864 .43498 .91384 .44238 .92738 .4383 .92222 .43071 Metetra
.654 .749 .919 r
.31554 .60626 .32253 .61243 .33353 .60924 .32658 .60299 Metetra
.669 .751 .912 r
.32658 .60299 .33353 .60924 .34461 .60566 .33769 .59928 Metetra
.705 .755 .891 r
.33769 .59928 .34461 .60566 .35575 .60157 .34891 .59435 Metetra
.719 .736 .864 r
.34891 .59435 .35575 .60157 .36696 .59714 .3602 .58862 Metetra
.72 .706 .837 r
.3602 .58862 .36696 .59714 .3782 .59251 .37154 .58245 Metetra
.712 .675 .812 r
.37154 .58245 .3782 .59251 .3895 .58782 .38292 .5761 Metetra
.7 .645 .791 r
.38292 .5761 .3895 .58782 .40082 .58314 .39432 .5698 Metetra
.688 .619 .774 r
.39432 .5698 .40082 .58314 .41219 .57855 .40575 .5637 Metetra
.675 .597 .76 r
.40575 .5637 .41219 .57855 .42359 .57408 .41719 .55791 Metetra
.664 .579 .749 r
.41719 .55791 .42359 .57408 .43503 .56977 .42866 .5525 Metetra
.654 .564 .742 r
.42866 .5525 .43503 .56977 .4465 .56564 .44015 .5475 Metetra
.645 .553 .736 r
.44015 .5475 .4465 .56564 .45802 .56168 .45167 .54292 Metetra
.637 .544 .733 r
.45167 .54292 .45802 .56168 .46958 .55788 .46323 .53873 Metetra
.631 .538 .731 r
.46323 .53873 .46958 .55788 .48118 .55423 .47482 .53491 Metetra
.626 .535 .731 r
.47482 .53491 .48118 .55423 .49283 .55071 .48646 .53139 Metetra
.622 .533 .732 r
.48646 .53139 .49283 .55071 .50453 .54728 .49815 .52811 Metetra
.62 .533 .734 r
.49815 .52811 .50453 .54728 .51628 .54393 .50989 .52502 Metetra
.619 .534 .737 r
.50989 .52502 .51628 .54393 .52809 .54061 .52168 .52204 Metetra
.618 .537 .74 r
.52168 .52204 .52809 .54061 .53995 .53731 .53353 .51911 Metetra
.619 .541 .744 r
.53353 .51911 .53995 .53731 .55186 .53399 .54544 .51615 Metetra
.621 .545 .747 r
.54544 .51615 .55186 .53399 .56382 .53063 .5574 .51312 Metetra
.624 .55 .751 r
.5574 .51312 .56382 .53063 .57584 .5272 .56942 .50996 Metetra
.627 .554 .753 r
.56942 .50996 .57584 .5272 .58791 .52369 .58149 .50664 Metetra
.63 .558 .755 r
.58149 .50664 .58791 .52369 .60003 .5201 .59361 .50312 Metetra
.634 .561 .755 r
.59361 .50312 .60003 .5201 .6122 .5164 .60578 .4994 Metetra
.637 .563 .755 r
.60578 .4994 .6122 .5164 .62443 .5126 .618 .49547 Metetra
.639 .563 .753 r
.618 .49547 .62443 .5126 .6367 .50871 .63027 .49133 Metetra
.641 .562 .751 r
.63027 .49133 .6367 .50871 .64903 .50473 .64258 .48702 Metetra
.642 .56 .747 r
.64258 .48702 .64903 .50473 .6614 .50069 .65494 .48257 Metetra
.642 .557 .744 r
.65494 .48257 .6614 .50069 .67383 .49659 .66734 .47803 Metetra
.641 .554 .741 r
.66734 .47803 .67383 .49659 .68631 .49247 .67979 .47344 Metetra
.639 .549 .737 r
.67979 .47344 .68631 .49247 .69884 .48835 .6923 .46889 Metetra
.637 .545 .734 r
.6923 .46889 .69884 .48835 .71143 .48426 .70486 .46442 Metetra
.633 .541 .732 r
.70486 .46442 .71143 .48426 .72408 .48023 .71748 .46012 Metetra
.629 .537 .731 r
.71748 .46012 .72408 .48023 .73679 .47629 .73017 .45605 Metetra
.625 .534 .731 r
.73017 .45605 .73679 .47629 .74956 .47248 .74294 .45228 Metetra
.62 .532 .733 r
.74294 .45228 .74956 .47248 .76241 .46881 .7558 .44886 Metetra
.615 .531 .736 r
.7558 .44886 .76241 .46881 .77533 .4653 .76874 .44584 Metetra
.609 .531 .742 r
.76874 .44584 .77533 .4653 .78832 .46197 .78179 .44325 Metetra
.603 .534 .75 r
.78179 .44325 .78832 .46197 .8014 .45882 .79495 .4411 Metetra
.598 .54 .761 r
.79495 .4411 .8014 .45882 .81456 .45584 .80821 .43935 Metetra
.592 .549 .776 r
.80821 .43935 .81456 .45584 .8278 .453 .82159 .43796 Metetra
.587 .563 .795 r
.82159 .43796 .8278 .453 .84112 .45027 .83508 .43681 Metetra
.583 .583 .818 r
.83508 .43681 .84112 .45027 .85452 .44757 .84866 .43576 Metetra
.583 .611 .846 r
.84866 .43576 .85452 .44757 .86799 .44483 .86232 .43461 Metetra
.588 .646 .876 r
.86232 .43461 .86799 .44483 .88151 .44192 .87602 .43307 Metetra
.604 .689 .902 r
.87602 .43307 .88151 .44192 .89507 .4387 .88973 .4308 Metetra
.636 .731 .917 r
.88973 .4308 .89507 .4387 .90864 .43498 .90339 .42737 Metetra
.662 .752 .917 r
.90339 .42737 .90864 .43498 .92222 .43071 .91701 .42305 Metetra
.657 .749 .918 r
.3085 .60004 .31554 .60626 .32658 .60299 .31958 .59665 Metetra
.669 .749 .91 r
.31958 .59665 .32658 .60299 .33769 .59928 .33071 .59291 Metetra
.721 .759 .883 r
.33071 .59291 .33769 .59928 .34891 .59435 .342 .5873 Metetra
.745 .746 .853 r
.342 .5873 .34891 .59435 .3602 .58862 .35338 .58039 Metetra
.748 .72 .826 r
.35338 .58039 .3602 .58862 .37154 .58245 .36482 .57273 Metetra
.74 .69 .803 r
.36482 .57273 .37154 .58245 .38292 .5761 .37629 .56478 Metetra
.727 .661 .785 r
.37629 .56478 .38292 .5761 .39432 .5698 .38777 .55688 Metetra
.712 .635 .77 r
.38777 .55688 .39432 .5698 .40575 .5637 .39927 .54929 Metetra
.696 .612 .758 r
.39927 .54929 .40575 .5637 .41719 .55791 .41077 .5422 Metetra
.681 .592 .749 r
.41077 .5422 .41719 .55791 .42866 .5525 .42227 .5357 Metetra
.667 .576 .743 r
.42227 .5357 .42866 .5525 .44015 .5475 .43378 .52985 Metetra
.654 .562 .739 r
.43378 .52985 .44015 .5475 .45167 .54292 .44531 .52466 Metetra
.643 .552 .736 r
.44531 .52466 .45167 .54292 .46323 .53873 .45687 .5201 Metetra
.634 .544 .735 r
.45687 .5201 .46323 .53873 .47482 .53491 .46846 .51612 Metetra
.626 .539 .736 r
.46846 .51612 .47482 .53491 .48646 .53139 .48009 .51262 Metetra
.62 .536 .737 r
.48009 .51262 .48646 .53139 .49815 .52811 .49176 .50953 Metetra
.616 .535 .74 r
.49176 .50953 .49815 .52811 .50989 .52502 .50349 .50672 Metetra
.613 .536 .743 r
.50349 .50672 .50989 .52502 .52168 .52204 .51527 .5041 Metetra
.613 .539 .747 r
.51527 .5041 .52168 .52204 .53353 .51911 .52711 .50156 Metetra
.614 .543 .751 r
.52711 .50156 .53353 .51911 .54544 .51615 .53901 .49899 Metetra
.616 .548 .755 r
.53901 .49899 .54544 .51615 .5574 .51312 .55097 .49631 Metetra
.62 .554 .759 r
.55097 .49631 .5574 .51312 .56942 .50996 .56299 .49344 Metetra
.625 .56 .761 r
.56299 .49344 .56942 .50996 .58149 .50664 .57506 .49031 Metetra
.63 .565 .763 r
.57506 .49031 .58149 .50664 .59361 .50312 .58719 .48688 Metetra
.635 .569 .763 r
.58719 .48688 .59361 .50312 .60578 .4994 .59936 .48313 Metetra
.641 .572 .762 r
.59936 .48313 .60578 .4994 .618 .49547 .61158 .47905 Metetra
.645 .573 .76 r
.61158 .47905 .618 .49547 .63027 .49133 .62384 .47467 Metetra
.648 .573 .757 r
.62384 .47467 .63027 .49133 .64258 .48702 .63614 .47001 Metetra
.65 .571 .753 r
.63614 .47001 .64258 .48702 .65494 .48257 .64849 .46514 Metetra
.65 .568 .749 r
.64849 .46514 .65494 .48257 .66734 .47803 .66087 .46013 Metetra
.649 .564 .745 r
.66087 .46013 .66734 .47803 .67979 .47344 .6733 .45506 Metetra
.647 .559 .741 r
.6733 .45506 .67979 .47344 .6923 .46889 .68578 .45004 Metetra
.643 .554 .738 r
.68578 .45004 .6923 .46889 .70486 .46442 .69832 .44517 Metetra
.638 .548 .736 r
.69832 .44517 .70486 .46442 .71748 .46012 .71092 .44058 Metetra
.632 .543 .735 r
.71092 .44058 .71748 .46012 .73017 .45605 .72359 .43635 Metetra
.625 .538 .736 r
.72359 .43635 .73017 .45605 .74294 .45228 .73636 .4326 Metetra
.617 .534 .738 r
.73636 .4326 .74294 .45228 .7558 .44886 .74922 .42943 Metetra
.608 .531 .742 r
.74922 .42943 .7558 .44886 .76874 .44584 .76219 .42689 Metetra
.598 .529 .748 r
.76219 .42689 .76874 .44584 .78179 .44325 .77529 .42502 Metetra
.587 .529 .757 r
.77529 .42502 .78179 .44325 .79495 .4411 .78852 .42385 Metetra
.575 .532 .769 r
.78852 .42385 .79495 .4411 .80821 .43935 .80189 .42332 Metetra
.563 .538 .785 r
.80189 .42332 .80821 .43935 .82159 .43796 .8154 .42335 Metetra
.551 .55 .806 r
.8154 .42335 .82159 .43796 .83508 .43681 .82905 .42376 Metetra
.542 .568 .831 r
.82905 .42376 .83508 .43681 .84866 .43576 .84281 .42432 Metetra
.538 .595 .859 r
.84281 .42432 .84866 .43576 .86232 .43461 .85665 .42469 Metetra
.546 .633 .889 r
.85665 .42469 .86232 .43461 .87602 .43307 .87052 .42442 Metetra
.576 .682 .913 r
.87052 .42442 .87602 .43307 .88973 .4308 .88436 .42294 Metetra
.633 .733 .92 r
.88436 .42294 .88973 .4308 .90339 .42737 .89807 .41956 Metetra
.659 .746 .915 r
.89807 .41956 .90339 .42737 .91701 .42305 .91175 .41533 Metetra
.657 .749 .918 r
.30141 .59377 .3085 .60004 .31958 .59665 .31251 .59035 Metetra
.668 .752 .913 r
.31251 .59035 .31958 .59665 .33071 .59291 .32368 .5866 Metetra
.732 .765 .879 r
.32368 .5866 .33071 .59291 .342 .5873 .33502 .58053 Metetra
.765 .757 .845 r
.33502 .58053 .342 .5873 .35338 .58039 .34649 .57257 Metetra
.772 .734 .818 r
.34649 .57257 .35338 .58039 .36482 .57273 .35803 .56353 Metetra
.765 .706 .797 r
.35803 .56353 .36482 .57273 .37629 .56478 .3696 .55403 Metetra
.752 .679 .78 r
.3696 .55403 .37629 .56478 .38777 .55688 .38117 .54459 Metetra
.735 .652 .768 r
.38117 .54459 .38777 .55688 .39927 .54929 .39274 .53555 Metetra
.717 .628 .758 r
.39274 .53555 .39927 .54929 .41077 .5422 .4043 .52717 Metetra
.698 .607 .751 r
.4043 .52717 .41077 .5422 .42227 .5357 .41584 .5196 Metetra
.681 .589 .746 r
.41584 .5196 .42227 .5357 .43378 .52985 .42738 .51293 Metetra
.665 .574 .743 r
.42738 .51293 .43378 .52985 .44531 .52466 .43893 .50716 Metetra
.65 .562 .741 r
.43893 .50716 .44531 .52466 .45687 .5201 .45049 .50226 Metetra
.638 .552 .742 r
.45049 .50226 .45687 .5201 .46846 .51612 .46207 .49815 Metetra
.627 .545 .743 r
.46207 .49815 .46846 .51612 .48009 .51262 .47369 .49471 Metetra
.618 .541 .746 r
.47369 .49471 .48009 .51262 .49176 .50953 .48535 .49183 Metetra
.612 .54 .749 r
.48535 .49183 .49176 .50953 .50349 .50672 .49707 .48935 Metetra
.607 .541 .754 r
.49707 .48935 .50349 .50672 .51527 .5041 .50884 .48712 Metetra
.606 .544 .758 r
.50884 .48712 .51527 .5041 .52711 .50156 .52068 .485 Metetra
.607 .549 .763 r
.52068 .485 .52711 .50156 .53901 .49899 .53258 .48285 Metetra
.61 .555 .768 r
.53258 .48285 .53901 .49899 .55097 .49631 .54454 .48055 Metetra
.616 .562 .772 r
.54454 .48055 .55097 .49631 .56299 .49344 .55656 .47798 Metetra
.623 .57 .774 r
.55656 .47798 .56299 .49344 .57506 .49031 .56864 .47506 Metetra
.63 .577 .776 r
.56864 .47506 .57506 .49031 .58719 .48688 .58077 .47173 Metetra
.638 .582 .775 r
.58077 .47173 .58719 .48688 .59936 .48313 .59295 .46796 Metetra
.646 .587 .774 r
.59295 .46796 .59936 .48313 .61158 .47905 .60517 .46374 Metetra
.652 .589 .771 r
.60517 .46374 .61158 .47905 .62384 .47467 .61743 .45909 Metetra
.657 .589 .767 r
.61743 .45909 .62384 .47467 .63614 .47001 .62973 .45407 Metetra
.66 .587 .762 r
.62973 .45407 .63614 .47001 .64849 .46514 .64206 .44875 Metetra
.661 .583 .757 r
.64206 .44875 .64849 .46514 .66087 .46013 .65443 .44324 Metetra
.66 .579 .753 r
.65443 .44324 .66087 .46013 .6733 .45506 .66684 .43766 Metetra
.657 .573 .749 r
.66684 .43766 .6733 .45506 .68578 .45004 .6793 .43214 Metetra
.652 .566 .745 r
.6793 .43214 .68578 .45004 .69832 .44517 .69182 .42684 Metetra
.645 .559 .743 r
.69182 .42684 .69832 .44517 .71092 .44058 .7044 .42191 Metetra
.637 .552 .742 r
.7044 .42191 .71092 .44058 .72359 .43635 .71706 .4175 Metetra
.626 .545 .743 r
.71706 .4175 .72359 .43635 .73636 .4326 .72982 .41375 Metetra
.615 .539 .746 r
.72982 .41375 .73636 .4326 .74922 .42943 .74269 .41078 Metetra
.601 .533 .75 r
.74269 .41078 .74922 .42943 .76219 .42689 .75569 .40869 Metetra
.586 .529 .757 r
.75569 .40869 .76219 .42689 .77529 .42502 .76884 .40753 Metetra
.569 .526 .767 r
.76884 .40753 .77529 .42502 .78852 .42385 .78214 .40731 Metetra
.55 .525 .781 r
.78214 .40731 .78852 .42385 .80189 .42332 .79561 .40797 Metetra
.53 .528 .798 r
.79561 .40797 .80189 .42332 .8154 .42335 .80925 .40938 Metetra
.509 .536 .819 r
.80925 .40938 .8154 .42335 .82905 .42376 .82305 .41131 Metetra
.492 .552 .845 r
.82305 .41131 .82905 .42376 .84281 .42432 .83698 .41342 Metetra
.485 .579 .874 r
.83698 .41342 .84281 .42432 .85665 .42469 .85099 .41522 Metetra
.499 .622 .903 r
.85099 .41522 .85665 .42469 .87052 .42442 .86502 .41608 Metetra
.549 .68 .925 r
.86502 .41608 .87052 .42442 .88436 .42294 .87897 .41521 Metetra
.633 .738 .924 r
.87897 .41521 .88436 .42294 .89807 .41956 .89272 .41177 Metetra
.657 .748 .917 r
.89272 .41177 .89807 .41956 .91175 .41533 .90645 .40755 Metetra
.657 .749 .918 r
.29426 .58745 .30141 .59377 .31251 .59035 .30539 .584 Metetra
.662 .751 .916 r
.30539 .584 .31251 .59035 .32368 .5866 .31657 .58042 Metetra
.738 .77 .879 r
.31657 .58042 .32368 .5866 .33502 .58053 .32796 .57412 Metetra
.782 .768 .84 r
.32796 .57412 .33502 .58053 .34649 .57257 .33952 .56529 Metetra
.793 .749 .812 r
.33952 .56529 .34649 .57257 .35803 .56353 .35116 .55498 Metetra
.788 .724 .792 r
.35116 .55498 .35803 .56353 .3696 .55403 .36283 .54403 Metetra
.775 .697 .777 r
.36283 .54403 .3696 .55403 .38117 .54459 .37451 .5331 Metetra
.757 .671 .767 r
.37451 .5331 .38117 .54459 .39274 .53555 .38616 .52266 Metetra
.737 .647 .759 r
.38616 .52266 .39274 .53555 .4043 .52717 .39778 .51304 Metetra
.717 .625 .754 r
.39778 .51304 .4043 .52717 .41584 .5196 .40937 .50445 Metetra
.696 .606 .751 r
.40937 .50445 .41584 .5196 .42738 .51293 .42094 .49699 Metetra
.677 .589 .75 r
.42094 .49699 .42738 .51293 .43893 .50716 .4325 .49068 Metetra
.658 .575 .75 r
.4325 .49068 .43893 .50716 .45049 .50226 .44407 .48547 Metetra
.642 .563 .751 r
.44407 .48547 .45049 .50226 .46207 .49815 .45565 .48128 Metetra
.627 .555 .754 r
.45565 .48128 .46207 .49815 .47369 .49471 .46727 .47794 Metetra
.615 .55 .758 r
.46727 .47794 .47369 .49471 .48535 .49183 .47892 .47531 Metetra
.606 .548 .763 r
.47892 .47531 .48535 .49183 .49707 .48935 .49063 .47319 Metetra
.6 .549 .768 r
.49063 .47319 .49707 .48935 .50884 .48712 .5024 .4714 Metetra
.598 .552 .775 r
.5024 .4714 .50884 .48712 .52068 .485 .51423 .46975 Metetra
.599 .558 .781 r
.51423 .46975 .52068 .485 .53258 .48285 .52613 .46806 Metetra
.603 .567 .786 r
.52613 .46806 .53258 .48285 .54454 .48055 .53809 .46616 Metetra
.611 .576 .791 r
.53809 .46616 .54454 .48055 .55656 .47798 .55012 .46393 Metetra
.62 .586 .793 r
.55012 .46393 .55656 .47798 .56864 .47506 .56221 .46124 Metetra
.631 .595 .795 r
.56221 .46124 .56864 .47506 .58077 .47173 .57435 .45802 Metetra
.643 .603 .794 r
.57435 .45802 .58077 .47173 .59295 .46796 .58654 .45422 Metetra
.653 .608 .791 r
.58654 .45422 .59295 .46796 .60517 .46374 .59877 .44984 Metetra
.662 .611 .787 r
.59877 .44984 .60517 .46374 .61743 .45909 .61104 .44492 Metetra
.669 .611 .781 r
.61104 .44492 .61743 .45909 .62973 .45407 .62334 .43951 Metetra
.673 .609 .775 r
.62334 .43951 .62973 .45407 .64206 .44875 .63567 .43372 Metetra
.675 .605 .769 r
.63567 .43372 .64206 .44875 .65443 .44324 .64803 .42767 Metetra
.674 .599 .764 r
.64803 .42767 .65443 .44324 .66684 .43766 .66043 .42154 Metetra
.67 .592 .759 r
.66043 .42154 .66684 .43766 .6793 .43214 .67287 .41549 Metetra
.663 .584 .756 r
.67287 .41549 .6793 .43214 .69182 .42684 .68537 .40972 Metetra
.654 .575 .753 r
.68537 .40972 .69182 .42684 .7044 .42191 .69793 .40442 Metetra
.643 .566 .753 r
.69793 .40442 .7044 .42191 .71706 .4175 .71058 .39978 Metetra
.629 .556 .754 r
.71058 .39978 .71706 .4175 .72982 .41375 .72334 .39598 Metetra
.613 .547 .757 r
.72334 .39598 .72982 .41375 .74269 .41078 .73622 .39319 Metetra
.594 .539 .762 r
.73622 .39319 .74269 .41078 .75569 .40869 .74925 .3915 Metetra
.573 .531 .77 r
.74925 .3915 .75569 .40869 .76884 .40753 .76244 .39101 Metetra
.548 .524 .781 r
.76244 .39101 .76884 .40753 .78214 .40731 .77582 .3917 Metetra
.52 .519 .795 r
.77582 .3917 .78214 .40731 .79561 .40797 .78939 .39352 Metetra
.489 .517 .813 r
.78939 .39352 .79561 .40797 .80925 .40938 .80315 .39627 Metetra
.458 .521 .835 r
.80315 .39627 .80925 .40938 .82305 .41131 .8171 .39965 Metetra
.432 .534 .86 r
.8171 .39965 .82305 .41131 .83698 .41342 .83118 .40321 Metetra
.423 .561 .889 r
.83118 .40321 .83698 .41342 .85099 .41522 .84536 .40633 Metetra
.448 .611 .918 r
.84536 .40633 .85099 .41522 .86502 .41608 .85952 .40816 Metetra
.527 .683 .937 r
.85952 .40816 .86502 .41608 .87897 .41521 .87356 .40765 Metetra
.64 .749 .928 r
.87356 .40765 .87897 .41521 .89272 .41177 .88733 .40395 Metetra
.657 .749 .918 r
.88733 .40395 .89272 .41177 .90645 .40755 .90111 .39969 Metetra
.657 .749 .918 r
.28706 .58108 .29426 .58745 .30539 .584 .29821 .57761 Metetra
.657 .749 .918 r
.29821 .57761 .30539 .584 .31657 .58042 .30942 .57412 Metetra
.73 .767 .882 r
.30942 .57412 .31657 .58042 .32796 .57412 .32082 .56811 Metetra
.795 .78 .839 r
.32082 .56811 .32796 .57412 .33952 .56529 .33246 .55861 Metetra
.812 .764 .808 r
.33246 .55861 .33952 .56529 .35116 .55498 .3442 .54719 Metetra
.81 .741 .788 r
.3442 .54719 .35116 .55498 .36283 .54403 .35598 .53491 Metetra
.797 .716 .775 r
.35598 .53491 .36283 .54403 .37451 .5331 .36776 .52257 Metetra
.779 .692 .767 r
.36776 .52257 .37451 .5331 .38616 .52266 .3795 .5108 Metetra
.758 .668 .762 r
.3795 .5108 .38616 .52266 .39778 .51304 .39119 .5 Metetra
.736 .646 .759 r
.39119 .5 .39778 .51304 .40937 .50445 .40284 .49043 Metetra
.712 .625 .758 r
.40284 .49043 .40937 .50445 .42094 .49699 .41445 .48223 Metetra
.689 .607 .759 r
.41445 .48223 .42094 .49699 .4325 .49068 .42603 .47543 Metetra
.667 .591 .761 r
.42603 .47543 .4325 .49068 .44407 .48547 .43761 .46997 Metetra
.646 .578 .764 r
.43761 .46997 .44407 .48547 .45565 .48128 .44919 .46573 Metetra
.627 .569 .769 r
.44919 .46573 .45565 .48128 .46727 .47794 .4608 .46255 Metetra
.611 .562 .775 r
.4608 .46255 .46727 .47794 .47892 .47531 .47245 .46022 Metetra
.599 .559 .782 r
.47245 .46022 .47892 .47531 .49063 .47319 .48416 .45852 Metetra
.59 .56 .789 r
.48416 .45852 .49063 .47319 .5024 .4714 .49592 .45721 Metetra
.586 .565 .797 r
.49592 .45721 .5024 .4714 .51423 .46975 .50775 .45607 Metetra
.587 .573 .805 r
.50775 .45607 .51423 .46975 .52613 .46806 .51966 .45488 Metetra
.593 .584 .812 r
.51966 .45488 .52613 .46806 .53809 .46616 .53163 .45343 Metetra
.603 .596 .817 r
.53163 .45343 .53809 .46616 .55012 .46393 .54367 .45155 Metetra
.617 .609 .821 r
.54367 .45155 .55012 .46393 .56221 .46124 .55578 .44911 Metetra
.632 .621 .821 r
.55578 .44911 .56221 .46124 .57435 .45802 .56794 .44601 Metetra
.648 .631 .819 r
.56794 .44601 .57435 .45802 .58654 .45422 .58014 .4422 Metetra
.663 .638 .815 r
.58014 .4422 .58654 .45422 .59877 .44984 .59239 .43766 Metetra
.675 .642 .809 r
.59239 .43766 .59877 .44984 .61104 .44492 .60467 .43244 Metetra
.685 .642 .801 r
.60467 .43244 .61104 .44492 .62334 .43951 .61698 .42662 Metetra
.69 .639 .793 r
.61698 .42662 .62334 .43951 .63567 .43372 .62931 .42032 Metetra
.692 .634 .786 r
.62931 .42032 .63567 .43372 .64803 .42767 .64167 .41371 Metetra
.691 .626 .779 r
.64167 .41371 .64803 .42767 .66043 .42154 .65406 .40698 Metetra
.686 .617 .773 r
.65406 .40698 .66043 .42154 .67287 .41549 .66649 .40035 Metetra
.678 .607 .769 r
.66649 .40035 .67287 .41549 .68537 .40972 .67898 .39406 Metetra
.666 .596 .767 r
.67898 .39406 .68537 .40972 .69793 .40442 .69153 .38834 Metetra
.652 .584 .766 r
.69153 .38834 .69793 .40442 .71058 .39978 .70417 .38342 Metetra
.634 .572 .768 r
.70417 .38342 .71058 .39978 .72334 .39598 .71692 .37953 Metetra
.613 .56 .771 r
.71692 .37953 .72334 .39598 .73622 .39319 .72982 .37686 Metetra
.587 .548 .778 r
.72982 .37686 .73622 .39319 .74925 .3915 .74287 .37554 Metetra
.557 .536 .787 r
.74287 .37554 .74925 .3915 .76244 .39101 .75612 .37566 Metetra
.523 .524 .798 r
.75612 .37566 .76244 .39101 .77582 .3917 .76957 .37722 Metetra
.482 .513 .813 r
.76957 .37722 .77582 .3917 .78939 .39352 .78323 .38013 Metetra
.438 .505 .83 r
.78323 .38013 .78939 .39352 .80315 .39627 .79712 .38415 Metetra
.393 .502 .851 r
.79712 .38415 .80315 .39627 .8171 .39965 .8112 .38891 Metetra
.357 .511 .874 r
.8112 .38891 .8171 .39965 .83118 .40321 .82543 .39382 Metetra
.348 .54 .901 r
.82543 .39382 .83118 .40321 .84536 .40633 .83975 .39811 Metetra
.393 .602 .931 r
.83975 .39811 .84536 .40633 .85952 .40816 .85403 .40071 Metetra
.514 .693 .95 r
.85403 .40071 .85952 .40816 .87356 .40765 .86812 .40028 Metetra
.654 .763 .929 r
.86812 .40028 .87356 .40765 .88733 .40395 .88189 .39607 Metetra
.657 .749 .918 r
.88189 .39607 .88733 .40395 .90111 .39969 .89571 .39177 Metetra
.657 .749 .918 r
.2798 .57466 .28706 .58108 .29821 .57761 .29098 .57116 Metetra
.657 .749 .918 r
.29098 .57116 .29821 .57761 .30942 .57412 .30222 .56765 Metetra
.707 .76 .893 r
.30222 .56765 .30942 .57412 .32082 .56811 .3136 .5625 Metetra
.805 .791 .84 r
.3136 .5625 .32082 .56811 .33246 .55861 .3253 .55259 Metetra
.828 .779 .805 r
.3253 .55259 .33246 .55861 .3442 .54719 .33714 .54024 Metetra
.829 .759 .785 r
.33714 .54024 .3442 .54719 .35598 .53491 .34903 .52675 Metetra
.819 .736 .774 r
.34903 .52675 .35598 .53491 .36776 .52257 .36091 .51313 Metetra
.801 .713 .768 r
.36091 .51313 .36776 .52257 .3795 .5108 .37275 .5001 Metetra
.78 .691 .765 r
.37275 .5001 .3795 .5108 .39119 .5 .38452 .48819 Metetra
.756 .669 .765 r
.38452 .48819 .39119 .5 .40284 .49043 .39623 .47771 Metetra
.73 .648 .767 r
.39623 .47771 .40284 .49043 .41445 .48223 .40788 .46883 Metetra
.703 .629 .771 r
.40788 .46883 .41445 .48223 .42603 .47543 .41949 .46159 Metetra
.677 .612 .776 r
.41949 .46159 .42603 .47543 .43761 .46997 .43108 .45593 Metetra
.651 .598 .782 r
.43108 .45593 .43761 .46997 .44919 .46573 .44268 .45171 Metetra
.627 .586 .789 r
.44268 .45171 .44919 .46573 .4608 .46255 .45429 .44873 Metetra
.605 .579 .798 r
.45429 .44873 .4608 .46255 .47245 .46022 .46593 .44676 Metetra
.587 .575 .807 r
.46593 .44676 .47245 .46022 .48416 .45852 .47764 .44553 Metetra
.575 .576 .817 r
.47764 .44553 .48416 .45852 .49592 .45721 .4894 .44477 Metetra
.568 .582 .828 r
.4894 .44477 .49592 .45721 .50775 .45607 .50124 .44419 Metetra
.569 .593 .838 r
.50124 .44419 .50775 .45607 .51966 .45488 .51315 .44354 Metetra
.576 .608 .847 r
.51315 .44354 .51966 .45488 .53163 .45343 .52514 .44257 Metetra
.59 .624 .854 r
.52514 .44257 .53163 .45343 .54367 .45155 .5372 .44109 Metetra
.609 .642 .858 r
.5372 .44109 .54367 .45155 .55578 .44911 .54932 .43892 Metetra
.631 .658 .858 r
.54932 .43892 .55578 .44911 .56794 .44601 .56151 .43596 Metetra
.654 .671 .854 r
.56151 .43596 .56794 .44601 .58014 .4422 .57374 .43213 Metetra
.674 .679 .847 r
.57374 .43213 .58014 .4422 .59239 .43766 .58601 .42742 Metetra
.691 .683 .838 r
.58601 .42742 .59239 .43766 .60467 .43244 .59831 .42189 Metetra
.704 .683 .827 r
.59831 .42189 .60467 .43244 .61698 .42662 .61064 .41563 Metetra
.711 .678 .816 r
.61064 .41563 .61698 .42662 .62931 .42032 .62298 .40879 Metetra
.714 .671 .807 r
.62298 .40879 .62931 .42032 .64167 .41371 .63535 .40157 Metetra
.712 .661 .798 r
.63535 .40157 .64167 .41371 .65406 .40698 .64774 .3942 Metetra
.706 .65 .791 r
.64774 .3942 .65406 .40698 .66649 .40035 .66017 .38694 Metetra
.696 .637 .786 r
.66017 .38694 .66649 .40035 .67898 .39406 .67264 .38007 Metetra
.682 .623 .784 r
.67264 .38007 .67898 .39406 .69153 .38834 .68519 .37388 Metetra
.663 .609 .784 r
.68519 .37388 .69153 .38834 .70417 .38342 .69783 .36863 Metetra
.641 .594 .786 r
.69783 .36863 .70417 .38342 .71692 .37953 .71059 .3646 Metetra
.613 .578 .791 r
.71059 .3646 .71692 .37953 .72982 .37686 .72349 .36199 Metetra
.58 .561 .798 r
.72349 .36199 .72982 .37686 .74287 .37554 .73658 .36098 Metetra
.539 .544 .808 r
.73658 .36098 .74287 .37554 .75612 .37566 .74987 .36166 Metetra
.491 .526 .82 r
.74987 .36166 .75612 .37566 .76957 .37722 .76339 .36403 Metetra
.435 .507 .834 r
.76339 .36403 .76957 .37722 .78323 .38013 .77715 .36796 Metetra
.373 .49 .848 r
.77715 .36796 .78323 .38013 .79712 .38415 .79114 .37317 Metetra
.311 .478 .864 r
.79114 .37317 .79712 .38415 .8112 .38891 .80535 .37919 Metetra
.264 .481 .881 r
.80535 .37919 .8112 .38891 .82543 .39382 .81973 .38533 Metetra
.26 .514 .905 r
.81973 .38533 .82543 .39382 .83975 .39811 .83417 .3906 Metetra
.337 .594 .94 r
.83417 .3906 .83975 .39811 .85403 .40071 .84855 .39373 Metetra
.54 .725 .959 r
.84855 .39373 .85403 .40071 .86812 .40028 .86259 .39243 Metetra
.657 .751 .919 r
.86259 .39243 .86812 .40028 .88189 .39607 .8764 .38811 Metetra
.657 .749 .918 r
.8764 .38811 .88189 .39607 .89571 .39177 .89027 .38378 Metetra
.657 .749 .918 r
.27248 .56819 .2798 .57466 .29098 .57116 .28369 .56467 Metetra
.657 .749 .918 r
.28369 .56467 .29098 .57116 .30222 .56765 .29495 .56113 Metetra
.668 .752 .913 r
.29495 .56113 .30222 .56765 .3136 .5625 .30629 .55726 Metetra
.81 .802 .844 r
.30629 .55726 .3136 .5625 .3253 .55259 .31804 .54722 Metetra
.842 .794 .805 r
.31804 .54722 .3253 .55259 .33714 .54024 .32998 .53416 Metetra
.847 .776 .783 r
.32998 .53416 .33714 .54024 .34903 .52675 .34198 .51963 Metetra
.838 .757 .773 r
.34198 .51963 .34903 .52675 .36091 .51313 .35397 .50484 Metetra
.822 .736 .769 r
.35397 .50484 .36091 .51313 .37275 .5001 .3659 .49066 Metetra
.801 .715 .769 r
.3659 .49066 .37275 .5001 .38452 .48819 .37776 .47772 Metetra
.776 .694 .773 r
.37776 .47772 .38452 .48819 .39623 .47771 .38953 .4664 Metetra
.749 .674 .778 r
.38953 .4664 .39623 .47771 .40788 .46883 .40123 .45691 Metetra
.719 .655 .786 r
.40123 .45691 .40788 .46883 .41949 .46159 .41288 .4493 Metetra
.687 .638 .795 r
.41288 .4493 .41949 .46159 .43108 .45593 .42449 .4435 Metetra
.655 .622 .805 r
.42449 .4435 .43108 .45593 .44268 .45171 .43609 .43936 Metetra
.624 .609 .816 r
.43609 .43936 .44268 .45171 .45429 .44873 .4477 .43665 Metetra
.594 .6 .828 r
.4477 .43665 .45429 .44873 .46593 .44676 .45935 .4351 Metetra
.569 .596 .841 r
.45935 .4351 .46593 .44676 .47764 .44553 .47106 .4344 Metetra
.549 .598 .855 r
.47106 .4344 .47764 .44553 .4894 .44477 .48282 .43422 Metetra
.538 .605 .868 r
.48282 .43422 .4894 .44477 .50124 .44419 .49467 .43426 Metetra
.537 .619 .882 r
.49467 .43426 .50124 .44419 .51315 .44354 .50659 .4342 Metetra
.546 .639 .893 r
.50659 .4342 .51315 .44354 .52514 .44257 .5186 .43376 Metetra
.566 .662 .902 r
.5186 .43376 .52514 .44257 .5372 .44109 .53069 .4327 Metetra
.593 .686 .906 r
.53069 .4327 .5372 .44109 .54932 .43892 .54284 .43084 Metetra
.625 .708 .905 r
.54284 .43084 .54932 .43892 .56151 .43596 .55506 .42802 Metetra
.657 .724 .899 r
.55506 .42802 .56151 .43596 .57374 .43213 .56732 .42417 Metetra
.686 .735 .888 r
.56732 .42417 .57374 .43213 .58601 .42742 .57963 .41929 Metetra
.71 .738 .874 r
.57963 .41929 .58601 .42742 .59831 .42189 .59196 .41343 Metetra
.727 .736 .859 r
.59196 .41343 .59831 .42189 .61064 .41563 .60431 .4067 Metetra
.737 .729 .844 r
.60431 .4067 .61064 .41563 .62298 .40879 .61668 .39929 Metetra
.74 .719 .832 r
.61668 .39929 .62298 .40879 .63535 .40157 .62906 .39141 Metetra
.738 .706 .821 r
.62906 .39141 .63535 .40157 .64774 .3942 .64146 .38335 Metetra
.731 .692 .813 r
.64146 .38335 .64774 .3942 .66017 .38694 .65389 .37541 Metetra
.718 .676 .807 r
.65389 .37541 .66017 .38694 .67264 .38007 .66637 .36791 Metetra
.701 .659 .805 r
.66637 .36791 .67264 .38007 .68519 .37388 .67892 .36119 Metetra
.678 .641 .806 r
.67892 .36119 .68519 .37388 .69783 .36863 .69156 .35555 Metetra
.65 .622 .809 r
.69156 .35555 .69783 .36863 .71059 .3646 .70432 .35131 Metetra
.614 .602 .815 r
.70432 .35131 .71059 .3646 .72349 .36199 .71725 .34871 Metetra
.571 .58 .824 r
.71725 .34871 .72349 .36199 .73658 .36098 .73036 .34795 Metetra
.517 .556 .834 r
.73036 .34795 .73658 .36098 .74987 .36166 .7437 .34912 Metetra
.451 .528 .846 r
.7437 .34912 .74987 .36166 .76339 .36403 .75728 .35222 Metetra
.374 .498 .856 r
.75728 .35222 .76339 .36403 .77715 .36796 .77113 .3571 Metetra
.288 .468 .863 r
.77113 .3571 .77715 .36796 .79114 .37317 .78523 .3634 Metetra
.206 .444 .867 r
.78523 .3634 .79114 .37317 .80535 .37919 .79957 .37057 Metetra
.152 .441 .875 r
.79957 .37057 .80535 .37919 .81973 .38533 .81406 .37777 Metetra
.163 .483 .899 r
.81406 .37777 .81973 .38533 .83417 .3906 .82862 .38383 Metetra
.286 .59 .946 r
.82862 .38383 .83417 .3906 .84855 .39373 .84306 .3872 Metetra
.593 .767 .962 r
.84306 .3872 .84855 .39373 .86259 .39243 .85701 .38444 Metetra
.657 .749 .918 r
.85701 .38444 .86259 .39243 .8764 .38811 .87086 .38009 Metetra
.657 .749 .918 r
.87086 .38009 .8764 .38811 .89027 .38378 .88479 .37571 Metetra
.657 .749 .918 r
.2651 .56167 .27248 .56819 .28369 .56467 .27635 .55812 Metetra
.657 .749 .918 r
.27635 .55812 .28369 .56467 .29495 .56113 .28764 .55455 Metetra
.657 .749 .918 r
.28764 .55455 .29495 .56113 .30629 .55726 .29898 .55097 Metetra
.777 .776 .852 r
.29898 .55097 .30629 .55726 .31804 .54722 .31068 .54246 Metetra
.852 .807 .806 r
.31068 .54246 .31804 .54722 .32998 .53416 .3227 .52893 Metetra
.862 .793 .782 r
.3227 .52893 .32998 .53416 .34198 .51963 .3348 .51356 Metetra
.856 .776 .772 r
.3348 .51356 .34198 .51963 .35397 .50484 .3469 .49774 Metetra
.843 .759 .77 r
.3469 .49774 .35397 .50484 .3659 .49066 .35894 .48254 Metetra
.823 .741 .774 r
.35894 .48254 .3659 .49066 .37776 .47772 .37088 .46867 Metetra
.798 .722 .781 r
.37088 .46867 .37776 .47772 .38953 .4664 .38273 .45659 Metetra
.768 .704 .791 r
.38273 .45659 .38953 .4664 .40123 .45691 .39448 .44656 Metetra
.735 .686 .804 r
.39448 .44656 .40123 .45691 .41288 .4493 .40617 .43864 Metetra
.698 .669 .818 r
.40617 .43864 .41288 .4493 .42449 .4435 .4178 .43277 Metetra
.658 .653 .833 r
.4178 .43277 .42449 .4435 .43609 .43936 .42942 .42877 Metetra
.617 .639 .85 r
.42942 .42877 .43609 .43936 .4477 .43665 .44104 .42639 Metetra
.575 .628 .867 r
.44104 .42639 .4477 .43665 .45935 .4351 .45269 .42532 Metetra
.537 .622 .884 r
.45269 .42532 .45935 .4351 .47106 .4344 .4644 .4252 Metetra
.505 .623 .901 r
.4644 .4252 .47106 .4344 .48282 .43422 .47618 .42568 Metetra
.483 .631 .918 r
.47618 .42568 .48282 .43422 .49467 .43426 .48804 .42639 Metetra
.477 .649 .934 r
.48804 .42639 .49467 .43426 .50659 .4342 .49998 .42696 Metetra
.487 .675 .948 r
.49998 .42696 .50659 .4342 .5186 .43376 .51201 .42709 Metetra
.514 .707 .958 r
.51201 .42709 .5186 .43376 .53069 .4327 .52413 .4265 Metetra
.555 .74 .963 r
.52413 .4265 .53069 .4327 .54284 .43084 .53632 .42495 Metetra
.603 .771 .96 r
.53632 .42495 .54284 .43084 .55506 .42802 .54857 .4223 Metetra
.651 .793 .95 r
.54857 .4223 .55506 .42802 .56732 .42417 .56088 .41844 Metetra
.694 .806 .934 r
.56088 .41844 .56732 .42417 .57963 .41929 .57323 .41338 Metetra
.728 .808 .915 r
.57323 .41338 .57963 .41929 .59196 .41343 .5856 .40717 Metetra
.751 .803 .894 r
.5856 .40717 .59196 .41343 .60431 .4067 .59799 .39994 Metetra
.765 .793 .875 r
.59799 .39994 .60431 .4067 .61668 .39929 .61038 .39191 Metetra
.771 .778 .859 r
.61038 .39191 .61668 .39929 .62906 .39141 .62279 .38334 Metetra
.769 .761 .846 r
.62279 .38334 .62906 .39141 .64146 .38335 .63521 .37454 Metetra
.76 .743 .837 r
.63521 .37454 .64146 .38335 .65389 .37541 .64766 .36587 Metetra
.745 .723 .831 r
.64766 .36587 .65389 .37541 .66637 .36791 .66014 .35768 Metetra
.724 .703 .83 r
.66014 .35768 .66637 .36791 .67892 .36119 .6727 .35037 Metetra
.697 .682 .832 r
.6727 .35037 .67892 .36119 .69156 .35555 .68535 .34429 Metetra
.661 .659 .837 r
.68535 .34429 .69156 .35555 .70432 .35131 .69813 .33978 Metetra
.616 .634 .845 r
.69813 .33978 .70432 .35131 .71725 .34871 .71107 .33713 Metetra
.559 .605 .855 r
.71107 .33713 .71725 .34871 .73036 .34795 .72422 .33654 Metetra
.487 .571 .866 r
.72422 .33654 .73036 .34795 .7437 .34912 .7376 .33814 Metetra
.398 .531 .874 r
.7376 .33814 .7437 .34912 .75728 .35222 .75126 .34189 Metetra
.293 .484 .875 r
.75126 .34189 .75728 .35222 .77113 .3571 .76519 .34761 Metetra
.179 .435 .867 r
.76519 .34761 .77113 .3571 .78523 .3634 .77939 .35489 Metetra
.079 .396 .853 r
.77939 .35489 .78523 .3634 .79957 .37057 .79383 .36307 Metetra
.026 .39 .849 r
.79383 .36307 .79957 .37057 .81406 .37777 .80844 .37114 Metetra
.064 .448 .879 r
.80844 .37114 .81406 .37777 .82862 .38383 .82308 .37774 Metetra
.268 .606 .954 r
.82308 .37774 .82862 .38383 .84306 .3872 .83754 .38076 Metetra
.652 .797 .952 r
.83754 .38076 .84306 .3872 .85701 .38444 .85138 .37639 Metetra
.657 .749 .918 r
.85138 .37639 .85701 .38444 .87086 .38009 .86528 .37199 Metetra
.657 .749 .918 r
.86528 .37199 .87086 .38009 .88479 .37571 .87925 .36758 Metetra
.657 .749 .918 r
.25767 .5551 .2651 .56167 .27635 .55812 .26894 .55152 Metetra
.657 .749 .918 r
.26894 .55152 .27635 .55812 .28764 .55455 .28026 .54792 Metetra
.657 .749 .918 r
.28026 .54792 .28764 .55455 .29898 .55097 .29163 .54431 Metetra
.728 .764 .881 r
.29163 .54431 .29898 .55097 .31068 .54246 .30321 .53822 Metetra
.859 .82 .809 r
.30321 .53822 .31068 .54246 .3227 .52893 .3153 .52451 Metetra
.874 .809 .782 r
.3153 .52451 .3227 .52893 .3348 .51356 .32751 .5085 Metetra
.872 .796 .772 r
.32751 .5085 .3348 .51356 .3469 .49774 .33972 .49184 Metetra
.861 .781 .771 r
.33972 .49184 .3469 .49774 .35894 .48254 .35186 .47573 Metetra
.843 .767 .778 r
.35186 .47573 .35894 .48254 .37088 .46867 .36389 .46104 Metetra
.819 .752 .79 r
.36389 .46104 .37088 .46867 .38273 .45659 .37581 .44831 Metetra
.788 .737 .805 r
.37581 .44831 .38273 .45659 .39448 .44656 .38763 .43782 Metetra
.752 .722 .824 r
.38763 .43782 .39448 .44656 .40617 .43864 .39935 .42967 Metetra
.708 .706 .846 r
.39935 .42967 .40617 .43864 .4178 .43277 .41102 .42379 Metetra
.658 .69 .869 r
.41102 .42379 .4178 .43277 .42942 .42877 .42265 .41999 Metetra
.601 .675 .892 r
.42265 .41999 .42942 .42877 .44104 .42639 .43428 .418 Metetra
.539 .66 .915 r
.43428 .418 .44104 .42639 .45269 .42532 .44594 .41747 Metetra
.477 .649 .934 r
.44594 .41747 .45269 .42532 .4644 .4252 .45766 .418 Metetra
.421 .644 .95 r
.45766 .418 .4644 .4252 .47618 .42568 .46945 .41918 Metetra
.378 .648 .962 r
.46945 .41918 .47618 .42568 .48804 .42639 .48132 .4206 Metetra
.358 .664 .972 r
.48132 .4206 .48804 .42639 .49998 .42696 .49329 .42187 Metetra
.365 .694 .982 r
.49329 .42187 .49998 .42696 .51201 .42709 .50535 .42261 Metetra
.402 .737 .992 r
.50535 .42261 .51201 .42709 .52413 .4265 .5175 .42251 Metetra
.463 .785 .999 r
.5175 .42251 .52413 .4265 .53632 .42495 .52974 .42131 Metetra
.539 .83 .999 r
.52974 .42131 .53632 .42495 .54857 .4223 .54204 .41883 Metetra
.616 .865 .99 r
.54204 .41883 .54857 .4223 .56088 .41844 .5544 .41497 Metetra
.683 .884 .972 r
.5544 .41497 .56088 .41844 .57323 .41338 .5668 .40971 Metetra
.735 .888 .95 r
.5668 .40971 .57323 .41338 .5856 .40717 .57922 .40313 Metetra
.771 .88 .925 r
.57922 .40313 .5856 .40717 .59799 .39994 .59165 .39539 Metetra
.793 .866 .903 r
.59165 .39539 .59799 .39994 .61038 .39191 .60409 .38671 Metetra
.802 .847 .884 r
.60409 .38671 .61038 .39191 .62279 .38334 .61654 .3774 Metetra
.801 .825 .87 r
.61654 .3774 .62279 .38334 .63521 .37454 .62899 .36781 Metetra
.793 .803 .861 r
.62899 .36781 .63521 .37454 .64766 .36587 .64146 .35834 Metetra
.776 .78 .856 r
.64146 .35834 .64766 .36587 .66014 .35768 .65396 .34942 Metetra
.752 .757 .857 r
.65396 .34942 .66014 .35768 .6727 .35037 .66653 .34145 Metetra
.719 .732 .861 r
.66653 .34145 .6727 .35037 .68535 .34429 .67919 .33487 Metetra
.675 .705 .87 r
.67919 .33487 .68535 .34429 .69813 .33978 .69199 .33003 Metetra
.618 .674 .881 r
.69199 .33003 .69813 .33978 .71107 .33713 .70496 .32726 Metetra
.544 .636 .893 r
.70496 .32726 .71107 .33713 .72422 .33654 .71814 .32679 Metetra
.447 .589 .901 r
.71814 .32679 .72422 .33654 .7376 .33814 .73158 .32873 Metetra
.326 .53 .9 r
.73158 .32873 .7376 .33814 .75126 .34189 .74529 .33304 Metetra
.186 .459 .882 r
.74529 .33304 .75126 .34189 .76519 .34761 .7593 .33951 Metetra
.046 .387 .848 r
.7593 .33951 .76519 .34761 .77939 .35489 .7736 .34764 Metetra
0 .334 .811 r
.7736 .34764 .77939 .35489 .79383 .36307 .78814 .35666 Metetra
0 .331 .801 r
.78814 .35666 .79383 .36307 .80844 .37114 .80284 .3654 Metetra
0 .415 .849 r
.80284 .3654 .80844 .37114 .82308 .37774 .81755 .37226 Metetra
.399 .71 .985 r
.81755 .37226 .82308 .37774 .83754 .38076 .83181 .37267 Metetra
.657 .749 .918 r
.83181 .37267 .83754 .38076 .85138 .37639 .8457 .36826 Metetra
.657 .749 .918 r
.8457 .36826 .85138 .37639 .86528 .37199 .85965 .36383 Metetra
.657 .749 .918 r
.85965 .36383 .86528 .37199 .87925 .36758 .87366 .35937 Metetra
.657 .749 .918 r
.25017 .54848 .25767 .5551 .26894 .55152 .26147 .54487 Metetra
.657 .749 .918 r
.26147 .54487 .26894 .55152 .28026 .54792 .27282 .54124 Metetra
.657 .749 .918 r
.27282 .54124 .28026 .54792 .29163 .54431 .28422 .5376 Metetra
.657 .749 .918 r
.28422 .5376 .29163 .54431 .30321 .53822 .29567 .53394 Metetra
.854 .823 .817 r
.29567 .53394 .30321 .53822 .3153 .52451 .30778 .52079 Metetra
.884 .824 .784 r
.30778 .52079 .3153 .52451 .32751 .5085 .32008 .50439 Metetra
.886 .813 .772 r
.32008 .50439 .32751 .5085 .33972 .49184 .3324 .48707 Metetra
.877 .803 .773 r
.3324 .48707 .33972 .49184 .35186 .47573 .34465 .47022 Metetra
.862 .793 .782 r
.34465 .47022 .35186 .47573 .36389 .46104 .35678 .45483 Metetra
.839 .783 .798 r
.35678 .45483 .36389 .46104 .37581 .44831 .36878 .44153 Metetra
.808 .773 .82 r
.36878 .44153 .37581 .44831 .38763 .43782 .38065 .43066 Metetra
.768 .762 .847 r
.38065 .43066 .38763 .43782 .39935 .42967 .39242 .42235 Metetra
.717 .75 .878 r
.39242 .42235 .39935 .42967 .41102 .42379 .40412 .41654 Metetra
.651 .735 .911 r
.40412 .41654 .41102 .42379 .42265 .41999 .41577 .41301 Metetra
.569 .716 .941 r
.41577 .41301 .42265 .41999 .43428 .418 .42742 .41147 Metetra
.471 .691 .963 r
.42742 .41147 .43428 .418 .44594 .41747 .43909 .41153 Metetra
.364 .662 .971 r
.43909 .41153 .44594 .41747 .45766 .418 .45082 .41276 Metetra
.262 .633 .962 r
.45082 .41276 .45766 .418 .46945 .41918 .46262 .4147 Metetra
.182 .613 .942 r
.46262 .4147 .46945 .41918 .48132 .4206 .47451 .41689 Metetra
.138 .612 .922 r
.47451 .41689 .48132 .4206 .49329 .42187 .48651 .41889 Metetra
.14 .636 .911 r
.48651 .41889 .49329 .42187 .50535 .42261 .49861 .42027 Metetra
.187 .685 .915 r
.49861 .42027 .50535 .42261 .5175 .42251 .5108 .4207 Metetra
.275 .754 .931 r
.5108 .4207 .5175 .42251 .52974 .42131 .52309 .41987 Metetra
.391 .829 .95 r
.52309 .41987 .52974 .42131 .54204 .41883 .53545 .41758 Metetra
.514 .893 .963 r
.53545 .41758 .54204 .41883 .5544 .41497 .54787 .41371 Metetra
.625 .936 .963 r
.54787 .41371 .5544 .41497 .5668 .40971 .56033 .40826 Metetra
.712 .953 .951 r
.56033 .40826 .5668 .40971 .57922 .40313 .57281 .4013 Metetra
.772 .952 .933 r
.57281 .4013 .57922 .40313 .59165 .39539 .5853 .393 Metetra
.809 .937 .914 r
.5853 .393 .59165 .39539 .60409 .38671 .59779 .38364 Metetra
.827 .917 .897 r
.59779 .38364 .60409 .38671 .61654 .3774 .61028 .37355 Metetra
.831 .893 .885 r
.61028 .37355 .61654 .3774 .62899 .36781 .62277 .36312 Metetra
.824 .868 .879 r
.62277 .36312 .62899 .36781 .64146 .35834 .63527 .35282 Metetra
.807 .843 .877 r
.63527 .35282 .64146 .35834 .65396 .34942 .64781 .3431 Metetra
.781 .818 .882 r
.64781 .3431 .65396 .34942 .66653 .34145 .6604 .33444 Metetra
.743 .791 .891 r
.6604 .33444 .66653 .34145 .67919 .33487 .67309 .32729 Metetra
.691 .76 .905 r
.67309 .32729 .67919 .33487 .69199 .33003 .68591 .32206 Metetra
.619 .723 .92 r
.68591 .32206 .69199 .33003 .70496 .32726 .69891 .31911 Metetra
.521 .674 .933 r
.69891 .31911 .70496 .32726 .71814 .32679 .71213 .31867 Metetra
.392 .607 .935 r
.71213 .31867 .71814 .32679 .73158 .32873 .72561 .32088 Metetra
.231 .52 .914 r
.72561 .32088 .73158 .32873 .74529 .33304 .73939 .32566 Metetra
.055 .418 .865 r
.73939 .32566 .74529 .33304 .7593 .33951 .75347 .33275 Metetra
0 .322 .798 r
.75347 .33275 .7593 .33951 .7736 .34764 .76786 .34159 Metetra
0 .263 .742 r
.76786 .34159 .7736 .34764 .78814 .35666 .78249 .35127 Metetra
0 .273 .736 r
.78249 .35127 .78814 .35666 .80284 .3654 .79726 .36044 Metetra
0 .393 .817 r
.79726 .36044 .80284 .3654 .81755 .37226 .81202 .36726 Metetra
.557 .811 .993 r
.81202 .36726 .81755 .37226 .83181 .37267 .82603 .36451 Metetra
.657 .749 .918 r
.82603 .36451 .83181 .37267 .8457 .36826 .83996 .36006 Metetra
.657 .749 .918 r
.83996 .36006 .8457 .36826 .85965 .36383 .85396 .35559 Metetra
.657 .749 .918 r
.85396 .35559 .85965 .36383 .87366 .35937 .86803 .35109 Metetra
.657 .749 .918 r
.24262 .5418 .25017 .54848 .26147 .54487 .25395 .53816 Metetra
.657 .749 .918 r
.25395 .53816 .26147 .54487 .27282 .54124 .26533 .53451 Metetra
.657 .749 .918 r
.26533 .53451 .27282 .54124 .28422 .5376 .27676 .53084 Metetra
.657 .749 .918 r
.27676 .53084 .28422 .5376 .29567 .53394 .28823 .52715 Metetra
.788 .769 .836 r
.28823 .52715 .29567 .53394 .30778 .52079 .30015 .51764 Metetra
.89 .836 .787 r
.30015 .51764 .30778 .52079 .32008 .50439 .31253 .50112 Metetra
.896 .829 .773 r
.31253 .50112 .32008 .50439 .3324 .48707 .32495 .48335 Metetra
.891 .823 .774 r
.32495 .48335 .3324 .48707 .34465 .47022 .3373 .46591 Metetra
.878 .818 .785 r
.3373 .46591 .34465 .47022 .35678 .45483 .34952 .44995 Metetra
.857 .814 .806 r
.34952 .44995 .35678 .45483 .36878 .44153 .3616 .43619 Metetra
.827 .81 .835 r
.3616 .43619 .36878 .44153 .38065 .43066 .37354 .42504 Metetra
.783 .806 .871 r
.37354 .42504 .38065 .43066 .39242 .42235 .38536 .41665 Metetra
.72 .799 .914 r
.38536 .41665 .39242 .42235 .40412 .41654 .39709 .41095 Metetra
.63 .784 .955 r
.39709 .41095 .40412 .41654 .41577 .41301 .40877 .40775 Metetra
.504 .752 .985 r
.40877 .40775 .41577 .41301 .42742 .41147 .42044 .40671 Metetra
.343 .696 .982 r
.42044 .40671 .42742 .41147 .43909 .41153 .43212 .40742 Metetra
.166 .617 .936 r
.43212 .40742 .43909 .41153 .45082 .41276 .44386 .4094 Metetra
.01 .534 .856 r
.44386 .4094 .45082 .41276 .46262 .4147 .45568 .41215 Metetra
0 .471 .77 r
.45568 .41215 .46262 .4147 .47451 .41689 .4676 .41516 Metetra
0 .443 .705 r
.4676 .41516 .47451 .41689 .48651 .41889 .47963 .41793 Metetra
.139 0 0 r
.47963 .41793 .48651 .41889 .49861 .42027 .49176 .42 Metetra
.082 0 0 r
.49176 .42 .49861 .42027 .5108 .4207 .50401 .42098 Metetra
.50401 .42098 .5108 .4207 .52309 .41987 .51635 .42054 Metetra
.165 .703 .753 r
.51635 .42054 .52309 .41987 .53545 .41758 .52878 .41845 Metetra
.331 .815 .81 r
.52878 .41845 .53545 .41758 .54787 .41371 .54126 .41458 Metetra
.496 .906 .856 r
.54126 .41458 .54787 .41371 .56033 .40826 .55379 .40893 Metetra
.634 .963 .883 r
.55379 .40893 .56033 .40826 .57281 .4013 .56635 .40156 Metetra
.734 .987 .892 r
.56635 .40156 .57281 .4013 .5853 .393 .57891 .39269 Metetra
.798 .987 .89 r
.57891 .39269 .5853 .393 .59779 .38364 .59146 .38261 Metetra
.833 .973 .885 r
.59146 .38261 .59779 .38364 .61028 .37355 .60401 .3717 Metetra
.848 .952 .882 r
.60401 .3717 .61028 .37355 .62277 .36312 .61655 .36041 Metetra
.848 .93 .882 r
.61655 .36041 .62277 .36312 .63527 .35282 .62909 .34922 Metetra
.834 .906 .888 r
.62909 .34922 .63527 .35282 .64781 .3431 .64167 .33866 Metetra
.807 .881 .899 r
.64167 .33866 .64781 .3431 .6604 .33444 .65429 .32924 Metetra
.766 .854 .916 r
.65429 .32924 .6604 .33444 .67309 .32729 .66701 .32148 Metetra
.704 .822 .938 r
.66701 .32148 .67309 .32729 .68591 .32206 .67986 .31581 Metetra
.615 .778 .959 r
.67986 .31581 .68591 .32206 .69891 .31911 .69289 .31261 Metetra
.488 .714 .971 r
.69289 .31261 .69891 .31911 .71213 .31867 .70615 .31214 Metetra
.316 .62 .957 r
.70615 .31214 .71213 .31867 .72561 .32088 .71969 .31453 Metetra
.111 .495 .903 r
.71969 .31453 .72561 .32088 .73939 .32566 .73353 .31968 Metetra
0 .36 .813 r
.73353 .31968 .73939 .32566 .75347 .33275 .74768 .32727 Metetra
0 .249 .717 r
.74768 .32727 .75347 .33275 .76786 .34159 .76214 .33666 Metetra
0 .194 .657 r
.76214 .33666 .76786 .34159 .78249 .35127 .77685 .34679 Metetra
0 .225 .671 r
.77685 .34679 .78249 .35127 .79726 .36044 .79168 .35613 Metetra
.012 .498 .871 r
.79168 .35613 .79726 .36044 .81202 .36726 .80629 .36075 Metetra
.652 .799 .953 r
.80629 .36075 .81202 .36726 .82603 .36451 .8202 .35628 Metetra
.657 .749 .918 r
.8202 .35628 .82603 .36451 .83996 .36006 .83418 .35179 Metetra
.657 .749 .918 r
.83418 .35179 .83996 .36006 .85396 .35559 .84823 .34727 Metetra
.657 .749 .918 r
.84823 .34727 .85396 .35559 .86803 .35109 .86234 .34274 Metetra
.657 .749 .918 r
.23501 .53507 .24262 .5418 .25395 .53816 .24637 .5314 Metetra
.657 .749 .918 r
.24637 .5314 .25395 .53816 .26533 .53451 .25777 .52772 Metetra
.657 .749 .918 r
.25777 .52772 .26533 .53451 .27676 .53084 .26923 .52402 Metetra
.657 .749 .918 r
.26923 .52402 .27676 .53084 .28823 .52715 .28074 .5203 Metetra
.708 .761 .893 r
.28074 .5203 .28823 .52715 .30015 .51764 .29242 .51487 Metetra
.893 .847 .792 r
.29242 .51487 .30015 .51764 .31253 .50112 .30485 .49853 Metetra
.904 .843 .774 r
.30485 .49853 .31253 .50112 .32495 .48335 .31736 .48053 Metetra
.902 .841 .775 r
.31736 .48053 .32495 .48335 .3373 .46591 .32981 .4627 Metetra
.892 .841 .788 r
.32981 .4627 .3373 .46591 .34952 .44995 .34213 .4463 Metetra
.873 .843 .813 r
.34213 .4463 .34952 .44995 .3616 .43619 .35429 .43219 Metetra
.842 .847 .848 r
.35429 .43219 .3616 .43619 .37354 .42504 .3663 .42084 Metetra
.793 .851 .895 r
.3663 .42084 .37354 .42504 .38536 .41665 .37817 .41244 Metetra
.713 .849 .947 r
.37817 .41244 .38536 .41665 .39709 .41095 .38994 .40693 Metetra
.583 .827 .991 r
.38994 .40693 .39709 .41095 .40877 .40775 .40164 .40411 Metetra
.385 .759 .991 r
.40164 .40411 .40877 .40775 .42044 .40671 .41333 .40363 Metetra
.137 .632 .911 r
.41333 .40363 .42044 .40671 .43212 .40742 .42503 .40503 Metetra
0 .477 .765 r
.42503 .40503 .43212 .40742 .44386 .4094 .43678 .4078 Metetra
.253 0 0 r
.43678 .4078 .44386 .4094 .45568 .41215 .44862 .4114 Metetra
.338 0 0 r
.44862 .4114 .45568 .41215 .4676 .41516 .46057 .41526 Metetra
.364 0 0 r
.46057 .41526 .4676 .41516 .47963 .41793 .47263 .41884 Metetra
.344 0 0 r
.47263 .41884 .47963 .41793 .49176 .42 .48481 .42162 Metetra
.284 0 0 r
.48481 .42162 .49176 .42 .50401 .42098 .49711 .42318 Metetra
.184 0 0 r
.49711 .42318 .50401 .42098 .51635 .42054 .50952 .42315 Metetra
.043 0 0 r
.50952 .42315 .51635 .42054 .52878 .41845 .52201 .42128 Metetra
.52201 .42128 .52878 .41845 .54126 .41458 .53458 .41741 Metetra
.327 .791 .673 r
.53458 .41741 .54126 .41458 .55379 .40893 .54719 .41154 Metetra
.508 .898 .746 r
.54719 .41154 .55379 .40893 .56635 .40156 .55982 .40377 Metetra
.653 .965 .795 r
.55982 .40377 .56635 .40156 .57891 .39269 .57246 .3943 Metetra
.753 .994 .824 r
.57246 .3943 .57891 .39269 .59146 .38261 .58509 .38348 Metetra
.814 .999 .84 r
.58509 .38348 .59146 .38261 .60401 .3717 .5977 .37172 Metetra
.846 .99 .852 r
.5977 .37172 .60401 .3717 .61655 .36041 .61031 .35951 Metetra
.856 .975 .864 r
.61031 .35951 .61655 .36041 .62909 .34922 .6229 .3474 Metetra
.849 .957 .88 r
.6229 .3474 .62909 .34922 .64167 .33866 .63552 .33596 Metetra
.825 .937 .902 r
.63552 .33596 .64167 .33866 .65429 .32924 .64819 .32575 Metetra
.782 .914 .929 r
.64819 .32575 .65429 .32924 .66701 .32148 .66094 .31732 Metetra
.712 .882 .96 r
.66094 .31732 .66701 .32148 .67986 .31581 .67383 .31116 Metetra
.602 .832 .987 r
.67383 .31116 .67986 .31581 .69289 .31261 .68691 .30765 Metetra
.439 .748 .993 r
.68691 .30765 .69289 .31261 .70615 .31214 .70021 .30708 Metetra
.22 .618 .953 r
.70021 .30708 .70615 .31214 .71969 .31453 .7138 .30956 Metetra
0 .451 .855 r
.7138 .30956 .71969 .31453 .73353 .31968 .72769 .31498 Metetra
0 .291 .729 r
.72769 .31498 .73353 .31968 .74768 .32727 .74192 .32294 Metetra
0 .179 .623 r
.74192 .32294 .74768 .32727 .76214 .33666 .75644 .3327 Metetra
.41 0 0 r
.75644 .3327 .76214 .33666 .77685 .34679 .77121 .34307 Metetra
0 .197 .619 r
.77121 .34307 .77685 .34679 .79168 .35613 .78608 .35229 Metetra
.314 .726 .977 r
.78608 .35229 .79168 .35613 .80629 .36075 .80036 .35248 Metetra
.657 .749 .918 r
.80036 .35248 .80629 .36075 .8202 .35628 .81432 .34797 Metetra
.657 .749 .918 r
.81432 .34797 .8202 .35628 .83418 .35179 .82835 .34344 Metetra
.657 .749 .918 r
.82835 .34344 .83418 .35179 .84823 .34727 .84244 .33889 Metetra
.657 .749 .918 r
.84244 .33889 .84823 .34727 .86234 .34274 .85661 .33431 Metetra
.657 .749 .918 r
.22733 .52828 .23501 .53507 .24637 .5314 .23872 .52459 Metetra
.657 .749 .918 r
.23872 .52459 .24637 .5314 .25777 .52772 .25016 .52087 Metetra
.657 .749 .918 r
.25016 .52087 .25777 .52772 .26923 .52402 .26164 .51714 Metetra
.657 .749 .918 r
.26164 .51714 .26923 .52402 .28074 .5203 .27318 .51339 Metetra
.657 .749 .918 r
.27318 .51339 .28074 .5203 .29242 .51487 .28477 .50963 Metetra
.845 .805 .812 r
.28477 .50963 .29242 .51487 .30485 .49853 .29706 .49644 Metetra
.908 .854 .778 r
.29706 .49644 .30485 .49853 .31736 .48053 .30964 .47846 Metetra
.91 .856 .776 r
.30964 .47846 .31736 .48053 .32981 .4627 .32218 .46041 Metetra
.902 .861 .79 r
.32218 .46041 .32981 .4627 .34213 .4463 .3346 .44373 Metetra
.884 .87 .818 r
.3346 .44373 .34213 .4463 .35429 .43219 .34684 .42939 Metetra
.853 .882 .86 r
.34684 .42939 .35429 .43219 .3663 .42084 .35892 .41793 Metetra
.795 .894 .914 r
.35892 .41793 .3663 .42084 .37817 .41244 .37084 .40958 Metetra
.689 .893 .972 r
.37084 .40958 .37817 .41244 .38994 .40693 .38265 .40432 Metetra
.496 .844 .995 r
.38265 .40432 .38994 .40693 .40164 .40411 .39438 .40193 Metetra
.203 .7 .916 r
.39438 .40193 .40164 .40411 .41333 .40363 .40608 .40204 Metetra
0 .484 .726 r
.40608 .40204 .41333 .40363 .42503 .40503 .4178 .40417 Metetra
.315 0 0 r
.4178 .40417 .42503 .40503 .43678 .4078 .42957 .40778 Metetra
.431 0 0 r
.42957 .40778 .43678 .4078 .44862 .4114 .44143 .41225 Metetra
.481 0 0 r
.44143 .41225 .44862 .4114 .46057 .41526 .45341 .417 Metetra
.486 0 0 r
.45341 .417 .46057 .41526 .47263 .41884 .4655 .42141 Metetra
.458 0 0 r
.4655 .42141 .47263 .41884 .48481 .42162 .47773 .42493 Metetra
.4 0 0 r
.47773 .42493 .48481 .42162 .49711 .42318 .49009 .42709 Metetra
.309 0 0 r
.49009 .42709 .49711 .42318 .50952 .42315 .50257 .42749 Metetra
.181 0 0 r
.50257 .42749 .50952 .42315 .52201 .42128 .51514 .42583 Metetra
.015 0 0 r
.51514 .42583 .52201 .42128 .53458 .41741 .52779 .42198 Metetra
.52779 .42198 .53458 .41741 .54719 .41154 .54049 .41589 Metetra
.54049 .41589 .54719 .41154 .55982 .40377 .55321 .40769 Metetra
.555 .9 .673 r
.55321 .40769 .55982 .40377 .57246 .3943 .56594 .39761 Metetra
.687 .962 .731 r
.56594 .39761 .57246 .3943 .58509 .38348 .57866 .38603 Metetra
.774 .991 .77 r
.57866 .38603 .58509 .38348 .5977 .37172 .59135 .37339 Metetra
.824 1 .799 r
.59135 .37339 .5977 .37172 .61031 .35951 .60402 .36025 Metetra
.848 .997 .825 r
.60402 .36025 .61031 .35951 .6229 .3474 .61668 .34718 Metetra
.849 .989 .852 r
.61668 .34718 .6229 .3474 .63552 .33596 .62936 .33482 Metetra
.83 .977 .884 r
.62936 .33482 .63552 .33596 .64819 .32575 .64207 .32379 Metetra
.787 .961 .922 r
.64207 .32379 .64819 .32575 .66094 .31732 .65488 .31465 Metetra
.709 .932 .963 r
.65488 .31465 .66094 .31732 .67383 .31116 .66781 .30794 Metetra
.577 .875 .994 r
.66781 .30794 .67383 .31116 .68691 .30765 .68093 .30408 Metetra
.375 .767 .988 r
.68093 .30408 .68691 .30765 .70021 .30708 .69428 .30335 Metetra
.114 .595 .912 r
.69428 .30335 .70021 .30708 .7138 .30956 .70792 .30584 Metetra
0 .394 .775 r
.70792 .30584 .7138 .30956 .72769 .31498 .72187 .31141 Metetra
0 .225 .633 r
.72187 .31141 .72769 .31498 .74192 .32294 .73615 .3196 Metetra
.44 0 0 r
.73615 .3196 .74192 .32294 .75644 .3327 .75074 .32955 Metetra
.462 0 0 r
.75074 .32955 .75644 .3327 .77121 .34307 .76555 .33991 Metetra
.371 0 0 r
.76555 .33991 .77121 .34307 .78608 .35229 .78043 .34867 Metetra
.602 .883 .991 r
.78043 .34867 .78608 .35229 .80036 .35248 .79437 .34414 Metetra
.657 .749 .918 r
.79437 .34414 .80036 .35248 .81432 .34797 .80838 .33959 Metetra
.657 .749 .918 r
.80838 .33959 .81432 .34797 .82835 .34344 .82246 .33502 Metetra
.657 .749 .918 r
.82246 .33502 .82835 .34344 .84244 .33889 .8366 .33042 Metetra
.657 .749 .918 r
.8366 .33042 .84244 .33889 .85661 .33431 .85082 .32581 Metetra
.657 .749 .918 r
.21959 .52144 .22733 .52828 .23872 .52459 .23101 .51772 Metetra
.657 .749 .918 r
.23101 .51772 .23872 .52459 .25016 .52087 .24248 .51397 Metetra
.657 .749 .918 r
.24248 .51397 .25016 .52087 .26164 .51714 .25399 .51021 Metetra
.657 .749 .918 r
.25399 .51021 .26164 .51714 .27318 .51339 .26556 .50643 Metetra
.657 .749 .918 r
.26556 .50643 .27318 .51339 .28477 .50963 .27718 .50264 Metetra
.762 .768 .858 r
.27718 .50264 .28477 .50963 .29706 .49644 .28915 .49461 Metetra
.909 .863 .783 r
.28915 .49461 .29706 .49644 .30964 .47846 .3018 .47692 Metetra
.914 .868 .779 r
.3018 .47692 .30964 .47846 .32218 .46041 .31442 .45886 Metetra
.909 .878 .793 r
.31442 .45886 .32218 .46041 .3346 .44373 .32692 .44205 Metetra
.892 .892 .822 r
.32692 .44205 .3346 .44373 .34684 .42939 .33925 .42759 Metetra
.858 .912 .868 r
.33925 .42759 .34684 .42939 .35892 .41793 .35139 .41611 Metetra
.788 .93 .927 r
.35139 .41611 .35892 .41793 .37084 .40958 .36337 .40789 Metetra
.642 .92 .978 r
.36337 .40789 .37084 .40958 .38265 .40432 .37522 .40293 Metetra
.366 .814 .946 r
.37522 .40293 .38265 .40432 .39438 .40193 .38698 .40101 Metetra
0 .574 .759 r
.38698 .40101 .39438 .40193 .40608 .40204 .3987 .40174 Metetra
.29 0 0 r
.3987 .40174 .40608 .40204 .4178 .40417 .41044 .40463 Metetra
.453 0 0 r
.41044 .40463 .4178 .40417 .42957 .40778 .42223 .40909 Metetra
.53 0 0 r
.42223 .40909 .42957 .40778 .44143 .41225 .43411 .41446 Metetra
.557 .009 0 r
.43411 .41446 .44143 .41225 .45341 .417 .44611 .42011 Metetra
.552 .016 0 r
.44611 .42011 .45341 .417 .4655 .42141 .45825 .42537 Metetra
.521 0 0 r
.45825 .42537 .4655 .42141 .47773 .42493 .47053 .42966 Metetra
.465 0 0 r
.47053 .42966 .47773 .42493 .49009 .42709 .48295 .43243 Metetra
.381 0 0 r
.48295 .43243 .49009 .42709 .50257 .42749 .4955 .43326 Metetra
.263 0 0 r
.4955 .43326 .50257 .42749 .51514 .42583 .50815 .43183 Metetra
.107 0 0 r
.50815 .43183 .51514 .42583 .52779 .42198 .52089 .42798 Metetra
.52089 .42798 .52779 .42198 .54049 .41589 .53369 .42168 Metetra
.53369 .42168 .54049 .41589 .55321 .40769 .54651 .41304 Metetra
.474 .83 .564 r
.54651 .41304 .55321 .40769 .56594 .39761 .55933 .40235 Metetra
.624 .916 .64 r
.55933 .40235 .56594 .39761 .57866 .38603 .57214 .38998 Metetra
.729 .965 .695 r
.57214 .38998 .57866 .38603 .59135 .37339 .58492 .37646 Metetra
.795 .988 .737 r
.58492 .37646 .59135 .37339 .60402 .36025 .59768 .36235 Metetra
.829 .997 .774 r
.59768 .36235 .60402 .36025 .61668 .34718 .61042 .34832 Metetra
.838 .999 .81 r
.61042 .34832 .61668 .34718 .62936 .33482 .62316 .33502 Metetra
.824 .996 .85 r
.62316 .33502 .62936 .33482 .64207 .32379 .63593 .32313 Metetra
.781 .987 .896 r
.63593 .32313 .64207 .32379 .65488 .31465 .64879 .31327 Metetra
.695 .962 .943 r
.64879 .31327 .65488 .31465 .66781 .30794 .66177 .30598 Metetra
.543 .898 .974 r
.66177 .30598 .66781 .30794 .68093 .30408 .67494 .30171 Metetra
.307 .765 .951 r
.67494 .30171 .68093 .30408 .69428 .30335 .68834 .30074 Metetra
.018 .558 .843 r
.68834 .30074 .69428 .30335 .70792 .30584 .70203 .30316 Metetra
0 .339 .686 r
.70203 .30316 .70792 .30584 .72187 .31141 .71604 .30877 Metetra
.405 0 0 r
.71604 .30877 .72187 .31141 .73615 .3196 .73038 .31705 Metetra
.486 0 0 r
.73038 .31705 .73615 .3196 .75074 .32955 .74501 .327 Metetra
.484 0 0 r
.74501 .327 .75074 .32955 .76555 .33991 .75985 .33709 Metetra
0 .525 .831 r
.75985 .33709 .76555 .33991 .78043 .34867 .77435 .34029 Metetra
.657 .749 .918 r
.77435 .34029 .78043 .34867 .79437 .34414 .78834 .33572 Metetra
.657 .749 .918 r
.78834 .33572 .79437 .34414 .80838 .33959 .80239 .33113 Metetra
.657 .749 .918 r
.80239 .33113 .80838 .33959 .82246 .33502 .81652 .32652 Metetra
.657 .749 .918 r
.81652 .32652 .82246 .33502 .8366 .33042 .83071 .32188 Metetra
.657 .749 .918 r
.83071 .32188 .8366 .33042 .85082 .32581 .84498 .31723 Metetra
.657 .749 .918 r
.21179 .51455 .21959 .52144 .23101 .51772 .22324 .51079 Metetra
.657 .749 .918 r
.22324 .51079 .23101 .51772 .24248 .51397 .23474 .50702 Metetra
.657 .749 .918 r
.23474 .50702 .24248 .51397 .25399 .51021 .24628 .50322 Metetra
.657 .749 .918 r
.24628 .50322 .25399 .51021 .26556 .50643 .25788 .49942 Metetra
.657 .749 .918 r
.25788 .49942 .26556 .50643 .27718 .50264 .26953 .49559 Metetra
.657 .749 .918 r
.26953 .49559 .27718 .50264 .28915 .49461 .28123 .49175 Metetra
.89 .851 .798 r
.28123 .49175 .28915 .49461 .3018 .47692 .29384 .47568 Metetra
.915 .877 .783 r
.29384 .47568 .3018 .47692 .31442 .45886 .30654 .45782 Metetra
.912 .89 .796 r
.30654 .45782 .31442 .45886 .32692 .44205 .31912 .44105 Metetra
.896 .91 .826 r
.31912 .44105 .32692 .44205 .33925 .42759 .33152 .42659 Metetra
.858 .936 .874 r
.33152 .42659 .33925 .42759 .35139 .41611 .34373 .41517 Metetra
.771 .955 .932 r
.34373 .41517 .35139 .41611 .36337 .40789 .35576 .40714 Metetra
.574 .921 .96 r
.35576 .40714 .36337 .40789 .37522 .40293 .36765 .40252 Metetra
.217 .737 .849 r
.36765 .40252 .37522 .40293 .38698 .40101 .37944 .40109 Metetra
.168 0 0 r
.37944 .40109 .38698 .40101 .3987 .40174 .39119 .40248 Metetra
.411 0 0 r
.39119 .40248 .3987 .40174 .41044 .40463 .40294 .40614 Metetra
.533 0 0 r
.40294 .40614 .41044 .40463 .42223 .40909 .41475 .41145 Metetra
.586 .048 0 r
.41475 .41145 .42223 .40909 .43411 .41446 .42665 .41774 Metetra
.601 .08 0 r
.42665 .41774 .43411 .41446 .44611 .42011 .43868 .4243 Metetra
.59 .08 .008 r
.43868 .4243 .44611 .42011 .45825 .42537 .45086 .43042 Metetra
.558 .054 .013 r
.45086 .43042 .45825 .42537 .47053 .42966 .46319 .43546 Metetra
.504 .003 0 r
.46319 .43546 .47053 .42966 .48295 .43243 .47567 .43886 Metetra
.424 0 0 r
.47567 .43886 .48295 .43243 .4955 .43326 .48829 .44012 Metetra
.311 0 0 r
.48829 .44012 .4955 .43326 .50815 .43183 .50104 .43893 Metetra
.161 0 0 r
.50104 .43893 .50815 .43183 .52089 .42798 .51387 .43509 Metetra
.51387 .43509 .52089 .42798 .53369 .42168 .52677 .42856 Metetra
.52677 .42856 .53369 .42168 .54651 .41304 .5397 .4195 Metetra
.5397 .4195 .54651 .41304 .55933 .40235 .55263 .40818 Metetra
.584 .878 .573 r
.55263 .40818 .55933 .40235 .57214 .38998 .56554 .39503 Metetra
.699 .938 .636 r
.56554 .39503 .57214 .38998 .58492 .37646 .57842 .3806 Metetra
.772 .971 .685 r
.57842 .3806 .58492 .37646 .59768 .36235 .59126 .36554 Metetra
.812 .988 .726 r
.59126 .36554 .59768 .36235 .61042 .34832 .60408 .35052 Metetra
.826 .996 .766 r
.60408 .35052 .61042 .34832 .62316 .33502 .6169 .33628 Metetra
.814 1 .81 r
.6169 .33628 .62316 .33502 .63593 .32313 .62974 .32353 Metetra
.77 .996 .859 r
.62974 .32353 .63593 .32313 .64879 .31327 .64266 .31291 Metetra
.678 .973 .908 r
.64266 .31291 .64879 .31327 .66177 .30598 .6557 .30502 Metetra
.51 .903 .935 r
.6557 .30502 .66177 .30598 .67494 .30171 .66892 .3003 Metetra
.249 .749 .897 r
.66892 .3003 .67494 .30171 .68834 .30074 .68238 .29905 Metetra
0 .521 .77 r
.68238 .29905 .68834 .30074 .70203 .30316 .69612 .30131 Metetra
.296 0 0 r
.69612 .30131 .70203 .30316 .71604 .30877 .71018 .30686 Metetra
.444 0 0 r
.71018 .30686 .71604 .30877 .73038 .31705 .72456 .31506 Metetra
.505 0 0 r
.72456 .31506 .73038 .31705 .74501 .327 .73923 .3248 Metetra
.478 0 0 r
.73923 .3248 .74501 .327 .75985 .33709 .75409 .33436 Metetra
.434 .833 .98 r
.75409 .33436 .75985 .33709 .77435 .34029 .76821 .33184 Metetra
.657 .749 .918 r
.76821 .33184 .77435 .34029 .78834 .33572 .78224 .32723 Metetra
.657 .749 .918 r
.78224 .32723 .78834 .33572 .80239 .33113 .79635 .3226 Metetra
.657 .749 .918 r
.79635 .3226 .80239 .33113 .81652 .32652 .81052 .31794 Metetra
.657 .749 .918 r
.81052 .31794 .81652 .32652 .83071 .32188 .82477 .31327 Metetra
.657 .749 .918 r
.82477 .31327 .83071 .32188 .84498 .31723 .83908 .30857 Metetra
.657 .749 .918 r
.20393 .5076 .21179 .51455 .22324 .51079 .2154 .50381 Metetra
.657 .749 .918 r
.2154 .50381 .22324 .51079 .23474 .50702 .22693 .5 Metetra
.657 .749 .918 r
.22693 .5 .23474 .50702 .24628 .50322 .23851 .49618 Metetra
.657 .749 .918 r
.23851 .49618 .24628 .50322 .25788 .49942 .25014 .49234 Metetra
.657 .749 .918 r
.25014 .49234 .25788 .49942 .26953 .49559 .26182 .48848 Metetra
.657 .749 .918 r
.26182 .48848 .26953 .49559 .28123 .49175 .27355 .48461 Metetra
.793 .77 .832 r
.27355 .48461 .28123 .49175 .29384 .47568 .28579 .47448 Metetra
.913 .881 .789 r
.28579 .47448 .29384 .47568 .30654 .45782 .29854 .45705 Metetra
.912 .898 .8 r
.29854 .45705 .30654 .45782 .31912 .44105 .31119 .44048 Metetra
.896 .923 .83 r
.31119 .44048 .31912 .44105 .33152 .42659 .32367 .42614 Metetra
.853 .952 .878 r
.32367 .42614 .33152 .42659 .34373 .41517 .33594 .41487 Metetra
.746 .968 .932 r
.33594 .41487 .34373 .41517 .35576 .40714 .34802 .40708 Metetra
.496 .899 .925 r
.34802 .40708 .35576 .40714 .36765 .40252 .35995 .40283 Metetra
.081 .641 .738 r
.35995 .40283 .36765 .40252 .37944 .40109 .37177 .40192 Metetra
.284 0 0 r
.37177 .40192 .37944 .40109 .39119 .40248 .38354 .40396 Metetra
.486 0 0 r
.38354 .40396 .39119 .40248 .40294 .40614 .39531 .40839 Metetra
.581 .04 0 r
.39531 .40839 .40294 .40614 .41475 .41145 .40713 .41457 Metetra
.621 .103 0 r
.40713 .41457 .41475 .41145 .42665 .41774 .41906 .42176 Metetra
.629 .127 .039 r
.41906 .42176 .42665 .41774 .43868 .4243 .43111 .42921 Metetra
.616 .123 .059 r
.43111 .42921 .43868 .4243 .45086 .43042 .44333 .43619 Metetra
.583 .094 .059 r
.44333 .43619 .45086 .43042 .46319 .43546 .45571 .44199 Metetra
.53 .042 .042 r
.45571 .44199 .46319 .43546 .47567 .43886 .46826 .446 Metetra
.45 0 .005 r
.46826 .446 .47567 .43886 .48829 .44012 .48096 .4477 Metetra
.339 0 0 r
.48096 .4477 .48829 .44012 .50104 .43893 .49379 .44674 Metetra
.188 0 0 r
.49379 .44674 .50104 .43893 .51387 .43509 .50672 .4429 Metetra
.001 0 0 r
.50672 .4429 .51387 .43509 .52677 .42856 .51973 .43616 Metetra
.51973 .43616 .52677 .42856 .5397 .4195 .53277 .42667 Metetra
.53277 .42667 .5397 .4195 .55263 .40818 .54581 .41472 Metetra
.574 .861 .538 r
.54581 .41472 .55263 .40818 .56554 .39503 .55883 .4008 Metetra
.691 .924 .602 r
.55883 .4008 .56554 .39503 .57842 .3806 .57182 .38549 Metetra
.765 .959 .651 r
.57182 .38549 .57842 .3806 .59126 .36554 .58476 .36946 Metetra
.807 .978 .692 r
.58476 .36946 .59126 .36554 .60408 .35052 .59767 .35348 Metetra
.821 .99 .732 r
.59767 .35348 .60408 .35052 .6169 .33628 .61057 .3383 Metetra
.81 .997 .776 r
.61057 .3383 .6169 .33628 .62974 .32353 .62349 .32468 Metetra
.765 .996 .825 r
.62349 .32468 .62974 .32353 .64266 .31291 .63647 .31331 Metetra
.668 .975 .873 r
.63647 .31331 .64266 .31291 .6557 .30502 .64958 .30479 Metetra
.489 .901 .896 r
.64958 .30479 .6557 .30502 .66892 .3003 .66286 .2996 Metetra
.214 .735 .848 r
.66286 .2996 .66892 .3003 .68238 .29905 .67637 .29801 Metetra
0 .497 .716 r
.67637 .29801 .68238 .29905 .69612 .30131 .69016 .30004 Metetra
.323 0 0 r
.69016 .30004 .69612 .30131 .71018 .30686 .70427 .3054 Metetra
.456 0 0 r
.70427 .3054 .71018 .30686 .72456 .31506 .7187 .31337 Metetra
.499 0 0 r
.7187 .31337 .72456 .31506 .73923 .3248 .73339 .32268 Metetra
0 .348 .666 r
.73339 .32268 .73923 .3248 .75409 .33436 .74799 .32794 Metetra
.65 .809 .96 r
.74799 .32794 .75409 .33436 .76821 .33184 .76201 .32331 Metetra
.657 .749 .918 r
.76201 .32331 .76821 .33184 .78224 .32723 .7761 .31866 Metetra
.657 .749 .918 r
.7761 .31866 .78224 .32723 .79635 .3226 .79025 .31399 Metetra
.657 .749 .918 r
.79025 .31399 .79635 .3226 .81052 .31794 .80447 .30929 Metetra
.657 .749 .918 r
.80447 .30929 .81052 .31794 .82477 .31327 .81877 .30457 Metetra
.657 .749 .918 r
.81877 .30457 .82477 .31327 .83908 .30857 .83313 .29983 Metetra
.657 .749 .918 r
.196 .50059 .20393 .5076 .2154 .50381 .2075 .49677 Metetra
.657 .749 .918 r
.2075 .49677 .2154 .50381 .22693 .5 .21906 .49293 Metetra
.657 .749 .918 r
.21906 .49293 .22693 .5 .23851 .49618 .23067 .48908 Metetra
.657 .749 .918 r
.23067 .48908 .23851 .49618 .25014 .49234 .24233 .4852 Metetra
.657 .749 .918 r
.24233 .4852 .25014 .49234 .26182 .48848 .25404 .48132 Metetra
.657 .749 .918 r
.25404 .48132 .26182 .48848 .27355 .48461 .2658 .47741 Metetra
.672 .753 .911 r
.2658 .47741 .27355 .48461 .28579 .47448 .27766 .47303 Metetra
.907 .882 .798 r
.27766 .47303 .28579 .47448 .29854 .45705 .29044 .45627 Metetra
.909 .902 .806 r
.29044 .45627 .29854 .45705 .31119 .44048 .30315 .44007 Metetra
.893 .929 .835 r
.30315 .44007 .31119 .44048 .32367 .42614 .31569 .42597 Metetra
.845 .961 .883 r
.31569 .42597 .32367 .42614 .33594 .41487 .32803 .41494 Metetra
.719 .972 .93 r
.32803 .41494 .33594 .41487 .34802 .40708 .34016 .40744 Metetra
.422 .866 .888 r
.34016 .40744 .34802 .40708 .35995 .40283 .35213 .40359 Metetra
.023 0 0 r
.35213 .40359 .35995 .40283 .37177 .40192 .36397 .4032 Metetra
.361 0 0 r
.36397 .4032 .37177 .40192 .38354 .40396 .37576 .40589 Metetra
.533 0 0 r
.37576 .40589 .38354 .40396 .39531 .40839 .38755 .41107 Metetra
.612 .087 0 r
.38755 .41107 .39531 .40839 .40713 .41457 .39939 .41808 Metetra
.645 .141 .035 r
.39939 .41808 .40713 .41457 .41906 .42176 .41133 .42615 Metetra
.65 .159 .072 r
.41133 .42615 .41906 .42176 .43111 .42921 .42341 .43448 Metetra
.636 .152 .086 r
.42341 .43448 .43111 .42921 .44333 .43619 .43566 .44229 Metetra
.602 .121 .083 r
.43566 .44229 .44333 .43619 .45571 .44199 .44809 .44883 Metetra
.548 .066 .063 r
.44809 .44883 .45571 .44199 .46826 .446 .4607 .45344 Metetra
.467 0 .023 r
.4607 .45344 .46826 .446 .48096 .4477 .47348 .45557 Metetra
.352 0 0 r
.47348 .45557 .48096 .4477 .49379 .44674 .48641 .45483 Metetra
.195 0 0 r
.48641 .45483 .49379 .44674 .50672 .4429 .49944 .451 Metetra
.49944 .451 .50672 .4429 .51973 .43616 .51256 .44405 Metetra
.51256 .44405 .51973 .43616 .53277 .42667 .52571 .43413 Metetra
.52571 .43413 .53277 .42667 .54581 .41472 .53887 .42158 Metetra
.593 .867 .535 r
.53887 .42158 .54581 .41472 .55883 .4008 .55201 .4069 Metetra
.707 .925 .595 r
.55201 .4069 .55883 .4008 .57182 .38549 .5651 .39072 Metetra
.778 .957 .639 r
.5651 .39072 .57182 .38549 .58476 .36946 .57815 .37376 Metetra
.816 .975 .676 r
.57815 .37376 .58476 .36946 .59767 .35348 .59116 .35683 Metetra
.829 .986 .714 r
.59116 .35683 .59767 .35348 .61057 .3383 .60415 .34074 Metetra
.816 .994 .755 r
.60415 .34074 .61057 .3383 .62349 .32468 .61715 .32627 Metetra
.771 .995 .802 r
.61715 .32627 .62349 .32468 .63647 .31331 .63021 .31415 Metetra
.673 .976 .849 r
.63021 .31415 .63647 .31331 .64958 .30479 .64338 .30502 Metetra
.489 .903 .871 r
.64338 .30502 .64958 .30479 .66286 .2996 .65673 .29933 Metetra
.209 .734 .821 r
.65673 .29933 .66286 .2996 .67637 .29801 .6703 .29735 Metetra
.096 0 0 r
.6703 .29735 .67637 .29801 .69016 .30004 .68414 .29908 Metetra
.323 0 0 r
.68414 .29908 .69016 .30004 .70427 .3054 .6983 .30415 Metetra
.444 0 0 r
.6983 .30415 .70427 .3054 .7187 .31337 .71276 .31172 Metetra
.47 0 0 r
.71276 .31172 .7187 .31337 .73339 .32268 .72746 .32037 Metetra
.283 .756 .937 r
.72746 .32037 .73339 .32268 .74799 .32794 .74169 .31938 Metetra
.657 .749 .918 r
.74169 .31938 .74799 .32794 .76201 .32331 .75576 .31471 Metetra
.657 .749 .918 r
.75576 .31471 .76201 .32331 .7761 .31866 .76989 .31001 Metetra
.657 .749 .918 r
.76989 .31001 .7761 .31866 .79025 .31399 .7841 .3053 Metetra
.657 .749 .918 r
.7841 .3053 .79025 .31399 .80447 .30929 .79837 .30056 Metetra
.657 .749 .918 r
.79837 .30056 .80447 .30929 .81877 .30457 .81271 .29579 Metetra
.657 .749 .918 r
.81271 .29579 .81877 .30457 .83313 .29983 .82713 .29101 Metetra
.657 .749 .918 r
.18801 .49352 .196 .50059 .2075 .49677 .19954 .48967 Metetra
.657 .749 .918 r
.19954 .48967 .2075 .49677 .21906 .49293 .21113 .4858 Metetra
.657 .749 .918 r
.21113 .4858 .21906 .49293 .23067 .48908 .22276 .48191 Metetra
.657 .749 .918 r
.22276 .48191 .23067 .48908 .24233 .4852 .23445 .47801 Metetra
.657 .749 .918 r
.23445 .47801 .24233 .4852 .25404 .48132 .2462 .47409 Metetra
.657 .749 .918 r
.2462 .47409 .25404 .48132 .2658 .47741 .25799 .47015 Metetra
.657 .749 .918 r
.25799 .47015 .2658 .47741 .27766 .47303 .26984 .46619 Metetra
.807 .781 .829 r
.26984 .46619 .27766 .47303 .29044 .45627 .28227 .4552 Metetra
.903 .901 .814 r
.28227 .4552 .29044 .45627 .30315 .44007 .29502 .43955 Metetra
.888 .931 .842 r
.29502 .43955 .30315 .44007 .31569 .42597 .30761 .42582 Metetra
.836 .964 .889 r
.30761 .42582 .31569 .42597 .32803 .41494 .32 .41509 Metetra
.696 .969 .931 r
.32 .41509 .32803 .41494 .34016 .40744 .33218 .40793 Metetra
.365 .835 .863 r
.33218 .40793 .34016 .40744 .35213 .40359 .34419 .40449 Metetra
.093 0 0 r
.34419 .40449 .35213 .40359 .36397 .4032 .35606 .40462 Metetra
.41 0 0 r
.35606 .40462 .36397 .4032 .37576 .40589 .36787 .40792 Metetra
.565 .016 0 r
.36787 .40792 .37576 .40589 .38755 .41107 .37967 .41383 Metetra
.635 .117 0 r
.37967 .41383 .38755 .41107 .39939 .41808 .39152 .42163 Metetra
.664 .166 .054 r
.39152 .42163 .39939 .41808 .41133 .42615 .40348 .43054 Metetra
.667 .181 .086 r
.40348 .43054 .41133 .42615 .42341 .43448 .41559 .4397 Metetra
.652 .17 .097 r
.41559 .4397 .42341 .43448 .43566 .44229 .42787 .4483 Metetra
.617 .137 .09 r
.42787 .4483 .43566 .44229 .44809 .44883 .44035 .45555 Metetra
.562 .078 .065 r
.44035 .45555 .44809 .44883 .4607 .45344 .45302 .46073 Metetra
.477 0 .02 r
.45302 .46073 .4607 .45344 .47348 .45557 .46588 .46326 Metetra
.354 0 0 r
.46588 .46326 .47348 .45557 .48641 .45483 .47889 .46274 Metetra
.183 0 0 r
.47889 .46274 .48641 .45483 .49944 .451 .49203 .45892 Metetra
.49203 .45892 .49944 .451 .51256 .44405 .50525 .45176 Metetra
.50525 .45176 .51256 .44405 .52571 .43413 .51852 .44144 Metetra
.51852 .44144 .52571 .43413 .53887 .42158 .5318 .4283 Metetra
.641 .893 .561 r
.5318 .4283 .53887 .42158 .55201 .4069 .54506 .4129 Metetra
.745 .941 .611 r
.54506 .4129 .55201 .4069 .5651 .39072 .55827 .39588 Metetra
.807 .965 .647 r
.55827 .39588 .5651 .39072 .57815 .37376 .57144 .37804 Metetra
.84 .978 .679 r
.57144 .37804 .57815 .37376 .59116 .35683 .58455 .36021 Metetra
.848 .987 .711 r
.58455 .36021 .59116 .35683 .60415 .34074 .59764 .34324 Metetra
.834 .994 .749 r
.59764 .34324 .60415 .34074 .61715 .32627 .61073 .32796 Metetra
.79 .997 .795 r
.61073 .32796 .61715 .32627 .63021 .31415 .62387 .31512 Metetra
.694 .982 .842 r
.62387 .31512 .63021 .31415 .64338 .30502 .63711 .30538 Metetra
.513 .915 .867 r
.63711 .30538 .64338 .30502 .65673 .29933 .65052 .29919 Metetra
.234 .752 .823 r
.65052 .29919 .65673 .29933 .6703 .29735 .66414 .29679 Metetra
.072 0 0 r
.66414 .29679 .6703 .29735 .68414 .29908 .67804 .29815 Metetra
.296 0 0 r
.67804 .29815 .68414 .29908 .6983 .30415 .69224 .3028 Metetra
.409 0 0 r
.69224 .3028 .6983 .30415 .71276 .31172 .70672 .3098 Metetra
.285 0 0 r
.70672 .3098 .71276 .31172 .72746 .32037 .72129 .31543 Metetra
.633 .855 .984 r
.72129 .31543 .72746 .32037 .74169 .31938 .73534 .31074 Metetra
.657 .749 .918 r
.73534 .31074 .74169 .31938 .75576 .31471 .74945 .30603 Metetra
.657 .749 .918 r
.74945 .30603 .75576 .31471 .76989 .31001 .76363 .30129 Metetra
.657 .749 .918 r
.76363 .30129 .76989 .31001 .7841 .3053 .77788 .29653 Metetra
.657 .749 .918 r
.77788 .29653 .7841 .3053 .79837 .30056 .79221 .29175 Metetra
.657 .749 .918 r
.79221 .29175 .79837 .30056 .81271 .29579 .8066 .28694 Metetra
.657 .749 .918 r
.8066 .28694 .81271 .29579 .82713 .29101 .82107 .28211 Metetra
.657 .749 .918 r
.17995 .4864 .18801 .49352 .19954 .48967 .19151 .48251 Metetra
.657 .749 .918 r
.19151 .48251 .19954 .48967 .21113 .4858 .20313 .47861 Metetra
.657 .749 .918 r
.20313 .47861 .21113 .4858 .22276 .48191 .21479 .47469 Metetra
.657 .749 .918 r
.21479 .47469 .22276 .48191 .23445 .47801 .22652 .47076 Metetra
.657 .749 .918 r
.22652 .47076 .23445 .47801 .2462 .47409 .23829 .4668 Metetra
.657 .749 .918 r
.23829 .4668 .2462 .47409 .25799 .47015 .25012 .46283 Metetra
.657 .749 .918 r
.25012 .46283 .25799 .47015 .26984 .46619 .262 .45884 Metetra
.696 .759 .9 r
.262 .45884 .26984 .46619 .28227 .4552 .27403 .45357 Metetra
.893 .894 .823 r
.27403 .45357 .28227 .4552 .29502 .43955 .28681 .43865 Metetra
.88 .926 .85 r
.28681 .43865 .29502 .43955 .30761 .42582 .29945 .4254 Metetra
.828 .96 .897 r
.29945 .4254 .30761 .42582 .32 .41509 .31189 .41506 Metetra
.68 .963 .938 r
.31189 .41506 .32 .41509 .33218 .40793 .32411 .40826 Metetra
.332 .815 .86 r
.32411 .40826 .33218 .40793 .34419 .40449 .33615 .40523 Metetra
.133 0 0 r
.33615 .40523 .34419 .40449 .35606 .40462 .34805 .40585 Metetra
.439 0 0 r
.34805 .40585 .35606 .40462 .36787 .40792 .35987 .40974 Metetra
.586 .04 0 r
.35987 .40974 .36787 .40792 .37967 .41383 .37169 .41631 Metetra
.653 .136 0 r
.37169 .41631 .37967 .41383 .39152 .42163 .38355 .42485 Metetra
.68 .182 .056 r
.38355 .42485 .39152 .42163 .40348 .43054 .39552 .43452 Metetra
.682 .194 .084 r
.39552 .43452 .40348 .43054 .41559 .4397 .40765 .44446 Metetra
.666 .181 .091 r
.40765 .44446 .41559 .4397 .42787 .4483 .41997 .4538 Metetra
.63 .144 .08 r
.41997 .4538 .42787 .4483 .44035 .45555 .43249 .46169 Metetra
.572 .08 .049 r
.43249 .46169 .44035 .45555 .45302 .46073 .44522 .46741 Metetra
.481 0 0 r
.44522 .46741 .45302 .46073 .46588 .46326 .45815 .47032 Metetra
.344 0 0 r
.45815 .47032 .46588 .46326 .47889 .46274 .47125 .46999 Metetra
.151 0 0 r
.47125 .46999 .47889 .46274 .49203 .45892 .48448 .46618 Metetra
.48448 .46618 .49203 .45892 .50525 .45176 .49782 .45883 Metetra
.49782 .45883 .50525 .45176 .51852 .44144 .51121 .44812 Metetra
.563 .862 .552 r
.51121 .44812 .51852 .44144 .5318 .4283 .52461 .43444 Metetra
.709 .932 .61 r
.52461 .43444 .5318 .4283 .54506 .4129 .53799 .41836 Metetra
.798 .963 .645 r
.53799 .41836 .54506 .4129 .55827 .39588 .55132 .40057 Metetra
.847 .975 .67 r
.55132 .40057 .55827 .39588 .57144 .37804 .5646 .3819 Metetra
.871 .982 .694 r
.5646 .3819 .57144 .37804 .58455 .36021 .57782 .36322 Metetra
.876 .988 .721 r
.57782 .36322 .58455 .36021 .59764 .34324 .59101 .34544 Metetra
.86 .994 .756 r
.59101 .34544 .59764 .34324 .61073 .32796 .60419 .3294 Metetra
.818 1 .8 r
.60419 .3294 .61073 .32796 .62387 .31512 .61742 .31589 Metetra
.728 .99 .849 r
.61742 .31589 .62387 .31512 .63711 .30538 .63074 .30556 Metetra
.558 .934 .882 r
.63074 .30556 .63711 .30538 .65052 .29919 .64421 .29887 Metetra
.287 .786 .851 r
.64421 .29887 .65052 .29919 .66414 .29679 .6579 .29603 Metetra
0 .561 .742 r
.6579 .29603 .66414 .29679 .67804 .29815 .67184 .29695 Metetra
.241 0 0 r
.67184 .29695 .67804 .29815 .69224 .3028 .68608 .30108 Metetra
.344 0 0 r
.68608 .30108 .69224 .3028 .70672 .3098 .70058 .30735 Metetra
.256 .736 .932 r
.70058 .30735 .70672 .3098 .72129 .31543 .71483 .30675 Metetra
.657 .749 .918 r
.71483 .30675 .72129 .31543 .73534 .31074 .72892 .30202 Metetra
.657 .749 .918 r
.72892 .30202 .73534 .31074 .74945 .30603 .74308 .29726 Metetra
.657 .749 .918 r
.74308 .29726 .74945 .30603 .76363 .30129 .75731 .29248 Metetra
.657 .749 .918 r
.75731 .29248 .76363 .30129 .77788 .29653 .77162 .28768 Metetra
.657 .749 .918 r
.77162 .28768 .77788 .29653 .79221 .29175 .78599 .28285 Metetra
.657 .749 .918 r
.78599 .28285 .79221 .29175 .8066 .28694 .80044 .278 Metetra
.657 .749 .918 r
.80044 .278 .8066 .28694 .82107 .28211 .81496 .27312 Metetra
.657 .749 .918 r
.17182 .47921 .17995 .4864 .19151 .48251 .18341 .4753 Metetra
.657 .749 .918 r
.18341 .4753 .19151 .48251 .20313 .47861 .19506 .47136 Metetra
.657 .749 .918 r
.19506 .47136 .20313 .47861 .21479 .47469 .20676 .46741 Metetra
.657 .749 .918 r
.20676 .46741 .21479 .47469 .22652 .47076 .21851 .46344 Metetra
.657 .749 .918 r
.21851 .46344 .22652 .47076 .23829 .4668 .23031 .45945 Metetra
.657 .749 .918 r
.23031 .45945 .23829 .4668 .25012 .46283 .24217 .45545 Metetra
.657 .749 .918 r
.24217 .45545 .25012 .46283 .262 .45884 .25409 .45142 Metetra
.657 .749 .918 r
.25409 .45142 .262 .45884 .27403 .45357 .26605 .44738 Metetra
.804 .802 .85 r
.26605 .44738 .27403 .45357 .28681 .43865 .27855 .43708 Metetra
.869 .915 .858 r
.27855 .43708 .28681 .43865 .29945 .4254 .29122 .42444 Metetra
.819 .95 .906 r
.29122 .42444 .29945 .4254 .31189 .41506 .3037 .41454 Metetra
.673 .954 .951 r
.3037 .41454 .31189 .41506 .32411 .40826 .31596 .40813 Metetra
.324 .807 .879 r
.31596 .40813 .32411 .40826 .33615 .40523 .32803 .4055 Metetra
.145 0 0 r
.32803 .4055 .33615 .40523 .34805 .40585 .33995 .40658 Metetra
.454 0 0 r
.33995 .40658 .34805 .40585 .35987 .40974 .35179 .41099 Metetra
.6 .051 0 r
.35179 .41099 .35987 .40974 .37169 .41631 .36362 .41817 Metetra
.667 .146 0 r
.36362 .41817 .37169 .41631 .38355 .42485 .37549 .42736 Metetra
.693 .19 .042 r
.37549 .42736 .38355 .42485 .39552 .43452 .38748 .43772 Metetra
.695 .201 .067 r
.38748 .43772 .39552 .43452 .40765 .44446 .39962 .44835 Metetra
.678 .186 .071 r
.39962 .44835 .40765 .44446 .41997 .4538 .41196 .45834 Metetra
.641 .144 .053 r
.41196 .45834 .41997 .4538 .43249 .46169 .42452 .46682 Metetra
.578 .072 .014 r
.42452 .46682 .43249 .46169 .44522 .46741 .43731 .47301 Metetra
.477 0 0 r
.43731 .47301 .44522 .46741 .45815 .47032 .4503 .47627 Metetra
.319 0 0 r
.4503 .47627 .45815 .47032 .47125 .46999 .46349 .47612 Metetra
.089 0 0 r
.46349 .47612 .47125 .46999 .48448 .46618 .47682 .4723 Metetra
.47682 .4723 .48448 .46618 .49782 .45883 .49026 .46477 Metetra
.467 .828 .567 r
.49026 .46477 .49782 .45883 .51121 .44812 .50376 .45372 Metetra
.666 .929 .638 r
.50376 .45372 .51121 .44812 .52461 .43444 .51729 .43954 Metetra
.787 .969 .671 r
.51729 .43954 .52461 .43444 .53799 .41836 .53079 .42284 Metetra
.854 .981 .688 r
.53079 .42284 .53799 .41836 .55132 .40057 .54425 .40434 Metetra
.889 .982 .7 r
.54425 .40434 .55132 .40057 .5646 .3819 .55764 .38492 Metetra
.904 .982 .715 r
.55764 .38492 .5646 .3819 .57782 .36322 .57098 .36549 Metetra
.904 .984 .737 r
.57098 .36549 .57782 .36322 .59101 .34544 .58427 .34697 Metetra
.888 .991 .768 r
.58427 .34697 .59101 .34544 .60419 .3294 .59754 .33025 Metetra
.849 .998 .812 r
.59754 .33025 .60419 .3294 .61742 .31589 .61086 .31613 Metetra
.769 .995 .864 r
.61086 .31613 .61742 .31589 .63074 .30556 .62425 .30525 Metetra
.616 .954 .907 r
.62425 .30525 .63074 .30556 .64421 .29887 .6378 .29808 Metetra
.363 .83 .898 r
.6378 .29808 .64421 .29887 .6579 .29603 .65154 .29478 Metetra
.068 .624 .81 r
.65154 .29478 .6579 .29603 .67184 .29695 .66554 .2952 Metetra
0 .435 .706 r
.66554 .2952 .67184 .29695 .68608 .30108 .6798 .29869 Metetra
0 .432 .736 r
.6798 .29869 .68608 .30108 .70058 .30735 .69424 .30275 Metetra
.626 .866 .988 r
.69424 .30275 .70058 .30735 .71483 .30675 .70831 .298 Metetra
.657 .749 .918 r
.70831 .298 .71483 .30675 .72892 .30202 .72245 .29322 Metetra
.657 .749 .918 r
.72245 .29322 .72892 .30202 .74308 .29726 .73666 .28842 Metetra
.657 .749 .918 r
.73666 .28842 .74308 .29726 .75731 .29248 .75094 .2836 Metetra
.657 .749 .918 r
.75094 .2836 .75731 .29248 .77162 .28768 .76529 .27875 Metetra
.657 .749 .918 r
.76529 .27875 .77162 .28768 .78599 .28285 .77972 .27387 Metetra
.657 .749 .918 r
.77972 .27387 .78599 .28285 .80044 .278 .79421 .26898 Metetra
.657 .749 .918 r
.79421 .26898 .80044 .278 .81496 .27312 .80879 .26406 Metetra
.657 .749 .918 r
.16362 .47197 .17182 .47921 .18341 .4753 .17525 .46802 Metetra
.657 .749 .918 r
.17525 .46802 .18341 .4753 .19506 .47136 .18692 .46405 Metetra
.657 .749 .918 r
.18692 .46405 .19506 .47136 .20676 .46741 .19865 .46007 Metetra
.657 .749 .918 r
.19865 .46007 .20676 .46741 .21851 .46344 .21044 .45607 Metetra
.657 .749 .918 r
.21044 .45607 .21851 .46344 .23031 .45945 .22227 .45205 Metetra
.657 .749 .918 r
.22227 .45205 .23031 .45945 .24217 .45545 .23416 .44801 Metetra
.657 .749 .918 r
.23416 .44801 .24217 .45545 .25409 .45142 .24611 .44395 Metetra
.657 .749 .918 r
.24611 .44395 .25409 .45142 .26605 .44738 .25811 .43987 Metetra
.693 .758 .902 r
.25811 .43987 .26605 .44738 .27855 .43708 .27026 .4346 Metetra
.854 .897 .866 r
.27026 .4346 .27855 .43708 .29122 .42444 .28295 .42268 Metetra
.809 .932 .914 r
.28295 .42268 .29122 .42444 .3037 .41454 .29545 .41328 Metetra
.672 .939 .965 r
.29545 .41328 .3037 .41454 .31596 .40813 .30775 .40727 Metetra
.339 .809 .915 r
.30775 .40727 .31596 .40813 .32803 .4055 .31985 .40503 Metetra
.13 0 0 r
.31985 .40503 .32803 .4055 .33995 .40658 .33179 .40651 Metetra
.452 0 0 r
.33179 .40651 .33995 .40658 .35179 .41099 .34365 .41137 Metetra
.606 .048 0 r
.34365 .41137 .35179 .41099 .36362 .41817 .35548 .41905 Metetra
.675 .146 0 r
.35548 .41905 .36362 .41817 .37549 .42736 .36736 .4288 Metetra
.703 .191 .01 r
.36736 .4288 .37549 .42736 .38748 .43772 .37936 .43974 Metetra
.706 .201 .034 r
.37936 .43974 .38748 .43772 .39962 .44835 .39152 .45096 Metetra
.689 .183 .032 r
.39152 .45096 .39962 .44835 .41196 .45834 .40388 .46152 Metetra
.649 .135 .006 r
.40388 .46152 .41196 .45834 .42452 .46682 .41648 .4705 Metetra
.579 .051 0 r
.41648 .4705 .42452 .46682 .43731 .47301 .42931 .4771 Metetra
.461 0 0 r
.42931 .4771 .43731 .47301 .4503 .47627 .44236 .48065 Metetra
.269 0 0 r
.44236 .48065 .4503 .47627 .46349 .47612 .45562 .48064 Metetra
.45562 .48064 .46349 .47612 .47682 .4723 .46905 .47682 Metetra
.46905 .47682 .47682 .4723 .49026 .46477 .48259 .46913 Metetra
.606 .927 .697 r
.48259 .46913 .49026 .46477 .50376 .45372 .49621 .45777 Metetra
.769 .982 .728 r
.49621 .45777 .50376 .45372 .51729 .43954 .50985 .44315 Metetra
.856 .991 .731 r
.50985 .44315 .51729 .43954 .53079 .42284 .52347 .42591 Metetra
.901 .984 .728 r
.52347 .42591 .53079 .42284 .54425 .40434 .53705 .40681 Metetra
.922 .976 .729 r
.53705 .40681 .54425 .40434 .55764 .38492 .55056 .38674 Metetra
.929 .972 .736 r
.55056 .38674 .55764 .38492 .57098 .36549 .56401 .36665 Metetra
.926 .972 .753 r
.56401 .36665 .57098 .36549 .58427 .34697 .5774 .34749 Metetra
.91 .978 .782 r
.5774 .34749 .58427 .34697 .59754 .33025 .59078 .33018 Metetra
.876 .987 .824 r
.59078 .33018 .59754 .33025 .61086 .31613 .60418 .31552 Metetra
.807 .99 .879 r
.60418 .31552 .61086 .31613 .62425 .30525 .61765 .30416 Metetra
.675 .965 .933 r
.61765 .30416 .62425 .30525 .6378 .29808 .63127 .29653 Metetra
.452 .868 .947 r
.63127 .29653 .6378 .29808 .65154 .29478 .64507 .29276 Metetra
.179 .694 .89 r
.64507 .29276 .65154 .29478 .66554 .2952 .65911 .29263 Metetra
0 .526 .81 r
.65911 .29263 .66554 .2952 .6798 .29869 .6734 .29539 Metetra
.374 .788 .979 r
.6734 .29539 .6798 .29869 .69424 .30275 .6876 .29396 Metetra
.657 .749 .918 r
.6876 .29396 .69424 .30275 .70831 .298 .70172 .28916 Metetra
.657 .749 .918 r
.70172 .28916 .70831 .298 .72245 .29322 .71591 .28434 Metetra
.657 .749 .918 r
.71591 .28434 .72245 .29322 .73666 .28842 .73017 .27949 Metetra
.657 .749 .918 r
.73017 .27949 .73666 .28842 .75094 .2836 .7445 .27463 Metetra
.657 .749 .918 r
.7445 .27463 .75094 .2836 .76529 .27875 .75891 .26973 Metetra
.657 .749 .918 r
.75891 .26973 .76529 .27875 .77972 .27387 .77338 .26481 Metetra
.657 .749 .918 r
.77338 .26481 .77972 .27387 .79421 .26898 .78793 .25987 Metetra
.657 .749 .918 r
.78793 .25987 .79421 .26898 .80879 .26406 .80256 .2549 Metetra
.657 .749 .918 r
.15536 .46467 .16362 .47197 .17525 .46802 .16701 .46068 Metetra
.657 .749 .918 r
.16701 .46068 .17525 .46802 .18692 .46405 .17872 .45668 Metetra
.657 .749 .918 r
.17872 .45668 .18692 .46405 .19865 .46007 .19048 .45267 Metetra
.657 .749 .918 r
.19048 .45267 .19865 .46007 .21044 .45607 .2023 .44863 Metetra
.657 .749 .918 r
.2023 .44863 .21044 .45607 .22227 .45205 .21416 .44457 Metetra
.657 .749 .918 r
.21416 .44457 .22227 .45205 .23416 .44801 .22609 .4405 Metetra
.657 .749 .918 r
.22609 .4405 .23416 .44801 .24611 .44395 .23806 .43641 Metetra
.657 .749 .918 r
.23806 .43641 .24611 .44395 .25811 .43987 .2501 .43229 Metetra
.657 .749 .918 r
.2501 .43229 .25811 .43987 .27026 .4346 .26218 .42816 Metetra
.768 .8 .879 r
.26218 .42816 .27026 .4346 .28295 .42268 .27465 .41987 Metetra
.795 .905 .918 r
.27465 .41987 .28295 .42268 .29545 .41328 .28718 .41103 Metetra
.673 .916 .975 r
.28718 .41103 .29545 .41328 .30775 .40727 .2995 .40544 Metetra
.372 .812 .957 r
.2995 .40544 .30775 .40727 .31985 .40503 .31163 .40354 Metetra
0 .499 .723 r
.31163 .40354 .31985 .40503 .33179 .40651 .32359 .40536 Metetra
.43 0 0 r
.32359 .40536 .33179 .40651 .34365 .41137 .33546 .41058 Metetra
.6 .031 0 r
.33546 .41058 .34365 .41137 .35548 .41905 .3473 .41866 Metetra
.676 .135 0 r
.3473 .41866 .35548 .41905 .36736 .4288 .35919 .42884 Metetra
.708 .183 0 r
.35919 .42884 .36736 .4288 .37936 .43974 .37119 .44025 Metetra
.712 .192 0 r
.37119 .44025 .37936 .43974 .39152 .45096 .38336 .45194 Metetra
.694 .17 0 r
.38336 .45194 .39152 .45096 .40388 .46152 .39574 .46294 Metetra
.65 .113 0 r
.39574 .46294 .40388 .46152 .41648 .4705 .40837 .47233 Metetra
.568 .011 0 r
.40837 .47233 .41648 .4705 .42931 .4771 .42124 .47925 Metetra
.422 0 0 r
.42124 .47925 .42931 .4771 .44236 .48065 .43435 .48303 Metetra
.176 0 0 r
.43435 .48303 .44236 .48065 .45562 .48064 .44768 .48314 Metetra
.44768 .48314 .45562 .48064 .46905 .47682 .46119 .47931 Metetra
.514 .908 .784 r
.46119 .47931 .46905 .47682 .48259 .46913 .47483 .47148 Metetra
.735 .99 .813 r
.47483 .47148 .48259 .46913 .49621 .45777 .48855 .45985 Metetra
.848 .998 .797 r
.48855 .45985 .49621 .45777 .50985 .44315 .5023 .44488 Metetra
.903 .984 .774 r
.5023 .44488 .50985 .44315 .52347 .42591 .51604 .42718 Metetra
.929 .968 .757 r
.51604 .42718 .52347 .42591 .53705 .40681 .52973 .40757 Metetra
.94 .956 .75 r
.52973 .40757 .53705 .40681 .55056 .38674 .54336 .38697 Metetra
.942 .95 .752 r
.54336 .38697 .55056 .38674 .56401 .36665 .55691 .36635 Metetra
.937 .95 .765 r
.55691 .36635 .56401 .36665 .5774 .34749 .57042 .34668 Metetra
.922 .955 .791 r
.57042 .34668 .5774 .34749 .59078 .33018 .58389 .32888 Metetra
.892 .965 .831 r
.58389 .32888 .59078 .33018 .60418 .31552 .59738 .31378 Metetra
.834 .971 .886 r
.59738 .31378 .60418 .31552 .61765 .30416 .61093 .302 Metetra
.724 .957 .947 r
.61093 .302 .61765 .30416 .63127 .29653 .62462 .29395 Metetra
.538 .888 .982 r
.62462 .29395 .63127 .29653 .64507 .29276 .63848 .28972 Metetra
.303 .753 .959 r
.63848 .28972 .64507 .29276 .65911 .29263 .65255 .28899 Metetra
.207 .675 .94 r
.65255 .28899 .65911 .29263 .6734 .29539 .66681 .2899 Metetra
.64 .844 .978 r
.66681 .2899 .6734 .29539 .6876 .29396 .68091 .28508 Metetra
.657 .749 .918 r
.68091 .28508 .6876 .29396 .70172 .28916 .69508 .28024 Metetra
.657 .749 .918 r
.69508 .28024 .70172 .28916 .71591 .28434 .70932 .27538 Metetra
.657 .749 .918 r
.70932 .27538 .71591 .28434 .73017 .27949 .72363 .27049 Metetra
.657 .749 .918 r
.72363 .27049 .73017 .27949 .7445 .27463 .73801 .26557 Metetra
.657 .749 .918 r
.73801 .26557 .7445 .27463 .75891 .26973 .75246 .26063 Metetra
.657 .749 .918 r
.75246 .26063 .75891 .26973 .77338 .26481 .76699 .25567 Metetra
.657 .749 .918 r
.76699 .25567 .77338 .26481 .78793 .25987 .78159 .25068 Metetra
.657 .749 .918 r
.78159 .25068 .78793 .25987 .80256 .2549 .79627 .24566 Metetra
.657 .749 .918 r
.14703 .4573 .15536 .46467 .16701 .46068 .15871 .45328 Metetra
.657 .749 .918 r
.15871 .45328 .16701 .46068 .17872 .45668 .17045 .44925 Metetra
.657 .749 .918 r
.17045 .44925 .17872 .45668 .19048 .45267 .18224 .4452 Metetra
.657 .749 .918 r
.18224 .4452 .19048 .45267 .2023 .44863 .19409 .44113 Metetra
.657 .749 .918 r
.19409 .44113 .2023 .44863 .21416 .44457 .20598 .43704 Metetra
.657 .749 .918 r
.20598 .43704 .21416 .44457 .22609 .4405 .21794 .43293 Metetra
.657 .749 .918 r
.21794 .43293 .22609 .4405 .23806 .43641 .22995 .4288 Metetra
.657 .749 .918 r
.22995 .4288 .23806 .43641 .2501 .43229 .24201 .42465 Metetra
.657 .749 .918 r
.24201 .42465 .2501 .43229 .26218 .42816 .25414 .42049 Metetra
.673 .754 .911 r
.25414 .42049 .26218 .42816 .27465 .41987 .26635 .41581 Metetra
.778 .871 .916 r
.26635 .41581 .27465 .41987 .28718 .41103 .27889 .40758 Metetra
.672 .882 .976 r
.27889 .40758 .28718 .41103 .2995 .40544 .29124 .40239 Metetra
.413 .804 .988 r
.29124 .40239 .2995 .40544 .31163 .40354 .30338 .4008 Metetra
0 .54 .815 r
.30338 .4008 .31163 .40354 .32359 .40536 .31537 .40288 Metetra
.381 0 0 r
.31537 .40288 .32359 .40536 .33546 .41058 .32725 .40837 Metetra
.575 0 0 r
.32725 .40837 .33546 .41058 .3473 .41866 .3391 .41672 Metetra
.664 .111 0 r
.3391 .41672 .3473 .41866 .35919 .42884 .35099 .4272 Metetra
.701 .163 0 r
.35099 .4272 .35919 .42884 .37119 .44025 .363 .43893 Metetra
.707 .172 0 r
.363 .43893 .37119 .44025 .38336 .45194 .37518 .45095 Metetra
.686 .144 0 r
.37518 .45095 .38336 .45194 .39574 .46294 .38757 .46227 Metetra
.634 .075 0 r
.38757 .46227 .39574 .46294 .40837 .47233 .40022 .47194 Metetra
.531 0 0 r
.40022 .47194 .40837 .47233 .42124 .47925 .41312 .4791 Metetra
.34 0 0 r
.41312 .4791 .42124 .47925 .43435 .48303 .42628 .48304 Metetra
.02 0 0 r
.42628 .48304 .43435 .48303 .44768 .48314 .43967 .48323 Metetra
.37 .837 .872 r
.43967 .48323 .44768 .48314 .46119 .47931 .45325 .47938 Metetra
.662 .968 .914 r
.45325 .47938 .46119 .47931 .47483 .47148 .46698 .47143 Metetra
.815 .988 .879 r
.46698 .47143 .47483 .47148 .48855 .45985 .4808 .4596 Metetra
.887 .972 .833 r
.4808 .4596 .48855 .45985 .5023 .44488 .49465 .44434 Metetra
.92 .951 .796 r
.49465 .44434 .5023 .44488 .51604 .42718 .5085 .4263 Metetra
.936 .934 .772 r
.5085 .4263 .51604 .42718 .52973 .40757 .52231 .40632 Metetra
.943 .922 .76 r
.52231 .40632 .52973 .40757 .54336 .38697 .53604 .38532 Metetra
.943 .917 .76 r
.53604 .38532 .54336 .38697 .55691 .36635 .54971 .36429 Metetra
.936 .917 .77 r
.54971 .36429 .55691 .36635 .57042 .34668 .56331 .34425 Metetra
.923 .923 .794 r
.56331 .34425 .57042 .34668 .58389 .32888 .57688 .3261 Metetra
.896 .932 .832 r
.57688 .3261 .58389 .32888 .59738 .31378 .59046 .31066 Metetra
.847 .939 .884 r
.59046 .31066 .59738 .31378 .61093 .302 .60409 .29854 Metetra
.756 .93 .945 r
.60409 .29854 .61093 .302 .62462 .29395 .61784 .29013 Metetra
.606 .882 .991 r
.61784 .29013 .62462 .29395 .63848 .28972 .63176 .28544 Metetra
.417 .783 .995 r
.63176 .28544 .63848 .28972 .65255 .28899 .64587 .28407 Metetra
.545 .825 .998 r
.64587 .28407 .65255 .28899 .66681 .2899 .66001 .28099 Metetra
.657 .749 .918 r
.66001 .28099 .66681 .2899 .68091 .28508 .67416 .27613 Metetra
.657 .749 .918 r
.67416 .27613 .68091 .28508 .69508 .28024 .68837 .27124 Metetra
.657 .749 .918 r
.68837 .27124 .69508 .28024 .70932 .27538 .70266 .26633 Metetra
.657 .749 .918 r
.70266 .26633 .70932 .27538 .72363 .27049 .71702 .26139 Metetra
.657 .749 .918 r
.71702 .26139 .72363 .27049 .73801 .26557 .73145 .25643 Metetra
.657 .749 .918 r
.73145 .25643 .73801 .26557 .75246 .26063 .74596 .25145 Metetra
.657 .749 .918 r
.74596 .25145 .75246 .26063 .76699 .25567 .76054 .24644 Metetra
.657 .749 .918 r
.76054 .24644 .76699 .25567 .78159 .25068 .77519 .2414 Metetra
.657 .749 .918 r
.77519 .2414 .78159 .25068 .79627 .24566 .78992 .23634 Metetra
.657 .749 .918 r
.13863 .44987 .14703 .4573 .15871 .45328 .15034 .44582 Metetra
.657 .749 .918 r
.15034 .44582 .15871 .45328 .17045 .44925 .16211 .44175 Metetra
.657 .749 .918 r
.16211 .44175 .17045 .44925 .18224 .4452 .17393 .43767 Metetra
.657 .749 .918 r
.17393 .43767 .18224 .4452 .19409 .44113 .1858 .43356 Metetra
.657 .749 .918 r
.1858 .43356 .19409 .44113 .20598 .43704 .19774 .42944 Metetra
.657 .749 .918 r
.19774 .42944 .20598 .43704 .21794 .43293 .20972 .42529 Metetra
.657 .749 .918 r
.20972 .42529 .21794 .43293 .22995 .4288 .22176 .42113 Metetra
.657 .749 .918 r
.22176 .42113 .22995 .4288 .24201 .42465 .23386 .41695 Metetra
.657 .749 .918 r
.23386 .41695 .24201 .42465 .25414 .42049 .24602 .41274 Metetra
.657 .749 .918 r
.24602 .41274 .25414 .42049 .26635 .41581 .25823 .40852 Metetra
.704 .774 .906 r
.25823 .40852 .26635 .41581 .27889 .40758 .27062 .40276 Metetra
.667 .841 .966 r
.27062 .40276 .27889 .40758 .29124 .40239 .28298 .39797 Metetra
.453 .783 .998 r
.28298 .39797 .29124 .40239 .30338 .4008 .29515 .39664 Metetra
.079 .576 .894 r
.29515 .39664 .30338 .4008 .31537 .40288 .30715 .39889 Metetra
0 .279 .647 r
.30715 .39889 .31537 .40288 .32725 .40837 .31904 .40452 Metetra
.52 0 0 r
.31904 .40452 .32725 .40837 .3391 .41672 .3309 .41302 Metetra
.629 .07 0 r
.3309 .41302 .3391 .41672 .35099 .4272 .3428 .42365 Metetra
.674 .127 0 r
.3428 .42365 .35099 .4272 .363 .43893 .35481 .43554 Metetra
.681 .135 0 r
.35481 .43554 .363 .43893 .37518 .45095 .36699 .44773 Metetra
.654 .099 0 r
.36699 .44773 .37518 .45095 .38757 .46227 .37939 .45922 Metetra
.584 .012 0 r
.37939 .45922 .38757 .46227 .40022 .47194 .39206 .46906 Metetra
.443 0 0 r
.39206 .46906 .40022 .47194 .41312 .4791 .40499 .47635 Metetra
0 .397 .7 r
.40499 .47635 .41312 .4791 .42628 .48304 .41819 .48037 Metetra
.185 .688 .909 r
.41819 .48037 .42628 .48304 .43967 .48323 .43163 .4806 Metetra
.53 .878 .987 r
.43163 .4806 .43967 .48323 .45325 .47938 .44528 .47671 Metetra
.738 .936 .952 r
.44528 .47671 .45325 .47938 .46698 .47143 .45908 .46868 Metetra
.84 .934 .89 r
.45908 .46868 .46698 .47143 .4808 .4596 .47298 .45671 Metetra
.889 .917 .836 r
.47298 .45671 .4808 .4596 .49465 .44434 .48693 .44126 Metetra
.914 .901 .798 r
.48693 .44126 .49465 .44434 .5085 .4263 .50088 .423 Metetra
.927 .888 .774 r
.50088 .423 .5085 .4263 .52231 .40632 .51479 .40276 Metetra
.932 .881 .762 r
.51479 .40276 .52231 .40632 .53604 .38532 .52863 .38151 Metetra
.931 .878 .76 r
.52863 .38151 .53604 .38532 .54971 .36429 .5424 .36025 Metetra
.926 .879 .77 r
.5424 .36025 .54971 .36429 .56331 .34425 .5561 .33997 Metetra
.913 .884 .791 r
.5561 .33997 .56331 .34425 .57688 .3261 .56976 .3216 Metetra
.889 .892 .825 r
.56976 .3216 .57688 .3261 .59046 .31066 .58342 .30595 Metetra
.846 .897 .874 r
.58342 .30595 .59046 .31066 .60409 .29854 .59713 .29359 Metetra
.77 .89 .93 r
.59713 .29359 .60409 .29854 .61784 .29013 .61094 .28487 Metetra
.651 .854 .978 r
.61094 .28487 .61784 .29013 .63176 .28544 .62491 .27973 Metetra
.551 .803 .992 r
.62491 .27973 .63176 .28544 .64587 .28407 .63902 .27688 Metetra
.654 .798 .952 r
.63902 .27688 .64587 .28407 .66001 .28099 .65315 .27199 Metetra
.657 .749 .918 r
.65315 .27199 .66001 .28099 .67416 .27613 .66734 .26709 Metetra
.657 .749 .918 r
.66734 .26709 .67416 .27613 .68837 .27124 .6816 .26216 Metetra
.657 .749 .918 r
.6816 .26216 .68837 .27124 .70266 .26633 .69594 .2572 Metetra
.657 .749 .918 r
.69594 .2572 .70266 .26633 .71702 .26139 .71035 .25222 Metetra
.657 .749 .918 r
.71035 .25222 .71702 .26139 .73145 .25643 .72483 .24721 Metetra
.657 .749 .918 r
.72483 .24721 .73145 .25643 .74596 .25145 .73939 .24218 Metetra
.657 .749 .918 r
.73939 .24218 .74596 .25145 .76054 .24644 .75402 .23712 Metetra
.657 .749 .918 r
.75402 .23712 .76054 .24644 .77519 .2414 .76873 .23203 Metetra
.657 .749 .918 r
.76873 .23203 .77519 .2414 .78992 .23634 .78351 .22692 Metetra
.657 .749 .918 r
.13015 .44238 .13863 .44987 .15034 .44582 .1419 .4383 Metetra
.657 .749 .918 r
.1419 .4383 .15034 .44582 .16211 .44175 .15369 .43419 Metetra
.657 .749 .918 r
.15369 .43419 .16211 .44175 .17393 .43767 .16555 .43007 Metetra
.657 .749 .918 r
.16555 .43007 .17393 .43767 .1858 .43356 .17745 .42593 Metetra
.657 .749 .918 r
.17745 .42593 .1858 .43356 .19774 .42944 .18942 .42177 Metetra
.657 .749 .918 r
.18942 .42177 .19774 .42944 .20972 .42529 .20144 .41759 Metetra
.657 .749 .918 r
.20144 .41759 .20972 .42529 .22176 .42113 .21351 .41339 Metetra
.657 .749 .918 r
.21351 .41339 .22176 .42113 .23386 .41695 .22564 .40917 Metetra
.657 .749 .918 r
.22564 .40917 .23386 .41695 .24602 .41274 .23783 .40494 Metetra
.657 .749 .918 r
.23783 .40494 .24602 .41274 .25823 .40852 .25008 .40068 Metetra
.657 .749 .918 r
.25008 .40068 .25823 .40852 .27062 .40276 .26238 .3964 Metetra
.657 .793 .947 r
.26238 .3964 .27062 .40276 .28298 .39797 .27474 .39205 Metetra
.485 .749 .988 r
.27474 .39205 .28298 .39797 .29515 .39664 .28693 .3909 Metetra
.177 .595 .94 r
.28693 .3909 .29515 .39664 .30715 .39889 .29895 .39324 Metetra
0 .345 .762 r
.29895 .39324 .30715 .39889 .31904 .40452 .31086 .39889 Metetra
.425 0 0 r
.31086 .39889 .31904 .40452 .3309 .41302 .32273 .40738 Metetra
.556 .008 0 r
.32273 .40738 .3309 .41302 .3428 .42365 .33463 .418 Metetra
.611 .07 0 r
.33463 .418 .3428 .42365 .35481 .43554 .34664 .4299 Metetra
.616 .076 0 r
.34664 .4299 .35481 .43554 .36699 .44773 .35882 .4421 Metetra
.575 .03 0 r
.35882 .4421 .36699 .44773 .37939 .45922 .37124 .45361 Metetra
.474 0 0 r
.37124 .45361 .37939 .45922 .39206 .46906 .38391 .46346 Metetra
0 .257 .683 r
.38391 .46346 .39206 .46906 .40499 .47635 .39686 .47077 Metetra
.018 .498 .874 r
.39686 .47077 .40499 .47635 .41819 .48037 .41009 .4748 Metetra
.355 .712 .986 r
.41009 .4748 .41819 .48037 .43163 .4806 .42357 .47501 Metetra
.608 .824 .983 r
.42357 .47501 .43163 .4806 .44528 .47671 .43727 .47109 Metetra
.752 .858 .927 r
.43727 .47109 .44528 .47671 .45908 .46868 .45114 .463 Metetra
.829 .86 .869 r
.45114 .463 .45908 .46868 .47298 .45671 .46512 .45095 Metetra
.871 .853 .822 r
.46512 .45095 .47298 .45671 .48693 .44126 .47915 .43541 Metetra
.894 .845 .789 r
.47915 .43541 .48693 .44126 .50088 .423 .49319 .41705 Metetra
.906 .839 .768 r
.49319 .41705 .50088 .423 .51479 .40276 .50719 .39672 Metetra
.912 .836 .757 r
.50719 .39672 .51479 .40276 .52863 .38151 .52113 .37538 Metetra
.913 .836 .756 r
.52113 .37538 .52863 .38151 .5424 .36025 .53499 .35404 Metetra
.908 .839 .764 r
.53499 .35404 .5424 .36025 .5561 .33997 .54878 .33369 Metetra
.897 .844 .784 r
.54878 .33369 .5561 .33997 .56976 .3216 .56253 .31525 Metetra
.875 .85 .815 r
.56253 .31525 .56976 .3216 .58342 .30595 .57627 .2995 Metetra
.836 .853 .857 r
.57627 .2995 .58342 .30595 .59713 .29359 .59006 .28701 Metetra
.772 .845 .907 r
.59006 .28701 .59713 .29359 .61094 .28487 .60393 .27804 Metetra
.676 .816 .95 r
.60393 .27804 .61094 .28487 .62491 .27973 .61794 .27249 Metetra
.645 .794 .954 r
.61794 .27249 .62491 .27973 .63902 .27688 .63205 .26784 Metetra
.657 .749 .918 r
.63205 .26784 .63902 .27688 .65315 .27199 .64622 .26292 Metetra
.657 .749 .918 r
.64622 .26292 .65315 .27199 .66734 .26709 .66046 .25796 Metetra
.657 .749 .918 r
.66046 .25796 .66734 .26709 .6816 .26216 .67477 .25299 Metetra
.657 .749 .918 r
.67477 .25299 .6816 .26216 .69594 .2572 .68916 .24798 Metetra
.657 .749 .918 r
.68916 .24798 .69594 .2572 .71035 .25222 .70362 .24295 Metetra
.657 .749 .918 r
.70362 .24295 .71035 .25222 .72483 .24721 .71815 .2379 Metetra
.657 .749 .918 r
.71815 .2379 .72483 .24721 .73939 .24218 .73276 .23282 Metetra
.657 .749 .918 r
.73276 .23282 .73939 .24218 .75402 .23712 .74745 .22771 Metetra
.657 .749 .918 r
.74745 .22771 .75402 .23712 .76873 .23203 .76221 .22258 Metetra
.657 .749 .918 r
.76221 .22258 .76873 .23203 .78351 .22692 .77704 .21742 Metetra
.657 .749 .918 r
.1216 .43483 .13015 .44238 .1419 .4383 .13338 .43071 Metetra
.657 .749 .918 r
.13338 .43071 .1419 .4383 .15369 .43419 .14521 .42657 Metetra
.657 .749 .918 r
.14521 .42657 .15369 .43419 .16555 .43007 .15709 .42241 Metetra
.657 .749 .918 r
.15709 .42241 .16555 .43007 .17745 .42593 .16903 .41824 Metetra
.657 .749 .918 r
.16903 .41824 .17745 .42593 .18942 .42177 .18103 .41404 Metetra
.657 .749 .918 r
.18103 .41404 .18942 .42177 .20144 .41759 .19308 .40982 Metetra
.657 .749 .918 r
.19308 .40982 .20144 .41759 .21351 .41339 .20518 .40559 Metetra
.657 .749 .918 r
.20518 .40559 .21351 .41339 .22564 .40917 .21735 .40133 Metetra
.657 .749 .918 r
.21735 .40133 .22564 .40917 .23783 .40494 .22957 .39706 Metetra
.657 .749 .918 r
.22957 .39706 .23783 .40494 .25008 .40068 .24185 .39276 Metetra
.657 .749 .918 r
.24185 .39276 .25008 .40068 .26238 .3964 .25419 .38845 Metetra
.643 .745 .923 r
.25419 .38845 .26238 .3964 .27474 .39205 .26655 .38455 Metetra
.508 .711 .963 r
.26655 .38455 .27474 .39205 .28693 .3909 .27875 .38353 Metetra
.264 .595 .95 r
.27875 .38353 .28693 .3909 .29895 .39324 .29079 .38585 Metetra
0 .399 .84 r
.29079 .38585 .29895 .39324 .31086 .39889 .30271 .3914 Metetra
0 .203 .683 r
.30271 .3914 .31086 .39889 .32273 .40738 .31459 .39973 Metetra
0 .07 .561 r
.31459 .39973 .32273 .40738 .33463 .418 .3265 .41018 Metetra
.499 0 0 r
.3265 .41018 .33463 .418 .34664 .4299 .33852 .4219 Metetra
.498 0 0 r
.33852 .4219 .34664 .4299 .35882 .4421 .35071 .43394 Metetra
0 .058 .56 r
.35071 .43394 .35882 .4421 .37124 .45361 .36312 .44531 Metetra
0 .173 .671 r
.36312 .44531 .37124 .45361 .38391 .46346 .3758 .45504 Metetra
0 .343 .811 r
.3758 .45504 .38391 .46346 .39686 .47077 .38877 .46225 Metetra
.195 .529 .922 r
.38877 .46225 .39686 .47077 .41009 .4748 .40202 .4662 Metetra
.45 .669 .956 r
.40202 .4662 .41009 .4748 .42357 .47501 .41553 .46634 Metetra
.63 .744 .93 r
.41553 .46634 .42357 .47501 .43727 .47109 .42927 .46238 Metetra
.74 .776 .882 r
.42927 .46238 .43727 .47109 .45114 .463 .44319 .45426 Metetra
.805 .788 .837 r
.44319 .45426 .45114 .463 .46512 .45095 .45723 .44221 Metetra
.844 .791 .8 r
.45723 .44221 .46512 .45095 .47915 .43541 .47133 .42668 Metetra
.867 .791 .774 r
.47133 .42668 .47915 .43541 .49319 .41705 .48544 .40835 Metetra
.881 .791 .757 r
.48544 .40835 .49319 .41705 .50719 .39672 .49953 .38807 Metetra
.889 .793 .748 r
.49953 .38807 .50719 .39672 .52113 .37538 .51355 .36681 Metetra
.89 .795 .748 r
.51355 .36681 .52113 .37538 .53499 .35404 .5275 .34556 Metetra
.887 .799 .757 r
.5275 .34556 .53499 .35404 .54878 .33369 .54138 .32531 Metetra
.876 .804 .774 r
.54138 .32531 .54878 .33369 .56253 .31525 .55521 .30695 Metetra
.856 .808 .802 r
.55521 .30695 .56253 .31525 .57627 .2995 .56902 .29125 Metetra
.821 .809 .839 r
.56902 .29125 .57627 .2995 .59006 .28701 .58287 .27872 Metetra
.765 .8 .881 r
.58287 .27872 .59006 .28701 .60393 .27804 .5968 .26957 Metetra
.686 .775 .918 r
.5968 .26957 .60393 .27804 .61794 .27249 .61085 .26368 Metetra
.657 .756 .923 r
.61085 .26368 .61794 .27249 .63205 .26784 .625 .25873 Metetra
.657 .749 .918 r
.625 .25873 .63205 .26784 .64622 .26292 .63922 .25375 Metetra
.657 .749 .918 r
.63922 .25375 .64622 .26292 .66046 .25796 .65351 .24875 Metetra
.657 .749 .918 r
.65351 .24875 .66046 .25796 .67477 .25299 .66787 .24373 Metetra
.657 .749 .918 r
.66787 .24373 .67477 .25299 .68916 .24798 .68231 .23868 Metetra
.657 .749 .918 r
.68231 .23868 .68916 .24798 .70362 .24295 .69682 .2336 Metetra
.657 .749 .918 r
.69682 .2336 .70362 .24295 .71815 .2379 .71141 .2285 Metetra
.657 .749 .918 r
.71141 .2285 .71815 .2379 .73276 .23282 .72607 .22337 Metetra
.657 .749 .918 r
.72607 .22337 .73276 .23282 .74745 .22771 .74081 .21821 Metetra
.657 .749 .918 r
.74081 .21821 .74745 .22771 .76221 .22258 .75562 .21303 Metetra
.657 .749 .918 r
.75562 .21303 .76221 .22258 .77704 .21742 .77051 .20782 Metetra
.657 .749 .918 r
.11299 .42721 .1216 .43483 .13338 .43071 .12479 .42305 Metetra
.657 .749 .918 r
.12479 .42305 .13338 .43071 .14521 .42657 .13665 .41888 Metetra
.657 .749 .918 r
.13665 .41888 .14521 .42657 .15709 .42241 .14857 .41469 Metetra
.657 .749 .918 r
.14857 .41469 .15709 .42241 .16903 .41824 .16054 .41047 Metetra
.657 .749 .918 r
.16054 .41047 .16903 .41824 .18103 .41404 .17256 .40624 Metetra
.657 .749 .918 r
.17256 .40624 .18103 .41404 .19308 .40982 .18465 .40199 Metetra
.657 .749 .918 r
.18465 .40199 .19308 .40982 .20518 .40559 .19679 .39772 Metetra
.657 .749 .918 r
.19679 .39772 .20518 .40559 .21735 .40133 .20898 .39342 Metetra
.657 .749 .918 r
.20898 .39342 .21735 .40133 .22957 .39706 .22124 .38911 Metetra
.657 .749 .918 r
.22124 .38911 .22957 .39706 .24185 .39276 .23355 .38478 Metetra
.657 .749 .918 r
.23355 .38478 .24185 .39276 .25419 .38845 .24592 .38042 Metetra
.657 .749 .918 r
.24592 .38042 .25419 .38845 .26655 .38455 .25835 .37605 Metetra
.546 .699 .94 r
.25835 .37605 .26655 .38455 .27875 .38353 .27062 .37451 Metetra
.333 .584 .935 r
.27062 .37451 .27875 .38353 .29079 .38585 .28268 .37672 Metetra
.088 .435 .875 r
.28268 .37672 .29079 .38585 .30271 .3914 .29462 .38202 Metetra
0 .273 .769 r
.29462 .38202 .30271 .3914 .31459 .39973 .30652 .39005 Metetra
0 .153 .675 r
.30652 .39005 .31459 .39973 .3265 .41018 .31844 .40016 Metetra
0 .093 .625 r
.31844 .40016 .3265 .41018 .33852 .4219 .33046 .41153 Metetra
0 .093 .629 r
.33046 .41153 .33852 .4219 .35071 .43394 .34265 .42323 Metetra
0 .147 .68 r
.34265 .42323 .35071 .43394 .36312 .44531 .35507 .4343 Metetra
0 .251 .762 r
.35507 .4343 .36312 .44531 .3758 .45504 .36775 .44376 Metetra
.09 .386 .846 r
.36775 .44376 .3758 .45504 .38877 .46225 .38073 .45075 Metetra
.309 .517 .895 r
.38073 .45075 .38877 .46225 .40202 .4662 .39399 .45453 Metetra
.496 .615 .899 r
.39399 .45453 .40202 .4662 .41553 .46634 .40752 .45457 Metetra
.63 .675 .874 r
.40752 .45457 .41553 .46634 .42927 .46238 .42129 .45055 Metetra
.72 .708 .839 r
.42129 .45055 .42927 .46238 .44319 .45426 .43525 .44244 Metetra
.777 .726 .805 r
.43525 .44244 .44319 .45426 .45723 .44221 .44933 .43045 Metetra
.815 .737 .778 r
.44933 .43045 .45723 .44221 .47133 .42668 .46349 .41503 Metetra
.839 .743 .758 r
.46349 .41503 .47133 .42668 .48544 .40835 .47767 .39687 Metetra
.855 .748 .745 r
.47767 .39687 .48544 .40835 .49953 .38807 .49182 .37681 Metetra
.864 .753 .739 r
.49182 .37681 .49953 .38807 .51355 .36681 .50591 .35579 Metetra
.867 .757 .739 r
.50591 .35579 .51355 .36681 .5275 .34556 .51994 .3348 Metetra
.864 .762 .748 r
.51994 .3348 .5275 .34556 .54138 .32531 .53389 .31481 Metetra
.855 .766 .764 r
.53389 .31481 .54138 .32531 .55521 .30695 .54779 .29669 Metetra
.836 .77 .789 r
.54779 .29669 .55521 .30695 .56902 .29125 .56168 .28117 Metetra
.803 .769 .821 r
.56168 .28117 .56902 .29125 .58287 .27872 .57559 .2687 Metetra
.754 .759 .857 r
.57559 .2687 .58287 .27872 .5968 .26957 .58957 .25949 Metetra
.656 .725 .899 r
.58957 .25949 .5968 .26957 .61085 .26368 .6037 .25452 Metetra
.657 .749 .918 r
.6037 .25452 .61085 .26368 .625 .25873 .61789 .24952 Metetra
.657 .749 .918 r
.61789 .24952 .625 .25873 .63922 .25375 .63216 .2445 Metetra
.657 .749 .918 r
.63216 .2445 .63922 .25375 .65351 .24875 .6465 .23946 Metetra
.657 .749 .918 r
.6465 .23946 .65351 .24875 .66787 .24373 .66091 .23438 Metetra
.657 .749 .918 r
.66091 .23438 .66787 .24373 .68231 .23868 .6754 .22929 Metetra
.657 .749 .918 r
.6754 .22929 .68231 .23868 .69682 .2336 .68996 .22416 Metetra
.657 .749 .918 r
.68996 .22416 .69682 .2336 .71141 .2285 .7046 .21901 Metetra
.657 .749 .918 r
.7046 .21901 .71141 .2285 .72607 .22337 .71931 .21383 Metetra
.657 .749 .918 r
.71931 .21383 .72607 .22337 .74081 .21821 .73411 .20863 Metetra
.657 .749 .918 r
.73411 .20863 .74081 .21821 .75562 .21303 .74897 .20339 Metetra
.657 .749 .918 r
.74897 .20339 .75562 .21303 .77051 .20782 .76392 .19814 Metetra
.657 .749 .918 r
.10429 .41952 .11299 .42721 .12479 .42305 .11613 .41533 Metetra
.657 .749 .918 r
.11613 .41533 .12479 .42305 .13665 .41888 .12802 .41112 Metetra
.657 .749 .918 r
.12802 .41112 .13665 .41888 .14857 .41469 .13996 .40689 Metetra
.657 .749 .918 r
.13996 .40689 .14857 .41469 .16054 .41047 .15197 .40264 Metetra
.657 .749 .918 r
.15197 .40264 .16054 .41047 .17256 .40624 .16403 .39838 Metetra
.657 .749 .918 r
.16403 .39838 .17256 .40624 .18465 .40199 .17614 .39409 Metetra
.657 .749 .918 r
.17614 .39409 .18465 .40199 .19679 .39772 .18831 .38978 Metetra
.657 .749 .918 r
.18831 .38978 .19679 .39772 .20898 .39342 .20055 .38545 Metetra
.657 .749 .918 r
.20055 .38545 .20898 .39342 .22124 .38911 .21283 .3811 Metetra
.657 .749 .918 r
.21283 .3811 .22124 .38911 .23355 .38478 .22518 .37672 Metetra
.657 .749 .918 r
.22518 .37672 .23355 .38478 .24592 .38042 .23759 .37233 Metetra
.657 .749 .918 r
.23759 .37233 .24592 .38042 .25835 .37605 .25005 .36792 Metetra
.644 .745 .923 r
.25005 .36792 .25835 .37605 .27062 .37451 .26254 .36389 Metetra
.385 .57 .91 r
.26254 .36389 .27062 .37451 .28268 .37672 .27463 .36588 Metetra
.193 .455 .878 r
.27463 .36588 .28268 .37672 .29462 .38202 .2866 .37082 Metetra
.007 .327 .812 r
.2866 .37082 .29462 .38202 .30652 .39005 .29851 .37839 Metetra
0 .225 .746 r
.29851 .37839 .30652 .39005 .31844 .40016 .31045 .388 Metetra
0 .173 .708 r
.31045 .388 .31844 .40016 .33046 .41153 .32248 .39885 Metetra
0 .172 .709 r
.32248 .39885 .33046 .41153 .34265 .42323 .33468 .41006 Metetra
0 .219 .742 r
.33468 .41006 .34265 .42323 .35507 .4343 .3471 .42066 Metetra
.046 .302 .791 r
.3471 .42066 .35507 .4343 .36775 .44376 .35978 .42971 Metetra
.211 .402 .833 r
.35978 .42971 .36775 .44376 .38073 .45075 .37276 .43637 Metetra
.377 .496 .852 r
.37276 .43637 .38073 .45075 .39399 .45453 .38602 .4399 Metetra
.518 .57 .847 r
.38602 .4399 .39399 .45453 .40752 .45457 .39957 .43977 Metetra
.624 .621 .827 r
.39957 .43977 .40752 .45457 .42129 .45055 .41335 .43569 Metetra
.7 .655 .802 r
.41335 .43569 .42129 .45055 .43525 .44244 .42733 .42762 Metetra
.752 .677 .778 r
.42733 .42762 .43525 .44244 .44933 .43045 .44145 .41575 Metetra
.788 .691 .757 r
.44145 .41575 .44933 .43045 .46349 .41503 .45565 .40056 Metetra
.813 .702 .742 r
.45565 .40056 .46349 .41503 .47767 .39687 .46988 .3827 Metetra
.83 .71 .733 r
.46988 .3827 .47767 .39687 .49182 .37681 .48408 .36299 Metetra
.839 .717 .729 r
.48408 .36299 .49182 .37681 .50591 .35579 .49824 .34238 Metetra
.844 .723 .731 r
.49824 .34238 .50591 .35579 .51994 .3348 .51233 .32182 Metetra
.842 .729 .739 r
.51233 .32182 .51994 .3348 .53389 .31481 .52634 .30226 Metetra
.833 .733 .754 r
.52634 .30226 .53389 .31481 .54779 .29669 .54031 .28453 Metetra
.815 .735 .777 r
.54031 .28453 .54779 .29669 .56168 .28117 .55426 .26931 Metetra
.785 .733 .805 r
.55426 .26931 .56168 .28117 .57559 .2687 .56823 .25702 Metetra
.693 .706 .857 r
.56823 .25702 .57559 .2687 .58957 .25949 .5823 .25029 Metetra
.657 .749 .918 r
.5823 .25029 .58957 .25949 .6037 .25452 .59647 .24528 Metetra
.657 .749 .918 r
.59647 .24528 .6037 .25452 .61789 .24952 .61071 .24023 Metetra
.657 .749 .918 r
.61071 .24023 .61789 .24952 .63216 .2445 .62503 .23517 Metetra
.657 .749 .918 r
.62503 .23517 .63216 .2445 .6465 .23946 .63942 .23007 Metetra
.657 .749 .918 r
.63942 .23007 .6465 .23946 .66091 .23438 .65388 .22495 Metetra
.657 .749 .918 r
.65388 .22495 .66091 .23438 .6754 .22929 .66842 .2198 Metetra
.657 .749 .918 r
.66842 .2198 .6754 .22929 .68996 .22416 .68304 .21463 Metetra
.657 .749 .918 r
.68304 .21463 .68996 .22416 .7046 .21901 .69773 .20943 Metetra
.657 .749 .918 r
.69773 .20943 .7046 .21901 .71931 .21383 .71249 .2042 Metetra
.657 .749 .918 r
.71249 .2042 .71931 .21383 .73411 .20863 .72734 .19895 Metetra
.657 .749 .918 r
.72734 .19895 .73411 .20863 .74897 .20339 .74226 .19366 Metetra
.657 .749 .918 r
.74226 .19366 .74897 .20339 .76392 .19814 .75726 .18835 Metetra
.657 .749 .918 r
.09552 .41177 .10429 .41952 .11613 .41533 .10739 .40755 Metetra
.657 .749 .918 r
.10739 .40755 .11613 .41533 .12802 .41112 .11931 .4033 Metetra
.657 .749 .918 r
.11931 .4033 .12802 .41112 .13996 .40689 .13129 .39903 Metetra
.657 .749 .918 r
.13129 .39903 .13996 .40689 .15197 .40264 .14332 .39475 Metetra
.657 .749 .918 r
.14332 .39475 .15197 .40264 .16403 .39838 .15541 .39044 Metetra
.657 .749 .918 r
.15541 .39044 .16403 .39838 .17614 .39409 .16756 .38611 Metetra
.657 .749 .918 r
.16756 .38611 .17614 .39409 .18831 .38978 .17977 .38177 Metetra
.657 .749 .918 r
.17977 .38177 .18831 .38978 .20055 .38545 .19203 .3774 Metetra
.657 .749 .918 r
.19203 .3774 .20055 .38545 .21283 .3811 .20436 .37301 Metetra
.657 .749 .918 r
.20436 .37301 .21283 .3811 .22518 .37672 .21674 .3686 Metetra
.657 .749 .918 r
.21674 .3686 .22518 .37672 .23759 .37233 .22918 .36417 Metetra
.657 .749 .918 r
.22918 .36417 .23759 .37233 .25005 .36792 .24168 .35972 Metetra
.657 .749 .918 r
.24168 .35972 .25005 .36792 .26254 .36389 .25424 .35524 Metetra
.553 .703 .939 r
.25424 .35524 .26254 .36389 .27463 .36588 .26664 .35346 Metetra
.274 .466 .867 r
.26664 .35346 .27463 .36588 .2866 .37082 .27864 .35793 Metetra
.126 .365 .825 r
.27864 .35793 .2866 .37082 .29851 .37839 .29058 .3649 Metetra
.017 .281 .779 r
.29058 .3649 .29851 .37839 .31045 .388 .30254 .37385 Metetra
0 .236 .75 r
.30254 .37385 .31045 .388 .32248 .39885 .31458 .38403 Metetra
0 .233 .746 r
.31458 .38403 .32248 .39885 .33468 .41006 .32679 .39457 Metetra
.052 .269 .763 r
.32679 .39457 .33468 .41006 .3471 .42066 .33921 .40456 Metetra
.161 .332 .788 r
.33921 .40456 .3471 .42066 .35978 .42971 .3519 .41307 Metetra
.292 .406 .807 r
.3519 .41307 .35978 .42971 .37276 .43637 .36487 .41928 Metetra
.42 .477 .814 r
.36487 .41928 .37276 .43637 .38602 .4399 .37814 .42247 Metetra
.53 .536 .806 r
.37814 .42247 .38602 .4399 .39957 .43977 .39168 .42214 Metetra
.617 .581 .791 r
.39168 .42214 .39957 .43977 .41335 .43569 .40547 .41799 Metetra
.682 .614 .773 r
.40547 .41799 .41335 .43569 .42733 .42762 .41946 .40998 Metetra
.73 .637 .755 r
.41946 .40998 .42733 .42762 .44145 .41575 .4336 .39832 Metetra
.765 .655 .74 r
.4336 .39832 .44145 .41575 .45565 .40056 .44783 .38344 Metetra
.79 .668 .729 r
.44783 .38344 .45565 .40056 .46988 .3827 .46209 .366 Metetra
.806 .678 .722 r
.46209 .366 .46988 .3827 .48408 .36299 .47633 .3468 Metetra
.817 .687 .72 r
.47633 .3468 .48408 .36299 .49824 .34238 .49054 .32675 Metetra
.822 .694 .723 r
.49054 .32675 .49824 .34238 .51233 .32182 .50467 .30678 Metetra
.82 .7 .732 r
.50467 .30678 .51233 .32182 .52634 .30226 .51875 .2878 Metetra
.812 .704 .746 r
.51875 .2878 .52634 .30226 .54031 .28453 .53277 .2706 Metetra
.795 .706 .766 r
.53277 .2706 .54031 .28453 .55426 .26931 .54677 .25581 Metetra
.736 .691 .808 r
.54677 .25581 .55426 .26931 .56823 .25702 .56081 .24605 Metetra
.655 .707 .886 r
.56081 .24605 .56823 .25702 .5823 .25029 .57496 .24101 Metetra
.657 .749 .918 r
.57496 .24101 .5823 .25029 .59647 .24528 .58918 .23595 Metetra
.657 .749 .918 r
.58918 .23595 .59647 .24528 .61071 .24023 .60347 .23086 Metetra
.657 .749 .918 r
.60347 .23086 .61071 .24023 .62503 .23517 .61783 .22574 Metetra
.657 .749 .918 r
.61783 .22574 .62503 .23517 .63942 .23007 .63227 .2206 Metetra
.657 .749 .918 r
.63227 .2206 .63942 .23007 .65388 .22495 .64679 .21543 Metetra
.657 .749 .918 r
.64679 .21543 .65388 .22495 .66842 .2198 .66138 .21023 Metetra
.657 .749 .918 r
.66138 .21023 .66842 .2198 .68304 .21463 .67605 .20501 Metetra
.657 .749 .918 r
.67605 .20501 .68304 .21463 .69773 .20943 .69079 .19976 Metetra
.657 .749 .918 r
.69079 .19976 .69773 .20943 .71249 .2042 .70561 .19448 Metetra
.657 .749 .918 r
.70561 .19448 .71249 .2042 .72734 .19895 .72051 .18917 Metetra
.657 .749 .918 r
.72051 .18917 .72734 .19895 .74226 .19366 .73548 .18384 Metetra
.657 .749 .918 r
.73548 .18384 .74226 .19366 .75726 .18835 .75054 .17848 Metetra
.657 .749 .918 r
.08668 .40395 .09552 .41177 .10739 .40755 .09858 .39969 Metetra
.657 .749 .918 r
.09858 .39969 .10739 .40755 .11931 .4033 .11053 .39541 Metetra
.657 .749 .918 r
.11053 .39541 .11931 .4033 .13129 .39903 .12254 .3911 Metetra
.657 .749 .918 r
.12254 .3911 .13129 .39903 .14332 .39475 .1346 .38678 Metetra
.657 .749 .918 r
.1346 .38678 .14332 .39475 .15541 .39044 .14673 .38244 Metetra
.657 .749 .918 r
.14673 .38244 .15541 .39044 .16756 .38611 .15891 .37807 Metetra
.657 .749 .918 r
.15891 .37807 .16756 .38611 .17977 .38177 .17115 .37369 Metetra
.657 .749 .918 r
.17115 .37369 .17977 .38177 .19203 .3774 .18345 .36928 Metetra
.657 .749 .918 r
.18345 .36928 .19203 .3774 .20436 .37301 .1958 .36485 Metetra
.657 .749 .918 r
.1958 .36485 .20436 .37301 .21674 .3686 .20822 .3604 Metetra
.657 .749 .918 r
.20822 .3604 .21674 .3686 .22918 .36417 .22069 .35593 Metetra
.657 .749 .918 r
.22069 .35593 .22918 .36417 .24168 .35972 .23323 .35144 Metetra
.657 .749 .918 r
.23323 .35144 .24168 .35972 .25424 .35524 .24583 .34693 Metetra
.657 .749 .918 r
.24583 .34693 .25424 .35524 .26664 .35346 .25848 .34239 Metetra
.434 .588 .906 r
.25848 .34239 .26664 .35346 .27864 .35793 .27075 .34351 Metetra
.218 .392 .823 r
.27075 .34351 .27864 .35793 .29058 .3649 .28272 .34977 Metetra
.129 .323 .79 r
.28272 .34977 .29058 .3649 .30254 .37385 .29471 .35793 Metetra
.088 .283 .766 r
.29471 .35793 .30254 .37385 .31458 .38403 .30677 .36729 Metetra
.1 .278 .758 r
.30677 .36729 .31458 .38403 .32679 .39457 .31899 .37702 Metetra
.156 .304 .764 r
.31899 .37702 .32679 .39457 .33921 .40456 .33142 .38625 Metetra
.244 .351 .775 r
.33142 .38625 .33921 .40456 .3519 .41307 .34411 .3941 Metetra
.346 .407 .782 r
.34411 .3941 .3519 .41307 .36487 .41928 .35708 .39976 Metetra
.447 .463 .783 r
.35708 .39976 .36487 .41928 .37814 .42247 .37034 .40255 Metetra
.537 .512 .776 r
.37034 .40255 .37814 .42247 .39168 .42214 .38387 .40197 Metetra
.61 .552 .764 r
.38387 .40197 .39168 .42214 .40547 .41799 .39766 .39774 Metetra
.668 .583 .75 r
.39766 .39774 .40547 .41799 .41946 .40998 .41165 .38982 Metetra
.712 .606 .737 r
.41165 .38982 .41946 .40998 .4336 .39832 .42579 .37841 Metetra
.745 .625 .726 r
.42579 .37841 .4336 .39832 .44783 .38344 .44003 .36394 Metetra
.769 .639 .718 r
.44003 .36394 .44783 .38344 .46209 .366 .45431 .34704 Metetra
.786 .651 .714 r
.45431 .34704 .46209 .366 .47633 .3468 .46858 .32848 Metetra
.797 .661 .713 r
.46858 .32848 .47633 .3468 .49054 .32675 .48282 .30913 Metetra
.801 .669 .717 r
.48282 .30913 .49054 .32675 .50467 .30678 .497 .28989 Metetra
.8 .675 .726 r
.497 .28989 .50467 .30678 .51875 .2878 .51111 .27163 Metetra
.792 .679 .739 r
.51111 .27163 .51875 .2878 .53277 .2706 .52518 .25509 Metetra
.766 .677 .764 r
.52518 .25509 .53277 .2706 .54677 .25581 .53923 .24179 Metetra
.645 .646 .837 r
.53923 .24179 .54677 .25581 .56081 .24605 .55335 .23673 Metetra
.657 .749 .918 r
.55335 .23673 .56081 .24605 .57496 .24101 .56755 .23164 Metetra
.657 .749 .918 r
.56755 .23164 .57496 .24101 .58918 .23595 .58181 .22653 Metetra
.657 .749 .918 r
.58181 .22653 .58918 .23595 .60347 .23086 .59615 .22139 Metetra
.657 .749 .918 r
.59615 .22139 .60347 .23086 .61783 .22574 .61057 .21622 Metetra
.657 .749 .918 r
.61057 .21622 .61783 .22574 .63227 .2206 .62506 .21103 Metetra
.657 .749 .918 r
.62506 .21103 .63227 .2206 .64679 .21543 .63963 .20581 Metetra
.657 .749 .918 r
.63963 .20581 .64679 .21543 .66138 .21023 .65427 .20057 Metetra
.657 .749 .918 r
.65427 .20057 .66138 .21023 .67605 .20501 .66899 .19529 Metetra
.657 .749 .918 r
.66899 .19529 .67605 .20501 .69079 .19976 .68378 .18999 Metetra
.657 .749 .918 r
.68378 .18999 .69079 .19976 .70561 .19448 .69865 .18466 Metetra
.657 .749 .918 r
.69865 .18466 .70561 .19448 .72051 .18917 .71361 .1793 Metetra
.657 .749 .918 r
.71361 .1793 .72051 .18917 .73548 .18384 .72864 .17392 Metetra
.657 .749 .918 r
.72864 .17392 .73548 .18384 .75054 .17848 .74375 .1685 Metetra
.657 .749 .918 r
.07776 .39607 .08668 .40395 .09858 .39969 .08969 .39177 Metetra
.657 .749 .918 r
.08969 .39177 .09858 .39969 .11053 .39541 .10167 .38745 Metetra
.657 .749 .918 r
.10167 .38745 .11053 .39541 .12254 .3911 .11371 .38311 Metetra
.657 .749 .918 r
.11371 .38311 .12254 .3911 .1346 .38678 .12581 .37874 Metetra
.657 .749 .918 r
.12581 .37874 .1346 .38678 .14673 .38244 .13796 .37436 Metetra
.657 .749 .918 r
.13796 .37436 .14673 .38244 .15891 .37807 .15018 .36996 Metetra
.657 .749 .918 r
.15018 .36996 .15891 .37807 .17115 .37369 .16245 .36553 Metetra
.657 .749 .918 r
.16245 .36553 .17115 .37369 .18345 .36928 .17478 .36109 Metetra
.657 .749 .918 r
.17478 .36109 .18345 .36928 .1958 .36485 .18717 .35662 Metetra
.657 .749 .918 r
.18717 .35662 .1958 .36485 .20822 .3604 .19962 .35213 Metetra
.657 .749 .918 r
.19962 .35213 .20822 .3604 .22069 .35593 .21213 .34762 Metetra
.657 .749 .918 r
.21213 .34762 .22069 .35593 .23323 .35144 .2247 .34309 Metetra
.657 .749 .918 r
.2247 .34309 .23323 .35144 .24583 .34693 .23734 .33854 Metetra
.657 .749 .918 r
.23734 .33854 .24583 .34693 .25848 .34239 .25003 .33396 Metetra
.657 .749 .918 r
.25003 .33396 .25848 .34239 .27075 .34351 .26279 .32936 Metetra
.338 .471 .847 r
.26279 .32936 .27075 .34351 .28272 .34977 .27493 .33326 Metetra
.216 .355 .79 r
.27493 .33326 .28272 .34977 .29471 .35793 .28695 .3405 Metetra
.181 .32 .77 r
.28695 .3405 .29471 .35793 .30677 .36729 .29905 .34891 Metetra
.189 .312 .76 r
.29905 .34891 .30677 .36729 .31899 .37702 .31128 .35771 Metetra
.233 .33 .758 r
.31128 .35771 .31899 .37702 .33142 .38625 .32372 .36607 Metetra
.303 .365 .761 r
.32372 .36607 .33142 .38625 .34411 .3941 .33641 .37314 Metetra
.385 .409 .762 r
.33641 .37314 .34411 .3941 .35708 .39976 .34937 .37816 Metetra
.467 .454 .76 r
.34937 .37816 .35708 .39976 .37034 .40255 .36262 .38048 Metetra
.542 .495 .753 r
.36262 .38048 .37034 .40255 .38387 .40197 .37615 .37962 Metetra
.605 .53 .744 r
.37615 .37962 .38387 .40197 .39766 .39774 .38992 .37531 Metetra
.656 .559 .734 r
.38992 .37531 .39766 .39774 .41165 .38982 .4039 .36751 Metetra
.696 .582 .724 r
.4039 .36751 .41165 .38982 .42579 .37841 .41803 .35641 Metetra
.727 .601 .716 r
.41803 .35641 .42579 .37841 .44003 .36394 .43227 .34242 Metetra
.751 .616 .71 r
.43227 .34242 .44003 .36394 .45431 .34704 .44655 .32616 Metetra
.767 .629 .707 r
.44655 .32616 .45431 .34704 .46858 .32848 .46084 .30835 Metetra
.778 .639 .708 r
.46084 .30835 .46858 .32848 .48282 .30913 .4751 .28982 Metetra
.783 .648 .712 r
.4751 .28982 .48282 .30913 .497 .28989 .4893 .27144 Metetra
.782 .654 .721 r
.4893 .27144 .497 .28989 .51111 .27163 .50345 .25402 Metetra
.775 .658 .734 r
.50345 .25402 .51111 .27163 .52518 .25509 .51755 .23824 Metetra
.648 .608 .795 r
.51755 .23824 .52518 .25509 .53923 .24179 .53165 .23243 Metetra
.657 .749 .918 r
.53165 .23243 .53923 .24179 .55335 .23673 .54582 .22732 Metetra
.657 .749 .918 r
.54582 .22732 .55335 .23673 .56755 .23164 .56006 .22218 Metetra
.657 .749 .918 r
.56006 .22218 .56755 .23164 .58181 .22653 .57438 .21702 Metetra
.657 .749 .918 r
.57438 .21702 .58181 .22653 .59615 .22139 .58877 .21183 Metetra
.657 .749 .918 r
.58877 .21183 .59615 .22139 .61057 .21622 .60324 .20662 Metetra
.657 .749 .918 r
.60324 .20662 .61057 .21622 .62506 .21103 .61778 .20138 Metetra
.657 .749 .918 r
.61778 .20138 .62506 .21103 .63963 .20581 .63239 .19611 Metetra
.657 .749 .918 r
.63239 .19611 .63963 .20581 .65427 .20057 .64709 .19081 Metetra
.657 .749 .918 r
.64709 .19081 .65427 .20057 .66899 .19529 .66186 .18548 Metetra
.657 .749 .918 r
.66186 .18548 .66899 .19529 .68378 .18999 .67671 .18013 Metetra
.657 .749 .918 r
.67671 .18013 .68378 .18999 .69865 .18466 .69163 .17475 Metetra
.657 .749 .918 r
.69163 .17475 .69865 .18466 .71361 .1793 .70664 .16934 Metetra
.657 .749 .918 r
.70664 .16934 .71361 .1793 .72864 .17392 .72173 .1639 Metetra
.657 .749 .918 r
.72173 .1639 .72864 .17392 .74375 .1685 .73689 .15843 Metetra
.657 .749 .918 r
.06876 .38811 .07776 .39607 .08969 .39177 .08072 .38378 Metetra
.657 .749 .918 r
.08072 .38378 .08969 .39177 .10167 .38745 .09273 .37942 Metetra
.657 .749 .918 r
.09273 .37942 .10167 .38745 .11371 .38311 .10481 .37504 Metetra
.657 .749 .918 r
.10481 .37504 .11371 .38311 .12581 .37874 .11694 .37064 Metetra
.657 .749 .918 r
.11694 .37064 .12581 .37874 .13796 .37436 .12912 .36622 Metetra
.657 .749 .918 r
.12912 .36622 .13796 .37436 .15018 .36996 .14137 .36177 Metetra
.657 .749 .918 r
.14137 .36177 .15018 .36996 .16245 .36553 .15368 .35731 Metetra
.657 .749 .918 r
.15368 .35731 .16245 .36553 .17478 .36109 .16604 .35282 Metetra
.657 .749 .918 r
.16604 .35282 .17478 .36109 .18717 .35662 .17847 .34832 Metetra
.657 .749 .918 r
.17847 .34832 .18717 .35662 .19962 .35213 .19095 .34379 Metetra
.657 .749 .918 r
.19095 .34379 .19962 .35213 .21213 .34762 .2035 .33924 Metetra
.657 .749 .918 r
.2035 .33924 .21213 .34762 .2247 .34309 .2161 .33466 Metetra
.657 .749 .918 r
.2161 .33466 .2247 .34309 .23734 .33854 .22877 .33007 Metetra
.657 .749 .918 r
.22877 .33007 .23734 .33854 .25003 .33396 .2415 .32545 Metetra
.657 .749 .918 r
.2415 .32545 .25003 .33396 .26279 .32936 .25429 .32081 Metetra
.657 .749 .918 r
.25429 .32081 .26279 .32936 .27493 .33326 .26715 .31615 Metetra
.299 .398 .797 r
.26715 .31615 .27493 .33326 .28695 .3405 .27925 .32188 Metetra
.254 .35 .769 r
.27925 .32188 .28695 .3405 .29905 .34891 .29138 .32924 Metetra
.258 .34 .757 r
.29138 .32924 .29905 .34891 .31128 .35771 .30365 .33701 Metetra
.292 .351 .752 r
.30365 .33701 .31128 .35771 .32372 .36607 .3161 .34439 Metetra
.348 .377 .75 r
.3161 .34439 .32372 .36607 .33641 .37314 .32879 .35061 Metetra
.415 .412 .748 r
.32879 .35061 .33641 .37314 .34937 .37816 .34175 .35492 Metetra
.483 .449 .744 r
.34175 .35492 .34937 .37816 .36262 .38048 .35499 .35671 Metetra
.546 .484 .737 r
.35499 .35671 .36262 .38048 .37615 .37962 .3685 .35554 Metetra
.601 .515 .73 r
.3685 .35554 .37615 .37962 .38992 .37531 .38225 .35114 Metetra
.647 .542 .722 r
.38225 .35114 .38992 .37531 .4039 .36751 .39621 .34347 Metetra
.684 .564 .714 r
.39621 .34347 .4039 .36751 .41803 .35641 .41033 .33273 Metetra
.713 .583 .708 r
.41033 .33273 .41803 .35641 .43227 .34242 .42455 .31929 Metetra
.735 .598 .704 r
.42455 .31929 .43227 .34242 .44655 .32616 .43882 .30374 Metetra
.752 .611 .702 r
.43882 .30374 .44655 .32616 .46084 .30835 .45311 .28678 Metetra
.762 .622 .704 r
.45311 .28678 .46084 .30835 .4751 .28982 .46738 .26918 Metetra
.767 .63 .709 r
.46738 .26918 .4751 .28982 .4893 .27144 .48159 .25176 Metetra
.766 .637 .719 r
.48159 .25176 .4893 .27144 .50345 .25402 .49576 .23527 Metetra
.662 .594 .769 r
.49576 .23527 .50345 .25402 .51755 .23824 .50986 .22811 Metetra
.656 .731 .904 r
.50986 .22811 .51755 .23824 .53165 .23243 .524 .22297 Metetra
.657 .749 .918 r
.524 .22297 .53165 .23243 .54582 .22732 .53822 .21782 Metetra
.657 .749 .918 r
.53822 .21782 .54582 .22732 .56006 .22218 .55251 .21263 Metetra
.657 .749 .918 r
.55251 .21263 .56006 .22218 .57438 .21702 .56687 .20742 Metetra
.657 .749 .918 r
.56687 .20742 .57438 .21702 .58877 .21183 .58132 .20218 Metetra
.657 .749 .918 r
.58132 .20218 .58877 .21183 .60324 .20662 .59583 .19692 Metetra
.657 .749 .918 r
.59583 .19692 .60324 .20662 .61778 .20138 .61042 .19162 Metetra
.657 .749 .918 r
.61042 .19162 .61778 .20138 .63239 .19611 .62509 .1863 Metetra
.657 .749 .918 r
.62509 .1863 .63239 .19611 .64709 .19081 .63984 .18095 Metetra
.657 .749 .918 r
.63984 .18095 .64709 .19081 .66186 .18548 .65466 .17558 Metetra
.657 .749 .918 r
.65466 .17558 .66186 .18548 .67671 .18013 .66956 .17017 Metetra
.657 .749 .918 r
.66956 .17017 .67671 .18013 .69163 .17475 .68454 .16474 Metetra
.657 .749 .918 r
.68454 .16474 .69163 .17475 .70664 .16934 .69961 .15927 Metetra
.657 .749 .918 r
.69961 .15927 .70664 .16934 .72173 .1639 .71475 .15378 Metetra
.657 .749 .918 r
.71475 .15378 .72173 .1639 .73689 .15843 .72997 .14826 Metetra
.657 .749 .918 r
.05968 .38009 .06876 .38811 .08072 .38378 .07167 .37571 Metetra
.657 .749 .918 r
.07167 .37571 .08072 .38378 .09273 .37942 .08372 .37132 Metetra
.657 .749 .918 r
.08372 .37132 .09273 .37942 .10481 .37504 .09582 .3669 Metetra
.657 .749 .918 r
.09582 .3669 .10481 .37504 .11694 .37064 .10798 .36246 Metetra
.657 .749 .918 r
.10798 .36246 .11694 .37064 .12912 .36622 .1202 .358 Metetra
.657 .749 .918 r
.1202 .358 .12912 .36622 .14137 .36177 .13248 .35352 Metetra
.657 .749 .918 r
.13248 .35352 .14137 .36177 .15368 .35731 .14482 .34901 Metetra
.657 .749 .918 r
.14482 .34901 .15368 .35731 .16604 .35282 .15722 .34449 Metetra
.657 .749 .918 r
.15722 .34449 .16604 .35282 .17847 .34832 .16968 .33994 Metetra
.657 .749 .918 r
.16968 .33994 .17847 .34832 .19095 .34379 .1822 .33537 Metetra
.657 .749 .918 r
.1822 .33537 .19095 .34379 .2035 .33924 .19478 .33078 Metetra
.657 .749 .918 r
.19478 .33078 .2035 .33924 .2161 .33466 .20742 .32616 Metetra
.657 .749 .918 r
.20742 .32616 .2161 .33466 .22877 .33007 .22013 .32153 Metetra
.657 .749 .918 r
.22013 .32153 .22877 .33007 .2415 .32545 .23289 .31687 Metetra
.657 .749 .918 r
.23289 .31687 .2415 .32545 .25429 .32081 .24572 .31218 Metetra
.657 .749 .918 r
.24572 .31218 .25429 .32081 .26715 .31615 .25862 .30748 Metetra
.657 .749 .918 r
.25862 .30748 .26715 .31615 .27925 .32188 .27157 .30275 Metetra
.32 .385 .773 r
.27157 .30275 .27925 .32188 .29138 .32924 .28377 .30865 Metetra
.312 .363 .755 r
.28377 .30865 .29138 .32924 .30365 .33701 .29607 .3153 Metetra
.338 .369 .747 r
.29607 .3153 .30365 .33701 .3161 .34439 .30855 .32164 Metetra
.383 .389 .742 r
.30855 .32164 .3161 .34439 .32879 .35061 .32125 .32693 Metetra
.438 .416 .738 r
.32125 .32693 .32879 .35061 .34175 .35492 .3342 .33048 Metetra
.495 .447 .733 r
.3342 .33048 .34175 .35492 .35499 .35671 .34743 .33171 Metetra
.55 .477 .727 r
.34743 .33171 .35499 .35671 .3685 .35554 .36091 .3302 Metetra
.598 .505 .72 r
.36091 .3302 .3685 .35554 .38225 .35114 .37464 .3257 Metetra
.639 .53 .713 r
.37464 .3257 .38225 .35114 .39621 .34347 .38857 .31819 Metetra
.674 .551 .707 r
.38857 .31819 .39621 .34347 .41033 .33273 .40266 .30783 Metetra
.701 .569 .703 r
.40266 .30783 .41033 .33273 .42455 .31929 .41686 .295 Metetra
.722 .584 .7 r
.41686 .295 .42455 .31929 .43882 .30374 .43112 .28023 Metetra
.738 .597 .7 r
.43112 .28023 .43882 .30374 .45311 .28678 .4454 .26417 Metetra
.748 .608 .703 r
.4454 .26417 .45311 .28678 .46738 .26918 .45966 .24758 Metetra
.753 .617 .708 r
.45966 .24758 .46738 .26918 .48159 .25176 .47388 .23119 Metetra
.657 .575 .751 r
.47388 .23119 .48159 .25176 .49576 .23527 .48797 .22377 Metetra
.653 .701 .881 r
.48797 .22377 .49576 .23527 .50986 .22811 .50208 .21861 Metetra
.657 .749 .918 r
.50208 .21861 .50986 .22811 .524 .22297 .51628 .21343 Metetra
.657 .749 .918 r
.51628 .21343 .524 .22297 .53822 .21782 .53054 .20823 Metetra
.657 .749 .918 r
.53054 .20823 .53822 .21782 .55251 .21263 .54488 .20299 Metetra
.657 .749 .918 r
.54488 .20299 .55251 .21263 .56687 .20742 .5593 .19773 Metetra
.657 .749 .918 r
.5593 .19773 .56687 .20742 .58132 .20218 .57379 .19244 Metetra
.657 .749 .918 r
.57379 .19244 .58132 .20218 .59583 .19692 .58835 .18712 Metetra
.657 .749 .918 r
.58835 .18712 .59583 .19692 .61042 .19162 .603 .18178 Metetra
.657 .749 .918 r
.603 .18178 .61042 .19162 .62509 .1863 .61772 .17641 Metetra
.657 .749 .918 r
.61772 .17641 .62509 .1863 .63984 .18095 .63252 .17101 Metetra
.657 .749 .918 r
.63252 .17101 .63984 .18095 .65466 .17558 .64739 .16558 Metetra
.657 .749 .918 r
.64739 .16558 .65466 .17558 .66956 .17017 .66235 .16012 Metetra
.657 .749 .918 r
.66235 .16012 .66956 .17017 .68454 .16474 .67738 .15463 Metetra
.657 .749 .918 r
.67738 .15463 .68454 .16474 .69961 .15927 .6925 .14911 Metetra
.657 .749 .918 r
.6925 .14911 .69961 .15927 .71475 .15378 .7077 .14356 Metetra
.657 .749 .918 r
.7077 .14356 .71475 .15378 .72997 .14826 .72298 .13799 Metetra
.657 .749 .918 r
.05052 .37199 .05968 .38009 .07167 .37571 .06254 .36758 Metetra
.657 .749 .918 r
.06254 .36758 .07167 .37571 .08372 .37132 .07462 .36314 Metetra
.657 .749 .918 r
.07462 .36314 .08372 .37132 .09582 .3669 .08676 .35869 Metetra
.657 .749 .918 r
.08676 .35869 .09582 .3669 .10798 .36246 .09895 .35421 Metetra
.657 .749 .918 r
.09895 .35421 .10798 .36246 .1202 .358 .11121 .34971 Metetra
.657 .749 .918 r
.11121 .34971 .1202 .358 .13248 .35352 .12352 .34518 Metetra
.657 .749 .918 r
.12352 .34518 .13248 .35352 .14482 .34901 .13589 .34064 Metetra
.657 .749 .918 r
.13589 .34064 .14482 .34901 .15722 .34449 .14832 .33607 Metetra
.657 .749 .918 r
.14832 .33607 .15722 .34449 .16968 .33994 .16082 .33149 Metetra
.657 .749 .918 r
.16082 .33149 .16968 .33994 .1822 .33537 .17337 .32687 Metetra
.657 .749 .918 r
.17337 .32687 .1822 .33537 .19478 .33078 .18599 .32224 Metetra
.657 .749 .918 r
.18599 .32224 .19478 .33078 .20742 .32616 .19867 .31758 Metetra
.657 .749 .918 r
.19867 .31758 .20742 .32616 .22013 .32153 .21141 .31291 Metetra
.657 .749 .918 r
.21141 .31291 .22013 .32153 .23289 .31687 .22421 .3082 Metetra
.657 .749 .918 r
.22421 .3082 .23289 .31687 .24572 .31218 .23708 .30348 Metetra
.657 .749 .918 r
.23708 .30348 .24572 .31218 .25862 .30748 .25001 .29873 Metetra
.657 .749 .918 r
.25001 .29873 .25862 .30748 .27157 .30275 .263 .29396 Metetra
.657 .749 .918 r
.263 .29396 .27157 .30275 .28377 .30865 .27606 .28916 Metetra
.399 .431 .778 r
.27606 .28916 .28377 .30865 .29607 .3153 .28853 .29299 Metetra
.376 .387 .744 r
.28853 .29299 .29607 .3153 .30855 .32164 .30103 .29824 Metetra
.412 .401 .738 r
.30103 .29824 .30855 .32164 .32125 .32693 .31375 .30255 Metetra
.458 .423 .732 r
.31375 .30255 .32125 .32693 .3342 .33048 .3267 .3053 Metetra
.506 .448 .726 r
.3267 .3053 .3342 .33048 .34743 .33171 .33992 .30594 Metetra
.554 .475 .72 r
.33992 .30594 .34743 .33171 .36091 .3302 .35338 .30408 Metetra
.597 .499 .714 r
.35338 .30408 .36091 .3302 .37464 .3257 .36708 .29949 Metetra
.634 .522 .709 r
.36708 .29949 .37464 .3257 .38857 .31819 .38098 .29214 Metetra
.665 .542 .704 r
.38098 .29214 .38857 .31819 .40266 .30783 .39504 .28219 Metetra
.691 .559 .7 r
.39504 .28219 .40266 .30783 .41686 .295 .4092 .26999 Metetra
.711 .574 .699 r
.4092 .26999 .41686 .295 .43112 .28023 .42344 .25604 Metetra
.726 .587 .7 r
.42344 .25604 .43112 .28023 .4454 .26417 .43769 .24095 Metetra
.735 .598 .703 r
.43769 .24095 .4454 .26417 .45966 .24758 .45194 .2254 Metetra
.628 .546 .742 r
.45194 .2254 .45966 .24758 .47388 .23119 .46598 .21941 Metetra
.652 .695 .877 r
.46598 .21941 .47388 .23119 .48797 .22377 .48007 .21423 Metetra
.657 .749 .918 r
.48007 .21423 .48797 .22377 .50208 .21861 .49424 .20903 Metetra
.657 .749 .918 r
.49424 .20903 .50208 .21861 .51628 .21343 .50848 .2038 Metetra
.657 .749 .918 r
.50848 .2038 .51628 .21343 .53054 .20823 .52279 .19854 Metetra
.657 .749 .918 r
.52279 .19854 .53054 .20823 .54488 .20299 .53718 .19326 Metetra
.657 .749 .918 r
.53718 .19326 .54488 .20299 .5593 .19773 .55165 .18794 Metetra
.657 .749 .918 r
.55165 .18794 .5593 .19773 .57379 .19244 .56619 .1826 Metetra
.657 .749 .918 r
.56619 .1826 .57379 .19244 .58835 .18712 .5808 .17723 Metetra
.657 .749 .918 r
.5808 .17723 .58835 .18712 .603 .18178 .5955 .17184 Metetra
.657 .749 .918 r
.5955 .17184 .603 .18178 .61772 .17641 .61027 .16641 Metetra
.657 .749 .918 r
.61027 .16641 .61772 .17641 .63252 .17101 .62512 .16096 Metetra
.657 .749 .918 r
.62512 .16096 .63252 .17101 .64739 .16558 .64005 .15547 Metetra
.657 .749 .918 r
.64005 .15547 .64739 .16558 .66235 .16012 .65506 .14996 Metetra
.657 .749 .918 r
.65506 .14996 .66235 .16012 .67738 .15463 .67015 .14442 Metetra
.657 .749 .918 r
.67015 .14442 .67738 .15463 .6925 .14911 .68533 .13885 Metetra
.657 .749 .918 r
.68533 .13885 .6925 .14911 .7077 .14356 .70058 .13324 Metetra
.657 .749 .918 r
.70058 .13324 .7077 .14356 .72298 .13799 .71592 .12761 Metetra
.657 .749 .918 r
.04128 .36383 .05052 .37199 .06254 .36758 .05334 .35937 Metetra
.657 .749 .918 r
.05334 .35937 .06254 .36758 .07462 .36314 .06545 .3549 Metetra
.657 .749 .918 r
.06545 .3549 .07462 .36314 .08676 .35869 .07761 .3504 Metetra
.657 .749 .918 r
.07761 .3504 .08676 .35869 .09895 .35421 .08984 .34588 Metetra
.657 .749 .918 r
.08984 .34588 .09895 .35421 .11121 .34971 .10213 .34134 Metetra
.657 .749 .918 r
.10213 .34134 .11121 .34971 .12352 .34518 .11447 .33678 Metetra
.657 .749 .918 r
.11447 .33678 .12352 .34518 .13589 .34064 .12688 .33219 Metetra
.657 .749 .918 r
.12688 .33219 .13589 .34064 .14832 .33607 .13935 .32759 Metetra
.657 .749 .918 r
.13935 .32759 .14832 .33607 .16082 .33149 .15187 .32296 Metetra
.657 .749 .918 r
.15187 .32296 .16082 .33149 .17337 .32687 .16446 .3183 Metetra
.657 .749 .918 r
.16446 .3183 .17337 .32687 .18599 .32224 .17711 .31363 Metetra
.657 .749 .918 r
.17711 .31363 .18599 .32224 .19867 .31758 .18983 .30893 Metetra
.657 .749 .918 r
.18983 .30893 .19867 .31758 .21141 .31291 .2026 .30421 Metetra
.657 .749 .918 r
.2026 .30421 .21141 .31291 .22421 .3082 .21544 .29946 Metetra
.657 .749 .918 r
.21544 .29946 .22421 .3082 .23708 .30348 .22835 .29469 Metetra
.657 .749 .918 r
.22835 .29469 .23708 .30348 .25001 .29873 .24132 .2899 Metetra
.657 .749 .918 r
.24132 .2899 .25001 .29873 .263 .29396 .25435 .28508 Metetra
.657 .749 .918 r
.25435 .28508 .263 .29396 .27606 .28916 .26745 .28024 Metetra
.657 .749 .918 r
.26745 .28024 .27606 .28916 .28853 .29299 .28061 .27538 Metetra
.532 .534 .802 r
.28061 .27538 .28853 .29299 .30103 .29824 .29354 .27459 Metetra
.437 .415 .736 r
.29354 .27459 .30103 .29824 .31375 .30255 .30627 .27792 Metetra
.475 .432 .73 r
.30627 .27792 .31375 .30255 .3267 .3053 .31923 .27985 Metetra
.517 .453 .723 r
.31923 .27985 .3267 .3053 .33992 .30594 .33243 .27989 Metetra
.558 .475 .717 r
.33243 .27989 .33992 .30594 .35338 .30408 .34588 .27767 Metetra
.596 .497 .712 r
.34588 .27767 .35338 .30408 .36708 .29949 .35955 .27298 Metetra
.63 .517 .707 r
.35955 .27298 .36708 .29949 .38098 .29214 .37341 .2658 Metetra
.659 .536 .703 r
.37341 .2658 .38098 .29214 .39504 .28219 .38743 .25627 Metetra
.683 .552 .7 r
.38743 .25627 .39504 .28219 .4092 .26999 .40156 .24472 Metetra
.702 .567 .7 r
.40156 .24472 .4092 .26999 .42344 .25604 .41576 .2316 Metetra
.688 .564 .71 r
.41576 .2316 .42344 .25604 .43769 .24095 .42991 .2202 Metetra
.619 .554 .759 r
.42991 .2202 .43769 .24095 .45194 .2254 .4439 .21503 Metetra
.656 .729 .903 r
.4439 .21503 .45194 .2254 .46598 .21941 .45797 .20983 Metetra
.657 .749 .918 r
.45797 .20983 .46598 .21941 .48007 .21423 .4721 .2046 Metetra
.657 .749 .918 r
.4721 .2046 .48007 .21423 .49424 .20903 .48632 .19935 Metetra
.657 .749 .918 r
.48632 .19935 .49424 .20903 .50848 .2038 .50061 .19407 Metetra
.657 .749 .918 r
.50061 .19407 .50848 .2038 .52279 .19854 .51497 .18876 Metetra
.657 .749 .918 r
.51497 .18876 .52279 .19854 .53718 .19326 .52941 .18343 Metetra
.657 .749 .918 r
.52941 .18343 .53718 .19326 .55165 .18794 .54392 .17806 Metetra
.657 .749 .918 r
.54392 .17806 .55165 .18794 .56619 .1826 .55851 .17267 Metetra
.657 .749 .918 r
.55851 .17267 .56619 .1826 .5808 .17723 .57318 .16725 Metetra
.657 .749 .918 r
.57318 .16725 .5808 .17723 .5955 .17184 .58793 .1618 Metetra
.657 .749 .918 r
.58793 .1618 .5955 .17184 .61027 .16641 .60275 .15632 Metetra
.657 .749 .918 r
.60275 .15632 .61027 .16641 .62512 .16096 .61766 .15081 Metetra
.657 .749 .918 r
.61766 .15081 .62512 .16096 .64005 .15547 .63264 .14527 Metetra
.657 .749 .918 r
.63264 .14527 .64005 .15547 .65506 .14996 .64771 .13971 Metetra
.657 .749 .918 r
.64771 .13971 .65506 .14996 .67015 .14442 .66285 .13411 Metetra
.657 .749 .918 r
.66285 .13411 .67015 .14442 .68533 .13885 .67808 .12848 Metetra
.657 .749 .918 r
.67808 .12848 .68533 .13885 .70058 .13324 .69339 .12282 Metetra
.657 .749 .918 r
.69339 .12282 .70058 .13324 .71592 .12761 .70878 .11713 Metetra
.657 .749 .918 r
.03196 .35559 .04128 .36383 .05334 .35937 .04405 .35109 Metetra
.657 .749 .918 r
.04405 .35109 .05334 .35937 .06545 .3549 .05619 .34658 Metetra
.657 .749 .918 r
.05619 .34658 .06545 .3549 .07761 .3504 .06839 .34204 Metetra
.657 .749 .918 r
.06839 .34204 .07761 .3504 .08984 .34588 .08065 .33748 Metetra
.657 .749 .918 r
.08065 .33748 .08984 .34588 .10213 .34134 .09297 .3329 Metetra
.657 .749 .918 r
.09297 .3329 .10213 .34134 .11447 .33678 .10534 .3283 Metetra
.657 .749 .918 r
.10534 .3283 .11447 .33678 .12688 .33219 .11778 .32367 Metetra
.657 .749 .918 r
.11778 .32367 .12688 .33219 .13935 .32759 .13029 .31902 Metetra
.657 .749 .918 r
.13029 .31902 .13935 .32759 .15187 .32296 .14285 .31435 Metetra
.657 .749 .918 r
.14285 .31435 .15187 .32296 .16446 .3183 .15547 .30965 Metetra
.657 .749 .918 r
.15547 .30965 .16446 .3183 .17711 .31363 .16816 .30493 Metetra
.657 .749 .918 r
.16816 .30493 .17711 .31363 .18983 .30893 .18091 .30019 Metetra
.657 .749 .918 r
.18091 .30019 .18983 .30893 .2026 .30421 .19372 .29543 Metetra
.657 .749 .918 r
.19372 .29543 .2026 .30421 .21544 .29946 .2066 .29064 Metetra
.657 .749 .918 r
.2066 .29064 .21544 .29946 .22835 .29469 .21954 .28582 Metetra
.657 .749 .918 r
.21954 .28582 .22835 .29469 .24132 .2899 .23255 .28099 Metetra
.657 .749 .918 r
.23255 .28099 .24132 .2899 .25435 .28508 .24562 .27613 Metetra
.657 .749 .918 r
.24562 .27613 .25435 .28508 .26745 .28024 .25876 .27124 Metetra
.657 .749 .918 r
.25876 .27124 .26745 .28024 .28061 .27538 .27196 .26633 Metetra
.657 .749 .918 r
.27196 .26633 .28061 .27538 .29354 .27459 .28523 .26139 Metetra
.646 .658 .848 r
.28523 .26139 .29354 .27459 .30627 .27792 .29857 .25643 Metetra
.556 .508 .756 r
.29857 .25643 .30627 .27792 .31923 .27985 .31176 .25452 Metetra
.526 .459 .724 r
.31176 .25452 .31923 .27985 .33243 .27989 .32496 .25396 Metetra
.563 .479 .718 r
.32496 .25396 .33243 .27989 .34588 .27767 .33838 .25138 Metetra
.597 .498 .712 r
.33838 .25138 .34588 .27767 .35955 .27298 .35202 .2466 Metetra
.628 .516 .708 r
.35202 .2466 .35955 .27298 .37341 .2658 .36585 .23959 Metetra
.654 .534 .704 r
.36585 .23959 .37341 .2658 .38743 .25627 .37983 .23048 Metetra
.66 .54 .706 r
.37983 .23048 .38743 .25627 .40156 .24472 .39386 .22099 Metetra
.609 .523 .732 r
.39386 .22099 .40156 .24472 .41576 .2316 .40775 .21583 Metetra
.638 .621 .817 r
.40775 .21583 .41576 .2316 .42991 .2202 .42172 .21063 Metetra
.657 .749 .918 r
.42172 .21063 .42991 .2202 .4439 .21503 .43576 .20541 Metetra
.657 .749 .918 r
.43576 .20541 .4439 .21503 .45797 .20983 .44987 .20016 Metetra
.657 .749 .918 r
.44987 .20016 .45797 .20983 .4721 .2046 .46406 .19489 Metetra
.657 .749 .918 r
.46406 .19489 .4721 .2046 .48632 .19935 .47832 .18958 Metetra
.657 .749 .918 r
.47832 .18958 .48632 .19935 .50061 .19407 .49266 .18425 Metetra
.657 .749 .918 r
.49266 .18425 .50061 .19407 .51497 .18876 .50707 .17889 Metetra
.657 .749 .918 r
.50707 .17889 .51497 .18876 .52941 .18343 .52156 .1735 Metetra
.657 .749 .918 r
.52156 .1735 .52941 .18343 .54392 .17806 .53612 .16808 Metetra
.657 .749 .918 r
.53612 .16808 .54392 .17806 .55851 .17267 .55076 .16264 Metetra
.657 .749 .918 r
.55076 .16264 .55851 .17267 .57318 .16725 .56548 .15716 Metetra
.657 .749 .918 r
.56548 .15716 .57318 .16725 .58793 .1618 .58028 .15166 Metetra
.657 .749 .918 r
.58028 .15166 .58793 .1618 .60275 .15632 .59516 .14613 Metetra
.657 .749 .918 r
.59516 .14613 .60275 .15632 .61766 .15081 .61012 .14056 Metetra
.657 .749 .918 r
.61012 .14056 .61766 .15081 .63264 .14527 .62516 .13497 Metetra
.657 .749 .918 r
.62516 .13497 .63264 .14527 .64771 .13971 .64027 .12935 Metetra
.657 .749 .918 r
.64027 .12935 .64771 .13971 .66285 .13411 .65548 .12369 Metetra
.657 .749 .918 r
.65548 .12369 .66285 .13411 .67808 .12848 .67076 .11801 Metetra
.657 .749 .918 r
.67076 .11801 .67808 .12848 .69339 .12282 .68613 .1123 Metetra
.657 .749 .918 r
.68613 .1123 .69339 .12282 .70878 .11713 .70158 .10655 Metetra
.657 .749 .918 r
.02256 .34727 .03196 .35559 .04405 .35109 .03467 .34274 Metetra
.657 .749 .918 r
.03467 .34274 .04405 .35109 .05619 .34658 .04685 .33818 Metetra
.657 .749 .918 r
.04685 .33818 .05619 .34658 .06839 .34204 .05908 .33361 Metetra
.657 .749 .918 r
.05908 .33361 .06839 .34204 .08065 .33748 .07137 .32901 Metetra
.657 .749 .918 r
.07137 .32901 .08065 .33748 .09297 .3329 .08372 .32438 Metetra
.657 .749 .918 r
.08372 .32438 .09297 .3329 .10534 .3283 .09613 .31974 Metetra
.657 .749 .918 r
.09613 .31974 .10534 .3283 .11778 .32367 .10861 .31507 Metetra
.657 .749 .918 r
.10861 .31507 .11778 .32367 .13029 .31902 .12114 .31038 Metetra
.657 .749 .918 r
.12114 .31038 .13029 .31902 .14285 .31435 .13374 .30566 Metetra
.657 .749 .918 r
.13374 .30566 .14285 .31435 .15547 .30965 .1464 .30092 Metetra
.657 .749 .918 r
.1464 .30092 .15547 .30965 .16816 .30493 .15912 .29616 Metetra
.657 .749 .918 r
.15912 .29616 .16816 .30493 .18091 .30019 .17191 .29138 Metetra
.657 .749 .918 r
.17191 .29138 .18091 .30019 .19372 .29543 .18476 .28657 Metetra
.657 .749 .918 r
.18476 .28657 .19372 .29543 .2066 .29064 .19767 .28173 Metetra
.657 .749 .918 r
.19767 .28173 .2066 .29064 .21954 .28582 .21065 .27688 Metetra
.657 .749 .918 r
.21065 .27688 .21954 .28582 .23255 .28099 .2237 .27199 Metetra
.657 .749 .918 r
.2237 .27199 .23255 .28099 .24562 .27613 .23681 .26709 Metetra
.657 .749 .918 r
.23681 .26709 .24562 .27613 .25876 .27124 .24998 .26216 Metetra
.657 .749 .918 r
.24998 .26216 .25876 .27124 .27196 .26633 .26322 .2572 Metetra
.657 .749 .918 r
.26322 .2572 .27196 .26633 .28523 .26139 .27654 .25222 Metetra
.657 .749 .918 r
.27654 .25222 .28523 .26139 .29857 .25643 .28991 .24721 Metetra
.657 .749 .918 r
.28991 .24721 .29857 .25643 .31176 .25452 .30336 .24218 Metetra
.649 .679 .865 r
.30336 .24218 .31176 .25452 .32496 .25396 .31688 .23712 Metetra
.632 .601 .801 r
.31688 .23712 .32496 .25396 .33838 .25138 .33046 .23203 Metetra
.623 .568 .772 r
.33046 .23203 .33838 .25138 .35202 .2466 .34411 .22692 Metetra
.622 .565 .769 r
.34411 .22692 .35202 .2466 .36585 .23959 .35784 .22179 Metetra
.629 .59 .791 r
.35784 .22179 .36585 .23959 .37983 .23048 .37164 .21662 Metetra
.645 .655 .845 r
.37164 .21662 .37983 .23048 .39386 .22099 .3855 .21143 Metetra
.657 .749 .918 r
.3855 .21143 .39386 .22099 .40775 .21583 .39944 .20622 Metetra
.657 .749 .918 r
.39944 .20622 .40775 .21583 .42172 .21063 .41346 .20097 Metetra
.657 .749 .918 r
.41346 .20097 .42172 .21063 .43576 .20541 .42754 .1957 Metetra
.657 .749 .918 r
.42754 .1957 .43576 .20541 .44987 .20016 .4417 .1904 Metetra
.657 .749 .918 r
.4417 .1904 .44987 .20016 .46406 .19489 .45594 .18507 Metetra
.657 .749 .918 r
.45594 .18507 .46406 .19489 .47832 .18958 .47024 .17972 Metetra
.657 .749 .918 r
.47024 .17972 .47832 .18958 .49266 .18425 .48463 .17433 Metetra
.657 .749 .918 r
.48463 .17433 .49266 .18425 .50707 .17889 .49909 .16892 Metetra
.657 .749 .918 r
.49909 .16892 .50707 .17889 .52156 .1735 .51363 .16348 Metetra
.657 .749 .918 r
.51363 .16348 .52156 .1735 .53612 .16808 .52824 .15801 Metetra
.657 .749 .918 r
.52824 .15801 .53612 .16808 .55076 .16264 .54294 .15251 Metetra
.657 .749 .918 r
.54294 .15251 .55076 .16264 .56548 .15716 .55771 .14698 Metetra
.657 .749 .918 r
.55771 .14698 .56548 .15716 .58028 .15166 .57256 .14142 Metetra
.657 .749 .918 r
.57256 .14142 .58028 .15166 .59516 .14613 .58749 .13583 Metetra
.657 .749 .918 r
.58749 .13583 .59516 .14613 .61012 .14056 .6025 .13022 Metetra
.657 .749 .918 r
.6025 .13022 .61012 .14056 .62516 .13497 .61759 .12457 Metetra
.657 .749 .918 r
.61759 .12457 .62516 .13497 .64027 .12935 .63277 .11889 Metetra
.657 .749 .918 r
.63277 .11889 .64027 .12935 .65548 .12369 .64803 .11318 Metetra
.657 .749 .918 r
.64803 .11318 .65548 .12369 .67076 .11801 .66337 .10743 Metetra
.657 .749 .918 r
.66337 .10743 .67076 .11801 .68613 .1123 .67879 .10166 Metetra
.657 .749 .918 r
.67879 .10166 .68613 .1123 .70158 .10655 .6943 .09586 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.04003 .25401 m
.04482 .2585 L
s
[(-1)] .03045 .24505 1 .93576 Mshowa
.18786 .19613 m
.19242 .20085 L
s
[(-0.5)] .17875 .18668 .96492 1 Mshowa
.34468 .13472 m
.34896 .13969 L
s
[(0)] .33612 .12478 .8612 1 Mshowa
.51132 .06947 m
.51528 .0747 L
s
[(0.5)] .5034 .05901 .75747 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06892 .2427 m
.07176 .24542 L
s
.09814 .23126 m
.10096 .23401 L
s
.1277 .21969 m
.13049 .22246 L
s
.1576 .20797 m
.16037 .21078 L
s
.21848 .18414 m
.22119 .187 L
s
.24947 .172 m
.25214 .1749 L
s
.28082 .15973 m
.28346 .16265 L
s
.31256 .1473 m
.31516 .15025 L
s
.37719 .12199 m
.37973 .125 L
s
.41011 .1091 m
.4126 .11215 L
s
.44343 .09606 m
.44588 .09913 L
s
.47716 .08285 m
.47958 .08595 L
s
.54591 .05593 m
.54824 .0591 L
s
.58094 .04221 m
.58323 .04541 L
s
.61641 .02832 m
.61866 .03155 L
s
.65234 .01425 m
.65454 .01752 L
s
gsave
.29165 .07573 -70.3112 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00o?ooool4o`000003oa0@4?oooooooooo06Gooooo003nooooo`03o`00
0?oooooooooo06Oooooo003nooooo`03o`000?oooooooooo06Oooooo003nooooo`03o`000?oooooo
oooo06Oooooo003nooooo`03o`000?oooooooooo06Oooooo003nooooo`03o`000?oooooooooo06Oo
oooo003nooooo`03o`000?oooooooooo06Oooooo003looooo`03oeEEEOmVIVKo000000[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP1Jooooo`00ooooool:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
F_ooool00?oooooo2_ooool01Ol@413ooooooooooooooooo410@05[ooooo003oooooo`[ooooo00Go
0000ooooooooooooooooo`00001Jooooo`00ooooool:ooooo`05o`000?ooooooooooooooool00000
F_ooool00?oooooo0oooool2o`0000Gooooo00Go410@oooooooooooooooooa0@401Jooooo`00oooo
ool3o`000003ooooool0003ooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Jooooo`00oOoo
ool2o`0000?ooooo0ol00004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0F_ooool00?[ooooo0ol0
0006ooooo`03o`000?oooooo000006;ooooo003hooooo`;o00002Oooool00ol0003oooooo`00001R
ooooo`00mOooool3o`0000_ooooo00Co0000oooooooooooo0000HOooool00?;ooooo0ol00003oooo
o`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00001Pooooo`00l?ooool2o`00
017ooooo00Go0000ooooooooooooooooo`00001Pooooo`00kOooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Mooooo`00joooool2o`0001Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Looooo`00/oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd07oooool3o`000003ooooool0003ooooo
01Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Looooo`00/oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01cooooo0_l0000Loooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Foooool00;?ooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo01Sooooo0ol0000Nooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0F_ooool00;?ooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01Oooooo0_l0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0F_ooool00;?ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`05Oooool3o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1I
ooooo`00/oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool3
o`0000?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`04ooooo`;o0000Foooool0
0;?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo01;ooooo0_l0000Y
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0F?ooool007cooooo0_l00002oooo
o`;o0000<Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000>ooooo`?o0000:oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Oooooo001looooo`06onk^k_lQ8B7oQhN7
okZj^_l0003ogMgMD_ooool2o`0002kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Gooooo`00OOooool01?oMgMgo0000oa0@4?o<c<a@ooooo`?o00000_ooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0E_ooool007gooooo00Cok^k^
ob4Q8Ol@413ok^k^C_ooool2o`0003?ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`1Eooooo`00OOooool01?lQ8B7oMgMgogMgMolb<S9;ooooo`?o0000=Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo05Gooooo001looooo`;o00000_ooool2o`0004Sooooo0_l0000h
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0E?ooool00<Oooooo1?l0000ioooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Doooool00<Gooooo0_l00004ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Cooooo`00
`_ooool3o`0003oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Booooo`00_ooo
ool3o`0004;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Aooooo`00_Oooool3
o`0004Cooooo00?o0000ooooooooool03?ooool2o`0005?ooooo002jooooo`?o00000oooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0D?ooool00;So
oooo0_l0001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Coooool00;Gooooo
0ol0001<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Coooool008_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Sooooo`;o0000Coooool2o`00017ooooo00?o0000ooooooooool0
C_ooool008_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Pooooo`?o00000_ooool00ol0003ooooo
ooooo`19ooooo`?o000000?oZ;o[o`000?ooool04Oooool00ol0003oooooooooo`1=ooooo`00Rooo
ool01Ol@413ooooooooooooooooo410@01kooooo0_l0001?ooooo`;o00001?nX_n/2o`00017ooooo
00?o0000ooooooooool0COooool008_ooooo00Go0000ooooooooooooooooo`00000Kooooo`?o0000
C_ooool3o`000003ojRojol0003oZ;o[00?oZ;o[0ol0000Aooooo`03o`000?oooooooooo04cooooo
002;ooooo`05o`000?ooooooooooooooool000006Oooool2o`0004oooooo0_l00005ojRoj`03o`00
0?nX_n_o000000;o000000?oZ;o[o`000?ooool04Oooool00ol0003oooooooooo`1;ooooo`00Rooo
ool01Ol@413ooooooooooooooooo410@01Kooooo0ol000000ooooooo0000ooooo`1;ooooo`?o0000
00?oZ;o[o`000?nX_n/01?nX_n/2o`0000;oZ;o[00Co0000ojRojonX_n_o00004Oooool00ol0003o
ooooooooo`1;ooooo`00Roooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo0ol0001>ooooo`?o
00001OnX_n/00ol0003oZ;o[o`000002o`000005ojRojol0003oZ;o[ojRojol000000_nX_n/00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo04[ooooo002;ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h04Oooool2o`0004gooooo1?l00002ojRoj`03o`000?nX_n_oZ;o[00?oZ;o[0_l00005ojRo
j`03o`000?nX_n_o000000;oZ;o[0_l0000Aooooo`03o`000?oooooooooo04[ooooo002Nooooo`?o
0000C?ooool3o`000003ojRojol0003oZ;o[00CoZ;o[00?o0000ojRojol000000_l000000onX_n_o
0000ojRoj`04ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?ooool04?ooool2o`0004_o
oooo002Looooo`;o00000_ooool00ol0003oooooooooo`18ooooo`;o00001OnX_n/00ol0003oZ;o[
ojRoj`02ojRoj`;o00001OnX_n/01?l0003oZ;o[ojRojonX_n/4o`0000CoZ;o[00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`18ooooo`00VOooool3o`0004cooooo0ol000000onX_n_o0000
ojRoj`04ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/01?nX_n/4o`0000?oZ;o[
00?o0000ojRojonX_n/00_nX_n/2o`00017ooooo00?o0000ooooooooool0B?ooool009Oooooo0_l0
001=ooooo`;o00001OnX_n/00ol0003oZ;o[ojRoj`02ojRoj`;o00001OnX_n/00ol0003oZ;o[o`00
0002o`000003ojRojol0003oZ;o[00CoZ;o[0_l000001OnX_n_o0000o`000?nX_n_o000001;ooooo
00?o0000ooooooooool0Aoooool009Cooooo0ol0001<ooooo`?o00000_nX_n/00ol0003oZ;o[ojRo
j`02ojRoj`03o`000?nX_n_o000000;o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`;o00001OnX
_n/00ol0003oZ;o[ojRoj`02ojRoj`?o00001?nX_n/00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo04Kooooo002Booooo`;o000000?oooooo`000?ooool0B_ooool2o`0000KoZ;o[00?o0000
ojRojonX_n/00ol00006ojRoj`06o`000?nX_n_o0000o`000?nX_n_o00001_nX_n/00ol0003oZ;o[
o`000002o`000003ojRojol0003oZ;o[00CoZ;o[00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`16ooooo`00Soooool3o`0000Cooooo00?o0000ooooooooool0A_ooool2o`0000;oZ;o[00?o
0000ojRojonX_n/00onX_n/3o`0000?oZ;o[00?o0000ojRojonX_n/00onX_n/2o`0000CoZ;o[00?o
0000ojRojonX_n/00onX_n/2o`0000;oZ;o[00Co0000ojRojonX_n_o00000onX_n/3o`00017ooooo
00?o0000ooooooooool0AOooool008cooooo0ol0001=ooooo`?o00001OnX_n/00ol0003oZ;o[o`00
0002o`000003ojRojol0003oZ;o[00CoZ;o[00?o0000ojRojol000000_l000000onX_n_o0000ojRo
j`04ojRoj`03o`000?nX_n_o000000;o000000GoZ;o[o`000?nX_n_oZ;o[o`000002ojRoj`Co0000
0_nX_n/00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04Cooooo002:ooooo`;o0000C?oo
ool4o`0000;oZ;o[00?o0000ojRojonX_n/00onX_n/2o`0000GoZ;o[00?o0000ojRojonX_n/00_nX
_n/2o`0000GoZ;o[00Co0000ojRojonX_n_oZ;o[0ol00005ojRoj`03o`000?nX_n_o000000;o0000
00?oZ;o[o`000?nX_n/01?nX_n/00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
0027ooooo`Go0000BOooool3o`000003ojRojol0003oZ;o[00CoZ;o[00?o0000ojRojol000000_l0
00000onX_n_o0000ojRoj`04ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/01?nX
_n/4o`0000;oZ;o[00?o0000ojRojonX_n/00onX_n/3o`0000CoZ;o[00?o0000ojRojonX_n/00_nX
_n/2o`00017ooooo00?o0000ooooooooool0@oooool008Gooooo0_l0001<ooooo`;o00001OnX_n/0
0ol0003oZ;o[ojRoj`02ojRoj`;o00001OnX_n/01?l0003oZ;o[ojRojonX_n/3o`0000GoZ;o[00?o
0000ojRojol000000_l000000onX_n_o0000ojRoj`04ojRoj`03o`000?nX_n_o000000;o000000?o
Z;o[o`000?l000001?nX_n/00ol0003oZ;o[o`000002o`000003ojRojol0003ooooo017ooooo00?o
0000ooooooooool0@_ooool008;ooooo0ol0001;ooooo`?o00000_nX_n/00ol0003oZ;o[ojRoj`02
ojRoj`03o`000?nX_n_o000000;o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`Co00000_nX_n/0
0ol0003oZ;o[ojRoj`03ojRoj`;o00001OnX_n/00ol0003oZ;o[ojRoj`02ojRoj`;o00001OnX_n/2
o`0000;oZ;o[0ol00005ojRoj`03o`000?oooooooooo00kooooo0_l00014ooooo`00BOooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd08Ooo
ool2o`0004cooooo0_l00006ojRoj`03o`000?nX_n_oZ;o[00?o00001_nX_n/01_l0003oZ;o[o`00
0?l0003oZ;o[o`0000GoZ;o[00?o0000ojRojol000000_l00002ojRoj`03o`000?nX_n_oZ;o[00;o
Z;o[00?o0000ojRojol000000_l000000onX_n_o0000ojRoj`04ojRoj`Co00000_nX_n/00ol0003o
Z;o[ojRoj`03ojRoj`;o00004Oooool00ol0003oooooooooo`11ooooo`00BOooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01gooooo0ol000000ooooooo
0000ooooo`19ooooo`;o00000_nX_n/00ol0003oZ;o[ojRoj`03ojRoj`?o00000onX_n/00ol0003o
Z;o[ojRoj`03ojRoj`;o00001?nX_n/00ol0003oZ;o[ojRoj`02ojRoj`;o00001_nX_n/00ol0003o
Z;o[ojRoj`03o`0000GoZ;o[00?o0000ojRojol000000_l000000onX_n_o0000ojRoj`04ojRoj`03
o`000?nX_n_o000000;o000000?oZ;o[o`000?ooool04Oooool00ol0003oooooooooo`10ooooo`00
@Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01[o
oooo0_l0001<ooooo`?o00001OnX_n/00ol0003oZ;o[o`000002o`000003ojRojol0003oZ;o[00Co
Z;o[00?o0000ojRojol000000_l000000onX_n_o0000ojRoj`04ojRoj`04o`000?nX_n_o0000o`00
00;oZ;o[00?o0000ojRojonX_n/00onX_n/3o`0000?oZ;o[00?o0000ojRojonX_n/00_nX_n/2o`00
00CoZ;o[0_l00004ojRoj`;o00001OnX_n/00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
043ooooo0019ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Hoooo
o`?o0000B_ooool4o`0000;oZ;o[00?o0000ojRojonX_n/00onX_n/2o`0000GoZ;o[00?o0000ojRo
jonX_n/00_nX_n/2o`0000GoZ;o[00Co0000ojRojonX_n_oZ;o[0ol00005ojRoj`03o`000?nX_n_o
000000;o000000?oZ;o[o`000?nX_n/01?nX_n/01?l0003oZ;o[o`000?l00002ojRoj`08o`000?nX
_n_oZ;o[ojRojol0003oZ;o[o`000?nX_n/2o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/2o`00
017ooooo00?o0000ooooooooool0?oooool004Wooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`05oooool2o`0004[ooooo0ol000000onX_n_o0000ojRoj`04
ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/01?nX_n/00ol0003oZ;o[o`000002
o`000003ojRojol0003oZ;o[00CoZ;o[1?l00002ojRoj`03o`000?nX_n_oZ;o[00?oZ;o[0_l00005
ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0_l00005ojRoj`03o`000?nX_n_oZ;o[00Co00001OnX_n/0
1?l0003oZ;o[o`000?l00002ojRoj`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd08oooool004Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01Ko
oooo0ol000000ooooooo0000ooooo`17ooooo`;o00001OnX_n/00ol0003oZ;o[ojRoj`02ojRoj`;o
00001OnX_n/01?l0003oZ;o[ojRojonX_n/3o`0000GoZ;o[00?o0000ojRojol000000_l000000onX
_n_o0000ojRoj`04ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/01?nX_n/00ol0
003oZ;o[o`000002o`000003ojRojol0003oZ;o[00CoZ;o[1?l00002ojRoj`03o`000?nX_n_oZ;o[
00?oZ;o[0_l00005ojRoj`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo02;ooooo0019oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Cooooo`?o0000Boooool2
o`0000;oZ;o[00?o0000ojRojonX_n/00onX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX
_n_oZ;o[00;oZ;o[1?l00003ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0_l00005ojRoj`03o`000?nX
_n_oZ;o[00;oZ;o[0_l00005ojRoj`04o`000?nX_n_oZ;o[ojRoj`?o00001OnX_n/00ol0003oZ;o[
o`000002o`000004ojRojol0003oZ;o[o`0000?oZ;o[00?o0000ojRojol000000_l000000onX_n_o
0000ojRoj`04ojRoj`;o00004?ooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`0Qooooo`00BOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l0000@ooooo`;o0000C?ooool2o`0000GoZ;o[00Co0000ojRojonX_n_oZ;o[0ol00005
ojRoj`06o`000?nX_n_o0000o`000?nX_n_o00001_nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03
o`000?nX_n_oZ;o[00;oZ;o[00?o0000ojRojol000000_l000000onX_n_o0000ojRoj`04ojRoj`Co
00000_nX_n/00ol0003oZ;o[ojRoj`03ojRoj`;o00001OnX_n/2o`0000;oZ;o[0ol00005ojRoj`03
o`000?nX_n_o000000;o000000?oZ;o[o`000?ooool04?ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Rooooo`00Joooool3o`0004_o
oooo0ol000000onX_n_o0000ojRoj`04ojRoj`Co00000_nX_n/00ol0003oZ;o[ojRoj`03ojRoj`;o
00001?nX_n/00ol0003oZ;o[ojRoj`03ojRoj`;o00001OnX_n/00ol0003oZ;o[ojRoj`03o`0000Go
Z;o[00?o0000ojRojol000000_l000000onX_n_o0000ojRoj`04ojRoj`03o`000?nX_n_o000000;o
000000?oZ;o[o`000?nX_n/01?nX_n/4o`0000;oZ;o[00?o0000ojRojonX_n/00onX_n/2o`0000Go
Z;o[00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<02?ooooo001Yooooo`;o00000_ooool00ol0
003oooooooooo`16ooooo`?o00001OnX_n/00ol0003oZ;o[o`000002o`0000;oZ;o[00?o0000ojRo
jonX_n/00_nX_n/00ol0003oZ;o[o`000002o`000003ojRojol0003oZ;o[00CoZ;o[00?o0000ojRo
jol000000_l000000onX_n_o0000ojRoj`04ojRoj`?o00000onX_n/00ol0003oZ;o[ojRoj`02ojRo
j`;o00001OnX_n/01?l0003oZ;o[ojRojonX_n/3o`0000GoZ;o[00?o0000ojRojol000000_l00000
0onX_n_o0000ojRoj`04ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/01?nX_n/0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo02Gooooo001Vooooo`?o0000B_ooool3o`0000?oZ;o[00?o0000
ojRojonX_n/00_nX_n/2o`0000KoZ;o[00?o0000ojRojonX_n/00ol00005ojRoj`04o`000?nX_n_o
Z;o[ojRoj`?o00001OnX_n/00ol0003oZ;o[o`000002o`000003ojRojol0003oZ;o[00CoZ;o[00Co
0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`Co00000_nX_n/00ol0003oZ;o[
ojRoj`03ojRoj`;o00001?nX_n/2o`0000CoZ;o[0_l00005ojRoj`04o`000?nX_n_oZ;o[ojRoj`?o
00003oooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00cooooo0ol000000ol@413oooooooooo`0Cooooo`00I?ooool2o`0004[ooooo0ol000000onX_n_o
0000ojRoj`04ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o0000ojRojonX_n/00onX_n/3o`00
00?oZ;o[00?o0000ojRojonX_n/00_nX_n/4o`0000;oZ;o[00?o0000ojRojonX_n/00onX_n/2o`00
00GoZ;o[00Co0000ojRojonX_n_oZ;o[0ol00005ojRoj`06o`000?nX_n_o0000o`000?nX_n_o0000
1OnX_n/00ol0003oZ;o[o`000002o`000003ojRojol0003oZ;o[00?oZ;o[0_l000001_nX_n_o0000
o`000?l0003oZ;o[o`0000GoZ;o[1?l00002ojRoj`03o`000?oooooooooo00cooooo00Co0000oooo
oooooooo00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000=ooooo`03oa0@4?nj
^[[ooooo01Cooooo001Qooooo`?o0000B_ooool2o`0000GoZ;o[00Co0000ojRojonX_n_oZ;o[0ol0
0005ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/01?nX_n/01?l0003oZ;o[o`00
0?l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[00?o0000ojRojol000000_l000000onX_n_o0000
ojRoj`04ojRoj`Co00000_nX_n/00ol0003oZ;o[ojRoj`03ojRoj`;o00001?nX_n/00ol0003oZ;o[
ojRoj`02ojRoj`;o00001OnX_n/01?l0003oZ;o[ojRojonX_n/3o`0000GoZ;o[00?o0000ojRojol0
00000_l000000onX_n_o0000ojRoj`04ojRoj`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool08_ooool00onHV9So<S8booooo`0Dooooo`00Goooool2o`0000;ooooo00?o0000ooooooooool0
A_ooool2o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/4o`0000;oZ;o[00?o0000ojRojonX_n/0
0onX_n/2o`0000GoZ;o[00?o0000ojRojonX_n/00_nX_n/2o`0000GoZ;o[00?o0000ojRojonX_n/0
0ol00005ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/01?nX_n/00ol0003oZ;o[
o`000002o`000003ojRojol0003oZ;o[00CoZ;o[00Co0000ojRojol0003o00000_nX_n/00ol0003o
Z;o[ojRoj`02ojRoj`Go000000?oZ;o[o`000?nX_n/01?nX_n/2o`0000GoZ;o[00Co0000ojRojonX
_n_oZ;o[0ol0000@ooooo`03o`000?oooooooooo02;ooooo00?ogMgMo`000?nj^[X05?ooool005co
oooo0ol00005ooooo`03o`000?oooooooooo04;ooooo0ol00005ojRoj`06o`000?nX_n_o0000o`00
0?nX_n_o00001OnX_n/00ol0003oZ;o[o`000002o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/0
0ol0003oZ;o[o`000002o`000003ojRojol0003oZ;o[00CoZ;o[0ol00003ojRoj`03o`000?nX_n_o
Z;o[00;oZ;o[0_l00005ojRoj`04o`000?nX_n_oZ;o[ojRoj`?o00001OnX_n/01?l0003oZ;o[ojRo
jonX_n/3o`0000GoZ;o[00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[o`000002ojRoj`03
o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/01?nX_n/4o`0000;oZ;o[00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Qooooo`03oeEEEOmgMgOoA4A401Cooooo001Jooooo`;o0000
BOooool4o`0000;oZ;o[00?o0000ojRojonX_n/00onX_n/2o`0000CoZ;o[00?o0000ojRojonX_n/0
0_nX_n/2o`0000KoZ;o[00?o0000ojRojonX_n/00ol00005ojRoj`03o`000?nX_n_o000000;o0000
00?oZ;o[o`000?nX_n/01?nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;o
Z;o[1?l00002ojRoj`03o`000?nX_n_oZ;o[00?oZ;o[1?l00002ojRoj`03o`000?nX_n_oZ;o[00?o
Z;o[0_l00005ojRoj`;o000000CoZ;o[o`000?l0003o00001OnX_n/00ol0003oZ;o[o`000002o`00
0003ojRojol0003oZ;o[00CoZ;o[00?o0000ooooooooool03oooool00ol0003oooooooooo`0Ooooo
o`05omgMgOl@413oooooob4Q8OoMgMd04oooool005Oooooo0ol00019ooooo`;o00000_nX_n/00ol0
003oZ;o[ojRoj`02ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/01?nX_n/01?l0
003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00?oZ;o[0ol00003ojRoj`03o`000?nX_n_o
Z;o[00;oZ;o[0_l00005ojRoj`04o`000?nX_n_oZ;o[ojRoj`?o00001OnX_n/01_l0003oZ;o[o`00
0?l0003oZ;o[o`0000GoZ;o[00?o0000ojRojol000000_l000000onX_n_o0000ojRoj`04ojRoj`03
o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/01?nX_n/3o`0000?oZ;o[00?o0000ojRojonX
_n/00_nX_n/2o`0000GoZ;o[00?o0000ojRojonX_n/00_nX_n/2o`00013ooooo00?o0000oooooooo
ool07oooool01OmVIVKoQhN7oooooonHV9SoEEEE01?ooooo001Dooooo`?o00000oooool00ol0003o
ooooooooo`14ooooo`;o00001OnX_n/00ol0003oZ;o[ojRoj`03o`0000GoZ;o[00Co0000ojRojonX
_n_oZ;o[0ol00005ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/01?nX_n/01?l0
003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[1?l00002ojRoj`03o`000?nX_n_o
Z;o[00?oZ;o[0_l00004ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0_l00005ojRoj`04o`000?nX_n_o
Z;o[ojRoj`?o00001OnX_n/00ol0003oZ;o[o`000002o`000003ojRojol0003oZ;o[00CoZ;o[00Ko
0000ojRojol0003o0000ojRojol00005ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?oo
ool04?ooool00ol0003oooooooooo`0Mooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOoo
ool04Oooool005;ooooo0_l0001:ooooo`?o000000?oYJOHo`000?nX_n/01?nX_n/3o`0000?oXikA
00?o0000ojRojonX_n/00_nX_n/4o`0000?oYk[W00?o0000ojRojonX_n/00_nX_n/2o`0000GoZ;o[
00Co0000ojRojonX_n_oZ;o[0ol00005ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o0000ojRo
jonX_n/00_nX_n/00ol0003oZ;o[o`000002o`000003ojRojol0003oZ;o[00CoZ;o[00Co0000ojRo
jol0003o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`Co00000_nX_n/00ol0003oZ;o[ojRoj`03
ojRoj`;o00001?nX_n/2o`0000?oZ;o[0ol00004ojRoj`04o`000?nX_n_oZ;o[ojRoj`?o00001OnX
_n/00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo00Co410@o`000?l0003ooooo
0_l000000ol@413oooooooooo`0@ooooo`00:_ooool4o`000003oa0@4?oooooooooo01kooooo0ol0
0019ooooo`?o00001OnUYmP00ol0003oZ;o[o`000002o`000003oi^5^ol0003oXikA00CoXikA00Co
0000ojRojol0003o00000_nNSL800ol0003oYk[WojNji`03ojNji`04o`000?nX_n_o0000o`0000;o
Y[7P00?o0000ojRojonX_n/00_nX_n/4o`0000;oZ;o[00?o0000ojRojonX_n/00onX_n/2o`0000Go
Z;o[00?o0000ojRojonX_n/00ol00005ojRoj`04o`000?nX_n_oZ;o[ojRoj`?o00001OnX_n/01?l0
003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[00?o0000ojRojol000000_l00000
0onX_n_o0000ojRoj`04ojRoj`Co00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`Co00000_nX_n/0
0ol0003oZ;o[ojRoj`03ojRoj`;o00004?ooool00ol0003oooooooooo`0eooooo`00;?ooool00ol0
003oooooooooo`0Nooooo`?o0000B?ooool3o`0000;oXIO:00?o0000ojFWf?nUYmP00onUYmP2o`00
00GoVhFk00?o0000oj>NdOnSW]400_nSW]42o`0000GoWXg200Co0000ojNjionW^^OoYk[W0ol00005
ojJah004o`000?nX_n_o0000o`0000;oYk?Q00?o0000ojRojonX_n/00_nX_n/00ol0003oZ;o[o`00
0002o`000003ojRojol0003oZ;o[00CoZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[1?l0
0002ojRoj`03o`000?nX_n_oZ;o[00?oZ;o[0_l00005ojRoj`03o`000?nX_n_oZ;o[00?o00001OnX
_n/00ol0003oZ;o[o`000004o`0000GoZ;o[00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[
ojRoj`02ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?ooool04?ooool00ol0003ooooo
ooooo`0dooooo`008Oooool6o`0000Gooooo00?o0000ooooooooool06oooool3o`0000?ooooo00?o
0000ooooooooool0@oooool2o`000003oin@a?l0003oXIO:00?oXIO:00Oo0000ojFWf?nUYmSoYJOH
o`000?nXR[Co000000GoVhFk00?o0000oj>NdOnSW]400_l000000on`T;Go0000oij=`P05oij=`P?o
00000_nPRkd00ol0003oY[7PojJah003ojJah0;o00001OnW/n400ol0003oZ;o[ojRoj`03o`0000Go
Z;o[00?o0000ojRojol000000_l000000onX_n_o0000ojRoj`04ojRoj`04o`000?nX_n_o0000o`00
00;oZ;o[00?o0000ojRojonX_n/00_nX_n/00ol0003oZ;o[o`000002o`000003ojRojol0003oZ;o[
00CoZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0_l00003ojRoj`03o`000?nX_n_o0000
00?oZ;o[0ol00005ojRoj`03o`000?nX_n_oZ;o[00?o00001OnX_n/00ol0003oooooooooo`0=oooo
o`?o0000=Oooool002cooooo00?o0000ooooooooool06Oooool2o`0004[ooooo0_l00004oin@a003
o`000?nQUl[oXIO:00;oXIO:00?o0000ojFWf?l000000onXR[@00ol0003oVhFkoi^5^`02oi^5^`03
o`000?nSW]7o000000Co/92e00?o0000oij=`_nNSL800_nNSL82o`0000GoX8^m00?o0000ojJah?l0
00000_l000000onXTl3o0000ojNch@04ojNch@?o00000onW^nL00ol0003oZ;o[ojRoj`02ojRoj`;o
00001OnX_n/01?l0003oZ;o[ojRojonX_n/3o`0000GoZ;o[00?o0000ojRojonX_n/00ol00005ojRo
j`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/01?nX_n/01_l0003oZ;o[o`000?l0003o
Z;o[o`0000?oZ;o[00?o0000ojRojol000000ol00002ojRoj`03o`000?nX_n_oZ;o[00?oZ;o[0ol0
0002ojRoj`03o`000?nX_n_oZ;o[00?oZ;o[0_l0000@ooooo`03o`000?oooooooooo03?ooooo000/
ooooo`03o`000?oooooooooo01Kooooo0ol00019ooooo`?o000000?oWi75o`000?nOT<@00onOT<@0
0ol0003oXIO:oj6GbP02oj6GbP;o00001?nXR[@00ol0003oVhFkoi^5^`03oi^5^`03o`000?n`T;Go
/92e00?o/92e00Go0000oij=`_nNSL;oWXg2o`000002okbI/`03o`000?nPRkgoX8^m00?oX8^m00?o
0000ojRC`?nXTl000onXTl000ol0003oYk?QojNch@02o`000003ojVHa?l0003oYk_W00CoYk_W00Ko
0000ojRojol0003o0000ojRojol00005ojRoj`Co00000_nX_n/00ol0003oZ;o[ojRoj`03ojRoj`?o
00000_nX_n/00ol0003oZ;o[ojRoj`03ojRoj`;o00001OnX_n/01?l0003oZ;o[ojRojonX_n/3o`00
00CoZ;o[00?o0000ojRojol000000_l000000onX_n_o0000ojRoj`04ojRoj`03o`000?nX_n_o0000
00;o000000?oZ;o[o`000?nX_n/00onX_n/00ol0003oZ;o[o`000002o`000003ojRojol0003ooooo
013ooooo00?o0000ooooooooool0<_ooool002cooooo00?o0000ooooooooool05?ooool2o`0000;o
oooo00?o0000ooooooooool0A?ooool3o`0000GoWi7500Go0000oin@a?nOT<CoWi34o`000002oj6G
bP;o000000?oYhRdo`000?nXR[@00onXR[@00ol0003oVhFkoi^5^`03oi^5^`03o`000?n`T;Go/92e
00?o/92e00Co0000oij=`_nNSL;o00000onlVK<00ol0003oX8^moj2;_@03oj2;_@03o`000?nXTl3o
Z9?000?oZ9?000?o0000ojNchOl000001?nYV<@00ol0003oYk_WojNki`02ojNki`;o00001?nX_n/0
0ol0003oZ;o[o`000002o`000003ojRojol0003oZ;o[00CoZ;o[00?o0000ojRojol000000_l00000
0onX_n_o0000ojRoj`03ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/01?nX_n/4
o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/2o`000003ojRojol0003oZ;o[00;oZ;o[00Co0000
ojRojonX_n_oZ;o[0ol00005ojRoj`03o`000?nX_n_oZ;o[00?o00001OnX_n/00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo037ooooo000/ooooo`03o`000?oooooooooo017ooooo0ol00018
ooooo`?o00000_nQVLd00ol0003oWi75oinAa@03oinAa@03o`000?nOT<CoWi3400;oWi340_l00003
ojN8]003o`000?nXR[CoZ8Zd00?oZ8Zd00Oo0000oi^5^onKQK_oVhFko`000?ncTK?o000000Go/92e
0_l00004okbI/`03o`000?nPRkgoX8^m00;oX8^m00?o0000ol2M]Ol000001OnXTl000ol0003oZIS4
ojVHa003ojVHa003o`000?nW^nOo000000;o000000?oYI_;o`000?nX_n/00onX_n/2o`0000GoZ;o[
00Co0000ojRojonX_n_oZ;o[0ol00005ojRoj`03o`000?nX_n_oZ;o[00?o00001OnX_n/00ol0003o
Z;o[o`000002o`000003ojRojol0003oZ;o[00CoZ;o[00Co0000ojRojol0003o00000_nX_n/2o`00
00?oZ;o[1?l00002ojRoj`03o`000?nX_n_oZ;o[00?oZ;o[0ol00002ojRoj`03o`000?nX_n_oZ;o[
00?oZ;o[0_l0000@ooooo`03o`000?oooooooooo037ooooo000Zooooo`03oeEEEOmVIVKo0000013o
oooo0ol00019ooooo`;o000000?oYZgMo`000?nQVLd00onQVLd00ol0003oWi75oinAa@02oinAa@04
o`000?nOT<CoWi34oin@a0;o00001OnWR;@00ol0003oZ8ZdojR:]002ojR:]004o`000?nKQK_oVhFk
o`0000;o/i6c00?o0000ok2@]On`T;D00on`T;D00ol0003o_9VcokbI/`04okbI/`04o`000?nPRkgo
X8^mo`0000;o`9fe00?o0000ojRC`?nXTl000onXTl000ol0003oZIS4ojVHa004ojVHa003o`000?nU
Vl_oYI_;00?oYI_;00Co0000ojRojol0003o00000_nUYMH00ol0003oZ;o[ojRoj`02ojRoj`Co0000
0_nX_n/00ol0003oZ;o[ojRoj`03ojRoj`?o00000onX_n/00ol0003oZ;o[ojRoj`02ojRoj`;o0000
1OnX_n/01?l0003oZ;o[ojRojonX_n/3o`0000GoZ;o[00Ko0000ojRojol0003o0000ojRojol00005
ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/00onX_n/00ol0003oZ;o[o`000002
o`000003ojRojol0003ooooo013ooooo00?o0000ooooooooool0<?ooool003_ooooo0ol00018oooo
o`?o00001?nV[Md01Ol0003oXIW=oj6IcOnQVLgo000000GoWi750ol000000onPQ;Go0000ojN8]004
ojN8]003o`000?nXR[CoZ8Zd00;oZ8Zd00?o0000oi^5^ol000000oncTK<00ol0003o/92eok2@]@03
ok2@]@03o`000?nlVK?o_9Vc00Co_9Vc00Co0000oj2;_OnPRkgo00000oo0WKD01ol0003oZ9?0ojRC
`?nXTl3o0000olBS^?l000001OnYV<@00ol0003oYI_;ojFKb`03ojFKb`;o00001OnUYMH01?l0003o
Z;o[o`000?l00002ojNdhP03o`000?nX_n_oZ;o[00;oZ;o[00?o0000ojRojol000000_l000000onX
_n_o0000ojRoj`04ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/4
o`0000;oZ;o[00?o0000ojRojonX_n/00onX_n/2o`0000CoZ;o[00Co0000ojRojonX_n_oZ;o[0ol0
0005ojRoj`03o`000?nX_n_oZ;o[00?o00001OnX_n/00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo02oooooo000hooooo`?o00000_ooool00ol0003oooooooooo`12ooooo`Co00000_nX_n/0
0ol0003oYZgMojJ]g@02ojJ]g@03o`000?nQVLgoXIW=00;oXIW=00Co0000oinAaOnOTLGoWi750_l0
0004oj24]@03o`000?nWR;CoYhRd00;oYhRd00?o0000ojR:]?nXR[@00_nXR[@2o`0000Go/i6c00Oo
0000ok2@]On`T;Go/92eo`000?niU[?o000000Go_9Vc00?o0000oj2;_Ol000001?o0WKD01?l0003o
Z9?0ojRC`?l00002olBS^003o`000?nYV<CoZIS400;oZIS400?o0000olJX^ol000000onUVl/00ol0
003oa:g3o`000005ojFUeP;o00001OnW]>800ol0003oZ;o[ojRoj`03o`0000GoZ;o[00Co0000ojRo
jonX_n_oZ;o[0ol00005ojRoj`06o`000?nX_n_o0000o`000?nX_n_o00001OnX_n/00ol0003oZ;o[
o`000004o`0000CoZ;o[1?l00002ojRoj`03o`000?nX_n_oZ;o[00?oZ;o[0ol00002ojRoj`03o`00
0?nX_n_oZ;o[00?oZ;o[0_l0000@ooooo`03o`000?oooooooooo02oooooo000fooooo`;o0000B?oo
ool2o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/01Ol0003oYZgMojJ]gOnV[Mgo000000CoXIW=
00Ko0000oinAaOl0003o0000oiQo]_l00004oj24]@03o`000?nWR;CoYhRd00;oYhRd00?o0000ojR:
]?nXR[@00_l000000on^SK?o0000ok>A/`04ok>A/`04o`000?n`T;Go/92eo`0000;o^IJc00?o0000
okbI/onlVK<01?nlVK<00ol0003o`9feol2M]@03ol2M]@03o`000?nXTl3o000000Coa:>h00Co0000
ojVHa?nYV<Co00000_o6Z;/01?l0003oYI_;ojFKbol00003olB]``03o`000?nUYMKoYJGF00;o0000
00?o_;3>o`000?nW]>801?nW]>83o`0000?oZ;o[00?o0000ojRojonX_n/00_nX_n/4o`0000;oZ;o[
00?o0000ojRojonX_n/00onX_n/2o`0000CoZ;o[00Co0000ojRojonX_n_oZ;o[1Ol000001OnX_n_o
0000ojRojol0003oZ;o[00;o000000?oZ;o[o`000?nX_n/01?nX_n/00ol0003oZ;o[o`000002o`00
0003ojRojol0003oZ;o[00?oZ;o[00?o0000ojRojol000000_l000000onX_n_o0000ooooo`0@oooo
o`03o`000?oooooooooo02kooooo000cooooo`?o0000B?ooool2o`0000GoZ;o[00Go0000ojRojonX
_n_oZ;o[o`000004ojJ]g@03o`000?nQVLgoXIW=00?o00000onHOkH00ol0003oX8Beoj24]@02oj24
]@03o`000?nWR;CoYhRd00?oYhRd0_l00003ojj=/`03o`000?ncTK?o/i6c00?o/i6c00?o0000ok2@
]Ol000000oniU[<00ol0003o_9VcokbI/`03okbI/`;o00001_o0WKD00ol0003oa:>holBS^003olBS
^003o`000?nYV<Co000000?oaZRk00?o0000ojFKbol000001?o4[L<00ol0003oYJGFo`000004okb`
cP03o`000?nW]>;oYkCR00;o000000?o/KCKo`000?nX_n/01?nX_n/01_l0003oZ;o[o`000?l0003o
Z;o[o`0000GoZ;o[00?o0000ojRojol000000_l000000onX_n_o0000ojRoj`03ojRoj`Oo00001?nX
_n/3o`0000CoZ;o[00Co0000ojRojonX_n_oZ;o[0ol00005ojRoj`03o`000?nX_n_oZ;o[00?o0000
1OnX_n/00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02gooooo000booooo`?o0000Aooo
ool2o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/<o`0000;oT7Zg00?o0000oiQo]_nHOkH00_nH
OkH00ol0003oX8Beoj24]@02oj24]@04o`000?nWR;CoYhRdojN8]0;o00001On^SK<00ol0003o/i6c
ok>A/`03ok>A/`03o`000?niU[?o^IJc00?o^IJc00Go0000okbI/onlVK?o_9Vco`000002oknK/`03
o`000?o0WKGo`9fe00;o`9fe0_l00006olBS^003o`000?o6Z;_oaZRk00?oaZRk00?o0000olB]`oo4
[L<01?o4[L<00ol0003o_;3>okb`cP03okb`cP03o`000?nW]>;o000000Co/KCK00Co0000ojRojonX
_n_oZ;o[0ol00004ojRoj`04o`000?nX_n_oZ;o[ojRoj`?o00001OnX_n/00ol0003oZ;o[o`000004
o`0000CoZ;o[00?o0000ojRojol000001?l00004ojRoj`Co00000_nX_n/00ol0003oZ;o[ojRoj`03
ojRoj`?o00000onX_n/00ol0003oZ;o[ojRoj`02ojRoj`;o00003oooool2o`0002oooooo000boooo
o`Co0000@oooool3o`0000GoZ;o[00Ko0000ojRojol0003o0000ojFXfOl00003ohj2`@05o`000?n6
MKWoQWFiohIe^Ol000001?n@N[L00ol0003oV7nfoiQo]P02oiQo]P03o`000?nPQ;GoX8Be00;oX8Be
00Ko0000ojN8]?nWR;Co0000ojR9/ol00005ojj=/`03o`000?ncTK?o/i6c00;o/i6c0_l00005okVF
/`04o`000?nlVK?o_9Vco`0000?o_i^c00Go0000ol2M]Oo0WKGo`9feo`000002olBQ]@03o`000?o4
XkSoa:>h00;oa:>h0_l00005olJX^`03o`000?o4[L?oa:g300Coa:g300?o0000okb`c_nl/<h01?nl
/<h00ol0003o/KCKok6df`03ok6df`Co00000_nW^NH00ol0003oZ;o[ojRoj`02ojRoj`Co00000onX
_n/01?l0003oZ;o[ojRojonX_n/5o`0000;oZ;o[00Co0000ojRojonX_n_oZ;o[0ol00004ojRoj`;o
000000?oZ;o[o`000?l000000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`03o`000?nX_n_o000000;o
000000?oZ;o[o`000?nX_n/01?nX_n/01_l0003oZ;o[o`000?l0003oZ;o[o`00017ooooo00?o0000
ooooooooool0;?ooool003;ooooo00Co0000oooooooooooo0000?oooool4o`0000;oZ;o[00?o0000
ojRojonX_n/00onX_n/2o`0000?oYJSI00?o0000ohj2`On>P/400_n>P/401Ol0003oQWFiohIe^On6
MKWo000000CoT7Zg00Go0000oiQo]_nHOkKoV7nfo`000004oj24]@03o`000?nWR;Co000000?oZ8Vc
00?o0000ojj=/on^SK<00_n^SK<01ol0003o/i6cok>A/oncTK?o0000okJB/_l000001OniU[<00ol0
003o_9Vco`000004oknK/`04o`000?o0WKGo`9feo`0000?oa:6e00Go0000olBS^?o4XkSoa:>ho`00
0002olRW^007o`000?o6Z;_oaZRkolJX^ol0003obZfmo`000004olB]``03o`000?o;]<Co000000Co
_;3>00?o0000olRkc_l000000ona]=/00ol0003o`L;Ko`000005ojNiiP04o`000?nX_n_o0000o`00
00;oZ<7/00?o0000ojRojonX_n/00_nX_n/7o`0000CoZ;o[1?l00002ojRoj`03o`000?nX_n_oZ;o[
00;oZ;o[0ol00005ojRoj`03o`000?nX_n_oZ;o[00?o00001OnX_n/01?l0003oZ;o[ojRojonX_n/3
o`0000CoZ;o[00?o0000ooooooooool03_ooool00ol0003oooooooooo`0/ooooo`00<_ooool01Ol0
003ooooooooooooooooo000003cooooo0_l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[00?o0000
ojRojol000000_l000000onX_n_o0000ojFXf@03ojFXf@05o`000?n>P/7oSX;1ohj2`Ol000000on6
MKT00ol0003oT7Zgoi1j]`02oi1j]`05o`000?nHOkKoV7nfoiQo]_l000001?nPQ;D2o`0000CoZ8Vc
00?o0000ojj=/on^SK<00_n^SK<01?l0003o/i6cok>A/ol00003okJB/P03o`000?niU[?o^IJc00?o
^IJc00?o0000oknK/onoVk<01?noVk<2o`0000Coa:6e00Co0000olBS^?o4XkSo00000oo8YkP01?l0
003oaZRkolJX^ol00003olZ]_@04o`000?o4[L?oa:g3o`0000?obkC400Co0000okb`c_nl/<ko0000
0oo8^lh00ol0003o/KCKo`000003ol72f`03o`000?nW^NKoYkWV00;oYkWV0_l00005ojS1k003o`00
0?nX_n_o000000Co00001?nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;o
Z;o[00?o0000ojRojol000001?l00005ojRoj`?o00000_nX_n/00ol0003oZ;o[ojRoj`03ojRoj`Co
00000onX_n/00ol0003oZ;o[ojRoj`03o`00013ooooo00?o0000ooooooooool0:oooool000Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`Go00001Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo03Kooooo0ol00005ojRoj`03o`000?nX_n_oZ;o[00Co00001?nX_n/0
1Ol0003oYJSIojFXfOnUZ=Wo000000?oSX;100Go0000ohIe^On6MKWoQWFio`000004oi1j]`05o`00
0?nHOkKoV7nfoiQo]_l000000_nPQ;D2o`000003oj64]?l0003oZ8Vc00?oZ8Vc00?o0000ojj=/on^
SK<00on^SK<2o`0000Co]Y:b00?o0000okVF/oniU[<00_niU[<2o`0000Ko_i^c00?o0000olBQ]Oo4
XKD01?o4XKD2o`0000Cob:Nh00?o0000olJX^ol000001?o:[Kd00ol0003oa:g3o`000004ol^da003
o`000?nl/<ko000000Cob;_>0_l00004ol72f`03o`000?nW^NKo000000;o000000?o[lK[o`000?nX
`N`01?nX`N`4o`0000;oZ;o[00Co0000ojRojonX_n_oZ;o[0ol00005ojRoj`03o`000?nX_n_oZ;o[
00?o00001?nX_n/2o`000006ojRojol0003o0000o`000?nX_n_o00001?nX_n/00ol0003oZ;o[o`00
0002o`000003ojRojol0003oZ;o[00CoZ;o[0ol00002ojRoj`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0:_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
03;ooooo0ol00003ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0ol00004ojRoj`05o`000?nX_n_oZ;o[
ojRojol000000onUZ=T00ol0003oSX;1ohj2`@02ohj2`@05o`000?n6MKWoQWFiohIe^Ol000000on@
N[L00ol0003oV7nfoiQo]P02oiQo]P;o00000onQQ;@00ol0003oZ8VcojR9/`03ojR9/`03o`000?n^
SK?o[Xfc00;o[Xfc00?o0000okJB/_nfT[800onfT[801ol0003o^IJcokVF/oniU[?o0000okbH/ol0
00001_noVk<00ol0003oa:6eolBQ]@04olBQ]@03o`000?o8YkSob:Nh00Cob:Nh00?o0000olZ]_Oo:
[Kd01?o:[Kd00ol0003obkC4ol^da003ol^da0;o00001?o8^lh00ol0003ocLCBo`000004ol72f`?o
00001?n_a^/00ol0003oZ<7/o`000004o`0000CoZ;o[1?l00002ojRoj`03o`000?nX_n_oZ;o[00?o
Z;o[0ol00003ojRoj`04o`000?nX_n_oZ;o[ojRoj`?o00001OnX_n/00ol0003oZ;o[ojRoj`03o`00
00GoZ;o[00?o0000ojRojol000000_l000000onX_n_o0000ojRoj`03ojRoj`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0:_ooool000Go00000_ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001?oo
ool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;ooo
ool2o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`00
0?nX_n_oZ;o[00;oZ;o[2?l000000onUZ=Wo0000ohj2`@02ohj2`@05o`000?n6MKWoQWFiohIe^Ol0
00001?n@N[L00ol0003oV7nfo`000002o`0000GoXHBd00?o0000ojR9/onXRK<00_nXRK<01?l0003o
[Xfcojj=/on^SK<2o`0000Go]Y:b00Co0000okVF/oniU[?o00000onlV;<00ol0003o_i^coknK/`02
oknK/`;o00001_o4XKD00ol0003ob:NholRW^004olRW^003o`000?o:[KgobZfm00?obZfm0_l00004
ol^da003o`000?o@_<Ko000000?ob;_>00Go0000olg4d_o=a=;ocLCBo`000002ol72f`05o`000?o3
c>7o`lcQol?<hOl000000_n_a^/4o`0000CoYL_d00Co0000ojRojol0003o00000_nWc?<00ol0003o
Z;o[ojRoj`02ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/00onX_n/4o`000003
ojRojol0003o000000GoZ;o[0ol00002ojRoj`03o`000?nX_n_oZ;o[00?oZ;o[0_l00005ojRoj`03
o`000?nX_n_oZ;o[00?o00004?ooool00ol0003oooooooooo`0Yooooo`001oooool01Ol0003ooooo
oooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000001Oooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0;?ooool2o`0000GoZ;o[00?o0000ojRojonX_n/00ol00005ojRoj`06o`000?nX_n_o
0000o`000?nX_n_o00000on8R<d00ol0003oKfZlofmZ_006o`0000?oQWFi00?o0000oi1j]on@N[L0
1?l00002oiQo]P03o`000?nQQ;CoXHBd00?oXHBd00?o0000ojR9/onXRK<00_nXRK<01?l0003o[Xfc
ojj=/ol00002ok2?/`03o`000?nfT[;o]Y:b00?o]Y:b0_l00004okbH/`05o`000?noVk?o_i^coknK
/ol000000_o3Wk@00ol0003oa:6eolBQ]@02olBQ]@03o`000?o8YKKo000000Cob:Nh00?o0000olb/
^Ol000000oo:[Kd01?l0003ockBnolnd__l00002ol^da007o`000?o@_<Kod;c6om2la_l0003ob;_>
o`000004olg4dP03o`000?o1`]_o000000Co`lcQ1Ol000000on]d??o0000ojG;m002ojG;m0?o0000
1OnWc?<00ol0003oZ;o[ojRoj`03o`0000GoZ;o[00Ko0000ojRojol0003o0000ojRojol00004ojRo
j`;o000000KoZ;o[o`000?l0003o0000ojRojol00004ojRoj`03o`000?nX_n_o000000;o000000?o
Z;o[o`000?nX_n/01?nX_n/3o`0000;oZ;o[00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Xooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000001_ooool00omgMgOoIVIVooooo`04ooooo`;o
00002?ooool00ol0003oooooooooo`0Yooooo`;o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`?o
00000onX_n/00ol0003oZ;o[ojRoj`02ojRoj`;o00001?nX_n/01Ol0003oR8S=ohR8cOn8R<go0000
00;oKfZl00Co0000ogU^^_miK[[oNFjj1ol00002ohii]`03o`000?nHOkKoV7nf00;oV7nf00?o0000
oj64]?nQQ;@00_nQQ;@00ol0003oZ8VcojR9/`03ojR9/`;o00000on`Sk<00ol0003o]Y:bokJB/P03
okJB/P03o`000?nlV;?o_9Rc00?o_9Rc00Co0000oknK/onoVk?o00000oo3Wk@01Ol0003oa:6eolBQ
]Oo4XKGo000000;ob:Ff00Go0000olRW^?o8YkSob:Nho`000002olb/^@04o`000?o:[KgobZfmo`00
00?ockBn00?o0000ol^da?l000001Oo@_<H00ol0003ocLCBolg4dP03olg4dP;o00000oo3c>44o`00
00Co[M3c1?l00003ohg=o@04o`000?nWc??oYlccojO<l`Co00000_nX_n/00ol0003oZ;o[ojRoj`03
ojRoj`;o00001?nX_n/01?l0003oZ;o[ojRojonX_n/3o`0000GoZ;o[00?o0000ojRojonX_n/00ol0
0005ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/00onX_n/00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo02Sooooo0007ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4007ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Uooooo`Co
00001?nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[00Co0000ojRo
jol0003o00000_nX_n/01Ol0003oZ;o[ojRojonX_n_o000000?oR8S=00Go0000ofmZ_?m_J[coKfZl
o`000003ogU^^P05o`000?n4LkWoQ7>iohAc^Ol000001?n>NKL01Ol0003oV7nfoiQo]_nHOkKo0000
00CoXHBd00?o0000ojR9/onXRK<00_nXRK<2o`0000Co/8nc00?o0000okJB/_nfT[800onfT[800ol0
003o_9RcokbH/`04okbH/`;o00001?o3Wk@01?l0003oa:6eolBQ]Ol00003olRU]P04o`000?o8YkSo
b:Nho`0000?oc:bi00?o0000olZ]_Ol000001Oo?];h00ol0003od;c6om2laP04om2laP03o`000?o=
a=;ocLCB00;ocLCB00?o0000om;?e_oBcmH01?l00003olGHj004o`000?n]d??o0000o`0000?oY][j
00?o0000ohg=oOn=cOd01Ol00002oh_Co`03o`000?nX_n_oZ;o[00;oZ;o[00?o0000ojRojol00000
0_l000000onX_n_o0000ojRoj`03ojRoj`Co000000?oZ;o[o`000?l000001OnX_n/3o`0000?oZ;o[
00Co0000ojRojonX_n_oZ;o[0ol00005ojRoj`03o`000?nX_n_oZ;o[00?o00004?ooool00ol0003o
ooooooooo`0Wooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Ol0003o^[ZjoooooonH
V9So410@00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`?o00001?nX
_n/00ol0003oZ;o[ojRoj`03o`0000GoZ;o[00?o0000ojRojonX_n/01?l00004ojRoj`05o`000?nX
_n_oZ;o[ojRojol000000_n8R<d01Ol0003oKfZlofmZ_?m_J[co000000?oNFjj00Go0000ohAc^On4
LkWoQ7>io`000004ohii]`05o`000?nHOkKoV7nfoiQo]_l000001?nQQ;@00ol0003oZ8VcojR9/`02
o`000003ojZ:]?l0003o/8nc00Co/8nc00Oo0000okJB/_nfT[;o]Y:bo`000?nhUK?o000000Go_9Rc
00?o0000ol>O]?o3Wk@01?o3Wk@2o`0000Gob:Ff0_l00005olb/^@03o`000?o?];kockBn00CockBn
00?o0000om2la_o@_<H00oo@_<H00ol0003oe/G9o`000002olg4dP03o`000?oBcmKo000000?o0000
1Oo5f>P3o`0000?oY][j1?l00003of[8oP03o`000?n;doooRm?o00;oRm?o00?o0000ojRojonX_n/0
0ol00005ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00Co0000ojRojonX_n_oZ;o[0_l000001_nX
_n_o0000o`000?l0003oZ;o[o`0000CoZ;o[1?l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[1?l0
0003ojRoj`03o`000?oooooooooo00gooooo0_l0000Xooooo`001oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Mooooo`?o000000?oZ;o[o`000?nX_n/01?nX_n/3o`0000?oZ;o[00?o0000ojRo
jonX_n/00_nX_n/3o`0000CoZ;o[00?o0000ojRojonX_n/01_l00003ohR8c@04o`000?m_J[coKfZl
o`0000CoNFjj00Go0000ohAc^On4LkWoQ7>io`000003ohii]`03o`000?nHOkKoV7nf00;oV7nf00?o
0000oj64]?nQQ;@00_nQQ;@2o`0000?oZXZd00?o0000ok2?/on`Sk<00on`Sk<01?l0003o]Y:bokJB
/_l00002okRE/`03o`000?nlV;?o_9Rc00?o_9Rc00?o0000ol>O]?o3Wk@01?o3Wk@00ol0003ob:Ff
olRU]P04olRU]P03o`000?o<[;Woc:bi00Coc:bi00?o0000olnd__o?];h00oo?];h00ol0003oeK_1
o`000003om2laP05o`000?oFaLWoe/G9o`000?o=a=800ol00002om;?eP04o`000?oFf]_o0000olGH
j0?o00000_o5hnh4o`0000;oVn7m3Ol00003oj?HnP04o`000?nX_n_oZ;o[ojRoj`?o00001OnX_n/0
0ol0003oZ;o[ojRoj`03o`0000GoZ;o[00Ko0000ojRojol0003o0000ojRojol00005ojRoj`06o`00
0?nX_n_o0000o`000?nX_n_o00001OnX_n/2o`0000oooooo00?o0000ooooooooool09_ooool0033o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Iooooo`Co00001?nX_n/00ol0003o
Z;o[o`000002o`000003ojRojol0003oZ;o[00CoZ;o[00Ko0000ojRojol0003o0000ojRojol00005
ojRoj`?o00000_nX_n/00ol0003oIVk7ofI^a`03o`000003ohR8cOl0003oKfZl00;oKfZl00Go0000
ogU^^_miK[[oNFjjo`000003ohAc^@03o`000?n>NKOoSWVg00;oSWVg00Go0000oiQo]_nHOkKoV7nf
o`000003oj64]0;o00001OnZR[@00ol0003o/8ncok2?/`02ok2?/`03o`000?nfT[;o000000?o^9Fc
00?o0000okbH/onlV;<00_nlV;<00ol0003o`9bco`000005ol>O]003o`000?o8YKKob:Ff00Cob:Ff
00?o0000olb/^Oo<[;T00oo<[;T00ol0003odK>ko`000003olnd_P07o`000?oE^l7oeK_1omFk`Ol0
003od;c6o`000002omK5b@Co00000ooBcmH01?l0003oe][KomKJfooFf]/2o`0000?oaN?^00?o0000
ol7^lOo1k_401?l00002ohWSn`_o00000_nSf?X5o`0000;oZ;o[00?o0000ojRojonX_n/00onX_n/3
o`0000;oZ;o[0_l00003ojRoj`?o00001?nX_n/01?l0003oZ;o[ojRojonX_n/3o`0000CoZ;o[00?o
0000ojRojol000000_l000000onX_n_o0000ooooo`0?ooooo`03o`000?oooooooooo02Gooooo000`
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05Oooool3o`0000CoZ;o[00?o0000
ojRojonX_n/00ol00005ojRoj`04o`000?nX_n_oZ;o[ojRoj`?o00001?nX_n/00ol0003oZ;o[o`00
0002o`000003ojRojol0003oZ;o[00?oZ;o[00Go0000ofI^aomVK/Oo0000of1S_P02o`0000?oKfZl
00Go0000ogU^^_miK[[oNFjjo`000003ohAc^@03o`000?n>NKOoSWVg00;oSWVg00Ko0000oiQo]_nH
OkKoV7nfo`000?nQQ;@2o`000003oj:5]Ol0003oZXZd00CoZXZd00?o0000ok2?/on`Sk<00_n`Sk<2
o`0000Go^9Fc00Co0000okbH/onlV;?o00000_o0W;<00ol0003o`indol>O]002ol>O]003o`000?o7
XkGo000000Cob:Ff00?o0000olf[]ol000001?o<[;T01?l0003odK>kom6c^ol00002olnd_P03o`00
0?oE^l7oeK_100;oeK_11?l00002omK5b@05o`000?oKc/go0000om;?e_l000000ooFf]/01_l0003o
f>GOomSUgol0003oaN?^o`0000;o`Nka00?o0000okWdl_nim?801?l00002og?NlP_o00000omObOX0
0ol0003oZ;o[ojRoj`02ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/00_nX_n/5
o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/4o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/2
o`0000GoZ;o[00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Tooooo`00<?ooool00ol0
003oooooooooo`0>ooooo`;o00004oooool2o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/3o`00
00?oZ;o[00?o0000ojRojonX_n/00_nX_n/4o`0000?oZ;o[00?o0000ojRojonX_n/00ol00005ojRo
j`05o`000?nX_n_oZ;o[ojRojol000000_mVK/L01?l0003oH6>nof1S__mPHkh4o`0000?oNFjj00Go
0000ohAc^On4LkWoQ7>io`000004ohii]`04o`000?nHOkKoV7nfoiQo]P;o00001?nRQKD00ol0003o
ZXZdojZ:]002ojZ:]007o`000?n`Sk?o/8ncok2?/ol0003o/i6co`000005okRE/`04o`000?nlV;?o
_9Rco`0000?o`9bc00Co0000ol>O]?o3WkCo00000_o7XkD01Ol0003ob:FfolRU]_o8YKKo000000;o
cJ^g00Go0000olb/^Oo<[;Woc:bio`000003om6c^`03o`000?o?];ko000000CoeK_10_l00004omK5
b@05o`000?oKc/goflk=om_>cOl000000ooFf]/01?l0003of>GOomSUgooHiMl3o`000005ol7^lOl0
003o^OCbokWdl_l000000_n/mnhDo`0000;oZ;o[0ol00005ojRoj`03o`000?nX_n_o000000?o0000
1OnX_n/01_l0003oZ;o[o`000?l0003oZ;o[o`0000GoZ;o[00Ko0000ojRojol0003o0000ojRojol0
0005ojRoj`;o00003oooool00ol0003oooooooooo`0Tooooo`00<?ooool2o`00017ooooo00?o0000
ooooooooool03Oooool4o`0000CoZ;o[00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRo
j`02ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/3o`0000?oZ;o[
00?o0000ojRojonX_n/00_nX_n/3o`000003ojRojol0003oIVk700;oIVk700Co0000of1S__mPHkko
00000_mYI[`4o`000003ogU^^_l0003oQ7>i00;oQ7>i00?o0000ohii]on>NKL00_n>NKL3o`000003
oiQo]_l0003oXXFe00?oXXFe00?o0000ojZ:]?nZR[@00_nZR[@01?l0003o/8ncok2?/ol00002ok>A
/`03o`000?nhUK?o^9Fc00?o^9Fc00?o0000okbH/ol000001?o0W;<01?l0003o`indol>O]?l00003
olNS]@04o`000?o8YKKob:Ffo`0000?ocJ^g00?o0000olb/^Ol000001OoA/k/00ol0003oeK_1omFk
`@04o`000005om[4`ol0003oe/G9omK5bOl000000ooKc/d01Ol0003ogmW@o`000?oFf]_o000000?o
f>GO00Co0000omS`h_oHl>;of?3R0_l000000onim?;o0000ojcgkP0<o`000003oh;Wkol0003o0000
00Wo00000_nPgO`00ol0003oZ;o[ojRoj`03ojRoj`;o00000onX_n/2o`0000?oZ;o[0ol00004ojRo
j`04o`000?nX_n_oZ;o[ojRoj`?o00001?nX_n/00ol0003oZ;o[o`000002o`000003ojRojol0003o
oooo00oooooo00?o0000ooooooooool08oooool0033ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`09ooooo`?o00001?nX_n/00ol0003oZ;o[ojRoj`03o`0000GoZ;o[00?o0000ojRo
jonX_n/01?l00004ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/0
1ol0003oZ;o[o`000?l0003oZ;o[o`000?mAH/D00ol00002ofI^a`04o`000?mPHkkoH6>no`0000?o
JFJl00?o0000ogE/^omeK;/02ol00003oiQo]P03o`000?nRQKGoXXFe00;oXXFe00?o0000ojZ:]?nZ
R[@00onZR[@2o`0000Co/i6c00?o0000okRE/onhUK<00onhUK<00ol0003o`9bcol2L/`03ol2L/`03
o`000?o3WkCo000000Coaj>e00?o0000olRU]_l000001?o=ZkL00ol0003oc:bio`000005om6c^`?o
00000_oE^l401_l0003of/C3om[4`ol0003oe/G9o`0000?oflk=00Go0000omoId?oOfM3ogmW@o`00
0003omSUg`06o`000?oHl>;of?3RomS`h_l0003oeOSR4Ol00002oh_Un@Go000000CoGlClo`000?l0
003o00000onPgO`00ol0003oZ;o[o`000002o`000003ojRojol0003oZ;o[00?oZ;o[1?l00002ojRo
j`03o`000?nX_n_oZ;o[00;oZ;o[1?l00003ojRoj`03o`000?nX_n_oZ;o[00?o00001OnX_n/00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo02;ooooo000_ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool01_ooool2o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/3o`0000?o
Z;o[00?o0000ojRojonX_n/00_nX_n/3o`0000CoZ;o[00?o0000ojRojonX_n/00ol00005ojRoj`03
o`000?nX_n_oZ;o[00?o00001?nX_n/00ol0003oDF;5oe5Ra@02o`000003ofI^aol0003oH6>n00;o
H6>n00Co0000ofUV_?mYI[co00000omeK;/01Ol0003oPG:ioh5b^On1L[Wo000000CoSGVh00?o0000
oiQo]_nHOkH00_nHOkH00ol0003oXXFeoj:5]@02oj:5]@04o`000?nZR[CoZXZdojZ:]0;o00001Onc
TK<00ol0003o^9FcokRE/`02okRE/`;o00001_o0W;<00ol0003oaj>eolNS]@04olNS]@03o`000?o=
ZkOocJ^g00CocJ^g00Co0000om6c^ooA/k_odK>k0ol000001OoG^[go0000omFk`OoE^l7o000000Co
f/C300Go0000om_>cOoKc/goflk=o`000004omoId0;o000000?of>GOo`000?oHl>800_oHl>800ol0
003oeOSRo`000002olkmh@;o000000Go^_gIo`000?nanmOo0000ojcif@03o`000004ojgij?l0003o
/OKaok7fl@?o00000_nCgoh<o`0000GoZ;o[00?o0000ojRojol000000ol00005ojRoj`06o`000?nX
_n_o0000o`000?nX_n_o00001OnX_n/3o`0000;oZ;o[00?o0000ojRojonX_n/00onX_n/2o`0000oo
oooo00?o0000ooooooooool08_ooool002oooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`02ooooo`Co00001?nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;o
Z;o[00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`?o00000onX_n/00ol0
003oZ;o[ojRoj`02ojRoj`?o00000onX_n/01Ol0003oZ;o[ojRojonX_n_o000000;oDF;500?o0000
odmL`Ol000000_l00002of1S_P05o`000?mYI[coJFJlofUV_?l000000_meK;/00ol0003oPG:ioh5b
^@02oh5b^@05o`000?n=NKSoSGVhohei^?l000001?nHOkH00ol0003oXXFeoj:5]@02oj:5]@06o`00
0?nZR[CoZXZdo`000?n/SKCo00001OncTK<01ol0003o^9FcokRE/onhUK?o0000okbI]?l000001_o0
W;<00ol0003oaj>eolNS]@04olNS]@03o`000?o=ZkOocJ^g00CocJ^g1?l000001ooA/k_o0000omNj
_OoG^[go0000omFk`Ol000001OoJa<<2o`000003om_>cOl0003ogmW@00?ogmW@00?o0000on?TdooS
i=<00ol000001?oHl>;o0000omGhh_l00002olkmh@;o000000Go^_gIo`000?nanmOo0000ojcif@03
o`000003ojgij?l0003o/OKa00;o00000_nek_H3o`0000;oV]Cl2ol00003ojRoj`?o00000onX_n/2
o`0000?oZ;o[0ol00004ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/00onX_n/0
0ol0003oZ;o[o`000002o`000003ojRojol0003ooooo00oooooo00?o0000ooooooooool08Oooool0
02oooooo00?o0000ooooooooool05Oooool4o`0000CoZ;o[00?o0000ojRojonX_n/00ol00005ojRo
j`03o`000?nX_n_oZ;o[00Co00001?nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_o
Z;o[00;oZ;o[00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`05o`000?nX
_n_oZ;o[ojRojol000000_mAH/D00ol0003oCec1odmL`@02o`000003of1S__l0003oJFJl00;oJFJl
00Go0000ogE/^omeK;_oMFbko`000003oh5b^@03o`000?n=NKSoSGVh00;oSGVh00Go0000oiQo]_nH
OkKoV7nfo`000004oj:5]@03o`000?nZR[Co000000?o[8fd00?o0000ok>A/oncTK<00_ncTK<01?l0
003o^9FcokRE/ol00003okbI]003o`000?o0W;?o`9bc00;o`9bc00?o0000olBQ]?l000001?o7XkD0
0ol0003oc:Vfo`000003olf[]`Co00000_oA/k/00ol0003oekZmomNj_@02omNj_@03o`000?oJa<?o
f/C300?of/C300?o0000on3=a_oPcLH00_l00003omoId005o`000?oSi=?ohnCCon?Tdol000000_oU
k]@4o`000003olkmhOl0003o000000Oo000000?oaOkKo`000?l000000ol000000onek_Ko0000o`00
0002okKQm@?o00000onMaoD01Ol0003oO;Khogbfn?ml]_So000000;oD9kd1?l00002oj;Jn`03o`00
0?nX_n_oZ;o[00;oZ;o[1?l00003ojRoj`03o`000?nX_n_oZ;o[00?o00001OnX_n/00ol0003oZ;o[
ojRoj`03o`0000GoZ;o[00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Pooooo`00;ooo
ool00ol0003oooooooooo`0Dooooo`;o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`?o00000onX
_n/00ol0003oZ;o[ojRoj`02ojRoj`?o00001?nX_n/00ol0003oZ;o[ojRoj`03o`0000GoZ;o[00?o
0000ojRojonX_n/01?l00004ojRoj`03o`000?nX_n_oZ;o[00Ko00000_mAH/D01Ol0003oCec1odmL
`Ol0003oEUjo00?o00000_mYI[`01Ol0003oMFbkogE/^omeK;_o000000?oPG:i00?o0000ohei^?n=
NKP00_n=NKP01Ol0003oV7nfoiQo]_nHOkKo000000CoXXFe0_l00004ojb=]003o`000?ncTK?o/i6c
00?o/i6c0_l00004okbI]005o`000?o0W;?o`9bcol2L/ol000000_o4XK@01Ol0003oaj>eolNS]Oo7
XkGo000000;oc:Vf1Ol00002om:a^@03o`000?oA/k_o000000GoekZm0_l00003om[4``09o`000?oP
cLKoh<g6on3=a_l0003oiMS8o`000?oOfM3o000000?ohnCC00Ko0000onG^e?oUk]Co0000onCge?l0
0002on3ldP05o`000?oIoloo0000o`000?o:ol/00_l000001_o3o]?o0000olGnfol0003oaocUo`00
00;obOK/0ol000000onfhOGo0000o`000002okCBl003o`000?nMaoGoWLOe00_o00001?nRf_/00ol0
003oZ;o[o`000003o`0000GoZ;o[0ol00002ojRoj`03o`000?nX_n_oZ;o[00?oZ;o[0ol00003ojRo
j`04o`000?nX_n_oZ;o[ojRoj`?o00003_ooool2o`0002;ooooo000_ooooo`03o`000?oooooooooo
017ooooo1?l00004ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/0
1?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0ol00003ojRoj`03o`000?nX
_n_oZ;o[00;oZ;o[0ol00004ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oC6G<odaU
c003o`000005oe5RaOl0003oCec1odmL`Ol000000_mFG[l2o`000003ofUV_?l0003oMFbk00;oMFbk
00?o0000oh5b^On1L[T00_n1L[T01Ol0003oSGVhohei^?n=NKSo000000?oV7nf00?o0000oj:5]OnR
QKD00_l000000onSQkKo0000ojb=]003ojb=]003o`000?ncTK?o/i6c00?o/i6c00?o0000okbI]?nl
VK@00onlVK@01?l0003o`9bcol2L/ol00003olBQ]005o`000?o7XkGoaj>eo`000?o<ZKH00ol00002
olf[]`03o`000?oB/KWod[6i00;od[6i00?o0000omNj_OoG^[d00ooG^[d01_l0003ogL>oomg3_ol0
003of/C3o`0000?oh<g600Go0000onGHb?oUf<SoiMS8o`000003on?Td`06o`000?oUk]CoiNkDo`00
0?oTmmCo00000_oPo=801Ol0003ofOo?o`000?l0003ob_o;00;o000000Ko`okCo`000?o5o]_o0000
olOliOl00002olWfk003o`000?o8jNgob>W]00;o00001?ndd_03o`0000;oW[W[00Go0000ohF/k_n5
[>koQJc^o`000003ofBKk`Oo00000onX_n/2o`000006ojRojol0003o0000o`000?nX_n_o00001?nX
_n/00ol0003oZ;o[o`000002o`000003ojRojol0003oZ;o[00?oZ;o[1?l00002ojRoj`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool07oooool002oooooo0_l0000?ooooo`?o00001?nX_n/0
0ol0003oZ;o[ojRoj`03o`0000GoZ;o[00?o0000ojRojonX_n/01?l00004ojRoj`04o`000?nX_n_o
0000o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`00
0?nX_n_oZ;o[00;oZ;o[0ol00003ojRoj`05o`000?nX_n_oZ;o[ojRojol000000_m<IL`01?l0003o
@EW4o`000?l00002odmL`@05o`000?mFG[ooEUjoo`000?mRHkd00ol00002ogE/^`03o`000?n1L[Wo
PG:i00;oPG:i00Go0000ohei^?n=NKSoSGVho`000004oiQo]P;o00000onSQkH00ol0003o[8fdojb=
]003ojb=]004o`000?ncTK?o/i6cok>A/`;o00001_nlVK@2o`0000Goa:6d1?l00003olbY]P;o0000
1OoB/KT00ol0003oekZmomNj_@02omNj_@03o`000?oM`koogL>o00;ogL>o00Go0000on3=a_oPcLKo
h<g6o`000004onGHb0;o000000OohnCCo`000?oUk]CoiNkDo`000?oTmmCo000000;oh?cB00Go0000
omWocol0003o0000ol[ob`09o`000005olWfk?l0003ob>W]olSYkOl000000_o4f^X01_l0003o]=;`
o`000?l0003o/<;Wo`0000CoW[W[00Go0000ohF/k_n5[>koQJc^o`000003ofBKk`03o`000?lkQNWo
000000Co00000_nX_n/3o`0000GoZ;o[00?o0000ojRojonX_n/00ol00005ojRoj`06o`000?nX_n_o
0000o`000?nX_n_o00001OnX_n/00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01kooooo
000^ooooo`03o`000?oooooooooo00gooooo0_l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0ol0
0003ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0ol00004ojRoj`03o`000?nX_n_oZ;o[00?o00001OnX
_n/00ol0003oZ;o[ojRoj`04o`0000CoZ;o[00Ko0000ojRojol0003o0000ojRojol00005ojRoj`04
o`000?nX_n_oZ;o[o`0000?oC6G<00?o0000od5Ia?l000000om?G<401?l0003oEUjooeIN_ol00002
of9S_@?o000000?oMFbko`000?n1L[T00_n1L[T00ol0003oSGVhohei^002ohei^003o`000?nHOkKo
000000;o00001OnSQkH00ol0003o[8fdojb=]002ojb=]004o`000?ncTK?o/i6co`0000;o]YFe00?o
0000okbI]?nlVK@00onlVK@00ol0003oa:6dolBQ]003olBQ]0;o00001_o<ZKH00ol0003od[6iom:a
^@03om:a^@03o`000?oH^K_o000000?oekZm00?o0000omg3_ooM`kl00_oM`kl01Ol0003oh<g6on3=
a_oPcLKo000000?oiMS800?o0000onWRb_oYh/X00_l000001?oUk]Co0000onCge?l00002on3ldP03
o`000?oIoloo000000?o000000Cod?k1o`000?l0003od?o?0_l00002omCjhP?o000000?ob>W]o`00
0?o4f^X00_o4f^X2o`0000Co/<;W00?o0000oijijonN^N/02Ol000001?mTVnoo0000oc^5jOlkQNT5
o`0000;oY/oe00?o0000ojRojonX_n/00onX_n/3o`0000?oZ;o[00Co0000ojRojonX_n_oZ;o[0ol0
0004ojRoj`04o`000?nX_n_oZ;o[ojRoj`?o00003oooool00ol0003oooooooooo`07ooooo`Co0000
00?o410@ooooooooool04?ooool002kooooo00?o0000ooooooooool02_ooool4o`0000CoZ;o[00Co
0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`04o`000?nX_n_o0000o`0000;o
Z;o[00?o0000ojRojonX_n/00_nX_n/3o`0000?oZ;o[00?o0000ojRojonX_n/00_nX_n/3o`0000Co
Z;o[00?o0000ojRojonX_n/00ol00004ojRoj`04o`000?nX_n_oZ;o[ojRoj`Go00000om<IL`00ol0
003o@EW4od5Ia002o`000005odmL`Ol0003oEUjooeIN_ol000000_mRHkd00ol0003oL6Zlog1Z_00<
o`0000;oVH6h00?o0000oj>7]_nSQkH00onSQkH00ol0003o[8fdojb=]002ojb=]003o`000?ncTK?o
000000?o]YFe00?o0000okbI]?nlVK@00onlVK@00ol0003oa:6dolBQ]003o`000003olBQ]?l0003o
c:Vf00Goc:Vf00?o0000om:a^OoB/KT00ooB/KT01_l0003of;VkomRi^ol0003oekZmo`0000CogL>o
00Go0000on?<`Ol0003oh<g6o`000003onGHb006o`000?oYh/[ojN;:onWRb_l0003ok>c;2?l00000
1?oLo/7o0000o`000?o@o/42o`000003om3ocol0003o000000;oe?[R00?o0000om?_i_oCknH00ol0
00000oo4f^[o0000o`000002okk:i003o`000?n``^Oo/<;W00Co00000_nN[>401Ol0003oRj;Toh^R
i?n;X^Co000000;oLYKV2Ol00002ojK?m@;o000000KoZ;o[o`000?l0003o0000ojRojol00004ojRo
j`Co00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`Co00000_nX_n/00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool002kooooo00?o0000oooooooo
ool01oooool3o`0000CoZ;o[00?o0000ojRojonX_n/00ol00005ojRoj`03o`000?nX_n_oZ;o[00Co
00001?nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[00Co0000ojRo
jol0003o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`?o00000_nX_n/00ol0003oZ;o[ojRoj`02
ojRoj`Co00000_nX_n/00ol0003oEWSHoeIhf002o`000006odaUc?l0003o@EW4od5Ia?l0003o@UO1
0_l00002oeIN_`05o`000?mRHkgoHV>mof9S_Ol000000_m`J[`00ol0003oOW:kogib^`02ogib^`05
o`000?n<N[[oS7Zjohaj^_l000001?nIPKP00ol0003oXhNfoj>7]P02oj>7]P03o`000?n/SKCo[8fd
00;o[8fd0_l00005okJE]@04o`000?nlVKCo_9VdokbI]0Co00000oo4XK@00ol0003obJJfo`000004
olbY]P03o`000?oA[kSo000000?od[6i00?o0000omRi^ooH^K/00_oH^K/00ol0003ogL>oomg3_`02
omg3_`05o`000?oSc<7ohlc1on?<`Ol000000ooUf<P01Ol0003ojN;:onWRb_oYh/[o000000;ok>c;
00Go0000oncdb_l0003oj?[8o`000002on?ma0?o000000Cod?k1o`000?l0003od?o?0ol000001OoD
n^;o0000om?_i_oCknKo000000;oc^7V0_l00004okk:i0?o00000_n/]=h00ol0003oWZcQoij/h@02
oij/h@05o`000?n;X^CoRj;Toh^Ri?l000000_mbU^H01?l0003oDhOVoe>7i_mCQnH9o`0000GoZ;o[
00Ko0000ojRojol0003o0000ojRojol00005ojRoj`06o`000?nX_n_o0000o`000?nX_n_o00001?nX
_n/2o`0000oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Booooo`00;_ooool0
0ol0003oooooooooo`05ooooo`;o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`?o00000onX_n/0
0ol0003oZ;o[ojRoj`02ojRoj`?o00001?nX_n/00ol0003oZ;o[ojRoj`03o`0000GoZ;o[00?o0000
ojRojonX_n/01?l00004ojRoj`06o`000?nX_n_o0000o`000?nX_n_o00001?nX_n/01?l0003oZ;o[
o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[00Co0000oeIhf?l0003o=e[:0ol00002od5I
a003o`000?m2El7o@UO100;o000000GoEUjoo`000?mRHkgoHV>mo`000003og1Z_005o`000?mnL[_o
OW:kogib^ol000000on<N[X00ol0003oVH6hoiV1^002oiV1^003o`000?nSQkKoXhNf00;oXhNf00?o
0000ojb=]?n/SK@00_l000000on_T;Ko0000okJE]@04okJE]@03o`000?nlVKCo000000;o000000?o
`9feo`000?o4XK@00_o4XK@01?l0003obJJfolVV]_l00003olbY]P07o`000?oA[kSodJnhom6_^?l0
003od[6io`000005omRi^`05o`000?oM`koogL>oomg3_ol000001?oSc<42o`000003onGHb?l0003o
jN;:00;ojN;:00So0000onc/boo/k<_o0000oncdb_l0003oj?[8o`0000;ohog40ol000000oo@o/7o
0000o`000003o`0000;ofOgJ0_l000001ooCknKo0000olkQi_o>hNKo0000olOAhOl000000onnb^@0
0ol0003o^;_Lo`000004ojbdgP03o`000?nN[>7oWZcQ00[o00000omCQnH00ol0003o;gGQo`000006
o`0000?oZ;o[0ol00004ojRoj`04o`000?nX_n_oZ;o[ojRoj`?o00001?nX_n/01_l0003oZ;o[o`00
0?l0003oZ;o[o`00013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`00
;_ooool00ol0003oooooooooo`03ooooo`?o00001?nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03
o`000?nX_n_oZ;o[00;oZ;o[00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRo
j`?o00000onX_n/00ol0003oZ;o[ojRoj`02ojRoj`?o00001?nX_n/00ol0003oZ;o[ojRoj`03o`00
00CoZ;o[00?o0000ojRojonX_n/01?l00004ojRoj`05o`000?nX_n_oZ;o[ojRojol000000_mFN=P0
0ol0003o=e[:ocMJbP02o`000006od5Ia?l0003o@UO1od9G`Ol0003oBUW00_l00002of9S_@05o`00
0?m`J[coL6Zlog1Z_?l000001?mnL[/01Ol0003oS7Zjohaj^_n<N[[o000000?oVH6h00?o0000oj>7
]_nSQkH00onSQkH2o`0000?o[i2f00?o0000okJE]OnfUKD00_nfUKD4o`0000Co`9fe00Co0000olBQ
]?o4XKCo00000oo9Y[H01?l0003oc:VfolbY]_l00003om6_^003o`000?oB/KWo000000Cof;Vk00?o
0000omg1_Ol000000_oM`kl01Ol0003ohlc1on?<`OoSc<7o000000;oj=K30_l00003onWRbP07o`00
0?o/k<_o0000oncdb_l0003oj?[8o`000002on?ma0Go000000Cod_fko`000?l0003o00000_oIoMX0
0ol0003ofOCQo`000002o`000003olkQi_l0003oam7Q00;oam7Q00?o0000okk:i?l000000onh^m`0
1?l0003o[;CNojbdg_n/]=h3o`0000;oWJ;H00Go0000ohnJf_n?V][oSi[Jo`000002ogbBg@Ko0000
0_l_MN48o`0000?oZ;o[00?o0000ojRojonX_n/01Ol00002ojRoj`04o`000?nX_n_oZ;o[ojRoj`?o
00001?nX_n/00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool04_ooool002kooooo00?o0000ooooool000000ol00003ojRoj`03o`000?nX_n_oZ;o[00Co0000
1?nX_n/00ol0003oZ;o[ojRoj`04o`0000CoZ;o[00Co0000ojRojol0003o00000_nX_n/00ol0003o
Z;o[ojRoj`02ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/3o`00
00;oZ;o[00?o0000ojRojonX_n/00_nX_n/3o`0000CoZ;o[00?o0000ojRojonX_n/02?l000001OmF
N=So0000ocMJb_l0003o;U7500;o00000_m2El401?l0003oBUW0odYI`?l00003of9S_@04o`000?m`
J[coL6Zlo`0000CoOW:k00Go0000ohaj^_n<N[[oS7Zjo`000004oiV1^004o`000?nSQkKoXhNfoj>7
]P;o00001On_T;H4o`000003okJE]Ol0003o000000Go`9fe00?o0000olBQ]?l000001?o9Y[H00ol0
003oc:Vfo`000005om6_^003o`000?oH^K_of;Vk00;of;Vk00Ko0000omg1_OoM`Kgo0000omg3_ol0
0004on?<`@0:o`000?oXe/?oj=K3o`000?o]hLGo0000onWRb_l0003ok>c;o`0000;ok?C:0_l00002
on?ma0;o000000CofObfo`000?l0003od_fk0ol00002omWmfP03o`000?oIm>7o000000;oeNOS0_l0
0004olOAh@;o00001?nh^m`01_l0003o[;CNo`000?l0003oZJSFo`0000CoWJ;H00Go0000ohnJf_n?
V][oSi[Jo`000002ogbBg@04o`000?mUQmooIHOOofF7g`Co000000?o2f?Io`000?l000000_l00005
ojRoj`?o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`Co00000onX_n/00ol0003oZ;o[ojRoj`03
o`0000oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`00;Oooool3o`00
00?oZ;o[00Co0000ojRojonX_n_oZ;o[0ol00004ojRoj`03o`000?nX_n_oZ;o[00Co00001?nX_n/0
0ol0003oZ;o[ojRoj`04o`0000CoZ;o[00?o0000ojRojonX_n/01?l00004ojRoj`06o`000?nX_n_o
0000o`000?nX_n_o00001?nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;o
Z;o[0ol00003ojRoj`05o`000?m_U^OoKiKWo`000?lgI=800_l00002ocMJbP04o`000?l^DLGo0000
o`0000;o@UO100?o0000odYI`?m:FL000_l000000omRHkgo0000og1Z_002og1Z_005o`000?mnL[_o
OW:kogib^ol000000on<N[X00ol0003oVH6hoiV1^002oiV1^006o`000?nSQkKoXhNfo`000?nUR[So
00000on_T;H3o`0000?o]YFe00?o0000okZI]ol000001_o0WKD00ol0003obJJfolVV]P04olVV]P03
o`000?oA[kSodJnh00CodJnh00Go0000omRi^ooH^K_of;Vko`000004omg1_@03o`000?oSc<7ohlc1
00;ohlc100Co0000onSF`ooXe/?o00000oo]hLD4o`000003oncdb_l0003o000000?o000000Goh?bh
o`000?l0003o0000om;m^`04o`000004omWmf_l0003ofOCQo`0000;oeNOS00Go0000olkGh?o>en3o
0000olOAh@02o`0000;o`<7K00?o0000okRkg?nh^m`00ol00004ojVXeP05o`000?nMX]SoWJ;HoifR
f?l000000on?V]X01Ol0003oO9;MogbBgOmlT]go000000?oIHOO00Co0000od]kgol0003o00000_l;
HmT3o`000006ojRojol0003o0000o`000?nJh_go00001?nX_n/01_l0003oZ;o[o`000?l0003oZ;o[
o`0000GoZ;o[0ol00002ojRoj`03o`000?oooooooooo00gooooo0_l00007ooooo`03o`000?oooooo
oooo01;ooooo000]ooooo`03o`000?oooooo000000CoZ;o[00?o0000ojRojol000000_nX_n/00ol0
003oZ;o[ojRoj`02ojRoj`?o00000onX_n/00ol0003oZ;o[ojRoj`02ojRoj`?o00001?nX_n/00ol0
003oZ;o[ojRoj`04o`0000CoZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`03o`000?nX_n_oZ;o[
00Co00001?nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[00Co0000
ofnFiom_U^Oo00000_lgI=83o`0000;o;U750_l000001_m2El7o0000odYI`?m:FL3o0000oeUP_`;o
00000om`J[`01Ol0003oOW:kogib^omnL[_o000000?oS7Zj00?o0000oiV1^?nIPKP00_nIPKP00ol0
003oXhNfo`000003ojF:^0?o00000_n_T;H01?l0003o]YFeokJE]Ol00002okZI]`03o`000?o0WKGo
`9fe00Co`9fe00?o0000olVV]_o9Y[H01?o9Y[H00ol0003odJnhom6_^003om6_^003o`000?oF]k[o
000000;of;Vk00?o0000omg1_OoM`Kd00_oM`Kd2o`0000;ohlc100Go0000onSF`ooXe/?oj=K3o`00
0003ongQa@07o`000?o_j/Go0000onoc`ol0003okOS0o`000002onOk_0Co000000Cod_fko`000?l0
003oe?o61_l000000ooEin?o0000olkGh002olkGh0;o00001?o0`M/3o`0000;o/ZkD00?o0000ojVX
e_nYZ=H00_nYZ=H00ol0003oWJ;HoifRf00?o`0000;oBg_O0_l000000ol;HmWo0000o`000002o`00
00CoV^;m00?o0000ojRojonX_n/00ol00004ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`00
0?nX_n/00onX_n/00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0000Cooooo00?oEEEE
ofIVI_l000005?ooool002?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`04o`000?oooooo
ooooo`0000;oZ;o[1?l00003ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o0000ojRojonX_n/0
0_nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0ol00003ojRoj`03
o`000?nX_n_oZ;o[00;oZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00001?nX_n/00ol0003o
Z;o[ojRoj`04o`0000CoZ;o[00?o0000ojRojonX_n/01?l000001Om_U^Oo0000ocMTd_l0003o8E;:
00;o000000?o;U75o`000?l`Cl800_l00003odYI`003o`000?mIH;ooFF2o00Co00001?mnL[/01Ol0
003oS7Zjohaj^_n<N[[o000000;oVH6h0ol000000onUR[So0000o`000002o`0000Go[i2f0_l00004
okZI]`03o`000?o0WKGo`9fe00;o`9fe00?o0000olBS]ol000001?o9Y[H00ol0003ocZfho`000003
om6_^006o`000?oF]k[oe[Njo`000?oH^K_o00001?oM`Kd01_l0003ohl^oon?;_ol0003ohlc1o`00
00;oj=K300Oo0000ongQaOo]hLGokN75o`000?o_j/Go000000;oko?30_l00002onOk_0;o000000?o
fObfo`000?l000000_l000000ooDolKo0000o`000002om_ig@04o`000?oIk^7ofNkQo`0000?oc]OP
00?o0000olK7fol000000oo0`M/00ol0003o^K?Do`000004ok:^e003o`000?nYZ=KoZJSF00Co0000
0_nMV]001Ol0003oTYCBoi:Dd_nBU=;o000000?oQ8kE00Co0000og>7f?mcQmSoLhOH1?l000000ol]
Kmgo0000o`00000:o`0000?oZ;o[00?o0000ojRojonX_n/00ol00005ojRoj`03o`000?nX_n_oZ;o[
00?o00003oooool00ol0003oooooooooo`0Iooooo`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo00Co0000oooooooooooooooo0_l00004ojRoj`03o`000?nX_n_oZ;o[00;o00001OnX_n/0
0ol0003oZ;o[ojRoj`04o`0000CoZ;o[00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRo
j`02ojRoj`06o`000?nX_n_o0000o`000?nX_n_o00001?nX_n/3o`0000?oZ;o[00?o0000ojRojonX
_n/00_nX_n/3o`0000CoZ;o[00?o0000ojRojonX_n/01?l00002ohfcl004o`000?m6Mmgo0000o`00
00;o=fCB00?o0000ob5Bb_l000000_l^DLD01?l0003o<4o2o`000?l00002odYI`004o`000?mIH;oo
FF2oo`0000;oJVVo3?l00002oiV3^P;o00000onUR[P00ol0003o[i2fojn@]P03ojn@]P03o`000?nj
VKOo^YVg00?o^YVg00Go0000ol2M]Oo0WKGo`9feo`000002olBS]`05o`000?o9Y[KobJJfolVV]_l0
00000_o>[KP01?l0003odJnhom6_^?l00004omJg^P03o`000?oM`KgogL6m00?ogL6m00Go0000on?;
_ooSbkoohl^oo`000002onSF``05o`000?o]hLGokN75ongQaOl000000_o_j/D01?l0003oko?3o`00
0?l00002onOk_0;o000000?ofObfo`000?l000000_l000000ooDolKo0000o`000002om_ig@08o`00
0?oIk^7ofNkQo`000?oBg^7o0000olkGh?l00003olK7f`03o`000?o0`M_o000000?o^K?D00Co0000
ok:^e?nb[]Co/ZkD0ol00002ojJOc`03o`000?nMV]3oWI[@00;oWI[@00Go0000oi:Dd_nBU=;oTYCB
o`000003ohB>e@06o`000?mcQmSoLhOHog>7f?l0003oGgoK0_l00003obe_g@;o000000?o05G?o`00
0?l000000_l00005ojRoj`?o00000_nX_n/00ol0003oZ;o[ojRoj`03ojRoj`?o00000onX_n/00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01Sooooo000Sooooo`05oa0@4?oooooooooooooo
ool@41001Oooool00ol0003oooooooooo`02ooooo`03o`000?nX_n_oZ;o[00;oZ;o[0ol00002ojRo
j`03o`000?nX_n_oZ;o[00;oZ;o[0ol00004ojRoj`03o`000?nX_n_oZ;o[00?o00001OnX_n/00ol0
003oZ;o[ojRoj`03o`0000CoZ;o[00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRoj`02
ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/3o`0000;oZ;o[00?o
0000ohfcl?n=/o000_n=/o000ol0003oAWOModIgg@03o`0000;o8E;:0ol00002oc1?`P;o000000Go
BUW0o`000?mIH;ooFF2oo`000003ofYY_`05o`000?mkL[koNg:nog]b__l000000on;Nk`00ol0003o
VH>jo`000003o`0000GoYHZh00Co0000ojn@]_n_T;Ko[i2f0_l00005okZI]`04o`000?o0WKGo`9fe
o`0000?oa:>g00Co0000olVV]_o9Y[Ko00000oo>[KP00ol0003odJnho`000005omJg^P03o`000?oM
`KgogL6m00;ogL6m00?o0000on?;_ooSbkl00_oSbkl2o`000005onSF`ol0003okN75ongQaOl00000
0_o_j/D01_l0003oko?3o`000?o]n<3o0000onOk_0Oo000000Koe?o6o`000?l0003o0000om_igOl0
0002omW^h@03o`000?oBg^7od]kQ00;o00001?o6am/2o`0000Co^K?D00Ko0000ok:^e?l0003o0000
ojfTc_l00004ojJOc`05o`000?nMV]3oWI[@oifJd?l000000onBU=801Ol0003oQ8kEohB>eOn4S]Go
000000CoLhOH00?o0000oemofomOOm/00_l000000ol]Kmgo0000o`000003o`000004o`=og_l0003o
0000ojRoj`?o000000?oY/cco`000?nX_n/00onX_n/00ol0003oZ;o[o`000002o`000003ojRojol0
003oZ;o[00?oZ;o[0_l0000?ooooo`03o`000?oooooooooo01Oooooo000Sooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`03ooooo`06o`000?nX_n_o0000o`000?nX_n_o
00001?nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0ol00003ojRo
j`03o`000?nX_n_oZ;o[00;oZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00?o00001OnX_n/00ol0
003oZ;o[ojRoj`04o`0000CoZ;o[00Ko0000ojRojol0003o0000ojRojol00004ojRoj`05o`000?n=
/o3oSK?`ohfcl?l000000_m6Mmd00ol0003o85gCo`000002ob5BbP07o`000?lFB<Co0000o`000?l`
Cl;o0000oc]D`P03o`0000;oFF2o00Co0000ofYY_omZJKoo00000omkL[h00ol0003oRg^loh]k_003
o`0000CoVH>j00?o0000ojF:^?nUR[P00_nUR[P01?l0003o[i2fojn@]_l00002ok:D^@03o`000?nj
VKOo^YVg00?o^YVg0_l00005olBS]`;o00001Oo>[KP00ol0003oe[NjomJg^P03omJg^P03o`000?oM
`;go000000;ogL6m00?o0000on?;_ooSbkl00_oSbkl00ol0003ojMK1onWF`@02o`000005ongQaOl0
003okn[5onoZaOl000000_o_ll<2o`000003onOk_?l0003o000000So000000Kof?gJo`000?l0003o
0000omW^hOl00002om;Nh@05o`000?o;cMcoblgLo`000?o6am/00_l000000onn^MCo0000okVce003
okVce0;o00001?n]Y<h01Ol0003oYYo?ojJOconVWloo000000;oWI[@3ol00002oemof`03o`000?m9
Mmco000000Oo000000?o0goNo`000?nVc?<01?nVc?<00ol0003oZ;o[ojRoj`03o`0000GoZ;o[1?l0
00000onX_n_o0000ooooo`0>ooooo`03o`000?oooooooooo01Oooooo000Sooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`05ooooo`;o00000onX_n/00ol0003oZ;o[ojRo
j`04o`0000CoZ;o[00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`04o`00
0?nX_n_o0000o`0000;oZ;o[00Co0000ojRojonX_n_oZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[
00;oZ;o[0ol00004ojRoj`03o`000?nX_n_oZ;o[00?o00001?nX_n/00ol0003oZ;o[ojRoj`08o`00
0003odIggOl0003o85gC00;o000000Co8E;:o`000?lFB<Co00000_l`Cl800ol0003o>eC2oc]D`P02
o`000003oeUP_ol0003oJVVo00;oJVVo00?o0000og]b__mkL[h00ol00002oh]k_003o`000?nIPk[o
VH>j00;oVH>j00?o0000ojF:^?nUR[P00_nUR[P00ol0003o[i2fo`000003ok:D^@03o`000?njVKOo
^YVg00?o^YVg00?o0000olBS]oo4XkL01?o4XkL00ol0003ocZfholj]^004olj]^003o`000?oF]k[o
e[Nj00?oe[Nj00Ko0000omg0_OoM`;go0000omg1_Ol00003on?;_`06o`000?oYe/7ojMK1onWF`Ol0
003ok^320ol000000oo_j/Go0000onoc``04o`000006omkk/Ol0003o0000om3i[Ol0003oaOR_0ol0
00001?oHoM[o0000omWchOoIln43o`000003om;NhOl0003oblgL00;oblgL0_l00004okjie006o`00
0?ni/mCo0000o`000?ncZ<ko00001?n]Y<h00ol0003oYYo?ojJOc`04o`0000;oW9?:00Go0000oiB?
c?nDSlcoU8o<o`000003ohV;cP04o`000?mmQ]7oOHKAogf6d@Go00000om9Mm`4o`000004o`1DcOl0
003o0000o`0000?oY/cc1?l00003ojRoj`03o`000?nX_n_oZ;o[00?o00001OnX_n/00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo01Kooooo000Sooooo`05oa0@4?ooooooooooooooool@4100
1?ooool00ol0003oooooo`000007ooooo`03o`000?nX_n_oZ;o[00?o00001?nX_n/00ol0003oZ;o[
ojRoj`04o`0000CoZ;o[00?o0000ojRojonX_n/01?l00004ojRoj`03o`000?nX_n_o000000;oZ;o[
00?o0000ojRojonX_n/00_nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;o
Z;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onT_^`01Ol0003oHY7Xof:Aj?l0003o<GCP
00;o000000?o85gCo`000?l4AlL00_l00002oaI8a0?o00000_lkE<801?l0003oCEg2o`000?l00003
ofYY_`?o000000?oNg:no`000?n;Nk`00_n;Nk`00ol0003oVH>joiV3^P02oiV3^P03o`000?nUR[So
YHZh00;oYHZh0_l00005ok:D^@04o`000?njVKOo^YVgokZI]`;o00001_o4XkL00ol0003ocZfholj]
^003olj]^003o`000?oD]K_o000000?oe[Nj00?o0000omg0_OoM`;d00_oM`;d01Ol0003ohl^oon?;
_ooSbkoo000000?ojMK100Co0000onkP`_o^h<;o00000_oaj/83o`000003ongh_?l0003oio^g00?o
000000?od?V]o`000?o5n:l00ol000001OoHoM[o0000omWchOoIln7o000000;oe>CR0_l00003ol_=
g003o`000?o2_]Ko000000Co_[WD0_l00004ok>XcP04o`000?n]Y<ko[JC>ojfTcP?o00000_nTV<T0
0ol0003oW9?:oibCbP02oibCbP05o`000?nDSlcoU8o<oiB?c?l000000on9Rlh01Ol0003oOHKAogf6
dOmmQ]7o000000;oKh7E0ol000000om9Mmco0000o`000009o`0000;oS/on00?o0000ojRojonX_n/0
0_nX_n/3o`0000?oZ;o[00Co0000ojRojonX_n_oZ;o[0ol0000?ooooo`03o`000?oooooooooo01Go
oooo000Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool2o`0000Wooooo0_l00002ojRoj`03
o`000?nX_n_oZ;o[00;oZ;o[0ol00004ojRoj`03o`000?nX_n_oZ;o[00Co00001?nX_n/00ol0003o
Z;o[ojRoj`03o`0000CoZ;o[00?o0000ojRojonX_n/01?l00004ojRoj`04o`000?nX_n_o0000o`00
00;oZ;o[00Co0000ojRojonX_n_oZ;o[0ol00003ojRoj`03o`000?nT_^coY;k/00;oY;k/00Co0000
of:Aj?mRTNSo00000_laM>03o`000006o`A7aol0003o5TS4oaI8a?l0003o6DO20_l000001?lkE<;o
0000odeM`_m=GL85o`0000?oNg:n00?o0000oh]k_?n;Nk`00_n;Nk`00ol0003oVH>joiV3^P02oiV3
^PCo000000?oYhnko`000?nbU;T01?nbU;T01?l0003o^YVgokZI]ol00002okjO^@03o`000?o4XkOo
a:>g00;oa:>g00?o0000olZ[^_l000001?o>[KP01_l0003oe;FkomBe^ol0003oe[Njo`0000GogL2m
0_l000000ooSbkoo0000onWF`@02onWF`@04o`000?o^h<;ok^32o`0000?olN[200Go0000oo7c`?l0
003o0000onOk]`05o`000003olGh[ol0003o000000Co000000GofO?Qo`000?oDi>;oe>CRo`000002
olgCgP03o`000?o;cMco000000?o`[kF00Ko0000okjie?l0003o0000okN]c_l00004ok>XcP06o`00
0?n]Y<ko0000o`000?nYVlSo00001?nTV<T01Ol0003oW9?:oibCb_nLTl[o000000?oU8o<00Go0000
ohV;c_n9RlkoRH_>o`000004ogf6d@05o`000?m_PMGoKh7Eo`000?mOOMT01?l000001?ldLMgo0000
o`000?l6HmT2o`000003o`1ZfOl0003o000000?o000000GoZ;o[o`000?l0003oZ;o[o`000004ojRo
j`Co00000_nX_n/00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Gooooo000Sooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003oooooooooo`09ooooo`06o`000?nX_n_oZ;o[
ojRojol0003oZ;o[0_l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0ol00003ojRoj`03o`000?nX
_n_oZ;o[00;oZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00001?nX_n/00ol0003oZ;o[ojRo
j`04o`0000CoZ;o[00?o0000ojRojol000000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`03o`000?nT
_^coY;k/00Ko000000?o<GCPo`000?l1Dll00_l000001ol4AlOo0000o`000?lFB<Co0000oaU7`_l0
00000_lkE<86o`000005ofYY_ol0003oNg:nog]b__l000001?n;Nk`01?l0003oVH>joiV3^_nIPkX2
o`0000CoYhnk00?o0000ok:D^OnbU;T00onbU;T00ol0003o^YVgo`000003okjO^@05o`000?o4XkOo
a:>golBS]ol000000_o:ZkX01Ol0003ocZfholj]^?o>[KSo000000?oe;Fk00?o0000omJg^_l00000
1?oM`;d00ol0003ohl^oon?;_`02o`0000?ojMK100Co0000onkP`_o^h<;o00000_oaj/801?l0003o
lO?0o`000?o]n;`6o`000007olGh[ol0003o0000o`000?o@omOo0000omGihP03o`000003omCTh_l0
003ocM?N00;ocM?N0_l00004ol:neP;o00001?ng[Lh01?l0003o/jS>ok>Xc_ncZ<h2o`0000CoZI_8
00Go0000ojBHbOnTV<WoY9S9o`000003oibCbP05o`000?nDSlcoU8o<oiB?c?l000000on9Rlh00ol0
003oOHKAogf6d@02ogf6d@05o`000?m_PMGoKh7Eofn1eOl000000omOOMT3o`000003obI`gol0003o
000000Co00000_mV]O`2o`0000CoZ;o[00Ko0000ojRojol0003o0000ojRojol00005ojRoj`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool05?ooool002cooooo00?o0000ooooooooool02_oo
ool00ol0003oZ;o[ojRoj`03o`0000CoZ;o[00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[
ojRoj`02ojRoj`06o`000?nX_n_o0000o`000?nX_n_o00001?nX_n/3o`0000?oZ;o[00?o0000ojRo
jonX_n/00_nX_n/3o`0000CoZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`03o`000?nX_n_oZ;o[
00Co00000on;/_000ol0003oEIG_o`000003o`0000;o0E??0_l000001?l0?;oo0000o`000?lIAl84
o`0000;oCEg200?o0000of9X`omRJ<<01?l000000omkL[ko0000oh]k_002oh]k_006o`000?nIPk[o
0000o`000?nJQkko00001OnWSk/00ol0003o/YBiok:D^@02ok:D^@;o00001OnnWkT01?l0003oa:>g
olBS]ol00003olZ[^P03o`000?o>[KSo000000Goe;Fk00?o0000omg0_OoM`;d00_oM`;d02Ol0003o
hl^oon?;_ooSbkoo0000onWF`Ol0003ojMK1o`000002onkP`P0;o`000?oaj/;olN[2o`000?oall3o
0000ongh_?l0003oio^go`000?o>mjD01_l000001?o@omOo0000omGih_l00002om?Zi@;o00000oo=
dmh00ol0003oa<;Ho`000003ol:neP03o`000?nk/M3o000000Co]jg>00Ko0000ok>Xc_l0003o0000
ojjOb?l00004ojVKb005o`000?nTV<WoY9S9ojBHbOl000000_nLTlXCo`0000?oGggI1?l00003obI`
g`;o000000?o47;Qo`000?l000000_l00003ojRoj`?o00001?nX_n/00ol0003oZ;o[ojRoj`03o`00
00kooooo00?o0000ooooool000005Oooool002cooooo00?o0000ooooooooool02oooool2o`0000?o
Z;o[00?o0000ojRojonX_n/01?l00004ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/01?l0003o
Z;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[00Co0000ojRojol0003o00000_nX_n/0
0ol0003oZ;o[ojRoj`02ojRoj`?o00000onX_n/00ol0003oZ;o[ojRoj`04o`0000CoZ;o[00So0000
oh^bl?n;/_3oRk;`o`000?mEUNoo0000oaI_g`;o000000Go0E??o`000?l0>Kko0000o`0l_`02o`00
0004oaU7`_l0003o0000o`0000?oCEg200Co0000of9X`omRJ<?o00000_mgM<87o`0000CoVXNn00?o
0000ojN?^onWSk/00_nWSk/01ol0003o/YBiok:D^OnbU;Wo0000okJK_?l000001OnnWkT00ol0003o
a:>go`000004olZ[^P03o`000?o>[KSo000000Goe;Fk00Go0000omg0_OoM`;gogL2mo`000003on?;
_`05o`000?oYe/7ojMK1onWF`Ol000000_o^h<801?l0003olN[2oo7Z`_l00002oo7c`0;o000000?o
io^go`000?l000000ol000001onjmk7o0000o`000?o@omOo0000omGih_l000000_oCj^D01_l0003o
cMSRolgHh_l0003ocM?No`0000?oa<;H00?o0000ol:ne_l000000onk/M001?l0003o]jg>okN]c_ng
[Lh2o`0000Co[Yo800Go0000ojVKb?nYVlSoZI_8o`000002ojBHb@Co00000_nLSlD01Ol0003oUXc7
oiJ<aonFS<Oo000000?oSXW900?o0000ohF6c?n5Q/`00_n5Q/`00ol0003oNh?@og^3d004o`000004
oemmfOl0003o0000odmjg@;o000000?o9W3Oo`000?lYNnH00ol000000om4VoCo0000o`000002o`00
00?oY/cc00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool04oooool002cooooo00?o0000ooooooooool02oooool00ol0003oZ;o[ojRoj`02ojRoj`?o
00001?nX_n/00ol0003oZ;o[ojRoj`04o`0000CoZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`03
o`000?nX_n_oZ;o[00Co00001?nX_n/01_l0003oZ;o[o`000?l0003oZ;o[o`0000CoZ;o[0ol00003
ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[2?l00002oaI_g`Go000000Co03boo`000?lIAl;o6DO20ol0
0002odeM`P05o`000?mRJ<?oHVS3of9X`ol000000_mgM<800ol0003oRWk0ohYn`002ohYn`003o`00
0?nJQkkoVXNn00;oVXNn00?o0000ojN?^onWSk/00_nWSk/01?l0003o/YBiok:D^Ol00002okJK_003
o`000?nnWkWo_Yni00Co_Yni00?o0000olZ[^_o:ZkX01?o:ZkX00ol0003oe;FkomBe^`03omBe^`03
o`000?oJ_kko000000;ogL2m00Go0000on?;_ooSbkoohl^oo`000003onWF`@;o000000Cok^32o`00
0?oaj/;o00000_oall000ol0003okORlo`000005o`000003ok[g/Ol0003o000000Go000000?odn[U
o`000?o=f>800_o=f>82o`0000Coa<;H0_l00004ok^ad006o`000?ng[Lko0000o`000?nbXlWo0000
1?n^WlP01?l0003oZI_8ojVKb?nYVlP3o`0000;oXY;400?o0000oib?aOnLSlD00_nLSlD01Ol0003o
UXc7oiJ<aonFS<Oo000000?oSXW900?o0000ohF6c?n5Q/`00_n5Q/`01?l0003oNh?@og^3d?l00002
og21e0Go000000Co@g_Qo`000?l0003o00000olYNnH4o`0000?oY/cc1?l00002ojRoj`03o`000?nX
_n_oZ;o[00;oZ;o[0_l0000?ooooo`03o`000?oooooooooo01;ooooo000[ooooo`03o`000?oooooo
oooo00gooooo00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`?o00001?nX
_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00004ojRoj`03o`000?nX
_n_oZ;o[00?o00001?nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[
00Ko0000ojRojol0003o0000ojBnk?l00004oh:fmP03o`000?m3V??o000000Go000000Oo03Vno`00
0?l0003o0000oaU7`_l0003o9dg300;o00000_m=GL801?l0003oHVS3of9X`ol00003ogMd`P05o`00
0?n:O/3oRWk0ohYn`?l000001?nJQkh00ol0003oYhnkojN?^`03ojN?^`;o00001?nfVk`00ol0003o
_YniokjO^@02okjO^@;o00001_o:ZkX00ol0003oe;FkomBe^`02omBe^`06o`000?oJ_kkof[nno`00
0?oM`;go00000ooSbkl01Ol0003ojMK1onWF`OoYe/7o000000;ok^732?l000000ooSnk?o0000o`00
0006o`000004olclhol0003ocnoYolo_j@;o00000oo=f>800ol0003oaLOKo`000003olC2f003o`00
0?nl]=;o000000Co^k7@0_l00004ok:Sb@06o`000?n^WlSo[Yo8ojjOb?l0003oZI_80_l000000onV
ULCo0000oj:Ba003oj:Ba005o`000?nLSlGoW8o5oib?aOl000000onFS<L01Ol0003oSXW9ohj9bOn>
RLWo000000CoQHK<00Go0000og^3d?mkPm3oNh?@o`000002og21e003o`000?mTP=Wo000000;o0000
0om3Nn44o`0000;oBIOb1?l00002oiO4mP03o`000?nX_n_oZ;o[00;oZ;o[00Ko0000ojRojol0003o
0000ojRojol0000@ooooo`03o`000?oooooooooo017ooooo000[ooooo`?o00003_ooool2o`0000Co
Z;o[00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`?o00000_nX_n/00ol0
003oZ;o[ojRoj`02ojRoj`?o00001?nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRo
jonX_n/01?l00004ojRoj`03o`000?nX_n_oZ;o[00?o00001?nT_^`00ol0003oP[Kfoh:fmP07o`00
00;o04G41_l000000olWCL?o0000ociIaP03o`0000?oHVS300Co0000ogMd`_mgM<;o00001?n:O/00
0ol0003oVXNnoiZ7_P02oiZ7_P04o`000?nWSk_oYhnkojN?^`;o00001OnfVk`01Ol0003o_YniokjO
^OnnWkWo000000;o`jNm00?o0000olZ[^_o:ZkX00_o:ZkX00ol0003od;>mo`000002omBe^`03o`00
0?oJ_kkof[nn00;of[nn0_l00002on?;_`05o`000?oYe/7ojMK1onWF`Ol000000oo^hL<00ol0003o
lNc2o`000002oo3d_`03o`000?o/nK[o000000;o000000?o]>bHo`000?l000000ol000001Oo<o>?o
0000olo_jOo?knWo000000;obmgW00?o0000olgHh_l000000oo5am/00ol0003oa<;Ho`000003okbd
dP06o`000?nk/M3o0000o`000?ndY/[o00001?nbXlT00ol0003o[Yo8ojjOb003o`0000CoYYG400Go
0000oj:Ba?nRT/CoXY;4o`000003oib?a@05o`000?nFS<OoUXc7oiJ<aol000000_n>RLT7o`0000?o
Nh?@00So0000og21e?m`PMCoL87Do`000?mTP=Wo0000ofB0f@Go000000?o@X?Wo`000?l000001?l0
0004oiO4mP03o`000?nX_n_oZ;o[00?o00001?nX_n/00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo017ooooo000[ooooo`03o`000?oooooooooo013ooooo00?o0000ojRojonX_n/01?l00004
ojRoj`06o`000?nX_n_o0000o`000?nX_n_o00001?nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03
o`000?nX_n_oZ;o[00;oZ;o[0ol00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0ol00004ojRoj`03
o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oY;k/ojBnk005o`0000?oO;ol3?l000000olWCL?o
0000ociIaP02ociIaP;o000000?oHVS3o`000?mgM<800_mgM<801Ol0003oRWk0ohYn`?n:O/3o0000
00CoVXNn00Ko0000ojN?^onWSk_o0000oj^E_ol00005okJK_004o`000?nnWkWo_Ynio`0000?o`jNm
00Go0000olZ[^_o:Zk[obZ^jo`000002om2c_@03o`000?oD]K_o000000Gof[nn00Go0000on7:`Ol0
003ohl^oo`000002onWF`@07o`000?o^hL?ok^73onkQ`ol0003olNc2o`000002oo3d_`03o`000?o/
nK[o000000Co000000?oWnZSo`000?l000001?l000000oo?knWo0000ol_Mi`02ol_Mi`;o00001?o5
am/2o`0000Co_;CB0_l00004okBVbP04o`000?nbXlWo/Z?9ok:Sb@?o00000_nZV<@00ol0003oYYG4
ojJEa002ojJEa005o`000?nRT/CoXY;4oj:Ba?l000000_nLSlD8o`0000;oTXO500Co0000ohb6aon<
Q/OoS8K72Ol00002ofB0f@;o00000omKP]l4o`0000?oEYS`2?l00003ojS0j`03o`000?nX_n_oZ;o[
00?o00003oooool00ol0003oooooooooo`0@ooooo`00:oooool00ol0003oooooooooo`0Aooooo`;o
00001?nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00004ojRoj`04
o`000?nX_n_o0000o`0000;oZ;o[00Ko0000ojRojonX_n_oZ;o[o`000?nX_n/2o`0000;oZ;o[00?o
0000ojRojonX_n/00_nX_n/3o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/5o`0000;oZ<_b00?o
0000ogboo?ml_o`02Ol000000ol0;;Go0000o`0k_P03o`0000?o?UW600Co0000oeQXb?l0003o0000
0omgM<801Ol0003oRWk0ohYn`?n:O/3o000000CoVXNn00?o0000ojN?^ol000000on[UKl00ol0003o
]Y^lokJK_003okJK_0;o00001?o3Ykd01?l0003obZ^jolZ[^_l00004om2c_@03o`000?oJ_kkof[nn
00?of[nn00Go0000on7:`OoQb/7ohL[1o`000003onWF`@04o`000?o^hL?ok^73o`0000;olNc200Ko
0000oo3d_ol0003ok?Vjo`000?oSnk<3o`000005oioZXol0003o0000ok_li?l000000_o5lnh3o`00
0003ol_Miol0003o000000;o`l_O00Ko0000olG7fol0003o0000okfhe?l00003okbddP03o`000?nf
ZLco000000Co]:K:00Ko0000ok:SbOl0003o0000ojfKa?l00004ojZHa005o`000?nVULCoYYG4ojJE
a?l000000_nRT/@4o`0000;oW8c100Go0000oiR9`onHRL?oV8W3o`000004oi:7a@05o`000?n<Q/Oo
S8K7ohb6aol000000on5Q</00ol0003oOHC@ogf4d006o`0000?oFh;O00Co0000oeV:i_l0003o0000
0omFV?000ol0003oR[WeohZim@02ohZim@04o`000?nX`>_oZ<3[ojS0j`Co00000onX_n/00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00oooooo000[ooooo`03o`000?oooooooooo01;ooooo
00?o0000ojRojonX_n/00_nX_n/3o`0000CoZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`03o`00
0?nX_n_oZ;o[00Co00001?nX_n/00ol0003oZ;o[ojRoj`03o`0000CoZ;o[00Co0000ojRojol0003o
00000_nX_n/01_l0003oZ;o[ojRojonX_n_o0000ojRoj`Co000000CoZ;o[o`000?nXbo;oZ<_b1Ol0
0003og?8o`Ko000000Co02beo`000?l0003o3DC30_l00002ociIaP04o`000?mHJ<SoF6S8oeQXb0Co
00001?n:O/000ol0003oVXNnoiZ7_P03o`0000CoZiFo00?o0000okJK_?nfVk`00onfVk`00ol0003o
`jNmol>W_@04ol>W_@;o00001Oo@/kd00ol0003of[nnomZo_P02omZo_P03o`000?oQb/7ohL[100;o
hL[10_l000000ooYe/7o0000onkQ``02onkQ``05o`000?oak<;o0000oo3d_ol000000_o/nKX7o`00
0003ok_li?l0003oaO?^00;o00000_o5hN`2o`0000Co`l_O0_l00004okfhe003o`000?nl]=;o0000
00?o]ZW<00Co0000okBVb_ndY/[o]:K:0_l00004ojfKa005o`000?nZV<CoZYS4ojZHa?l000000onV
UL@3o`0000;oXHk100?o0000oib<`OnLS<400_nLS<401Ol0003oV8W3oiR9`onHRL?o000000?oTXO5
00?o0000ohb6aon<Q/L00_n<Q/L01Ol0003oQHC;ohF4bon5Q<_o000000;oOHC@00?o0000ogF5eOme
QMD01Ol000001?mKP]oo0000oeV:i_mIR^H5o`0000;oR[We1Ol00002ojO3k@03o`000?nX_n_oZ;o[
00;oZ;o[0_l0000>ooooo`03o`000?oooooooooo00oooooo000[ooooo`03o`000?oooooooooo01?o
oooo00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`?o00000_nX_n/00ol0
003oZ;o[ojRoj`02ojRoj`?o00001?nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRo
jonX_n/01?l00004ojRoj`03o`000?nX_n_oZ;o[00?o00001?nX_n/3o`0000CoZ]Og3_l000000ol=
A<?o0000ociIaP02ociIaP04o`000?mHJ<SoF6S8o`0000;oLWK82?l00002oib=``03o`000?n[UKoo
ZiFo00?oZiFo00Co0000okJK_?nfVkco]Y^l0_l00006ol>W_@03o`000?o@/kgod;>m00?od;>m00?o
0000omJn`_l000000ooJ_kh01Ol0003ohL[1on7:`OoQb/7o000000;oimK40ol000001?o^hL?o0000
oo7/`_l00002oo3d_`03o`000?o/nK[o000000[o00000oo5hN`01Ol0003o`<gTol3=i?l0003o`l_O
00;o000000?o_;[Ho`000?nm^=@00onm^=@2o`0000Co]ZW<00Ko0000okBVb_ndY/[o0000ojnMaOl0
0004ojfKa006o`000?nZV<CoZYS4ojZHa?l0003oYYG40_l000000onTT<3o0000oj6>`@03oj6>`@05
o`000?nLS<7oW8c1oib<`Ol000000onHRL<01Ol0003oTXO5oi:7aOnBQlGo000000CoS8K700Go0000
ohF4bon5Q<_oQHC;o`000003ogf4d003o`000?meQMGoMHGE00;o00000_m^R=`6o`0000;oI9[^0ol0
0002oh>al`03o`000?nW`ngoYl?]00?oYl?]1?l000000onX_n_o0000ooooo`0=ooooo`;o00004?oo
ool002[ooooo00?o0000ooooooooool05Oooool2o`0000CoZ;o[00Ko0000ojRojol0003o0000ojRo
jol00004ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/3o`0000?o
Z;o[00?o0000ojRojonX_n/01?l00004ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/01?l0003o
Z;o[o`000?l00003okC6i`04o`000?nZeoOo0000o`0000;o[>7i1?l00002oeo?m0Oo000000Go3DC3
o`000?l0003o?UW6o`000003oeQXb004o`000?mbM/SoLWK8o`0000?oRH?600?o0000oib=`onLSL<0
0onLSL<00ol0003oZiFooj^E_`02oj^E_`04o`000?nfVkco]Y^lo`0000;o^Z?100?o0000ol>W_Oo3
Ykd00_o3Ykd2o`0000Cod;>m00Oo0000omJn`_oF_/;oe[k2o`000?oJ_kko000000?ohL[100Go0000
onOFa?oWe/CoimK4o`000002ongSaP;o000000?olNc2o`000?o`m;l00ol000000ooJnk3o0000o`00
0006o`0000;o_>?c00?o0000olGQk?l000000oo0cN@2o`0000Co_;[H00Ko0000okfhe?l0003o0000
okJ[c_l00004okJYc003o`000?ndY/[o000000?o[ig500Go0000ojfKa?n]VlCo[I_4o`000002ojZH
a0?o00001?nTT<001Ol0003oXHk1oj6>`OnQS/7o000000?oW8c100Go0000oiR9`onHRL?oV8W3o`00
0004oi:7a@05o`000?n<Q/OoS8K7ohb6aol000000on5Q</01Ol0003oOHC@ogf4d?mmQ=3o000000?o
MHGE0_l00002ofj8g004o`000?m/Sn?oK8oSofb?h`Go00001?n3/O<00ol0003oYl?]ojO3k@03o`00
00GoZ;o[00?o0000ooooooooool03?ooool00ol0003oooooooooo`0>ooooo`00:_ooool00ol0003o
ooooooooo`0Gooooo`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000Co
Z;o[00Ko0000ojRojol0003o0000ojRojol00004ojRoj`?o00000onX_n/00ol0003oZ;o[ojRoj`02
ojRoj`Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000Co]<KW0ol000000on/hOWo0000o`000003
ojcZn@So000000Go02beo`000?l=A<?o0000obUDb@02o`0000?oF6S800Co0000og9fb?mbM/So0000
1?n9PlH00ol0003oW8g3oib=``02oib=``03o`000?n[UKooZiFo00;oZiFo00?o0000okJK_?l00000
1?njXl401?l0003o`jNmol>W_Ol00002olV``@05o`000?o@/kgod;>mom2c_Ol000001?oF_/801Ol0
003ohL[1on7:`OoQb/7o000000?oimK400Ko0000ongSa_o]hlKokN?6o`000?o_klD4o`000003onKk
^_l0003o000000Ko00001?nlho<2o`0000?o`<gT00?o0000okZlfol000001?nl^]P2o`0000Co]Z_>
00Co0000okJYc?nfZLco]ZW<0_l00004ojnMa@04o`000?n]VlCo[I_4ojfKa0?o00000_nWTl000ol0
003oY930ojB@`002ojB@`005o`000?nQS/7oXHk1oj6>`Ol000001?nLS<400ol0003oV8W3o`00000G
o`0000?oKXSL00Go0000ofb?hom/Sn?oK8oSo`000002og:Lj`So00000onS_nd00ol0003oZ;o[ojRo
j`03o`0000oooooo00?o0000ooooooooool03Oooool002[ooooo00?o0000ooooooooool06?ooool2
o`0000CoZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/0
1?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[00?o0000ojRojol000000ol0
0004ojRoj`?o00001?nX_n/01?l0003o]<KWo`000?l00002olONjPCo000000Co[>[io`000?l0003o
[?3g1?l000001On^m_3o0000o`000?l0003o02be00?o000000?o:EC9o`000?l000000_mHJ<P01Ol0
003oLWK8og9fb?mbM/So000000?oRH?600?o0000oib=`onLSL<00_nLSL<00ol0003oZiFooj^E_`02
oj^E_`;o00001OnjXl400ol0003o`jNmo`000004olV``@03o`000?o@/kgo000000Goe[k200Go0000
on7:`OoQb/7ohL[1o`000003onOFa004o`000?o]hlKokN?6o`0000;okno500Co0000ongg`Ol0003o
i_^j1ol00002ojkRn004o`000?nlho?o0000o`0000;o^/kZ00?o0000ol3=i?l000000onj_=/01_l0
003o_;[Ho`000?l0003o]Zg@o`0000Co]Z_>00Ko0000okJYc?l0003o0000ok2Paol00004ojnMa@06
o`000?n]VlCo0000o`000?nYUL7o00001?nWTl001Ol0003oY930ojB@`?nTT<3o000000CoXHk100?o
0000oib<`Ol000000ol00002oiV8_`05o`000?nFQl7oUXO1oiJ7`Ol000001?nAQ/@01Ol0003oS8K7
ohb6aon<Q/Oo000000?oQhO<00Co0000oh:9dOn2RM7oPXWA1Ol00004ofb?h`05o`000?mbW>_oLYc[
og:Ljol000001?n6[^l00ol0003oXko]oj>ok@04o`0000?oZ;oZ00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0<ooooo`00:_ooool2o`0001[ooooo00?o0000ojRojonX_n/00_nX_n/3o`00
00?oZ;o[00?o0000ojRojonX_n/01?l00004ojRoj`03o`000?nX_n_oZ;o[00?o00001?nX_n/00ol0
003oZ;o[ojRoj`04o`0000?oZ;o[00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRoj`02
ojRoj`;o00000oo7g^X01?l0003obnO[ol_Wjoo;in/?o`000004o`0h_Ol0003o0000obUDb@?o0000
00GoF6S8o`000?mbM/SoLWK8o`000004ohV3aP03o`000?nLSL?oW8g300;oW8g31?l000000on^WLGo
0000okZS`@04okZS`@;o00001_o9/<400ol0003oe[k2omJn`P03omJn`P05o`000?oMb/Ko0000on7:
`Ol000000ooWe/@01?l0003okN?6ongSa_l00002ono_a@04o`000?o]ml7o0000onKk^POo00000_n^
h_P3o`0000Co^/kZ0_l00004okZlf`;o00001?nf[M001?l0003o]Z_>okJ[c_nfZlh2o`0000Co/:37
00Co0000ojnMaOn_WLGo[ig50_l00004ojVE`@05o`000?nWTl3oYi?0ojNC`?l000001?nTT<000ol0
003oXHk1o`000003o`0000;oWHVn00?o0000oiV8_onIR;l00_nIR;l01Ol0003oUXO1oiJ7`OnFQl7o
000000CoTHK400Go0000ohb6aon<Q/OoS8K7o`000003ohN7c005o`000?n2RM7oPXWAoh:9dOl00000
0_mmSMPAo`0000;oX[c/00?o0000ojRoj_nX_nX00_nX_nX2o`0000kooooo00?o0000ooooooooool0
3?ooool002[ooooo00?o0000ooooooooool06_ooool01_l0003oZ;o[o`000?l0003oZ;o[o`0000Co
Z;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00Go
00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000CoZ;o[00Co0000ojRojol0003o00000_n/`NT00ol0
003oamkZo`000003ol_Wj`06o`000?o?k^WocnkYo`000?oAlnOo00000ooCmND00ol0003oe_KSo`00
0002omSfhP?o000000Co03Rmo`000?lYE<Wo00000_m:Ilh3o`000003og9fb?l0003oRH?600?oRH?6
00?o0000oib=`onLSL<00ol00005ojjMa@07o`000?njXl7o^Z?1okZS`Ol0003o`:g7o`000005olV`
`@;o00001?oF_/801?l0003ogL[6omg:a_oMb/H2o`0000;oimK400Co0000ongSa_o]hlKo00000_o_
klD01?l0003okOO1o`000?oVnkX4o`0000;oWMgm1?l00003ok7>k`04o`000?njc^[o0000o`0000;o
]KcO00Ko0000okZlfol0003o0000okB^dol00004okJ]d006o`000?nfZlko0000o`000?naX/Wo0000
1?n`X<L01_l0003o[ig5o`000?l0003oZiO2o`0000CoZIG100Go0000ojNC`?nWTl3oYi?0o`000002
ojB@`0Co00000_nPRkh00ol0003oWHVnoif9_P02oif9_P05o`000?nIR;ooVHRooiV8_ol000000onF
Ql400ol0003oTHK4oi66a002oi66a005o`000?n<Q/OoS8K7ohb6aol000000on7Ql`00ol0003oPXWA
oh:9d@02oh:9d@04o`000?mmSMSoOHgHo`0000CoO9CO00Go0000ognOiomoWnOoOioWo`000004ohb^
k003o`000?nR_>coX[c/00;oX[c/00Ko0000ojRoj_l0003o0000ojRnj_l0000?ooooo`03o`000?oo
oooooooo00_ooooo000Zooooo`03o`000?oooooooooo01_ooooo0_l00003ojRoj`04o`000?nX_n_o
0000o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/01_l0003oZ;o[o`000?l0003oZ;o[o`0000Co
Z;o[1Ol00002ojRoj`03o`000?nX_n_oZ;o[00?o00001?nX_n/00ol0003oZ;o[ojRoj`03o`0000Co
[<7Y1?l000001oo;in_o0000olo^jOo?k^Wo0000om7ciol000000ooCmND00ol0003oe_KSo`000002
omSfhP04o`000?oJln3o0000o`0000;o03Rm0ol00002odYWcP03o`000?m[N]3o000000;o00000_n9
PlH4o`0000;oWIC:00?o0000ojjMaOn^WLD00on^WLD01?l0003o^Z?1okZS`Ol00003ol2]a`05o`00
0?o9/<7obK31olV``Ol000000_o@_<L01?l0003oe[k2omJn`_l00004omg:aP05o`000?oTf<Wo0000
onOFa?l000000_o]hlH01Ol0003okno5ono_aOl0003okOO100So00000onVbo<00ol0003o/Lk_ok7>
k`03o`0000Co]KcO0_l00004okB^d`04o`000?nf[M3o]Zg@okJ]d0;o00001?naX/T01?l0003o/:37
ok2Paon`X<L2o`0000CoZiO200Go0000ojVE`OnYUL7oZIG1o`000003ojNC`0?o00000_nSSKd00ol0
003oX8^noj2;_P02oj2;_P05o`000?nMRKkoWHVnoif9__l000000onIR;l01Ol0003oUXO1oiJ7`OnF
Ql7o000000CoTHK400Go0000ohb6aon<Q/OoS8K7o`000003ohN7c003o`000?n2RM7oPXWA00;oPXWA
0_l00002ogf=f003o`000?mlU=ooO9CO00;oO9CO00Go0000ognOiomoWnOoOioWo`000004ohb^k003
o`000?nR_>coX[c/00?o00001?nX_^X00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[o
oooo000Yooooo`03o`000?oooooooooo01kooooo00?o0000ojRojonX_n/00ol00004ojRoj`03o`00
0?nX_n_oZ;o[00?o00001?nX_n/00ol0003oZ;o[o`000004o`0000CoZ;o[0ol00002ojRoj`03o`00
0?nX_n_oZ;o[00;oZ;o[0ol00003ojRoj`04o`000?n/`NWo0000o`0000?oa<cQ2Ol000001?oCmNGo
0000omKfhol00002omSfhP03o`000?oJln3of_?P00Go000000?o2dg:o`000?l000000_m:Ilh00ol0
003oJg[@of]jd003o`0000;oQhW>00?o0000oifDb_nMU<X00_nMU<X00ol0003o[Yg5ojjMa@02ojjM
a@03o`000?njXl7o000000Co`:g700Co0000olV``Oo9/<7o00000oo@_<L00ol0003oe[k2o`000004
omg:aP04o`000?oTf<Woi=S9onCHb@;o000000KokN?6o`000?o_klGokno5o`000?o]ml45o`0000?o
V/Ge00?o0000ojK;lonVbo<01?l00003ojnlh`06o`000?ne_=oo0000o`000?n`[]Ko00001?nd[]<0
1_l0003o]Zg@o`000?l0003o/:?;o`0000Co/J;900Ko0000ok2Paol0003o0000ojbI`ol00004oj^G
`P03o`000?nYUL7oZIG100;oZIG10ol000000onUSkko0000oj>=_@03oj>=_@05o`000?nPRkkoX8^n
oj2;__l000000onMRKh00ol0003oVHRooiV8_`02oiV8_`03o`000?nFQl7o000002Oo00000_nR^n/0
1?l0003oZ;kZojRnj_nX_^X3o`0000kooooo00?o0000ooooooooool02_ooool002Wooooo00?o0000
ooooooooool07oooool2o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_o
Z;o[00Co00001?nX_n/01_l0003oZ;o[o`000?l0003oZ;o[o`0000CoZ;o[00Ko0000ojRojol0003o
0000ojRojol00004ojRoj`?o00000oo4c>401Ol0003of^GMom[UgOoJiMgo000000;og^[K00?o0000
on7]fOoQkMT03ol000001Ol;CL[o0000odYWc_m:Ilko000000;oJg[@00?o0000ohN9c_n7RLh00on7
RLh01Ol0003oWIC:oifDb_nMU<[o000000Co[Yg50_l00005ol2]a`03o`000?o9/<7o000000God;c7
00?o0000omg:a_oMb/H00_oMb/H00ol0003oi=S9onCHb@02onCHb@03o`000?oYi/co000000Go0000
00Gofofko`000?l0003oS[gfo`000002oi[5m@Co00000_nX^NH00ol0003o[kcSojnlh`02ojnlh`;o
00001?n`[]H01?l0003o]:kCokB^dond[]<2o`0000Co/:?;00Co0000ok6RbOnaX/Wo/J;90_l00004
ojbI``05o`000?n[Ul;oZiO2oj^G`_l000000onYUL42o`0000CoYHnn00Go0000oj>=_OnSSKgoXhfm
o`000003oj2;_P03o`000?nMRKkoWHVn00;oWHVn00?o0000oiV8_ol000000ol00002oiV7_`03o`00
0?nFQl7oUXO100;oUXO100Go0000oi>8a?nCR<CoThS4o`000003oi29b003o`000?n=S<koSHc>00;o
SHc>0_l00002ohZAe005o`000?n9V=_oRISKohVHfol000001?n;X^<00ol0003oTjkYoi>^j@02oi>^
j@03o`000?nR^n_oX[_[00Go00000_nY`>X00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00Wooooo000Yooooo`03o`000?oooooooooo023ooooo00?o0000ojRojonX_n/01?l00004ojRoj`03
o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03o`0000CoZ;o[00?o0000ojRojonX
_n/01?l00003ojRoj`04o`000?nX_n_o0000o`0000?oZ;o[00?o0000olC<hOl000000ooJiMd01?l0
003og^[KomkZfol00002on7]f@03o`000?oSk]Oo000000;oi>gE00Co0000onG/e?oUk=Co00000_oU
j=<00ol0003oi>CBo`000002o`0000;o2dg:0_l000001Om:Ilko0000of]jd?m[N]3o000000CoQhW>
00?o0000oifDb_nMU<X00_nMU<X01_l0003o[Yg5ojjMaOl0003o/jO=o`0000Ko`:g700?o0000om2l
aoo@_<L01?o@_<L2o`0000?ogL[600Go0000onCHbOoTf<Woi=S9o`000002onWVc005o`000?o[ll_o
jo?;o`000?oWnlH00ol000000on>_OKo0000o`000002o`0000;oWkGW00?o0000ojRii_nX^NH00_nX
^NH01_l0003o[kcSo`000?l0003o[:gHo`0000Co/:kF00Ko0000okB^dol0003o0000ojnTcOl00004
ok2Sb`06o`000?naX/Wo0000o`000?n/V/Co00001?n/VL<00ol0003oZiO2oj^G`P02oj^G`P?o0000
00?oYY2no`000?nUSkh00onUSkh01Ol0003oXhfmoj>=_OnSSKgo000000CoX8^n00?o0000oif9__l0
00000ol00002oi^7_@03o`000?nIQkooVHNo00;oVHNo00?o0000oiJ7`OnFQl400_nFQl401Ol0003o
ThS4oi>8a?nCR<Co000000?oT8W800?o0000ohf<c_n=S<h00_n=S<h2o`0000;oRY7D00Go0000ohVH
fon9V=_oRISKo`000004oh^Rh`03o`000?nC[^WoTjkY00Co00000_nR^nX00ol0003oZL3ZojW0jP02
ojW0jP;o00003Oooool3o`0000[ooooo000Yooooo`03o`000?oooooooooo027ooooo0_l00003ojRo
j`03o`000?nX_n_oZ;o[00;oZ;o[1?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0
003oZ;o[ojRoj`04o`0000CoZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`Co000000Gof^GMo`00
0?oNj]_og^[Ko`000002on7]f@03o`000?oSk]Oo000000;oi>gE00Co0000onG/e?oUk=Co00000_oU
j=<00ol0003oi>CBonCTdP06o`000003ocIVeOl0003o000000?oJg[@00Go0000ohN9c_n7RLkoQhW>
o`000004oifDbP03o`000?n^WLGo000000?o/jO=00?o0000ol2]aoo0[LL00_o0[LL2o`0000God;c7
00Ko0000omS:c?oHb/co0000omg:a_l00003onCHb@04o`000?oYi/cojNK<o`0000;ojo?;00?o0000
onOka_l000001?l00002oiN_i`03o`000?nO]NOoWkGW00;oWkGW00?o0000ojRii_nX^NH00ol00004
ojb]f003o`000?n`[]Ko/:kF00?o00001?n_Y<d01?l0003o/:?;ok2Sbon`Xl/2o`0000Co[9[400Go
0000ojbI`on/VL?o[9W3o`000002oj^G`P?o00001?nVT;h01Ol0003oYHnnojF?__nUSkko000000Co
Xhfm00?o0000oj2;__l000000ol00002oif8_003o`000?nKQkgoVhNm00;oVhNm00Go0000oiV7_onI
QkooVHNoo`000004oiJ7`@05o`000?nCR<CoThS4oi>8a?l000000on@RLP00ol0003oSHc>ohf<cP02
ohf<cP;o00000_n:TM@00ol0003oRISKohVHf`09o`0000;oV[3V00?o0000oj:kj_nR^nX00_nR^nX0
1_l0003oZL3Zo`000?l0003oZL7[o`0000[ooooo0ol00002ooooo`03o`000?oooooooooo00Sooooo
000Yooooo`?o00008_ooool00ol0003oZ;o[ojRoj`02ojRoj`03o`000?nX_n_o000000?o00001?nX
_n/3o`0000CoZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`03o`000?nX_n_oZ;o[00Co00000onX
_n/01?l0003oZ;o[o`000?l00003ok72iP?o000000Oog^[Ko`000?oQkMWohNgIo`000?oSk]Oo0000
00;oi>gE00Co0000onG/e?oUk=Co00000_oUj=<01?l0003oi>CBonCTd_l00002on;Nd@;o000000?o
0433o`000?l000000_lfI]D4o`0000CoQhW>00?o0000oifDb_nMU<X00ol00005ok>Wc@04o`000?o0
[LOo`:g7o`0000;oa[W>00Go0000om2laoo@_<Ood;c7o`000004omS:c005o`000?oTf<Woi=S9onCH
bOl000000_oYi/`01Ol0003ojo?;on_cbol0003oio_600?o00000_n@ZNH01Ol0003oUjoWoiN_ionG
[nOo000000;oWkGW1?l00002ojN[fP03o`000?n/[MSo[:gH00;o[:gH0ol00002ojbTc`03o`000?n_
Y<go[jC=00;o[jC=00Ko0000ok2Sbol0003o0000ojbKa_l00004ojbJa004o`000?n/VL?o[9W3ojbI
``?o00000_nXT[l00ol0003oYY2nojJ@_P02ojJ@_P03o`000?nUSkkoYHnn00;oYHnn00?o0000oj>=
_Ol000000ol00002oin9_003o`000?nMR;coWHRl00;oWHRl00Go0000oi^7_OnKQkgoVhNmo`000004
oiV7_`05o`000?nFQl7oUXO1oiJ7`Ol000000onCR<@00ol0003oT8W8oi29b00=o`0000;oUIcH00?o
0000oiJUh?nFYN000_nFYN000ol0003oV[3VoiZ`iP02oiZ`iP03o`000?nR^n[oX[_Z00?o00001?nY
`N/00ol0003oooooooooo`04ooooo`?o00001Oooool00ol0003oooooooooo`08ooooo`00:Oooool0
0ol0003oooooooooo`0Sooooo`03o`000?nX_n_oZ;o[00Co00000onX_n/01?l0003oZ;o[o`000?l0
0002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0ol00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0ol0
0003ojRoj`03o`000?nX_n_oZ;o[00Co00000ona`^H01?l0003ocLgIolg=fOo=cMT=o`000005onGX
dol0003oi>CBonCTd_l000000_oRg]401_l0003ogmO@o`000?l0003o0433o`0000;o=VKE00?o0000
of1nf_mPO]X02?l00002oinNd`03o`000?ncYlgo/jO=00?o/jO=00?o0000ol2]aol000001?o6^Lh0
0ol0003od;c7o`000004omS:c005o`000?oNf];o0000onCHbOl000000ooYi/`01?l0003ojo?;o`00
0?oWnlH3o`0000;oT:WV2?l00002oj6Xf`03o`000?nWZm[oYj_J00;oYj_J00Ko0000ojb]f?l0003o
0000ojVSd?l00004ojbTc`04o`000?n_Y<go[jC=ojnTc@;o00001?n/VlH01_l0003o[9[4ojbJa?n/
V/Co0000ojbI``;o000000?oZ9C0o`000?nXT[l00onXT[l01Ol0003oYY2nojJ@__nVT;ko000000?o
YHnn0ol00002oj6;_003o`000?nORKcoWhVl00;oWhVl00Go0000oif8_?nMR;coWHRlo`000003oi^7
_@03o`000?nIQkooVHNo00;oVHNo00?o0000oiJ7`OnFQl402?l00002oiN<aP03o`000?nFT<_oUY3;
00;oUY3;00Go0000oiFEdOl0003oUIGAo`000004oiFLf003o`000?nFYN3oUZGP00;oUZGP00?o0000
oiZ`i_nJ/>H01?l00003ojFljP03o`000?nY`N_oZL7[00?o000000?oooooo`000?l000000_l00008
ooooo`03o`000?oooooooooo00Sooooo00000ol0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`Go00001Ooo
ool00ol0003oooooooooo`0Uooooo`?o00000onX_n/00ol0003oZ;o[ojRoj`03o`0000CoZ;o[00Ko
0000ojRojol0003o0000ojRojol00004ojRoj`06o`000?nX_n_o0000o`000?nX_n_o00001?nX_n/3
o`0000CoZ;o[00?o0000ok72i_l000000oo=cMT01ol0003oi>CBonCTd_oTi=;o0000onOVd?l00000
0_oXi/h01Ol0003ojNG<onWUc?l0003ojN?;00Go000000Coh]kAo`000?oOem3ogmO@0ol000001Ol0
@<?o0000o`000?lfI]Go000000;oH7kJ00Go0000ohBAf?n4TMSoQ97Ho`000005oinNd`03o`000?nc
Ylgo/jO=00;o/jO=0_l00005olJicP;o00001?oHb/`01?l0003og][BomkJd_oNf]83o`000003onWV
c?l0003ojo?;00?o000000?oa?^jo`000?l000000_l00002oiNOfP05o`000?nKY=_oVjCKoi^Tfol0
00001?nQZ=/00ol0003oYj_JojN[fP03o`0000CoZJ?@00Ko0000ojbTcon/Y<oo[:C?o`000?n_Y<d2
o`000003oj^Laol0003o[9_600?o[9_600Co0000ojbJa?n/V/Co[9[40_l00004ojRD`005o`000?nX
T[ooZ9:oojRB_ol000001?nVT;h3o`000003oj><_?l0003oXH^l00?oXH^l00Go0000oin9_?nORKco
WhVlo`000003oif8_003o`000?nKQkgoVhNm00;oVhNm00?o0000oiV7_onIQkl01?l00002oiZ8_`05
o`000?nIR/;oVH[2oiV:`_l000001?nGS<H00ol0003oUY3;oiJ@b`02oiJ@b`05o`000?nEUM7o0000
oiFEdOl000000onEW=P00ol0003oUZGPoiJUh005o`0000;oX[GV00Co0000ojFlj_nU_>[oYKcZ1?l0
0003ojRoj`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00003oooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo02;o
oooo0ol00002ooooo`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03o`0000Co
Z;o[00?o0000ojRojonX_n/01?l00003ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o0000ojRo
jonX_n/00_nX_n/2o`0000?ocLgI00Oo0000onCTd_oTi=;oi>CBo`000?oWi]3o000000;oj>K>00Co
0000onWUc?oYiLco00000_oYhl/01Ol0003oj>3;onSPbol0003oi]c:00;o000000?ogmO@o`000?oK
d<h00_oKd<h2o`000003oaMRf?l0003o000000?oH7kJ00Go0000ohBAf?n4TMSoQ97Ho`000004oinN
d`03o`000?ncYlgo/jO=00;o000000?o^;GFo`000?o6^Lh00oo6^Lh00ol0003oc/WFo`000003omS:
c005o`000?oNf];og][BomkJd_l000000_oSj]H6o`000003olCk^_l0003oTi_H00;oTi_H00Go0000
oiNOf_nGWm[oUioJo`000003oi^Tf`03o`000?nQZ=_oXJSK00Co00000_nUXM400ol0003oZJ?@ojVS
d002ojVSd003o`000?n/Y<oo[:C?00?o00001?n[W<L01_l0003o[9_6ojbKa_n/VlKo0000ojbJa0;o
000000?oZIG1o`000?nXU<000onXU<001Ol0003oZ9:oojRB_onXT[oo000000;oYY2n0ol00003oj><
_003o`000?nQRkcoXH^l00;oXH^l00Go0000oin9_?nORKcoWhVlo`000004oif8_003o`000?nKQkgo
000000Co00000_nKQkd00ol0003oVXRooiZ8_`02oiZ8_`05o`000?nIR/;oVH[2oiV:`_l000000onG
S<H00ol0003oUY3;oiJ@b`02oiJ@b`05o`000?nEUM7o0000oiFEdOl000000_nEW=P4o`0000?oX:gP
00?o0000oj:ei_nR]NH01Ol00002ojRoj`04o`000?nX_n_oZ;o[ojRoj`?o00003?ooool00ol0003o
ooooooooo`07ooooo`000_ooool00ol@413oooooooooo`09ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00Cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0
003oooooooooo`0Oooooo`?o00001_ooool2o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRo
j`03o`000?nX_n_oZ;o[00Co00001?nX_n/00ol0003oZ;o[ojRoj`03o`0000CoZ;o[00Co0000ojRo
jol0003o00000_nX_n/00ol0003ocLgIo`000003onCTdP03o`000?oWi]3o000000;oj>K>00Co0000
onWUc?oYiLco00000_oYhl/01?l0003oj>3;onSPbol00002onKLbP04o`000?oTelWo0000o`0000?o
fm3>0ol000000olGH]So0000of1nfP03of1nfP05o`000?n4TMSoQ97HohBAf?l000000onOW]<00ol0
003o/jO=o`000004okReeP04o`000?o6^Lkoa[W>o`0000?oc/WF00?o0000omS:c?l000000ooNf]80
1?l0003ohn[Fon?Ze_l00002on?he@07o`000?oIolco0000olCk^_l0003oTIOFo`000003oi>Kf004
o`000?nGWm[oUioJo`0000;oVjCK1?l00002oj6NdP03o`000?nUXM7oYJ7A00;oYJ7A00Co0000ojVS
d?nYXm3oZJ?@0ol00002ojVLb@03o`000?n[W<OoZic700;oZic700Co0000ojbKa_n/VlKo[9_60_l0
0004ojVE`@05o`000?nXU<3oZ9C0ojRD`?l000000onXT[l3o`0000;oY8fl00?o0000oj><_?nSS;`0
0_nSS;`01Ol0003oXH^loj6;_?nQRkco000000CoWhVl00?o0000oif8_?l000000ol00002oif7_003
o`000?nKQkgoVhNm00?oVhNm00Go0000oiZ8_onJR;ooVXRoo`000003oiV:`P05o`000?nGS<KoUhc6
oiN<a_l000000onFT</8o`0000;oWjGJ00?o0000oj2]h?nP[N000_nP[N03o`0000;oZ;o[00?o0000
ojRojonX_n/00_nX_n/4o`0000;oZ;o[00?o0000ooooooooool02_ooool00ol0003oooooooooo`07
ooooo`000_ooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000Gooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003ooooooooo
o`0Looooo`?o00002_ooool01?l0003oZ;o[ojRojonX_n/3o`0000CoZ;o[00?o0000ojRojonX_n/0
0ol00004ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03o`0000CoZ;o[
1?l000001?oTi=;o0000onOVd?l00003onSVcP06o`000?oYiLcojNG<o`000?oYhl_o00000_oXh</0
1?l0003oi]c:onKLb_l00002onCGb@05o`000?oPdLSo0000om_@c_l000000_oFb<`2o`000003oaMR
f?l0003o000000?o00000on4TMP00ol0003oWikCoinNd`03o`0000Go^;GF00?o0000olJic_l00000
1?o>bMH4o`000005omkJd_l0003ohn[Fon?Ze_l000000_oSn=D01Ol0003ofOo<o`000?o4nk[o0000
00;oTIOF00?o0000oi>Kf?nCVmP01ol00002oifKdP03o`000?nQW];oXIkB00;oXIkB00Ko0000ojFQ
dOnUXM7oYJ7Ao`000?nYXm02o`000003ojNKb_l0003oZIc900?oZIc900Ko0000oj^Laon[W<OoZic7
o`000?n/VlH2o`000003ojRF`ol0003oZIG100?oZIG100?o0000ojRD`?nXU<000_nXU<03o`000003
ojF?_Ol0003oY8fl00?oY8fl00Go0000oj><_?nSS;coXhblo`000004oj6;_003o`000?nORKco0000
00?o00000_nNR;/00ol0003oWHNloif7_002oif7_003o`000?nKQkgoVhNm00;oVhNm00Go0000oiZ8
_onJR;ooVXRoo`000003oiV:`P03o`000?nGS<KoUhc600Go00000_nNVLl00ol0003oWYkDoijNe002
o`0000CoWjGJ00Ko0000oj2]h?l0003o0000ojRojol00004ojRoj`06o`000?nX_n_o0000o`000?nX
_n_o00001?nX_n/2o`0000_ooooo00?o0000ooooooooool01oooool000;ooooo00?o0000oooooooo
ool02Oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006
ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool06Oooool3o`0000kooooo00?o0000
ojRojol000000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`?o00000_nX_n/00ol0003oZ;o[ojRoj`02
ojRoj`?o00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00Co0000ojRojol0003o00001?nb
`^H5o`000007onSVc_l0003ojNG<onWUc?l0003ojN?;o`000003onSPb`03o`000?oVg<[o000000;o
i=O900Go0000on3Ab?oPdLSoh=78o`000003omK8c0Go00000_m?Q>D7o`0000?oXJcO00?o0000okRe
e_nh]MH00_nh]MH3o`0000?oc/WF00Co0000omCLg_oDg=koe=cN0ol000001_oSj]Ko0000on?heOoS
n=Go0000omWoc0Wo00000_nGULl01?l0003oVYSAoiZHdOl00004oifKdP05o`000?nQW];oXIkBoj6N
d_l000000_nUXM43o`0000CoYi_:00Go0000ojVLbOnYW<WoZIc9o`000002oj^La`?o00001?nXU/<0
1Ol0003oZIG1ojVE`OnYUL7o000000?oZ9C00_l00004ojF?_@05o`000?nTSKcoY8flojB=_?l00000
0onSS;`01?l0003oXH^loj6;_?nQRk`3o`0000;oWhRk00?o0000oij8^onNR;/00_nNR;/01Ol0003o
WHNloif7_?nMQkco000000CoVhNm00?o0000oiZ8_onJR;l00_nJR;l00ol0003oVH[2o`000003o`00
00;oWYK;00?o0000oijIconNVLl00_nNVLl01?l0003oWYkDoijNe?nNW]@2o`0000;oWjGJ0ol00004
ojRoj`03o`000?nX_n_oZ;o[00?o00001?nX_n/01_l0003oZ;o[o`000?l0003oZ;o[o`0000_ooooo
00?o0000ooooooooool01oooool000;ooooo00?o410@ooooooooool02Oooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo00?o
oooo0_l0000Gooooo`?o00004_ooool00ol0003oZ;o[ojRoj`02ojRoj`06o`000?nX_n_o0000o`00
0?nX_n_o00001?nX_n/01_l0003oZ;o[o`000?l0003oZ;o[o`0000CoZ;o[0ol00003ojRoj`03o`00
0?nX_n_oZ;o[00?o00001Onb`^H01?l0003oc/ODolk7e?l00002onSQc0So000000Coj>3;o`000?oV
g<[o00000_oTelT00ol0003oh=78on3Ab002on3Ab0;o000000Koe/S<o`000?oA`<[odL3:o`000?l0
Ell2o`0000;oChCU00Go0000ogjMi_mnWNKoOYgVo`000005oj6/g`04o`000?nh]MKo0000o`0000?o
_LKQ00?o0000olk9e_l000000ooDg=h01?l0003oenoSomO_hooGkn<7o`0000;oUY3<00Go0000oiJB
c_nFT/koUY;>o`000004oiNEc`04o`000?nJV=7oVYSAo`0000?oWI_B00?o0000oj6Nd_nQW]801?l0
0002ojBJb`03o`000?nWVl[oYi_:00;oYi_:00Co0000ojVLbOnYW<WoZIc90ol00002ojRFa003o`00
0?nXU/?oZ9K300;oZ9K300?o0000ojVE`OnYUL400_nYUL43o`000003ojJ@__l0003oYHnm00?oYHnm
00Go0000ojB=_?nTSKcoY8flo`000004oj><_0?o000000?oXHVko`000?nOR;/00_nOR;/00ol0003o
WXRkoij8^`02oij8^`05o`000?nMQkcoWHNloif7_?l000001OnKQkd00ol0003oVXRoo`000003o`00
00;oWi?700?o0000oijFbonNU//00_nNU//00ol0003oWYW?oijIc`02oijIc`03o`000?nNW]CoWYkD
00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00004ojRo
j`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00003oooooonHV9SoMgMg00_o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool05?ooool2o`0001Kooooo00?o
0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/01?l0003oZ;o[o`00
0?l00002ojRoj`04o`000?nX_n_oZ;o[ojRoj`?o00000onX_n/01Ol0003o//;Vok;2i_nb`^Ko0000
00;oc/OD00Go0000onSQc?oXhLcoj>7<o`000002onWQb@03o`000?oZh<So000000;ojMk71?l00000
0ooTelWo0000on3Ab003on3Ab004o`000?oLblSog<_8o`0000?odL3:0_l00002o`1Gc`;o000000?o
ChCUo`000?mnWNH00_mnWNH00ol0003oXJcOoj6/g`02oj6/g`;o00001Onma^42o`0000?oe=cN00So
0000omO_hooGkn?oenoSo`000?o@o>7o0000okcmd0?o00001?nFT<`01Ol0003oUY;>oiJBc_nFT/ko
000000?oUiG?00Co0000oiZHdOnJV=7o00000_nMVm84o`0000;oXIS;00?o0000ojBJbonTV//00_nT
V//01_l0003oYi_:ojNKb_nWVl[o0000ojVLb@;o000000?oYYK5o`000?nXU/@00onXU/@01Ol0003o
Z9K3ojRF`onXU/?o000000;oZIG10ol00004ojJ@_P05o`000?nUSkgoYHnmojF?_Ol000001?nTSK`0
0ol0003oXhblo`000002o`0000?oXHVk00?o0000oin8^onOR;/00_nOR;/01Ol0003oWXRkoij8^onN
R;_o000000CoWHNl00?o0000oi^7_OnKQkd01?l00002oinAa@03o`000?nOTlOoWi?700;oWi?700Go
0000oijFbonNU/_oWYK;o`000003oijIc`Co000000?oZ;o[o`000?l000000onX_n/4o`0000?oZ;o[
00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00?o00002Oooool00ol0003ooooo
ooooo`07ooooo`0000?o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool00ol0
003oooooooooo`0Booooo`?o00006Oooool2o`0000CoZ;o[00?o0000ojRojonX_n/00ol00004ojRo
j`03o`000?nX_n_oZ;o[00?o00001?nX_n/00ol0003oZ;o[o`000002ojRoj`03o`000?nX_n_oZ;o[
00;oZ;o[00?o0000ok;2i_l000000_o>am@01Ol0003oj>7<onSQc?oXhLco000000;ojN7900?o0000
on[Pb?l000000ooYg/L01?l0003oj=_6o`000?oVelH2o`0000?oh=7800Co0000omc;b?oLblSog<_8
0_l000001?oA`<[o0000olbhaoo<^<L3o`000003oc67k?l0003o000000?oOYgV00?o0000oj6/gol0
00000_l000000onQ_^ko0000okg6h@02okg6h@;o00000_o0fnd00ol0003oe=cNo`000003omO_h`04
o`000?o@o>7o0000okcmd0;o00000_nGSlT01Ol0003oUY3<oiJ@c?nFT<co000000?oUY;>00?o0000
oiNEconGULl01ol00002oijFb`03o`000?nQV<_oXIS;00;oXIS;00Go0000ojBJbonTV/_oY9[;o`00
0002ojNKbP?o00001?nVU/D01Ol0003oZ9K4ojRFa?nXU/Co000000?oZ9K30ol00002ojJA_`03o`00
0?nVT;koYY2n00;oYY2n00?o0000ojF?_OnUSkd00_nUSkd00ol0003oY8flo`000003o`0000;oXXZk
00?o0000oj69^onQRK/00_nQRK/01Ol0003oWhRkoin8^onOR;_o000000CoWXRk00?o0000oif7_?l0
00001?l00002oj2?``03o`000?nOTLGoWi7500;oWi7500Go0000oinCaonOTlOoWi?7o`000003oijF
b`06o`000?nNVLoo0000o`000?nX_n_o00001?nX_n/4o`0000;oZ;o[00Co0000ojRojonX_n_oZ;o[
1?l00002ojRoj`04o`000?nX_n_oZ;o[ojRoj`Co00000onX_n/00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Oooooo000Wooooo`03o`000?oooooooooo00oooooo0ol0000Nooooo`03o`00
0?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/0
0ol00004ojRoj`03o`000?nX_n_oZ;o[00?o00000oo>am@01?l0003oj>7<onSQc?l00002onWQb@03
o`000?oZh<So000000?ojMk700?o0000onSKa_l000000_oVelH01Ol0003oi=;6o`000?oPdLSo0000
00?og<_800Co0000omO4aooGa<Oo00001?o<^<L3o`0000;o<HO/1_l00004oj6nkP03o`000?nma^7o
000000Co`=_]1?l000000ooGkn?o0000om3lh@04o`0000?oUho900Go0000oiJ@c?nFT<coUY3<o`00
0002oiJBcPCo00000_nJTLT01?l0003oW9?:oibCb_l00004oijFb`05o`000?nQV<_oXIS;oj6Hbol0
00000_nTV//4o`0000;oYIK600?o0000ojJFaOnVU/D00_nVU/D01_l0003oZ9K4ojRFa?nXU/Co0000
ojRF``;o000000?oYY;0o`000?nVTKl00onVTKl01Ol0003oYY2nojJ@__nVT;ko000000?oYHnm0ol0
0002oj>;^`03o`000?nRR[_oXXZk00;oXXZk00Go0000oj69^onQRK_oXHVko`000003oin8^`04o`00
0?nNR;_oWXRkoij8^`?o00000_nPSl800ol0003oX8o3oj2?``03oj2?``05o`000?nOTLGoWi75oinA
aOl000000onOTlL00ol0003oWYK;oijFb`03o`0000CoZ;o[00Ko0000ojRojol0003o0000ojRojol0
0004ojRoj`Co00000_nX_n/01?l0003oZ;o[ojRojonX_n/4o`0000;oZ;o[00Co0000ojRojonX_n_o
Z;o[0ol00007ooooo`03o`000?oooooooooo00Oooooo000Wooooo`03o`000?oooooooooo00cooooo
0ol0000Rooooo`;o00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/0
1?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oc/ODo`000002onSQc004o`00
0?oYhLWojN79o`0000;oj^3800Ko0000onWNaooYg/Oo0000onSKa_l00002onKGaP05o`000?oTd/Ko
i=;6onCBa_l000000ooLblP01Ol0003oelC7omO4aooGa<Oo000000?oc;S700Co0000olJaaOl0003o
_jc71Ol00003og>[m003o`000?nQ_^koXKk^00Co00000oo0fnd01?l0003o_>ocokc_lonlko<5o`00
00;oVHo800?o0000oiN?bOnGSlT02?l00002oiV>a`03o`000?nJTLWoVY7900;oVY7900Co0000oibC
b_nLTl[o00000onNU//00ol0003oXIS;oj6Hb`04o`0000;oXiC600?o0000ojFFa_nUU/H00_nUU/H0
1Ol0003oYYK5ojJFaOnVU/Go000000;oZ9K40ol00004ojJB`005o`000?nVTKooYY6oojJA_ol00000
1?nVT;h3o`000003oj><_?l0003oXh^k00?oXh^k00Go0000oj::^onRR[_oXXZko`000003oj69^`03
o`000?nOR;_oWhRk00;oWhRk0ol000000onQS/7o0000oj2?`P03oj2?`P03o`000?nPSl?oX8o300;o
X8o300Go0000oinAaOnOTLGoWi75o`000002oinCa`Co00000onX_n/00ol0003oZ;o[ojRoj`03o`00
00?oZ;o[0_l000001OnX_n_o0000o`000?nX_n_o000000GoZ;o[0ol000000onX_n_o0000ojRoj`03
ojRoj`Co00000_nX_n/00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo000Woooo
o`03o`000?oooooooooo00Wooooo0ol0000Uooooo`03o`000?nX_n_oZ;o[00;oZ;o[0ol00003ojRo
j`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRo
jonX_n/01ol000001OoYhLWo0000on[Pb?oZh<So000000;ojMk700Ko0000onSKa_oXflKo0000onKG
a_l00004onCBaP;o000000?og<_8o`000?oGa<L00_oGa<L01Ol0003od[g6o`000?o<^<Oo000000?o
a[7500Go0000okn/aol0003o0000o`Aog`07o`0000CoVm;k00?o0000ol3KkOl000000_nlko<2o`00
0003ojWgjOl0003oPnS800Oo00000_nIS<@01Ol0003oVHg6oiV=a_nISLKo000000CoVHk700Go0000
oiZAbOnJTLWoVY79o`000003oibCbP03o`000?nNU/_oWYK;00?o00000_nQTlH00ol0003oXiC6oj>D
aP02oj>DaP05o`000?nUU/KoYIK6ojFFa_l000000onVU/D3o`0000;oYI;100?o0000ojJB`?nVT/00
0_nVT/001Ol0003oYY6oojJA_onVTKoo000000;oYY2n0ol00003oj><_003o`000?nSRk_oXh^k00;o
Xh^k00Go0000oj::^onRR[_oXXZko`000004oj69^`03o`000?nOR;_o000000;o00001?nQS/401Ol0
003oX8o2oj2?`_nPSl;o000000CoX8o300?o0000oinAaOnOTLD01?l00003ojRoj`03o`000?nX_n_o
Z;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03o`0000CoZ;o[00?o0000ojRojonX_n/00ol00004
ojRoj`06o`000?nX_n_o0000o`000?nX_n_o00001?nX_n/2o`0000Oooooo00?o0000ooooooooool0
1_ooool002Oooooo00?o0000ooooooooool01_ooool3o`0002Wooooo00Co0000ojRojol0003o0000
0_nX_n/01?l0003oZ;o[ojRojonX_n/3o`0000?oZ;o[00Co0000ojRojonX_n_oZ;o[0ol00004ojRo
j`03o`000?nX_n_oZ;o[00?o00000on/`>T01?l0003oblGDol_5e?o;aM@8o`000005onSKa_l0003o
i]O6onKGa_l000000ooTd/H01?l0003oh<g5on3=aOl00003omO4a`05o`000?oB_LKod[g6om:ma_l0
00001Oo6/LD00ol0003o^ZG4okZUa004o`0000CoF[Kl00?o0000oi_BnonKd_/01?l000001?nlko?o
0000ojWgjOnYmnT3o`0000;oWHc200Co0000oi^<`onKS<?o00001?nIS<@01Ol0003oVHg6oiV=a_nI
SLKo000000?oVHk700Go0000oiZAbOnJTLWoVY79o`000002oibCbPCo000000?oWi76o`000?nQTlH0
0onQTlH01Ol0003oXiC6oj>Da_nSU<Ko000000?oYIK600Ko0000ojJFaOl0003o0000ojFB`_l00004
ojFB`@05o`000?nVT/3oYY;0ojJB`?l000000onVTKl3o`0000;oY8fm00?o0000oj><_?nSS;`00_nS
S;`01Ol0003oXh^koj>;^onSRk_o000000CoXXZk00?o0000oj69^ol000000ol00002oj6?`@03o`00
0?nQS/7oXHk100;oXHk100?o0000oj2?`_nPSl800_nPSl801?l0003oX8o3oj2?`onPSl<3o`0000?o
Z;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/2o`0000;o
Z;o[1?l00003ojRoj`03o`000?nX_n_oZ;o[00?o00001?nX_n/01_l0003oZ;o[o`000?l0003oZ;o[
o`0000Oooooo00?o0000ooooooooool01_ooool002Oooooo00?o0000ooooooooool00oooool3o`00
02gooooo0_l00004ojRoj`03o`000?nX_n_o000000;oZ;o[00?o0000ojRojonX_n/00_nX_n/00ol0
003oZ;o[o`000002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0ol00003ojRoj`03o`000?n/`>Wo0000
00CoblGD00Co0000on?Ic?oSfLco00000_oXg<P01_l0003oj=[7o`000?l0003oi]O6o`0000?oi=;6
00Co0000on3=aOoPcLGoh<g50_l000000ooGa<Oo0000om:maP03om:maP03o`000?o6/LGoa[7500;o
a[750_l00004okZUa0Wo00000_n7h?`8o`0000CoWHc200Co0000oi^<`onKS<?o00000onIS<@01Ol0
003oVHg6oiV=a_nISLKo000000?oVHk700?o0000oiZAbOnJTLT01?l00002oif?a@05o`000?nOTLKo
Wi76oinAa_l000000onQTlH01Ol0003oXiC6oj>Da_nSU<Ko000000;oYIK60ol00004ojFB`P05o`00
0?nUT/7oYI;1ojFB`Ol000001?nVT/03o`000003ojB>__l0003oY8fm00?oY8fm00Go0000oj><_?nS
S;coXhblo`000004oj>;^`03o`000?nRR[_o000000?o00000_nRSl400ol0003oXHo1oj6?`@02oj6?
`@05o`000?nQS/7oXHk1oj6>`Ol000001?nPSl801_l0003oX8o3o`000?l0003oZ;o[o`0000CoZ;o[
0ol00002ojRoj`04o`000?nX_n_oZ;o[ojRoj`Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?o
Z;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00?o00001?nX_n/00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Kooooo000Vooooo`?o000000Coooooo`000?l0003o
0000<_ooool00ol0003oZ;o[ojRoj`03o`0000CoZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`06
o`000?nX_n_o0000o`000?nX_n_o00001?nX_n/2o`0000CoblGD00Co0000on?Ic?oSfLco00000_oX
g<P01Ol0003oj=[7onSJaol0003oimO600?o000000?oi=;6o`000?oPcLD00_oPcLD00ol0003og<O5
omc7a@02o`0000?od[g600?o0000olfga?l000000_o6/LD01?l0003o`J_3ol6[`ol00003okZUa0;o
00000_n`Vl8;o`0000CoX8k100Go0000oif<`_nMS<;oWHc2o`000002oi^<``05o`000?nIS<CoVHc4
oiV<a?l000000onISLH00ol0003oVHk7oiV>a`04o`0000;oW8k400?o0000oif?aOnMSlD00_nMSlD0
1?l0003oWi76oinAa_l00003oj6CaP03o`000?nSU<KoXiC600Co00000_nTT/<00ol0003oYI;2ojFB
`P02ojFB`P05o`000?nUT/7oYI;1ojFB`Ol000000_nVT/03o`0000CoY8jn00Go0000ojB=_OnTSKgo
Y8fmo`000003oj><_004o`000?nSRk_oXh^koj>;^`?o00000_nST<400ol0003oXXo1oj:?`@02oj:?
`@05o`000?nQSl7oXHo1oj6?`Ol000001?nQS/400ol0003oX8o2oj2?`P03o`0000CoZ;o[1?l00000
0onX_n_o0000ojRoj`02ojRoj`Co00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`?o000000?oZ;o[
o`000?l000000onX_n/4o`0000;oZ;o[00Co0000ojRojonX_n_oZ;o[1?l00002ojRoj`04o`000?nX
_n_oZ;o[ojRoj`?o00001Oooool00ol0003oooooooooo`06ooooo`009_ooool4o`0003Kooooo0_l0
0003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03o`0000CoZ;o[00Ko
0000ojRojol0003o0000ojRojol00003ol_5e004o`000?oSfLcohmW<o`0000;oj=c800Co0000onSJ
aooXf/Oo00000_oWelH01?l0003oiMC5onGDaOl00003on3=a@09o`000?oLalGog<O5omc7aOl0003o
el;5o`000?oB_LKo000000;ocKO400?o0000olJaaOl000000oo1Zl<01_l0003o^ZG4o`000?l0003o
]Yo2o`0000Co/9_200?o0000ojZG`_nZUl800ol00003ojB@`005o`000?nPS/7oX8k1oj2>`Ol00000
0onMS<801?l0003oVhc3oi^<`ol00002oiV<a0So00000_nKS<<00ol0003oW8k4oib>a002oib>a005
o`000?nMSlGoWHo5oif?aOl000000_nOTLH00ol0003oXI?6oj6CaP04o`0000;oXY7300?o0000ojBB
`onTT/<00_nTT/<01Ol0003oYI;2ojFB`_nUT/;o000000?oYI;10ol00002ojB?_`03o`000?nTS[ko
Y8jn00;oY8jn00Go0000ojB=_OnTSKgoY8fmo`000004oj><_0?o000000?oXi71o`000?nST<400onS
T<401Ol0003oXXo1oj:?`OnRSl7o000000?oXHo100?o0000oj6>`OnQS/401Ol00002ojRoj`03o`00
0?nX_n_oZ;o[00?o00001OnX_n/3o`000003ojRojol0003oZ;o[00CoZ;o[1?l000000onX_n_o0000
ojRoj`02ojRoj`Co00000_nX_n/00ol0003oZ;o[ojRoj`05o`0000;oZ;o[00?o0000ojRojonX_n/0
1Ol00002ojRoj`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool002Kooooo0_l0
000jooooo`03o`000?nX_n_oZ;o[00?o00001?nX_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o
0000ojRojonX_n/01?l00003ojRoj`03o`000?o;aMCo000000?ohmW<00?o0000onSLb?l000000_oX
f/L01?l0003oimO6onOGa_l00003onGDa@;o000000?oh<g5o`000?oLalD00_oLalD01Ol0003oel;5
omO2aOoG`/Go000000CocKO400?o0000ol6[`oo1Zl<00oo1Zl<00ol0003o]Yo2okJO`P02okJO`P04
o`000?n`Vl;o/9_2ok2K`P?o00000_nXTkl01Ol0003oY930ojB@`?nTT<3o000000?oX8k100?o0000
oif<`_nMS<800_nMS<800ol0003oVhc3o`000002o`0000;oVh[100Go0000oi^;`_nKRl;oVh_2o`00
0004oi^<``05o`000?nLS/CoW8k4oib>a?l000000onMSlD00ol0003oWi76oinAaP03o`0000;oXI33
00?o0000oj:A`onRTL<00_nRTL<01Ol0003oY9;3ojBB`onTT/?o000000CoYI;20ol000000onTSl3o
0000ojB?_`03ojB?_`05o`000?nTS[koY8jnojB>__l000001?nTSKd00ol0003oXhblo`000002o`00
00CoXi7100Go0000oj>@`OnST<7oXi31o`000003oj:?`@03o`000?nQSl7oXHo100Co00000onX_n/0
0ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`03o`000?nX_n_o
Z;o[00?o00001OnX_n/3o`000003ojRojol0003oZ;o[00?oZ;o[0ol00003ojRoj`03o`000?nX_n_o
Z;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03o`0000Cooooo00?o0000ooooooooool01_ooool0
02Sooooo00?o0000ooooooooool0>?ooool2o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRo
j`03o`000?nX_n_oZ;o[00?o00001?nX_n/00ol0003oZ;o[ojRoj`04o`000004on?Ic?l0003oj=c8
o`0000?oj=[700?o0000onOGa_l000000ooUe<D01?l0003oh]35on;@aOl00003omc7a@03o`000?oG
`/Goel;500;oel;500Oo0000olfga?o=]lCocKO4o`000?o7/<?o000000?o`J_30_l00004okJO`P06
o`000?n`Vl;o0000o`000?n]U[oo00001?nXTkl01?l0003oY930ojB@`?l00004oj2>`@03o`000?nM
S<;o000000?o000000?oW8Zoo`000?nKR/400onKR/401Ol0003oVh_2oi^;`_nKRl;o000000?oVhc3
00Go0000oib>a?nLS/CoW8k4o`000002oif?a@Co000000?oWho2o`000?nQT<<00onQT<<01Ol0003o
XY73oj:A`onRTL?o000000?oY9;300?o0000ojFB`_nUT/800ol00004ojB?`005o`000?nTSkooY8no
ojB?_ol000001?nTS[h00ol0003oY8fmo`000003o`0000;oXi7200?o0000oj>A`OnSTL400_nSTL40
1Ol0003oXi31oj>@`OnST<7o000000?oXXo10ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX
_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX
_n_oZ;o[00?o00000onX_n/2o`000005ojRojol0003o0000ojRojol000001?nX_n/3o`0000?oZ;o[
00?o0000ojRojonX_n/01?l00003ojRoj`05o`000?ooooooooooooooool000002?ooool002Wooooo
00?o0000ooooooooool0=oooool00ol0003oZ;o[ojRoj`02ojRoj`?o00000onX_n/00ol0003oZ;o[
ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`Ko000000Goj=[7o`000?oWelKo
imO6o`000002onGDa@04o`000?oRd<Goh]35on;@a@;o000000?og<O5o`000?oG`/D00ooG`/D01Ol0
003od[c4o`000?o=]lCo000000?oak3300?o0000ol6[`ol000000_nlYL801?l0003o]Yo2okJO`_nf
Wl82o`0000Co[IJo00Go0000ojRC_onXTkooZ9>oo`000003ojB@`003o`000?nPS/7o000000?o0000
0_nNR[h01Ol0003oW8Zooib:_onLR[oo000000?oVh[100Go0000oi^;`_nKRl;oVh_2o`000003oi^<
``03o`000?nLS/CoW8k400Co00000_nNSL801Ol0003oWho2oin?`_nOSl;o000000?oXI3300Go0000
oj:A`onRTL?oXY73o`000002ojBB``Co00000_nST<000ol0003oY8o0ojB?`002ojB?`005o`000?nT
SkooY8noojB?_ol000000onTS[h3o`0000;oY9;300?o0000oj>A`_nSTL800_nSTL801Ol0003oXi71
oj>A`OnSTL7o000000CoXi310ol000000onX_n_o0000ojRoj`03ojRoj`?o00000onX_n/00ol0003o
Z;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co
00000onX_n/00ol0003oZ;o[ojRoj`03o`0000CoZ;o[00Ko0000ojRojol0003o0000ojRojol00004
ojRoj`?o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`;o00000oooool00ol0003oooooooooo`05
ooooo`00:_ooool00ol0003oooooooooo`0gooooo`06o`000?nX_n_o0000o`000?nX_n_o00001?nX
_n/3o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`04o`000?nX_n_o0000o`0000?o`lCK
00?o0000omS>cooHc/l00_l000000ooWelKo0000onGDa@02onGDa@04o`000?oRd<Goh]35o`0000;o
gl_50_l00003omO2a@05o`000?oB_<Cod[c4om:la?l000001Oo7/<<01Ol0003o_:G2okbU`_nlYL;o
000000;o]Yo200?o0000ok:K`?l000001?n]U[l01Ol0003oZ9>oojRC_onXTkoo000000;oY9300ol0
0002oj2;_P03o`000?nNR[koWXZn00;oWXZn00Go0000oib:_onLR[ooW8Zoo`000002oi^:`@05o`00
0?nKRl;oVh_2oi^;`_l000000_nKS<<4o`0000;oWHc100?o0000oij=`_nNSL800_nNSL801?l0003o
Who2oin?`_l00003oj6@``03o`000?nRTL?oXY7300Co00000_nST<400ol0003oXi30oj>@`002oj>@
`005o`000?nTSl3oY8o0ojB?`?l000001?nTSkl3o`000003ojBCa?l0003oY9;300?oY9;300Go0000
oj>A`_nSTL;oXi72o`000004oj>A`@03o`000?nST<7o000000;o00001?nX_n/01_l0003oZ;o[o`00
0?l0003oZ;o[o`0000CoZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003o
Z;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`;o00000_nX_n/3o`0000Co
Z;o[00Ko0000ojRojol0003o0000ojRojol00004ojRoj`06o`000?nX_n_o0000o`000?nX_n_o0000
0oooool00ol0003oooooooooo`05ooooo`00:oooool2o`0003Sooooo0_l00003ojRoj`04o`000?nX
_n_o0000o`0000;oZ;o[00Co0000ojRojonX_n_oZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00Co
00000oo3a=/01_l0003of<k?omS>cooHc/oo0000onCHbP?o000000GoiMC5o`000?oRd<Goh]35o`00
0003omo;a@05o`000?oKa/Go0000omO2aOl000001?oB_<@00ol0003oak33olN```02olN```;o0000
0onlYL800ol0003o]Yo2o`000003ok:K`005o`000?n]U[oo[IJoojfF_ol000000onXTkl3o`000003
oj>=_Ol0003oX8^n00?oX8^n00Go0000oij:__nNR[koWXZno`000003oib:_`06o`000?nKR/7oVh[1
oi^:`Ol0003oVh_21?l00002oif;`003o`000?nMS<7oWHc100;oWHc100Go0000oij=`_nNSL;oWXg2
o`000002oin?`P03o`000?nQT<?oXI3300Co00000_nRSl400ol0003oXi31oj>@`@02oj>@`@05o`00
0?nST<3oXi30oj>@`?l000001?nTSl000ol0003oY8noo`000002o`0000CoY9?400Go0000ojBB`onT
T/?oY9;3o`000003oj>A`P03o`000?nSTL7oXi7100Co00000onX_n/00ol0003oZ;o[ojRoj`03o`00
00CoZ;o[00Ko0000ojRojol0003o0000ojRojol00004ojRoj`?o00000onX_n/00ol0003oZ;o[ojRo
j`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX
_n/01?l0003oZ;o[ojRojonX_n/3o`0000CoZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`04o`00
0?ooooooooooo`0000Oooooo000]ooooo`03o`000?oooooooooo03Oooooo00?o0000ojRojonX_n/0
0ol00004ojRoj`03o`000?nX_n_o000000;oZ;o[00Co0000ojRojonX_n_oZ;o[0ol00004ojRoj`03
o`000?o3a=_o000000?of<k?00Co0000onCHb_oTf<[o00000_oSe/T2o`000003on;@aOl0003ogl_5
00;ogl_500Go0000om_6aOoKa/GoflK5o`000004om:la003o`000?o=]/Co000000;oak3300Co0000
ol:[`oo2Zl?o00000_nlYL82o`0000Co/Y_000?o0000ojfF_on]U[l00_n]U[l3o`000003ojJ?_Ol0
003oXhfm00;oXhfm00Go0000oj2;__nPRkkoX8^no`000003oij:_P03o`000?nLR[ooW8Zo00Oo0000
0_nLRKl00ol0003oWH_0oif;`002oif;`005o`000?nMS<7oWHc1oif<`Ol000000onNSL800ol0003o
Who2oin?`P03o`0000;oXHk100?o0000oj:?`OnRSl400_nRSl401Ol0003oXi31oj>@`OnST<7o0000
00?oXi3000?o0000ojB?`?nTSl001?l00002ojBDa@03o`000?nTTlCoY9?400;oY9?400Go0000ojBB
`onTT/?oY9;3o`000002oj>A`PCo00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000
ojRojonX_n/00ol00004ojRoj`06o`000?nX_n_o0000o`000?nX_n_o00001?nX_n/3o`0000;oZ;o[
00Co0000ojRojonX_n_oZ;o[1?l00002ojRoj`04o`000?nX_n_oZ;o[ojRoj`Co000000?oZ;o[o`00
0?l000000_nX_n/5o`0000;oZ;o[00?o0000ojRojonX_n/01Ol00002ojRoj`03o`000?nX_n_oZ;o[
00?o00000_ooool00ol0003oooooooooo`05ooooo`00;_ooool00ol0003oooooooooo`0gooooo`;o
00000onX_n/00ol0003oZ;o[ojRoj`03o`0000CoZ;o[00?o0000ojRojol000000_nX_n/00ol0003o
Z;o[ojRoj`02ojRoj`;o00000ooHc/l01?l0003oi=S:onCHb_l00003on?Fb@04o`000?oRd/So0000
o`0000;ogl_500?o0000om_6aOoKa/D00_oKa/D01Ol0003od[c4om:la?oB_<Co000000;ocKK400?o
0000olN``ol000000oo2Zl<01Ol0003o_:G2o`000?ngWl7o000000Co/Y_000?o0000ojfF_on]U[l0
0ol00004ojJ?_@04o`000?nSSKgoXhfmo`0000?oX8^n00?o0000oij:__nNR[h01?l00002oif8_@04
o`000?nLRKkoW8Vno`0000CoW8Vo00Go0000oif;`?nMRl3oWH_0o`000003oif<`@03o`000?nNSL;o
WXg200;oWXg20_l000000onPSL3o0000oj6>`@03oj6>`@05o`000?nRSl7oXXo1oj:?`Ol000000onS
T<400ol0003oXi30oj>@`004o`0000;oY9G500?o0000ojBDaOnTU<D00_nTU<D01Ol0003oY9?4ojBC
a?nTTlCo000000;oY9;31?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[
ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`06o`000?nX_n_o0000o`000?nX
_n_o00000onX_n/4o`0000;oZ;o[00Co0000ojRojonX_n_oZ;o[1?l00002ojRoj`03o`000?nX_n_o
Z;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003
ojRoj`03o`000?oooooo000000Oooooo000_ooooo`03o`000?oooooooooo03Oooooo00?o0000ojRo
jonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00?o00001?nX_n/01?l0003oZ;o[o`000?l00002
ojRoj`03o`000?oHc/oo000000;oi=S:00Go0000on?FbOoSe/WohmK9o`000002on;Bb005o`000?oO
clSo0000omo;aOl000000ooKa/D01Ol0003oe/75o`000?oB_<Co000000CocKK400?o0000ol:[`oo2
Zl<00oo2Zl<01Ol0003o]io1okNO`OngWl7o000000?o/Y_00ol00002ojZB_P03o`000?nVSkgoYXnm
00;oYXnm00Co0000oj>=_OnSSKgo00000_nPRkh4o`0000;oWXVl00?o0000oif8_OnMR;d00_nMR;d0
1?l0003oW8Vnoib9__l00003oib9_`05o`000?nMRl3oWH_0oif;`?l000001?nMS<400ol0003oWXg2
o`000002o`0000?oX8g000Go0000oj6>`OnQS/7oXHk1o`000003oj:?`@04o`000?nST<7oXi31oj>@
`@?o00000_nTULH00ol0003oY9G5ojBEa@02ojBEa@05o`000?nTU<GoY9C5ojBDaOl000000onTTl@3
o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/0
0ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`?o000000?oZ;o[
o`000?nX_n/01?nX_n/3o`000003ojRojol0003oZ;o[00?oZ;o[0ol00002ojRoj`;o00000_nX_n/4
o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00001oooool0
033ooooo0_l0000hooooo`;o00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRo
jonX_n/00ol00004ojRoj`?o000000?oi=S:o`000?oSe/T00_oSe/T01?l0003oh];8on;Bb?l00003
omo?b005o`000?oKa/GoflK5om_6aOl000000ooF`LD00ol0003ocKK4olffa002olffa0;o00001?o2
Zl<2o`0000?o]io100Ko0000ok:K`?nbVl3o0000ojjF__l00004ojZB_P05o`000?nVSkgoYXnmojJ?
_Ol000000_nSSKd3o`0000;oX8Vl00?o0000oij9_?nNRK`00_nNRK`01Ol0003oWHRmoif8_OnMR;go
000000;oW8Vn00Go0000oib9_onLRKooW8Voo`000002oif;`0So00000_nOS<001Ol0003oX8g0oj2=
`?nPSL3o000000?oXHk100?o0000oj:?`OnRSl400_nRSl43o`000003ojBEa_l0003oY9G600?oY9G6
00Go0000ojBEaOnTULGoY9G5o`000003ojBDa@06o`000?nTTlCo0000o`000?nX_n_o00001?nX_n/3
o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/0
1?l0003oZ;o[ojRojonX_n/4o`0000;oZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`03o`000?nX
_n_oZ;o[00?o00001?nX_n/01_l0003oZ;o[o`000?l0003oZ;o[o`0000?oZ;o[1?l00003ojRoj`03
o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[0_l00007ooooo`00
<_ooool00ol0003oooooooooo`0gooooo`03o`000?nX_n_oZ;o[00?o00000onX_n/00ol0003oZ;o[
ojRoj`04o`0000?oZ;o[00Co0000ojRojol0003o00000one`^@3o`000005on?FbOl0003oh];8on;B
b?l000001?oOclP2o`000003om_6aOl0003oe/7500;oe/750_l00003olffa004o`000?o7/LCoak74
o`0000;o`Z_300Co0000okbU`_nlYL;o00000_ngWl400ol0003o/Y_0o`000003ojjF_P05o`000?nZ
T[koZY:nojZB__l000001?nVSkd2o`000003oj:;_?l0003oX8Vl00?oX8Vl00Go0000oij9_?nNRKco
WXVlo`000003oif8_@04o`000?nLRKkoW8Vno`0000;oW8Vo1?l00002oij:_P05o`000?nNRkooWX^o
oij;_ol000001?nOS<001Ol0003oX8g0oj2=`?nPSL3o000000?oXHk100?o0000oj:?`Ol000000_l0
0004ojBEaP05o`000?nTULKoY9G6ojBEa_l000000onTULD00ol0003oY9C5ojBDa@03o`0000CoZ;o[
00Ko0000ojRojol0003o0000ojRojol00004ojRoj`?o00000onX_n/00ol0003oZ;o[ojRoj`04o`00
00;oZ;o[00?o0000ojRojonX_n/01Ol00002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0
003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`03o`000?nX_n_o0000
00?o00001?nX_n/3o`0000;oZ;o[00Co0000ojRojonX_n_oZ;o[1?l00002ojRoj`03o`000?nX_n_o
Z;o[00?o00001oooool003?ooooo00?o0000ooooooooool0=oooool2o`0000?oZ;o[00?o0000ojRo
jonX_n/00ol00004ojRoj`03o`000?nX_n_oZ;o[00?o00000one`^@01?l0003obLCFolW4e_o9a=H2
o`000003on;Bb?l0003oglo800?oglo800Co0000omc;b?oLblSo00000ooF`LD01_l0003odKc6om6l
a_l0003ocKK4o`0000?oak7400?o0000ol:[`ol000000onlYL800ol0003o]io1okNO`@02o`0000Co
[YJn00Go0000ojZB__nZT[koZY:no`000002ojJ?_@?o00000onRRk`01Ol0003oX8Vloj29_?nPRKco
000000?oWXVl00?o0000oif8_OnMR;d00_nMR;d00ol0003oW8Vno`000002o`0000;oWXVm00?o0000
oij:__nNR[h00_nNR[h01Ol0003oWX^ooij;_onNRkoo000000?oWhc000Go0000oj2=`?nPSL3oX8g0
o`000002oj6>`@?o00000_nSULH00ol0003oY9G6ojBEaP02ojBEaP05o`000?nTULKoY9G6ojBEa_l0
00000_nTULD4o`0000?oZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`06o`000?nX_n_o0000o`00
0?nX_n_o00001?nX_n/3o`0000;oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_o
Z;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003
ojRoj`03o`000?nX_n_oZ;o[00?o00000onX_n/2o`000005ojRojol0003o0000ojRojol000000onX
_n/4o`0000;oZ;o[00?o0000ojRojonX_n/01?l00003ooooo`03o`000?oooooooooo00Cooooo000d
ooooo`03o`000?oooooooooo03Oooooo00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_o
Z;o[00Co00000onX_n/00ol0003o]L;To`000003olW4eP03o`000?oJd]7of];A00;o00000ooOclP0
2?l0003og<_8omc;b?l0003of<K8o`000?oF`LGo00000ooA_<H2o`0000Coak740_l00004okbU`P05
o`000?ngWl7o0000ok:K`?l000001?n^U[h01?l0003oZY:nojZB__nZT[h3o`0000;oY8fl00Go0000
oj:;_?nRRkcoXX^lo`000003oj29_003o`000?nNRKcoWXVl00;oWXVl00?o0000oif8_Ol000000ol0
00000onNR;co0000oij9_@03oij9_@05o`000?nNR[koWXZnoij:__l000000onNRkl01Ol0003oWhc0
oin<`?nOS<3o000000;oX8g01?l000000onSU<Ko0000oj>EaP03oj>EaP05o`000?nTULKoY9G6ojBE
a_l000000_nTULH4o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[
00?o00001?nX_n/01_l0003oZ;o[o`000?l0003oZ;o[o`0000?oZ;o[0ol00003ojRoj`03o`000?nX
_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l0
0003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/01?l0003oZ;o[ojRojonX_n/3o`0000CoZ;o[
0ol000000onX_n_o0000ojRoj`03ojRoj`?o00001oooool00ol0003oooooooooo`04ooooo`00=Ooo
ool2o`0003Sooooo0_l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRo
j`03o`0000?obLCF00Wo0000om[BdOoJd]7of];Ao`000?oKdLoo0000omo?b?l000000_oLblP01Ol0
003of<K8omS6b?oHa/So000000?odKc600?o0000olbga_l000000oo7/L@00ol0003o`J_4o`000004
okbU`P;o00000onbVl000ol0003o[YJnojjF_P02ojjF_P?o000000?oYhnmo`000?nTSK`00onTSK`0
1?l0003oXX^loj:;_?l00004oj29_003o`000?nNRKco000000?o00000_nNR;/01Ol0003oWXRloij8
_?nNR;co000000?oWXVm00Go0000oij:__nNR[koWXZno`000003oij;_`03o`000?nOS<3oWhc000Co
00000_nRU<D01Ol0003oXiC6oj>Da_nSU<Ko000000?oXiG600?o0000ojBEa_nTULH01?l00003ojRo
j`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRo
jonX_n/00ol00004ojRoj`?o000000?oZ;o[o`000?nX_n/00onX_n/3o`0000?oZ;o[00?o0000ojRo
jonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`00
00;oZ;o[00?o0000ojRojonX_n/01Ol000000onX_n_o0000o`000002ojRoj`?o00001?nX_n/01?l0
003oZ;o[o`000?l0000:ooooo`03o`000?oooooooooo00Cooooo000gooooo`03o`000?oooooooooo
03Kooooo00Co0000ojRojonX_n_oZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/0
0ol0003obLCFo`000003om[Bd@04o`000?oKdLoofm7?om_Ac`;o000000?og<_8o`000?oHa/P00_oH
a/P01Ol0003oe<;8o`000?oA_<Ko000000?oc;O600?o0000olNaa?l000000oo1Zl@01_l0003o_:G2
okbU`_l0003o]j32o`0000Co/Y_000?o0000ojjF__n^U[h00_l00004ojN?_@05o`000?nTSKcoY8fl
ojB=_?l000000onRRk`00ol0003oX8Vlo`000003o`0000;oWhRk00?o0000oij8^onNR;/00_nNR;/0
1?l0003oWXRloij8_?l00003oij9_@03o`000?nNR[koWXZn00;oWXZn00?o0000oij;_ol000000ol0
0002oj:Ca@03o`000?nRU<GoXYC500;oXYC500Co0000oj>Da_nSU<Ko00000onSULH3o`0000?oZ;o[
00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[
ojRoj`04o`0000;oZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`06o`000?nX_n_o0000o`000?nX
_n_o00001?nX_n/3o`0000?oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`04o`000?nX_n_oZ;o[
ojRoj`Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003
ojRoj`03o`000?nX_n_oZ;o[00?o00003?ooool00ol0003oooooooooo`04ooooo`00>?ooool00ol0
003oooooooooo`0fooooo`03o`000?nX_n_o000000;oZ;o[00Co0000ojRojonX_n_oZ;o[0ol00003
ojRoj`03o`000?nX_n_oZ;o[00?o00000ooJd]401Ol0003ofm7?om_AcooKdLoo000000;of/k>00Go
0000omS6b?oHa/Sof<K8o`000003omC2b003o`000?o<]lKoc;O600?oc;O600?o0000ol6[a?o1Zl@0
0_o1Zl@00ol0003o_:G2o`000003okNP`P09o`000?nbVl3o/Y_0ok:K`?l0003o[YJno`000?nZTkko
000000CoYhnm00Go0000ojB=_?nTSKcoY8flo`000002oj:;_0?o00000_nPR;/00ol0003oWhRkoin8
^`02oin8^`05o`000?nNR;_oWXRkoij8^ol000000_nNR;`00ol0003oWXVmoij9_@02oij9_@03o`00
0?nNR[ko000000?o00000_nQT/@00ol0003oXY?5oj:Ca@02oj:Ca@05o`000?nRU<GoXYC5oj:DaOl0
00000_nSU<H01_l0003oXiG6o`000?l0003oZ;o[o`0000CoZ;o[0ol00003ojRoj`03o`000?nX_n_o
Z;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[00?o0000ojRojonX_n/01?l00003
ojRoj`03o`000?nX_n_oZ;o[00?o00001?nX_n/01_l0003oZ;o[o`000?l0003oZ;o[o`0000CoZ;o[
0ol00002ojRoj`03o`000?nX_n_oZ;o[00Go00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[
00?o0000ojRojonX_n/01?l00002ojRoj`;o00000_nX_n/4o`0000oooooo00?o0000ooooooooool0
1?ooool003Wooooo00?o0000ooooooooool0=_ooool00ol0003oZ;o[ojRoj`02ojRoj`03o`000?nX
_n_o000000;oZ;o[00Co0000ojRojonX_n_oZ;o[0ol00003ojRoj`03o`000?oJd]7o000000?ofm7?
00So0000om[>c_oJc/ko0000omO;c_l0003of<K8o`0000Coe<;80_l00003olbgaP;o00001?o1Zl@2
o`0000Co]j3200Co0000ok:K`?nbVl3o/Y_00_l00003ojZC_P05o`000?nWSkgoYhnmojN?_Ol00000
1?nTSK`2o`000003oj69^ol0003oX8Rk00;oX8Rk00?o0000oin8^onOR;/00_nOR;/01Ol0003oWXRk
oij8^onNR;_o000000?oWXRl00?o0000oij9_Ol000000ol00002oj6A``03o`000?nQT/CoXI;400;o
XI;400Go0000oj:CaOnRTlGoXY?5o`000003oj:Da@03o`000?nSU<KoXiC600;o00001?nX_n/01_l0
003oZ;o[o`000?l0003oZ;o[o`0000CoZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX
_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX
_n_oZ;o[00?o00001?nX_n/01_l0003oZ;o[o`000?l0003oZ;o[o`0000?oZ;o[0ol00003ojRoj`03
o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX
_n/01?l0000Cooooo`03o`000?oooooooooo00Cooooo000jooooo`;o0000=oooool00ol0003oZ;o[
ojRoj`03o`0000CoZ;o[00?o0000ojRojol000000onX_n/00ol0003oZ;o[ojRoj`04o`000005om_A
col0003of/k>om[>c_l000000ooGblh2o`0000?oe<;800Ko0000olnmbOo?_LWo0000olbga_l00002
olJbaP06o`000?o1ZlCo`J_4o`000?nlY/Co00001?ngX<801_l0003o/Y_0o`000?l0003o[YNoo`00
00?oZY>n00?o0000ojN?_OnWSkd00_nWSkd00ol0003oY8flo`000002o`0000;oXHVk00?o0000oj28
^onPR;/00_nPR;/01Ol0003oWhRkoin8^onOR;_o000000CoWXRk00?o0000oij8_?l000000_l00002
oj6@``03o`000?nQTL?oXI7300;oXI7300Go0000oj6Ba?nQT/CoXI;4o`000003oj:Ca@03o`000?nR
U<GoXYC500Co00000_nX_n/00ol0003oZ;o[ojRoj`03o`0000CoZ;o[00Co0000ojRojol0003o0000
0_nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`00
0?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/0
0ol00004ojRoj`?o000000?oZ;o[o`000?nX_n/00onX_n/3o`0000?oZ;o[00?o0000ojRojonX_n/0
1?l00003ojRoj`03o`000?nX_n_oZ;o[00Co000000?oooooo`000?ooool05?ooool00ol0003ooooo
ooooo`04ooooo`00??ooool00ol0003oooooooooo`0eooooo`;o00000onX_n/00ol0003oZ;o[ojRo
j`03o`0000CoZ;o[0ol00003ok[3h@?o000000?of/k>o`000?oGblh00ooGblh01Ol0003odlO>o`00
0?oD`/So000000Cockg900Oo0000olJba_o6//Koa[;6o`000?o1ZlCo000000?o_:K400Co0000okNP
`_ngX<;o]j320_l00004ojjG_`04o`000?nZTkkoZY>no`0000?oYhnm0ol00002oj>;^`05o`000?nQ
RK_oXHVkoj69^ol000000onPR;/00ol0003oWhRkoin8^`02oin8^`03o`000?nNR;_o000000?o0000
00?oXHo2o`000?nQT<<00onQT<<01Ol0003oXI73oj6A`onQTL?o000000?oXI;400?o0000oj:CaOnR
TlD01?l00003ojRoj`03o`000?nX_n_oZ;o[00?o00000onX_n/00ol0003oZ;o[ojRoj`03o`0000Co
Z;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000?o
Z;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003o
Z;o[ojRoj`03o`0000CoZ;o[00Ko0000ojRojol0003o0000ojRojol00004ojRoj`?o00000_nX_n/0
1?l0003oZ;o[ojRojonX_n/4o`0000Kooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`03ooooo`00?Oooool00ol0003oooooooooo`0eooooo`03o`000?nX_n_oZ;o[00Co00000onX_n/0
1_l0003oZ;o[o`000?l0003oZ;o[o`0000?o^/?Q00Co0000olK6f_o6a][oa/KJ0_l00003omO;cP05
o`000?oCalkodlO>om?7c_l000001?o?_LT2o`0000Coa[;600?o0000okbVa?nlY/@00_nlY/@01_l0
003o]j32o`000?l0003o/Yc2o`0000Co[YNo00Co0000ojZC__nZTkkoZY>n0ol000000onUSKco0000
oj>;^`03oj>;^`04o`000?nQRK_oXHVko`0000?oX8Rk00Co0000oin8^onOR;_oWhRk0ol00002oj6?
`@05o`000?nQSl;oXHo2oj6?`_l000000onQT<<01Ol0003oXI73oj6A`onQTL?o000000;oXI;41?l0
0003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00Ko
0000ojRojol0003o0000ojRojol00004ojRoj`?o00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000?o
Z;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003o
Z;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`06o`000?nX_n_o0000o`00
0?nX_n_o00000onX_n/4o`0000_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03
ooooo`00?_ooool00ol0003oooooooooo`0eooooo`;o00001?nX_n/00ol0003oZ;o[ojRoj`02o`00
00CoZ;o[00?o0000ok[3hOl000000oo6a]X01_l0003oclgHolo=f?l0003oel_>o`0000?odlO>0_l0
0003olnmb@04o`000?o9^L[obKW:o`0000;oa[;60_l00005okbVa003o`000?nbW<;o/Yc200;o/Yc2
00Go0000ojjG_on^Ukoo[YNoo`000002ojZC_P;o00001?nUSK`01Ol0003oXh^koj>;^onSRk_o0000
00;oXHVk00?o0000oj28^onPR;/00_nPR;/3o`000003oj6?`Ol0003oXHo100?oXHo100Co0000oj6?
`_nQSl;o00000onQT<<00ol0003oXI73oj6A``04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00002
ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03o`0000CoZ;o[00Ko0000
ojRojol0003o0000ojRojol00003ojRoj`?o00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[
00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[
ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`?o00004?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00?ooooo000oooooo`03o`000?oooooooooo03Kooooo00?o
0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00?o00000oo6a]X01?l0003oclgHolo=
f?o?cMP2o`0000?odlO>00Ko0000olo3c_o?`lko0000olnmbOl00003olVibP03o`000?o6//Ko0000
00;o`:g700Co0000okbVa?nlY/Co_:K40_l00004ok:L`P04o`000?n^Ukoo[YNoojjG_`?o000000?o
Yi2mo`000?nUSK`00onUSK`01Ol0003oXh^koj>;^onSRk_o000000?oXHVk00?o0000oj28^ol00000
0_l00004oj6?`@05o`000?nQSl7oXHo1oj6?`Ol000000_nQSl800ol0003oXI33oj6@``04o`0000?o
Z;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00?o00000onX_n/00ol0003o
Z;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`05o`000?nX_n_o0000ojRo
jol000001?nX_n/3o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[
00?o00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00002ojRo
j`03o`000?nX_n_oZ;o[00?o00004_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00?ooooo0010ooooo`;o0000=oooool2o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`03
o`000?o6a][o000000?oclgH00Ko0000olk:eoo>b]Oo0000om?7c_l00003olo3cP;o00001?o9^LX2
o`0000Co`:g700?o0000okbVa?l000000_nfX/D01_l0003o/Yc2ok:L`_nbW<;o0000ojjG_`;o0000
00?oZIBoo`000?nWT;d00_nWT;d01Ol0003oYHflojF=_?nUSKco000000CoXh^k00?o0000oj69^ol0
00000_l00002oj:?`@03o`000?nQSl7oXHo100;oXHo100Go0000oj6?`OnQSl7oXHo1o`000002oj6?
`P?o00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00002ojRo
j`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRo
jonX_n/00ol00003ojRoj`06o`000?nX_n_o0000o`000?nX_n_o00001?nX_n/3o`0000?oZ;o[00?o
0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRo
j`04o`0000;oZ;o[00?o0000ojRojonX_n/01?l0000Fooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool00oooool004;ooooo00?o0000ooooooooool0=Oooool00ol0003oZ;o[ojRoj`04
o`0000?oZ;o[00?o0000ojRojonX_n/01?l000000oo?cMSo0000olk:e`02olk:e`;o00000oo?`lh0
0ol0003obko?o`000003olVibP03o`000?o3]<co000000Co`:g70_l00003okJRa@04o`000?nbW<;o
/Yc2ok:L`P;o00001?nYU;l01?l0003oYi2mojN@_Ol00004ojF=_003o`000?nSRk_o000000?o0000
00?oXXo1o`000?nRSl400onRSl401Ol0003oXHo1oj6?`OnQSl7o000000CoXHo10_l000000onX_n_o
0000ojRoj`03ojRoj`?o00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX
_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000;o
Z;o[00?o0000ojRojonX_n/00ol00004ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o0000ojRo
jonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`00
00;oZ;o[00?o0000ojRojonX_n/01?l0000Kooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00oooool004?ooooo00?o0000ooooooooool0=Oooool2o`0000?oZ;o[00?o0000ojRojonX
_n/01?l00003oj_0j@;o00000oo>b]L01_l0003oblOFol_7e_l0003ocl?>o`0000?obko?00?o0000
olVib_l000000oo3]<`01_l0003o`:g7o`000?l0003o^ZW8o`0000?o]Z;500Ko0000ok:L`_l0003o
0000ojbH`_l00004ojVD_`04o`000?nWT;goYi2mo`0000;oYHfl1?l00002oj>@`@05o`000?nRSl7o
XXo1oj:?`Ol000000onRSl400ol0003oXHo1oj6?`@02oj6?`@03o`000?nQSl7o000000;o00000onX
_n/01_l0003oZ;o[o`000?l0003oZ;o[o`0000CoZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00Co
00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03
o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03o`0000CoZ;o[0ol00002ojRoj`03
o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[00?o0000ojRojonX
_n/01?l0000Oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool004Cooooo
00?o0000ooooooooool0=_ooool00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00Co0000oj_0jOl0003o
00000_nd`^@00ol0003oc/[Go`000003ol_7eP;o00001?o;_ll2o`0000Co`kC<0_l00004okZYb003
o`000?nfX/Go]Z;500;o00001?n/V<801Ol0003oZIBoojVD_onYU;oo000000;oYi2m0ol00002ojBB
`P03o`000?nST<7oXi3100;oXi3100Co0000oj:?`OnRSl7o00000onRSl400ol0003oXHo1oj6?`@04
o`0000?oZ;o[00?o0000ojRojonX_n/00_l00004ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o
0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00?o00000onX_n/00ol0003oZ;o[ojRo
j`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX
_n/01_l0003oZ;o[o`000?l0003oZ;o[o`0000?oZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00Co
00000onX_n/00ol0003oZ;o[ojRoj`03o`0002Cooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`03ooooo`00AOooool2o`0003Oooooo0_l00003ojRoj`03o`000?nX_n_oZ;o[00;o0000
1?nd`^@2o`0000?oblOF00?o0000olS4eol000000oo;_ll00ol0003oaK_Ao`000003ol>dc003o`00
0?nm/<go000000Co^ZW800Go0000okJRaOl0003o/9k6o`000004ojbH`P03o`000?nYU;ooZIBo00;o
ZIBo0_l000000onVU<Co0000ojBB`P03ojBB`P05o`000?nST<7oXi31oj>@`Ol000000_nRSl400ol0
003oXXo1oj:?`@04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[
00?o00001?nX_n/3o`0000?oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[
00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[00?o0000ojRojonX_n/01?l00003ojRo
j`03o`000?nX_n_oZ;o[00?o00001?nX_n/3o`000003ojRojol0003oZ;o[00?oZ;o[0ol00003ojRo
j`03o`000?nX_n_oZ;o[00Co0000:?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00;ooooo0017ooooo`03o`000?oooooooooo03Gooooo00?o0000ojRojonX_n/01?l00002ojRoj`04
o`000?nd`^Co0000o`0000;o^/CQ00?o0000ol_7e_l000000oo8a=L00ol0003obko?o`000003olFk
d@03o`000?o3]<co000000?o_K3=00Co0000okZYb?njZLSo^ZW80_l00003ok2NaP05o`000?n/V<;o
[9S2ojbH`_l000000_nYU;l3o`0000?oYYC400Go0000ojBB`_nTT/;oY9;2o`000003oj>@`@03o`00
0?nRSl7oXXo100?o00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/0
0ol00003ojRoj`06o`000?nX_n_o0000o`000?nX_n_o00001?nX_n/3o`0000;oZ;o[00?o0000ojRo
jonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`00
00?oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00;o00001?nX_n/01?l0
003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00Co0000;Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00;ooooo0018ooooo`03o`000?oooooooooo03Gooooo0_l00003ojRo
j`03o`000?nX_n_oZ;o[00?o00000onja>43o`0000?ob<CG0ol00003olFkd@;o00001?nm/<d01_l0
003o^ZW8o`000?l0003o/jG:o`0000?o/9k600?o0000ojbH`_n/V<801?l00002ojNHaP05o`000?nV
U<CoYYC4ojJDa?l000000onTT/800ol0003oXi31oj>@`@04o`0000;oZ;o[00?o0000ojRojonX_n/0
1?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`03o`0000CoZ;o[
00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRojonX
_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00?o00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?o
Z;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00?o00001?nX_n/3o`00037o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00BOooool00ol0003ooooo
ooooo`0eooooo`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003o^/CQo`000003okc5h@03o`00
0?o8a=Oo000000?o`l7H00Go0000olFkdOl0003o_kSCo`000004okf`c@;o00001?ncYLX00ol0003o
/9k6ok2NaP03o`0000;oZIc800?o0000ojNHa_nWV<H00_nWV<H01?l0003oYYC4ojJDa?l00002ojBB
`PCo00000onX_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRo
j`03o`000?nX_n_oZ;o[00?o00000onX_n/00ol0003oZ;o[ojRoj`03o`0000CoZ;o[0ol00002ojRo
j`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[00?o0000ojRo
jonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`00
00?oZ;o[00Co0000ojRojol0003o0000=Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00;ooooo001:ooooo`;o0000=_ooool2o`0000?oZ;o[00?o0000ojRojonX_n/00ol00004okc5
h@;o00001?o3`MP2o`0000?o_kSC00Ko0000okf`cOl0003o0000okJ/col00004ok>UbP05o`000?n`
W/Ko0000oj^Qc?l000001?nYW<P01Ol0003oYiS6ojNHa_nWV<Ko000000;oYYC40ol00003ojRoj`03
o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRojonX
_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/01_l0003oZ;o[o`000?l0003oZ;o[
o`0000?oZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04
o`0000?oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/0
0ol0003oZ;o[ojRoj`03o`0003Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02
ooooo`00C?ooool00ol0003oooooooooo`0eooooo`03o`000?nX_n_oZ;o[00?o00000onY`>X01?l0
003o_<GQo`000?l00002ok_3h@06o`000?o3`MSo0000o`000?nn_][o00000ono^=<2o`0000Co]Zc?
00?o0000ok>Ub_ncYLX00ol00003oj^Qc005o`000?nYW<SoZIc8ojVLb?l000000onWV<H3o`0000;o
Z;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003o
Z;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[00?o
00001?nX_n/00ol0003oZ;o[o`000002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003o
Z;o[ojRoj`03o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00?o
00000onX_n/00ol0003oZ;o[ojRoj`04o`0003cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`02ooooo`00COooool00ol0003oooooooooo`0eooooo`;o00000_nX_n/00ol0003oZL3Z
ojW0jP03o`0000Co^l?Q0_l00004okjnfP05o`000?no^=?o0000okRde_l000001?nf[<l3o`0000;o
[JKA00Go0000oj^Qc?n[XLcoZj7<o`000003ojVLb004o`000?nWV<Ko0000o`0000;oZ;o[00?o0000
ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03
o`0000?oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/0
0ol0003oZ;o[ojRoj`03o`0000?oZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/0
0ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_o
Z;o[00Co0000@?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo001>oooo
o`03o`000?oooooooooo03Gooooo00?o0000ojRojonX_n/00ol00003oj_0j@04o`000?nk`n7o0000
o`0000;o^<;R00?o0000okjnf_nn_]X00ol00003okRdeP06o`000?nf[<oo0000o`000?n_[MKo0000
1?n]Y]401?l0003oZj7<oj^Qc?l00002ojVLb0?o00001?nX_n/3o`0000?oZ;o[00?o0000ojRojonX
_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000?o
Z;o[00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/01?l0003o
Z;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03o`00
00?oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co0000AOooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo001?ooooo`;o0000=_ooool2o`0000?o
Z;o[00?o0000oj_0jOn[`>T00_l00004okS2hP?o00000onh_=d00ol0003o^;CFokRdeP02o`0000Co
[jgF00Go0000ojfVdOn]Y]7o[JKAo`000002oj^Qc0?o00000onX_n/01?l0003oZ;o[o`000?l00002
ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000
ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04
o`0000?oZ;o[00?o0000ojRojonX_n/00_l00004ojRoj`?o00000onX_n/00ol0003oZ;o[ojRoj`04
o`0000;oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00?o0000B_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo007ooooo001Aooooo`03o`000?oooooooooo
03Cooooo00?o0000ojRojonX_n/01?l00002oj^oj006o`000?nh`^;o0000o`000?nd`NCo00001?nh
_=d3o`0000;o/;CL00Go0000ojn]e_n_[MKo[jgFo`000002ojfVd@Co00000onX_n/00ol0003oZ;o[
ojRoj`02o`0000CoZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00?o00000onX_n/00ol0003oZ;o[
ojRoj`04o`0000;oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00?o0000
0onX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[00Co0000ojRojol0003o00000_nX_n/00ol0003o
Z;o[ojRoj`04o`0000;oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co
0000COooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo007ooooo001Booooo`03o`00
0?oooooooooo03Cooooo0_l00003ojRoj`03o`000?n[_nSoZkoX00?o00000ond`N@01_l0003o^;cM
o`000?l0003o/;_Ro`0000Co/;CL00?o0000ojn]e_n_[MH00ol00003ojRoj`03o`000?nX_n_oZ;o[
00Co00000_nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/0
0ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_o
Z;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00_l00004
ojRoj`?o00000onX_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRojonX_n/01?l0001B
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool005?ooooo00?o0000oooo
ooooool0=?ooool00ol0003oZ;o[ojRoj`04o`0000?oZl3Y00?o0000okC1i?nd`N@00_l00004ok2k
hP03o`000?n`]=co/;CL00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRo
jonX_n/00_l00004ojRoj`?o00000onX_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRo
jonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03o`00
00?oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o0000
ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co0000Eoooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo007ooooo001Dooooo`;o0000=Oooool2o`0000?oYko[00?o0000oj_0
jOn[`>T01?l00002ojk0i`03o`000?n`^n;o/;_R00Co00000onX_n/00ol0003oZ;o[ojRoj`03o`00
00?oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o0000
ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03
o`0000?oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/0
0ol0003oZ;o[ojRoj`02o`0000CoZ;o[0ol00002ojRoj`03o`000?nX_n_oZ;o[00Co0000G?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo007ooooo001Fooooo`03o`000?oooooooooo
03Cooooo00?o0000ojNojonW_n/00ol00003oj[1j`03o`000?n^`>Oo[/3W00?o00000onX_n/00ol0
003oZ;o[ojRoj`04o`0000;oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[
00;o00001?nX_n/3o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[
00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRo
j`03o`000?nX_n_oZ;o[00Co00000_nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_o
Z;o[00?o0000H?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo007ooooo001Goooo
o`03o`000?oooooooooo03Cooooo0_l00002ojJoj`03o`000?nZ`N_oZ/7[00Co00000onX_n/00ol0
003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[
00Co00000_nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/0
0ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_o
Z;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[00?o0000ojRojonX_n/00ol00004
ojRoj`?o0000I?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo007ooooo001Hoooo
o`03o`000?oooooooooo03Cooooo00?o0000ojJojonV_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[
00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRo
j`03o`000?nX_n_oZ;o[00?o00000_nX_n/4o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRo
j`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[00?o0000ojRo
jonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00?o00000onX_n/01?l0003oZ;o[o`000?l0001X
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00Oooool005Wooooo0_l0000eoooo
o`;o00000onX_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRo
j`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[0ol00003ojRo
j`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRo
jonX_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[00?o00000onX_n/00ol0003oZ;o[ojRoj`04o`00
00;oZ;o[00?o0000ojRojonX_n/00ol0001[ooooo`03o`000?oooooooooo00Cooooo0Ol00001oooo
o`7ooooo001Kooooo`03o`000?oooooooooo03?ooooo00?o0000ojRojonX_n/01?l00002ojRoj`03
o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX
_n/00ol00003ojRoj`03o`000?nX_n_o000000;oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03
o`000?nX_n_oZ;o[00?o00000onX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[00?o0000ojRojonX
_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03o`0006ko
oooo00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool005cooooo00?o0000ooooooooool0
<oooool2o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[00?o0000
0onX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`?o0000
0onX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`00
0?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRojonX_n/0
1?l0001booooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo001Mooooo`03o`000?oo
oooooooo03?ooooo00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX
_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`?o00000onX
_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX
_n_oZ;o[00?o00000onX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[00?o0000ojRojonX_n/01?l0
001gooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`7ooooo001Nooooo`;o0000=?ooool2
o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/0
0ol0003oZ;o[ojRoj`04o`0000;oZ;o[00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRo
j`04o`0000;oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX
_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol0001looooo`05o`000?oo
ooooooooooooool000000_ooool0063ooooo00?o0000ooooooooool0<_ooool00ol0003oZ;o[ojRo
j`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[00?o00000onX
_n/00ol0003oZ;o[ojRoj`03o`0000;oZ;o[1?l00003ojRoj`03o`000?nX_n_oZ;o[00?o00000onX
_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX
_n_oZ;o[00Co0000Ooooool01Ol0003ooooooooooooooooo000000;ooooo001Qooooo`03o`000?oo
oooooooo03;ooooo0_l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oZ;o[ojRo
j`04o`0000;oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`?o00000onX_n/00ol0003oZ;o[ojRo
j`04o`0000;oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX
_n/00ol0003oZ;o[ojRoj`04o`0008Cooooo00Co0000oooooooooooo00000_ooool006;ooooo00?o
0000ooooooooool0<oooool00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRojonX_n/00ol0
0003ojRoj`03o`000?nX_n_oZ;o[00?o00000_nX_n/4o`0000;oZ;o[00?o0000ojRojonX_n/01?l0
0003ojRoj`03o`000?nX_n_oZ;o[00?o00000onX_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o
0000ojRojonX_n/00ol00029ooooo`03o`000?oooooo000000;ooooo001Sooooo`;o0000=?ooool2
o`0000;oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/3
o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/0
0ol0003oZ;o[ojRoj`04o`0000;oZ;o[00?o0000ojRojonX_n/01?l0002<ooooo`04o`000?oooooo
ooooo`00007ooooo001Uooooo`03o`000?oooooooooo03;ooooo00?o0000ojRojonX_n/00ol00003
ojRoj`03o`000?nX_n_oZ;o[00?o00000onX_n/00ol0003oZ;o[o`000002ojRoj`03o`000?nX_n_o
Z;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[00?o0000ojRojonX_n/01?l00003
ojRoj`03o`000?nX_n_oZ;o[00?o0000TOooool00ol0003oooooo`000001ooooo`00I_ooool00ol0
003oooooooooo`0booooo`;o00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[00?o0000ojRo
jonX_n/01?l00002ojRoj`?o00000onX_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRo
jonX_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[00Co0000UOooool2o`00007ooooo001Wooooo`03
o`000?oooooooooo03;ooooo00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[00?o
00000_nX_n/4o`0000;oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co
00000_nX_n/00ol0003oZ;o[ojRoj`04o`0009Sooooo0ol00001ooooo`00J?ooool00ol0003ooooo
ooooo`0booooo`;o00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[0ol00003ojRoj`03o`00
0?nX_n_oZ;o[00?o00000onX_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRojonX_n/0
0ol0002Hooooo`Co00001?ooool006Wooooo0_l0000cooooo`03o`000?nX_n_oZ;o[00?o00000_nX
_n/4o`0000;oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX
_n/00ol0003oZ;o[ojRoj`04o`0009Sooooo0ol00008ooooo`00Joooool00ol0003oooooooooo`0a
ooooo`;o00000_nX_n/3o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_o
Z;o[00?o00000onX_n/00ol0003oZ;o[ojRoj`03o`0009Sooooo1?l0000;ooooo`00K?ooool00ol0
003oooooooooo`0booooo`;o00000onX_n/00ol0003oZ;o[ojRoj`03o`0000;oZ;o[00?o0000ojRo
jonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co0000Uoooool4o`0000oooooo001]ooooo`03
o`000?oooooooooo03;ooooo00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00?o
00000onX_n/00ol0003oZ;o[ojRoj`03o`0009Oooooo1?l0000Cooooo`00K_ooool2o`0003?ooooo
0_l00003ojRoj`03o`000?nX_n_oZ;o[00?o00000_nX_n/00ol0003oZ;o[ojRoj`04o`0009Oooooo
0ol0000Gooooo`00L?ooool00ol0003oooooooooo`0aooooo`03o`000?nX_n_oZ;o[00Co00000_nX
_n/00ol0003oZ;o[ojRoj`03o`0009Oooooo1?l0000Jooooo`00LOooool00ol0003oooooooooo`0a
ooooo`;o00000onX_n/00ol0003oZ;o[ojRoj`03o`0009Kooooo1?l0000Nooooo`00L_ooool00ol0
003oooooooooo`0aooooo`03o`000?nX_n_oZ;o[00Co0000UOooool4o`0002;ooooo001cooooo`;o
0000<_ooool2o`0009Gooooo1?l0000Vooooo`00MOooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo097ooooo0ol0000Zooooo`00M_ooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo08gooooo1?l0000]ooooo`00Moooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo08Wooooo1?l0000aooooo`00N?ooool2o`0002gooooo00?o0000ooooooooool0QOooool4o`00
03Gooooo001jooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0P_ooool3o`0003Wo
oooo001kooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0O_ooool4o`0003cooooo
001looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0N_ooool4o`00043ooooo001m
ooooo`;o0000:?ooool00ol0003oooooooooo`1fooooo`Co0000A?ooool007oooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1cooooo`?o0000B?ooool0083ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`1_ooooo`Co0000Boooool0087ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`1[ooooo`Co0000Coooool008;ooooo0_l0000Sooooo`03o`000?oo
oooooooo06Oooooo1?l0001Cooooo`00Q?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo06Cooooo0ol0001Gooooo`00QOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
063ooooo1?l0001Jooooo`00Q_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05co
oooo1?l0001Nooooo`00Qoooool2o`0001kooooo00?o0000ooooooooool0F?ooool4o`0006;ooooo
0029ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0E?ooool4o`0006Kooooo002:
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0DOooool3o`0006[ooooo002;oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0COooool4o`0006gooooo002<ooooo`;o
00006Oooool00ol0003oooooooooo`19ooooo`Co0000LOooool008kooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`15ooooo`Co0000MOooool008oooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`12ooooo`?o0000NOooool0093ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0nooooo`Co0000O?ooool0097ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0jooooo`Co0000P?ooool009;ooooo0_l0000Booooo`03o`000?oooooooooo03Oo
oooo1?l00024ooooo`00U?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Cooooo
0ol00028ooooo`00UOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo033ooooo1?l0
002;ooooo`00U_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02cooooo1?l0002?
ooooo`00Uoooool2o`0000gooooo00?o0000ooooooooool0:?ooool4o`0009?ooooo002Iooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool09Oooool3o`0009Oooooo002Jooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool08Oooool4o`0009[ooooo002Kooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool07Oooool4o`0009kooooo002Looooo`;o00002?ooool0
0ol0003oooooooooo`0Iooooo`Co0000X_ooool009kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Eooooo`Co0000Y_ooool009oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Booooo`?o0000Z_ooool00:3ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0>ooooo`Co0000[Oooool00:7ooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo1?l0
002aooooo`00Xoooool01?l0003oooooooooool00008ooooo`Co0000]Oooool00:Cooooo00?o0000
ooooool000001Oooool3o`000;Wooooo002Uooooo`;o000000?oooooo`000?l000000_l0002loooo
o`00Y_ooool2o`000<3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo002nooooo`?o000000?o410@ooooooooool0Y?ooool009cooooo00?o^[Zjoc8b<_ooool0
3Oooool2o`0000_ooooo00?o0000okZj^_ooool01?ooool00ol@413o^[Zjooooo`05ooooo`;o0000
1Oooool00ol0003o^[Zjooooo`2Fooooo`00WOooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`;o<S8b1Oooool00onHV9So<S8b
ooooo`06ooooo`03o`000?oooooooooo00?ooooo0_lb<S:Gooooo`00Voooool01onHV9So410@o`00
0?l0003oZJVYooooool000000_ooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooooooo
o`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool00ooMgMgo0000okZj^P06oooo
o`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X02oooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00Kooooo1Ol0001gooooo`00Voooool01ol0003oZJVYoeEEEOnHV9So
EEEEokZj^_l000000_ooool00ol0003oooooooooo`05ooooo`0:o`000?ooooooooooooooooo^k^ko
8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool00omEEEGoMgMgodA4A006
ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41003?ooool01Ol0003ooooooooooooo
oooo000000;ooooo1_l000001_ooooooV9RHob4Q8Oo^k^koooooodA4A7Oooooo002Kooooo`06oc8b
<_o^k^koV9RHoeEEEOoMgMgo410@0ol00008ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`00
0?l@413oc<c<2_ooool01OoMgMgo410@oooooolQ8B7ogMgM00Gooooo00?o0000ooooooooool04_oo
ool01Ol0003ooooooooooooooooo000000[ooooo00?oV9RHob4Q8Oo^k^h0N?ooool009_ooooo00Oo
^[ZjodA4A?o<c<co8B4Qooooool@413oc<c<00[ooooo00?o0000ooooooooool00_ooool01?o^k^ko
8B4Qoa0@4?o^k^h:ooooo`05ofIVI_n7QhOooooooiRHV?mEEED01Oooool00ol0003oooooooooo`0B
ooooo`05o`000?ooooooooooooooool000000_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h0Mooo
ool009_ooooo00Ook^k^o`000?oooooo0000oooooomVIVKoQhN700[ooooo00?o0000ooooooooool0
0_ooool01?lQ8B7oMgMgogMgMolb<S89ooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOoo
ool00oooool00ol0003oooooooooo`0Booooo`05o`000?n7QhOoooooojVYZOl000003?ooool00omg
MgOoIVIVooooo`1fooooo`00Voooool01?mVIVKoV9RHoooooolb<S82okZj^P03o`000?oooooooooo
00Sooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool01?l@413o0000o`000?oo
ool2o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool04Oooool00ol@413o0000ogMg
M`02o`000003oiRHV?oooooooooo00_ooooo00?o0000ooooooooool0MOooool009kooooo00?oIVIV
ohN7Qoooool02oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo023ooooo00Go0000
okZj^_ooooooV9RHoa0@401gooooo`00W_ooool00onYZJWoA4A4ooooo`0;ooooo`;o00006_ooool2
o`0002;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c01gooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.875, 0}} -> {-0.11607, 0.0207698, \
0.00372262, 0.00372262}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -37.6875 0 ]
[.5 .82364 37.6875 10.125 ]
[.03045 .24505 -12 -8.71092 ]
[.03045 .24505 0 .28908 ]
[.17875 .18668 -23.5791 -9 ]
[.17875 .18668 .42091 0 ]
[.33612 .12478 -5.58359 -9 ]
[.33612 .12478 .41641 0 ]
[.5034 .05901 -15.8172 -9 ]
[.5034 .05901 2.18278 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.29165 .07573 -9.31117 -9.8125 ]
[.29165 .07573 .68883 0 ]
[.70361 -0.00072 0 -6.25801 ]
[.70361 -0.00072 6 2.74199 ]
[.82501 .18517 0 -6.07699 ]
[.82501 .18517 18 2.92301 ]
[.92763 .34231 0 -5.92977 ]
[.92763 .34231 6 3.07023 ]
[.91861 .21225 0 -6.57576 ]
[.91861 .21225 10.0625 3.23674 ]
[.01698 .30981 -36 -2.7801 ]
[.01698 .30981 0 6.2199 ]
[.00392 .3917 -6 -2.8496 ]
[.00392 .3917 0 6.1504 ]
[-0.00985 .478 -30 -2.92324 ]
[-0.00985 .478 0 6.07676 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -98.6875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
74.312 11.250 moveto
(@) show
80.312 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
86.312 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
92.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
98.375 11.250 moveto
(D) show
104.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
116.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
122.375 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
128.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
134.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.04003 .25401 m
.04482 .2585 L
s
[(-1)] .03045 .24505 1 .93576 Mshowa
.18786 .19613 m
.19242 .20085 L
s
[(-0.5)] .17875 .18668 .96492 1 Mshowa
.34468 .13472 m
.34896 .13969 L
s
[(0)] .33612 .12478 .8612 1 Mshowa
.51132 .06947 m
.51528 .0747 L
s
[(0.5)] .5034 .05901 .75747 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06892 .2427 m
.07176 .24542 L
s
.09814 .23126 m
.10096 .23401 L
s
.1277 .21969 m
.13049 .22246 L
s
.1576 .20797 m
.16037 .21078 L
s
.21848 .18414 m
.22119 .187 L
s
.24947 .172 m
.25214 .1749 L
s
.28082 .15973 m
.28346 .16265 L
s
.31256 .1473 m
.31516 .15025 L
s
.37719 .12199 m
.37973 .125 L
s
.41011 .1091 m
.4126 .11215 L
s
.44343 .09606 m
.44588 .09913 L
s
.47716 .08285 m
.47958 .08595 L
s
.54591 .05593 m
.54824 .0591 L
s
.58094 .04221 m
.58323 .04541 L
s
.61641 .02832 m
.61866 .03155 L
s
.65234 .01425 m
.65454 .01752 L
s
gsave
.29165 .07573 -70.3112 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69139 .00406 m
.68528 .00644 L
s
[(0)] .70361 -0.00072 -1 .39067 Mshowa
.81263 .18951 m
.80643 .19168 L
s
[(0.5)] .82501 .18517 -1 .35044 Mshowa
.91512 .34629 m
.90887 .34827 L
s
[(1)] .92763 .34231 -1 .31773 Mshowa
.125 Mabswid
.71738 .04381 m
.7137 .04521 L
s
.74245 .08216 m
.73876 .08354 L
s
.76665 .11918 m
.76296 .12054 L
s
.79003 .15495 m
.78632 .15627 L
s
.83448 .22293 m
.83075 .22421 L
s
.85562 .25527 m
.85189 .25653 L
s
.87608 .28658 m
.87235 .28781 L
s
.89591 .3169 m
.89216 .31811 L
s
.93375 .37478 m
.92999 .37595 L
s
.95181 .40242 m
.94805 .40357 L
s
gsave
.91861 .21225 -61 -10.5758 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.062 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.062 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02924 .30512 m
.03537 .30278 L
s
[(-0.001)] .01698 .30981 1 -0.3822 Mshowa
.01623 .38718 m
.02239 .38492 L
s
[(0)] .00392 .3917 1 -0.36675 Mshowa
.00253 .47366 m
.00872 .47149 L
s
[(0.001)] -0.00985 .478 1 -0.35039 Mshowa
.125 Mabswid
.02669 .3212 m
.03037 .3198 L
s
.02412 .33744 m
.0278 .33605 L
s
.02152 .35385 m
.02521 .35247 L
s
.01889 .37043 m
.02258 .36906 L
s
.01355 .40411 m
.01725 .40277 L
s
.01084 .42122 m
.01454 .41989 L
s
.0081 .43852 m
.01181 .43719 L
s
.00533 .45599 m
.00904 .45468 L
s
.03176 .28921 m
.03543 .2878 L
s
.03426 .27346 m
.03793 .27204 L
s
.03673 .25787 m
.04039 .25644 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.654 .753 .922 r
.39463 .71356 .40109 .71913 .41189 .71612 .40546 .71053 Metetra
.654 .753 .922 r
.40546 .71053 .41189 .71612 .42273 .71309 .41633 .70748 Metetra
.654 .753 .922 r
.41633 .70748 .42273 .71309 .43361 .71006 .42724 .70442 Metetra
.654 .753 .922 r
.42724 .70442 .43361 .71006 .44454 .70701 .4382 .70135 Metetra
.654 .753 .922 r
.4382 .70135 .44454 .70701 .45552 .70395 .4492 .69827 Metetra
.654 .753 .922 r
.4492 .69827 .45552 .70395 .46653 .70088 .46025 .69518 Metetra
.654 .753 .922 r
.46025 .69518 .46653 .70088 .4776 .6978 .47134 .69207 Metetra
.654 .753 .922 r
.47134 .69207 .4776 .6978 .48871 .6947 .48248 .68895 Metetra
.654 .753 .922 r
.48248 .68895 .48871 .6947 .49986 .69159 .49366 .68582 Metetra
.654 .753 .922 r
.49366 .68582 .49986 .69159 .51106 .68847 .50489 .68267 Metetra
.654 .753 .922 r
.50489 .68267 .51106 .68847 .5223 .68534 .51616 .67951 Metetra
.654 .753 .922 r
.51616 .67951 .5223 .68534 .53359 .68219 .52749 .67634 Metetra
.654 .753 .922 r
.52749 .67634 .53359 .68219 .54493 .67903 .53885 .67316 Metetra
.654 .753 .922 r
.53885 .67316 .54493 .67903 .55632 .67585 .55027 .66996 Metetra
.654 .753 .922 r
.55027 .66996 .55632 .67585 .56775 .67267 .56173 .66675 Metetra
.654 .753 .922 r
.56173 .66675 .56775 .67267 .57923 .66947 .57324 .66353 Metetra
.654 .753 .922 r
.57324 .66353 .57923 .66947 .59075 .66625 .5848 .66029 Metetra
.654 .753 .922 r
.5848 .66029 .59075 .66625 .60233 .66303 .59641 .65704 Metetra
.654 .753 .922 r
.59641 .65704 .60233 .66303 .61395 .65979 .60806 .65377 Metetra
.654 .753 .922 r
.60806 .65377 .61395 .65979 .62562 .65654 .61977 .65049 Metetra
.654 .753 .922 r
.61977 .65049 .62562 .65654 .63734 .65327 .63152 .6472 Metetra
.654 .753 .922 r
.63152 .6472 .63734 .65327 .64911 .64999 .64332 .64389 Metetra
.654 .753 .922 r
.64332 .64389 .64911 .64999 .66093 .64669 .65518 .64057 Metetra
.654 .753 .922 r
.65518 .64057 .66093 .64669 .6728 .64338 .66708 .63724 Metetra
.654 .753 .922 r
.66708 .63724 .6728 .64338 .68472 .64006 .67903 .63389 Metetra
.654 .753 .922 r
.67903 .63389 .68472 .64006 .69669 .63673 .69103 .63053 Metetra
.654 .753 .922 r
.69103 .63053 .69669 .63673 .70871 .63338 .70309 .62715 Metetra
.654 .753 .922 r
.70309 .62715 .70871 .63338 .72078 .63001 .7152 .62376 Metetra
.654 .753 .922 r
.7152 .62376 .72078 .63001 .7329 .62663 .72735 .62035 Metetra
.654 .753 .922 r
.72735 .62035 .7329 .62663 .74507 .62324 .73956 .61693 Metetra
.654 .753 .922 r
.73956 .61693 .74507 .62324 .7573 .61983 .75183 .6135 Metetra
.654 .753 .922 r
.75183 .6135 .7573 .61983 .76958 .61641 .76414 .61005 Metetra
.654 .753 .922 r
.76414 .61005 .76958 .61641 .78191 .61297 .77651 .60658 Metetra
.654 .753 .922 r
.77651 .60658 .78191 .61297 .79429 .60952 .78893 .60311 Metetra
.654 .753 .922 r
.78893 .60311 .79429 .60952 .80673 .60605 .80141 .59961 Metetra
.654 .753 .922 r
.80141 .59961 .80673 .60605 .81922 .60257 .81394 .5961 Metetra
.654 .753 .922 r
.81394 .5961 .81922 .60257 .83177 .59907 .82652 .59258 Metetra
.654 .753 .922 r
.82652 .59258 .83177 .59907 .84437 .59556 .83916 .58903 Metetra
.654 .753 .922 r
.83916 .58903 .84437 .59556 .85702 .59203 .85185 .58548 Metetra
.654 .753 .922 r
.85185 .58548 .85702 .59203 .86973 .58849 .8646 .58191 Metetra
.654 .753 .922 r
.8646 .58191 .86973 .58849 .88249 .58493 .87741 .57832 Metetra
.654 .753 .922 r
.87741 .57832 .88249 .58493 .89532 .58136 .89027 .57472 Metetra
.654 .753 .922 r
.89027 .57472 .89532 .58136 .90819 .57777 .90319 .5711 Metetra
.654 .753 .922 r
.90319 .5711 .90819 .57777 .92113 .57416 .91617 .56746 Metetra
.654 .753 .922 r
.91617 .56746 .92113 .57416 .93412 .57054 .9292 .56381 Metetra
.654 .753 .922 r
.9292 .56381 .93412 .57054 .94717 .5669 .94229 .56015 Metetra
.654 .753 .922 r
.94229 .56015 .94717 .5669 .96027 .56325 .95544 .55646 Metetra
.654 .753 .922 r
.95544 .55646 .96027 .56325 .97344 .55958 .96865 .55276 Metetra
.654 .753 .922 r
.96865 .55276 .97344 .55958 .98666 .55589 .98191 .54905 Metetra
.654 .753 .922 r
.38813 .70795 .39463 .71356 .40546 .71053 .39898 .7049 Metetra
.654 .753 .922 r
.39898 .7049 .40546 .71053 .41633 .70748 .40988 .70183 Metetra
.654 .753 .922 r
.40988 .70183 .41633 .70748 .42724 .70442 .42082 .69875 Metetra
.654 .753 .922 r
.42082 .69875 .42724 .70442 .4382 .70135 .43181 .69566 Metetra
.654 .753 .922 r
.43181 .69566 .4382 .70135 .4492 .69827 .44284 .69255 Metetra
.654 .753 .922 r
.44284 .69255 .4492 .69827 .46025 .69518 .45391 .68943 Metetra
.654 .753 .922 r
.45391 .68943 .46025 .69518 .47134 .69207 .46503 .6863 Metetra
.654 .753 .922 r
.46503 .6863 .47134 .69207 .48248 .68895 .4762 .68316 Metetra
.654 .753 .922 r
.4762 .68316 .48248 .68895 .49366 .68582 .48741 .68 Metetra
.654 .753 .922 r
.48741 .68 .49366 .68582 .50489 .68267 .49867 .67683 Metetra
.654 .753 .922 r
.49867 .67683 .50489 .68267 .51616 .67951 .50998 .67365 Metetra
.654 .753 .922 r
.50998 .67365 .51616 .67951 .52749 .67634 .52133 .67045 Metetra
.654 .753 .922 r
.52133 .67045 .52749 .67634 .53885 .67316 .53273 .66724 Metetra
.654 .753 .922 r
.53273 .66724 .53885 .67316 .55027 .66996 .54418 .66402 Metetra
.654 .753 .922 r
.54418 .66402 .55027 .66996 .56173 .66675 .55567 .66079 Metetra
.654 .753 .922 r
.55567 .66079 .56173 .66675 .57324 .66353 .56721 .65754 Metetra
.654 .753 .922 r
.56721 .65754 .57324 .66353 .5848 .66029 .5788 .65427 Metetra
.654 .753 .922 r
.5788 .65427 .5848 .66029 .59641 .65704 .59044 .651 Metetra
.654 .753 .922 r
.59044 .651 .59641 .65704 .60806 .65377 .60213 .64771 Metetra
.654 .753 .922 r
.60213 .64771 .60806 .65377 .61977 .65049 .61387 .6444 Metetra
.654 .753 .922 r
.61387 .6444 .61977 .65049 .63152 .6472 .62565 .64109 Metetra
.654 .753 .922 r
.62565 .64109 .63152 .6472 .64332 .64389 .63749 .63775 Metetra
.654 .753 .922 r
.63749 .63775 .64332 .64389 .65518 .64057 .64938 .63441 Metetra
.654 .753 .922 r
.64938 .63441 .65518 .64057 .66708 .63724 .66131 .63105 Metetra
.654 .753 .922 r
.66131 .63105 .66708 .63724 .67903 .63389 .6733 .62767 Metetra
.654 .753 .922 r
.6733 .62767 .67903 .63389 .69103 .63053 .68534 .62428 Metetra
.654 .753 .922 r
.68534 .62428 .69103 .63053 .70309 .62715 .69743 .62088 Metetra
.654 .753 .922 r
.69743 .62088 .70309 .62715 .7152 .62376 .70957 .61746 Metetra
.654 .753 .922 r
.70957 .61746 .7152 .62376 .72735 .62035 .72177 .61403 Metetra
.654 .753 .922 r
.72177 .61403 .72735 .62035 .73956 .61693 .73401 .61058 Metetra
.654 .753 .922 r
.73401 .61058 .73956 .61693 .75183 .6135 .74631 .60712 Metetra
.654 .753 .922 r
.74631 .60712 .75183 .6135 .76414 .61005 .75866 .60364 Metetra
.654 .753 .922 r
.75866 .60364 .76414 .61005 .77651 .60658 .77107 .60015 Metetra
.654 .753 .922 r
.77107 .60015 .77651 .60658 .78893 .60311 .78353 .59664 Metetra
.654 .753 .922 r
.78353 .59664 .78893 .60311 .80141 .59961 .79604 .59312 Metetra
.654 .753 .922 r
.79604 .59312 .80141 .59961 .81394 .5961 .80861 .58958 Metetra
.654 .753 .922 r
.80861 .58958 .81394 .5961 .82652 .59258 .82123 .58603 Metetra
.654 .753 .922 r
.82123 .58603 .82652 .59258 .83916 .58903 .83391 .58246 Metetra
.654 .753 .922 r
.83391 .58246 .83916 .58903 .85185 .58548 .84665 .57887 Metetra
.654 .753 .922 r
.84665 .57887 .85185 .58548 .8646 .58191 .85944 .57527 Metetra
.654 .753 .922 r
.85944 .57527 .8646 .58191 .87741 .57832 .87228 .57166 Metetra
.654 .753 .922 r
.87228 .57166 .87741 .57832 .89027 .57472 .88519 .56802 Metetra
.654 .753 .922 r
.88519 .56802 .89027 .57472 .90319 .5711 .89815 .56438 Metetra
.654 .753 .922 r
.89815 .56438 .90319 .5711 .91617 .56746 .91116 .56071 Metetra
.654 .753 .922 r
.91116 .56071 .91617 .56746 .9292 .56381 .92424 .55703 Metetra
.654 .753 .922 r
.92424 .55703 .9292 .56381 .94229 .56015 .93737 .55333 Metetra
.654 .753 .922 r
.93737 .55333 .94229 .56015 .95544 .55646 .95056 .54962 Metetra
.654 .753 .922 r
.95056 .54962 .95544 .55646 .96865 .55276 .96382 .54589 Metetra
.654 .753 .922 r
.96382 .54589 .96865 .55276 .98191 .54905 .97713 .54214 Metetra
.654 .753 .922 r
.38158 .7023 .38813 .70795 .39898 .7049 .39246 .69922 Metetra
.654 .753 .922 r
.39246 .69922 .39898 .7049 .40988 .70183 .40339 .69613 Metetra
.654 .753 .922 r
.40339 .69613 .40988 .70183 .42082 .69875 .41435 .69303 Metetra
.654 .753 .922 r
.41435 .69303 .42082 .69875 .43181 .69566 .42537 .68991 Metetra
.654 .753 .922 r
.42537 .68991 .43181 .69566 .44284 .69255 .43643 .68678 Metetra
.654 .753 .922 r
.43643 .68678 .44284 .69255 .45391 .68943 .44753 .68364 Metetra
.654 .753 .922 r
.44753 .68364 .45391 .68943 .46503 .6863 .45868 .68049 Metetra
.654 .753 .922 r
.45868 .68049 .46503 .6863 .4762 .68316 .46988 .67732 Metetra
.654 .753 .922 r
.46988 .67732 .4762 .68316 .48741 .68 .48112 .67414 Metetra
.654 .753 .922 r
.48112 .67414 .48741 .68 .49867 .67683 .49241 .67095 Metetra
.654 .753 .922 r
.49241 .67095 .49867 .67683 .50998 .67365 .50374 .66774 Metetra
.654 .753 .922 r
.50374 .66774 .50998 .67365 .52133 .67045 .51513 .66452 Metetra
.654 .753 .922 r
.51513 .66452 .52133 .67045 .53273 .66724 .52656 .66129 Metetra
.654 .753 .922 r
.52656 .66129 .53273 .66724 .54418 .66402 .53803 .65804 Metetra
.654 .753 .922 r
.53803 .65804 .54418 .66402 .55567 .66079 .54956 .65478 Metetra
.654 .753 .922 r
.54956 .65478 .55567 .66079 .56721 .65754 .56113 .6515 Metetra
.654 .753 .922 r
.56113 .6515 .56721 .65754 .5788 .65427 .57276 .64822 Metetra
.654 .753 .922 r
.57276 .64822 .5788 .65427 .59044 .651 .58443 .64491 Metetra
.654 .753 .922 r
.58443 .64491 .59044 .651 .60213 .64771 .59615 .6416 Metetra
.654 .753 .922 r
.59615 .6416 .60213 .64771 .61387 .6444 .60792 .63827 Metetra
.654 .753 .922 r
.60792 .63827 .61387 .6444 .62565 .64109 .61974 .63492 Metetra
.654 .753 .922 r
.61974 .63492 .62565 .64109 .63749 .63775 .63161 .63157 Metetra
.654 .753 .922 r
.63161 .63157 .63749 .63775 .64938 .63441 .64353 .62819 Metetra
.654 .753 .922 r
.64353 .62819 .64938 .63441 .66131 .63105 .6555 .62481 Metetra
.654 .753 .922 r
.6555 .62481 .66131 .63105 .6733 .62767 .66752 .6214 Metetra
.654 .753 .922 r
.66752 .6214 .6733 .62767 .68534 .62428 .6796 .61799 Metetra
.654 .753 .922 r
.6796 .61799 .68534 .62428 .69743 .62088 .69172 .61456 Metetra
.654 .753 .922 r
.69172 .61456 .69743 .62088 .70957 .61746 .7039 .61111 Metetra
.654 .753 .922 r
.7039 .61111 .70957 .61746 .72177 .61403 .71613 .60765 Metetra
.654 .753 .922 r
.71613 .60765 .72177 .61403 .73401 .61058 .72842 .60418 Metetra
.654 .753 .922 r
.72842 .60418 .73401 .61058 .74631 .60712 .74075 .60069 Metetra
.654 .753 .922 r
.74075 .60069 .74631 .60712 .75866 .60364 .75314 .59718 Metetra
.654 .753 .922 r
.75314 .59718 .75866 .60364 .77107 .60015 .76558 .59366 Metetra
.654 .753 .922 r
.76558 .59366 .77107 .60015 .78353 .59664 .77808 .59013 Metetra
.654 .753 .922 r
.77808 .59013 .78353 .59664 .79604 .59312 .79064 .58657 Metetra
.654 .753 .922 r
.79064 .58657 .79604 .59312 .80861 .58958 .80324 .58301 Metetra
.654 .753 .922 r
.80324 .58301 .80861 .58958 .82123 .58603 .8159 .57943 Metetra
.654 .753 .922 r
.8159 .57943 .82123 .58603 .83391 .58246 .82862 .57583 Metetra
.654 .753 .922 r
.82862 .57583 .83391 .58246 .84665 .57887 .8414 .57221 Metetra
.654 .753 .922 r
.8414 .57221 .84665 .57887 .85944 .57527 .85423 .56858 Metetra
.654 .753 .922 r
.85423 .56858 .85944 .57527 .87228 .57166 .86711 .56494 Metetra
.654 .753 .922 r
.86711 .56494 .87228 .57166 .88519 .56802 .88006 .56128 Metetra
.654 .753 .922 r
.88006 .56128 .88519 .56802 .89815 .56438 .89306 .5576 Metetra
.654 .753 .922 r
.89306 .5576 .89815 .56438 .91116 .56071 .90612 .5539 Metetra
.654 .753 .922 r
.90612 .5539 .91116 .56071 .92424 .55703 .91924 .55019 Metetra
.654 .753 .922 r
.91924 .55019 .92424 .55703 .93737 .55333 .93242 .54646 Metetra
.654 .753 .922 r
.93242 .54646 .93737 .55333 .95056 .54962 .94565 .54272 Metetra
.654 .753 .922 r
.94565 .54272 .95056 .54962 .96382 .54589 .95895 .53896 Metetra
.654 .753 .922 r
.95895 .53896 .96382 .54589 .97713 .54214 .9723 .53518 Metetra
.654 .753 .922 r
.37498 .69661 .38158 .7023 .39246 .69922 .38589 .69351 Metetra
.654 .753 .922 r
.38589 .69351 .39246 .69922 .40339 .69613 .39684 .69039 Metetra
.654 .753 .922 r
.39684 .69039 .40339 .69613 .41435 .69303 .40784 .68727 Metetra
.654 .753 .922 r
.40784 .68727 .41435 .69303 .42537 .68991 .41888 .68413 Metetra
.654 .753 .922 r
.41888 .68413 .42537 .68991 .43643 .68678 .42997 .68097 Metetra
.654 .753 .922 r
.42997 .68097 .43643 .68678 .44753 .68364 .4411 .67781 Metetra
.654 .753 .922 r
.4411 .67781 .44753 .68364 .45868 .68049 .45228 .67463 Metetra
.654 .753 .922 r
.45228 .67463 .45868 .68049 .46988 .67732 .46351 .67144 Metetra
.654 .753 .922 r
.46351 .67144 .46988 .67732 .48112 .67414 .47478 .66823 Metetra
.654 .753 .922 r
.47478 .66823 .48112 .67414 .49241 .67095 .4861 .66502 Metetra
.654 .753 .922 r
.4861 .66502 .49241 .67095 .50374 .66774 .49746 .66178 Metetra
.654 .753 .922 r
.49746 .66178 .50374 .66774 .51513 .66452 .50888 .65854 Metetra
.654 .753 .922 r
.50888 .65854 .51513 .66452 .52656 .66129 .52034 .65528 Metetra
.654 .753 .922 r
.52034 .65528 .52656 .66129 .53803 .65804 .53185 .65201 Metetra
.654 .753 .922 r
.53185 .65201 .53803 .65804 .54956 .65478 .5434 .64872 Metetra
.654 .753 .922 r
.5434 .64872 .54956 .65478 .56113 .6515 .55501 .64542 Metetra
.654 .753 .922 r
.55501 .64542 .56113 .6515 .57276 .64822 .56666 .64211 Metetra
.654 .753 .922 r
.56666 .64211 .57276 .64822 .58443 .64491 .57837 .63878 Metetra
.654 .753 .922 r
.57837 .63878 .58443 .64491 .59615 .6416 .59012 .63544 Metetra
.654 .753 .922 r
.59012 .63544 .59615 .6416 .60792 .63827 .60193 .63208 Metetra
.654 .753 .922 r
.60193 .63208 .60792 .63827 .61974 .63492 .61378 .62871 Metetra
.654 .753 .922 r
.61378 .62871 .61974 .63492 .63161 .63157 .62568 .62533 Metetra
.654 .753 .922 r
.62568 .62533 .63161 .63157 .64353 .62819 .63764 .62193 Metetra
.654 .753 .922 r
.63764 .62193 .64353 .62819 .6555 .62481 .64964 .61851 Metetra
.654 .753 .922 r
.64964 .61851 .6555 .62481 .66752 .6214 .6617 .61509 Metetra
.654 .753 .922 r
.6617 .61509 .66752 .6214 .6796 .61799 .67381 .61164 Metetra
.654 .753 .922 r
.67381 .61164 .6796 .61799 .69172 .61456 .68597 .60819 Metetra
.654 .753 .922 r
.68597 .60819 .69172 .61456 .7039 .61111 .69819 .60471 Metetra
.654 .753 .922 r
.69819 .60471 .7039 .61111 .71613 .60765 .71045 .60123 Metetra
.654 .753 .922 r
.71045 .60123 .71613 .60765 .72842 .60418 .72277 .59772 Metetra
.654 .753 .922 r
.72277 .59772 .72842 .60418 .74075 .60069 .73515 .5942 Metetra
.654 .753 .922 r
.73515 .5942 .74075 .60069 .75314 .59718 .74757 .59067 Metetra
.654 .753 .922 r
.74757 .59067 .75314 .59718 .76558 .59366 .76006 .58712 Metetra
.654 .753 .922 r
.76006 .58712 .76558 .59366 .77808 .59013 .77259 .58356 Metetra
.654 .753 .922 r
.77259 .58356 .77808 .59013 .79064 .58657 .78518 .57998 Metetra
.654 .753 .922 r
.78518 .57998 .79064 .58657 .80324 .58301 .79783 .57638 Metetra
.654 .753 .922 r
.79783 .57638 .80324 .58301 .8159 .57943 .81053 .57277 Metetra
.654 .753 .922 r
.81053 .57277 .8159 .57943 .82862 .57583 .82329 .56914 Metetra
.654 .753 .922 r
.82329 .56914 .82862 .57583 .8414 .57221 .8361 .5655 Metetra
.654 .753 .922 r
.8361 .5655 .8414 .57221 .85423 .56858 .84898 .56184 Metetra
.654 .753 .922 r
.84898 .56184 .85423 .56858 .86711 .56494 .8619 .55816 Metetra
.654 .753 .922 r
.8619 .55816 .86711 .56494 .88006 .56128 .87489 .55447 Metetra
.654 .753 .922 r
.87489 .55447 .88006 .56128 .89306 .5576 .88793 .55076 Metetra
.654 .753 .922 r
.88793 .55076 .89306 .5576 .90612 .5539 .90104 .54704 Metetra
.654 .753 .922 r
.90104 .54704 .90612 .5539 .91924 .55019 .9142 .5433 Metetra
.654 .753 .922 r
.9142 .5433 .91924 .55019 .93242 .54646 .92742 .53954 Metetra
.654 .753 .922 r
.92742 .53954 .93242 .54646 .94565 .54272 .9407 .53576 Metetra
.654 .753 .922 r
.9407 .53576 .94565 .54272 .95895 .53896 .95404 .53197 Metetra
.654 .753 .922 r
.95404 .53197 .95895 .53896 .9723 .53518 .96743 .52816 Metetra
.654 .753 .922 r
.36833 .69087 .37498 .69661 .38589 .69351 .37927 .68775 Metetra
.654 .753 .922 r
.37927 .68775 .38589 .69351 .39684 .69039 .39025 .68461 Metetra
.654 .753 .922 r
.39025 .68461 .39684 .69039 .40784 .68727 .40127 .68146 Metetra
.654 .753 .922 r
.40127 .68146 .40784 .68727 .41888 .68413 .41234 .6783 Metetra
.654 .753 .922 r
.41234 .6783 .41888 .68413 .42997 .68097 .42346 .67512 Metetra
.654 .753 .922 r
.42346 .67512 .42997 .68097 .4411 .67781 .43462 .67193 Metetra
.654 .753 .922 r
.43462 .67193 .4411 .67781 .45228 .67463 .44583 .66873 Metetra
.654 .753 .922 r
.44583 .66873 .45228 .67463 .46351 .67144 .45709 .66551 Metetra
.654 .753 .922 r
.45709 .66551 .46351 .67144 .47478 .66823 .46839 .66228 Metetra
.654 .753 .922 r
.46839 .66228 .47478 .66823 .4861 .66502 .47974 .65904 Metetra
.654 .753 .922 r
.47974 .65904 .4861 .66502 .49746 .66178 .49113 .65578 Metetra
.654 .753 .922 r
.49113 .65578 .49746 .66178 .50888 .65854 .50258 .65251 Metetra
.654 .753 .922 r
.50258 .65251 .50888 .65854 .52034 .65528 .51407 .64923 Metetra
.654 .753 .922 r
.51407 .64923 .52034 .65528 .53185 .65201 .52561 .64593 Metetra
.654 .753 .922 r
.52561 .64593 .53185 .65201 .5434 .64872 .5372 .64262 Metetra
.654 .753 .922 r
.5372 .64262 .5434 .64872 .55501 .64542 .54884 .63929 Metetra
.654 .753 .922 r
.54884 .63929 .55501 .64542 .56666 .64211 .56052 .63595 Metetra
.654 .753 .922 r
.56052 .63595 .56666 .64211 .57837 .63878 .57226 .6326 Metetra
.654 .753 .922 r
.57226 .6326 .57837 .63878 .59012 .63544 .58405 .62923 Metetra
.654 .753 .922 r
.58405 .62923 .59012 .63544 .60193 .63208 .59588 .62585 Metetra
.654 .753 .922 r
.59588 .62585 .60193 .63208 .61378 .62871 .60777 .62245 Metetra
.654 .753 .922 r
.60777 .62245 .61378 .62871 .62568 .62533 .61971 .61904 Metetra
.654 .753 .922 r
.61971 .61904 .62568 .62533 .63764 .62193 .6317 .61562 Metetra
.654 .753 .922 r
.6317 .61562 .63764 .62193 .64964 .61851 .64374 .61217 Metetra
.654 .753 .922 r
.64374 .61217 .64964 .61851 .6617 .61509 .65583 .60872 Metetra
.654 .753 .922 r
.65583 .60872 .6617 .61509 .67381 .61164 .66798 .60525 Metetra
.654 .753 .922 r
.66798 .60525 .67381 .61164 .68597 .60819 .68018 .60176 Metetra
.654 .753 .922 r
.68018 .60176 .68597 .60819 .69819 .60471 .69243 .59826 Metetra
.654 .753 .922 r
.69243 .59826 .69819 .60471 .71045 .60123 .70473 .59475 Metetra
.654 .753 .922 r
.70473 .59475 .71045 .60123 .72277 .59772 .71709 .59122 Metetra
.654 .753 .922 r
.71709 .59122 .72277 .59772 .73515 .5942 .7295 .58767 Metetra
.654 .753 .922 r
.7295 .58767 .73515 .5942 .74757 .59067 .74196 .58411 Metetra
.654 .753 .922 r
.74196 .58411 .74757 .59067 .76006 .58712 .75448 .58053 Metetra
.654 .753 .922 r
.75448 .58053 .76006 .58712 .77259 .58356 .76706 .57694 Metetra
.654 .753 .922 r
.76706 .57694 .77259 .58356 .78518 .57998 .77969 .57333 Metetra
.654 .753 .922 r
.77969 .57333 .78518 .57998 .79783 .57638 .79237 .5697 Metetra
.654 .753 .922 r
.79237 .5697 .79783 .57638 .81053 .57277 .80512 .56606 Metetra
.654 .753 .922 r
.80512 .56606 .81053 .57277 .82329 .56914 .81791 .5624 Metetra
.654 .753 .922 r
.81791 .5624 .82329 .56914 .8361 .5655 .83077 .55873 Metetra
.654 .753 .922 r
.83077 .55873 .8361 .5655 .84898 .56184 .84368 .55504 Metetra
.654 .753 .922 r
.84368 .55504 .84898 .56184 .8619 .55816 .85665 .55134 Metetra
.654 .753 .922 r
.85665 .55134 .8619 .55816 .87489 .55447 .86968 .54761 Metetra
.654 .753 .922 r
.86968 .54761 .87489 .55447 .88793 .55076 .88276 .54387 Metetra
.654 .753 .922 r
.88276 .54387 .88793 .55076 .90104 .54704 .89591 .54012 Metetra
.654 .753 .922 r
.89591 .54012 .90104 .54704 .9142 .5433 .90911 .53634 Metetra
.654 .753 .922 r
.90911 .53634 .9142 .5433 .92742 .53954 .92238 .53255 Metetra
.654 .753 .922 r
.92238 .53255 .92742 .53954 .9407 .53576 .9357 .52875 Metetra
.654 .753 .922 r
.9357 .52875 .9407 .53576 .95404 .53197 .94908 .52492 Metetra
.654 .753 .922 r
.94908 .52492 .95404 .53197 .96743 .52816 .96253 .52108 Metetra
.654 .753 .922 r
.36163 .68509 .36833 .69087 .37927 .68775 .3726 .68195 Metetra
.654 .753 .922 r
.3726 .68195 .37927 .68775 .39025 .68461 .3836 .67878 Metetra
.654 .753 .922 r
.3836 .67878 .39025 .68461 .40127 .68146 .39466 .67561 Metetra
.654 .753 .922 r
.39466 .67561 .40127 .68146 .41234 .6783 .40576 .67242 Metetra
.654 .753 .922 r
.40576 .67242 .41234 .6783 .42346 .67512 .4169 .66922 Metetra
.654 .753 .922 r
.4169 .66922 .42346 .67512 .43462 .67193 .42809 .66601 Metetra
.654 .753 .922 r
.42809 .66601 .43462 .67193 .44583 .66873 .43933 .66278 Metetra
.654 .753 .922 r
.43933 .66278 .44583 .66873 .45709 .66551 .45062 .65954 Metetra
.654 .753 .922 r
.45062 .65954 .45709 .66551 .46839 .66228 .46195 .65628 Metetra
.654 .753 .922 r
.46195 .65628 .46839 .66228 .47974 .65904 .47333 .65302 Metetra
.654 .753 .922 r
.47333 .65302 .47974 .65904 .49113 .65578 .48475 .64973 Metetra
.654 .753 .922 r
.48475 .64973 .49113 .65578 .50258 .65251 .49623 .64644 Metetra
.654 .753 .922 r
.49623 .64644 .50258 .65251 .51407 .64923 .50775 .64313 Metetra
.654 .753 .922 r
.50775 .64313 .51407 .64923 .52561 .64593 .51932 .63981 Metetra
.654 .753 .922 r
.51932 .63981 .52561 .64593 .5372 .64262 .53095 .63647 Metetra
.654 .753 .922 r
.53095 .63647 .5372 .64262 .54884 .63929 .54262 .63312 Metetra
.654 .753 .922 r
.54262 .63312 .54884 .63929 .56052 .63595 .55434 .62975 Metetra
.654 .753 .922 r
.55434 .62975 .56052 .63595 .57226 .6326 .56611 .62637 Metetra
.654 .753 .922 r
.56611 .62637 .57226 .6326 .58405 .62923 .57793 .62298 Metetra
.654 .753 .922 r
.57793 .62298 .58405 .62923 .59588 .62585 .5898 .61957 Metetra
.654 .753 .922 r
.5898 .61957 .59588 .62585 .60777 .62245 .60172 .61614 Metetra
.654 .753 .922 r
.60172 .61614 .60777 .62245 .61971 .61904 .61369 .6127 Metetra
.654 .753 .922 r
.61369 .6127 .61971 .61904 .6317 .61562 .62571 .60925 Metetra
.654 .753 .922 r
.62571 .60925 .6317 .61562 .64374 .61217 .63779 .60578 Metetra
.654 .753 .922 r
.63779 .60578 .64374 .61217 .65583 .60872 .64992 .6023 Metetra
.654 .753 .922 r
.64992 .6023 .65583 .60872 .66798 .60525 .6621 .5988 Metetra
.654 .753 .922 r
.6621 .5988 .66798 .60525 .68018 .60176 .67433 .59529 Metetra
.654 .753 .922 r
.67433 .59529 .68018 .60176 .69243 .59826 .68662 .59176 Metetra
.654 .753 .922 r
.68662 .59176 .69243 .59826 .70473 .59475 .69896 .58822 Metetra
.654 .753 .922 r
.69896 .58822 .70473 .59475 .71709 .59122 .71135 .58466 Metetra
.654 .753 .922 r
.71135 .58466 .71709 .59122 .7295 .58767 .7238 .58108 Metetra
.654 .753 .922 r
.7238 .58108 .7295 .58767 .74196 .58411 .73631 .57749 Metetra
.654 .753 .922 r
.73631 .57749 .74196 .58411 .75448 .58053 .74886 .57388 Metetra
.654 .753 .922 r
.74886 .57388 .75448 .58053 .76706 .57694 .76148 .57026 Metetra
.654 .753 .922 r
.76148 .57026 .76706 .57694 .77969 .57333 .77415 .56662 Metetra
.654 .753 .922 r
.77415 .56662 .77969 .57333 .79237 .5697 .78687 .56297 Metetra
.654 .753 .922 r
.78687 .56297 .79237 .5697 .80512 .56606 .79965 .5593 Metetra
.654 .753 .922 r
.79965 .5593 .80512 .56606 .81791 .5624 .81249 .55561 Metetra
.654 .753 .922 r
.81249 .55561 .81791 .5624 .83077 .55873 .82539 .55191 Metetra
.654 .753 .922 r
.82539 .55191 .83077 .55873 .84368 .55504 .83834 .54819 Metetra
.654 .753 .922 r
.83834 .54819 .84368 .55504 .85665 .55134 .85135 .54445 Metetra
.654 .753 .922 r
.85135 .54445 .85665 .55134 .86968 .54761 .86442 .5407 Metetra
.654 .753 .922 r
.86442 .5407 .86968 .54761 .88276 .54387 .87755 .53693 Metetra
.654 .753 .922 r
.87755 .53693 .88276 .54387 .89591 .54012 .89074 .53314 Metetra
.654 .753 .922 r
.89074 .53314 .89591 .54012 .90911 .53634 .90399 .52933 Metetra
.654 .753 .922 r
.90399 .52933 .90911 .53634 .92238 .53255 .91729 .52551 Metetra
.654 .753 .922 r
.91729 .52551 .92238 .53255 .9357 .52875 .93066 .52167 Metetra
.654 .753 .922 r
.93066 .52167 .9357 .52875 .94908 .52492 .94409 .51782 Metetra
.654 .753 .922 r
.94409 .51782 .94908 .52492 .96253 .52108 .95758 .51394 Metetra
.654 .753 .922 r
.35488 .67927 .36163 .68509 .3726 .68195 .36587 .6761 Metetra
.654 .753 .922 r
.36587 .6761 .3726 .68195 .3836 .67878 .37691 .67291 Metetra
.654 .753 .922 r
.37691 .67291 .3836 .67878 .39466 .67561 .38799 .66971 Metetra
.654 .753 .922 r
.38799 .66971 .39466 .67561 .40576 .67242 .39912 .6665 Metetra
.654 .753 .922 r
.39912 .6665 .40576 .67242 .4169 .66922 .41029 .66328 Metetra
.654 .753 .922 r
.41029 .66328 .4169 .66922 .42809 .66601 .42151 .66004 Metetra
.654 .753 .922 r
.42151 .66004 .42809 .66601 .43933 .66278 .43278 .65679 Metetra
.654 .753 .922 r
.43278 .65679 .43933 .66278 .45062 .65954 .4441 .65352 Metetra
.654 .753 .922 r
.4441 .65352 .45062 .65954 .46195 .65628 .45546 .65024 Metetra
.654 .753 .922 r
.45546 .65024 .46195 .65628 .47333 .65302 .46687 .64695 Metetra
.654 .753 .922 r
.46687 .64695 .47333 .65302 .48475 .64973 .47833 .64364 Metetra
.654 .753 .922 r
.47833 .64364 .48475 .64973 .49623 .64644 .48983 .64032 Metetra
.654 .753 .922 r
.48983 .64032 .49623 .64644 .50775 .64313 .50139 .63698 Metetra
.654 .753 .922 r
.50139 .63698 .50775 .64313 .51932 .63981 .51299 .63363 Metetra
.654 .753 .922 r
.51299 .63363 .51932 .63981 .53095 .63647 .52464 .63027 Metetra
.654 .753 .922 r
.52464 .63027 .53095 .63647 .54262 .63312 .53635 .62689 Metetra
.654 .753 .922 r
.53635 .62689 .54262 .63312 .55434 .62975 .5481 .6235 Metetra
.654 .753 .922 r
.5481 .6235 .55434 .62975 .56611 .62637 .5599 .62009 Metetra
.654 .753 .922 r
.5599 .62009 .56611 .62637 .57793 .62298 .57176 .61667 Metetra
.654 .753 .922 r
.57176 .61667 .57793 .62298 .5898 .61957 .58366 .61323 Metetra
.654 .753 .922 r
.58366 .61323 .5898 .61957 .60172 .61614 .59562 .60978 Metetra
.654 .753 .922 r
.59562 .60978 .60172 .61614 .61369 .6127 .60762 .60632 Metetra
.654 .753 .922 r
.60762 .60632 .61369 .6127 .62571 .60925 .61968 .60284 Metetra
.654 .753 .922 r
.61968 .60284 .62571 .60925 .63779 .60578 .63179 .59934 Metetra
.654 .753 .922 r
.63179 .59934 .63779 .60578 .64992 .6023 .64396 .59583 Metetra
.654 .753 .922 r
.64396 .59583 .64992 .6023 .6621 .5988 .65617 .5923 Metetra
.654 .753 .922 r
.65617 .5923 .6621 .5988 .67433 .59529 .66844 .58876 Metetra
.654 .753 .922 r
.66844 .58876 .67433 .59529 .68662 .59176 .68077 .5852 Metetra
.654 .753 .922 r
.68077 .5852 .68662 .59176 .69896 .58822 .69314 .58163 Metetra
.654 .753 .922 r
.69314 .58163 .69896 .58822 .71135 .58466 .70558 .57804 Metetra
.654 .753 .922 r
.70558 .57804 .71135 .58466 .7238 .58108 .71806 .57444 Metetra
.654 .753 .922 r
.71806 .57444 .7238 .58108 .73631 .57749 .7306 .57082 Metetra
.654 .753 .922 r
.7306 .57082 .73631 .57749 .74886 .57388 .7432 .56718 Metetra
.654 .753 .922 r
.7432 .56718 .74886 .57388 .76148 .57026 .75585 .56353 Metetra
.654 .753 .922 r
.75585 .56353 .76148 .57026 .77415 .56662 .76856 .55986 Metetra
.654 .753 .922 r
.76856 .55986 .77415 .56662 .78687 .56297 .78133 .55618 Metetra
.654 .753 .922 r
.78133 .55618 .78687 .56297 .79965 .5593 .79415 .55248 Metetra
.654 .753 .922 r
.79415 .55248 .79965 .5593 .81249 .55561 .80703 .54876 Metetra
.654 .753 .922 r
.80703 .54876 .81249 .55561 .82539 .55191 .81996 .54503 Metetra
.654 .753 .922 r
.81996 .54503 .82539 .55191 .83834 .54819 .83296 .54127 Metetra
.654 .753 .922 r
.83296 .54127 .83834 .54819 .85135 .54445 .84601 .53751 Metetra
.654 .753 .922 r
.84601 .53751 .85135 .54445 .86442 .5407 .85912 .53372 Metetra
.654 .753 .922 r
.85912 .53372 .86442 .5407 .87755 .53693 .8723 .52992 Metetra
.654 .753 .922 r
.8723 .52992 .87755 .53693 .89074 .53314 .88553 .5261 Metetra
.654 .753 .922 r
.88553 .5261 .89074 .53314 .90399 .52933 .89882 .52226 Metetra
.654 .753 .922 r
.89882 .52226 .90399 .52933 .91729 .52551 .91217 .51841 Metetra
.654 .753 .922 r
.91217 .51841 .91729 .52551 .93066 .52167 .92558 .51454 Metetra
.654 .753 .922 r
.92558 .51454 .93066 .52167 .94409 .51782 .93905 .51065 Metetra
.654 .753 .922 r
.93905 .51065 .94409 .51782 .95758 .51394 .95259 .50674 Metetra
.654 .753 .922 r
.34808 .6734 .35488 .67927 .36587 .6761 .3591 .67021 Metetra
.654 .753 .922 r
.3591 .67021 .36587 .6761 .37691 .67291 .37016 .667 Metetra
.654 .753 .922 r
.37016 .667 .37691 .67291 .38799 .66971 .38127 .66377 Metetra
.654 .753 .922 r
.38127 .66377 .38799 .66971 .39912 .6665 .39243 .66054 Metetra
.654 .753 .922 r
.39243 .66054 .39912 .6665 .41029 .66328 .40363 .65729 Metetra
.654 .753 .922 r
.40363 .65729 .41029 .66328 .42151 .66004 .41488 .65402 Metetra
.654 .753 .922 r
.41488 .65402 .42151 .66004 .43278 .65679 .42618 .65075 Metetra
.654 .753 .922 r
.42618 .65075 .43278 .65679 .4441 .65352 .43752 .64745 Metetra
.654 .753 .922 r
.43752 .64745 .4441 .65352 .45546 .65024 .44892 .64415 Metetra
.654 .753 .922 r
.44892 .64415 .45546 .65024 .46687 .64695 .46036 .64083 Metetra
.654 .753 .922 r
.46036 .64083 .46687 .64695 .47833 .64364 .47185 .6375 Metetra
.654 .753 .922 r
.47185 .6375 .47833 .64364 .48983 .64032 .48338 .63415 Metetra
.654 .753 .922 r
.48338 .63415 .48983 .64032 .50139 .63698 .49497 .63079 Metetra
.654 .753 .922 r
.49497 .63079 .50139 .63698 .51299 .63363 .50661 .62741 Metetra
.654 .753 .922 r
.50661 .62741 .51299 .63363 .52464 .63027 .51829 .62402 Metetra
.654 .753 .922 r
.51829 .62402 .52464 .63027 .53635 .62689 .53003 .62062 Metetra
.654 .753 .922 r
.53003 .62062 .53635 .62689 .5481 .6235 .54181 .6172 Metetra
.654 .753 .922 r
.54181 .6172 .5481 .6235 .5599 .62009 .55365 .61376 Metetra
.654 .753 .922 r
.55365 .61376 .5599 .62009 .57176 .61667 .56554 .61032 Metetra
.654 .753 .922 r
.56554 .61032 .57176 .61667 .58366 .61323 .57747 .60685 Metetra
.654 .753 .922 r
.57747 .60685 .58366 .61323 .59562 .60978 .58946 .60337 Metetra
.654 .753 .922 r
.58946 .60337 .59562 .60978 .60762 .60632 .60151 .59988 Metetra
.654 .753 .922 r
.60151 .59988 .60762 .60632 .61968 .60284 .6136 .59637 Metetra
.654 .753 .922 r
.6136 .59637 .61968 .60284 .63179 .59934 .62575 .59285 Metetra
.654 .753 .922 r
.62575 .59285 .63179 .59934 .64396 .59583 .63795 .58931 Metetra
.654 .753 .922 r
.63795 .58931 .64396 .59583 .65617 .5923 .6502 .58575 Metetra
.654 .753 .922 r
.6502 .58575 .65617 .5923 .66844 .58876 .66251 .58218 Metetra
.654 .753 .922 r
.66251 .58218 .66844 .58876 .68077 .5852 .67487 .5786 Metetra
.654 .753 .922 r
.67487 .5786 .68077 .5852 .69314 .58163 .68728 .57499 Metetra
.654 .753 .922 r
.68728 .57499 .69314 .58163 .70558 .57804 .69975 .57138 Metetra
.654 .753 .922 r
.69975 .57138 .70558 .57804 .71806 .57444 .71227 .56774 Metetra
.654 .753 .922 r
.71227 .56774 .71806 .57444 .7306 .57082 .72485 .56409 Metetra
.654 .753 .922 r
.72485 .56409 .7306 .57082 .7432 .56718 .73749 .56043 Metetra
.654 .753 .922 r
.73749 .56043 .7432 .56718 .75585 .56353 .75018 .55675 Metetra
.654 .753 .922 r
.75018 .55675 .75585 .56353 .76856 .55986 .76293 .55305 Metetra
.654 .753 .922 r
.76293 .55305 .76856 .55986 .78133 .55618 .77573 .54933 Metetra
.654 .753 .922 r
.77573 .54933 .78133 .55618 .79415 .55248 .7886 .5456 Metetra
.654 .753 .922 r
.7886 .5456 .79415 .55248 .80703 .54876 .80152 .54185 Metetra
.654 .753 .922 r
.80152 .54185 .80703 .54876 .81996 .54503 .8145 .53809 Metetra
.654 .753 .922 r
.8145 .53809 .81996 .54503 .83296 .54127 .82753 .53431 Metetra
.654 .753 .922 r
.82753 .53431 .83296 .54127 .84601 .53751 .84063 .53051 Metetra
.654 .753 .922 r
.84063 .53051 .84601 .53751 .85912 .53372 .85378 .52669 Metetra
.654 .753 .922 r
.85378 .52669 .85912 .53372 .8723 .52992 .867 .52286 Metetra
.654 .753 .922 r
.867 .52286 .8723 .52992 .88553 .5261 .88027 .519 Metetra
.654 .753 .922 r
.88027 .519 .88553 .5261 .89882 .52226 .89361 .51514 Metetra
.654 .753 .922 r
.89361 .51514 .89882 .52226 .91217 .51841 .907 .51125 Metetra
.654 .753 .922 r
.907 .51125 .91217 .51841 .92558 .51454 .92046 .50735 Metetra
.654 .753 .922 r
.92046 .50735 .92558 .51454 .93905 .51065 .93398 .50342 Metetra
.654 .753 .922 r
.93398 .50342 .93905 .51065 .95259 .50674 .94756 .49948 Metetra
.654 .753 .922 r
.34122 .66749 .34808 .6734 .3591 .67021 .35227 .66427 Metetra
.654 .753 .922 r
.35227 .66427 .3591 .67021 .37016 .667 .36336 .66104 Metetra
.654 .753 .922 r
.36336 .66104 .37016 .667 .38127 .66377 .3745 .65779 Metetra
.654 .753 .922 r
.3745 .65779 .38127 .66377 .39243 .66054 .38569 .65453 Metetra
.654 .753 .922 r
.38569 .65453 .39243 .66054 .40363 .65729 .39692 .65125 Metetra
.654 .753 .922 r
.39692 .65125 .40363 .65729 .41488 .65402 .4082 .64796 Metetra
.654 .753 .922 r
.4082 .64796 .41488 .65402 .42618 .65075 .41953 .64466 Metetra
.654 .753 .922 r
.41953 .64466 .42618 .65075 .43752 .64745 .4309 .64134 Metetra
.654 .753 .922 r
.4309 .64134 .43752 .64745 .44892 .64415 .44233 .63801 Metetra
.654 .753 .922 r
.44233 .63801 .44892 .64415 .46036 .64083 .4538 .63467 Metetra
.654 .753 .922 r
.4538 .63467 .46036 .64083 .47185 .6375 .46532 .63131 Metetra
.654 .753 .922 r
.46532 .63131 .47185 .6375 .48338 .63415 .47689 .62793 Metetra
.654 .753 .922 r
.47689 .62793 .48338 .63415 .49497 .63079 .4885 .62454 Metetra
.654 .753 .922 r
.4885 .62454 .49497 .63079 .50661 .62741 .50017 .62114 Metetra
.654 .753 .922 r
.50017 .62114 .50661 .62741 .51829 .62402 .51189 .61773 Metetra
.654 .753 .922 r
.51189 .61773 .51829 .62402 .53003 .62062 .52366 .61429 Metetra
.654 .753 .922 r
.52366 .61429 .53003 .62062 .54181 .6172 .53548 .61085 Metetra
.654 .753 .922 r
.53548 .61085 .54181 .6172 .55365 .61376 .54735 .60739 Metetra
.654 .753 .922 r
.54735 .60739 .55365 .61376 .56554 .61032 .55927 .60391 Metetra
.654 .753 .922 r
.55927 .60391 .56554 .61032 .57747 .60685 .57124 .60042 Metetra
.654 .753 .922 r
.57124 .60042 .57747 .60685 .58946 .60337 .58326 .59691 Metetra
.654 .753 .922 r
.58326 .59691 .58946 .60337 .60151 .59988 .59534 .59339 Metetra
.654 .753 .922 r
.59534 .59339 .60151 .59988 .6136 .59637 .60747 .58985 Metetra
.654 .753 .922 r
.60747 .58985 .6136 .59637 .62575 .59285 .61965 .5863 Metetra
.654 .753 .922 r
.61965 .5863 .62575 .59285 .63795 .58931 .63189 .58273 Metetra
.654 .753 .922 r
.63189 .58273 .63795 .58931 .6502 .58575 .64418 .57915 Metetra
.654 .753 .922 r
.64418 .57915 .6502 .58575 .66251 .58218 .65652 .57555 Metetra
.654 .753 .922 r
.65652 .57555 .66251 .58218 .67487 .5786 .66892 .57193 Metetra
.654 .753 .922 r
.66892 .57193 .67487 .5786 .68728 .57499 .68137 .5683 Metetra
.654 .753 .922 r
.68137 .5683 .68728 .57499 .69975 .57138 .69388 .56466 Metetra
.654 .753 .922 r
.69388 .56466 .69975 .57138 .71227 .56774 .70644 .56099 Metetra
.654 .753 .922 r
.70644 .56099 .71227 .56774 .72485 .56409 .71906 .55731 Metetra
.654 .753 .922 r
.71906 .55731 .72485 .56409 .73749 .56043 .73173 .55362 Metetra
.654 .753 .922 r
.73173 .55362 .73749 .56043 .75018 .55675 .74446 .54991 Metetra
.654 .753 .922 r
.74446 .54991 .75018 .55675 .76293 .55305 .75725 .54618 Metetra
.654 .753 .922 r
.75725 .54618 .76293 .55305 .77573 .54933 .7701 .54243 Metetra
.654 .753 .922 r
.7701 .54243 .77573 .54933 .7886 .5456 .783 .53867 Metetra
.654 .753 .922 r
.783 .53867 .7886 .5456 .80152 .54185 .79596 .53489 Metetra
.654 .753 .922 r
.79596 .53489 .80152 .54185 .8145 .53809 .80898 .53109 Metetra
.654 .753 .922 r
.80898 .53109 .8145 .53809 .82753 .53431 .82206 .52728 Metetra
.654 .753 .922 r
.82206 .52728 .82753 .53431 .84063 .53051 .8352 .52345 Metetra
.654 .753 .922 r
.8352 .52345 .84063 .53051 .85378 .52669 .84839 .5196 Metetra
.654 .753 .922 r
.84839 .5196 .85378 .52669 .867 .52286 .86165 .51573 Metetra
.654 .753 .922 r
.86165 .51573 .867 .52286 .88027 .519 .87497 .51185 Metetra
.654 .753 .922 r
.87497 .51185 .88027 .519 .89361 .51514 .88835 .50795 Metetra
.654 .753 .922 r
.88835 .50795 .89361 .51514 .907 .51125 .90179 .50403 Metetra
.654 .753 .922 r
.90179 .50403 .907 .51125 .92046 .50735 .91529 .50009 Metetra
.654 .753 .922 r
.91529 .50009 .92046 .50735 .93398 .50342 .92886 .49614 Metetra
.654 .753 .922 r
.92886 .49614 .93398 .50342 .94756 .49948 .94248 .49216 Metetra
.654 .753 .922 r
.33432 .66153 .34122 .66749 .35227 .66427 .34539 .65829 Metetra
.654 .753 .922 r
.34539 .65829 .35227 .66427 .36336 .66104 .35651 .65503 Metetra
.654 .753 .922 r
.35651 .65503 .36336 .66104 .3745 .65779 .36768 .65176 Metetra
.654 .753 .922 r
.36768 .65176 .3745 .65779 .38569 .65453 .3789 .64847 Metetra
.654 .753 .922 r
.3789 .64847 .38569 .65453 .39692 .65125 .39016 .64517 Metetra
.654 .753 .922 r
.39016 .64517 .39692 .65125 .4082 .64796 .40147 .64185 Metetra
.654 .753 .922 r
.40147 .64185 .4082 .64796 .41953 .64466 .41282 .63852 Metetra
.654 .753 .922 r
.41282 .63852 .41953 .64466 .4309 .64134 .42423 .63518 Metetra
.654 .753 .922 r
.42423 .63518 .4309 .64134 .44233 .63801 .43568 .63182 Metetra
.654 .753 .922 r
.43568 .63182 .44233 .63801 .4538 .63467 .44718 .62845 Metetra
.654 .753 .922 r
.44718 .62845 .4538 .63467 .46532 .63131 .45874 .62507 Metetra
.654 .753 .922 r
.45874 .62507 .46532 .63131 .47689 .62793 .47034 .62167 Metetra
.654 .753 .922 r
.47034 .62167 .47689 .62793 .4885 .62454 .48199 .61825 Metetra
.654 .753 .922 r
.48199 .61825 .4885 .62454 .50017 .62114 .49369 .61482 Metetra
.654 .753 .922 r
.49369 .61482 .50017 .62114 .51189 .61773 .50544 .61138 Metetra
.654 .753 .922 r
.50544 .61138 .51189 .61773 .52366 .61429 .51724 .60792 Metetra
.654 .753 .922 r
.51724 .60792 .52366 .61429 .53548 .61085 .52909 .60445 Metetra
.654 .753 .922 r
.52909 .60445 .53548 .61085 .54735 .60739 .54099 .60096 Metetra
.654 .753 .922 r
.54099 .60096 .54735 .60739 .55927 .60391 .55295 .59745 Metetra
.654 .753 .922 r
.55295 .59745 .55927 .60391 .57124 .60042 .56496 .59393 Metetra
.654 .753 .922 r
.56496 .59393 .57124 .60042 .58326 .59691 .57701 .5904 Metetra
.654 .753 .922 r
.57701 .5904 .58326 .59691 .59534 .59339 .58913 .58685 Metetra
.654 .753 .922 r
.58913 .58685 .59534 .59339 .60747 .58985 .60129 .58328 Metetra
.654 .753 .922 r
.60129 .58328 .60747 .58985 .61965 .5863 .61351 .5797 Metetra
.654 .753 .922 r
.61351 .5797 .61965 .5863 .63189 .58273 .62578 .5761 Metetra
.654 .753 .922 r
.62578 .5761 .63189 .58273 .64418 .57915 .63811 .57249 Metetra
.654 .753 .922 r
.63811 .57249 .64418 .57915 .65652 .57555 .65049 .56886 Metetra
.654 .753 .922 r
.65049 .56886 .65652 .57555 .66892 .57193 .66292 .56522 Metetra
.654 .753 .922 r
.66292 .56522 .66892 .57193 .68137 .5683 .67541 .56156 Metetra
.654 .753 .922 r
.67541 .56156 .68137 .5683 .69388 .56466 .68795 .55788 Metetra
.654 .753 .922 r
.68795 .55788 .69388 .56466 .70644 .56099 .70056 .55419 Metetra
.654 .753 .922 r
.70056 .55419 .70644 .56099 .71906 .55731 .71321 .55048 Metetra
.654 .753 .922 r
.71321 .55048 .71906 .55731 .73173 .55362 .72593 .54675 Metetra
.654 .753 .922 r
.72593 .54675 .73173 .55362 .74446 .54991 .7387 .54301 Metetra
.654 .753 .922 r
.7387 .54301 .74446 .54991 .75725 .54618 .75153 .53925 Metetra
.654 .753 .922 r
.75153 .53925 .75725 .54618 .7701 .54243 .76441 .53547 Metetra
.654 .753 .922 r
.76441 .53547 .7701 .54243 .783 .53867 .77736 .53168 Metetra
.654 .753 .922 r
.77736 .53168 .783 .53867 .79596 .53489 .79036 .52787 Metetra
.654 .753 .922 r
.79036 .52787 .79596 .53489 .80898 .53109 .80342 .52404 Metetra
.654 .753 .922 r
.80342 .52404 .80898 .53109 .82206 .52728 .81654 .52019 Metetra
.654 .753 .922 r
.81654 .52019 .82206 .52728 .8352 .52345 .82972 .51633 Metetra
.654 .753 .922 r
.82972 .51633 .8352 .52345 .84839 .5196 .84296 .51245 Metetra
.654 .753 .922 r
.84296 .51245 .84839 .5196 .86165 .51573 .85626 .50855 Metetra
.654 .753 .922 r
.85626 .50855 .86165 .51573 .87497 .51185 .86962 .50463 Metetra
.654 .753 .922 r
.86962 .50463 .87497 .51185 .88835 .50795 .88305 .5007 Metetra
.654 .753 .922 r
.88305 .5007 .88835 .50795 .90179 .50403 .89653 .49674 Metetra
.654 .753 .922 r
.89653 .49674 .90179 .50403 .91529 .50009 .91008 .49277 Metetra
.654 .753 .922 r
.91008 .49277 .91529 .50009 .92886 .49614 .92369 .48878 Metetra
.654 .753 .922 r
.92369 .48878 .92886 .49614 .94248 .49216 .93736 .48478 Metetra
.654 .753 .922 r
.32736 .65553 .33432 .66153 .34539 .65829 .33846 .65226 Metetra
.654 .753 .922 r
.33846 .65226 .34539 .65829 .35651 .65503 .34961 .64898 Metetra
.654 .753 .922 r
.34961 .64898 .35651 .65503 .36768 .65176 .36081 .64568 Metetra
.654 .753 .922 r
.36081 .64568 .36768 .65176 .3789 .64847 .37205 .64236 Metetra
.654 .753 .922 r
.37205 .64236 .3789 .64847 .39016 .64517 .38334 .63904 Metetra
.654 .753 .922 r
.38334 .63904 .39016 .64517 .40147 .64185 .39468 .6357 Metetra
.654 .753 .922 r
.39468 .6357 .40147 .64185 .41282 .63852 .40607 .63234 Metetra
.654 .753 .922 r
.40607 .63234 .41282 .63852 .42423 .63518 .4175 .62897 Metetra
.654 .753 .922 r
.4175 .62897 .42423 .63518 .43568 .63182 .42899 .62559 Metetra
.654 .753 .922 r
.42899 .62559 .43568 .63182 .44718 .62845 .44052 .62219 Metetra
.654 .753 .922 r
.44052 .62219 .44718 .62845 .45874 .62507 .4521 .61878 Metetra
.654 .753 .922 r
.4521 .61878 .45874 .62507 .47034 .62167 .46374 .61535 Metetra
.654 .753 .922 r
.46374 .61535 .47034 .62167 .48199 .61825 .47542 .61191 Metetra
.654 .753 .922 r
.47542 .61191 .48199 .61825 .49369 .61482 .48715 .60845 Metetra
.654 .753 .922 r
.48715 .60845 .49369 .61482 .50544 .61138 .49893 .60498 Metetra
.654 .753 .922 r
.49893 .60498 .50544 .61138 .51724 .60792 .51077 .60149 Metetra
.654 .753 .922 r
.51077 .60149 .51724 .60792 .52909 .60445 .52265 .59799 Metetra
.654 .753 .922 r
.52265 .59799 .52909 .60445 .54099 .60096 .53459 .59448 Metetra
.654 .753 .922 r
.53459 .59448 .54099 .60096 .55295 .59745 .54658 .59094 Metetra
.654 .753 .922 r
.54658 .59094 .55295 .59745 .56496 .59393 .55862 .5874 Metetra
.654 .753 .922 r
.55862 .5874 .56496 .59393 .57701 .5904 .57071 .58383 Metetra
.654 .753 .922 r
.57071 .58383 .57701 .5904 .58913 .58685 .58286 .58025 Metetra
.654 .753 .922 r
.58286 .58025 .58913 .58685 .60129 .58328 .59506 .57666 Metetra
.654 .753 .922 r
.59506 .57666 .60129 .58328 .61351 .5797 .60731 .57305 Metetra
.654 .753 .922 r
.60731 .57305 .61351 .5797 .62578 .5761 .61962 .56942 Metetra
.654 .753 .922 r
.61962 .56942 .62578 .5761 .63811 .57249 .63198 .56578 Metetra
.654 .753 .922 r
.63198 .56578 .63811 .57249 .65049 .56886 .6444 .56212 Metetra
.654 .753 .922 r
.6444 .56212 .65049 .56886 .66292 .56522 .65687 .55845 Metetra
.654 .753 .922 r
.65687 .55845 .66292 .56522 .67541 .56156 .6694 .55476 Metetra
.654 .753 .922 r
.6694 .55476 .67541 .56156 .68795 .55788 .68198 .55105 Metetra
.654 .753 .922 r
.68198 .55105 .68795 .55788 .70056 .55419 .69462 .54733 Metetra
.654 .753 .922 r
.69462 .54733 .70056 .55419 .71321 .55048 .70732 .54358 Metetra
.654 .753 .922 r
.70732 .54358 .71321 .55048 .72593 .54675 .72007 .53983 Metetra
.654 .753 .922 r
.72007 .53983 .72593 .54675 .7387 .54301 .73288 .53605 Metetra
.654 .753 .922 r
.73288 .53605 .7387 .54301 .75153 .53925 .74575 .53226 Metetra
.654 .753 .922 r
.74575 .53226 .75153 .53925 .76441 .53547 .75868 .52845 Metetra
.654 .753 .922 r
.75868 .52845 .76441 .53547 .77736 .53168 .77166 .52463 Metetra
.654 .753 .922 r
.77166 .52463 .77736 .53168 .79036 .52787 .78471 .52078 Metetra
.654 .753 .922 r
.78471 .52078 .79036 .52787 .80342 .52404 .79781 .51692 Metetra
.654 .753 .922 r
.79781 .51692 .80342 .52404 .81654 .52019 .81098 .51305 Metetra
.654 .753 .922 r
.81098 .51305 .81654 .52019 .82972 .51633 .8242 .50915 Metetra
.654 .753 .922 r
.8242 .50915 .82972 .51633 .84296 .51245 .83748 .50524 Metetra
.654 .753 .922 r
.83748 .50524 .84296 .51245 .85626 .50855 .85083 .5013 Metetra
.654 .753 .922 r
.85083 .5013 .85626 .50855 .86962 .50463 .86423 .49735 Metetra
.654 .753 .922 r
.86423 .49735 .86962 .50463 .88305 .5007 .8777 .49339 Metetra
.654 .753 .922 r
.8777 .49339 .88305 .5007 .89653 .49674 .89123 .4894 Metetra
.654 .753 .922 r
.89123 .4894 .89653 .49674 .91008 .49277 .90483 .48539 Metetra
.654 .753 .922 r
.90483 .48539 .91008 .49277 .92369 .48878 .91848 .48137 Metetra
.654 .753 .922 r
.91848 .48137 .92369 .48878 .93736 .48478 .9322 .47733 Metetra
.672 .757 .915 r
.32034 .64948 .32736 .65553 .33846 .65226 .3315 .64568 Metetra
.652 .737 .912 r
.3315 .64568 .33846 .65226 .34961 .64898 .34267 .64246 Metetra
.613 .729 .928 r
.34267 .64246 .34961 .64898 .36081 .64568 .35384 .64023 Metetra
.574 .753 .963 r
.35384 .64023 .36081 .64568 .37205 .64236 .36504 .63856 Metetra
.516 .796 .996 r
.36504 .63856 .37205 .64236 .38334 .63904 .37629 .63707 Metetra
.416 .819 .981 r
.37629 .63707 .38334 .63904 .39468 .6357 .3876 .63549 Metetra
.278 .777 .87 r
.3876 .63549 .39468 .6357 .40607 .63234 .39898 .63362 Metetra
.158 .695 .714 r
.39898 .63362 .40607 .63234 .4175 .62897 .41044 .63131 Metetra
.41044 .63131 .4175 .62897 .42899 .62559 .42197 .62847 Metetra
.42197 .62847 .42899 .62559 .44052 .62219 .43356 .62506 Metetra
.43356 .62506 .44052 .62219 .4521 .61878 .44522 .62108 Metetra
.298 .782 .708 r
.44522 .62108 .4521 .61878 .46374 .61535 .45693 .61655 Metetra
.468 .892 .849 r
.45693 .61655 .46374 .61535 .47542 .61191 .4687 .61155 Metetra
.623 .944 .95 r
.4687 .61155 .47542 .61191 .48715 .60845 .48051 .60614 Metetra
.708 .909 .966 r
.48051 .60614 .48715 .60845 .49893 .60498 .49236 .60043 Metetra
.73 .833 .928 r
.49236 .60043 .49893 .60498 .51077 .60149 .50425 .59451 Metetra
.724 .756 .878 r
.50425 .59451 .51077 .60149 .52265 .59799 .51617 .5885 Metetra
.708 .693 .834 r
.51617 .5885 .52265 .59799 .53459 .59448 .52813 .58249 Metetra
.691 .645 .799 r
.52813 .58249 .53459 .59448 .54658 .59094 .54012 .57659 Metetra
.675 .608 .772 r
.54012 .57659 .54658 .59094 .55862 .5874 .55215 .57089 Metetra
.661 .58 .753 r
.55215 .57089 .55862 .5874 .57071 .58383 .56423 .56547 Metetra
.65 .558 .738 r
.56423 .56547 .57071 .58383 .58286 .58025 .57634 .56041 Metetra
.64 .543 .729 r
.57634 .56041 .58286 .58025 .59506 .57666 .58851 .55576 Metetra
.631 .531 .723 r
.58851 .55576 .59506 .57666 .60731 .57305 .60074 .55156 Metetra
.624 .523 .72 r
.60074 .55156 .60731 .57305 .61962 .56942 .61303 .54783 Metetra
.617 .519 .721 r
.61303 .54783 .61962 .56942 .63198 .56578 .62538 .54457 Metetra
.611 .519 .725 r
.62538 .54457 .63198 .56578 .6444 .56212 .63781 .54177 Metetra
.607 .521 .732 r
.63781 .54177 .6444 .56212 .65687 .55845 .65032 .5394 Metetra
.602 .529 .744 r
.65032 .5394 .65687 .55845 .6694 .55476 .66291 .5374 Metetra
.599 .541 .761 r
.66291 .5374 .6694 .55476 .68198 .55105 .67559 .53572 Metetra
.595 .561 .785 r
.67559 .53572 .68198 .55105 .69462 .54733 .68834 .53428 Metetra
.592 .589 .818 r
.68834 .53428 .69462 .54733 .70732 .54358 .70119 .53298 Metetra
.586 .63 .862 r
.70119 .53298 .70732 .54358 .72007 .53983 .71411 .53172 Metetra
.574 .687 .917 r
.71411 .53172 .72007 .53983 .73288 .53605 .7271 .53039 Metetra
.544 .755 .975 r
.7271 .53039 .73288 .53605 .74575 .53226 .74017 .5289 Metetra
.475 .814 .999 r
.74017 .5289 .74575 .53226 .75868 .52845 .75329 .52712 Metetra
.353 .812 .932 r
.75329 .52712 .75868 .52845 .77166 .52463 .76646 .52496 Metetra
.218 .741 .783 r
.76646 .52496 .77166 .52463 .78471 .52078 .77967 .52232 Metetra
.77967 .52232 .78471 .52078 .79781 .51692 .79291 .51915 Metetra
.79291 .51915 .79781 .51692 .81098 .51305 .80617 .51539 Metetra
.80617 .51539 .81098 .51305 .8242 .50915 .81944 .51103 Metetra
.81944 .51103 .8242 .50915 .83748 .50524 .83271 .5061 Metetra
.387 .844 .783 r
.83271 .5061 .83748 .50524 .85083 .5013 .84599 .50067 Metetra
.552 .928 .913 r
.84599 .50067 .85083 .5013 .86423 .49735 .85929 .49489 Metetra
.662 .93 .971 r
.85929 .49489 .86423 .49735 .8777 .49339 .87262 .48894 Metetra
.699 .872 .963 r
.87262 .48894 .8777 .49339 .89123 .4894 .88601 .4831 Metetra
.693 .804 .934 r
.88601 .4831 .89123 .4894 .90483 .48539 .8995 .47772 Metetra
.667 .751 .914 r
.8995 .47772 .90483 .48539 .91848 .48137 .91315 .47326 Metetra
.637 .727 .913 r
.91315 .47326 .91848 .48137 .9322 .47733 .92699 .46982 Metetra
.668 .756 .917 r
.31327 .64338 .32034 .64948 .3315 .64568 .32446 .63968 Metetra
.665 .759 .921 r
.32446 .63968 .3315 .64568 .34267 .64246 .33568 .63604 Metetra
.561 .716 .945 r
.33568 .63604 .34267 .64246 .35384 .64023 .34682 .63488 Metetra
.443 .708 .979 r
.34682 .63488 .35384 .64023 .36504 .63856 .35795 .63511 Metetra
.268 .694 .966 r
.35795 .63511 .36504 .63856 .37629 .63707 .36913 .63591 Metetra
.04 .602 .8 r
.36913 .63591 .37629 .63707 .3876 .63549 .38039 .6366 Metetra
.129 0 0 r
.38039 .6366 .3876 .63549 .39898 .63362 .39175 .63668 Metetra
.192 0 0 r
.39175 .63668 .39898 .63362 .41044 .63131 .40321 .63581 Metetra
.183 0 0 r
.40321 .63581 .41044 .63131 .42197 .62847 .41478 .63376 Metetra
.122 0 0 r
.41478 .63376 .42197 .62847 .43356 .62506 .42644 .63042 Metetra
.008 0 0 r
.42644 .63042 .43356 .62506 .44522 .62108 .43818 .62579 Metetra
.43818 .62579 .44522 .62108 .45693 .61655 .45 .61992 Metetra
.436 .852 .693 r
.45 .61992 .45693 .61655 .4687 .61155 .46187 .61297 Metetra
.679 .978 .873 r
.46187 .61297 .4687 .61155 .48051 .60614 .47378 .6051 Metetra
.794 .952 .921 r
.47378 .6051 .48051 .60614 .49236 .60043 .48572 .59654 Metetra
.807 .859 .888 r
.48572 .59654 .49236 .60043 .50425 .59451 .49768 .58753 Metetra
.783 .768 .839 r
.49768 .58753 .50425 .59451 .51617 .5885 .50965 .57831 Metetra
.753 .697 .797 r
.50965 .57831 .51617 .5885 .52813 .58249 .52164 .56914 Metetra
.725 .642 .765 r
.52164 .56914 .52813 .58249 .54012 .57659 .53364 .56023 Metetra
.701 .601 .742 r
.53364 .56023 .54012 .57659 .55215 .57089 .54566 .5518 Metetra
.68 .57 .724 r
.54566 .5518 .55215 .57089 .56423 .56547 .5577 .54404 Metetra
.662 .545 .712 r
.5577 .54404 .56423 .56547 .57634 .56041 .56978 .53711 Metetra
.645 .526 .704 r
.56978 .53711 .57634 .56041 .58851 .55576 .5819 .53113 Metetra
.631 .511 .699 r
.5819 .53113 .58851 .55576 .60074 .55156 .59408 .52619 Metetra
.617 .5 .697 r
.59408 .52619 .60074 .55156 .61303 .54783 .60634 .52233 Metetra
.604 .491 .698 r
.60634 .52233 .61303 .54783 .62538 .54457 .61868 .51957 Metetra
.592 .486 .702 r
.61868 .51957 .62538 .54457 .63781 .54177 .63111 .51786 Metetra
.58 .484 .711 r
.63111 .51786 .63781 .54177 .65032 .5394 .64365 .51715 Metetra
.567 .486 .723 r
.64365 .51715 .65032 .5394 .66291 .5374 .6563 .51731 Metetra
.553 .493 .742 r
.6563 .51731 .66291 .5374 .67559 .53572 .66908 .51822 Metetra
.538 .506 .768 r
.66908 .51822 .67559 .53572 .68834 .53428 .68197 .51968 Metetra
.518 .528 .806 r
.68197 .51968 .68834 .53428 .70119 .53298 .69497 .5215 Metetra
.489 .564 .859 r
.69497 .5215 .70119 .53298 .71411 .53172 .70809 .52343 Metetra
.439 .617 .926 r
.70809 .52343 .71411 .53172 .7271 .53039 .7213 .52525 Metetra
.339 .674 .977 r
.7213 .52525 .7271 .53039 .74017 .5289 .7346 .52668 Metetra
.16 .667 .904 r
.7346 .52668 .74017 .5289 .75329 .52712 .74795 .52749 Metetra
.033 0 0 r
.74795 .52749 .75329 .52712 .76646 .52496 .76134 .52743 Metetra
.138 0 0 r
.76134 .52743 .76646 .52496 .77967 .52232 .77475 .5263 Metetra
.162 0 0 r
.77475 .5263 .77967 .52232 .79291 .51915 .78814 .52394 Metetra
.129 0 0 r
.78814 .52394 .79291 .51915 .80617 .51539 .8015 .52026 Metetra
.046 0 0 r
.8015 .52026 .80617 .51539 .81944 .51103 .8148 .51522 Metetra
.8148 .51522 .81944 .51103 .83271 .5061 .82805 .50891 Metetra
.82805 .50891 .83271 .5061 .84599 .50067 .84123 .50152 Metetra
.578 .939 .809 r
.84123 .50152 .84599 .50067 .85929 .49489 .85438 .49338 Metetra
.735 .975 .925 r
.85438 .49338 .85929 .49489 .87262 .48894 .86753 .48496 Metetra
.766 .907 .937 r
.86753 .48496 .87262 .48894 .88601 .4831 .88075 .47692 Metetra
.734 .823 .92 r
.88075 .47692 .88601 .4831 .8995 .47772 .89414 .47009 Metetra
.668 .755 .916 r
.89414 .47009 .8995 .47772 .91315 .47326 .90784 .46556 Metetra
.63 .738 .925 r
.90784 .46556 .91315 .47326 .92699 .46982 .92174 .46224 Metetra
.654 .753 .922 r
.30615 .63724 .31327 .64338 .32446 .63968 .31734 .63389 Metetra
.679 .771 .92 r
.31734 .63389 .32446 .63968 .33568 .63604 .32862 .62981 Metetra
.521 .709 .957 r
.32862 .62981 .33568 .63604 .34682 .63488 .33975 .62927 Metetra
.307 .635 .964 r
.33975 .62927 .34682 .63488 .35795 .63511 .35082 .63115 Metetra
.046 .537 .884 r
.35082 .63115 .35795 .63511 .36913 .63591 .36192 .63409 Metetra
.185 0 0 r
.36192 .63409 .36913 .63591 .38039 .6366 .37312 .63701 Metetra
.29 0 0 r
.37312 .63701 .38039 .6366 .39175 .63668 .38444 .63909 Metetra
.289 0 0 r
.38444 .63909 .39175 .63668 .40321 .63581 .3959 .63974 Metetra
.223 0 0 r
.3959 .63974 .40321 .63581 .41478 .63376 .4075 .63859 Metetra
.103 0 0 r
.4075 .63859 .41478 .63376 .42644 .63042 .41922 .63545 Metetra
.41922 .63545 .42644 .63042 .43818 .62579 .43105 .63029 Metetra
.43105 .63029 .43818 .62579 .45 .61992 .44297 .6232 Metetra
.608 .943 .76 r
.44297 .6232 .45 .61992 .46187 .61297 .45495 .6144 Metetra
.795 .996 .864 r
.45495 .6144 .46187 .61297 .47378 .6051 .46697 .60417 Metetra
.858 .942 .873 r
.46697 .60417 .47378 .6051 .48572 .59654 .47901 .59285 Metetra
.854 .857 .843 r
.47901 .59285 .48572 .59654 .49768 .58753 .49105 .58083 Metetra
.826 .778 .808 r
.49105 .58083 .49768 .58753 .50965 .57831 .50309 .5685 Metetra
.793 .714 .777 r
.50309 .5685 .50965 .57831 .52164 .56914 .51512 .55623 Metetra
.762 .663 .753 r
.51512 .55623 .52164 .56914 .53364 .56023 .52714 .54439 Metetra
.733 .622 .735 r
.52714 .54439 .53364 .56023 .54566 .5518 .53916 .5333 Metetra
.707 .589 .721 r
.53916 .5333 .54566 .5518 .5577 .54404 .55118 .52327 Metetra
.683 .561 .711 r
.55118 .52327 .5577 .54404 .56978 .53711 .56323 .51452 Metetra
.661 .539 .705 r
.56323 .51452 .56978 .53711 .5819 .53113 .57532 .50726 Metetra
.64 .52 .701 r
.57532 .50726 .5819 .53113 .59408 .52619 .58746 .50159 Metetra
.619 .504 .701 r
.58746 .50159 .59408 .52619 .60634 .52233 .59969 .49761 Metetra
.599 .491 .703 r
.59969 .49761 .60634 .52233 .61868 .51957 .61201 .49532 Metetra
.578 .481 .708 r
.61201 .49532 .61868 .51957 .63111 .51786 .62444 .49468 Metetra
.555 .473 .717 r
.62444 .49468 .63111 .51786 .64365 .51715 .63701 .49558 Metetra
.531 .468 .731 r
.63701 .49558 .64365 .51715 .6563 .51731 .64972 .49784 Metetra
.502 .467 .75 r
.64972 .49784 .6563 .51731 .66908 .51822 .66258 .50126 Metetra
.467 .47 .778 r
.66258 .50126 .66908 .51822 .68197 .51968 .67559 .50555 Metetra
.421 .48 .815 r
.67559 .50555 .68197 .51968 .69497 .5215 .68875 .5104 Metetra
.355 .498 .864 r
.68875 .5104 .69497 .5215 .70809 .52343 .70205 .51545 Metetra
.252 .521 .912 r
.70205 .51545 .70809 .52343 .7213 .52525 .71546 .52032 Metetra
.092 .527 .907 r
.71546 .52032 .7213 .52525 .7346 .52668 .72897 .52459 Metetra
0 .476 .768 r
.72897 .52459 .7346 .52668 .74795 .52749 .74255 .52789 Metetra
.21 0 0 r
.74255 .52789 .74795 .52749 .76134 .52743 .75614 .52983 Metetra
.234 0 0 r
.75614 .52983 .76134 .52743 .77475 .5263 .76973 .53009 Metetra
.193 0 0 r
.76973 .53009 .77475 .5263 .78814 .52394 .78326 .52842 Metetra
.1 0 0 r
.78326 .52842 .78814 .52394 .8015 .52026 .79671 .52468 Metetra
.79671 .52468 .8015 .52026 .8148 .51522 .81004 .51884 Metetra
.81004 .51884 .8148 .51522 .82805 .50891 .82325 .51105 Metetra
.54 .903 .705 r
.82325 .51105 .82805 .50891 .84123 .50152 .83634 .50164 Metetra
.746 .994 .845 r
.83634 .50164 .84123 .50152 .85438 .49338 .84935 .49115 Metetra
.825 .967 .895 r
.84935 .49115 .85438 .49338 .86753 .48496 .86234 .48038 Metetra
.815 .894 .899 r
.86234 .48038 .86753 .48496 .88075 .47692 .87542 .47037 Metetra
.758 .82 .902 r
.87542 .47037 .88075 .47692 .89414 .47009 .88875 .46251 Metetra
.65 .751 .923 r
.88875 .46251 .89414 .47009 .90784 .46556 .90256 .45851 Metetra
.645 .767 .937 r
.90256 .45851 .90784 .46556 .92174 .46224 .91644 .4546 Metetra
.654 .753 .922 r
.29897 .63105 .30615 .63724 .31734 .63389 .31019 .62767 Metetra
.674 .758 .914 r
.31019 .62767 .31734 .63389 .32862 .62981 .32149 .62371 Metetra
.508 .711 .963 r
.32149 .62371 .32862 .62981 .33975 .62927 .33263 .62329 Metetra
.192 .559 .934 r
.33263 .62329 .33975 .62927 .35082 .63115 .34365 .6265 Metetra
0 .383 .787 r
.34365 .6265 .35082 .63115 .36192 .63409 .35468 .6314 Metetra
.35 0 0 r
.35468 .6314 .36192 .63409 .37312 .63701 .36581 .63647 Metetra
.413 0 0 r
.36581 .63647 .37312 .63701 .38444 .63909 .37708 .64057 Metetra
.372 0 0 r
.37708 .64057 .38444 .63909 .3959 .63974 .38852 .64283 Metetra
.259 0 0 r
.38852 .64283 .3959 .63974 .4075 .63859 .40014 .64272 Metetra
.077 0 0 r
.40014 .64272 .4075 .63859 .41922 .63545 .41192 .63993 Metetra
.41192 .63993 .41922 .63545 .43105 .63029 .42383 .6344 Metetra
.48 .868 .672 r
.42383 .6344 .43105 .63029 .44297 .6232 .43585 .62625 Metetra
.732 .987 .798 r
.43585 .62625 .44297 .6232 .45495 .6144 .44795 .61577 Metetra
.861 .988 .842 r
.44795 .61577 .45495 .6144 .46697 .60417 .46008 .60333 Metetra
.895 .926 .833 r
.46008 .60333 .46697 .60417 .47901 .59285 .47223 .58941 Metetra
.884 .853 .807 r
.47223 .58941 .47901 .59285 .49105 .58083 .48437 .57454 Metetra
.856 .786 .781 r
.48437 .57454 .49105 .58083 .50309 .5685 .49648 .55922 Metetra
.825 .729 .759 r
.49648 .55922 .50309 .5685 .51512 .55623 .50857 .544 Metetra
.793 .682 .742 r
.50857 .544 .51512 .55623 .52714 .54439 .52062 .52935 Metetra
.762 .643 .729 r
.52062 .52935 .52714 .54439 .53916 .5333 .53266 .51573 Metetra
.733 .609 .719 r
.53266 .51573 .53916 .5333 .55118 .52327 .54468 .50352 Metetra
.705 .58 .712 r
.54468 .50352 .55118 .52327 .56323 .51452 .55671 .49304 Metetra
.677 .554 .708 r
.55671 .49304 .56323 .51452 .57532 .50726 .56876 .48454 Metetra
.65 .532 .706 r
.56876 .48454 .57532 .50726 .58746 .50159 .58088 .4782 Metetra
.622 .512 .707 r
.58088 .4782 .58746 .50159 .59969 .49761 .59307 .4741 Metetra
.593 .493 .71 r
.59307 .4741 .59969 .49761 .61201 .49532 .60538 .47226 Metetra
.562 .477 .717 r
.60538 .47226 .61201 .49532 .62444 .49468 .61781 .47263 Metetra
.527 .462 .726 r
.61781 .47263 .62444 .49468 .63701 .49558 .6304 .47506 Metetra
.487 .449 .74 r
.6304 .47506 .63701 .49558 .64972 .49784 .64316 .47933 Metetra
.439 .437 .76 r
.64316 .47933 .64972 .49784 .66258 .50126 .6561 .48514 Metetra
.377 .426 .785 r
.6561 .48514 .66258 .50126 .67559 .50555 .66922 .49214 Metetra
.294 .416 .815 r
.66922 .49214 .67559 .50555 .68875 .5104 .68252 .49989 Metetra
.179 .405 .844 r
.68252 .49989 .68875 .5104 .70205 .51545 .69598 .50791 Metetra
.02 .385 .846 r
.69598 .50791 .70205 .51545 .71546 .52032 .70958 .51567 Metetra
0 .344 .772 r
.70958 .51567 .71546 .52032 .72897 .52459 .72329 .52264 Metetra
.3 0 0 r
.72329 .52264 .72897 .52459 .74255 .52789 .73707 .52826 Metetra
.34 0 0 r
.73707 .52826 .74255 .52789 .75614 .52983 .75085 .53203 Metetra
.301 0 0 r
.75085 .53203 .75614 .52983 .76973 .53009 .7646 .53351 Metetra
.2 0 0 r
.7646 .53351 .76973 .53009 .78326 .52842 .77826 .53236 Metetra
.038 0 0 r
.77826 .53236 .78326 .52842 .79671 .52468 .79179 .5284 Metetra
.79179 .5284 .79671 .52468 .81004 .51884 .80514 .52161 Metetra
.482 .862 .65 r
.80514 .52161 .81004 .51884 .82325 .51105 .8183 .51224 Metetra
.726 .984 .784 r
.8183 .51224 .82325 .51105 .83634 .50164 .8313 .50076 Metetra
.85 .991 .845 r
.8313 .50076 .83634 .50164 .84935 .49115 .84417 .48797 Metetra
.873 .937 .859 r
.84417 .48797 .84935 .49115 .86234 .48038 .85701 .475 Metetra
.84 .871 .866 r
.85701 .475 .86234 .48038 .87542 .47037 .86998 .46334 Metetra
.767 .81 .887 r
.86998 .46334 .87542 .47037 .88875 .46251 .88331 .45492 Metetra
.644 .75 .926 r
.88331 .45492 .88875 .46251 .90256 .45851 .89719 .45107 Metetra
.654 .76 .928 r
.89719 .45107 .90256 .45851 .91644 .4546 .9111 .44689 Metetra
.654 .753 .922 r
.29173 .62481 .29897 .63105 .31019 .62767 .30298 .6214 Metetra
.662 .755 .919 r
.30298 .6214 .31019 .62767 .32149 .62371 .31429 .61777 Metetra
.529 .726 .964 r
.31429 .61777 .32149 .62371 .33263 .62329 .32548 .61691 Metetra
.118 .5 .906 r
.32548 .61691 .33263 .62329 .34365 .6265 .33646 .62104 Metetra
0 .26 .706 r
.33646 .62104 .34365 .6265 .35468 .6314 .34742 .62765 Metetra
.459 0 0 r
.34742 .62765 .35468 .6314 .36581 .63647 .35846 .63477 Metetra
.504 0 0 r
.35846 .63477 .36581 .63647 .37708 .64057 .36968 .64087 Metetra
.442 0 0 r
.36968 .64087 .37708 .64057 .38852 .64283 .38109 .64482 Metetra
.292 0 0 r
.38109 .64482 .38852 .64283 .40014 .64272 .39272 .64587 Metetra
.046 0 0 r
.39272 .64587 .40014 .64272 .41192 .63993 .40454 .64361 Metetra
.40454 .64361 .41192 .63993 .42383 .6344 .41653 .63792 Metetra
.606 .941 .755 r
.41653 .63792 .42383 .6344 .43585 .62625 .42865 .62893 Metetra
.812 1 .816 r
.42865 .62893 .43585 .62625 .44795 .61577 .44086 .61698 Metetra
.898 .97 .819 r
.44086 .61698 .44795 .61577 .46008 .60333 .45311 .60256 Metetra
.916 .91 .8 r
.45311 .60256 .46008 .60333 .47223 .58941 .46537 .58626 Metetra
.904 .848 .779 r
.46537 .58626 .47223 .58941 .48437 .57454 .47762 .56873 Metetra
.88 .792 .76 r
.47762 .56873 .48437 .57454 .49648 .55922 .48982 .55064 Metetra
.851 .744 .744 r
.48982 .55064 .49648 .55922 .50857 .544 .50198 .53265 Metetra
.821 .701 .733 r
.50198 .53265 .50857 .544 .52062 .52935 .51408 .51538 Metetra
.79 .664 .724 r
.51408 .51538 .52062 .52935 .53266 .51573 .52614 .49938 Metetra
.759 .631 .718 r
.52614 .49938 .53266 .51573 .54468 .50352 .53817 .48513 Metetra
.728 .6 .715 r
.53817 .48513 .54468 .50352 .55671 .49304 .55019 .47303 Metetra
.695 .573 .713 r
.55019 .47303 .55671 .49304 .56876 .48454 .56224 .46338 Metetra
.662 .547 .714 r
.56224 .46338 .56876 .48454 .58088 .4782 .57433 .45638 Metetra
.627 .523 .716 r
.57433 .45638 .58088 .4782 .59307 .4741 .5865 .45217 Metetra
.588 .499 .721 r
.5865 .45217 .59307 .4741 .60538 .47226 .59879 .45076 Metetra
.544 .475 .729 r
.59879 .45076 .60538 .47226 .61781 .47263 .61123 .45207 Metetra
.493 .452 .739 r
.61123 .45207 .61781 .47263 .6304 .47506 .62384 .45594 Metetra
.433 .427 .753 r
.62384 .45594 .6304 .47506 .64316 .47933 .63664 .46208 Metetra
.356 .399 .768 r
.63664 .46208 .64316 .47933 .6561 .48514 .64964 .47014 Metetra
.258 .368 .785 r
.64964 .47014 .6561 .48514 .66922 .49214 .66286 .47967 Metetra
.129 .329 .795 r
.66286 .47967 .66922 .49214 .68252 .49989 .67628 .49013 Metetra
0 .28 .783 r
.67628 .49013 .68252 .49989 .69598 .50791 .68989 .50091 Metetra
0 .222 .724 r
.68989 .50091 .69598 .50791 .70958 .51567 .70367 .51136 Metetra
0 .169 .611 r
.70367 .51136 .70958 .51567 .72329 .52264 .71755 .52079 Metetra
.444 0 0 r
.71755 .52079 .72329 .52264 .73707 .52826 .73151 .52852 Metetra
.429 0 0 r
.73151 .52852 .73707 .52826 .75085 .53203 .74546 .53389 Metetra
.341 0 0 r
.74546 .53389 .75085 .53203 .7646 .53351 .75936 .53637 Metetra
.18 0 0 r
.75936 .53637 .7646 .53351 .77826 .53236 .77312 .53552 Metetra
.77312 .53552 .77826 .53236 .79179 .5284 .78671 .53114 Metetra
.385 .812 .636 r
.78671 .53114 .79179 .5284 .80514 .52161 .80006 .52326 Metetra
.679 .967 .762 r
.80006 .52326 .80514 .52161 .8183 .51224 .81318 .5122 Metetra
.847 .998 .815 r
.81318 .5122 .8183 .51224 .8313 .50076 .82607 .49864 Metetra
.901 .957 .824 r
.82607 .49864 .8313 .50076 .84417 .48797 .83882 .48363 Metetra
.893 .899 .825 r
.83882 .48363 .84417 .48797 .85701 .475 .85154 .46868 Metetra
.85 .845 .838 r
.85154 .46868 .85701 .475 .86998 .46334 .86445 .45574 Metetra
.762 .794 .879 r
.86445 .45574 .86998 .46334 .88331 .45492 .87784 .44731 Metetra
.647 .753 .926 r
.87784 .44731 .88331 .45492 .89719 .45107 .89175 .44333 Metetra
.654 .753 .922 r
.89175 .44333 .89719 .45107 .9111 .44689 .90571 .43911 Metetra
.654 .753 .922 r
.28444 .61851 .29173 .62481 .30298 .6214 .29572 .61509 Metetra
.654 .753 .922 r
.29572 .61509 .30298 .6214 .31429 .61777 .30704 .61164 Metetra
.569 .735 .954 r
.30704 .61164 .31429 .61777 .32548 .61691 .3183 .6101 Metetra
.096 .473 .893 r
.3183 .6101 .32548 .61691 .33646 .62104 .32926 .61469 Metetra
0 .176 .654 r
.32926 .61469 .33646 .62104 .34742 .62765 .34015 .62272 Metetra
.526 0 0 r
.34015 .62272 .34742 .62765 .35846 .63477 .35111 .63173 Metetra
.567 0 0 r
.35111 .63173 .35846 .63477 .36968 .64087 .36225 .63978 Metetra
.5 0 0 r
.36225 .63978 .36968 .64087 .38109 .64482 .37362 .64547 Metetra
.322 0 0 r
.37362 .64547 .38109 .64482 .39272 .64587 .38524 .64782 Metetra
.011 0 0 r
.38524 .64782 .39272 .64587 .40454 .64361 .3971 .64628 Metetra
.387 .837 .736 r
.3971 .64628 .40454 .64361 .41653 .63792 .40915 .64065 Metetra
.703 .983 .819 r
.40915 .64065 .41653 .63792 .42865 .62893 .42137 .63108 Metetra
.861 .994 .823 r
.42137 .63108 .42865 .62893 .44086 .61698 .43368 .61793 Metetra
.918 .95 .8 r
.43368 .61793 .44086 .61698 .45311 .60256 .44606 .6018 Metetra
.928 .896 .776 r
.44606 .6018 .45311 .60256 .46537 .58626 .45845 .58339 Metetra
.918 .845 .756 r
.45845 .58339 .46537 .58626 .47762 .56873 .4708 .56348 Metetra
.898 .798 .742 r
.4708 .56348 .47762 .56873 .48982 .55064 .48311 .54288 Metetra
.873 .757 .732 r
.48311 .54288 .48982 .55064 .50198 .53265 .49534 .52237 Metetra
.845 .72 .725 r
.49534 .52237 .50198 .53265 .51408 .51538 .50751 .5027 Metetra
.816 .686 .721 r
.50751 .5027 .51408 .51538 .52614 .49938 .51961 .48451 Metetra
.785 .654 .719 r
.51961 .48451 .52614 .49938 .53817 .48513 .53166 .46839 Metetra
.751 .624 .719 r
.53166 .46839 .53817 .48513 .55019 .47303 .54369 .45479 Metetra
.715 .595 .721 r
.54369 .45479 .55019 .47303 .56224 .46338 .55573 .44408 Metetra
.676 .567 .724 r
.55573 .44408 .56224 .46338 .57433 .45638 .56781 .43649 Metetra
.632 .538 .73 r
.56781 .43649 .57433 .45638 .5865 .45217 .57997 .43218 Metetra
.582 .508 .737 r
.57997 .43218 .5865 .45217 .59879 .45076 .59225 .43115 Metetra
.522 .476 .746 r
.59225 .43115 .59879 .45076 .61123 .45207 .60469 .43333 Metetra
.45 .441 .756 r
.60469 .43333 .61123 .45207 .62384 .45594 .61731 .43851 Metetra
.361 .399 .766 r
.61731 .43851 .62384 .45594 .63664 .46208 .63015 .44637 Metetra
.246 .35 .772 r
.63015 .44637 .63664 .46208 .64964 .47014 .64321 .45649 Metetra
.101 .288 .767 r
.64321 .45649 .64964 .47014 .66286 .47967 .65652 .46833 Metetra
0 .215 .738 r
.65652 .46833 .66286 .47967 .67628 .49013 .67005 .48125 Metetra
0 .134 .672 r
.67005 .48125 .67628 .49013 .68989 .50091 .68379 .49454 Metetra
0 .065 .571 r
.68379 .49454 .68989 .50091 .70367 .51136 .69771 .50741 Metetra
.52 0 0 r
.69771 .50741 .70367 .51136 .71755 .52079 .71175 .51903 Metetra
.539 0 0 r
.71175 .51903 .71755 .52079 .73151 .52852 .72586 .52857 Metetra
.486 0 0 r
.72586 .52857 .73151 .52852 .74546 .53389 .73996 .53527 Metetra
.356 0 0 r
.73996 .53527 .74546 .53389 .75936 .53637 .75398 .53847 Metetra
.125 0 0 r
.75398 .53847 .75936 .53637 .77312 .53552 .76783 .53768 Metetra
.76783 .53768 .77312 .53552 .78671 .53114 .78145 .53267 Metetra
.589 .938 .776 r
.78145 .53267 .78671 .53114 .80006 .52326 .7948 .52353 Metetra
.818 1 .82 r
.7948 .52353 .80006 .52326 .81318 .5122 .80786 .5107 Metetra
.905 .967 .811 r
.80786 .5107 .81318 .5122 .82607 .49864 .82066 .49507 Metetra
.919 .912 .796 r
.82066 .49507 .82607 .49864 .83882 .48363 .8333 .478 Metetra
.898 .861 .796 r
.8333 .478 .83882 .48363 .85154 .46868 .84593 .46134 Metetra
.85 .819 .818 r
.84593 .46134 .85154 .46868 .86445 .45574 .85882 .44755 Metetra
.745 .775 .877 r
.85882 .44755 .86445 .45574 .87784 .44731 .87232 .43973 Metetra
.653 .758 .927 r
.87232 .43973 .87784 .44731 .89175 .44333 .88626 .43552 Metetra
.654 .753 .922 r
.88626 .43552 .89175 .44333 .90571 .43911 .90027 .43126 Metetra
.654 .753 .922 r
.27709 .61217 .28444 .61851 .29572 .61509 .28839 .60872 Metetra
.654 .753 .922 r
.28839 .60872 .29572 .61509 .30704 .61164 .29975 .60525 Metetra
.608 .74 .939 r
.29975 .60525 .30704 .61164 .3183 .6101 .31107 .60293 Metetra
.125 .48 .898 r
.31107 .60293 .3183 .6101 .32926 .61469 .32205 .60746 Metetra
0 .13 .631 r
.32205 .60746 .32926 .61469 .34015 .62272 .33288 .61655 Metetra
.561 .035 0 r
.33288 .61655 .34015 .62272 .35111 .63173 .34376 .62721 Metetra
.606 .054 0 r
.34376 .62721 .35111 .63173 .36225 .63978 .35482 .63713 Metetra
.541 0 0 r
.35482 .63713 .36225 .63978 .37362 .64547 .36613 .64458 Metetra
.348 0 0 r
.36613 .64458 .37362 .64547 .38524 .64782 .37773 .64835 Metetra
.37773 .64835 .38524 .64782 .3971 .64628 .3896 .64772 Metetra
.474 .895 .846 r
.3896 .64772 .3971 .64628 .40915 .64065 .40171 .64241 Metetra
.766 .995 .865 r
.40171 .64241 .40915 .64065 .42137 .63108 .41401 .63254 Metetra
.888 .977 .825 r
.41401 .63254 .42137 .63108 .43368 .61793 .42643 .61851 Metetra
.928 .931 .786 r
.42643 .61851 .43368 .61793 .44606 .6018 .43893 .601 Metetra
.936 .884 .758 r
.43893 .601 .44606 .6018 .45845 .58339 .45144 .5808 Metetra
.928 .842 .739 r
.45144 .5808 .45845 .58339 .4708 .56348 .46391 .55883 Metetra
.912 .804 .727 r
.46391 .55883 .4708 .56348 .48311 .54288 .47633 .53602 Metetra
.891 .77 .721 r
.47633 .53602 .48311 .54288 .49534 .52237 .48866 .51328 Metetra
.867 .738 .718 r
.48866 .51328 .49534 .52237 .50751 .5027 .50089 .49146 Metetra
.84 .708 .718 r
.50089 .49146 .50751 .5027 .51961 .48451 .51305 .47133 Metetra
.81 .68 .72 r
.51305 .47133 .51961 .48451 .53166 .46839 .52514 .45352 Metetra
.776 .651 .724 r
.52514 .45352 .53166 .46839 .54369 .45479 .53719 .43858 Metetra
.737 .622 .731 r
.53719 .43858 .54369 .45479 .55573 .44408 .54923 .42692 Metetra
.693 .592 .739 r
.54923 .42692 .55573 .44408 .56781 .43649 .56131 .4188 Metetra
.639 .559 .748 r
.56131 .4188 .56781 .43649 .57997 .43218 .57347 .41439 Metetra
.575 .522 .759 r
.57347 .41439 .57997 .43218 .59225 .43115 .58575 .41371 Metetra
.495 .48 .769 r
.58575 .41371 .59225 .43115 .60469 .43333 .59819 .41666 Metetra
.393 .427 .778 r
.59819 .41666 .60469 .43333 .61731 .43851 .61083 .42301 Metetra
.262 .362 .778 r
.61083 .42301 .61731 .43851 .63015 .44637 .6237 .43241 Metetra
.098 .281 .761 r
.6237 .43241 .63015 .44637 .64321 .45649 .63681 .44436 Metetra
0 .183 .715 r
.63681 .44436 .64321 .45649 .65652 .46833 .65019 .45826 Metetra
0 .08 .634 r
.65019 .45826 .65652 .46833 .67005 .48125 .66381 .47337 Metetra
0 0 .528 r
.66381 .47337 .67005 .48125 .68379 .49454 .67766 .48886 Metetra
.57 .061 0 r
.67766 .48886 .68379 .49454 .69771 .50741 .69171 .50382 Metetra
.614 .07 0 r
.69171 .50382 .69771 .50741 .71175 .51903 .70588 .51729 Metetra
.598 .029 0 r
.70588 .51729 .71175 .51903 .72586 .52857 .72013 .52832 Metetra
.517 0 0 r
.72013 .52832 .72586 .52857 .73996 .53527 .73435 .53601 Metetra
.343 0 0 r
.73435 .53601 .73996 .53527 .75398 .53847 .74846 .53962 Metetra
.022 0 0 r
.74846 .53962 .75398 .53847 .76783 .53768 .76237 .53862 Metetra
.418 .863 .799 r
.76237 .53862 .76783 .53768 .78145 .53267 .77602 .53277 Metetra
.751 .994 .858 r
.77602 .53277 .78145 .53267 .7948 .52353 .78934 .52222 Metetra
.889 .975 .827 r
.78934 .52222 .7948 .52353 .80786 .5107 .80234 .50757 Metetra
.925 .919 .79 r
.80234 .50757 .80786 .5107 .82066 .49507 .81505 .48993 Metetra
.92 .868 .77 r
.81505 .48993 .82066 .49507 .8333 .478 .8276 .47097 Metetra
.894 .827 .773 r
.8276 .47097 .8333 .478 .84593 .46134 .84017 .45295 Metetra
.842 .795 .805 r
.84017 .45295 .84593 .46134 .85882 .44755 .85308 .43881 Metetra
.721 .754 .878 r
.85308 .43881 .85882 .44755 .87232 .43973 .86674 .43192 Metetra
.654 .754 .923 r
.86674 .43192 .87232 .43973 .88626 .43552 .88073 .42764 Metetra
.654 .753 .922 r
.88073 .42764 .88626 .43552 .90027 .43126 .89478 .42335 Metetra
.654 .753 .922 r
.26968 .60578 .27709 .61217 .28839 .60872 .28101 .6023 Metetra
.654 .753 .922 r
.28101 .6023 .28839 .60872 .29975 .60525 .29239 .5988 Metetra
.647 .751 .925 r
.29239 .5988 .29975 .60525 .31107 .60293 .30381 .59549 Metetra
.202 .519 .917 r
.30381 .59549 .31107 .60293 .32205 .60746 .31484 .59939 Metetra
0 .116 .635 r
.31484 .59939 .32205 .60746 .33288 .61655 .32562 .60911 Metetra
.571 .073 0 r
.32562 .60911 .33288 .61655 .34376 .62721 .33642 .62115 Metetra
.624 .098 0 r
.33642 .62115 .34376 .62721 .35482 .63713 .34739 .63281 Metetra
.565 .004 0 r
.34739 .63281 .35482 .63713 .36613 .64458 .35864 .64201 Metetra
.365 0 0 r
.35864 .64201 .36613 .64458 .37773 .64835 .3702 .64729 Metetra
.052 .613 .797 r
.3702 .64729 .37773 .64835 .3896 .64772 .38207 .64776 Metetra
.534 .916 .93 r
.38207 .64776 .3896 .64772 .40171 .64241 .39421 .64303 Metetra
.799 .985 .894 r
.39421 .64303 .40171 .64241 .41401 .63254 .40658 .63316 Metetra
.899 .956 .826 r
.40658 .63316 .41401 .63254 .42643 .61851 .4191 .61861 Metetra
.932 .913 .777 r
.4191 .61861 .42643 .61851 .43893 .601 .43171 .60006 Metetra
.939 .874 .745 r
.43171 .60006 .43893 .601 .45144 .5808 .44435 .57845 Metetra
.934 .839 .726 r
.44435 .57845 .45144 .5808 .46391 .55883 .45695 .55479 Metetra
.923 .809 .716 r
.45695 .55479 .46391 .55883 .47633 .53602 .46947 .53012 Metetra
.907 .782 .712 r
.46947 .53012 .47633 .53602 .48866 .51328 .4819 .50547 Metetra
.887 .756 .712 r
.4819 .50547 .48866 .51328 .50089 .49146 .49423 .48181 Metetra
.864 .732 .715 r
.49423 .48181 .50089 .49146 .51305 .47133 .50645 .45998 Metetra
.836 .707 .722 r
.50645 .45998 .51305 .47133 .52514 .45352 .51859 .44071 Metetra
.802 .682 .731 r
.51859 .44071 .52514 .45352 .53719 .43858 .53067 .4246 Metetra
.762 .654 .743 r
.53067 .4246 .53719 .43858 .54923 .42692 .54274 .41209 Metetra
.712 .624 .757 r
.54274 .41209 .54923 .42692 .56131 .4188 .55483 .40351 Metetra
.649 .588 .773 r
.55483 .40351 .56131 .4188 .57347 .41439 .56699 .39901 Metetra
.566 .543 .789 r
.56699 .39901 .57347 .41439 .58575 .41371 .57928 .39863 Metetra
.456 .486 .801 r
.57928 .39863 .58575 .41371 .59819 .41666 .59173 .40225 Metetra
.311 .409 .801 r
.59173 .40225 .59819 .41666 .61083 .42301 .60438 .40963 Metetra
.123 .308 .778 r
.60438 .40963 .61083 .42301 .6237 .43241 .61728 .42036 Metetra
0 .185 .717 r
.61728 .42036 .6237 .43241 .63681 .44436 .63043 .4339 Metetra
0 .056 .615 r
.63043 .4339 .63681 .44436 .65019 .45826 .64387 .44956 Metetra
0 0 .495 r
.64387 .44956 .65019 .45826 .66381 .47337 .65757 .46653 Metetra
.607 .123 0 r
.65757 .46653 .66381 .47337 .67766 .48886 .67151 .48388 Metetra
.665 .151 0 r
.67151 .48388 .67766 .48886 .69171 .50382 .68566 .50056 Metetra
.673 .136 0 r
.68566 .50056 .69171 .50382 .70588 .51729 .69994 .51551 Metetra
.632 .072 0 r
.69994 .51551 .70588 .51729 .72013 .52832 .71429 .52764 Metetra
.525 0 0 r
.71429 .52764 .72013 .52832 .73435 .53601 .7286 .53597 Metetra
.295 0 0 r
.7286 .53597 .73435 .53601 .74846 .53962 .74279 .53966 Metetra
.133 .681 .77 r
.74279 .53966 .74846 .53962 .76237 .53862 .75674 .53816 Metetra
.605 .95 .91 r
.75674 .53816 .76237 .53862 .77602 .53277 .77039 .53124 Metetra
.841 .979 .874 r
.77039 .53124 .77602 .53277 .78934 .52222 .78368 .51915 Metetra
.913 .925 .809 r
.78368 .51915 .78934 .52222 .80234 .50757 .79661 .50266 Metetra
.925 .871 .766 r
.79661 .50266 .80234 .50757 .81505 .48993 .80925 .48312 Metetra
.913 .829 .749 r
.80925 .48312 .81505 .48993 .8276 .47097 .82172 .46252 Metetra
.886 .797 .757 r
.82172 .46252 .8276 .47097 .84017 .45295 .83427 .44354 Metetra
.828 .772 .798 r
.83427 .44354 .84017 .45295 .85308 .43881 .84727 .42962 Metetra
.689 .732 .883 r
.84727 .42962 .85308 .43881 .86674 .43192 .86111 .42401 Metetra
.654 .753 .922 r
.86111 .42401 .86674 .43192 .88073 .42764 .87514 .41969 Metetra
.654 .753 .922 r
.87514 .41969 .88073 .42764 .89478 .42335 .88925 .41536 Metetra
.654 .753 .922 r
.26221 .59934 .26968 .60578 .28101 .6023 .27357 .59583 Metetra
.654 .753 .922 r
.27357 .59583 .28101 .6023 .29239 .5988 .28498 .5923 Metetra
.654 .753 .922 r
.28498 .5923 .29239 .5988 .30381 .59549 .29645 .58876 Metetra
.348 .625 .956 r
.29645 .58876 .30381 .59549 .31484 .59939 .30761 .59059 Metetra
0 .133 .661 r
.30761 .59059 .31484 .59939 .32562 .60911 .31838 .60046 Metetra
.56 .089 0 r
.31838 .60046 .32562 .60911 .33642 .62115 .32911 .61356 Metetra
.624 .128 0 r
.32911 .61356 .33642 .62115 .34739 .63281 .33999 .62676 Metetra
.572 .041 0 r
.33999 .62676 .34739 .63281 .35864 .64201 .35115 .63765 Metetra
.371 0 0 r
.35115 .63765 .35864 .64201 .3702 .64729 .36266 .64451 Metetra
.066 .593 .87 r
.36266 .64451 .3702 .64729 .38207 .64776 .37451 .64624 Metetra
.559 .898 .981 r
.37451 .64624 .38207 .64776 .39421 .64303 .38667 .64234 Metetra
.809 .958 .911 r
.38667 .64234 .39421 .64303 .40658 .63316 .3991 .63282 Metetra
.899 .933 .828 r
.3991 .63282 .40658 .63316 .4191 .61861 .41171 .61809 Metetra
.931 .897 .772 r
.41171 .61809 .4191 .61861 .43171 .60006 .42442 .59892 Metetra
.94 .865 .737 r
.42442 .59892 .43171 .60006 .44435 .57845 .43717 .5763 Metetra
.939 .838 .717 r
.43717 .5763 .44435 .57845 .45695 .55479 .44989 .55133 Metetra
.932 .815 .707 r
.44989 .55133 .45695 .55479 .46947 .53012 .46254 .52519 Metetra
.92 .794 .704 r
.46254 .52519 .46947 .53012 .4819 .50547 .47508 .499 Metetra
.905 .774 .707 r
.47508 .499 .4819 .50547 .49423 .48181 .4875 .47381 Metetra
.886 .756 .713 r
.4875 .47381 .49423 .48181 .50645 .45998 .4998 .45057 Metetra
.861 .737 .724 r
.4998 .45057 .50645 .45998 .51859 .44071 .512 .43007 Metetra
.83 .716 .739 r
.512 .43007 .51859 .44071 .53067 .4246 .52413 .41296 Metetra
.789 .693 .758 r
.52413 .41296 .53067 .4246 .54274 .41209 .53623 .39974 Metetra
.735 .664 .781 r
.53623 .39974 .54274 .41209 .55483 .40351 .54834 .39075 Metetra
.66 .627 .806 r
.54834 .39075 .55483 .40351 .56699 .39901 .56052 .38618 Metetra
.553 .573 .829 r
.56052 .38618 .56699 .39901 .57928 .39863 .57282 .38605 Metetra
.4 .494 .84 r
.57282 .38605 .57928 .39863 .59173 .40225 .58528 .39024 Metetra
.189 .378 .82 r
.58528 .39024 .59173 .40225 .60438 .40963 .59795 .39847 Metetra
0 .226 .746 r
.59795 .39847 .60438 .40963 .61728 .42036 .61087 .41031 Metetra
0 .064 .619 r
.61087 .41031 .61728 .42036 .63043 .4339 .62407 .42517 Metetra
0 0 .475 r
.62407 .42517 .63043 .4339 .64387 .44956 .63755 .44229 Metetra
.636 .161 0 r
.63755 .44229 .64387 .44956 .65757 .46653 .65131 .46077 Metetra
.701 .206 0 r
.65131 .46077 .65757 .46653 .67151 .48388 .66533 .47959 Metetra
.722 .211 0 r
.66533 .47959 .67151 .48388 .68566 .50056 .67956 .49759 Metetra
.707 .178 0 r
.67956 .49759 .68566 .50056 .69994 .51551 .69393 .5136 Metetra
.648 .093 0 r
.69393 .5136 .69994 .51551 .71429 .52764 .70835 .52643 Metetra
.511 0 0 r
.70835 .52643 .71429 .52764 .7286 .53597 .72273 .535 Metetra
.204 0 0 r
.72273 .535 .7286 .53597 .74279 .53966 .73696 .53843 Metetra
.325 .8 .912 r
.73696 .53843 .74279 .53966 .75674 .53816 .75093 .53613 Metetra
.732 .96 .942 r
.75093 .53613 .75674 .53816 .77039 .53124 .76456 .52795 Metetra
.877 .93 .853 r
.76456 .52795 .77039 .53124 .78368 .51915 .77781 .51422 Metetra
.915 .874 .783 r
.77781 .51422 .78368 .51915 .79661 .50266 .79068 .49592 Metetra
.917 .829 .744 r
.79068 .49592 .79661 .50266 .80925 .48312 .80325 .47463 Metetra
.903 .796 .732 r
.80325 .47463 .80925 .48312 .82172 .46252 .81568 .4527 Metetra
.874 .772 .746 r
.81568 .4527 .82172 .46252 .83427 .44354 .82825 .43322 Metetra
.806 .75 .8 r
.82825 .43322 .83427 .44354 .84727 .42962 .84141 .42036 Metetra
.655 .718 .895 r
.84141 .42036 .84727 .42962 .86111 .42401 .85542 .41603 Metetra
.654 .753 .922 r
.85542 .41603 .86111 .42401 .87514 .41969 .86951 .41167 Metetra
.654 .753 .922 r
.86951 .41167 .87514 .41969 .88925 .41536 .88366 .4073 Metetra
.654 .753 .922 r
.25468 .59285 .26221 .59934 .27357 .59583 .26607 .58931 Metetra
.654 .753 .922 r
.26607 .58931 .27357 .59583 .28498 .5923 .27751 .58575 Metetra
.654 .753 .922 r
.27751 .58575 .28498 .5923 .29645 .58876 .28901 .58218 Metetra
.536 .716 .955 r
.28901 .58218 .29645 .58876 .30761 .59059 .30037 .58123 Metetra
0 .179 .706 r
.30037 .58123 .30761 .59059 .31838 .60046 .31115 .59071 Metetra
0 0 .457 r
.31115 .59071 .31838 .60046 .32911 .61356 .32182 .60449 Metetra
.61 .144 0 r
.32182 .60449 .32911 .61356 .33999 .62676 .33261 .61898 Metetra
.564 .07 0 r
.33261 .61898 .33999 .62676 .35115 .63765 .34369 .63146 Metetra
0 .153 .621 r
.34369 .63146 .35115 .63765 .36266 .64451 .35512 .63992 Metetra
.065 .541 .895 r
.35512 .63992 .36266 .64451 .37451 .64624 .36694 .64307 Metetra
.551 .847 .998 r
.36694 .64307 .37451 .64624 .38667 .64234 .3791 .64024 Metetra
.799 .921 .919 r
.3791 .64024 .38667 .64234 .3991 .63282 .39157 .63136 Metetra
.892 .908 .83 r
.39157 .63136 .3991 .63282 .41171 .61809 .40424 .61684 Metetra
.926 .881 .77 r
.40424 .61684 .41171 .61809 .42442 .59892 .41705 .59746 Metetra
.939 .857 .733 r
.41705 .59746 .42442 .59892 .43717 .5763 .42991 .57425 Metetra
.942 .837 .712 r
.42991 .57425 .43717 .5763 .44989 .55133 .44275 .54841 Metetra
.938 .82 .701 r
.44275 .54841 .44989 .55133 .46254 .52519 .45552 .5212 Metetra
.931 .805 .699 r
.45552 .5212 .46254 .52519 .47508 .499 .46817 .49384 Metetra
.92 .792 .702 r
.46817 .49384 .47508 .499 .4875 .47381 .48069 .46748 Metetra
.905 .78 .712 r
.48069 .46748 .4875 .47381 .4998 .45057 .49308 .44312 Metetra
.885 .767 .727 r
.49308 .44312 .4998 .45057 .512 .43007 .50536 .42164 Metetra
.858 .754 .748 r
.50536 .42164 .512 .43007 .52413 .41296 .51755 .40373 Metetra
.819 .738 .775 r
.51755 .40373 .52413 .41296 .53623 .39974 .52969 .38994 Metetra
.761 .715 .809 r
.52969 .38994 .53623 .39974 .54834 .39075 .54184 .38062 Metetra
.672 .679 .848 r
.54184 .38062 .54834 .39075 .56052 .38618 .55405 .37597 Metetra
.53 .615 .882 r
.55405 .37597 .56052 .38618 .57282 .38605 .56636 .37604 Metetra
.309 .5 .883 r
.56636 .37604 .57282 .38605 .58528 .39024 .57884 .38068 Metetra
.009 .322 .809 r
.57884 .38068 .58528 .39024 .59795 .39847 .59153 .38959 Metetra
0 .113 .652 r
.59153 .38959 .59795 .39847 .61087 .41031 .60448 .40232 Metetra
0 0 .471 r
.60448 .40232 .61087 .41031 .62407 .42517 .61771 .41821 Metetra
.657 .176 0 r
.61771 .41821 .62407 .42517 .63755 .44229 .63123 .43645 Metetra
.727 .238 0 r
.63123 .43645 .63755 .44229 .65131 .46077 .64504 .45607 Metetra
.756 .26 0 r
.64504 .45607 .65131 .46077 .66533 .47959 .65911 .47594 Metetra
.755 .248 0 r
.65911 .47594 .66533 .47959 .67956 .49759 .6734 .49483 Metetra
.725 .2 0 r
.6734 .49483 .67956 .49759 .69393 .5136 .68782 .51146 Metetra
.648 .094 0 r
.68782 .51146 .69393 .5136 .70835 .52643 .7023 .52457 Metetra
.469 0 0 r
.7023 .52457 .70835 .52643 .72273 .535 .71672 .53298 Metetra
0 .508 .779 r
.71672 .53298 .72273 .535 .73696 .53843 .73097 .53579 Metetra
.503 .865 .987 r
.73097 .53579 .73696 .53843 .75093 .53613 .74494 .53243 Metetra
.798 .922 .92 r
.74494 .53243 .75093 .53613 .76456 .52795 .75855 .5228 Metetra
.886 .875 .821 r
.75855 .5228 .76456 .52795 .77781 .51422 .77175 .50737 Metetra
.907 .828 .757 r
.77175 .50737 .77781 .51422 .79068 .49592 .78456 .48732 Metetra
.906 .793 .726 r
.78456 .48732 .79068 .49592 .80325 .47463 .79707 .46451 Metetra
.892 .768 .719 r
.79707 .46451 .80325 .47463 .81568 .4527 .80949 .44161 Metetra
.861 .75 .74 r
.80949 .44161 .81568 .4527 .82825 .43322 .82212 .42213 Metetra
.756 .72 .819 r
.82212 .42213 .82825 .43322 .84141 .42036 .83562 .41235 Metetra
.654 .753 .922 r
.83562 .41235 .84141 .42036 .85542 .41603 .84969 .40797 Metetra
.654 .753 .922 r
.84969 .40797 .85542 .41603 .86951 .41167 .86382 .40358 Metetra
.654 .753 .922 r
.86382 .40358 .86951 .41167 .88366 .4073 .87803 .39917 Metetra
.654 .753 .922 r
.24709 .5863 .25468 .59285 .26607 .58931 .25851 .58273 Metetra
.654 .753 .922 r
.25851 .58273 .26607 .58931 .27751 .58575 .26998 .57915 Metetra
.654 .753 .922 r
.26998 .57915 .27751 .58575 .28901 .58218 .2815 .57555 Metetra
.654 .753 .922 r
.2815 .57555 .28901 .58218 .30037 .58123 .29308 .57193 Metetra
0 .272 .775 r
.29308 .57193 .30037 .58123 .31115 .59071 .30394 .58004 Metetra
0 0 .491 r
.30394 .58004 .31115 .59071 .32182 .60449 .31456 .59405 Metetra
.585 .149 0 r
.31456 .59405 .32182 .60449 .33261 .61898 .32528 .60955 Metetra
0 0 .447 r
.32528 .60955 .33261 .61898 .34369 .63146 .33626 .62346 Metetra
0 .112 .625 r
.33626 .62346 .34369 .63146 .35512 .63992 .34761 .6335 Metetra
.05 .471 .884 r
.34761 .6335 .35512 .63992 .36694 .64307 .35937 .63816 Metetra
.519 .778 .991 r
.35937 .63816 .36694 .64307 .3791 .64024 .37152 .63662 Metetra
.775 .876 .921 r
.37152 .63662 .3791 .64024 .39157 .63136 .384 .6287 Metetra
.877 .881 .834 r
.384 .6287 .39157 .63136 .40424 .61684 .39672 .61476 Metetra
.918 .866 .772 r
.39672 .61476 .40424 .61684 .41705 .59746 .40961 .59557 Metetra
.936 .85 .733 r
.40961 .59557 .41705 .59746 .42991 .57425 .42257 .57221 Metetra
.942 .836 .71 r
.42257 .57221 .42991 .57425 .44275 .54841 .43552 .54595 Metetra
.943 .825 .698 r
.43552 .54595 .44275 .54841 .45552 .5212 .44841 .5181 Metetra
.94 .816 .695 r
.44841 .5181 .45552 .5212 .46817 .49384 .46117 .48997 Metetra
.933 .809 .699 r
.46117 .48997 .46817 .49384 .48069 .46748 .4738 .46278 Metetra
.923 .804 .71 r
.4738 .46278 .48069 .46748 .49308 .44312 .48629 .43762 Metetra
.908 .799 .728 r
.48629 .43762 .49308 .44312 .50536 .42164 .49865 .41541 Metetra
.885 .795 .756 r
.49865 .41541 .50536 .42164 .51755 .40373 .51091 .39691 Metetra
.849 .789 .793 r
.51091 .39691 .51755 .40373 .52969 .38994 .52311 .38267 Metetra
.789 .778 .843 r
.52311 .38267 .52969 .38994 .54184 .38062 .5353 .3731 Metetra
.682 .747 .901 r
.5353 .3731 .54184 .38062 .55405 .37597 .54755 .3684 Metetra
.485 .667 .944 r
.54755 .3684 .55405 .37597 .56636 .37604 .55989 .3686 Metetra
.158 .489 .903 r
.55989 .3686 .56636 .37604 .57884 .38068 .5724 .37357 Metetra
0 .224 .723 r
.5724 .37357 .57884 .38068 .59153 .38959 .58511 .38299 Metetra
.508 .013 0 r
.58511 .38299 .59153 .38959 .60448 .40232 .59808 .39636 Metetra
.665 .164 0 r
.59808 .39636 .60448 .40232 .61771 .41821 .61134 .41298 Metetra
.742 .247 0 r
.61134 .41298 .61771 .41821 .63123 .43645 .62489 .43199 Metetra
.777 .285 0 r
.62489 .43199 .63123 .43645 .64504 .45607 .63873 .45235 Metetra
.786 .292 0 r
.63873 .45235 .64504 .45607 .65911 .47594 .65284 .47285 Metetra
.772 .268 0 r
.65284 .47285 .65911 .47594 .6734 .49483 .66717 .49219 Metetra
.73 .206 0 r
.66717 .49219 .6734 .49483 .68782 .51146 .68164 .50899 Metetra
.631 .075 0 r
.68164 .50899 .68782 .51146 .7023 .52457 .69614 .52193 Metetra
.391 0 0 r
.69614 .52193 .7023 .52457 .71672 .53298 .71058 .52979 Metetra
.126 .624 .907 r
.71058 .52979 .71672 .53298 .73097 .53579 .72482 .53165 Metetra
.63 .87 .987 r
.72482 .53165 .73097 .53579 .74494 .53243 .73877 .52697 Metetra
.825 .87 .879 r
.73877 .52697 .74494 .53243 .75855 .5228 .75234 .51574 Metetra
.882 .827 .789 r
.75234 .51574 .75855 .5228 .77175 .50737 .76549 .49861 Metetra
.897 .791 .736 r
.76549 .49861 .77175 .50737 .78456 .48732 .77825 .47693 Metetra
.894 .765 .711 r
.77825 .47693 .78456 .48732 .79707 .46451 .79073 .45286 Metetra
.88 .746 .71 r
.79073 .45286 .79707 .46451 .80949 .44161 .80317 .42941 Metetra
.845 .732 .738 r
.80317 .42941 .80949 .44161 .82212 .42213 .81591 .4105 Metetra
.69 .684 .84 r
.81591 .4105 .82212 .42213 .83562 .41235 .82979 .40426 Metetra
.654 .753 .922 r
.82979 .40426 .83562 .41235 .84969 .40797 .8439 .39985 Metetra
.654 .753 .922 r
.8439 .39985 .84969 .40797 .86382 .40358 .85809 .39542 Metetra
.654 .753 .922 r
.85809 .39542 .86382 .40358 .87803 .39917 .87234 .39097 Metetra
.654 .753 .922 r
.23944 .5797 .24709 .5863 .25851 .58273 .25089 .5761 Metetra
.654 .753 .922 r
.25089 .5761 .25851 .58273 .26998 .57915 .26239 .57249 Metetra
.654 .753 .922 r
.26239 .57249 .26998 .57915 .2815 .57555 .27394 .56886 Metetra
.654 .753 .922 r
.27394 .56886 .2815 .57555 .29308 .57193 .28555 .56522 Metetra
.183 .541 .927 r
.28555 .56522 .29308 .57193 .30394 .58004 .29672 .56865 Metetra
0 0 .536 r
.29672 .56865 .30394 .58004 .31456 .59405 .30734 .58242 Metetra
0 0 .422 r
.30734 .58242 .31456 .59405 .32528 .60955 .31798 .59858 Metetra
0 0 .457 r
.31798 .59858 .32528 .60955 .33626 .62346 .32887 .61371 Metetra
0 .076 .617 r
.32887 .61371 .33626 .62346 .34761 .6335 .34013 .62526 Metetra
.027 .397 .853 r
.34013 .62526 .34761 .6335 .35937 .63816 .35182 .63149 Metetra
.471 .7 .968 r
.35182 .63149 .35937 .63816 .37152 .63662 .36393 .63142 Metetra
.739 .827 .919 r
.36393 .63142 .37152 .63662 .384 .6287 .3764 .62473 Metetra
.856 .853 .838 r
.3764 .62473 .384 .6287 .39672 .61476 .38916 .61172 Metetra
.907 .851 .777 r
.38916 .61172 .39672 .61476 .40961 .59557 .40211 .59314 Metetra
.93 .843 .736 r
.40211 .59314 .40961 .59557 .42257 .57221 .41515 .57008 Metetra
.941 .836 .711 r
.41515 .57008 .42257 .57221 .43552 .54595 .4282 .54382 Metetra
.946 .83 .698 r
.4282 .54382 .43552 .54595 .44841 .5181 .4412 .51577 Metetra
.947 .827 .693 r
.4412 .51577 .44841 .5181 .46117 .48997 .45407 .48728 Metetra
.944 .826 .697 r
.45407 .48728 .46117 .48997 .4738 .46278 .46681 .45964 Metetra
.938 .827 .709 r
.46681 .45964 .4738 .46278 .48629 .43762 .4794 .43399 Metetra
.928 .831 .73 r
.4794 .43399 .48629 .43762 .49865 .41541 .49185 .41132 Metetra
.909 .838 .762 r
.49185 .41132 .49865 .41541 .51091 .39691 .50419 .39242 Metetra
.877 .846 .81 r
.50419 .39242 .51091 .39691 .52311 .38267 .51646 .37789 Metetra
.814 .851 .877 r
.51646 .37789 .52311 .38267 .5353 .3731 .52872 .36814 Metetra
.679 .83 .956 r
.52872 .36814 .5353 .3731 .54755 .3684 .54101 .36339 Metetra
.39 .714 .987 r
.54101 .36339 .54755 .3684 .55989 .3686 .55339 .36368 Metetra
0 .425 .832 r
.55339 .36368 .55989 .3686 .5724 .37357 .56593 .36886 Metetra
.446 0 0 r
.56593 .36886 .5724 .37357 .58511 .38299 .57867 .37859 Metetra
.648 .115 0 r
.57867 .37859 .58511 .38299 .59808 .39636 .59167 .39235 Metetra
.742 .231 0 r
.59167 .39235 .59808 .39636 .61134 .41298 .60494 .40939 Metetra
.785 .289 0 r
.60494 .40939 .61134 .41298 .62489 .43199 .61852 .42882 Metetra
.802 .312 0 r
.61852 .42882 .62489 .43199 .63873 .45235 .63239 .44952 Metetra
.8 .308 0 r
.63239 .44952 .63873 .45235 .65284 .47285 .64653 .47022 Metetra
.778 .274 0 r
.64653 .47022 .65284 .47285 .66717 .49219 .66087 .48955 Metetra
.723 .197 0 r
.66087 .48955 .66717 .49219 .68164 .50899 .67535 .50607 Metetra
.593 .034 0 r
.67535 .50607 .68164 .50899 .69614 .52193 .68986 .51841 Metetra
0 .297 .682 r
.68986 .51841 .69614 .52193 .71058 .52979 .70429 .52533 Metetra
.319 .71 .98 r
.70429 .52533 .71058 .52979 .72482 .53165 .71852 .52592 Metetra
.705 .842 .948 r
.71852 .52592 .72482 .53165 .73877 .52697 .73243 .51971 Metetra
.835 .823 .837 r
.73243 .51971 .73877 .52697 .75234 .51574 .74595 .50679 Metetra
.875 .788 .761 r
.74595 .50679 .75234 .51574 .76549 .49861 .75905 .48798 Metetra
.886 .761 .719 r
.75905 .48798 .76549 .49861 .77825 .47693 .77177 .46486 Metetra
.883 .741 .701 r
.77177 .46486 .77825 .47693 .79073 .45286 .78425 .43986 Metetra
.868 .728 .705 r
.78425 .43986 .79073 .45286 .80317 .42941 .79673 .41632 Metetra
.81 .71 .755 r
.79673 .41632 .80317 .42941 .81591 .4105 .8098 .40053 Metetra
.654 .705 .884 r
.8098 .40053 .81591 .4105 .82979 .40426 .8239 .3961 Metetra
.654 .753 .922 r
.8239 .3961 .82979 .40426 .8439 .39985 .83806 .39165 Metetra
.654 .753 .922 r
.83806 .39165 .8439 .39985 .85809 .39542 .8523 .38718 Metetra
.654 .753 .922 r
.8523 .38718 .85809 .39542 .87234 .39097 .8666 .38269 Metetra
.654 .753 .922 r
.23173 .57305 .23944 .5797 .25089 .5761 .24321 .56942 Metetra
.654 .753 .922 r
.24321 .56942 .25089 .5761 .26239 .57249 .25474 .56578 Metetra
.654 .753 .922 r
.25474 .56578 .26239 .57249 .27394 .56886 .26632 .56212 Metetra
.654 .753 .922 r
.26632 .56212 .27394 .56886 .28555 .56522 .27795 .55845 Metetra
.568 .727 .949 r
.27795 .55845 .28555 .56522 .29672 .56865 .2895 .5568 Metetra
0 .028 .593 r
.2895 .5568 .29672 .56865 .30734 .58242 .30013 .56982 Metetra
0 0 .449 r
.30013 .56982 .30734 .58242 .31798 .59858 .31072 .58625 Metetra
0 0 .466 r
.31072 .58625 .31798 .59858 .32887 .61371 .32152 .60234 Metetra
0 .045 .604 r
.32152 .60234 .32887 .61371 .34013 .62526 .33268 .61527 Metetra
0 .328 .813 r
.33268 .61527 .34013 .62526 .35182 .63149 .34429 .62309 Metetra
.415 .621 .937 r
.34429 .62309 .35182 .63149 .36393 .63142 .35634 .62461 Metetra
.695 .774 .912 r
.35634 .62461 .36393 .63142 .3764 .62473 .36878 .6194 Metetra
.829 .823 .843 r
.36878 .6194 .3764 .62473 .38916 .61172 .38155 .60765 Metetra
.892 .835 .784 r
.38155 .60765 .38916 .61172 .40211 .59314 .39454 .59006 Metetra
.922 .836 .742 r
.39454 .59006 .40211 .59314 .41515 .57008 .40765 .56771 Metetra
.939 .835 .715 r
.40765 .56771 .41515 .57008 .4282 .54382 .42079 .54191 Metetra
.947 .835 .7 r
.42079 .54191 .4282 .54382 .4412 .51577 .43389 .51408 Metetra
.951 .837 .694 r
.43389 .51408 .4412 .51577 .45407 .48728 .44687 .48563 Metetra
.952 .841 .696 r
.44687 .48563 .45407 .48728 .46681 .45964 .45972 .45791 Metetra
.95 .849 .708 r
.45972 .45791 .46681 .45964 .4794 .43399 .47241 .43211 Metetra
.943 .862 .73 r
.47241 .43211 .4794 .43399 .49185 .41132 .48496 .40924 Metetra
.929 .88 .766 r
.48496 .40924 .49185 .41132 .50419 .39242 .49739 .39015 Metetra
.897 .904 .822 r
.49739 .39015 .50419 .39242 .51646 .37789 .50974 .37546 Metetra
.824 .926 .901 r
.50974 .37546 .51646 .37789 .52872 .36814 .52206 .36561 Metetra
.637 .904 .984 r
.52206 .36561 .52872 .36814 .54101 .36339 .53441 .36082 Metetra
.215 .698 .931 r
.53441 .36082 .54101 .36339 .55339 .36368 .54684 .36114 Metetra
.29 0 0 r
.54684 .36114 .55339 .36368 .56593 .36886 .55942 .36641 Metetra
.583 .013 0 r
.55942 .36641 .56593 .36886 .57867 .37859 .57219 .37627 Metetra
.714 .181 0 r
.57219 .37627 .57867 .37859 .59167 .39235 .58522 .39016 Metetra
.775 .268 0 r
.58522 .39016 .59167 .39235 .60494 .40939 .59852 .40733 Metetra
.802 .31 0 r
.59852 .40733 .60494 .40939 .61852 .42882 .61211 .4268 Metetra
.811 .324 0 r
.61211 .4268 .61852 .42882 .63239 .44952 .626 .44743 Metetra
.803 .312 0 r
.626 .44743 .63239 .44952 .64653 .47022 .64014 .4679 Metetra
.774 .268 0 r
.64014 .4679 .64653 .47022 .66087 .48955 .65449 .48677 Metetra
.704 .171 0 r
.65449 .48677 .66087 .48955 .67535 .50607 .66897 .50257 Metetra
.527 0 0 r
.66897 .50257 .67535 .50607 .68986 .51841 .68347 .5139 Metetra
0 .424 .815 r
.68347 .5139 .68986 .51841 .70429 .52533 .69787 .51952 Metetra
.477 .75 .989 r
.69787 .51952 .70429 .52533 .71852 .52592 .71206 .51857 Metetra
.747 .805 .899 r
.71206 .51857 .71852 .52592 .73243 .51971 .72592 .51066 Metetra
.837 .783 .801 r
.72592 .51066 .73243 .51971 .74595 .50679 .73939 .49601 Metetra
.867 .757 .739 r
.73939 .49601 .74595 .50679 .75905 .48798 .75245 .47561 Metetra
.876 .737 .705 r
.75245 .47561 .75905 .48798 .77177 .46486 .76514 .45128 Metetra
.872 .723 .693 r
.76514 .45128 .77177 .46486 .78425 .43986 .77764 .42572 Metetra
.855 .712 .704 r
.77764 .42572 .78425 .43986 .79673 .41632 .79022 .40259 Metetra
.741 .676 .787 r
.79022 .40259 .79673 .41632 .8098 .40053 .80382 .39234 Metetra
.654 .753 .922 r
.80382 .39234 .8098 .40053 .8239 .3961 .81796 .38787 Metetra
.654 .753 .922 r
.81796 .38787 .8239 .3961 .83806 .39165 .83217 .38338 Metetra
.654 .753 .922 r
.83217 .38338 .83806 .39165 .8523 .38718 .84646 .37887 Metetra
.654 .753 .922 r
.84646 .37887 .8523 .38718 .8666 .38269 .86081 .37434 Metetra
.654 .753 .922 r
.22395 .56634 .23173 .57305 .24321 .56942 .23546 .56269 Metetra
.654 .753 .922 r
.23546 .56269 .24321 .56942 .25474 .56578 .24702 .55901 Metetra
.654 .753 .922 r
.24702 .55901 .25474 .56578 .26632 .56212 .25863 .55533 Metetra
.654 .753 .922 r
.25863 .55533 .26632 .56212 .27795 .55845 .2703 .55162 Metetra
.654 .753 .922 r
.2703 .55162 .27795 .55845 .2895 .5568 .28201 .5479 Metetra
0 .218 .73 r
.28201 .5479 .2895 .5568 .30013 .56982 .29293 .5565 Metetra
0 0 .483 r
.29293 .5565 .30013 .56982 .31072 .58625 .30349 .57277 Metetra
0 0 .477 r
.30349 .57277 .31072 .58625 .32152 .60234 .31421 .58952 Metetra
0 .021 .59 r
.31421 .58952 .32152 .60234 .33268 .61527 .32528 .60366 Metetra
0 .267 .773 r
.32528 .60366 .33268 .61527 .34429 .62309 .33679 .61301 Metetra
.354 .544 .902 r
.33679 .61301 .34429 .62309 .35634 .62461 .34876 .6162 Metetra
.642 .718 .903 r
.34876 .6162 .35634 .62461 .36878 .6194 .36116 .61266 Metetra
.796 .791 .847 r
.36116 .61266 .36878 .6194 .38155 .60765 .37391 .60245 Metetra
.872 .818 .792 r
.37391 .60245 .38155 .60765 .39454 .59006 .38692 .58621 Metetra
.912 .828 .751 r
.38692 .58621 .39454 .59006 .40765 .56771 .40008 .56498 Metetra
.934 .834 .722 r
.40008 .56498 .40765 .56771 .42079 .54191 .41329 .54005 Metetra
.947 .839 .705 r
.41329 .54005 .42079 .54191 .43389 .51408 .42647 .51287 Metetra
.954 .846 .697 r
.42647 .51287 .43389 .51408 .44687 .48563 .43956 .48487 Metetra
.958 .856 .698 r
.43956 .48487 .44687 .48563 .45972 .45791 .45251 .45743 Metetra
.958 .871 .708 r
.45251 .45743 .45972 .45791 .47241 .43211 .46531 .43178 Metetra
.954 .891 .729 r
.46531 .43178 .47241 .43211 .48496 .40924 .47797 .40899 Metetra
.939 .919 .766 r
.47797 .40899 .48496 .40924 .49739 .39015 .49049 .38992 Metetra
.902 .955 .822 r
.49049 .38992 .49739 .39015 .50974 .37546 .50293 .37521 Metetra
.801 .983 .896 r
.50293 .37521 .50974 .37546 .52206 .36561 .51532 .36533 Metetra
.522 .912 .924 r
.51532 .36533 .52206 .36561 .53441 .36082 .52774 .36052 Metetra
0 .575 .724 r
.52774 .36052 .53441 .36082 .54684 .36114 .54022 .36081 Metetra
.433 0 0 r
.54022 .36081 .54684 .36114 .55942 .36641 .55285 .36604 Metetra
.642 .083 0 r
.55285 .36604 .55942 .36641 .57219 .37627 .56566 .37583 Metetra
.737 .215 0 r
.56566 .37583 .57219 .37627 .58522 .39016 .57872 .38962 Metetra
.783 .284 .002 r
.57872 .38962 .58522 .39016 .59852 .40733 .59204 .40659 Metetra
.805 .317 .026 r
.59204 .40659 .59852 .40733 .61211 .4268 .60565 .42576 Metetra
.81 .324 .021 r
.60565 .42576 .61211 .4268 .626 .44743 .61954 .44593 Metetra
.799 .305 0 r
.61954 .44593 .626 .44743 .64014 .4679 .63369 .46574 Metetra
.762 .249 0 r
.63369 .46574 .64014 .4679 .65449 .48677 .64803 .48372 Metetra
.668 .126 0 r
.64803 .48372 .65449 .48677 .66897 .50257 .66249 .49838 Metetra
.418 0 0 r
.66249 .49838 .66897 .50257 .68347 .5139 .67696 .50831 Metetra
.12 .546 .918 r
.67696 .50831 .68347 .5139 .69787 .51952 .69132 .51233 Metetra
.588 .756 .958 r
.69132 .51233 .69787 .51952 .71206 .51857 .70546 .50961 Metetra
.771 .772 .854 r
.70546 .50961 .71206 .51857 .72592 .51066 .71927 .49987 Metetra
.836 .752 .771 r
.71927 .49987 .72592 .51066 .73939 .49601 .73269 .4835 Metetra
.86 .733 .721 r
.73269 .4835 .73939 .49601 .75245 .47561 .74571 .46167 Metetra
.867 .718 .695 r
.74571 .46167 .75245 .47561 .76514 .45128 .7584 .43641 Metetra
.862 .708 .689 r
.7584 .43641 .76514 .45128 .77764 .42572 .77094 .41071 Metetra
.842 .7 .706 r
.77094 .41071 .77764 .42572 .79022 .40259 .78365 .38856 Metetra
.643 .627 .818 r
.78365 .38856 .79022 .40259 .80382 .39234 .79777 .38407 Metetra
.654 .753 .922 r
.79777 .38407 .80382 .39234 .81796 .38787 .81197 .37956 Metetra
.654 .753 .922 r
.81197 .37956 .81796 .38787 .83217 .38338 .82623 .37503 Metetra
.654 .753 .922 r
.82623 .37503 .83217 .38338 .84646 .37887 .84056 .37048 Metetra
.654 .753 .922 r
.84056 .37048 .84646 .37887 .86081 .37434 .85497 .36591 Metetra
.654 .753 .922 r
.21611 .55958 .22395 .56634 .23546 .56269 .22765 .55589 Metetra
.654 .753 .922 r
.22765 .55589 .23546 .56269 .24702 .55901 .23924 .55219 Metetra
.654 .753 .922 r
.23924 .55219 .24702 .55901 .25863 .55533 .25088 .54847 Metetra
.654 .753 .922 r
.25088 .54847 .25863 .55533 .2703 .55162 .26258 .54474 Metetra
.654 .753 .922 r
.26258 .54474 .2703 .55162 .28201 .5479 .27433 .54099 Metetra
.339 .627 .958 r
.27433 .54099 .28201 .5479 .29293 .5565 .28573 .54274 Metetra
0 0 .525 r
.28573 .54274 .29293 .5565 .30349 .57277 .29629 .55841 Metetra
0 0 .49 r
.29629 .55841 .30349 .57277 .31421 .58952 .30695 .57546 Metetra
0 .003 .579 r
.30695 .57546 .31421 .58952 .32528 .60366 .31792 .59058 Metetra
0 .215 .737 r
.31792 .59058 .32528 .60366 .33679 .61301 .32933 .60136 Metetra
.293 .473 .866 r
.32933 .60136 .33679 .61301 .34876 .6162 .34121 .60625 Metetra
.584 .66 .89 r
.34121 .60625 .34876 .6162 .36116 .61266 .35354 .6045 Metetra
.756 .755 .851 r
.35354 .6045 .36116 .61266 .37391 .60245 .36626 .59607 Metetra
.848 .798 .802 r
.36626 .59607 .37391 .60245 .38692 .58621 .37926 .58149 Metetra
.898 .819 .761 r
.37926 .58149 .38692 .58621 .40008 .56498 .39244 .56174 Metetra
.926 .832 .732 r
.39244 .56174 .40008 .56498 .41329 .54005 .40571 .53808 Metetra
.944 .843 .713 r
.40571 .53808 .41329 .54005 .42647 .51287 .41896 .51194 Metetra
.955 .855 .703 r
.41896 .51194 .42647 .51287 .43956 .48487 .43214 .48477 Metetra
.961 .87 .702 r
.43214 .48477 .43956 .48487 .45251 .45743 .44519 .45797 Metetra
.963 .89 .71 r
.44519 .45797 .45251 .45743 .46531 .43178 .4581 .43279 Metetra
.958 .917 .728 r
.4581 .43279 .46531 .43178 .47797 .40899 .47085 .41033 Metetra
.939 .951 .76 r
.47085 .41033 .47797 .40899 .49049 .38992 .48348 .39148 Metetra
.884 .989 .805 r
.48348 .39148 .49049 .38992 .50293 .37521 .49601 .37691 Metetra
.727 .99 .841 r
.49601 .37691 .50293 .37521 .51532 .36533 .50849 .36708 Metetra
.345 .818 .759 r
.50849 .36708 .51532 .36533 .52774 .36052 .52097 .36224 Metetra
.167 0 0 r
.52097 .36224 .52774 .36052 .54022 .36081 .53353 .36245 Metetra
.497 0 0 r
.53353 .36245 .54022 .36081 .55285 .36604 .54621 .36752 Metetra
.658 .121 0 r
.54621 .36752 .55285 .36604 .56566 .37583 .55906 .37706 Metetra
.737 .229 .011 r
.55906 .37706 .56566 .37583 .57872 .38962 .57215 .39049 Metetra
.778 .287 .048 r
.57215 .39049 .57872 .38962 .59204 .40659 .5855 .40697 Metetra
.798 .313 .054 r
.5855 .40697 .59204 .40659 .60565 .42576 .59912 .42549 Metetra
.802 .314 .033 r
.59912 .42549 .60565 .42576 .61954 .44593 .61302 .44481 Metetra
.787 .287 0 r
.61302 .44481 .61954 .44593 .63369 .46574 .62716 .46355 Metetra
.739 .216 0 r
.62716 .46355 .63369 .46574 .64803 .48372 .64148 .48024 Metetra
.607 .055 0 r
.64148 .48024 .64803 .48372 .66249 .49838 .6559 .49337 Metetra
0 .273 .708 r
.6559 .49337 .66249 .49838 .67696 .50831 .67033 .50157 Metetra
.318 .635 .964 r
.67033 .50157 .67696 .50831 .69132 .51233 .68464 .50371 Metetra
.659 .745 .914 r
.68464 .50371 .69132 .51233 .70546 .50961 .69872 .49905 Metetra
.785 .745 .816 r
.69872 .49905 .70546 .50961 .71927 .49987 .71247 .48744 Metetra
.834 .728 .748 r
.71247 .48744 .71927 .49987 .73269 .4835 .72585 .46942 Metetra
.853 .714 .708 r
.72585 .46942 .73269 .4835 .74571 .46167 .73884 .44636 Metetra
.859 .703 .688 r
.73884 .44636 .74571 .46167 .7584 .43641 .75155 .42051 Metetra
.853 .696 .687 r
.75155 .42051 .7584 .43641 .77094 .41071 .76416 .3951 Metetra
.779 .671 .744 r
.76416 .3951 .77094 .41071 .78365 .38856 .7775 .38026 Metetra
.654 .753 .922 r
.7775 .38026 .78365 .38856 .79777 .38407 .79167 .37573 Metetra
.654 .753 .922 r
.79167 .37573 .79777 .38407 .81197 .37956 .80592 .37118 Metetra
.654 .753 .922 r
.80592 .37118 .81197 .37956 .82623 .37503 .82023 .36661 Metetra
.654 .753 .922 r
.82023 .36661 .82623 .37503 .84056 .37048 .83462 .36202 Metetra
.654 .753 .922 r
.83462 .36202 .84056 .37048 .85497 .36591 .84907 .3574 Metetra
.654 .753 .922 r
.20821 .55276 .21611 .55958 .22765 .55589 .21978 .54905 Metetra
.654 .753 .922 r
.21978 .54905 .22765 .55589 .23924 .55219 .2314 .54531 Metetra
.654 .753 .922 r
.2314 .54531 .23924 .55219 .25088 .54847 .24307 .54156 Metetra
.654 .753 .922 r
.24307 .54156 .25088 .54847 .26258 .54474 .2548 .5378 Metetra
.654 .753 .922 r
.2548 .5378 .26258 .54474 .27433 .54099 .26657 .53401 Metetra
.654 .753 .922 r
.26657 .53401 .27433 .54099 .28573 .54274 .27841 .53021 Metetra
0 .033 .6 r
.27841 .53021 .28573 .54274 .29629 .55841 .2891 .54343 Metetra
0 0 .509 r
.2891 .54343 .29629 .55841 .30695 .57546 .29971 .56041 Metetra
0 0 .571 r
.29971 .56041 .30695 .57546 .31792 .59058 .3106 .57624 Metetra
0 .172 .706 r
.3106 .57624 .31792 .59058 .32933 .60136 .3219 .58828 Metetra
.234 .408 .831 r
.3219 .58828 .32933 .60136 .34121 .60625 .33368 .59483 Metetra
.522 .602 .875 r
.33368 .59483 .34121 .60625 .35354 .6045 .34593 .59496 Metetra
.711 .716 .853 r
.34593 .59496 .35354 .6045 .36626 .59607 .35858 .58848 Metetra
.818 .775 .812 r
.35858 .58848 .36626 .59607 .37926 .58149 .37156 .57581 Metetra
.879 .807 .774 r
.37156 .57581 .37926 .58149 .39244 .56174 .38475 .55785 Metetra
.916 .828 .745 r
.38475 .55785 .39244 .56174 .40571 .53808 .39804 .53581 Metetra
.938 .845 .725 r
.39804 .53581 .40571 .53808 .41896 .51194 .41136 .51108 Metetra
.953 .863 .713 r
.41136 .51108 .41896 .51194 .43214 .48477 .42461 .4851 Metetra
.961 .883 .709 r
.42461 .4851 .43214 .48477 .44519 .45797 .43775 .45928 Metetra
.963 .908 .713 r
.43775 .45928 .44519 .45797 .4581 .43279 .45075 .43487 Metetra
.955 .938 .727 r
.45075 .43487 .4581 .43279 .47085 .41033 .46361 .413 Metetra
.925 .973 .749 r
.46361 .413 .47085 .41033 .48348 .39148 .47634 .39456 Metetra
.839 .997 .769 r
.47634 .39456 .48348 .39148 .49601 .37691 .48897 .38025 Metetra
.612 .94 .741 r
.48897 .38025 .49601 .37691 .50849 .36708 .50154 .37055 Metetra
.50154 .37055 .50849 .36708 .52097 .36224 .51411 .36571 Metetra
.258 0 0 r
.51411 .36571 .52097 .36224 .53353 .36245 .52673 .36577 Metetra
.519 0 0 r
.52673 .36577 .53353 .36245 .54621 .36752 .53947 .37056 Metetra
.654 .137 0 r
.53947 .37056 .54621 .36752 .55906 .37706 .55238 .37968 Metetra
.726 .229 .053 r
.55238 .37968 .55906 .37706 .57215 .39049 .56551 .3925 Metetra
.766 .279 .073 r
.56551 .3925 .57215 .39049 .5855 .40697 .57888 .40821 Metetra
.786 .3 .066 r
.57888 .40821 .5855 .40697 .59912 .42549 .59252 .42573 Metetra
.788 .295 .03 r
.59252 .42573 .59912 .42549 .61302 .44481 .60641 .44385 Metetra
.767 .257 0 r
.60641 .44385 .61302 .44481 .62716 .46355 .62054 .46115 Metetra
.7 .162 0 r
.62054 .46115 .62716 .46355 .64148 .48024 .63483 .47617 Metetra
.506 0 0 r
.63483 .47617 .64148 .48024 .6559 .49337 .64921 .48744 Metetra
0 .425 .846 r
.64921 .48744 .6559 .49337 .67033 .50157 .66359 .49363 Metetra
.472 .682 .957 r
.66359 .49363 .67033 .50157 .68464 .50371 .67784 .49368 Metetra
.705 .73 .87 r
.67784 .49368 .68464 .50371 .69872 .49905 .69186 .48697 Metetra
.794 .723 .785 r
.69186 .48697 .69872 .49905 .71247 .48744 .70556 .4735 Metetra
.831 .71 .73 r
.70556 .4735 .71247 .48744 .72585 .46942 .71889 .45397 Metetra
.848 .699 .698 r
.71889 .45397 .72585 .46942 .73884 .44636 .73188 .42993 Metetra
.851 .692 .684 r
.73188 .42993 .73884 .44636 .75155 .42051 .74462 .40386 Metetra
.843 .687 .689 r
.74462 .40386 .75155 .42051 .76416 .3951 .75734 .3792 Metetra
.684 .624 .783 r
.75734 .3792 .76416 .3951 .7775 .38026 .7713 .37188 Metetra
.654 .753 .922 r
.7713 .37188 .7775 .38026 .79167 .37573 .78552 .36732 Metetra
.654 .753 .922 r
.78552 .36732 .79167 .37573 .80592 .37118 .79981 .36272 Metetra
.654 .753 .922 r
.79981 .36272 .80592 .37118 .82023 .36661 .81418 .35811 Metetra
.654 .753 .922 r
.81418 .35811 .82023 .36661 .83462 .36202 .82861 .35347 Metetra
.654 .753 .922 r
.82861 .35347 .83462 .36202 .84907 .3574 .84312 .34881 Metetra
.654 .753 .922 r
.20024 .54589 .20821 .55276 .21978 .54905 .21184 .54214 Metetra
.654 .753 .922 r
.21184 .54214 .21978 .54905 .2314 .54531 .22349 .53838 Metetra
.654 .753 .922 r
.22349 .53838 .2314 .54531 .24307 .54156 .23519 .5346 Metetra
.654 .753 .922 r
.23519 .5346 .24307 .54156 .2548 .5378 .24695 .5308 Metetra
.654 .753 .922 r
.24695 .5308 .2548 .5378 .26657 .53401 .25876 .52698 Metetra
.654 .753 .922 r
.25876 .52698 .26657 .53401 .27841 .53021 .27062 .52315 Metetra
.02 .435 .867 r
.27062 .52315 .27841 .53021 .2891 .54343 .2819 .52813 Metetra
0 0 .534 r
.2819 .52813 .2891 .54343 .29971 .56041 .2925 .54464 Metetra
0 0 .568 r
.2925 .54464 .29971 .56041 .3106 .57624 .30331 .56085 Metetra
0 .138 .68 r
.30331 .56085 .3106 .57624 .3219 .58828 .31451 .57395 Metetra
.178 .349 .798 r
.31451 .57395 .3219 .58828 .33368 .59483 .32618 .58205 Metetra
.457 .544 .857 r
.32618 .58205 .33368 .59483 .34593 .59496 .33833 .58406 Metetra
.658 .673 .853 r
.33833 .58406 .34593 .59496 .35858 .58848 .35091 .57964 Metetra
.782 .748 .822 r
.35091 .57964 .35858 .58848 .37156 .57581 .36383 .56909 Metetra
.856 .792 .788 r
.36383 .56909 .37156 .57581 .38475 .55785 .377 .55319 Metetra
.901 .822 .76 r
.377 .55319 .38475 .55785 .39804 .53581 .39031 .53308 Metetra
.93 .846 .739 r
.39031 .53308 .39804 .53581 .41136 .51108 .40366 .51008 Metetra
.948 .869 .726 r
.40366 .51008 .41136 .51108 .42461 .4851 .41697 .48562 Metetra
.959 .894 .72 r
.41697 .48562 .42461 .4851 .43775 .45928 .43019 .46108 Metetra
.96 .923 .721 r
.43019 .46108 .43775 .45928 .45075 .43487 .44329 .43773 Metetra
.947 .956 .727 r
.44329 .43773 .45075 .43487 .46361 .413 .45624 .41668 Metetra
.9 .985 .735 r
.45624 .41668 .46361 .413 .47634 .39456 .46907 .39885 Metetra
.774 .981 .722 r
.46907 .39885 .47634 .39456 .48897 .38025 .4818 .38493 Metetra
.487 .858 .63 r
.4818 .38493 .48897 .38025 .50154 .37055 .49447 .37542 Metetra
.49447 .37542 .50154 .37055 .51411 .36571 .50713 .37058 Metetra
.303 0 0 r
.50713 .37058 .51411 .36571 .52673 .36577 .51983 .37045 Metetra
.52 0 0 r
.51983 .37045 .52673 .36577 .53947 .37056 .53264 .37484 Metetra
.641 .136 .034 r
.53264 .37484 .53947 .37056 .55238 .37968 .54561 .38335 Metetra
.709 .218 .073 r
.54561 .38335 .55238 .37968 .56551 .3925 .55877 .39536 Metetra
.749 .262 .081 r
.55877 .39536 .56551 .3925 .57888 .40821 .57217 .41001 Metetra
.768 .278 .062 r
.57217 .41001 .57888 .40821 .59252 .42573 .58582 .42624 Metetra
.768 .265 .009 r
.58582 .42624 .59252 .42573 .60641 .44385 .59972 .44281 Metetra
.737 .212 0 r
.59972 .44281 .60641 .44385 .62054 .46115 .61382 .45834 Metetra
.635 .081 0 r
.61382 .45834 .62054 .46115 .63483 .47617 .62808 .47138 Metetra
0 .199 .634 r
.62808 .47138 .63483 .47617 .64921 .48744 .64242 .4805 Metetra
.194 .555 .933 r
.64242 .4805 .64921 .48744 .66359 .49363 .65674 .48445 Metetra
.579 .7 .924 r
.65674 .48445 .66359 .49363 .67784 .49368 .67093 .48227 Metetra
.736 .715 .832 r
.67093 .48227 .67784 .49368 .69186 .48697 .68489 .47348 Metetra
.8 .705 .761 r
.68489 .47348 .69186 .48697 .70556 .4735 .69854 .45822 Metetra
.829 .695 .716 r
.69854 .45822 .70556 .4735 .71889 .45397 .71184 .43736 Metetra
.842 .688 .691 r
.71184 .43736 .71889 .45397 .73188 .42993 .72483 .41265 Metetra
.844 .683 .682 r
.72483 .41265 .73188 .42993 .74462 .40386 .73764 .38675 Metetra
.801 .667 .716 r
.73764 .38675 .74462 .40386 .75734 .3792 .75083 .36802 Metetra
.652 .685 .869 r
.75083 .36802 .75734 .3792 .7713 .37188 .76503 .36343 Metetra
.654 .753 .922 r
.76503 .36343 .7713 .37188 .78552 .36732 .77931 .35882 Metetra
.654 .753 .922 r
.77931 .35882 .78552 .36732 .79981 .36272 .79365 .35419 Metetra
.654 .753 .922 r
.79365 .35419 .79981 .36272 .81418 .35811 .80807 .34953 Metetra
.654 .753 .922 r
.80807 .34953 .81418 .35811 .82861 .35347 .82255 .34485 Metetra
.654 .753 .922 r
.82255 .34485 .82861 .35347 .84312 .34881 .83711 .34015 Metetra
.654 .753 .922 r
.1922 .53896 .20024 .54589 .21184 .54214 .20383 .53518 Metetra
.654 .753 .922 r
.20383 .53518 .21184 .54214 .22349 .53838 .21551 .53138 Metetra
.654 .753 .922 r
.21551 .53138 .22349 .53838 .23519 .5346 .22725 .52757 Metetra
.654 .753 .922 r
.22725 .52757 .23519 .5346 .24695 .5308 .23904 .52374 Metetra
.654 .753 .922 r
.23904 .52374 .24695 .5308 .25876 .52698 .25088 .51989 Metetra
.654 .753 .922 r
.25088 .51989 .25876 .52698 .27062 .52315 .26277 .51603 Metetra
.63 .747 .931 r
.26277 .51603 .27062 .52315 .2819 .52813 .27467 .5128 Metetra
0 0 .568 r
.27467 .5128 .2819 .52813 .2925 .54464 .28528 .52842 Metetra
0 0 .572 r
.28528 .52842 .2925 .54464 .30331 .56085 .29604 .54467 Metetra
0 .112 .66 r
.29604 .54467 .30331 .56085 .31451 .57395 .30715 .55857 Metetra
.126 .298 .768 r
.30715 .55857 .31451 .57395 .32618 .58205 .31871 .56806 Metetra
.392 .487 .837 r
.31871 .56806 .32618 .58205 .33833 .58406 .33075 .5719 Metetra
.601 .627 .85 r
.33075 .5719 .33833 .58406 .35091 .57964 .34324 .56958 Metetra
.739 .717 .831 r
.34324 .56958 .35091 .57964 .36383 .56909 .35609 .56127 Metetra
.826 .774 .803 r
.35609 .56127 .36383 .56909 .377 .55319 .36921 .54763 Metetra
.882 .813 .777 r
.36921 .54763 .377 .55319 .39031 .53308 .38251 .52969 Metetra
.917 .845 .757 r
.38251 .52969 .39031 .53308 .40366 .51008 .39588 .50871 Metetra
.941 .874 .743 r
.39588 .50871 .40366 .51008 .41697 .48562 .40923 .48606 Metetra
.953 .904 .735 r
.40923 .48606 .41697 .48562 .43019 .46108 .42252 .46308 Metetra
.954 .936 .732 r
.42252 .46308 .43019 .46108 .44329 .43773 .4357 .44104 Metetra
.933 .969 .732 r
.4357 .44104 .44329 .43773 .45624 .41668 .44875 .42103 Metetra
.867 .989 .723 r
.44875 .42103 .45624 .41668 .46907 .39885 .46167 .40397 Metetra
.703 .952 .676 r
.46167 .40397 .46907 .39885 .4818 .38493 .4745 .39057 Metetra
.4745 .39057 .4818 .38493 .49447 .37542 .48727 .38133 Metetra
.013 0 0 r
.48727 .38133 .49447 .37542 .50713 .37058 .50002 .37649 Metetra
.321 0 0 r
.50002 .37649 .50713 .37058 .51983 .37045 .51281 .37611 Metetra
.51 .002 0 r
.51281 .37611 .51983 .37045 .53264 .37484 .5257 .38 Metetra
.621 .124 .049 r
.5257 .38 .53264 .37484 .54561 .38335 .53872 .38775 Metetra
.688 .197 .076 r
.53872 .38775 .54561 .38335 .55877 .39536 .55194 .39873 Metetra
.727 .236 .073 r
.55194 .39873 .55877 .39536 .57217 .41001 .56537 .41207 Metetra
.744 .245 .041 r
.56537 .41207 .57217 .41001 .58582 .42624 .57904 .42673 Metetra
.738 .221 0 r
.57904 .42673 .58582 .42624 .59972 .44281 .59293 .44147 Metetra
.688 .143 0 r
.59293 .44147 .59972 .44281 .61382 .45834 .60701 .45493 Metetra
.527 0 0 r
.60701 .45493 .61382 .45834 .62808 .47138 .62124 .46571 Metetra
0 .375 .803 r
.62124 .46571 .62808 .47138 .64242 .4805 .63553 .47246 Metetra
.389 .639 .955 r
.63553 .47246 .64242 .4805 .65674 .48445 .64979 .47402 Metetra
.65 .702 .884 r
.64979 .47402 .65674 .48445 .67093 .48227 .66391 .46955 Metetra
.756 .701 .8 r
.66391 .46955 .67093 .48227 .68489 .47348 .67782 .4587 Metetra
.804 .692 .742 r
.67782 .4587 .68489 .47348 .69854 .45822 .69142 .44179 Metetra
.827 .685 .705 r
.69142 .44179 .69854 .45822 .71184 .43736 .70471 .41985 Metetra
.838 .679 .686 r
.70471 .41985 .71184 .43736 .72483 .41265 .71774 .3948 Metetra
.837 .676 .683 r
.71774 .3948 .72483 .41265 .73764 .38675 .73063 .36949 Metetra
.712 .625 .759 r
.73063 .36949 .73764 .38675 .75083 .36802 .74446 .35953 Metetra
.654 .753 .922 r
.74446 .35953 .75083 .36802 .76503 .36343 .75872 .3549 Metetra
.654 .753 .922 r
.75872 .3549 .76503 .36343 .77931 .35882 .77304 .35025 Metetra
.654 .753 .922 r
.77304 .35025 .77931 .35882 .79365 .35419 .78743 .34557 Metetra
.654 .753 .922 r
.78743 .34557 .79365 .35419 .80807 .34953 .8019 .34087 Metetra
.654 .753 .922 r
.8019 .34087 .80807 .34953 .82255 .34485 .81644 .33615 Metetra
.654 .753 .922 r
.81644 .33615 .82255 .34485 .83711 .34015 .83105 .3314 Metetra
.654 .753 .922 r
.1841 .53197 .1922 .53896 .20383 .53518 .19576 .52816 Metetra
.654 .753 .922 r
.19576 .52816 .20383 .53518 .21551 .53138 .20747 .52433 Metetra
.654 .753 .922 r
.20747 .52433 .21551 .53138 .22725 .52757 .21924 .52049 Metetra
.654 .753 .922 r
.21924 .52049 .22725 .52757 .23904 .52374 .23106 .51663 Metetra
.654 .753 .922 r
.23106 .51663 .23904 .52374 .25088 .51989 .24293 .51275 Metetra
.654 .753 .922 r
.24293 .51275 .25088 .51989 .26277 .51603 .25486 .50885 Metetra
.654 .753 .922 r
.25486 .50885 .26277 .51603 .27467 .5128 .26684 .50493 Metetra
0 .293 .773 r
.26684 .50493 .27467 .5128 .28528 .52842 .27806 .51203 Metetra
0 .007 .583 r
.27806 .51203 .28528 .52842 .29604 .54467 .28879 .52795 Metetra
0 .095 .647 r
.28879 .52795 .29604 .54467 .30715 .55857 .29982 .54236 Metetra
.08 .255 .743 r
.29982 .54236 .30715 .55857 .31871 .56806 .31127 .55303 Metetra
.328 .432 .816 r
.31127 .55303 .31871 .56806 .33075 .5719 .3232 .55857 Metetra
.539 .579 .843 r
.3232 .55857 .33075 .5719 .34324 .56958 .33557 .55833 Metetra
.69 .682 .837 r
.33557 .55833 .34324 .56958 .35609 .56127 .34833 .55232 Metetra
.79 .751 .817 r
.34833 .55232 .35609 .56127 .36921 .54763 .3614 .54106 Metetra
.856 .8 .795 r
.3614 .54106 .36921 .54763 .38251 .52969 .37466 .52548 Metetra
.9 .84 .777 r
.37466 .52548 .38251 .52969 .39588 .50871 .38802 .50674 Metetra
.929 .875 .763 r
.38802 .50674 .39588 .50871 .40923 .48606 .40141 .48614 Metetra
.944 .911 .755 r
.40141 .48614 .40923 .48606 .42252 .46308 .41474 .46497 Metetra
.944 .947 .749 r
.41474 .46497 .42252 .46308 .4357 .44104 .42799 .44445 Metetra
.917 .979 .742 r
.42799 .44445 .4357 .44104 .44875 .42103 .44112 .42568 Metetra
.833 .988 .718 r
.44112 .42568 .44875 .42103 .46167 .40397 .45414 .40955 Metetra
.639 .922 .643 r
.45414 .40955 .46167 .40397 .4745 .39057 .46707 .39679 Metetra
.46707 .39679 .4745 .39057 .48727 .38133 .47994 .38786 Metetra
.049 0 0 r
.47994 .38786 .48727 .38133 .50002 .37649 .49279 .38304 Metetra
.32 0 0 r
.49279 .38304 .50002 .37649 .51281 .37611 .50567 .38237 Metetra
.491 0 0 r
.50567 .38237 .51281 .37611 .5257 .38 .51863 .38566 Metetra
.597 .1 .044 r
.51863 .38566 .5257 .38 .53872 .38775 .53173 .39249 Metetra
.661 .166 .061 r
.53173 .39249 .53872 .38775 .55194 .39873 .54499 .40225 Metetra
.699 .198 .048 r
.54499 .40225 .55194 .39873 .56537 .41207 .55846 .41407 Metetra
.712 .198 0 r
.55846 .41407 .56537 .41207 .57904 .42673 .57215 .42691 Metetra
.694 .155 0 r
.57215 .42691 .57904 .42673 .59293 .44147 .58604 .43957 Metetra
.607 .039 0 r
.58604 .43957 .59293 .44147 .60701 .45493 .60011 .45073 Metetra
0 .212 .621 r
.60011 .45073 .60701 .45493 .62124 .46571 .6143 .45905 Metetra
.145 .536 .922 r
.6143 .45905 .62124 .46571 .63553 .47246 .62854 .46328 Metetra
.528 .679 .934 r
.62854 .46328 .63553 .47246 .64979 .47402 .64274 .46236 Metetra
.697 .697 .847 r
.64274 .46236 .64979 .47402 .66391 .46955 .65681 .4556 Metetra
.77 .69 .775 r
.65681 .4556 .66391 .46955 .67782 .4587 .67066 .4428 Metetra
.807 .682 .727 r
.67066 .4428 .67782 .4587 .69142 .44179 .68424 .42443 Metetra
.825 .676 .698 r
.68424 .42443 .69142 .44179 .70471 .41985 .69753 .4017 Metetra
.833 .673 .684 r
.69753 .4017 .70471 .41985 .71774 .3948 .7106 .37668 Metetra
.81 .664 .701 r
.7106 .37668 .71774 .3948 .73063 .36949 .72381 .35562 Metetra
.644 .636 .827 r
.72381 .35562 .73063 .36949 .74446 .35953 .73804 .35097 Metetra
.654 .753 .922 r
.73804 .35097 .74446 .35953 .75872 .3549 .75234 .34629 Metetra
.654 .753 .922 r
.75234 .34629 .75872 .3549 .77304 .35025 .76671 .3416 Metetra
.654 .753 .922 r
.76671 .3416 .77304 .35025 .78743 .34557 .78116 .33688 Metetra
.654 .753 .922 r
.78116 .33688 .78743 .34557 .8019 .34087 .79568 .33213 Metetra
.654 .753 .922 r
.79568 .33213 .8019 .34087 .81644 .33615 .81027 .32736 Metetra
.654 .753 .922 r
.81027 .32736 .81644 .33615 .83105 .3314 .82493 .32257 Metetra
.654 .753 .922 r
.17593 .52492 .1841 .53197 .19576 .52816 .18762 .52108 Metetra
.654 .753 .922 r
.18762 .52108 .19576 .52816 .20747 .52433 .19936 .51722 Metetra
.654 .753 .922 r
.19936 .51722 .20747 .52433 .21924 .52049 .21116 .51334 Metetra
.654 .753 .922 r
.21116 .51334 .21924 .52049 .23106 .51663 .22301 .50945 Metetra
.654 .753 .922 r
.22301 .50945 .23106 .51663 .24293 .51275 .23491 .50554 Metetra
.654 .753 .922 r
.23491 .50554 .24293 .51275 .25486 .50885 .24687 .50161 Metetra
.654 .753 .922 r
.24687 .50161 .25486 .50885 .26684 .50493 .25889 .49766 Metetra
.57 .727 .948 r
.25889 .49766 .26684 .50493 .27806 .51203 .2708 .49576 Metetra
0 .032 .602 r
.2708 .49576 .27806 .51203 .28879 .52795 .28153 .51097 Metetra
0 .087 .64 r
.28153 .51097 .28879 .52795 .29982 .54236 .2925 .52555 Metetra
.041 .22 .722 r
.2925 .52555 .29982 .54236 .31127 .55303 .30386 .53714 Metetra
.268 .383 .795 r
.30386 .53714 .31127 .55303 .3232 .55857 .31566 .5442 Metetra
.475 .53 .833 r
.31566 .5442 .3232 .55857 .33557 .55833 .32792 .54594 Metetra
.635 .641 .839 r
.32792 .54594 .33557 .55833 .34833 .55232 .34058 .54221 Metetra
.747 .722 .829 r
.34058 .54221 .34833 .55232 .3614 .54106 .35356 .5334 Metetra
.824 .781 .813 r
.35356 .5334 .3614 .54106 .37466 .52548 .36677 .5203 Metetra
.876 .83 .798 r
.36677 .5203 .37466 .52548 .38802 .50674 .38011 .50396 Metetra
.911 .873 .787 r
.38011 .50396 .38802 .50674 .40141 .48614 .3935 .48559 Metetra
.931 .914 .779 r
.3935 .48559 .40141 .48614 .41474 .46497 .40686 .46642 Metetra
.932 .955 .773 r
.40686 .46642 .41474 .46497 .42799 .44445 .42017 .44762 Metetra
.899 .987 .761 r
.42017 .44762 .42799 .44445 .44112 .42568 .43337 .43025 Metetra
.802 .986 .725 r
.43337 .43025 .44112 .42568 .45414 .40955 .44648 .4152 Metetra
.593 .902 .631 r
.44648 .4152 .45414 .40955 .46707 .39679 .45951 .40316 Metetra
.45951 .40316 .46707 .39679 .47994 .38786 .47247 .3946 Metetra
.058 0 0 r
.47247 .3946 .47994 .38786 .49279 .38304 .48542 .3898 Metetra
.304 0 0 r
.48542 .3898 .49279 .38304 .50567 .38237 .4984 .3888 Metetra
.464 0 0 r
.4984 .3888 .50567 .38237 .51863 .38566 .51144 .3914 Metetra
.565 .062 .018 r
.51144 .3914 .51863 .38566 .53173 .39249 .52461 .3972 Metetra
.628 .121 .027 r
.52461 .3972 .53173 .39249 .54499 .40225 .53794 .40557 Metetra
.661 .145 0 r
.53794 .40557 .54499 .40225 .55846 .41407 .55145 .41568 Metetra
.666 .13 0 r
.55145 .41568 .55846 .41407 .57215 .42691 .56515 .4265 Metetra
.622 .058 0 r
.56515 .4265 .57215 .42691 .58604 .43957 .57905 .43688 Metetra
.468 0 0 r
.57905 .43688 .58604 .43957 .60011 .45073 .5931 .44557 Metetra
0 .415 .817 r
.5931 .44557 .60011 .45073 .6143 .45905 .60726 .4513 Metetra
.369 .64 .96 r
.60726 .4513 .6143 .45905 .62854 .46328 .62146 .45293 Metetra
.619 .693 .897 r
.62146 .45293 .62854 .46328 .64274 .46236 .63561 .44952 Metetra
.728 .691 .814 r
.63561 .44952 .64274 .46236 .65681 .4556 .64963 .44054 Metetra
.78 .682 .755 r
.64963 .44054 .65681 .4556 .67066 .4428 .66344 .42595 Metetra
.808 .675 .716 r
.66344 .42595 .67066 .4428 .68424 .42443 .677 .40637 Metetra
.823 .671 .693 r
.677 .40637 .68424 .42443 .69753 .4017 .69031 .38317 Metetra
.829 .669 .685 r
.69031 .38317 .69753 .4017 .7106 .37668 .70345 .35856 Metetra
.726 .626 .746 r
.70345 .35856 .7106 .37668 .72381 .35562 .71727 .34701 Metetra
.654 .753 .922 r
.71727 .34701 .72381 .35562 .73804 .35097 .73155 .34232 Metetra
.654 .753 .922 r
.73155 .34232 .73804 .35097 .75234 .34629 .7459 .3376 Metetra
.654 .753 .922 r
.7459 .3376 .75234 .34629 .76671 .3416 .76033 .33286 Metetra
.654 .753 .922 r
.76033 .33286 .76671 .3416 .78116 .33688 .77482 .3281 Metetra
.654 .753 .922 r
.77482 .3281 .78116 .33688 .79568 .33213 .78939 .32331 Metetra
.654 .753 .922 r
.78939 .32331 .79568 .33213 .81027 .32736 .80404 .3185 Metetra
.654 .753 .922 r
.80404 .3185 .81027 .32736 .82493 .32257 .81876 .31366 Metetra
.654 .753 .922 r
.16769 .51782 .17593 .52492 .18762 .52108 .17941 .51394 Metetra
.654 .753 .922 r
.17941 .51394 .18762 .52108 .19936 .51722 .19119 .51005 Metetra
.654 .753 .922 r
.19119 .51005 .19936 .51722 .21116 .51334 .20301 .50614 Metetra
.654 .753 .922 r
.20301 .50614 .21116 .51334 .22301 .50945 .21489 .50221 Metetra
.654 .753 .922 r
.21489 .50221 .22301 .50945 .23491 .50554 .22683 .49827 Metetra
.654 .753 .922 r
.22683 .49827 .23491 .50554 .24687 .50161 .23882 .4943 Metetra
.654 .753 .922 r
.23882 .4943 .24687 .50161 .25889 .49766 .25087 .49032 Metetra
.654 .753 .922 r
.25087 .49032 .25889 .49766 .2708 .49576 .26297 .48632 Metetra
0 .292 .787 r
.26297 .48632 .2708 .49576 .28153 .51097 .27425 .49398 Metetra
0 .089 .642 r
.27425 .49398 .28153 .51097 .2925 .52555 .28518 .50838 Metetra
.011 .194 .706 r
.28518 .50838 .2925 .52555 .30386 .53714 .29645 .5206 Metetra
.213 .339 .776 r
.29645 .5206 .30386 .53714 .31566 .5442 .30815 .52895 Metetra
.412 .481 .821 r
.30815 .52895 .31566 .5442 .32792 .54594 .32028 .53251 Metetra
.575 .598 .838 r
.32028 .53251 .32792 .54594 .34058 .54221 .33283 .53098 Metetra
.697 .688 .837 r
.33283 .53098 .34058 .54221 .35356 .5334 .34571 .52461 Metetra
.783 .757 .829 r
.34571 .52461 .35356 .5334 .36677 .5203 .35885 .51403 Metetra
.845 .814 .819 r
.35885 .51403 .36677 .5203 .38011 .50396 .37214 .50019 Metetra
.887 .864 .812 r
.37214 .50019 .38011 .50396 .3935 .48559 .38552 .48418 Metetra
.912 .913 .806 r
.38552 .48418 .3935 .48559 .40686 .46642 .3989 .46715 Metetra
.915 .958 .801 r
.3989 .46715 .40686 .46642 .42017 .44762 .41224 .45021 Metetra
.882 .992 .788 r
.41224 .45021 .42017 .44762 .43337 .43025 .42551 .43438 Metetra
.779 .988 .747 r
.42551 .43438 .43337 .43025 .44648 .4152 .4387 .42051 Metetra
.568 .897 .646 r
.4387 .42051 .44648 .4152 .45951 .40316 .45182 .40927 Metetra
.45182 .40927 .45951 .40316 .47247 .3946 .46488 .40113 Metetra
.043 0 0 r
.46488 .40113 .47247 .3946 .48542 .3898 .47793 .39636 Metetra
.272 0 0 r
.47793 .39636 .48542 .3898 .4984 .3888 .491 .39498 Metetra
.425 0 0 r
.491 .39498 .4984 .3888 .51144 .3914 .50413 .39682 Metetra
.522 .006 0 r
.50413 .39682 .51144 .3914 .52461 .3972 .51738 .40148 Metetra
.581 .057 0 r
.51738 .40148 .52461 .3972 .53794 .40557 .53076 .40833 Metetra
.608 .068 0 r
.53076 .40833 .53794 .40557 .55145 .41568 .54432 .41658 Metetra
.593 .028 0 r
.54432 .41658 .55145 .41568 .56515 .4265 .55805 .42524 Metetra
.501 0 0 r
.55805 .42524 .56515 .4265 .57905 .43688 .57195 .43321 Metetra
0 .327 .696 r
.57195 .43321 .57905 .43688 .5931 .44557 .586 .4393 Metetra
.198 .587 .943 r
.586 .4393 .5931 .44557 .60726 .4513 .60013 .44238 Metetra
.524 .687 .941 r
.60013 .44238 .60726 .4513 .62146 .45293 .61429 .44139 Metetra
.677 .694 .858 r
.61429 .44139 .62146 .45293 .63561 .44952 .62839 .43557 Metetra
.749 .684 .788 r
.62839 .43557 .63561 .44952 .64963 .44054 .64237 .42452 Metetra
.788 .675 .739 r
.64237 .42452 .64963 .44054 .66344 .42595 .65616 .40836 Metetra
.81 .669 .708 r
.65616 .40836 .66344 .42595 .677 .40637 .66972 .38786 Metetra
.821 .667 .691 r
.66972 .38786 .677 .40637 .69031 .38317 .68307 .36453 Metetra
.81 .661 .698 r
.68307 .36453 .69031 .38317 .70345 .35856 .69642 .34304 Metetra
.638 .611 .807 r
.69642 .34304 .70345 .35856 .71727 .34701 .71068 .33833 Metetra
.654 .753 .922 r
.71068 .33833 .71727 .34701 .73155 .34232 .72501 .33359 Metetra
.654 .753 .922 r
.72501 .33359 .73155 .34232 .7459 .3376 .73941 .32883 Metetra
.654 .753 .922 r
.73941 .32883 .7459 .3376 .76033 .33286 .75388 .32405 Metetra
.654 .753 .922 r
.75388 .32405 .76033 .33286 .77482 .3281 .76843 .31924 Metetra
.654 .753 .922 r
.76843 .31924 .77482 .3281 .78939 .32331 .78305 .31441 Metetra
.654 .753 .922 r
.78305 .31441 .78939 .32331 .80404 .3185 .79775 .30955 Metetra
.654 .753 .922 r
.79775 .30955 .80404 .3185 .81876 .31366 .81252 .30467 Metetra
.654 .753 .922 r
.15938 .51065 .16769 .51782 .17941 .51394 .17113 .50674 Metetra
.654 .753 .922 r
.17113 .50674 .17941 .51394 .19119 .51005 .18294 .50282 Metetra
.654 .753 .922 r
.18294 .50282 .19119 .51005 .20301 .50614 .1948 .49888 Metetra
.654 .753 .922 r
.1948 .49888 .20301 .50614 .21489 .50221 .20671 .49491 Metetra
.654 .753 .922 r
.20671 .49491 .21489 .50221 .22683 .49827 .21868 .49093 Metetra
.654 .753 .922 r
.21868 .49093 .22683 .49827 .23882 .4943 .2307 .48694 Metetra
.654 .753 .922 r
.2307 .48694 .23882 .4943 .25087 .49032 .24278 .48292 Metetra
.654 .753 .922 r
.24278 .48292 .25087 .49032 .26297 .48632 .25492 .47889 Metetra
.555 .721 .951 r
.25492 .47889 .26297 .48632 .27425 .49398 .26692 .47722 Metetra
0 .102 .652 r
.26692 .47722 .27425 .49398 .28518 .50838 .27785 .49109 Metetra
0 .179 .697 r
.27785 .49109 .28518 .50838 .29645 .5206 .28905 .50361 Metetra
.165 .302 .759 r
.28905 .50361 .29645 .5206 .30815 .52895 .30064 .51298 Metetra
.351 .435 .808 r
.30064 .51298 .30815 .52895 .32028 .53251 .31266 .51814 Metetra
.513 .553 .834 r
.31266 .51814 .32028 .53251 .33283 .53098 .32509 .51867 Metetra
.64 .648 .842 r
.32509 .51867 .33283 .53098 .34571 .52461 .33786 .51464 Metetra
.736 .725 .842 r
.33786 .51464 .34571 .52461 .35885 .51403 .35091 .50656 Metetra
.805 .79 .838 r
.35091 .50656 .35885 .51403 .37214 .50019 .36414 .49525 Metetra
.855 .848 .836 r
.36414 .49525 .37214 .50019 .38552 .48418 .37749 .48166 Metetra
.886 .903 .835 r
.37749 .48166 .38552 .48418 .3989 .46715 .39087 .46686 Metetra
.894 .954 .834 r
.39087 .46686 .3989 .46715 .41224 .45021 .40424 .45189 Metetra
.864 .993 .824 r
.40424 .45189 .41224 .45021 .42551 .43438 .41756 .43769 Metetra
.766 .992 .785 r
.41756 .43769 .42551 .43438 .4387 .42051 .43081 .42508 Metetra
.566 .909 .688 r
.43081 .42508 .4387 .42051 .45182 .40927 .44401 .4147 Metetra
.44401 .4147 .45182 .40927 .46488 .40113 .45717 .40702 Metetra
.001 0 0 r
.45717 .40702 .46488 .40113 .47793 .39636 .47031 .40227 Metetra
.219 0 0 r
.47031 .40227 .47793 .39636 .491 .39498 .48347 .4005 Metetra
.367 0 0 r
.48347 .4005 .491 .39498 .50413 .39682 .4967 .40152 Metetra
.461 0 0 r
.4967 .40152 .50413 .39682 .51738 .40148 .51002 .40495 Metetra
.513 0 0 r
.51002 .40495 .51738 .40148 .53076 .40833 .52348 .41019 Metetra
.523 0 0 r
.52348 .41019 .53076 .40833 .54432 .41658 .53708 .41648 Metetra
.469 0 0 r
.53708 .41648 .54432 .41658 .55805 .42524 .55085 .42287 Metetra
.291 0 0 r
.55085 .42287 .55805 .42524 .57195 .43321 .56476 .42835 Metetra
.066 .545 .895 r
.56476 .42835 .57195 .43321 .586 .4393 .5788 .43182 Metetra
.424 .681 .97 r
.5788 .43182 .586 .4393 .60013 .44238 .59291 .43224 Metetra
.62 .701 .903 r
.59291 .43224 .60013 .44238 .61429 .44139 .60704 .42871 Metetra
.715 .69 .825 r
.60704 .42871 .61429 .44139 .62839 .43557 .62111 .42061 Metetra
.764 .678 .767 r
.62111 .42061 .62839 .43557 .64237 .42452 .63506 .40769 Metetra
.793 .67 .728 r
.63506 .40769 .64237 .42452 .65616 .40836 .64883 .39023 Metetra
.81 .665 .703 r
.64883 .39023 .65616 .40836 .66972 .38786 .66241 .36913 Metetra
.819 .665 .691 r
.66241 .36913 .66972 .38786 .68307 .36453 .67581 .34605 Metetra
.726 .623 .744 r
.67581 .34605 .68307 .36453 .69642 .34304 .68971 .33433 Metetra
.654 .753 .922 r
.68971 .33433 .69642 .34304 .71068 .33833 .70402 .32957 Metetra
.654 .753 .922 r
.70402 .32957 .71068 .33833 .72501 .33359 .7184 .32479 Metetra
.654 .753 .922 r
.7184 .32479 .72501 .33359 .73941 .32883 .73285 .31998 Metetra
.654 .753 .922 r
.73285 .31998 .73941 .32883 .75388 .32405 .74738 .31515 Metetra
.654 .753 .922 r
.74738 .31515 .75388 .32405 .76843 .31924 .76198 .3103 Metetra
.654 .753 .922 r
.76198 .3103 .76843 .31924 .78305 .31441 .77665 .30542 Metetra
.654 .753 .922 r
.77665 .30542 .78305 .31441 .79775 .30955 .7914 .30052 Metetra
.654 .753 .922 r
.7914 .30052 .79775 .30955 .81252 .30467 .80623 .29559 Metetra
.654 .753 .922 r
.151 .50342 .15938 .51065 .17113 .50674 .16279 .49948 Metetra
.654 .753 .922 r
.16279 .49948 .17113 .50674 .18294 .50282 .17462 .49552 Metetra
.654 .753 .922 r
.17462 .49552 .18294 .50282 .1948 .49888 .18651 .49155 Metetra
.654 .753 .922 r
.18651 .49155 .1948 .49888 .20671 .49491 .19846 .48755 Metetra
.654 .753 .922 r
.19846 .48755 .20671 .49491 .21868 .49093 .21046 .48354 Metetra
.654 .753 .922 r
.21046 .48354 .21868 .49093 .2307 .48694 .22251 .47951 Metetra
.654 .753 .922 r
.22251 .47951 .2307 .48694 .24278 .48292 .23463 .47546 Metetra
.654 .753 .922 r
.23463 .47546 .24278 .48292 .25492 .47889 .2468 .47139 Metetra
.654 .753 .922 r
.2468 .47139 .25492 .47889 .26692 .47722 .25902 .4673 Metetra
.03 .365 .836 r
.25902 .4673 .26692 .47722 .27785 .49109 .27048 .47392 Metetra
0 .173 .695 r
.27048 .47392 .27785 .49109 .28905 .50361 .28164 .48639 Metetra
.127 .274 .746 r
.28164 .48639 .28905 .50361 .30064 .51298 .29315 .49647 Metetra
.295 .394 .794 r
.29315 .49647 .30064 .51298 .31266 .51814 .30505 .50297 Metetra
.451 .508 .826 r
.30505 .50297 .31266 .51814 .32509 .51867 .31736 .50534 Metetra
.581 .606 .842 r
.31736 .50534 .32509 .51867 .33786 .51464 .33002 .50351 Metetra
.681 .688 .85 r
.33002 .50351 .33786 .51464 .35091 .50656 .34296 .49785 Metetra
.758 .759 .853 r
.34296 .49785 .35091 .50656 .36414 .49525 .35612 .48901 Metetra
.814 .823 .857 r
.35612 .48901 .36414 .49525 .37749 .48166 .36942 .47785 Metetra
.851 .883 .862 r
.36942 .47785 .37749 .48166 .39087 .46686 .38278 .46531 Metetra
.865 .94 .867 r
.38278 .46531 .39087 .46686 .40424 .45189 .39616 .45235 Metetra
.843 .985 .864 r
.39616 .45235 .40424 .45189 .41756 .43769 .40951 .43984 Metetra
.759 .996 .835 r
.40951 .43984 .41756 .43769 .43081 .42508 .42283 .42854 Metetra
.585 .933 .754 r
.42283 .42854 .43081 .42508 .44401 .4147 .4361 .41908 Metetra
.4361 .41908 .44401 .4147 .45717 .40702 .44934 .41187 Metetra
.44934 .41187 .45717 .40702 .47031 .40227 .46258 .40715 Metetra
.137 0 0 r
.46258 .40715 .47031 .40227 .48347 .4005 .47584 .40496 Metetra
.281 0 0 r
.47584 .40496 .48347 .4005 .4967 .40152 .48915 .40512 Metetra
.368 0 0 r
.48915 .40512 .4967 .40152 .51002 .40495 .50256 .40727 Metetra
.405 0 0 r
.50256 .40727 .51002 .40495 .52348 .41019 .51608 .41084 Metetra
.38 0 0 r
.51608 .41084 .52348 .41019 .53708 .41648 .52974 .4151 Metetra
.256 0 0 r
.52974 .4151 .53708 .41648 .55085 .42287 .54354 .4192 Metetra
.016 .541 .856 r
.54354 .4192 .55085 .42287 .56476 .42835 .55748 .42217 Metetra
.346 .683 .979 r
.55748 .42217 .56476 .42835 .5788 .43182 .57151 .42303 Metetra
.566 .713 .941 r
.57151 .42303 .5788 .43182 .59291 .43224 .58561 .42088 Metetra
.679 .7 .863 r
.58561 .42088 .59291 .43224 .60704 .42871 .59972 .41495 Metetra
.739 .684 .798 r
.59972 .41495 .60704 .42871 .62111 .42061 .61376 .40476 Metetra
.774 .672 .751 r
.61376 .40476 .62111 .42061 .63506 .40769 .6277 .39022 Metetra
.796 .666 .72 r
.6277 .39022 .63506 .40769 .64883 .39023 .64147 .37176 Metetra
.81 .663 .701 r
.64147 .37176 .64883 .39023 .66241 .36913 .65508 .35042 Metetra
.8 .657 .705 r
.65508 .35042 .66241 .36913 .67581 .34605 .66866 .3303 Metetra
.637 .61 .806 r
.66866 .3303 .67581 .34605 .68971 .33433 .68294 .32552 Metetra
.654 .753 .922 r
.68294 .32552 .68971 .33433 .70402 .32957 .6973 .32072 Metetra
.654 .753 .922 r
.6973 .32072 .70402 .32957 .7184 .32479 .71173 .3159 Metetra
.654 .753 .922 r
.71173 .3159 .7184 .32479 .73285 .31998 .72623 .31105 Metetra
.654 .753 .922 r
.72623 .31105 .73285 .31998 .74738 .31515 .74081 .30617 Metetra
.654 .753 .922 r
.74081 .30617 .74738 .31515 .76198 .3103 .75546 .30127 Metetra
.654 .753 .922 r
.75546 .30127 .76198 .3103 .77665 .30542 .77019 .29635 Metetra
.654 .753 .922 r
.77019 .29635 .77665 .30542 .7914 .30052 .78499 .2914 Metetra
.654 .753 .922 r
.78499 .2914 .7914 .30052 .80623 .29559 .79987 .28642 Metetra
.654 .753 .922 r
.14255 .49614 .151 .50342 .16279 .49948 .15437 .49216 Metetra
.654 .753 .922 r
.15437 .49216 .16279 .49948 .17462 .49552 .16623 .48817 Metetra
.654 .753 .922 r
.16623 .48817 .17462 .49552 .18651 .49155 .17815 .48416 Metetra
.654 .753 .922 r
.17815 .48416 .18651 .49155 .19846 .48755 .19013 .48013 Metetra
.654 .753 .922 r
.19013 .48013 .19846 .48755 .21046 .48354 .20216 .47608 Metetra
.654 .753 .922 r
.20216 .47608 .21046 .48354 .22251 .47951 .21425 .47201 Metetra
.654 .753 .922 r
.21425 .47201 .22251 .47951 .23463 .47546 .2264 .46793 Metetra
.654 .753 .922 r
.2264 .46793 .23463 .47546 .2468 .47139 .2386 .46382 Metetra
.654 .753 .922 r
.2386 .46382 .2468 .47139 .25902 .4673 .25086 .4597 Metetra
.597 .736 .941 r
.25086 .4597 .25902 .4673 .27048 .47392 .26306 .45706 Metetra
0 .18 .701 r
.26306 .45706 .27048 .47392 .28164 .48639 .2742 .46915 Metetra
.098 .256 .738 r
.2742 .46915 .28164 .48639 .29315 .49647 .28564 .4796 Metetra
.247 .36 .782 r
.28564 .4796 .29315 .49647 .30505 .50297 .29745 .48715 Metetra
.393 .465 .816 r
.29745 .48715 .30505 .50297 .31736 .50534 .30964 .4911 Metetra
.52 .562 .838 r
.30964 .4911 .31736 .50534 .33002 .50351 .32218 .49126 Metetra
.623 .646 .852 r
.32218 .49126 .33002 .50351 .34296 .49785 .33502 .48785 Metetra
.703 .72 .862 r
.33502 .48785 .34296 .49785 .35612 .48901 .34809 .48139 Metetra
.765 .788 .872 r
.34809 .48139 .35612 .48901 .36942 .47785 .36133 .47259 Metetra
.807 .852 .883 r
.36133 .47259 .36942 .47785 .38278 .46531 .37466 .46229 Metetra
.829 .913 .895 r
.37466 .46229 .38278 .46531 .39616 .45235 .38803 .45134 Metetra
.818 .965 .901 r
.38803 .45134 .39616 .45235 .40951 .43984 .40141 .44053 Metetra
.755 .99 .889 r
.40141 .44053 .40951 .43984 .42283 .42854 .41477 .43057 Metetra
.618 .957 .836 r
.41477 .43057 .42283 .42854 .4361 .41908 .4281 .42202 Metetra
.41 .848 .731 r
.4281 .42202 .4361 .41908 .44934 .41187 .44142 .4153 Metetra
.44142 .4153 .44934 .41187 .46258 .40715 .45475 .41061 Metetra
.012 0 0 r
.45475 .41061 .46258 .40715 .47584 .40496 .4681 .40799 Metetra
.146 0 0 r
.4681 .40799 .47584 .40496 .48915 .40512 .4815 .40727 Metetra
.218 0 0 r
.4815 .40727 .48915 .40512 .50256 .40727 .49499 .40811 Metetra
.224 0 0 r
.49499 .40811 .50256 .40727 .51608 .41084 .50858 .40999 Metetra
.141 0 0 r
.50858 .40999 .51608 .41084 .52974 .4151 .5223 .41223 Metetra
.056 .591 .858 r
.5223 .41223 .52974 .4151 .54354 .4192 .53614 .41404 Metetra
.32 .703 .98 r
.53614 .41404 .54354 .4192 .55748 .42217 .5501 .41455 Metetra
.529 .732 .967 r
.5501 .41455 .55748 .42217 .57151 .42303 .56415 .41291 Metetra
.649 .716 .897 r
.56415 .41291 .57151 .42303 .58561 .42088 .57824 .40832 Metetra
.716 .694 .828 r
.57824 .40832 .58561 .42088 .59972 .41495 .59233 .40018 Metetra
.755 .678 .776 r
.59233 .40018 .59972 .41495 .61376 .40476 .60637 .38816 Metetra
.781 .668 .739 r
.60637 .38816 .61376 .40476 .6277 .39022 .6203 .37231 Metetra
.798 .663 .714 r
.6203 .37231 .6277 .39022 .64147 .37176 .63409 .35319 Metetra
.809 .662 .701 r
.63409 .35319 .64147 .37176 .65508 .35042 .64773 .33196 Metetra
.711 .618 .751 r
.64773 .33196 .65508 .35042 .66866 .3303 .66177 .32146 Metetra
.654 .753 .922 r
.66177 .32146 .66866 .3303 .68294 .32552 .67611 .31664 Metetra
.654 .753 .922 r
.67611 .31664 .68294 .32552 .6973 .32072 .69051 .31179 Metetra
.654 .753 .922 r
.69051 .31179 .6973 .32072 .71173 .3159 .705 .30692 Metetra
.654 .753 .922 r
.705 .30692 .71173 .3159 .72623 .31105 .71955 .30203 Metetra
.654 .753 .922 r
.71955 .30203 .72623 .31105 .74081 .30617 .73418 .29711 Metetra
.654 .753 .922 r
.73418 .29711 .74081 .30617 .75546 .30127 .74888 .29216 Metetra
.654 .753 .922 r
.74888 .29216 .75546 .30127 .77019 .29635 .76367 .28719 Metetra
.654 .753 .922 r
.76367 .28719 .77019 .29635 .78499 .2914 .77852 .28219 Metetra
.654 .753 .922 r
.77852 .28219 .78499 .2914 .79987 .28642 .79346 .27716 Metetra
.654 .753 .922 r
.13403 .48878 .14255 .49614 .15437 .49216 .14588 .48478 Metetra
.654 .753 .922 r
.14588 .48478 .15437 .49216 .16623 .48817 .15777 .48075 Metetra
.654 .753 .922 r
.15777 .48075 .16623 .48817 .17815 .48416 .16973 .47671 Metetra
.654 .753 .922 r
.16973 .47671 .17815 .48416 .19013 .48013 .18174 .47264 Metetra
.654 .753 .922 r
.18174 .47264 .19013 .48013 .20216 .47608 .1938 .46856 Metetra
.654 .753 .922 r
.1938 .46856 .20216 .47608 .21425 .47201 .20592 .46446 Metetra
.654 .753 .922 r
.20592 .46446 .21425 .47201 .2264 .46793 .2181 .46033 Metetra
.654 .753 .922 r
.2181 .46033 .2264 .46793 .2386 .46382 .23034 .45619 Metetra
.654 .753 .922 r
.23034 .45619 .2386 .46382 .25086 .4597 .24263 .45203 Metetra
.654 .753 .922 r
.24263 .45203 .25086 .4597 .26306 .45706 .25498 .44785 Metetra
.191 .493 .903 r
.25498 .44785 .26306 .45706 .2742 .46915 .26673 .45209 Metetra
.082 .249 .737 r
.26673 .45209 .2742 .46915 .28564 .4796 .27813 .46258 Metetra
.209 .334 .772 r
.27813 .46258 .28564 .4796 .29745 .48715 .28985 .47084 Metetra
.342 .428 .806 r
.28985 .47084 .29745 .48715 .30964 .4911 .30193 .47608 Metetra
.462 .519 .831 r
.30193 .47608 .30964 .4911 .32218 .49126 .31436 .47797 Metetra
.564 .602 .849 r
.31436 .47797 .32218 .49126 .33502 .48785 .32709 .4766 Metetra
.646 .676 .865 r
.32709 .4766 .33502 .48785 .34809 .48139 .34007 .47234 Metetra
.71 .745 .879 r
.34007 .47234 .34809 .48139 .36133 .47259 .35323 .46579 Metetra
.756 .811 .896 r
.35323 .46579 .36133 .47259 .37466 .46229 .36651 .45764 Metetra
.784 .873 .913 r
.36651 .45764 .37466 .46229 .38803 .45134 .37986 .44864 Metetra
.785 .929 .929 r
.37986 .44864 .38803 .45134 .40141 .44053 .39325 .4395 Metetra
.746 .966 .934 r
.39325 .4395 .40141 .44053 .41477 .43057 .40664 .43086 Metetra
.652 .965 .912 r
.40664 .43086 .41477 .43057 .4281 .42202 .42003 .42324 Metetra
.501 .908 .853 r
.42003 .42324 .4281 .42202 .44142 .4153 .43342 .41699 Metetra
.323 .806 .77 r
.43342 .41699 .44142 .4153 .45475 .41061 .44683 .41233 Metetra
.163 .696 .697 r
.44683 .41233 .45475 .41061 .4681 .40799 .46026 .40928 Metetra
.46026 .40928 .4681 .40799 .4815 .40727 .47376 .40769 Metetra
.47376 .40769 .4815 .40727 .49499 .40811 .48733 .40723 Metetra
.05 .614 .78 r
.48733 .40723 .49499 .40811 .50858 .40999 .50099 .40743 Metetra
.175 .683 .903 r
.50099 .40743 .50858 .40999 .5223 .41223 .51477 .40769 Metetra
.357 .744 .987 r
.51477 .40769 .5223 .41223 .53614 .41404 .52866 .40728 Metetra
.522 .756 .982 r
.52866 .40728 .53614 .41404 .5501 .41455 .54264 .40544 Metetra
.631 .734 .922 r
.54264 .40544 .5501 .41455 .56415 .41291 .5567 .40145 Metetra
.697 .707 .856 r
.5567 .40145 .56415 .41291 .57824 .40832 .5708 .39464 Metetra
.738 .686 .801 r
.5708 .39464 .57824 .40832 .59233 .40018 .58489 .38454 Metetra
.766 .673 .76 r
.58489 .38454 .59233 .40018 .60637 .38816 .59893 .37098 Metetra
.786 .665 .73 r
.59893 .37098 .60637 .38816 .6203 .37231 .61286 .35414 Metetra
.799 .662 .712 r
.61286 .35414 .6203 .37231 .63409 .35319 .62668 .33471 Metetra
.781 .652 .72 r
.62668 .33471 .63409 .35319 .64773 .33196 .64052 .31738 Metetra
.641 .631 .825 r
.64052 .31738 .64773 .33196 .66177 .32146 .65483 .31254 Metetra
.654 .753 .922 r
.65483 .31254 .66177 .32146 .67611 .31664 .66921 .30767 Metetra
.654 .753 .922 r
.66921 .30767 .67611 .31664 .69051 .31179 .68367 .30278 Metetra
.654 .753 .922 r
.68367 .30278 .69051 .31179 .705 .30692 .6982 .29786 Metetra
.654 .753 .922 r
.6982 .29786 .705 .30692 .71955 .30203 .71281 .29292 Metetra
.654 .753 .922 r
.71281 .29292 .71955 .30203 .73418 .29711 .72749 .28795 Metetra
.654 .753 .922 r
.72749 .28795 .73418 .29711 .74888 .29216 .74224 .28296 Metetra
.654 .753 .922 r
.74224 .28296 .74888 .29216 .76367 .28719 .75708 .27794 Metetra
.654 .753 .922 r
.75708 .27794 .76367 .28719 .77852 .28219 .77199 .27289 Metetra
.654 .753 .922 r
.77199 .27289 .77852 .28219 .79346 .27716 .78698 .26782 Metetra
.654 .753 .922 r
.12544 .48137 .13403 .48878 .14588 .48478 .13731 .47733 Metetra
.654 .753 .922 r
.13731 .47733 .14588 .48478 .15777 .48075 .14924 .47327 Metetra
.654 .753 .922 r
.14924 .47327 .15777 .48075 .16973 .47671 .16122 .46919 Metetra
.654 .753 .922 r
.16122 .46919 .16973 .47671 .18174 .47264 .17327 .46509 Metetra
.654 .753 .922 r
.17327 .46509 .18174 .47264 .1938 .46856 .18536 .46097 Metetra
.654 .753 .922 r
.18536 .46097 .1938 .46856 .20592 .46446 .19752 .45683 Metetra
.654 .753 .922 r
.19752 .45683 .20592 .46446 .2181 .46033 .20973 .45267 Metetra
.654 .753 .922 r
.20973 .45267 .2181 .46033 .23034 .45619 .222 .4485 Metetra
.654 .753 .922 r
.222 .4485 .23034 .45619 .24263 .45203 .23433 .4443 Metetra
.654 .753 .922 r
.23433 .4443 .24263 .45203 .25498 .44785 .24672 .44008 Metetra
.654 .753 .922 r
.24672 .44008 .25498 .44785 .26673 .45209 .25916 .43585 Metetra
.089 .268 .752 r
.25916 .43585 .26673 .45209 .27813 .46258 .27058 .44558 Metetra
.182 .318 .767 r
.27058 .44558 .27813 .46258 .28985 .47084 .28224 .45422 Metetra
.299 .398 .797 r
.28224 .45422 .28985 .47084 .30193 .47608 .29423 .46042 Metetra
.41 .481 .822 r
.29423 .46042 .30193 .47608 .31436 .47797 .30655 .46374 Metetra
.507 .558 .843 r
.30655 .46374 .31436 .47797 .32709 .4766 .31917 .46415 Metetra
.588 .63 .861 r
.31917 .46415 .32709 .4766 .34007 .47234 .33205 .46188 Metetra
.652 .697 .879 r
.33205 .46188 .34007 .47234 .35323 .46579 .34513 .45739 Metetra
.701 .761 .898 r
.34513 .45739 .35323 .46579 .36651 .45764 .35836 .45126 Metetra
.733 .822 .92 r
.35836 .45126 .36651 .45764 .37986 .44864 .37168 .44411 Metetra
.744 .878 .941 r
.37168 .44411 .37986 .44864 .39325 .4395 .38506 .43658 Metetra
.727 .922 .958 r
.38506 .43658 .39325 .4395 .40664 .43086 .39848 .42921 Metetra
.673 .943 .962 r
.39848 .42921 .40664 .43086 .42003 .42324 .41191 .42248 Metetra
.581 .931 .946 r
.41191 .42248 .42003 .42324 .43342 .41699 .42537 .4167 Metetra
.467 .887 .914 r
.42537 .4167 .43342 .41699 .44683 .41233 .43884 .41206 Metetra
.361 .831 .885 r
.43884 .41206 .44683 .41233 .46026 .40928 .45236 .40858 Metetra
.295 .787 .881 r
.45236 .40858 .46026 .40928 .47376 .40769 .46593 .40613 Metetra
.287 .773 .912 r
.46593 .40613 .47376 .40769 .48733 .40723 .47958 .40441 Metetra
.341 .782 .963 r
.47958 .40441 .48733 .40723 .50099 .40743 .49332 .403 Metetra
.441 .792 .997 r
.49332 .403 .50099 .40743 .51477 .40769 .50716 .40136 Metetra
.546 .781 .985 r
.50716 .40136 .51477 .40769 .52866 .40728 .5211 .39886 Metetra
.629 .753 .936 r
.5211 .39886 .52866 .40728 .54264 .40544 .53512 .39484 Metetra
.686 .722 .877 r
.53512 .39484 .54264 .40544 .5567 .40145 .5492 .3887 Metetra
.725 .696 .823 r
.5492 .3887 .5567 .40145 .5708 .39464 .56331 .37992 Metetra
.753 .679 .78 r
.56331 .37992 .5708 .39464 .58489 .38454 .5774 .36816 Metetra
.773 .668 .748 r
.5774 .36816 .58489 .38454 .59893 .37098 .59145 .35338 Metetra
.788 .663 .725 r
.59145 .35338 .59893 .37098 .61286 .35414 .6054 .33591 Metetra
.799 .662 .712 r
.6054 .33591 .61286 .35414 .62668 .33471 .61926 .31652 Metetra
.681 .607 .766 r
.61926 .31652 .62668 .33471 .64052 .31738 .63345 .30842 Metetra
.654 .753 .922 r
.63345 .30842 .64052 .31738 .65483 .31254 .64781 .30354 Metetra
.654 .753 .922 r
.64781 .30354 .65483 .31254 .66921 .30767 .66225 .29862 Metetra
.654 .753 .922 r
.66225 .29862 .66921 .30767 .68367 .30278 .67675 .29368 Metetra
.654 .753 .922 r
.67675 .29368 .68367 .30278 .6982 .29786 .69134 .28872 Metetra
.654 .753 .922 r
.69134 .28872 .6982 .29786 .71281 .29292 .706 .28373 Metetra
.654 .753 .922 r
.706 .28373 .71281 .29292 .72749 .28795 .72073 .27871 Metetra
.654 .753 .922 r
.72073 .27871 .72749 .28795 .74224 .28296 .73554 .27367 Metetra
.654 .753 .922 r
.73554 .27367 .74224 .28296 .75708 .27794 .75043 .2686 Metetra
.654 .753 .922 r
.75043 .2686 .75708 .27794 .77199 .27289 .7654 .26351 Metetra
.654 .753 .922 r
.7654 .26351 .77199 .27289 .78698 .26782 .78044 .25838 Metetra
.654 .753 .922 r
.11677 .47389 .12544 .48137 .13731 .47733 .12867 .46982 Metetra
.654 .753 .922 r
.12867 .46982 .13731 .47733 .14924 .47327 .14063 .46572 Metetra
.654 .753 .922 r
.14063 .46572 .14924 .47327 .16122 .46919 .15265 .4616 Metetra
.654 .753 .922 r
.15265 .4616 .16122 .46919 .17327 .46509 .16472 .45747 Metetra
.654 .753 .922 r
.16472 .45747 .17327 .46509 .18536 .46097 .17685 .45332 Metetra
.654 .753 .922 r
.17685 .45332 .18536 .46097 .19752 .45683 .18904 .44914 Metetra
.654 .753 .922 r
.18904 .44914 .19752 .45683 .20973 .45267 .20129 .44495 Metetra
.654 .753 .922 r
.20129 .44495 .20973 .45267 .222 .4485 .21359 .44073 Metetra
.654 .753 .922 r
.21359 .44073 .222 .4485 .23433 .4443 .22595 .4365 Metetra
.654 .753 .922 r
.22595 .4365 .23433 .4443 .24672 .44008 .23837 .43225 Metetra
.654 .753 .922 r
.23837 .43225 .24672 .44008 .25916 .43585 .25085 .42797 Metetra
.398 .652 .96 r
.25085 .42797 .25916 .43585 .27058 .44558 .26298 .42879 Metetra
.167 .312 .768 r
.26298 .42879 .27058 .44558 .28224 .45422 .27461 .43746 Metetra
.266 .377 .791 r
.27461 .43746 .28224 .45422 .29423 .46042 .28652 .44428 Metetra
.366 .449 .813 r
.28652 .44428 .29423 .46042 .30655 .46374 .29875 .44872 Metetra
.457 .519 .834 r
.29875 .44872 .30655 .46374 .31917 .46415 .31127 .45061 Metetra
.534 .586 .853 r
.31127 .45061 .31917 .46415 .33205 .46188 .32406 .45007 Metetra
.597 .649 .872 r
.32406 .45007 .33205 .46188 .34513 .45739 .33705 .44741 Metetra
.647 .709 .893 r
.33705 .44741 .34513 .45739 .35836 .45126 .35022 .44311 Metetra
.682 .765 .915 r
.35022 .44311 .35836 .45126 .37168 .44411 .3635 .43768 Metetra
.7 .818 .938 r
.3635 .43768 .37168 .44411 .38506 .43658 .37687 .43163 Metetra
.699 .862 .96 r
.37687 .43163 .38506 .43658 .39848 .42921 .39029 .42546 Metetra
.676 .893 .976 r
.39029 .42546 .39848 .42921 .41191 .42248 .40376 .41956 Metetra
.63 .905 .984 r
.40376 .41956 .41191 .42248 .42537 .4167 .41726 .41422 Metetra
.573 .898 .984 r
.41726 .41422 .42537 .4167 .43884 .41206 .43081 .4096 Metetra
.52 .878 .983 r
.43081 .4096 .43884 .41206 .45236 .40858 .4444 .40571 Metetra
.492 .858 .988 r
.4444 .40571 .45236 .40858 .46593 .40613 .45805 .40244 Metetra
.499 .84 .997 r
.45805 .40244 .46593 .40613 .47958 .40441 .47178 .39953 Metetra
.537 .822 .998 r
.47178 .39953 .47958 .40441 .49332 .403 .48559 .39661 Metetra
.59 .797 .979 r
.48559 .39661 .49332 .403 .50716 .40136 .49949 .3932 Metetra
.642 .765 .938 r
.49949 .3932 .50716 .40136 .5211 .39886 .51347 .38877 Metetra
.684 .733 .888 r
.51347 .38877 .5211 .39886 .53512 .39484 .52753 .3828 Metetra
.717 .706 .839 r
.52753 .3828 .53512 .39484 .5492 .3887 .54163 .37477 Metetra
.742 .686 .797 r
.54163 .37477 .5492 .3887 .56331 .37992 .55576 .3643 Metetra
.761 .672 .764 r
.55576 .3643 .56331 .37992 .5774 .36816 .56987 .35121 Metetra
.777 .665 .739 r
.56987 .35121 .5774 .36816 .59145 .35338 .58393 .33556 Metetra
.789 .662 .723 r
.58393 .33556 .59145 .35338 .6054 .33591 .59792 .3178 Metetra
.748 .641 .742 r
.59792 .3178 .6054 .33591 .61926 .31652 .61199 .30429 Metetra
.649 .678 .864 r
.61199 .30429 .61926 .31652 .63345 .30842 .62632 .29938 Metetra
.654 .753 .922 r
.62632 .29938 .63345 .30842 .64781 .30354 .64073 .29444 Metetra
.654 .753 .922 r
.64073 .29444 .64781 .30354 .66225 .29862 .65522 .28948 Metetra
.654 .753 .922 r
.65522 .28948 .66225 .29862 .67675 .29368 .66978 .2845 Metetra
.654 .753 .922 r
.66978 .2845 .67675 .29368 .69134 .28872 .68441 .27949 Metetra
.654 .753 .922 r
.68441 .27949 .69134 .28872 .706 .28373 .69912 .27445 Metetra
.654 .753 .922 r
.69912 .27445 .706 .28373 .72073 .27871 .71391 .26938 Metetra
.654 .753 .922 r
.71391 .26938 .72073 .27871 .73554 .27367 .72877 .26429 Metetra
.654 .753 .922 r
.72877 .26429 .73554 .27367 .75043 .2686 .74372 .25917 Metetra
.654 .753 .922 r
.74372 .25917 .75043 .2686 .7654 .26351 .75874 .25403 Metetra
.654 .753 .922 r
.75874 .25403 .7654 .26351 .78044 .25838 .77384 .24886 Metetra
.654 .753 .922 r
.10802 .46635 .11677 .47389 .12867 .46982 .11996 .46224 Metetra
.654 .753 .922 r
.11996 .46224 .12867 .46982 .14063 .46572 .13195 .45811 Metetra
.654 .753 .922 r
.13195 .45811 .14063 .46572 .15265 .4616 .144 .45396 Metetra
.654 .753 .922 r
.144 .45396 .15265 .4616 .16472 .45747 .15611 .44979 Metetra
.654 .753 .922 r
.15611 .44979 .16472 .45747 .17685 .45332 .16827 .44559 Metetra
.654 .753 .922 r
.16827 .44559 .17685 .45332 .18904 .44914 .18049 .44138 Metetra
.654 .753 .922 r
.18049 .44138 .18904 .44914 .20129 .44495 .19277 .43715 Metetra
.654 .753 .922 r
.19277 .43715 .20129 .44495 .21359 .44073 .20511 .4329 Metetra
.654 .753 .922 r
.20511 .4329 .21359 .44073 .22595 .4365 .2175 .42863 Metetra
.654 .753 .922 r
.2175 .42863 .22595 .4365 .23837 .43225 .22996 .42434 Metetra
.654 .753 .922 r
.22996 .42434 .23837 .43225 .25085 .42797 .24247 .42003 Metetra
.654 .753 .922 r
.24247 .42003 .25085 .42797 .26298 .42879 .25505 .41569 Metetra
.263 .443 .851 r
.25505 .41569 .26298 .42879 .27461 .43746 .26694 .42076 Metetra
.245 .366 .788 r
.26694 .42076 .27461 .43746 .28652 .44428 .2788 .42786 Metetra
.332 .425 .807 r
.2788 .42786 .28652 .44428 .29875 .44872 .29095 .43306 Metetra
.415 .487 .825 r
.29095 .43306 .29875 .44872 .31127 .45061 .30339 .43611 Metetra
.487 .547 .843 r
.30339 .43611 .31127 .45061 .32406 .45007 .31608 .437 Metetra
.548 .604 .862 r
.31608 .437 .32406 .45007 .33705 .44741 .32899 .43592 Metetra
.597 .658 .881 r
.32899 .43592 .33705 .44741 .35022 .44311 .34209 .43323 Metetra
.633 .709 .901 r
.34209 .43323 .35022 .44311 .3635 .43768 .35533 .42932 Metetra
.657 .756 .923 r
.35533 .42932 .3635 .43768 .37687 .43163 .36867 .42462 Metetra
.668 .797 .944 r
.36867 .42462 .37687 .43163 .39029 .42546 .3821 .41954 Metetra
.664 .829 .962 r
.3821 .41954 .39029 .42546 .40376 .41956 .39559 .41441 Metetra
.649 .849 .977 r
.39559 .41441 .40376 .41956 .41726 .41422 .40914 .40947 Metetra
.627 .855 .986 r
.40914 .40947 .41726 .41422 .43081 .4096 .42274 .40485 Metetra
.609 .851 .99 r
.42274 .40485 .43081 .4096 .4444 .40571 .43639 .40058 Metetra
.602 .839 .989 r
.43639 .40058 .4444 .40571 .45805 .40244 .45012 .39655 Metetra
.611 .82 .98 r
.45012 .39655 .45805 .40244 .47178 .39953 .46392 .39254 Metetra
.632 .795 .96 r
.46392 .39254 .47178 .39953 .48559 .39661 .47779 .38823 Metetra
.66 .767 .929 r
.47779 .38823 .48559 .39661 .49949 .3932 .49175 .38323 Metetra
.688 .738 .889 r
.49175 .38323 .49949 .3932 .51347 .38877 .50579 .3771 Metetra
.712 .712 .848 r
.50579 .3771 .51347 .38877 .52753 .3828 .51988 .3694 Metetra
.734 .691 .81 r
.51988 .3694 .52753 .3828 .54163 .37477 .53402 .35977 Metetra
.751 .677 .778 r
.53402 .35977 .54163 .37477 .55576 .3643 .54817 .34795 Metetra
.767 .667 .753 r
.54817 .34795 .55576 .3643 .56987 .35121 .56231 .33386 Metetra
.779 .663 .735 r
.56231 .33386 .56987 .35121 .58393 .33556 .5764 .3177 Metetra
.788 .662 .724 r
.5764 .3177 .58393 .33556 .59792 .3178 .59043 .30014 Metetra
.63 .588 .788 r
.59043 .30014 .59792 .3178 .61199 .30429 .60474 .29521 Metetra
.654 .753 .922 r
.60474 .29521 .61199 .30429 .62632 .29938 .61912 .29025 Metetra
.654 .753 .922 r
.61912 .29025 .62632 .29938 .64073 .29444 .63358 .28527 Metetra
.654 .753 .922 r
.63358 .28527 .64073 .29444 .65522 .28948 .64812 .28026 Metetra
.654 .753 .922 r
.64812 .28026 .65522 .28948 .66978 .2845 .66273 .27522 Metetra
.654 .753 .922 r
.66273 .27522 .66978 .2845 .68441 .27949 .67742 .27016 Metetra
.654 .753 .922 r
.67742 .27016 .68441 .27949 .69912 .27445 .69218 .26508 Metetra
.654 .753 .922 r
.69218 .26508 .69912 .27445 .71391 .26938 .70702 .25996 Metetra
.654 .753 .922 r
.70702 .25996 .71391 .26938 .72877 .26429 .72194 .25482 Metetra
.654 .753 .922 r
.72194 .25482 .72877 .26429 .74372 .25917 .73694 .24966 Metetra
.654 .753 .922 r
.73694 .24966 .74372 .25917 .75874 .25403 .75201 .24446 Metetra
.654 .753 .922 r
.75201 .24446 .75874 .25403 .77384 .24886 .76717 .23924 Metetra
.654 .753 .922 r
.0992 .45874 .10802 .46635 .11996 .46224 .11117 .4546 Metetra
.654 .753 .922 r
.11117 .4546 .11996 .46224 .13195 .45811 .12319 .45043 Metetra
.654 .753 .922 r
.12319 .45043 .13195 .45811 .144 .45396 .13527 .44624 Metetra
.654 .753 .922 r
.13527 .44624 .144 .45396 .15611 .44979 .14741 .44203 Metetra
.654 .753 .922 r
.14741 .44203 .15611 .44979 .16827 .44559 .15961 .4378 Metetra
.654 .753 .922 r
.15961 .4378 .16827 .44559 .18049 .44138 .17186 .43356 Metetra
.654 .753 .922 r
.17186 .43356 .18049 .44138 .19277 .43715 .18417 .42929 Metetra
.654 .753 .922 r
.18417 .42929 .19277 .43715 .20511 .4329 .19655 .425 Metetra
.654 .753 .922 r
.19655 .425 .20511 .4329 .2175 .42863 .20898 .42069 Metetra
.654 .753 .922 r
.20898 .42069 .2175 .42863 .22996 .42434 .22147 .41636 Metetra
.654 .753 .922 r
.22147 .41636 .22996 .42434 .24247 .42003 .23402 .41201 Metetra
.654 .753 .922 r
.23402 .41201 .24247 .42003 .25505 .41569 .24663 .40764 Metetra
.618 .742 .935 r
.24663 .40764 .25505 .41569 .26694 .42076 .25922 .40426 Metetra
.236 .365 .791 r
.25922 .40426 .26694 .42076 .2788 .42786 .27106 .41132 Metetra
.31 .411 .803 r
.27106 .41132 .2788 .42786 .29095 .43306 .28315 .41696 Metetra
.383 .462 .818 r
.28315 .41696 .29095 .43306 .30339 .43611 .29551 .42083 Metetra
.449 .514 .833 r
.29551 .42083 .30339 .43611 .31608 .437 .30812 .42283 Metetra
.506 .565 .849 r
.30812 .42283 .31608 .437 .32899 .43592 .32096 .42305 Metetra
.554 .613 .866 r
.32096 .42305 .32899 .43592 .34209 .43323 .33399 .42171 Metetra
.591 .658 .884 r
.33399 .42171 .34209 .43323 .35533 .42932 .34718 .41911 Metetra
.619 .699 .902 r
.34718 .41911 .35533 .42932 .36867 .42462 .3605 .41559 Metetra
.637 .735 .919 r
.3605 .41559 .36867 .42462 .3821 .41954 .37392 .41147 Metetra
.646 .764 .935 r
.37392 .41147 .3821 .41954 .39559 .41441 .38742 .40701 Metetra
.648 .785 .947 r
.38742 .40701 .39559 .41441 .40914 .40947 .401 .40242 Metetra
.647 .795 .954 r
.401 .40242 .40914 .40947 .42274 .40485 .41465 .39781 Metetra
.646 .796 .955 r
.41465 .39781 .42274 .40485 .43639 .40058 .42837 .39319 Metetra
.65 .789 .948 r
.42837 .39319 .43639 .40058 .45012 .39655 .44215 .38847 Metetra
.66 .774 .934 r
.44215 .38847 .45012 .39655 .46392 .39254 .45602 .38347 Metetra
.675 .755 .911 r
.45602 .38347 .46392 .39254 .47779 .38823 .46996 .37794 Metetra
.693 .733 .882 r
.46996 .37794 .47779 .38823 .49175 .38323 .48397 .37154 Metetra
.71 .712 .849 r
.48397 .37154 .49175 .38323 .50579 .3771 .49806 .36394 Metetra
.727 .693 .817 r
.49806 .36394 .50579 .3771 .51988 .3694 .51219 .35481 Metetra
.743 .679 .789 r
.51219 .35481 .51988 .3694 .53402 .35977 .52636 .3439 Metetra
.757 .669 .765 r
.52636 .3439 .53402 .35977 .54817 .34795 .54054 .33105 Metetra
.769 .663 .746 r
.54054 .33105 .54817 .34795 .56231 .33386 .55471 .31631 Metetra
.78 .662 .733 r
.55471 .31631 .56231 .33386 .5764 .3177 .56883 .29997 Metetra
.695 .621 .77 r
.56883 .29997 .5764 .3177 .59043 .30014 .58306 .29101 Metetra
.654 .753 .922 r
.58306 .29101 .59043 .30014 .60474 .29521 .59742 .28603 Metetra
.654 .753 .922 r
.59742 .28603 .60474 .29521 .61912 .29025 .61186 .28103 Metetra
.654 .753 .922 r
.61186 .28103 .61912 .29025 .63358 .28527 .62637 .276 Metetra
.654 .753 .922 r
.62637 .276 .63358 .28527 .64812 .28026 .64095 .27094 Metetra
.654 .753 .922 r
.64095 .27094 .64812 .28026 .66273 .27522 .65562 .26586 Metetra
.654 .753 .922 r
.65562 .26586 .66273 .27522 .67742 .27016 .67036 .26075 Metetra
.654 .753 .922 r
.67036 .26075 .67742 .27016 .69218 .26508 .68517 .25562 Metetra
.654 .753 .922 r
.68517 .25562 .69218 .26508 .70702 .25996 .70007 .25045 Metetra
.654 .753 .922 r
.70007 .25045 .70702 .25996 .72194 .25482 .71504 .24526 Metetra
.654 .753 .922 r
.71504 .24526 .72194 .25482 .73694 .24966 .73009 .24004 Metetra
.654 .753 .922 r
.73009 .24004 .73694 .24966 .75201 .24446 .74522 .2348 Metetra
.654 .753 .922 r
.74522 .2348 .75201 .24446 .76717 .23924 .76044 .22952 Metetra
.654 .753 .922 r
.09031 .45107 .0992 .45874 .11117 .4546 .10231 .44689 Metetra
.654 .753 .922 r
.10231 .44689 .11117 .4546 .12319 .45043 .11436 .44268 Metetra
.654 .753 .922 r
.11436 .44268 .12319 .45043 .13527 .44624 .12647 .43846 Metetra
.654 .753 .922 r
.12647 .43846 .13527 .44624 .14741 .44203 .13864 .43421 Metetra
.654 .753 .922 r
.13864 .43421 .14741 .44203 .15961 .4378 .15087 .42995 Metetra
.654 .753 .922 r
.15087 .42995 .15961 .4378 .17186 .43356 .16316 .42566 Metetra
.654 .753 .922 r
.16316 .42566 .17186 .43356 .18417 .42929 .17551 .42136 Metetra
.654 .753 .922 r
.17551 .42136 .18417 .42929 .19655 .425 .18791 .41703 Metetra
.654 .753 .922 r
.18791 .41703 .19655 .425 .20898 .42069 .20038 .41268 Metetra
.654 .753 .922 r
.20038 .41268 .20898 .42069 .22147 .41636 .2129 .40831 Metetra
.654 .753 .922 r
.2129 .40831 .22147 .41636 .23402 .41201 .22549 .40392 Metetra
.654 .753 .922 r
.22549 .40392 .23402 .41201 .24663 .40764 .23814 .39951 Metetra
.654 .753 .922 r
.23814 .39951 .24663 .40764 .25922 .40426 .25085 .39508 Metetra
.48 .66 .94 r
.25085 .39508 .25922 .40426 .27106 .41132 .26327 .39485 Metetra
.298 .406 .804 r
.26327 .39485 .27106 .41132 .28315 .41696 .27533 .40059 Metetra
.361 .446 .814 r
.27533 .40059 .28315 .41696 .29551 .42083 .28764 .40496 Metetra
.421 .49 .825 r
.28764 .40496 .29551 .42083 .30812 .42283 .30018 .40775 Metetra
.474 .534 .838 r
.30018 .40775 .30812 .42283 .32096 .42305 .31295 .40896 Metetra
.52 .575 .852 r
.31295 .40896 .32096 .42305 .33399 .42171 .32592 .4087 Metetra
.557 .615 .866 r
.32592 .4087 .33399 .42171 .34718 .41911 .33906 .40719 Metetra
.588 .651 .88 r
.33906 .40719 .34718 .41911 .3605 .41559 .35235 .40466 Metetra
.611 .682 .893 r
.35235 .40466 .3605 .41559 .37392 .41147 .36576 .40134 Metetra
.628 .708 .904 r
.36576 .40134 .37392 .41147 .38742 .40701 .37927 .39746 Metetra
.64 .727 .912 r
.37927 .39746 .38742 .40701 .401 .40242 .39287 .39317 Metetra
.649 .739 .915 r
.39287 .39317 .401 .40242 .41465 .39781 .40656 .38855 Metetra
.658 .743 .913 r
.40656 .38855 .41465 .39781 .42837 .39319 .42032 .38362 Metetra
.668 .74 .904 r
.42032 .38362 .42837 .39319 .44215 .38847 .43417 .3783 Metetra
.68 .731 .889 r
.43417 .3783 .44215 .38847 .45602 .38347 .44809 .37244 Metetra
.693 .718 .868 r
.44809 .37244 .45602 .38347 .46996 .37794 .46209 .36585 Metetra
.707 .704 .845 r
.46209 .36585 .46996 .37794 .48397 .37154 .47616 .35828 Metetra
.721 .69 .819 r
.47616 .35828 .48397 .37154 .49806 .36394 .49029 .34948 Metetra
.735 .678 .795 r
.49029 .34948 .49806 .36394 .51219 .35481 .50446 .33921 Metetra
.748 .669 .774 r
.50446 .33921 .51219 .35481 .52636 .3439 .51867 .32733 Metetra
.76 .663 .756 r
.51867 .32733 .52636 .3439 .54054 .33105 .53288 .3138 Metetra
.77 .661 .742 r
.53288 .3138 .54054 .33105 .55471 .31631 .54707 .29875 Metetra
.735 .642 .757 r
.54707 .29875 .55471 .31631 .56883 .29997 .56129 .2868 Metetra
.646 .663 .852 r
.56129 .2868 .56883 .29997 .58306 .29101 .57562 .2818 Metetra
.654 .753 .922 r
.57562 .2818 .58306 .29101 .59742 .28603 .59003 .27678 Metetra
.654 .753 .922 r
.59003 .27678 .59742 .28603 .61186 .28103 .60452 .27172 Metetra
.654 .753 .922 r
.60452 .27172 .61186 .28103 .62637 .276 .61908 .26665 Metetra
.654 .753 .922 r
.61908 .26665 .62637 .276 .64095 .27094 .63372 .26154 Metetra
.654 .753 .922 r
.63372 .26154 .64095 .27094 .65562 .26586 .64843 .25641 Metetra
.654 .753 .922 r
.64843 .25641 .65562 .26586 .67036 .26075 .66323 .25125 Metetra
.654 .753 .922 r
.66323 .25125 .67036 .26075 .68517 .25562 .6781 .24606 Metetra
.654 .753 .922 r
.6781 .24606 .68517 .25562 .70007 .25045 .69304 .24085 Metetra
.654 .753 .922 r
.69304 .24085 .70007 .25045 .71504 .24526 .70807 .23561 Metetra
.654 .753 .922 r
.70807 .23561 .71504 .24526 .73009 .24004 .72318 .23034 Metetra
.654 .753 .922 r
.72318 .23034 .73009 .24004 .74522 .2348 .73837 .22504 Metetra
.654 .753 .922 r
.73837 .22504 .74522 .2348 .76044 .22952 .75364 .21972 Metetra
.654 .753 .922 r
.08133 .44333 .09031 .45107 .10231 .44689 .09336 .43911 Metetra
.654 .753 .922 r
.09336 .43911 .10231 .44689 .11436 .44268 .10545 .43487 Metetra
.654 .753 .922 r
.10545 .43487 .11436 .44268 .12647 .43846 .11759 .4306 Metetra
.654 .753 .922 r
.11759 .4306 .12647 .43846 .13864 .43421 .1298 .42632 Metetra
.654 .753 .922 r
.1298 .42632 .13864 .43421 .15087 .42995 .14206 .42202 Metetra
.654 .753 .922 r
.14206 .42202 .15087 .42995 .16316 .42566 .15438 .4177 Metetra
.654 .753 .922 r
.15438 .4177 .16316 .42566 .17551 .42136 .16676 .41335 Metetra
.654 .753 .922 r
.16676 .41335 .17551 .42136 .18791 .41703 .1792 .40899 Metetra
.654 .753 .922 r
.1792 .40899 .18791 .41703 .20038 .41268 .1917 .4046 Metetra
.654 .753 .922 r
.1917 .4046 .20038 .41268 .2129 .40831 .20426 .40019 Metetra
.654 .753 .922 r
.20426 .40019 .2129 .40831 .22549 .40392 .21688 .39576 Metetra
.654 .753 .922 r
.21688 .39576 .22549 .40392 .23814 .39951 .22957 .39131 Metetra
.654 .753 .922 r
.22957 .39131 .23814 .39951 .25085 .39508 .24231 .38684 Metetra
.654 .753 .922 r
.24231 .38684 .25085 .39508 .26327 .39485 .25512 .38234 Metetra
.419 .551 .882 r
.25512 .38234 .26327 .39485 .27533 .40059 .26748 .38417 Metetra
.35 .44 .813 r
.26748 .38417 .27533 .40059 .28764 .40496 .27975 .38871 Metetra
.402 .475 .82 r
.27975 .38871 .28764 .40496 .30018 .40775 .29224 .39198 Metetra
.451 .511 .829 r
.29224 .39198 .30018 .40775 .31295 .40896 .30496 .39387 Metetra
.494 .547 .839 r
.30496 .39387 .31295 .40896 .32592 .4087 .31787 .39443 Metetra
.532 .581 .849 r
.31787 .39443 .32592 .4087 .33906 .40719 .33097 .39375 Metetra
.564 .612 .859 r
.33097 .39375 .33906 .40719 .35235 .40466 .34423 .392 Metetra
.59 .64 .868 r
.34423 .392 .35235 .40466 .36576 .40134 .35762 .38934 Metetra
.612 .663 .875 r
.35762 .38934 .36576 .40134 .37927 .39746 .37113 .38593 Metetra
.63 .681 .879 r
.37113 .38593 .37927 .39746 .39287 .39317 .38475 .38187 Metetra
.646 .693 .88 r
.38475 .38187 .39287 .39317 .40656 .38855 .39847 .37724 Metetra
.66 .699 .875 r
.39847 .37724 .40656 .38855 .42032 .38362 .41228 .37203 Metetra
.674 .7 .866 r
.41228 .37203 .42032 .38362 .43417 .3783 .42617 .3662 Metetra
.687 .696 .853 r
.42617 .3662 .43417 .3783 .44809 .37244 .44015 .35963 Metetra
.701 .689 .836 r
.44015 .35963 .44809 .37244 .46209 .36585 .45419 .35218 Metetra
.714 .681 .817 r
.45419 .35218 .46209 .36585 .47616 .35828 .46831 .34367 Metetra
.726 .673 .798 r
.46831 .34367 .47616 .35828 .49029 .34948 .48249 .33393 Metetra
.738 .666 .78 r
.48249 .33393 .49029 .34948 .50446 .33921 .4967 .32283 Metetra
.75 .662 .764 r
.4967 .32283 .50446 .33921 .51867 .32733 .51094 .3103 Metetra
.76 .659 .751 r
.51094 .3103 .51867 .32733 .53288 .3138 .52518 .2964 Metetra
.757 .655 .748 r
.52518 .2964 .53288 .3138 .54707 .29875 .53942 .28257 Metetra
.635 .612 .81 r
.53942 .28257 .54707 .29875 .56129 .2868 .55373 .27755 Metetra
.654 .753 .922 r
.55373 .27755 .56129 .2868 .57562 .2818 .56812 .2725 Metetra
.654 .753 .922 r
.56812 .2725 .57562 .2818 .59003 .27678 .58258 .26743 Metetra
.654 .753 .922 r
.58258 .26743 .59003 .27678 .60452 .27172 .59711 .26233 Metetra
.654 .753 .922 r
.59711 .26233 .60452 .27172 .61908 .26665 .61173 .2572 Metetra
.654 .753 .922 r
.61173 .2572 .61908 .26665 .63372 .26154 .62641 .25204 Metetra
.654 .753 .922 r
.62641 .25204 .63372 .26154 .64843 .25641 .64118 .24686 Metetra
.654 .753 .922 r
.64118 .24686 .64843 .25641 .66323 .25125 .65603 .24165 Metetra
.654 .753 .922 r
.65603 .24165 .66323 .25125 .6781 .24606 .67095 .23642 Metetra
.654 .753 .922 r
.67095 .23642 .6781 .24606 .69304 .24085 .68595 .23115 Metetra
.654 .753 .922 r
.68595 .23115 .69304 .24085 .70807 .23561 .70104 .22586 Metetra
.654 .753 .922 r
.70104 .22586 .70807 .23561 .72318 .23034 .7162 .22054 Metetra
.654 .753 .922 r
.7162 .22054 .72318 .23034 .73837 .22504 .73144 .21519 Metetra
.654 .753 .922 r
.73144 .21519 .73837 .22504 .75364 .21972 .74677 .20981 Metetra
.654 .753 .922 r
.07228 .43552 .08133 .44333 .09336 .43911 .08434 .43126 Metetra
.654 .753 .922 r
.08434 .43126 .09336 .43911 .10545 .43487 .09646 .42698 Metetra
.654 .753 .922 r
.09646 .42698 .10545 .43487 .11759 .4306 .10863 .42268 Metetra
.654 .753 .922 r
.10863 .42268 .11759 .4306 .1298 .42632 .12087 .41836 Metetra
.654 .753 .922 r
.12087 .41836 .1298 .42632 .14206 .42202 .13316 .41402 Metetra
.654 .753 .922 r
.13316 .41402 .14206 .42202 .15438 .4177 .14552 .40966 Metetra
.654 .753 .922 r
.14552 .40966 .15438 .4177 .16676 .41335 .15793 .40527 Metetra
.654 .753 .922 r
.15793 .40527 .16676 .41335 .1792 .40899 .17041 .40087 Metetra
.654 .753 .922 r
.17041 .40087 .1792 .40899 .1917 .4046 .18294 .39644 Metetra
.654 .753 .922 r
.18294 .39644 .1917 .4046 .20426 .40019 .19554 .392 Metetra
.654 .753 .922 r
.19554 .392 .20426 .40019 .21688 .39576 .2082 .38753 Metetra
.654 .753 .922 r
.2082 .38753 .21688 .39576 .22957 .39131 .22092 .38304 Metetra
.654 .753 .922 r
.22092 .38304 .22957 .39131 .24231 .38684 .2337 .37852 Metetra
.654 .753 .922 r
.2337 .37852 .24231 .38684 .25512 .38234 .24654 .37399 Metetra
.654 .753 .922 r
.24654 .37399 .25512 .38234 .26748 .38417 .25945 .36943 Metetra
.397 .497 .844 r
.25945 .36943 .26748 .38417 .27975 .38871 .27184 .3723 Metetra
.393 .468 .818 r
.27184 .3723 .27975 .38871 .29224 .39198 .2843 .37574 Metetra
.437 .497 .823 r
.2843 .37574 .29224 .39198 .30496 .39387 .29697 .37804 Metetra
.477 .527 .829 r
.29697 .37804 .30496 .39387 .31787 .39443 .30984 .37913 Metetra
.514 .556 .836 r
.30984 .37913 .31787 .39443 .33097 .39375 .3229 .37904 Metetra
.546 .583 .843 r
.3229 .37904 .33097 .39375 .34423 .392 .33613 .37787 Metetra
.574 .607 .848 r
.33613 .37787 .34423 .392 .35762 .38934 .34951 .3757 Metetra
.599 .628 .852 r
.34951 .3757 .35762 .38934 .37113 .38593 .36302 .37264 Metetra
.621 .645 .853 r
.36302 .37264 .37113 .38593 .38475 .38187 .37665 .36876 Metetra
.64 .658 .851 r
.37665 .36876 .38475 .38187 .39847 .37724 .39039 .3641 Metetra
.658 .666 .846 r
.39039 .3641 .39847 .37724 .41228 .37203 .40424 .35867 Metetra
.674 .669 .837 r
.40424 .35867 .41228 .37203 .42617 .3662 .41817 .35242 Metetra
.689 .669 .826 r
.41817 .35242 .42617 .3662 .44015 .35963 .43219 .34529 Metetra
.703 .667 .812 r
.43219 .34529 .44015 .35963 .45419 .35218 .44628 .33717 Metetra
.716 .664 .798 r
.44628 .33717 .45419 .35218 .46831 .34367 .46044 .32795 Metetra
.728 .66 .783 r
.46044 .32795 .46831 .34367 .48249 .33393 .47465 .31755 Metetra
.739 .658 .769 r
.47465 .31755 .48249 .33393 .4967 .32283 .4889 .30589 Metetra
.75 .657 .758 r
.4889 .30589 .4967 .32283 .51094 .3103 .50318 .29302 Metetra
.759 .657 .749 r
.50318 .29302 .51094 .3103 .52518 .2964 .51745 .27905 Metetra
.644 .603 .793 r
.51745 .27905 .52518 .2964 .53942 .28257 .53174 .27328 Metetra
.654 .753 .922 r
.53174 .27328 .53942 .28257 .55373 .27755 .5461 .26821 Metetra
.654 .753 .922 r
.5461 .26821 .55373 .27755 .56812 .2725 .56054 .26311 Metetra
.654 .753 .922 r
.56054 .26311 .56812 .2725 .58258 .26743 .57505 .25799 Metetra
.654 .753 .922 r
.57505 .25799 .58258 .26743 .59711 .26233 .58963 .25284 Metetra
.654 .753 .922 r
.58963 .25284 .59711 .26233 .61173 .2572 .6043 .24766 Metetra
.654 .753 .922 r
.6043 .24766 .61173 .2572 .62641 .25204 .61904 .24246 Metetra
.654 .753 .922 r
.61904 .24246 .62641 .25204 .64118 .24686 .63386 .23722 Metetra
.654 .753 .922 r
.63386 .23722 .64118 .24686 .65603 .24165 .64876 .23196 Metetra
.654 .753 .922 r
.64876 .23196 .65603 .24165 .67095 .23642 .66373 .22667 Metetra
.654 .753 .922 r
.66373 .22667 .67095 .23642 .68595 .23115 .67879 .22136 Metetra
.654 .753 .922 r
.67879 .22136 .68595 .23115 .70104 .22586 .69393 .21601 Metetra
.654 .753 .922 r
.69393 .21601 .70104 .22586 .7162 .22054 .70915 .21064 Metetra
.654 .753 .922 r
.70915 .21064 .7162 .22054 .73144 .21519 .72445 .20523 Metetra
.654 .753 .922 r
.72445 .20523 .73144 .21519 .74677 .20981 .73983 .1998 Metetra
.654 .753 .922 r
.06314 .42764 .07228 .43552 .08434 .43126 .07524 .42335 Metetra
.654 .753 .922 r
.07524 .42335 .08434 .43126 .09646 .42698 .08739 .41903 Metetra
.654 .753 .922 r
.08739 .41903 .09646 .42698 .10863 .42268 .0996 .41469 Metetra
.654 .753 .922 r
.0996 .41469 .10863 .42268 .12087 .41836 .11186 .41033 Metetra
.654 .753 .922 r
.11186 .41033 .12087 .41836 .13316 .41402 .12419 .40595 Metetra
.654 .753 .922 r
.12419 .40595 .13316 .41402 .14552 .40966 .13658 .40155 Metetra
.654 .753 .922 r
.13658 .40155 .14552 .40966 .15793 .40527 .14903 .39713 Metetra
.654 .753 .922 r
.14903 .39713 .15793 .40527 .17041 .40087 .16154 .39268 Metetra
.654 .753 .922 r
.16154 .39268 .17041 .40087 .18294 .39644 .17411 .38822 Metetra
.654 .753 .922 r
.17411 .38822 .18294 .39644 .19554 .392 .18674 .38373 Metetra
.654 .753 .922 r
.18674 .38373 .19554 .392 .2082 .38753 .19943 .37922 Metetra
.654 .753 .922 r
.19943 .37922 .2082 .38753 .22092 .38304 .21219 .37468 Metetra
.654 .753 .922 r
.21219 .37468 .22092 .38304 .2337 .37852 .22501 .37013 Metetra
.654 .753 .922 r
.22501 .37013 .2337 .37852 .24654 .37399 .23789 .36555 Metetra
.654 .753 .922 r
.23789 .36555 .24654 .37399 .25945 .36943 .25084 .36095 Metetra
.654 .753 .922 r
.25084 .36095 .25945 .36943 .27184 .3723 .26385 .35633 Metetra
.404 .483 .827 r
.26385 .35633 .27184 .3723 .2843 .37574 .27633 .35928 Metetra
.43 .491 .821 r
.27633 .35928 .2843 .37574 .29697 .37804 .28898 .3617 Metetra
.468 .515 .823 r
.28898 .3617 .29697 .37804 .30984 .37913 .30182 .36307 Metetra
.503 .539 .827 r
.30182 .36307 .30984 .37913 .3229 .37904 .31485 .36335 Metetra
.535 .563 .83 r
.31485 .36335 .3229 .37904 .33613 .37787 .32806 .36255 Metetra
.564 .584 .833 r
.32806 .36255 .33613 .37787 .34951 .3757 .34142 .36072 Metetra
.59 .603 .834 r
.34142 .36072 .34951 .3757 .36302 .37264 .35493 .3579 Metetra
.614 .619 .833 r
.35493 .3579 .36302 .37264 .37665 .36876 .36857 .35413 Metetra
.635 .632 .83 r
.36857 .35413 .37665 .36876 .39039 .3641 .38233 .34944 Metetra
.655 .641 .824 r
.38233 .34944 .39039 .3641 .40424 .35867 .39619 .34382 Metetra
.672 .647 .816 r
.39619 .34382 .40424 .35867 .41817 .35242 .41016 .33726 Metetra
.688 .65 .807 r
.41016 .33726 .41817 .35242 .43219 .34529 .42422 .32971 Metetra
.703 .651 .796 r
.42422 .32971 .43219 .34529 .44628 .33717 .43835 .32111 Metetra
.716 .651 .784 r
.43835 .32111 .44628 .33717 .46044 .32795 .45254 .31141 Metetra
.728 .651 .773 r
.45254 .31141 .46044 .32795 .47465 .31755 .46679 .30059 Metetra
.739 .652 .763 r
.46679 .30059 .47465 .31755 .4889 .30589 .48108 .28866 Metetra
.749 .654 .756 r
.48108 .28866 .4889 .30589 .50318 .29302 .49538 .2757 Metetra
.661 .612 .789 r
.49538 .2757 .50318 .29302 .51745 .27905 .50965 .26899 Metetra
.654 .735 .909 r
.50965 .26899 .51745 .27905 .53174 .27328 .52399 .2639 Metetra
.654 .753 .922 r
.52399 .2639 .53174 .27328 .5461 .26821 .5384 .25878 Metetra
.654 .753 .922 r
.5384 .25878 .5461 .26821 .56054 .26311 .55288 .25363 Metetra
.654 .753 .922 r
.55288 .25363 .56054 .26311 .57505 .25799 .56744 .24846 Metetra
.654 .753 .922 r
.56744 .24846 .57505 .25799 .58963 .25284 .58208 .24326 Metetra
.654 .753 .922 r
.58208 .24326 .58963 .25284 .6043 .24766 .5968 .23803 Metetra
.654 .753 .922 r
.5968 .23803 .6043 .24766 .61904 .24246 .61159 .23277 Metetra
.654 .753 .922 r
.61159 .23277 .61904 .24246 .63386 .23722 .62646 .22749 Metetra
.654 .753 .922 r
.62646 .22749 .63386 .23722 .64876 .23196 .64141 .22218 Metetra
.654 .753 .922 r
.64141 .22218 .64876 .23196 .66373 .22667 .65645 .21684 Metetra
.654 .753 .922 r
.65645 .21684 .66373 .22667 .67879 .22136 .67156 .21147 Metetra
.654 .753 .922 r
.67156 .21147 .67879 .22136 .69393 .21601 .68675 .20607 Metetra
.654 .753 .922 r
.68675 .20607 .69393 .21601 .70915 .21064 .70203 .20064 Metetra
.654 .753 .922 r
.70203 .20064 .70915 .21064 .72445 .20523 .71739 .19518 Metetra
.654 .753 .922 r
.71739 .19518 .72445 .20523 .73983 .1998 .73283 .1897 Metetra
.654 .753 .922 r
.05393 .41969 .06314 .42764 .07524 .42335 .06605 .41536 Metetra
.654 .753 .922 r
.06605 .41536 .07524 .42335 .08739 .41903 .07824 .411 Metetra
.654 .753 .922 r
.07824 .411 .08739 .41903 .0996 .41469 .09048 .40663 Metetra
.654 .753 .922 r
.09048 .40663 .0996 .41469 .11186 .41033 .10278 .40223 Metetra
.654 .753 .922 r
.10278 .40223 .11186 .41033 .12419 .40595 .11514 .39781 Metetra
.654 .753 .922 r
.11514 .39781 .12419 .40595 .13658 .40155 .12756 .39337 Metetra
.654 .753 .922 r
.12756 .39337 .13658 .40155 .14903 .39713 .14004 .3889 Metetra
.654 .753 .922 r
.14004 .3889 .14903 .39713 .16154 .39268 .15259 .38442 Metetra
.654 .753 .922 r
.15259 .38442 .16154 .39268 .17411 .38822 .16519 .37991 Metetra
.654 .753 .922 r
.16519 .37991 .17411 .38822 .18674 .38373 .17786 .37538 Metetra
.654 .753 .922 r
.17786 .37538 .18674 .38373 .19943 .37922 .19059 .37083 Metetra
.654 .753 .922 r
.19059 .37083 .19943 .37922 .21219 .37468 .20338 .36626 Metetra
.654 .753 .922 r
.20338 .36626 .21219 .37468 .22501 .37013 .21624 .36166 Metetra
.654 .753 .922 r
.21624 .36166 .22501 .37013 .23789 .36555 .22916 .35704 Metetra
.654 .753 .922 r
.22916 .35704 .23789 .36555 .25084 .36095 .24214 .3524 Metetra
.654 .753 .922 r
.24214 .3524 .25084 .36095 .26385 .35633 .25519 .34773 Metetra
.654 .753 .922 r
.25519 .34773 .26385 .35633 .27633 .35928 .26831 .34304 Metetra
.438 .5 .825 r
.26831 .34304 .27633 .35928 .28898 .3617 .28097 .34513 Metetra
.465 .511 .821 r
.28097 .34513 .28898 .3617 .30182 .36307 .29379 .34654 Metetra
.497 .53 .821 r
.29379 .34654 .30182 .36307 .31485 .36335 .3068 .34697 Metetra
.528 .55 .822 r
.3068 .34697 .31485 .36335 .32806 .36255 .31999 .34637 Metetra
.557 .569 .822 r
.31999 .34637 .32806 .36255 .34142 .36072 .33334 .34472 Metetra
.584 .587 .821 r
.33334 .34472 .34142 .36072 .35493 .3579 .34685 .34203 Metetra
.609 .602 .819 r
.34685 .34203 .35493 .3579 .36857 .35413 .36049 .33832 Metetra
.631 .614 .815 r
.36049 .33832 .36857 .35413 .38233 .34944 .37427 .33358 Metetra
.651 .624 .809 r
.37427 .33358 .38233 .34944 .39619 .34382 .38815 .32783 Metetra
.67 .631 .802 r
.38815 .32783 .39619 .34382 .41016 .33726 .40215 .32104 Metetra
.686 .636 .794 r
.40215 .32104 .41016 .33726 .42422 .32971 .41623 .31321 Metetra
.701 .64 .785 r
.41623 .31321 .42422 .32971 .43835 .32111 .43039 .3043 Metetra
.715 .643 .776 r
.43039 .3043 .43835 .32111 .45254 .31141 .44462 .29433 Metetra
.727 .646 .768 r
.44462 .29433 .45254 .31141 .46679 .30059 .4589 .28332 Metetra
.737 .649 .761 r
.4589 .28332 .46679 .30059 .48108 .28866 .47321 .27135 Metetra
.66 .613 .79 r
.47321 .27135 .48108 .28866 .49538 .2757 .48747 .26468 Metetra
.652 .714 .893 r
.48747 .26468 .49538 .2757 .50965 .26899 .50178 .25957 Metetra
.654 .753 .922 r
.50178 .25957 .50965 .26899 .52399 .2639 .51616 .25443 Metetra
.654 .753 .922 r
.51616 .25443 .52399 .2639 .5384 .25878 .53062 .24926 Metetra
.654 .753 .922 r
.53062 .24926 .5384 .25878 .55288 .25363 .54515 .24406 Metetra
.654 .753 .922 r
.54515 .24406 .55288 .25363 .56744 .24846 .55977 .23884 Metetra
.654 .753 .922 r
.55977 .23884 .56744 .24846 .58208 .24326 .57446 .23358 Metetra
.654 .753 .922 r
.57446 .23358 .58208 .24326 .5968 .23803 .58922 .2283 Metetra
.654 .753 .922 r
.58922 .2283 .5968 .23803 .61159 .23277 .60407 .223 Metetra
.654 .753 .922 r
.60407 .223 .61159 .23277 .62646 .22749 .61899 .21766 Metetra
.654 .753 .922 r
.61899 .21766 .62646 .22749 .64141 .22218 .634 .21229 Metetra
.654 .753 .922 r
.634 .21229 .64141 .22218 .65645 .21684 .64909 .2069 Metetra
.654 .753 .922 r
.64909 .2069 .65645 .21684 .67156 .21147 .66425 .20148 Metetra
.654 .753 .922 r
.66425 .20148 .67156 .21147 .68675 .20607 .6795 .19602 Metetra
.654 .753 .922 r
.6795 .19602 .68675 .20607 .70203 .20064 .69484 .19054 Metetra
.654 .753 .922 r
.69484 .19054 .70203 .20064 .71739 .19518 .71025 .18503 Metetra
.654 .753 .922 r
.71025 .18503 .71739 .19518 .73283 .1897 .72575 .17949 Metetra
.654 .753 .922 r
.04463 .41167 .05393 .41969 .06605 .41536 .05679 .4073 Metetra
.654 .753 .922 r
.05679 .4073 .06605 .41536 .07824 .411 .069 .40291 Metetra
.654 .753 .922 r
.069 .40291 .07824 .411 .09048 .40663 .08128 .39849 Metetra
.654 .753 .922 r
.08128 .39849 .09048 .40663 .10278 .40223 .09361 .39405 Metetra
.654 .753 .922 r
.09361 .39405 .10278 .40223 .11514 .39781 .106 .38959 Metetra
.654 .753 .922 r
.106 .38959 .11514 .39781 .12756 .39337 .11846 .38511 Metetra
.654 .753 .922 r
.11846 .38511 .12756 .39337 .14004 .3889 .13098 .38061 Metetra
.654 .753 .922 r
.13098 .38061 .14004 .3889 .15259 .38442 .14355 .37608 Metetra
.654 .753 .922 r
.14355 .37608 .15259 .38442 .16519 .37991 .15619 .37153 Metetra
.654 .753 .922 r
.15619 .37153 .16519 .37991 .17786 .37538 .1689 .36696 Metetra
.654 .753 .922 r
.1689 .36696 .17786 .37538 .19059 .37083 .18166 .36237 Metetra
.654 .753 .922 r
.18166 .36237 .19059 .37083 .20338 .36626 .19449 .35775 Metetra
.654 .753 .922 r
.19449 .35775 .20338 .36626 .21624 .36166 .20739 .35312 Metetra
.654 .753 .922 r
.20739 .35312 .21624 .36166 .22916 .35704 .22034 .34845 Metetra
.654 .753 .922 r
.22034 .34845 .22916 .35704 .24214 .3524 .23337 .34377 Metetra
.654 .753 .922 r
.23337 .34377 .24214 .3524 .25519 .34773 .24645 .33906 Metetra
.654 .753 .922 r
.24645 .33906 .25519 .34773 .26831 .34304 .25961 .33433 Metetra
.654 .753 .922 r
.25961 .33433 .26831 .34304 .28097 .34513 .27283 .32957 Metetra
.497 .545 .836 r
.27283 .32957 .28097 .34513 .29379 .34654 .28574 .3298 Metetra
.497 .528 .819 r
.28574 .3298 .29379 .34654 .3068 .34697 .29874 .3302 Metetra
.526 .545 .817 r
.29874 .3302 .3068 .34697 .31999 .34637 .31192 .32962 Metetra
.554 .561 .815 r
.31192 .32962 .31999 .34637 .33334 .34472 .32526 .32802 Metetra
.581 .576 .813 r
.32526 .32802 .33334 .34472 .34685 .34203 .33877 .32537 Metetra
.606 .59 .809 r
.33877 .32537 .34685 .34203 .36049 .33832 .35242 .32166 Metetra
.628 .602 .805 r
.35242 .32166 .36049 .33832 .37427 .33358 .3662 .31688 Metetra
.649 .613 .799 r
.3662 .31688 .37427 .33358 .38815 .32783 .38011 .31103 Metetra
.668 .621 .793 r
.38011 .31103 .38815 .32783 .40215 .32104 .39412 .3041 Metetra
.685 .628 .786 r
.39412 .3041 .40215 .32104 .41623 .31321 .40823 .2961 Metetra
.7 .633 .779 r
.40823 .2961 .41623 .31321 .43039 .3043 .42241 .28705 Metetra
.713 .638 .772 r
.42241 .28705 .43039 .3043 .44462 .29433 .43667 .27699 Metetra
.725 .643 .767 r
.43667 .27699 .44462 .29433 .4589 .28332 .45097 .26599 Metetra
.641 .603 .796 r
.45097 .26599 .4589 .28332 .47321 .27135 .46519 .26036 Metetra
.652 .715 .894 r
.46519 .26036 .47321 .27135 .48747 .26468 .47947 .25522 Metetra
.654 .753 .922 r
.47947 .25522 .48747 .26468 .50178 .25957 .49382 .25005 Metetra
.654 .753 .922 r
.49382 .25005 .50178 .25957 .51616 .25443 .50826 .24486 Metetra
.654 .753 .922 r
.50826 .24486 .51616 .25443 .53062 .24926 .52276 .23964 Metetra
.654 .753 .922 r
.52276 .23964 .53062 .24926 .54515 .24406 .53735 .23439 Metetra
.654 .753 .922 r
.53735 .23439 .54515 .24406 .55977 .23884 .55201 .22912 Metetra
.654 .753 .922 r
.55201 .22912 .55977 .23884 .57446 .23358 .56675 .22381 Metetra
.654 .753 .922 r
.56675 .22381 .57446 .23358 .58922 .2283 .58157 .21848 Metetra
.654 .753 .922 r
.58157 .21848 .58922 .2283 .60407 .223 .59647 .21312 Metetra
.654 .753 .922 r
.59647 .21312 .60407 .223 .61899 .21766 .61145 .20773 Metetra
.654 .753 .922 r
.61145 .20773 .61899 .21766 .634 .21229 .62651 .20231 Metetra
.654 .753 .922 r
.62651 .20231 .634 .21229 .64909 .2069 .64165 .19687 Metetra
.654 .753 .922 r
.64165 .19687 .64909 .2069 .66425 .20148 .65688 .19139 Metetra
.654 .753 .922 r
.65688 .19139 .66425 .20148 .6795 .19602 .67218 .18588 Metetra
.654 .753 .922 r
.67218 .18588 .6795 .19602 .69484 .19054 .68757 .18034 Metetra
.654 .753 .922 r
.68757 .18034 .69484 .19054 .71025 .18503 .70305 .17478 Metetra
.654 .753 .922 r
.70305 .17478 .71025 .18503 .72575 .17949 .71861 .16918 Metetra
.654 .753 .922 r
.03525 .40358 .04463 .41167 .05679 .4073 .04744 .39917 Metetra
.654 .753 .922 r
.04744 .39917 .05679 .4073 .069 .40291 .05969 .39474 Metetra
.654 .753 .922 r
.05969 .39474 .069 .40291 .08128 .39849 .07199 .39028 Metetra
.654 .753 .922 r
.07199 .39028 .08128 .39849 .09361 .39405 .08436 .3858 Metetra
.654 .753 .922 r
.08436 .3858 .09361 .39405 .106 .38959 .09679 .3813 Metetra
.654 .753 .922 r
.09679 .3813 .106 .38959 .11846 .38511 .10928 .37678 Metetra
.654 .753 .922 r
.10928 .37678 .11846 .38511 .13098 .38061 .12183 .37223 Metetra
.654 .753 .922 r
.12183 .37223 .13098 .38061 .14355 .37608 .13444 .36767 Metetra
.654 .753 .922 r
.13444 .36767 .14355 .37608 .15619 .37153 .14712 .36308 Metetra
.654 .753 .922 r
.14712 .36308 .15619 .37153 .1689 .36696 .15985 .35847 Metetra
.654 .753 .922 r
.15985 .35847 .1689 .36696 .18166 .36237 .17266 .35383 Metetra
.654 .753 .922 r
.17266 .35383 .18166 .36237 .19449 .35775 .18552 .34917 Metetra
.654 .753 .922 r
.18552 .34917 .19449 .35775 .20739 .35312 .19845 .34449 Metetra
.654 .753 .922 r
.19845 .34449 .20739 .35312 .22034 .34845 .21145 .33978 Metetra
.654 .753 .922 r
.21145 .33978 .22034 .34845 .23337 .34377 .22451 .33505 Metetra
.654 .753 .922 r
.22451 .33505 .23337 .34377 .24645 .33906 .23764 .3303 Metetra
.654 .753 .922 r
.23764 .3303 .24645 .33906 .25961 .33433 .25083 .32552 Metetra
.654 .753 .922 r
.25083 .32552 .25961 .33433 .27283 .32957 .26409 .32072 Metetra
.654 .753 .922 r
.26409 .32072 .27283 .32957 .28574 .3298 .27742 .3159 Metetra
.583 .618 .853 r
.27742 .3159 .28574 .3298 .29874 .3302 .29065 .31328 Metetra
.527 .544 .816 r
.29065 .31328 .29874 .3302 .31192 .32962 .30382 .31259 Metetra
.554 .558 .812 r
.30382 .31259 .31192 .32962 .32526 .32802 .31717 .31094 Metetra
.58 .572 .809 r
.31717 .31094 .32526 .32802 .33877 .32537 .33067 .30825 Metetra
.604 .584 .804 r
.33067 .30825 .33877 .32537 .35242 .32166 .34433 .3045 Metetra
.627 .596 .799 r
.34433 .3045 .35242 .32166 .3662 .31688 .35812 .29967 Metetra
.647 .606 .794 r
.35812 .29967 .3662 .31688 .38011 .31103 .37204 .29375 Metetra
.666 .615 .788 r
.37204 .29375 .38011 .31103 .39412 .3041 .38607 .28674 Metetra
.683 .623 .782 r
.38607 .28674 .39412 .3041 .40823 .2961 .40019 .27869 Metetra
.698 .63 .777 r
.40019 .27869 .40823 .2961 .42241 .28705 .4144 .26962 Metetra
.689 .626 .78 r
.4144 .26962 .42241 .28705 .43667 .27699 .42863 .26115 Metetra
.636 .622 .819 r
.42863 .26115 .43667 .27699 .45097 .26599 .44281 .25601 Metetra
.654 .74 .913 r
.44281 .25601 .45097 .26599 .46519 .26036 .45706 .25085 Metetra
.654 .753 .922 r
.45706 .25085 .46519 .26036 .47947 .25522 .47139 .24566 Metetra
.654 .753 .922 r
.47139 .24566 .47947 .25522 .49382 .25005 .48579 .24045 Metetra
.654 .753 .922 r
.48579 .24045 .49382 .25005 .50826 .24486 .50027 .2352 Metetra
.654 .753 .922 r
.50027 .2352 .50826 .24486 .52276 .23964 .51483 .22993 Metetra
.654 .753 .922 r
.51483 .22993 .52276 .23964 .53735 .23439 .52947 .22463 Metetra
.654 .753 .922 r
.52947 .22463 .53735 .23439 .55201 .22912 .54418 .2193 Metetra
.654 .753 .922 r
.54418 .2193 .55201 .22912 .56675 .22381 .55898 .21395 Metetra
.654 .753 .922 r
.55898 .21395 .56675 .22381 .58157 .21848 .57385 .20856 Metetra
.654 .753 .922 r
.57385 .20856 .58157 .21848 .59647 .21312 .5888 .20315 Metetra
.654 .753 .922 r
.5888 .20315 .59647 .21312 .61145 .20773 .60383 .19771 Metetra
.654 .753 .922 r
.60383 .19771 .61145 .20773 .62651 .20231 .61895 .19223 Metetra
.654 .753 .922 r
.61895 .19223 .62651 .20231 .64165 .19687 .63415 .18673 Metetra
.654 .753 .922 r
.63415 .18673 .64165 .19687 .65688 .19139 .64943 .1812 Metetra
.654 .753 .922 r
.64943 .1812 .65688 .19139 .67218 .18588 .66479 .17563 Metetra
.654 .753 .922 r
.66479 .17563 .67218 .18588 .68757 .18034 .68024 .17004 Metetra
.654 .753 .922 r
.68024 .17004 .68757 .18034 .70305 .17478 .69577 .16442 Metetra
.654 .753 .922 r
.69577 .16442 .70305 .17478 .71861 .16918 .71139 .15876 Metetra
.654 .753 .922 r
.02579 .39542 .03525 .40358 .04744 .39917 .038 .39097 Metetra
.654 .753 .922 r
.038 .39097 .04744 .39917 .05969 .39474 .05028 .38649 Metetra
.654 .753 .922 r
.05028 .38649 .05969 .39474 .07199 .39028 .06262 .382 Metetra
.654 .753 .922 r
.06262 .382 .07199 .39028 .08436 .3858 .07502 .37748 Metetra
.654 .753 .922 r
.07502 .37748 .08436 .3858 .09679 .3813 .08749 .37294 Metetra
.654 .753 .922 r
.08749 .37294 .09679 .3813 .10928 .37678 .10001 .36837 Metetra
.654 .753 .922 r
.10001 .36837 .10928 .37678 .12183 .37223 .11259 .36379 Metetra
.654 .753 .922 r
.11259 .36379 .12183 .37223 .13444 .36767 .12524 .35918 Metetra
.654 .753 .922 r
.12524 .35918 .13444 .36767 .14712 .36308 .13795 .35454 Metetra
.654 .753 .922 r
.13795 .35454 .14712 .36308 .15985 .35847 .15073 .34989 Metetra
.654 .753 .922 r
.15073 .34989 .15985 .35847 .17266 .35383 .16357 .34521 Metetra
.654 .753 .922 r
.16357 .34521 .17266 .35383 .18552 .34917 .17647 .34051 Metetra
.654 .753 .922 r
.17647 .34051 .18552 .34917 .19845 .34449 .18944 .33578 Metetra
.654 .753 .922 r
.18944 .33578 .19845 .34449 .21145 .33978 .20247 .33103 Metetra
.654 .753 .922 r
.20247 .33103 .21145 .33978 .22451 .33505 .21557 .32626 Metetra
.654 .753 .922 r
.21557 .32626 .22451 .33505 .23764 .3303 .22873 .32146 Metetra
.654 .753 .922 r
.22873 .32146 .23764 .3303 .25083 .32552 .24197 .31664 Metetra
.654 .753 .922 r
.24197 .31664 .25083 .32552 .26409 .32072 .25527 .31179 Metetra
.654 .753 .922 r
.25527 .31179 .26409 .32072 .27742 .3159 .26864 .30692 Metetra
.654 .753 .922 r
.26864 .30692 .27742 .3159 .29065 .31328 .28207 .30203 Metetra
.65 .701 .883 r
.28207 .30203 .29065 .31328 .30382 .31259 .29558 .29711 Metetra
.599 .604 .828 r
.29558 .29711 .30382 .31259 .31717 .31094 .30904 .29372 Metetra
.581 .571 .808 r
.30904 .29372 .31717 .31094 .33067 .30825 .32255 .29093 Metetra
.604 .583 .803 r
.32255 .29093 .33067 .30825 .34433 .3045 .33622 .2871 Metetra
.626 .594 .797 r
.33622 .2871 .34433 .3045 .35812 .29967 .35002 .28221 Metetra
.646 .604 .792 r
.35002 .28221 .35812 .29967 .37204 .29375 .36395 .27625 Metetra
.665 .613 .787 r
.36395 .27625 .37204 .29375 .38607 .28674 .37799 .26923 Metetra
.669 .615 .786 r
.37799 .26923 .38607 .28674 .40019 .27869 .3921 .26193 Metetra
.632 .607 .807 r
.3921 .26193 .40019 .27869 .4144 .26962 .40617 .2568 Metetra
.647 .677 .865 r
.40617 .2568 .4144 .26962 .42863 .26115 .42033 .25165 Metetra
.654 .753 .922 r
.42033 .25165 .42863 .26115 .44281 .25601 .43455 .24646 Metetra
.654 .753 .922 r
.43455 .24646 .44281 .25601 .45706 .25085 .44885 .24125 Metetra
.654 .753 .922 r
.44885 .24125 .45706 .25085 .47139 .24566 .46323 .23601 Metetra
.654 .753 .922 r
.46323 .23601 .47139 .24566 .48579 .24045 .47768 .23074 Metetra
.654 .753 .922 r
.47768 .23074 .48579 .24045 .50027 .2352 .49221 .22545 Metetra
.654 .753 .922 r
.49221 .22545 .50027 .2352 .51483 .22993 .50682 .22013 Metetra
.654 .753 .922 r
.50682 .22013 .51483 .22993 .52947 .22463 .52151 .21477 Metetra
.654 .753 .922 r
.52151 .21477 .52947 .22463 .54418 .2193 .53628 .20939 Metetra
.654 .753 .922 r
.53628 .20939 .54418 .2193 .55898 .21395 .55112 .20398 Metetra
.654 .753 .922 r
.55112 .20398 .55898 .21395 .57385 .20856 .56605 .19854 Metetra
.654 .753 .922 r
.56605 .19854 .57385 .20856 .5888 .20315 .58105 .19308 Metetra
.654 .753 .922 r
.58105 .19308 .5888 .20315 .60383 .19771 .59614 .18758 Metetra
.654 .753 .922 r
.59614 .18758 .60383 .19771 .61895 .19223 .61131 .18205 Metetra
.654 .753 .922 r
.61131 .18205 .61895 .19223 .63415 .18673 .62656 .17649 Metetra
.654 .753 .922 r
.62656 .17649 .63415 .18673 .64943 .1812 .6419 .1709 Metetra
.654 .753 .922 r
.6419 .1709 .64943 .1812 .66479 .17563 .65732 .16528 Metetra
.654 .753 .922 r
.65732 .16528 .66479 .17563 .68024 .17004 .67283 .15963 Metetra
.654 .753 .922 r
.67283 .15963 .68024 .17004 .69577 .16442 .68842 .15395 Metetra
.654 .753 .922 r
.68842 .15395 .69577 .16442 .71139 .15876 .70409 .14824 Metetra
.654 .753 .922 r
.01623 .38718 .02579 .39542 .038 .39097 .02849 .38269 Metetra
.654 .753 .922 r
.02849 .38269 .038 .39097 .05028 .38649 .0408 .37817 Metetra
.654 .753 .922 r
.0408 .37817 .05028 .38649 .06262 .382 .05317 .37364 Metetra
.654 .753 .922 r
.05317 .37364 .06262 .382 .07502 .37748 .0656 .36908 Metetra
.654 .753 .922 r
.0656 .36908 .07502 .37748 .08749 .37294 .0781 .36449 Metetra
.654 .753 .922 r
.0781 .36449 .08749 .37294 .10001 .36837 .09066 .35989 Metetra
.654 .753 .922 r
.09066 .35989 .10001 .36837 .11259 .36379 .10328 .35526 Metetra
.654 .753 .922 r
.10328 .35526 .11259 .36379 .12524 .35918 .11596 .35061 Metetra
.654 .753 .922 r
.11596 .35061 .12524 .35918 .13795 .35454 .12871 .34593 Metetra
.654 .753 .922 r
.12871 .34593 .13795 .35454 .15073 .34989 .14152 .34123 Metetra
.654 .753 .922 r
.14152 .34123 .15073 .34989 .16357 .34521 .15439 .33651 Metetra
.654 .753 .922 r
.15439 .33651 .16357 .34521 .17647 .34051 .16733 .33177 Metetra
.654 .753 .922 r
.16733 .33177 .17647 .34051 .18944 .33578 .18034 .327 Metetra
.654 .753 .922 r
.18034 .327 .18944 .33578 .20247 .33103 .19341 .3222 Metetra
.654 .753 .922 r
.19341 .3222 .20247 .33103 .21557 .32626 .20654 .31738 Metetra
.654 .753 .922 r
.20654 .31738 .21557 .32626 .22873 .32146 .21975 .31254 Metetra
.654 .753 .922 r
.21975 .31254 .22873 .32146 .24197 .31664 .23302 .30767 Metetra
.654 .753 .922 r
.23302 .30767 .24197 .31664 .25527 .31179 .24636 .30278 Metetra
.654 .753 .922 r
.24636 .30278 .25527 .31179 .26864 .30692 .25977 .29786 Metetra
.654 .753 .922 r
.25977 .29786 .26864 .30692 .28207 .30203 .27325 .29292 Metetra
.654 .753 .922 r
.27325 .29292 .28207 .30203 .29558 .29711 .28679 .28795 Metetra
.654 .753 .922 r
.28679 .28795 .29558 .29711 .30904 .29372 .30041 .28296 Metetra
.652 .716 .895 r
.30041 .28296 .30904 .29372 .32255 .29093 .3141 .27794 Metetra
.645 .67 .859 r
.3141 .27794 .32255 .29093 .33622 .2871 .32786 .27289 Metetra
.641 .648 .841 r
.32786 .27289 .33622 .2871 .35002 .28221 .34169 .26782 Metetra
.641 .645 .839 r
.34169 .26782 .35002 .28221 .36395 .27625 .35559 .26272 Metetra
.644 .662 .853 r
.35559 .26272 .36395 .27625 .37799 .26923 .36957 .25759 Metetra
.65 .702 .884 r
.36957 .25759 .37799 .26923 .3921 .26193 .38362 .25244 Metetra
.654 .753 .922 r
.38362 .25244 .3921 .26193 .40617 .2568 .39774 .24726 Metetra
.654 .753 .922 r
.39774 .24726 .40617 .2568 .42033 .25165 .41194 .24205 Metetra
.654 .753 .922 r
.41194 .24205 .42033 .25165 .43455 .24646 .42622 .23682 Metetra
.654 .753 .922 r
.42622 .23682 .43455 .24646 .44885 .24125 .44057 .23156 Metetra
.654 .753 .922 r
.44057 .23156 .44885 .24125 .46323 .23601 .45499 .22627 Metetra
.654 .753 .922 r
.45499 .22627 .46323 .23601 .47768 .23074 .46949 .22095 Metetra
.654 .753 .922 r
.46949 .22095 .47768 .23074 .49221 .22545 .48408 .2156 Metetra
.654 .753 .922 r
.48408 .2156 .49221 .22545 .50682 .22013 .49873 .21022 Metetra
.654 .753 .922 r
.49873 .21022 .50682 .22013 .52151 .21477 .51347 .20482 Metetra
.654 .753 .922 r
.51347 .20482 .52151 .21477 .53628 .20939 .52829 .19938 Metetra
.654 .753 .922 r
.52829 .19938 .53628 .20939 .55112 .20398 .54319 .19392 Metetra
.654 .753 .922 r
.54319 .19392 .55112 .20398 .56605 .19854 .55817 .18843 Metetra
.654 .753 .922 r
.55817 .18843 .56605 .19854 .58105 .19308 .57323 .1829 Metetra
.654 .753 .922 r
.57323 .1829 .58105 .19308 .59614 .18758 .58837 .17735 Metetra
.654 .753 .922 r
.58837 .17735 .59614 .18758 .61131 .18205 .60359 .17176 Metetra
.654 .753 .922 r
.60359 .17176 .61131 .18205 .62656 .17649 .6189 .16615 Metetra
.654 .753 .922 r
.6189 .16615 .62656 .17649 .6419 .1709 .6343 .1605 Metetra
.654 .753 .922 r
.6343 .1605 .6419 .1709 .65732 .16528 .64977 .15483 Metetra
.654 .753 .922 r
.64977 .15483 .65732 .16528 .67283 .15963 .66534 .14912 Metetra
.654 .753 .922 r
.66534 .14912 .67283 .15963 .68842 .15395 .68099 .14338 Metetra
.654 .753 .922 r
.68099 .14338 .68842 .15395 .70409 .14824 .69672 .13761 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.04003 .25401 m
.04482 .2585 L
s
[(-1)] .03045 .24505 1 .93576 Mshowa
.18786 .19613 m
.19242 .20085 L
s
[(-0.5)] .17875 .18668 .96492 1 Mshowa
.34468 .13472 m
.34896 .13969 L
s
[(0)] .33612 .12478 .8612 1 Mshowa
.51132 .06947 m
.51528 .0747 L
s
[(0.5)] .5034 .05901 .75747 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06892 .2427 m
.07176 .24542 L
s
.09814 .23126 m
.10096 .23401 L
s
.1277 .21969 m
.13049 .22246 L
s
.1576 .20797 m
.16037 .21078 L
s
.21848 .18414 m
.22119 .187 L
s
.24947 .172 m
.25214 .1749 L
s
.28082 .15973 m
.28346 .16265 L
s
.31256 .1473 m
.31516 .15025 L
s
.37719 .12199 m
.37973 .125 L
s
.41011 .1091 m
.4126 .11215 L
s
.44343 .09606 m
.44588 .09913 L
s
.47716 .08285 m
.47958 .08595 L
s
.54591 .05593 m
.54824 .0591 L
s
.58094 .04221 m
.58323 .04541 L
s
.61641 .02832 m
.61866 .03155 L
s
.65234 .01425 m
.65454 .01752 L
s
gsave
.29165 .07573 -70.3112 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00o?ooool4o`000003oa0@4?oooooooooo06Gooooo
003nooooo`03o`000?oooooooooo06Oooooo003nooooo`03o`000?oooooooooo06Oooooo003noooo
o`03o`000?oooooooooo06Oooooo003nooooo`03o`000?oooooooooo06Oooooo003nooooo`03o`00
0?oooooooooo06Oooooo003nooooo`03o`000?oooooooooo06Oooooo003looooo`03oeEEEOmVIVKo
000000[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Jooooo`00ooooool:ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0F_ooool00?oooooo2_ooool01Ol@413ooooooooooooooooo410@05[ooooo003o
ooooo`[ooooo00Go0000ooooooooooooooooo`00001Jooooo`00ooooool:ooooo`05o`000?oooooo
ooooooooool00000F_ooool00?oooooo0oooool2o`0000Gooooo00Go410@oooooooooooooooooa0@
401Jooooo`00ooooool3o`000003ooooool0003o000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`1Jooooo`00oOooool2o`0000?ooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0F_oo
ool00?[ooooo0ol00006ooooo`03o`000?oooooo000006;ooooo003gooooo`?o00002Oooool00ol0
003oooooo`00001Rooooo`00mOooool2o`000003ooooool0003ooooo00Wooooo00Co0000oooooooo
oooo0000HOooool00?;ooooo0ol00004ooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooo
ooooooooo`00001Pooooo`00l?ooool2o`00017ooooo00Go0000ooooooooooooooooo`00001Poooo
o`00kOooool3o`0001?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Mooooo`00
joooool2o`0001Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Looooo`00]?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd07_ooool3o`0000;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo05cooooo002dooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool06oooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1Kooooo`00]?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooooooo
ool05oooool3o`0001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Jooooo`00
]?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool05Oooool3o`00027o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Jooooo`00]?ooool01Ol0003ooooo
oooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Dooooo`;o00000_ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo0ol0001Jooooo`00]?ooool01Ol@413o
oooooooooooooooo410@00cooooo00?o0000ooooooooool04oooool3o`0002Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1Hooooo`00OOooool2o`0000;ooooo0_l0000aooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`;o0000:Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo05Sooooo001mooooo`06onk^k_lQ8B7oQhN7okZj
^_l0003ogMgM<Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000=ooooo`?o0000:ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Oooooo001nooooo`04omgMgOl0003o
410@olc<c5;ooooo0ol0000]ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Eooo
ool007kooooo00Cok^k^ob4Q8Ol@413ok^k^Coooool3o`0000?ooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Kooooo001nooooo`04ob4Q8OmgMgOo
MgMgoc8b<Tgooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0EOoo
ool007gooooo0_l00002ooooo`;o0000BOooool3o`0003Gooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`1Eooooo`00bOooool3o`0003Sooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`1Dooooo`00aoooool2o`0000;ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo05?ooooo0034ooooo`?o00001Oooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Doooool00<;ooooo0_l0
0011ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0D_ooool00;oooooo0ol00013
ooooo`03o`000?oooooooooo00cooooo0_l0001Booooo`00_Oooool2o`0000;ooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`0;ooooo`;o0000Doooool00;[ooooo0ol00018ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0D?ooool00;Sooooo0_l0001;ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0Coooool00;Gooooo0ol0001=ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0Coooool008gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Pooooo`Co0000Coooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04kooooo002=
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool2o`0000Cooooo00?o0000ooooooooool0C?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04gooooo002=ooooo`05oa0@4?oooooo
ooooooooool@41006oooool3o`0005Gooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`1=ooooo`00SOooool01Ol0003ooooooooooooooooo000001Wooooo0_l0001Hooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0C?ooool008gooooo00Go0000ooooooooooooooooo`00
000Fooooo`Co0000FOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo002=
ooooo`05oa0@4?ooooooooooooooool@41005?ooool2o`0000?ooooo00?o0000ooooooooool0Eooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo002=ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04Oooool3o`0005oooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`1:ooooo`00SOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00oooooo0_l0001Rooooo`03o`000?oo
oooooooo01?ooooo0_l0001;ooooo`00W_ooool3o`0006Cooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`19ooooo`00Voooool3o`0000?ooooo00?o0000ooooooooool0H_ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo04Sooooo002Iooooo`;o0000Joooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo04Oooooo002Fooooo`?o0000KOooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo04Oooooo002Dooooo`?o0000Koooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04Kooooo002Aooooo`?o00000oooool00ol0003oooooooooo`1[
ooooo`;o00006Oooool00ol0003oooooooooo`15ooooo`00Soooool2o`00077ooooo0ol000000onW
`>co0000ooooo`0Hooooo`03o`000?oooooooooo04Gooooo002<ooooo`?o0000L?ooool3o`0000Co
Yl3/0_l0000Iooooo`03o`000?oooooooooo04Cooooo002:ooooo`?o0000K_ooool4o`0000;oYl3/
00?o0000ojO0k?nW`>`00_nW`>`3o`0001Wooooo00?o0000ooooooooool0@oooool008Oooooo0ol0
0002ooooo`03o`000?oooooooooo06Wooooo0ol000000onW`>co0000ojO0k004ojO0k003o`000?nW
`>co000000;o000000?oYl3/o`000?ooool06?ooool00ol0003oooooooooo`13ooooo`00Q?ooool3
o`0006oooooo0_l00005ojO0k003o`000?nW`>coYl3/00;oYl3/0_l00002ojO0k004o`000?nW`>co
Yl3/o`0001Wooooo0_l00013ooooo`00Boooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd08Oooool2o`0006oooooo0ol000000onW`>co0000
ojO0k004ojO0k003o`000?nW`>co000000;o00000_nW`>`00ol0003oYl3/o`000003ojO0k003o`00
0?oooooooooo01Gooooo00?o0000ooooool00000@oooool004_ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Mooooo`Co0000K_ooool2o`0000GoYl3/
00?o0000ojO0k?nW`>`00_nW`>`2o`0000KoYl3/0_l00002ojO0k0?o00006?ooool00ol0003ooooo
ooooo`11ooooo`00@oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo01[ooooo0_l00003ooooo`03o`000?oooooooooo06Wooooo0ol000000onW`>co0000
ojO0k004ojO0k003o`000?nW`>co000000;o00000_nW`>`00ol0003oYl3/ojO0k003ojO0k0Co0000
0_nW`>`00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo043ooooo001;ooooo`05o`000?oo
ooooooooooooool000003oooool00omgMgOo<S8booooo`0Hooooo`?o0000Koooool2o`0000GoYl3/
00Co0000ojO0k?nW`>coYl3/0ol00006ojO0k003o`000?nW`>co000000;o000000?oYl3/o`000?nW
`>`01?nW`>`00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo043ooooo001;ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Oooooo0_l0001_oooo
o`?o00000_nW`>`00ol0003oYl3/ojO0k002ojO0k0Co00000onW`>`00ol0003oYl3/ojO0k003ojO0
k0;o00001?nW`>`2o`0000CoYl3/0_l0000Hooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM02;ooooo001;
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Fooooo`Co0000KOoo
ool3o`0000KoYl3/00Ko0000ojO0k?l0003o0000ojO0k?l00006ojO0k003o`000?nW`>co000000;o
000000?oYl3/o`000?nW`>`00onW`>`2o`000006ojO0k?l0003o0000o`000?nW`>co00006Oooool0
0ol0003oooooooooo`06ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool08Oooool004_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oo
oooooooo01Cooooo0_l00003ooooo`03o`000?oooooooooo06Oooooo1?l00003ojO0k003o`000?nW
`>coYl3/00?oYl3/0_l00004ojO0k003o`000?nW`>coYl3/00?oYl3/0_l00005ojO0k004o`000?nW
`>coYl3/ojO0k0?o00001OnW`>`00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo
00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo023ooooo001;ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo0ol0001]ooooo`;o000000?oYl3/o`000?nW
`>`01OnW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003oYl3/00CoYl3/00?o0000ojO0k?l0
00000_l000000onW`>co0000ojO0k004ojO0k0Co000000?oYl3/o`000?l000001OnW`>`2o`0001So
oooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b
<_ooool08Oooool006gooooo0ol0001^ooooo`;o00001?nW`>`00ol0003oYl3/ojO0k003ojO0k0;o
00001OnW`>`01?l0003oYl3/ojO0k?nW`>`3o`0000GoYl3/00?o0000ojO0k?l000000_l000000onW
`>co0000ojO0k002ojO0k004o`000?nW`>co0000ojO0k0?o000000?oYl3/o`000?ooool06?ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<02;ooooo001[ooooo`;o000000?oooooo`000?ooool0Joooool3o`000003ojO0k?l0
003oYl3/00CoYl3/00?o0000ojO0k?l000000_l000000onW`>co0000ojO0k004ojO0k0Co00000_nW
`>`00ol0003oYl3/ojO0k003ojO0k0;o00001OnW`>`01Ol0003oYl3/ojO0k?l0003oYl3/00;o0000
1OnW`>`00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo02Cooooo001Xooooo`?o00001?ooool00ol0003ooooo
ooooo`1Wooooo`;o00001OnW`>`01?l0003oYl3/ojO0k?nW`>`3o`0000GoYl3/00?o0000ojO0k?l0
00000_l000000onW`>co0000ojO0k004ojO0k003o`000?nW`>co000000;o000000?oYl3/o`000?nW
`>`01?nW`>`00ol0003oYl3/o`000002o`0000;oYl3/00?o0000ojO0k?nW`>`00_nW`>`2o`0001So
oooo0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Toooo
o`00I_ooool2o`0006kooooo0ol000000onW`>co0000ojO0k004ojO0k0Co00000_nW`>`00ol0003o
Yl3/ojO0k003ojO0k0;o00001OnW`>`00ol0003oYl3/ojO0k002ojO0k0;o00001OnW`>`01?l0003o
Yl3/ojO0k?nW`>`3o`000003ojO0k?l0003oYl3/00?oYl3/00Ko0000ojO0k?l0003o0000ojO0k?l0
000Gooooo`03o`000?oooooo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000
2_ooool3o`000003oa0@4?oooooooooo01?ooooo001Sooooo`?o0000KOooool3o`0000GoYl3/00?o
0000ojO0k?l000000_l000000onW`>co0000ojO0k004ojO0k003o`000?nW`>co000000;o00000_nW
`>`00ol0003oYl3/ojO0k002ojO0k003o`000?nW`>co000000;o00000_nW`>`00ol0003oYl3/ojO0
k002ojO0k0Co00000onW`>`2o`0000CoYl3/0_l00004ojO0k003o`000?oooooooooo01Kooooo00?o
0000ooooooooool08oooool00ol@413o^[Zjooooo`0Dooooo`00HOooool2o`000003ooooool0003o
oooo06Wooooo1?l00003ojO0k003o`000?nW`>coYl3/00;oYl3/0_l00005ojO0k003o`000?nW`>co
Yl3/00;oYl3/0_l00006ojO0k003o`000?nW`>coYl3/00?o00001_nW`>`01_l0003oYl3/o`000?l0
003oYl3/o`0000KoYl3/00?o0000ojO0k?l000000_l000000onW`>co0000ojO0k004ojO0k003o`00
0?oooooooooo01Kooooo00?o0000ooooooooool08_ooool00onHV9So<S8booooo`0Dooooo`00G_oo
ool3o`0000Cooooo00?o0000ooooooooool0IOooool2o`000003ojO0k?l0003oYl3/00GoYl3/00Co
0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k003ojO0k004o`000?nW`>co0000o`0000;o
Yl3/00?o0000ojO0k?nW`>`00onW`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`00onW`>`2o`0000Co
Yl3/00?o0000ojO0k?nW`>`00onW`>`2o`0000GoYl3/00Co0000ojO0k?nW`>coYl3/0ol0000Hoooo
o`03o`000?oooooooooo027ooooo00?ogMgMo`000?nj^[X05?ooool005cooooo0_l0001]ooooo`;o
00001?nW`>`00ol0003oYl3/ojO0k003ojO0k0;o00001OnW`>`01?l0003oYl3/ojO0k?nW`>`3o`00
00GoYl3/00?o0000ojO0k?l000000_l000000onW`>co0000ojO0k004ojO0k003o`000?nW`>co0000
00;o000000?oYl3/o`000?nW`>`01?nW`>`00ol0003oYl3/o`000004o`0000GoYl3/1?l00002ojO0
k003o`000?oooooooooo01Kooooo00?o0000ooooooooool08Oooool00omEEEGoMgMgodA4A00Doooo
o`00FOooool3o`0006cooooo0ol000000onW`>co0000ojO0k004ojO0k003o`000?nW`>co000000;o
000000?oYl3/o`000?nW`>`01?nW`>`4o`0000;oYl3/00?o0000ojO0k?nW`>`00onW`>`2o`0000Go
Yl3/00?o0000ojO0k?nW`>`00_nW`>`2o`0000GoYl3/00Co0000ojO0k?nW`>coYl3/0ol00003ojO0
k004o`000?nW`>co0000ojO0k0?o000000?oYl3/o`000?nW`>`01?nW`>`00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo01oooooo00GogMgMoa0@4?oooooo8B4QomgMg@0Cooooo`00E_ooool3
o`0000;ooooo00?o0000ooooooooool0J?ooool2o`0000GoYl3/00Co0000ojO0k?nW`>coYl3/0ol0
0005ojO0k003o`000?nW`>co000000;o000000?oYl3/o`000?nW`>`01?nW`>`00ol0003oYl3/o`00
0002o`000003ojO0k?l0003oYl3/00CoYl3/00?o0000ojO0k?l000000_l000000onW`>co0000ojO0
k004ojO0k0Co00000_nW`>`01_l0003oYl3/ojO0k?nW`>co0000ojO0k0;o00001OnW`>`00ol0003o
Yl3/ojO0k002ojO0k0;o00006?ooool00ol0003oooooooooo`0Nooooo`05ofIVI_n7QhOooooooiRH
V?mEEED04oooool005Cooooo0_l0001]ooooo`?o000000?oYl3/o`000?nW`>`01?nW`>`4o`0000;o
Yl3/00?o0000ojO0k?nW`>`00onW`>`2o`0000GoYl3/00?o0000ojO0k?nW`>`00_nW`>`2o`0000Go
Yl3/00Co0000ojO0k?nW`>coYl3/0ol00005ojO0k003o`000?nW`>co000000;o000000?oYl3/o`00
0?nW`>`01?nW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003oYl3/00CoYl3/00?o0000ojO0
k?l000000_l000000onW`>co0000ooooo`0Gooooo`03o`000?oooooooooo01gooooo00?ok^k^o`00
0?o^k^h00_ooool00ol0003ogMgMooooo`0Aooooo`00;?ooool4o`000003oa0@4?oooooooooo01ko
oooo0ol0001/ooooo`?o00001OnW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003oYl3/00Co
Yl3/00?o0000ojO0k?l000000_l00002ojO0k003o`000?nW`>coYl3/00;oYl3/00?o0000ojO0k?l0
00000_l000000onW`>co0000ojO0k004ojO0k0Co00000_nW`>`00ol0003oYl3/ojO0k003ojO0k0;o
00001OnW`>`01?l0003oYl3/ojO0k?nW`>`3o`000003ojO0k?l0003oYl3/00;oYl3/00Co0000ojO0
k?nW`>coYl3/0ol00005ojO0k003o`000?oooooooooo01Kooooo00?o0000ooooooooool07?ooool0
1?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo013ooooo000^ooooo`03o`000?oooooo
oooo01kooooo0ol0001[ooooo`?o00000onW`>`00ol0003oYl3/ojO0k002ojO0k0;o00001OnW`>`0
0ol0003oYl3/ojO0k002ojO0k0;o00001_nW`>`00ol0003oYl3/ojO0k003o`0000GoYl3/00?o0000
ojO0k?l000000_l00002ojO0k003o`000?nW`>coYl3/00;oYl3/00?o0000ojO0k?l000000_l00000
0onW`>co0000ojO0k004ojO0k0Co00000_nW`>`00ol0003oYl3/o`000003ojO0k0Co00000_nW`>`0
0ol0003oYl3/ojO0k003ojO0k0;o00006?ooool00ol0003oooooooooo`0dooooo`008oooool6o`00
00Gooooo00?o0000ooooooooool06oooool3o`0000?ooooo00?o0000ooooooooool0IOooool3o`00
0003ojO0k?l0003oYl3/00CoYl3/00Co0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k003
ojO0k004o`000?nW`>co0000o`0000;oYl3/00?o0000ojO0k?nW`>`00onW`>`3o`0000?oYl3/00?o
0000ojO0k?nW`>`00_nW`>`2o`0000KoYl3/00?o0000ojO0k?nW`>`00ol00005ojO0k003o`000?nW
`>co000000;o000000?oYl3/o`000?nW`>`01?nW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0
003oYl3/00CoYl3/00?o0000ojO0k?l000000_l000000onW`>co0000ooooo`0Gooooo`;o0000=Ooo
ool002kooooo00?o0000ooooooooool06Oooool2o`0006cooooo0_l00005ojO0k004o`000?nW`>co
Yl3/ojO0k0?o00001OnW`>`01?l0003oYl3/ojO0k?nW`>`3o`0000GoYl3/00?o0000ojO0k?l00000
0_l000000onW`>co0000ojO0k004ojO0k004o`000?nW`>co0000o`0000;oYl3/00?o0000ojO0k?nW
`>`00onW`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`00_nW`>`2o`0000GoYl3/00?o0000ojO0k?nW
`>`00_nW`>`3o`0000CoYl3/00Co0000ojO0k?nW`>coYl3/0ol00005ojO0k003o`000?oooooooooo
01Kooooo00?o0000ooooooooool0<oooool002kooooo00?o0000ooooooooool05_ooool3o`0006_o
oooo0ol00002ojO0k003o`000?nW`>coYl3/00;oYl3/1?l00002ojO0k003o`000?nW`>coYl3/00?o
Yl3/1?l00002ojO0k003o`000?nW`>coYl3/00?oYl3/0_l00005ojO0k004o`000?nW`>coYl3/ojO0
k0?o00001OnW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003oYl3/00CoYl3/00Co0000ojO0
k?l0003o00000_nW`>`00ol0003oYl3/ojO0k003ojO0k004o`000?nW`>co0000o`0000;oYl3/00?o
0000ojO0k?nW`>`00_nW`>`4o`0000;oYl3/00?o0000ojO0k?nW`>`00onW`>`2o`0001Sooooo00?o
0000ooooooooool0<_ooool002kooooo00?o0000ooooooooool05?ooool4o`0006Wooooo0ol00006
ojO0k006o`000?nW`>co0000o`000?nW`>co00001OnW`>`00ol0003oYl3/o`000002o`0000;oYl3/
00?o0000ojO0k?nW`>`00_nW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003oYl3/00CoYl3/
1?l00002ojO0k003o`000?nW`>coYl3/00?oYl3/0_l00005ojO0k003o`000?nW`>coYl3/00;oYl3/
0_l00005ojO0k004o`000?nW`>coYl3/ojO0k0?o00001?nW`>`2o`000003ojO0k?l0003o000000;o
Yl3/00?o0000ojO0k?nW`>`00_nW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003ooooo01Oo
oooo00?o0000ooooooooool0<_ooool002kooooo00?o0000ooooooooool04Oooool3o`0006[ooooo
0ol00003ojO0k003o`000?nW`>coYl3/00?oYl3/0_l00004ojO0k003o`000?nW`>coYl3/00;oYl3/
0_l00006ojO0k003o`000?nW`>coYl3/00?o00001OnW`>`00ol0003oYl3/o`000002o`000003ojO0
k?l0003oYl3/00CoYl3/00?o0000ojO0k?l000000_l000000onW`>co0000ojO0k004ojO0k003o`00
0?nW`>co000000;o000000?oYl3/o`000?nW`>`01?nW`>`4o`0000;oYl3/00?o0000ojO0k?nW`>`0
0_nW`>`3o`0000GoYl3/00?o0000ojO0k?nW`>`00ol00005ojO0k003o`000?oooooooooo01Kooooo
00?o0000ooooooooool0<Oooool002cooooo00?oEEEEofIVI_l000004?ooool3o`0006[ooooo0ol0
00000onW`>co0000ojO0k004ojO0k003o`000?nW`>co000000;o000000?oYl3/o`000?nW`>`01?nW
`>`01?l0003oYl3/o`000?l00002ojO0k003o`000?nW`>coYl3/00?oYl3/0ol00003ojO0k003o`00
0?nW`>coYl3/00;oYl3/0_l00005ojO0k004o`000?nW`>coYl3/ojO0k0?o00001OnW`>`01?l0003o
Yl3/ojO0k?nW`>`3o`0000GoYl3/00?o0000ojO0k?l000000_l000000onW`>co0000ojO0k004ojO0
k003o`000?nW`>co000000;o000000?oYl3/o`000?nW`>`01?nW`>`3o`0000?oYl3/00?o0000ojO0
k?nW`>`00_nW`>`2o`0001Sooooo00?o0000ooooooooool0<?ooool003gooooo0_l0001[ooooo`;o
00001OnW`>`01?l0003oYl3/ojO0k?nW`>`3o`0000GoYl3/00Co0000ojO0k?nW`>coYl3/0ol00005
ojO0k003o`000?nW`>co000000;o000000?oYl3/o`000?nW`>`01?nW`>`01?l0003oYl3/o`000?l0
0002ojO0k003o`000?nW`>coYl3/00;oYl3/1?l00003ojO0k003o`000?nW`>coYl3/00;oYl3/1?l0
0002ojO0k003o`000?nW`>coYl3/00?oYl3/0_l00005ojO0k004o`000?nW`>coYl3/ojO0k0?o0000
0_nW`>`01Ol0003oYl3/ojO0k?l0003oYl3/00?o000000?oYl3/o`000?nW`>`01?nW`>`01_l0003o
Yl3/o`000?l0003oYl3/o`0001Sooooo00?o0000ooooooooool0<?ooool003[ooooo0ol00002oooo
o`03o`000?oooooooooo06Kooooo0_l00002ojO0k003o`000?nW`>coYl3/00;oYl3/1?l00003ojO0
k003o`000?nW`>coYl3/00;oYl3/1?l00002ojO0k003o`000?nW`>coYl3/00?oYl3/0_l00005ojO0
k004o`000?nW`>coYl3/ojO0k0?o00001OnW`>`01?l0003oYl3/o`000?l00002ojO0k003o`000?nW
`>coYl3/00?oYl3/00Co0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k002ojO0k003o`00
0?nW`>co000000;o000000?oYl3/o`000?nW`>`01?nW`>`4o`0000;oYl3/00Co0000ojO0k?l0003o
00000_nW`>`2o`0000GoYl3/00Co0000ojO0k?nW`>coYl3/0ol00004ojO0k003o`000?oooooooooo
01Kooooo00?o0000ooooooooool0;oooool003Sooooo0_l0001[ooooo`?o00001OnW`>`01_l0003o
Yl3/o`000?l0003oYl3/o`0000KoYl3/00Co0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0
k002ojO0k003o`000?nW`>co000000;o000000?oYl3/o`000?nW`>`01?nW`>`4o`0000;oYl3/00?o
0000ojO0k?nW`>`00onW`>`2o`0000GoYl3/00Co0000ojO0k?nW`>coYl3/0ol00005ojO0k003o`00
0?nW`>coYl3/00?o00001OnW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003oYl3/00;oYl3/
0ol000001_nW`>co0000o`000?l0003oYl3/o`0000GoYl3/1?l00002ojO0k003o`000?nW`>coYl3/
00;oYl3/0_l0000Hooooo`03o`000?oooooooooo02kooooo000eooooo`?o0000JOooool4o`0000;o
Yl3/00?o0000ojO0k?nW`>`00onW`>`2o`0000CoYl3/00?o0000ojO0k?nW`>`00onW`>`2o`0000Go
Yl3/00?o0000ojO0k?nW`>`00ol00005ojO0k003o`000?nW`>co000000;o00000_nW`>`00ol0003o
Yl3/ojO0k002ojO0k003o`000?nW`>co000000;o000000?oYl3/o`000?nW`>`01?nW`>`4o`0000;o
Yl3/00?o0000ojO0k?nW`>`00onW`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`00_nW`>`2o`0000Go
Yl3/0ol000001_nW`>co0000o`000?l0003oYl3/o`0000?oYl3/00?o0000ojO0k?l000000_l00000
0onW`>co0000ojO0k004ojO0k004o`000?nW`>co0000o`0000;oYl3/00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0^ooooo`00=?ooool2o`0006Wooooo0_l00002ojJchP03o`000?nW`>co
Yl3/00;oYl3/00?o0000ojO0k?l000000_l00002ojF]g@03o`000?nW`>coYl3/00;oYl3/00?o0000
ojO0k?l000000_l000000onW_NWo0000ojO0k004ojO0k0?o00000onW`>`00ol0003oYl3/ojO0k002
ojO0k0;o00001_nW`>`00ol0003oYl3/ojO0k003o`0000GoYl3/00?o0000ojO0k?l000000_l00000
0onW`>co0000ojO0k004ojO0k003o`000?nW`>co000000;o000000?oYl3/o`000?nW`>`01?nW`>`0
1?l0003oYl3/o`000?l00002ojO0k003o`000?nW`>co000000Ko00000_nW`>`01?l0003oYl3/ojO0
k?l00002ojO0k0;o00001OnW`>`00ol0003oYl3/ojO0k002ojO0k0;o00001OnW`>`00ol0003ooooo
ooooo`0Eooooo`;o0000;_ooool003Cooooo0ol0001Vooooo`;o00001OnV/n800ol0003oYl3/ojO0
k003o`0000KoYJgM00?o0000ojO0k?nW`>`00ol00005ojNmj@03o`000?nW`>co000000;o000000?o
Y[OTo`000?nW`>`01?nW`>`01?l0003oYl3/o`000?l00002ojO0k003o`000?nW`>coYl3/00?oYl3/
0ol00003ojO0k003o`000?nW`>coYl3/00;oYl3/0_l00005ojO0k003o`000?nW`>coYl3/00;oYl3/
0_l00005ojO0k004o`000?nW`>coYl3/ojO0k0?o00000onW`>`3o`000003ojO0k?l0003o000000;o
Yl3/00?o0000ojO0k?nW`>`00_nW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003oYl3/00Co
Yl3/00?o0000ojO0k?l000000_l000000onW`>co0000ojO0k004ojO0k0;o00005Oooool00ol0003o
ooooo`00000^ooooo`00=?ooool01?l0003oooooooooool0001Rooooo`?o000000?oY:WJo`000?nV
/n801?nV/n83o`0000;oXI_>00?o0000ojF]gOnU[Md01?nU[Md3o`0000?oXYoA00?o0000ojNmjOnW
_NT00_nW_NT2o`0000GoY[OT00Co0000ojO0k?nW`>coYl3/0ol00005ojO0k003o`000?nW`>co0000
00;o000000?oYl3/o`000?nW`>`01?nW`>`01?l0003oYl3/o`000?l00002ojO0k003o`000?nW`>co
Yl3/00;oYl3/00?o0000ojO0k?l000000_l000000onW`>co0000ojO0k004ojO0k0Co00000_nW`>`4
o`0000;oYl3/0_l00005ojO0k003o`000?nW`>coYl3/00?o000000?oYl3/o`000?nW`>`00_nW`>`0
1?l0003oYl3/ojO0k?nW`>`3o`0000GoYl3/00?o0000ojO0k?l000000_l000000onW`>co0000oooo
o`0Fooooo`03o`000?oooooooooo02cooooo000dooooo`05o`000?ooooooooooooooool00000G_oo
ool3o`0000GoY:WJ00?o0000ojJch_nV/n800_l000000on[WLWo0000oj6KcP03oj6KcP04o`000?nU
[MgoYJgMojF]g@;o000000?o/:37o`000?nRWm401?nRWm401?l0003oYkgYo`000?l00002ojBJb`03
o`000?nV]nCoY[OT00;oY[OT1?l00002ojJfi003o`000?nW`>coYl3/00?oYl3/0_l00005ojO0k004
o`000?nW`>coYl3/ojO0k0?o00001OnW`>`00ol0003oYl3/ojO0k003o`0000GoYl3/00?o0000ojO0
k?l000000_l000001?nW`>co0000ojO0k?nW`>`4o`000006ojO0k?l0003o0000o`000?nW`>co0000
1OnW`>`3o`0000;oYl3/00Co0000ojO0k?nW`>co00000_nW`>`4o`0000;oYl3/00?o0000ojO0k?nW
`>`00onW`>`2o`0000GoYl3/00?o0000ooooooooool05Oooool00ol0003oooooooooo`0[ooooo`00
<oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Sooooo0ol00002ojBUeP03o`00
0?nTZM[oY:WJ00?oY:WJ00?o0000ojJch_l000001?n[WLT00ol0003oXI_>oj6KcP02oj6KcP03o`00
0?nU[Mgo000000Co/:3700?o0000oj:OdOnRWm400_nRWm42o`0000GoY9[;00Ko0000ojJgi?l0003o
0000ojRLb_l00005ojJfi003o`000?nW`>co000000;o000000?oYkcXo`000?nW`>`01?nW`>`4o`00
00;oYl3/00?o0000ojO0k?nW`>`00onW`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`00_nW`>`2o`00
00CoYl3/0ol00002ojO0k0?o00001OnW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003oYl3/
00?oYl3/00?o0000ojO0k?l000000_l000000onW`>co0000ojO0k004ojO0k003o`000?nW`>co0000
00;o000000?oYl3/o`000?nW`>`01?nW`>`2o`0001Oooooo00?o0000ooooooooool0:_ooool003?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Eooooo`;o000000?oY:GGo`000?nT
YMH00onTYMH00ol0003oY:WJojBYfP02ojBYfP;o00001On[WLT00ol0003oXI_>oj6KcP02oj6KcP;o
00001On`X<L00ol0003oXYoAoj:Od@02o`000003okVTa?l0003oY9[;00CoY9[;0_l00004ojRLbP03
o`000?nV]^CoY[KT00;oY[KT0_l00005ojNlj003o`000?nW`>co000000;o000000?oYl3/o`000?nW
`>`01?nW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003oYl3/00CoYl3/00Co0000ojO0k?l0
003o00000_nW`>`01Ol0003oYl3/o`000?l0003oYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k003
ojO0k0;o00001OnW`>`00ol0003oYl3/ojO0k003o`000003ojO0k?l0003oYl3/00;oYl3/00Co0000
ojO0k?nW`>coYl3/0ol00005ojO0k003o`000?nW`>co000000;o000000?oYl3/o`000?ooool05_oo
ool00ol0003oooooooooo`0Zooooo`00<oooool2o`0000Kooooo00?o0000ooooooooool0DOooool3
o`0000CoY:GG00?o0000ojBUe_nTYMH00_nTYMH01_l0003oY:WJo`000?l0003oZYc9o`0000KoZig9
00Ko0000oj6Kc_nQVlko0000ok:Qa_l00005ok2Pa`03o`000?nRWm7o000000Co^JC400Oo0000ojBJ
bonTV/_oY9[;o`000?nlY/;o000000GoZ9c:00Co0000ojJfi?l0003o00000_nYW<T00ol0003oYkcX
ojNlj002ojNlj0;o00001OnW`>`01?l0003oYl3/ojO0k?nW`>`3o`0000GoYl3/00Co0000ojO0k?nW
`>coYl3/0ol00003ojO0k0?o000000GoYl3/o`000?l0003oYl3/o`000005ojO0k003o`000?nW`>co
000000;o000000?oYl3/o`000?nW`>`01?nW`>`3o`0000?oYl3/00?o0000ojO0k?l000000_nW`>`4
o`0000?oYl3/00Co0000ojO0k?nW`>coYl3/0ol00005ojO0k003o`000?oooooooooo01Gooooo00?o
0000ooooooooool0:Oooool003?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1<
ooooo`Co00000_nUZm/00ol0003oY:GGojBUe`03ojBUe`04o`000?nTYMKoY:GFojBUeP;o00001?nZ
W<T00ol0003oZig9oj^Mb@03oj^Mb@03o`000?nQVlko000000?o/Z7600?o0000ok2Paon`X<L00_n`
X<L2o`0000Go^JC400Co0000ojBJbonTV/_o00000onlY/800ol0003oZ9c:ojRLbP02ojRLbP;o0000
1OnYW<T01?l0003oYkcXo`000?l00002ojBJb`03o`000?nW`>coYl3/00;oYl3/1?l00002ojO0k003
o`000?nW`>coYl3/00?oYl3/1?l00003ojO0k0?o000000CoYl3/o`000?l0003o00001?nW`>`01?l0
003oYl3/ojO0k?nW`>`3o`0000GoYl3/00?o0000ojO0k?l000000_l000000onW`>co0000ojO0k004
ojO0k006o`000?nW`>co0000o`000?nW`>co00001OnW`>`4o`0000;oYl3/00?o0000ojO0k?nW`>`0
0onW`>`2o`0001Kooooo00?o0000ooooooooool0:Oooool003?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`19ooooo`;o000000?oY[OUo`000?nUZm/01?nUZm/00ol0003oY:GGojBU
e`02ojBUe`06o`000?nTYMKo0000o`000?nUV/[o00001OnZW<T00ol0003oZig9oj^Mb@02oj^Mb@;o
00001OnbXLH01_l0003o/:37ok2Paol0003o]Z?5o`0000Go^JC400?o0000ojBJbol000001?nlY/80
1ol0003oZ9c:ojRLb_nXW<[o0000oknW`Ol000001OnYW<T2o`0000GoY9[;00Co0000ojO0k?l0003o
00000_nRW<l00ol0003oYl3/ojO0k002ojO0k003o`000?nW`>co000000;o000000CoYl3/o`000?nW
`>coYl3/1ol00002ojO0k003o`000?nW`>coYl3/00;oYl3/1?l00002ojO0k003o`000?nW`>coYl3/
00?oYl3/0_l00005ojO0k004o`000?nW`>coYl3/ojO0k0?o000000KoYl3/o`000?nW`>coYl3/o`00
0?nW`>`3o`000003ojO0k?l0003oYl3/00CoYl3/00?o0000ojO0k?l000000_l000000onW`>co0000
ooooo`0Fooooo`03o`000?oooooooooo02Sooooo000cooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0A_ooool2o`0000CoY[OU00?o0000ojF[fonUZm/00_nUZm/01?l0003oY:GGojBU
eonTYML3o`0000CoYI[:00?o0000ojZLbOnZW<T00_nZW<T00ol0003oZig9o`000002o`000003ojjO
b?l0003o/Z7600Co/Z7600?o0000ok2Paol000000onfXlD00ol0003o^JC4okVTa003okVTa003o`00
0?nlY/;o_:K200?o_:K200Co0000ojRLb_nXW<[o00000onoYl401ol0003oZIc9ojVLbOnYW<Wo0000
ol:X_ol000001OnTV//2o`0000GoXYc?00?o0000ojO0k?nW`>`00ol00004ojO0k0Ko000000?oYl3/
o`000?nW`>`01?nW`>`01?l0003oYl3/o`000?l00002ojO0k003o`000?nW`>coYl3/00;oYl3/00?o
0000ojO0k?l000000_l000000onW`>co0000ojO0k004ojO0k0Co00000_nW`>`00ol0003oYl3/o`00
0002ojO0k0;o00001OnW`>`01?l0003oYl3/ojO0k?nW`>`3o`0000GoYl3/00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0Wooooo`00<_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo04;ooooo0ol000000onW`>co0000ojJgi@04ojJgi@04o`000?nUZm_oYJ_KojF[f`Co0000
0_nPV<`00ol0003oYI[:ojFJbP02ojFJbP03o`000?nZW<WoZYc900;oZYc90_l00005ojjOb003o`00
0?nbXLKo/Z7600;o/Z760_l00004okJSa@03o`000?niY<Co^JC400;o^JC40_l00006okbV`P;o0000
1?noYl401?l0003oZIc9ojVLbOl00003ol:X_`07o`000?nTV/_oY9[;ojBJbol0003o`JNoo`000005
oj:Lc`?o00000onUZMX4o`000003ojO0k?l0003o000000GoYl3/00Co0000ojO0k?nW`>coYl3/0ol0
0005ojO0k003o`000?nW`>coYl3/00Co00001?nW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0
003oYl3/00CoYl3/00Co0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k002ojO0k0Co0000
0_nW`>`00ol0003oYl3/ojO0k003ojO0k0;o00005_ooool2o`0002Sooooo000booooo`;o00003?oo
ool00ol0003oooooooooo`0nooooo`?o00001OnW`>`00ol0003oY[OUojJgi@02ojJgi@06o`000?nU
Zm_o0000o`000?nJULgo00001OnPV<`00ol0003oYI[:ojFJbP02ojFJbP06o`000?nZW<WoZYc9o`00
0?nZWLWo00001On^WlP00ol0003o/Z76ok:QaP02o`000003ok>Raol0003o]Z?500Co]Z?500Co0000
okVTa?niY<Co00000_njYL@00ol0003o_:K2okbV`P03okbV`P03o`000?noYl7o_jO100?o_jO100?o
0000ojVLbOl000001?o2Z;l01?l0003oY9[;ojBJbol00003ol6W_`07o`000?nRW<ooXYc?oj:Lcol0
003o_:C1o`000002ojFYfPCo000000?oYl3/o`000?l000000_nW`>`00ol0003oYl3/ojO0k002ojO0
k0Co00000_nW`>`00ol0003oYl3/ojO0k003ojO0k0?o00001?nW`>`00ol0003oYl3/ojO0k003o`00
00GoYl3/00Co0000ojO0k?nW`>coYl3/0ol000000onW`>co0000ojO0k002ojO0k006o`000?nW`>co
0000o`000?nW`>co00001OnW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003ooooo01Gooooo
0_l0000Xooooo`00<_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03[ooooo0ol0
0003ojO0k003o`000?nW`>coYl3/00?oYl3/00?o0000ojJgiOnV]nD00ol00004oiZEc@03o`000?nP
V<coX9S<00;oX9S<00?o0000ojFJb_nUV/X00_nUV/X00ol0003oZYc9o`000003ojZMb@03o`000?n^
WlSo[Yo800;o[Yo800?o0000ok:Qa_l000001?ncX/L00ol0003o]Z?5okJSa@02okJSa@03o`000?ni
Y<Co000000?o^ZG400?o0000okbV`_nlY/800_nlY/82o`0000Ko_jO100?o0000ol:X_oo2Z;l00oo2
Z;l00ol0003oY9[;o`000004ol6W_`04o`000?nRW<ooXYc?o`0000;o_:C10ol00003ojFYfP;o0000
1OnW`>`01?l0003oYl3/o`000?l00002ojO0k003o`000?nW`>coYl3/00;oYl3/00?o0000ojO0k?l0
00000_l000000onW`>co0000ojO0k004ojO0k0?o00000_nW`>`00ol0003oYl3/ojO0k003ojO0k0Co
00000_nW`>`01?l0003oYl3/ojO0k?l00002ojO0k0;o00001?nW`>`01?l0003oYl3/ojO0k?nW`>`3
o`0000GoYl3/00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Uooooo`00<_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo03Oooooo0_l00002ojO0k003o`000?nW`>coYl3/
00;oYl3/00Co0000ojO0k?nW`>coYl3/1?l00002oiBBcP03o`000?nJULgoVYG=00;oVYG=00?o0000
oj2Hc?nPV<`00_nPV<`01?l0003oYI[:ojFJb_nUV/X3o`0000CoZYg900?o0000ojjOb?n^WlP00_n^
WlP2o`0000Go/j;700?o0000okJSaOnfXlD00_nfXlD2o`0000Go^ZG400Co0000okbV`_nlY/;o0000
0_nmY/<00ol0003o_jO1oknW`@02oknW`@;o00001_o2Z;l00ol0003o`JNool6W_`03ol6W_`04o`00
0?nRW<oo0000okbT`@;o000000?o_:C1o`000?nUZMX00ol000000onaW/Go0000ojO0k004ojO0k0;o
00001OnW`>`00ol0003oYl3/ojO0k003o`0000GoYl3/00?o0000ojO0k?l000000_l000000onW`>co
0000ojO0k003ojO0k003o`000?nW`>co000000;o000000?oYl3/o`000?nW`>`01?nW`>`00ol0003o
Yl3/o`000002o`000003ojO0k?l0003oYl3/00?oYl3/1?l00002ojO0k003o`000?nW`>coYl3/00?o
Yl3/0_l0000Fooooo`03o`000?oooooooooo02Gooooo000booooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0<oooool3o`0000GoYl3/00?o0000ojO0k?nW`>`01Ol00002oiVJd`03o`00
0?nDT/koU9;>00;oU9;>00?o0000oiZEcOnJULd00_nJULd01?l0003oX9S<oj2Hc?nPV<`4o`0000;o
YI_;00?o0000ojZMbOnZWLT00onZWLT01_l0003o[Yo8ojjOb?l0003o[j39o`0000Go/j;700?o0000
okJSaOnfXlD00_l000000ongY<Ko0000okZUa004okZUa003o`000?nlY/;o000000Co_JK300Co0000
oknW`OnoYl7o00000_noZ<800ol0003o`ZRool:X_`03ol:X_`03o`000?o1Ykoo`JNo00Co`JNo0ol0
0004okbT`@03o`000?naW/Go/Ik500?o/Ik500?o0000ojO0k?l000000_l000000onQU/Wo0000ojO0
k004ojO0k0?o00000_nW`>`00ol0003oYl3/ojO0k003ojO0k0;o00001OnW`>`00ol0003oYl3/ojO0
k003o`0000GoYl3/00Co0000ojO0k?nW`>coYl3/0ol000000onW`>co0000ojO0k002ojO0k006o`00
0?nW`>co0000o`000?nW`>co00001OnW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003ooooo
01Kooooo00?o0000ooooooooool09?ooool003;ooooo0_l0000@ooooo`03o`000?oooooooooo02oo
oooo0ol00003ojO0k003o`000?nW`>coYl3/00;oYl3/0ol00002ojJchP03o`000?nIV]?oVI[C00?o
VI[C00Go0000oiBBc_nDT/koU9;>o`000004oiZEc@06o`000?nPV<co0000o`000?nPV<co00001OnU
Vl/00ol0003oZYg9ojZMb@02ojZMb@03o`000?n^WlSo000000?o[j3900?o0000ok>RaoncX/L00onc
X/L2o`0000Co]jC600?o0000okZUa?njYL@00_njYL@2o`0000Go_JK300?o0000oknW`Ol000000ono
Z<800ol0003o`ZRool:X_`02ol:X_`03o`000?o2Z<3o000000;o`JNo1?l00006okbT`@03o`000?na
W/Go/Ik500Co/Ik500?o0000oj6FbOnQU/T00onQU/T00ol0003oYl3/o`000002o`000003ojJ]gOl0
003oYl3/00?oYl3/00?o0000ojO0k?l000000_l000000onW`>co0000ojO0k004ojO0k0?o00000onW
`>`00ol0003oYl3/ojO0k002ojO0k0Co00000onW`>`01?l0003oYl3/o`000?nW`>`3o`0000CoYl3/
00Co0000ojO0k?nW`>coYl3/0ol00005ojO0k003o`000?oooooooooo01Gooooo00?o0000oooooooo
ool08oooool0037ooooo0_l0000Booooo`;o0000;?ooool3o`000003ojO0k?l0003oYl3/00CoYl3/
00Ko0000ojO0k?l0003o0000ojO0k?l00004ojJchP03o`000?nIV]?oVI[C00;oVI[C00Go0000oiBB
c_nDT/koU9;>o`000003oiZEc@?o00001?nPV<`00ol0003oYI_;ojFKb`02ojFKb`03o`000?nZWLWo
ZYg900;oZYg90_l00004ojnPb@03o`000?ncX/Oo/j;700;o/j;70_l00005okNTaP03o`000?njYLCo
^ZG400;o000000?o^ZK5o`000?nmY/<01?nmY/<2o`0000Go_jS200Co0000ol:X_oo2Z;oo00000_o2
Z<03o`0000;o`JNo00?o0000olFY_Ol000001?nlY<400ol0003oajVko`000005ok6Na@03o`000?nQ
U/WoXIK900?oXIK90_l00005ojJ]g@03o`000?nW`>coYl3/00Co00001?nW`>`00ol0003oYl3/o`00
0002o`000003ojO0k?l0003oYl3/00CoYl3/00Ko0000ojO0k?l0003o0000ojO0k?l00005ojO0k0Co
00000_nW`>`00ol0003oYl3/ojO0k002ojO0k0Co00000_nW`>`00ol0003oYl3/ojO0k003ojO0k0;o
00005_ooool00ol0003oooooooooo`0Sooooo`00<Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo02Kooooo0ol00005ojO0k004o`000?nW`>coYl3/ojO0k0?o00001?nW`>`00ol0003o
Y[?RojJchP02ojJchP05o`000?nIV]?oVI[CoiVJdol000000_nDT/h5o`0000;oVYG=00?o0000oj2H
c?nPV<`00_nPV<`00ol0003oYI_;ojFKb`02ojFKb`03o`000?nZWLWo000000;o000000?oZik;o`00
0?n_X<T01?n_X<T01_l0003o/j;7ok>Raol0003o/j?8o`0000Go]jC600?o0000okZUa?l000001?nj
Y/D01ol0003o_JK3okfV`onmY/?o0000okfXa?l000001OnoZ<800ol0003o`ZRoo`000003o`000005
ol:X`?l0003o`JNool6W_ol000000_o5ZKd01Ol0003o_:C1okbT`OnlY<7o000000;oajVk00?o0000
ok6NaOnaW/D00_naW/D00ol0003obJVio`000003oj6Fb@03o`000?noY;go000000GoYZgM0ol00004
ojO0k003o`000?nW`>coYl3/00?o00001OnW`>`01?l0003oYl3/ojO0k?nW`>`3o`0000CoYl3/00?o
0000ojO0k?l000000_l000001?nW`>co0000ojO0k?l00003ojO0k006o`000?nW`>co0000o`000?nW
`>co00001OnW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003ooooo01Kooooo00?o0000oooo
ooooool08_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co000000?o
410@ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02;ooooo0ol0
0003ojO0k003o`000?nW`>coYl3/00;oYl3/1?l00002ojO0k003o`000?nW`>coYl3/00?oYl3/00Go
0000ojJch_nV/n;oY[?Ro`000002oiVJd`Co00000_nDT/l00ol0003oVYG=oiZEc@03oiZEc@03o`00
0?nPV<coX9S<00;oX9S<00Co0000ojFKbonUVl_oYI_;0_l00005oj^Nb`03o`000?n_X<Wo[j3900;o
[j3900?o0000ok>Raol000000oncXlP00ol0003o]jC6okNTaP02okNTaP;o00001OnjY/D01?l0003o
_JK3okfV`ol00003okfXa003o`000?noZ<;o_jS200;o_jS20ol00004ol:X`003o`000?o1Ykoo0000
00CoaJVm00Co0000okbT`OnlY<7o00000oo7ZK/01?l0003o/Ik5ok6NaOl00002olVY^@04o`000?nQ
U/WoXIK9o`0000?o_jBm00?o0000ojJ]gOnV[Md00_l000000on^VlCo0000ojO0k004ojO0k0?o0000
0_nW`>`00ol0003oYl3/ojO0k003ojO0k0Co00000_nW`>`00ol0003oYl3/ojO0k002ojO0k0;o0000
1OnW`>`01?l0003oYl3/o`000?nW`>`3o`0000CoYl3/00Co0000ojO0k?nW`>coYl3/0ol00005ojO0
k003o`000?oooooooooo01Gooooo00?o0000ooooooooool08Oooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Oooooo`;o00000_nW`>`00ol0003oYl3/ojO0k002ojO0k004o`000?nW
`>co0000o`0000;oYl3/00?o0000ojO0k?nW`>`00_nW`>`01?l0003oYl3/ojO0k?nW`>`8o`0000;o
SHk?00?o0000oiBBconDT/l00_nDT/l00ol0003oVYG=oiZEc@02oiZEc@03o`000?nPV<coX9S<00;o
X9S<00Ko0000ojFKbol0003o0000ojJLc?l00005oj^Nb`03o`000?n_X<Wo[j3900;o[j390_l00005
ok>Sb006o`000?ngY<Ko]jC6o`000?ngY/So00001OnjY/D00ol0003o_JK3o`000004okfXa003o`00
0?noZ<;o000000;o000000?o_jW3o`000?o2Z<001?o2Z<02o`0000GoaJVm00?o0000okbT`Ol00000
1?o7ZK/00ol0003o/Ik5o`000003olVY^@03o`000?nQU/Wo000000Co_jBm00?o0000ojJ]gOl00000
1?n^Vl@00ol0003oYl3/o`000002o`000003ojBQdol0003oYl3/00?oYl3/00?o0000ojO0k?l00000
0_l000000onW`>co0000ojO0k004ojO0k006o`000?nW`>co0000o`000?nW`>co00001OnW`>`4o`00
00;oYl3/00?o0000ojO0k?nW`>`00_nW`>`4o`0000?oYl3/00Co0000ojO0k?nW`>coYl3/0ol0000F
ooooo`03o`000?oooooooooo027ooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400;
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01cooooo
0_l00005ojO0k003o`000?nW`>coYl3/00?o00001OnW`>`00ol0003oYl3/ojO0k005o`0000;oUIkJ
00Go0000ohJ;d?n6Rm3oQX_@o`000004ohf>c`05o`000?nDT/ooU9;?oiBBcol000001?nJULd01?l0
003oX9S<oj2Hc?nPV<`3o`0000CoYYc<00?o0000oj^Nbon[W//00_n[W//00ol0003o[j39o`000002
o`000003ojnRbol0003o/j?800Co/j?800?o0000okNTa_l000000ongY/P00ol0003o^ZK5okZVa@02
okZVa@;o00001OnmZ<@2o`000003oknX`_l0003o_jW300;o_jW300Oo0000ol:X`?o2Z<3o`ZS0o`00
0?o2ZL7o000000GoaJVm0_l00006olNY^`03o`000?o9ZKWobJVi00?obJVi00?o0000oknT_OnoY;d0
1?noY;d00ol0003o[Y_4ojjKa004ojjKa003o`000?nTXM?oY:7C00?oY:7C00?o0000ojO0k?nW`>`0
0ol00005ojO0k004o`000?nW`>coYl3/ojO0k0?o00001?nW`>`00ol0003oYl3/o`000002o`000004
ojO0k?l0003oYl3/o`0000?oYl3/00Ko0000ojO0k?l0003o0000ojO0k?l00005ojO0k0Co00000_nW
`>`00ol0003oooooooooo`0Dooooo`;o00008_ooool000Oooooo00Go0000ooooooooooooooooo`00
000;ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool01?ooool2o`0001Sooooo00?o0000ooooooooool06Oooool2o`0000;o
Yl3/00?o0000ojO0k?nW`>`00_nW`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`00_nW`>`3o`0000;o
Yl3/00?o0000oiFNf_nEW]X00onEW]X01Ol0003oQX_@ohJ;d?n6Rm3o000000CoSHk?00Go0000oiBB
conDT/ooU9;?o`000003oiZEc@Co00000_nPV/h00ol0003oYYc<ojJLc003ojJLc004o`000?n[W/_o
Zik;oj^Nb`;o00001On_X//00ol0003o/j?8ok>Sb002ok>Sb0;o00001OngY/P01_l0003o^ZK5okZV
aOl0003o^ZS8o`0000;o_JS40ol000000onmZ<Co0000o`000004oknY``04o`000?o2Z<3o`ZS0o`00
00?o`ZW100Oo0000olFY_Oo5ZKgoaJVmo`000?o4ZKko000000GoajVk0_l00005olVY^@03o`000?no
Y;go_jBm00Co_jBm00?o0000ojjKa?n^Vl@01?n^Vl@00ol0003oY:7CojBQd`03ojBQd`?o00000onW
`>`00ol0003oYl3/ojO0k002ojO0k0Co00000onW`>`00ol0003oYl3/ojO0k003o`0000GoYl3/00Co
0000ojO0k?l0003oYl3/0ol00004ojO0k003o`000?nW`>co000000;o000000?oYl3/o`000?nW`>`0
1?nW`>`00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01oooooo0007ooooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Eooooo`Co00001?nW`>`01?l0003oYl3/o`000?l00002ojO0k003o`000?nW`>co
Yl3/00;oYl3/00Co0000ojO0k?l0003o00000_nW`>`01Ol0003oYl3/ojO0k?nW`>co000000CoUIkJ
00Go0000ohJ;d?n6Rm3oQX_@o`000004ohf>c`06o`000?nDT/ooU9;?oiBBcol0003oVYG=0_l00000
0onKUloo0000oj2JcP04oj2JcP03o`000?nVW<coYYc<00;oYYc<00Ko0000oj^Nbol0003o0000oj^Q
cOl00005ojnRb`03o`000?ncXlSo/j?800;o000000?o/jK;o`000?ngY/P01?ngY/P00ol0003o^ZK5
o`000002okZXb0?o00000onmZ<@2o`0000Go_jW300?o0000ol:X`?l000001?o2ZL401?l0003oaJVm
olFY_Ol00003olBY_P05o`000?o7ZK_oajVkolNY^ol000000_o7ZK`01ol0003obJViolVY^Oo9ZKWo
0000olVY^Ol000001?noY;d00ol0003oc:Vfo`000004ojjKa003o`000?o7Y[So000000?oY:7C00?o
0000okJN`?l000001OnW`>`01_l0003oYl3/o`000?l0003oYl3/o`0000GoYl3/0ol00003ojO0k003
o`000?nW`>coYl3/00;oYl3/1?l00003ojO0k003o`000?nW`>coYl3/00?o00001OnW`>`01?l0003o
Yl3/ojO0k?nW`>`3o`0001Kooooo00?o0000ooooooooool07oooool000Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo017ooooo0ol00004ojO0k003o`000?nW`>coYl3/00?o00001OnW`>`00ol0003oYl3/ojO0
k004o`0000CoYl3/00Go0000ojO0k?nW`>coYl3/o`000003oiFNfP05o`000?n6Rm3oQX_@ohJ;d?l0
00000on=S/l7o`0000CoViO?00?o0000oj2Jc_nPV/h00_nPV/h00ol0003oYYc<ojJLc002ojJLc0;o
00001?n[XLd00ol0003o[j;;ojnRb`02ojnRb`03o`000?ncXlSo000000Co/jK;00?o0000okNVb?ng
Y/P00_ngY/P5o`0000;o^ZS800Ko0000okfXa?nmZ<Co0000okbZaol00006oknY``03o`000?o2ZL7o
`ZW100?o`ZW100?o0000olFY_Ol000001?o4ZKh01?l0003oajVkolNY^ol00003olNY_004o`000?o9
ZKWobJVio`0000;obJVi00Go0000oknT_OnoY;go_jBmo`000002olbY]P05o`000?n^VlCo[Y_4ojjK
a?l000000_o7Y[P01?l0003oY:7CojBQdol00003okJN`004o`000?nW`>coYl3/ojO0k0?o00001?nW
`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003oYl3/00CoYl3/00Ko0000ojO0k?l0003o0000
ojO0k?l00002ojO0k003o`000?nW`>coYl3/00?o00000_nW`>`00ol0003oYl3/ojO0k003ojO0k0Co
00000_nW`>`00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo1?l000000ol@413o
ooooooooo`0@ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03Oooool3o`000003ojO0k?l0003o
Yl3/00CoYl3/0ol00003ojO0k003o`000?nW`>coYl3/00;oYl3/0ol00004ojO0k003o`000?nW`>co
Yl3/017o00000_n=Sm001Ol0003oU9?@oiBCd?nDTm3o000000CoViO?00?o0000oj2Jc_nPV/h00_nP
V/h00ol0003oYYc<o`000002o`000003ojJOcol0003oZj7=00CoZj7=00Co0000ojnRbon_X/_o[j;;
0_l00005ok>Vb`03o`000?ngY/So]jK800Co00001OnjZ<P00ol0003o_JS4o`000003okbZa`03o`00
0?noZL?o_jW300;o_jW30_l00006ol:Y`@03o`000?o4ZKkoa:Vn00?oa:Vn00?o0000olNY^ol00000
1?o7ZK`01?l0003obJViolVY^Ol00003olVY^@04o`000?noY;go_jBmo`0000?oc:Vf00Co0000ojjK
a?n^VlCo00000_o7Y[P00ol0003oY:7Co`000005okJN`0?o00000onSW<h00ol0003oYl3/ojO0k003
o`0000GoYl3/00Co0000ojO0k?nW`>coYl3/0ol00004ojO0k003o`000?nW`>co000000;o000000?o
Yl3/o`000?nW`>`00onW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003oYl3/00CoYl3/00?o
0000ooooooooool05Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01;ooooo0007
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03oeEEEOmVIVKo000000Gooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`09ooooo`Co00001?nW`>`00ol0003oYl3/o`000002o`000003
ojO0k?l0003oYl3/00CoYl3/00Co0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k002ojO0
k0?o00000_nW`>`01Ol0003oOh_Fogn;e_moRmKo000000?oOhOA00Go0000ohJ;dOn6Rm7oQX_Ao`00
0005ohf?d005o`000?nDTm3oU9?@oiBCd?l000001?nKUll01?l0003oX9[>oj2Jc_nPV/h2o`0000Go
YYo?00?o0000oj^QcOn[XLd00_n[XLd01_l0003o[j;;o`000?l0003o/:K>o`0000Go/jK;1?l00003
okNYc003o`000?njZ<So^ZS800;o^ZS80_l00005okbZa`04o`000?noZL?o_jW3o`0000;o_j_600?o
0000ol:Y`Oo2ZL400_o2ZL42o`0000Koa:Vn00?o0000olNY_?o7ZK`01?o7ZK`2o`0000CobJVi00?o
0000oknT_Ol000001?o<ZKH00ol0003o[Y_4o`000004olNV^003o`000?nfW/3o]Yk000Co]Yk000?o
0000oj>Lc_nSW<h00onSW<h3o`0000;oYl3/00?o0000ojO0k?nW`>`00onW`>`4o`0000?oYl3/00?o
0000ojO0k?nW`>`00ol000000onW`>co0000ojO0k002ojO0k003o`000?nW`>coYl3/00?o00001OnW
`>`01?l0003oYl3/ojO0k?nW`>`3o`0001Kooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Booooo`00<?ooool2o`0001kooooo00?o0000ooooooooool01Oooool3o`0000CoYl3/00?o
0000ojO0k?nW`>`00ol00005ojO0k004o`000?nW`>coYl3/ojO0k0?o00001OnW`>`01?l0003oYl3/
o`000?l00002ojO0k005o`000?nW`>coYl3/ojO0k?l000000omoRmH01Ol0003oOhOAogn7dOmoQm7o
000000?oQX_A00?o0000ohf?d?n=Sm000_n=Sm000ol0003oU9?@oiBCd002oiBCd006o`000?nKUloo
ViO?oi^Gcol0003oX9[>0_l000000onQWM3o0000ojJOc`04ojJOc`03o`000?n[XLgoZj7=00;oZj7=
0_l00004ok2VcP03o`000?ncY/_o/jK;00Co00001OngZL`00ol0003o^ZS8okZXb002o`000003okV/
c?l0003o_:[700Co_:[700?o0000oknY`ol000001?noZlH01?l0003o`ZW1ol:Y`Ol00002ol6[``03
o`000?o4ZKkoa:Vn00?oa:Vn00?o0000olNY_?o7ZK`01?o7ZK`00ol0003obJViolVY^@04olVY^@03
o`000?o<ZKKoc:Vf00Coc:Vf00?o0000olNV^?o7Y[P00oo7Y[P00ol0003o]Yk0okJN`003okJN`003
o`000?o<Z;Co000000?oXic>00?o0000okVO__l000001?nW`>`00ol0003oYl3/o`000002o`000003
ojO0k?l0003oYl3/00CoYl3/0ol00002ojO0k004o`000?nW`>coYl3/o`0000;oYl3/0ol00002ojO0
k003o`000?nW`>coYl3/00?oYl3/1?l00003ojO0k003o`000?oooooooooo01Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Booooo`00<?ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00;ooooo0_l00002ojO0k003o`000?nW`>coYl3/00;oYl3/0ol00003ojO0k003
o`000?nW`>coYl3/00;oYl3/1?l00003ojO0k004o`000?nW`>coYl3/ojO0k0?o00001OnW`>`01Ol0
003oYl3/ojO0k?nW`>co000000?oOh_F00Go0000ogn7dOmoQm7oOhOAo`000003ohJ;d@05o`000?n=
Sm3oSHo@ohf?d?l000001?nDTm000ol0003oViO?oi^Gc`03o`0000CoXIg@00?o0000ojJOconVWll0
0_nVWll00ol0003oZj7=o`000002o`000003ojbUd?l0003o/:K>00?o/:K>0ol000001?ncY/_o0000
ok>Zcol00005okNYc003o`000?njZ<So000000Co^Jc<00?o0000okbZaonlZ/L00_nlZ/L2o`0000Go
_j_600?o0000ol:Y`Ol000000oo1Zl<00ol0003oa:VnolBY_P02olBY_P03o`000?o4Z/3o000000Go
ajVl00?o0000olVY^Oo9ZKT01?o9ZKT00ol0003oc:VfolbY]P04olbY]P03o`000?o7Y[SoajJh00;o
ajJh00?o0000olnY/ol000001?nfW/000ol0003oc:Rdo`000002oj>LcP05o`000?niWkko^InnokVO
__l000000_nW`>`3o`0000GoYl3/00?o0000ojO0k?l000000_l000000onW`>co0000ojO0k003ojO0
k003o`000?nW`>co000000;o000000?oYl3/o`000?nW`>`00onW`>`00ol0003oYl3/o`000002o`00
0003ojO0k?l0003oYl3/00CoYl3/0_l0000Fooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool04_ooool0033ooooo00?o0000ooooooooool07oooool5o`0000CoYl3/00Co0000ojO0k?l0
003o00000_nW`>`00ol0003oYl3/ojO0k002ojO0k004o`000?nW`>co0000o`0000;oYl3/00?o0000
ojO0k?nW`>`00_nW`>`4o`0000;oYl3/00?o0000ojO0k?nW`>`00onW`>`5o`0000?oOh_F00Go0000
ogn7dOmoQm7oOhOAo`000003ohJ;d@03o`000?n=Sm3oSHo@00;oSHo@00?o0000oiBCd?nDTm001?l0
0002oi^Jd@03o`000?nQWM3oXIg@00?oXIg@00Co0000ojJOconVWlooYYo?0_l00005ojbUd008o`00
0?n`Y/ko0000o`000?n`Y/ko0000ok>Vbol00003ok>Zc`03o`000?ngZLco]jW<00;o]jW<0_l00005
okV/c003o`000?nlZ/Oo_:[700;o000000?o_:g;o`000?noZlH01?noZlH2o`0000Go`J_300Co0000
olBY__o4ZKko00000_o4Z/000ol0003oajVlolNY_002olNY_003o`000?o6Z[go000000CobJVi00?o
0000olVY^Ol000001?o<ZKH00ol0003oc:Vfo`000002olNV^004o`000?o?ZK?ocjVco`0000?o]Yk0
00Ko0000olbX]?o<Z;Co0000oj>Lc_l00005okVO_P;o00000onSW<h01?l0003oYl3/ojO0k?nW`>`3
o`0000GoYl3/00?o0000ojO0k?nW`>`00ol000000onW`>co0000ojO0k002ojO0k003o`000?nW`>co
Yl3/00?o00001OnW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003ooooo01Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Booooo`00;oooool00ol0003oooooooooo`0Noooo
o`?o00001?nW`>`00ol0003oYl3/ojO0k003o`0000GoYl3/00?o0000ojO0k?nW`>`01?l00004ojO0
k004o`000?nW`>co0000o`0000;oYl3/00?o0000ojO0k?nW`>`00_nW`>`00ol0003oYl3/o`000002
o`000004ojO0k?l0003oL7oCog1odaCo00000_nEU]800ol0003oVi[Aoi^Jd@02oi^Jd@03o`000?nQ
WM3oXIg@00;oXIg@00Ko0000ojJOcol0003o0000ojNTd_l00004ojbUd0?o00000on`Y/h2o`0000Go
/j[?00Ko0000okNYc?ngZLco0000okJ^dOl00005okV/c003o`000?nlZ/Oo000000Co_:g;00Oo0000
okn[a_noZlKo_j_6o`000?nn[LWo000000Go`J_300?o0000olBY__l000001?o4Z/001?l0003oajVl
olNY_?l00002olJZ_@05o`000?o9ZKWobJViolVY^Ol000000_o9ZKT01Ol0003oc:VfolbY]_o<ZKKo
000000;oc:Vf00Co0000olNV^?o7Y[So00000oo?ZK<00ol0003o]Yk0o`000004olbX]003o`000?ni
Wkko^Inn00Co^Inn00?o0000oj>Lc_nSW<h00onSW<h3o`0000;oYl3/00?o0000ojO0k?nW`>`00onW
`>`3o`0000;oYl3/00Co0000ojO0k?nW`>co00000_nW`>`3o`0000?oYl3/00Co0000ojO0k?nW`>co
Yl3/0ol00005ojO0k003o`000?oooooooooo01?ooooo0_l00007ooooo`03o`000?oooooooooo01;o
oooo000_ooooo`03o`000?oooooooooo01cooooo0_l00002ojO0k003o`000?nW`>coYl3/00;oYl3/
0ol00003ojO0k003o`000?nW`>coYl3/00;oYl3/0ol00004ojO0k003o`000?nW`>coYl3/00?o0000
1OnW`>`00ol0003oYl3/ojO0k004o`0000CoYl3/00Co0000og1odom`Om?o00000omgP]801Ol0003o
OhOBogn7d_moQm;o000000?oQhcB00Go0000ohjAd_n>TM;oSY7Bo`000005oiFFdP05o`000?nKV]7o
Vi[Aoi^JdOl000001?nQWM02o`0000CoYjCB1?l000000on/YM3o0000ok2VcP03o`000003ok2[dol0
003o/j[?00Co/j[?00?o0000okNYc?l000000onf[]400ol0003o^Jc<okV/c002okV/c0;o00001Onl
[L/01?l0003o_j_6okn[a_l00003okj]b@03o`000?o1Zl?o`J_300;o`J_30_l00005olBZ`003o`00
0?o7ZKco000000?oaZZm00Co0000olVY^Oo9ZKWo00000oo9ZKT01?l0003oc:VfolbY]_l00003olbY
]P03o`000?o7Y[So000000CocjVc00?o0000okJN`?l000001?o<Z;@00ol0003o^InnokVO_P03okVO
_P03o`000?o?ZK;o000000?oXic>00?o0000okVP__l000001?nW`>`00ol0003oYl3/o`000002o`00
0003ojO0k?l0003oYl3/00?oYl3/00?o0000ojO0k?l000000_l000000onW`>co0000ojO0k003ojO0
k0Co00000_nW`>`00ol0003oYl3/ojO0k003ojO0k0;o00004oooool01?l0003oooooooooool00004
ooooo`03oeEEEOmVIVKo000001Cooooo000_ooooo`;o00006_ooool4o`0000CoYl3/00Co0000ojO0
k?l0003o00000_nW`>`00ol0003oYl3/ojO0k002ojO0k004o`000?nW`>co0000o`0000;oYl3/00?o
0000ojO0k?nW`>`00_nW`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`00_nW`>`3o`0000CoYl3/00Go
0000ojO0k?nW`>coYl3/o`000003og1od`05o`000?mgP];oMh;BogN2d_l000000omoQm801Ol0003o
QhcBohN<d_n7S=;o000000?oSY7B00?o0000oiFFd_nEU]800_nEU]801_l0003oVi[Aoi^JdOnKV]7o
0000oj6Md0?o000000CoXZ7Do`000?nWY=;oYjCB1?l00003ojbUd0;o00001On`Zm<00ol0003o/j[?
ok>Zc`02ok>Zc`;o00001Onf[]401_l0003o^Jc<okV/c?l0003o^;3Ao`0000Go_:g;00?o0000okn[
a_l000001?nn[LT01ol0003o`J_3ol6[`oo1Zl?o0000ol2]aol000001Oo4Z/02o`0000GoaZZm0_l0
0005olVY^@;o00001Oo<ZKH00ol0003ocjVcolnY/`04olnY/`03o`000?o<Z;Coc:Rd00;oc:Rd00?o
0000om6Z/?l000001?niWkh00ol0003ocjVbo`000002oj>LcP05o`000?niX;ko^J2nokVP__l00000
0_nW`>`3o`0000GoYl3/00?o0000ojO0k?nW`>`00ol000000onW`>co0000ojO0k002ojO0k006o`00
0?nW`>co0000o`000?nW`>co00001OnW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003ooooo
01Gooooo00?o0000ooooooooool06Oooool002oooooo00?o0000ooooooooool05_ooool3o`0000Co
Yl3/00?o0000ojO0k?nW`>`00ol00005ojO0k003o`000?nW`>coYl3/00Co00001?nW`>`01?l0003o
Yl3/o`000?l00002ojO0k003o`000?nW`>coYl3/00;oYl3/00Co0000ojO0k?l0003o00000_nW`>`0
0ol0003oYl3/ojO0k002ojO0k0Go00000om`Om<01Ol0003oMh;BogN2d_mgP];o000000?oOhOB00?o
0000ohN<d_n7S=800_n7S=801Ol0003oSY7BohjAd_n>TM;o000000?oUIKB00?o0000oi^JdOnKV]40
0ol00004oj:Qe0?o00000onWY=801_l0003o[:G@o`000?l0003o[:_Fo`0000Go/:_C00?o0000ok>Z
col000000_l000000onc/=Ko0000okJ^d@04okJ^d@03o`000?ni[<co000000?o^;3A00?o0000okb]
bonl[L/00_nl[L/2o`0000Go_Zg900Co0000ol6[`oo1Zl?o00000oo0[LL01ol0003oa:[0olBZ`?o4
Z/3o0000ol:/`ol000001Oo6Z[d00ol0003obJViolVY^@04olVY^@03o`000?o<ZKKoc:Vf00Coc:Vf
00?o0000olnY/oo?ZK<01?o?ZK<00ol0003oc:RdolbX]002olbX]003o`000?oAZ[3o000000?o^Inn
00Ko0000olnY/_o?ZK;o0000oj>Lc_l00005okVP_P;o00000onTX]<01?l0003oYl3/ojO0k?nW`>`4
o`0000?oYl3/00Co0000ojO0k?l0003oYl3/0ol00004ojO0k004o`000?nW`>coYl3/ojO0k0?o0000
1OnW`>`00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Sooooo000_ooooo`03o`000?oo
oooooooo01Cooooo0_l00002ojO0k003o`000?nW`>coYl3/00;oYl3/0ol00003ojO0k003o`000?nW
`>coYl3/00;oYl3/0ol00004ojO0k003o`000?nW`>coYl3/00?o00001OnW`>`00ol0003oYl3/ojO0
k004o`0000CoYl3/00Ko0000ojO0k?l0003o0000ojO0k?l00002ofMkd`Go00000omgP]801Ol0003o
OhOBogn7d_moQm;o000000CoQhcB00Go0000ohjAd_n>TM;oSY7Bo`000002oiFFdPCo00000_nMW]D0
0ol0003oXZ7Do`000002o`000003oj:Qe?l0003oYjCB00?oYjCB0_l00004ojb[eP03o`000?n`Zm?o
/:_C00;o/:_C0_l00005ok>`eP03o`000?nf[]7o]ZkA00;o]ZkA0_l00005okR`d@06o`000?nl[L_o
_:g;o`000?nj/M7o00001_nn[LT2o`0000Co`:g700Co0000olBZ`?o4Z/3o00000oo2[<<01?l0003o
aZZmolJZ_Oo6Z[d2o`0000KobJVi00?o0000olbY]_o<ZKH00oo<ZKH00ol0003oc:Vfo`000004olnY
/`03o`000?o?ZK?o000000;oc:Rd00Oo0000om6Z/?oAZ[3odJZ`o`000?niWkko000000CocjVb00?o
0000okVP__niX;h01?niX;h00ol0003oY:;CojBRd`03ojBRd`?o00000_nW`>`00ol0003oYl3/ojO0
k002ojO0k0Co00000onW`>`00ol0003oYl3/ojO0k005o`0000?oYl3/00?o0000ojO0k?nW`>`00ol0
000Gooooo`03o`000?oooooooooo01Oooooo000_ooooo`03o`000?oooooooooo017ooooo1?l00004
ojO0k004o`000?nW`>co0000o`0000;oYl3/00?o0000ojO0k?nW`>`00_nW`>`01?l0003oYl3/o`00
0?l00002ojO0k003o`000?nW`>coYl3/00;oYl3/0ol00003ojO0k003o`000?nW`>coYl3/00;oYl3/
0ol00004ojO0k003o`000?nW`>coYl3/00?o00001?nW`>`01?l0003oIg_CofMkdol00002ofimdPCo
000000?oMh;Bo`000?moQm800_moQm800ol0003oQhcBohN<dP08o`0000;oUi[E00?o0000oifNeOnM
W]D00ol00004oj:Qe003o`000?nWY=;o000000;o000000?oZ:[Ho`000?n/ZmH01?n/ZmH01_l0003o
/:_Cok2[dol0003o[k;Jo`0000Go/k3F00?o0000okJ^dOl000000_l000000ond]=So0000okR`d@04
okR`d@03o`000?nl[L_o000000?o^[7A00?o0000okj]bOnn[LT00_nn[LT2o`0000Go`:g700?o0000
olBZ`?l000001?o2[<<01?l0003oaZZmolJZ_Ol00002olF[_`03o`000?o9ZKWobJVi00;obJVi00?o
0000olVZ^_l000001?o<ZKH00ol0003oc:Vfo`000003olnY/`04o`000?o?ZK?ocjVco`0000;oc:Rd
00Oo0000om6Z/?oAZ[3odJZ`o`000?niWkko000000CocjVb00?o0000okVP__niX;h00oniX;h00ol0
003ocjVco`000003ojBRd`;o00001OnW`>`01_l0003oYl3/o`000?l0003oYl3/o`0000;oYl3/00?o
0000ojO0k?nW`>`00ol00002ojO0k003o`000?nW`>coYl3/00?oYl3/0ol00003ojO0k003o`000?oo
oooooooo01Cooooo00?o0000ooooooooool05oooool002kooooo00?o0000ooooooooool03_ooool4
o`0000CoYl3/00?o0000ojO0k?nW`>`00ol00005ojO0k003o`000?nW`>coYl3/00Co00001?nW`>`0
1?l0003oYl3/o`000?l00002ojO0k003o`000?nW`>coYl3/00;oYl3/00Co0000ojO0k?l0003o0000
0_nW`>`00ol0003oYl3/ojO0k002ojO0k0?o00000onW`>`01Ol0003oYl3/ojO0k?nW`>co000000?o
Ig_C00Co0000ofimd_m^OM;o00000_mgPm88o`0000;oR93D00Go0000oi2EeOn@UMGoT9GEo`000003
oiNJe@?o00000onMW]D00ol0003oXZ7Doj:Qe003o`0000GoZ:[H00?o0000ojb[e_n/ZmH00_n/ZmH0
0ol0003o/:_Co`000003ojnbfP03o`000?nc/=Ko/k3F00;o/k3F0_l00005okBdf003o`000?nh/=7o
^;3A00;o^;3A0_l00005okZad@06o`000?nn[LWo_Zg9o`000?nk/<oo00001Oo0[LL2o`0000Go`Zc3
00?o0000olJZ_Ol000001?o5Zkl01?l0003obJViolVY^Ol00002olVZ^P05o`000?o<ZKKoc:VfolbY
]_l000000_o<ZKH01?l0003ocjVcolnY/ol00003olnY/`03o`000?o<Z;Co000000GodJZ`00?o0000
olnY/_o?ZK800_o?ZK800ol0003oe:^_o`000003okVP_P04o`000?o?ZK?ocjVco`0000;oY:;C00Co
0000okJO`_nfWl;o00000onW`>`3o`0000CoYl3/00?o0000ojO0k?l000000_l000000onW`>co0000
ojO0k003ojO0k003o`000?nW`>co000000;o000000?oYl3/o`000?nW`>`00onW`>`2o`0001Kooooo
00?o0000ooooooooool05_ooool002kooooo0_l0000<ooooo`?o00000onW`>`00ol0003oYl3/ojO0
k002ojO0k0?o00000onW`>`00ol0003oYl3/ojO0k002ojO0k0?o00001?nW`>`00ol0003oYl3/ojO0
k003o`0000GoYl3/00?o0000ojO0k?nW`>`01?l00004ojO0k004o`000?nW`>co0000o`0000;oYl3/
00?o0000ojO0k?nW`>`00_nW`>`01Ol0003oYl3/ojO0k?nW`>co000000;oIg_C00Go0000ofimd_m^
OM;oKWgBo`000002ogN3dP05o`000?n0RM?oP8WCoh29dol000001On8T=@01?l0003oT9GEoi2EeOn@
UMD3o`0000;oUi[E00Co0000oifNeOnMW]GoWIkE0ol00002oj>Xf@03o`000?nXZ]SoZ:[H00?oZ:[H
00Co0000ojb[e_n/ZmKo[:_F0ol00005ojnbfP06o`000?nc/=Ko/k3Fo`000?na]mko00001Ond]=P0
0ol0003o^;3Ao`000002o`000003okFffOl0003o^[7A00Co^[7A00?o0000okj]bOl000000onk/<l0
1ol0003o`:g7ol2]aoo0[LOo0000okf_c?l000001Oo2[<<2o`0000GoaJ^o00?o0000olVY^Ol00000
1?o9Z[X00ol0003oc:Vfo`000004olbY]P;o00001Oo?ZK<2o`0000GodJZ`00?o0000olnY/_o?ZK80
0_o?ZK800ol0003oe:^_o`000002okVP_P07o`000?o?ZK?ocjVcolnY/ol0003oY:;Co`000004okJO
`P?o00000onV[mh00ol0003oYl3/ojO0k003o`000003ojO0k?l0003oYl3/00;oYl3/00?o0000ojO0
k?nW`>`00ol00005ojO0k006o`000?nW`>co0000o`000?nW`>co00005oooool00ol0003ooooooooo
o`0Eooooo`00;_ooool00ol0003oooooooooo`09ooooo`;o00000_nW`>`00ol0003oYl3/ojO0k002
ojO0k004o`000?nW`>co0000o`0000;oYl3/00?o0000ojO0k?nW`>`00_nW`>`01?l0003oYl3/o`00
0?l00002ojO0k003o`000?nW`>coYl3/00;oYl3/0ol00003ojO0k003o`000?nW`>coYl3/00;oYl3/
0ol00004ojO0k003o`000?nW`>coYl3/00?o00001OnW`>`00ol0003oYl3/ojO0k006o`0000?oIg_C
00Go0000ofimd_m^OM;oKWgBo`000002ogN3dP05o`000?n0RM?oP8WCoh29dol000001?n8T=@00ol0
003oT9GEo`000002o`0000CoUi[E00Ko0000oifNeOl0003o0000oijUf_l00004oj>Xf@03o`000?nX
Z]SoZ:[H00;oZ:[H1?l00002ojbcg@03o`000?n_/][o[k;J00?o[k;J00?o0000ok>`e_l000000ona
]mh00ol0003o];CHokBdf002okBdf0;o00001One]]T00ol0003o^[7AokZad@02okZad@;o00001Onk
/<l00ol0003o`:g7o`000003okf_c007o`000?o2[<?o`Zc3ol:/`ol0003o`:g7o`000005olF[_`;o
00001Oo9Z[X00ol0003oc:Vfo`000004olbY]P03o`000?o?ZK?ocjVc00CocjVc00?o0000om6Z/?oA
Z[000ooAZ[000ol0003odZZ`o`000002olnY/P04o`000?oDZjooe:^_o`0000;o^J2n00?o0000olnY
/oo?ZK<00_o?ZK<00ol0003o]Yo2okJO`P03okJO`P03o`000?nV[mkoYZoN00?oYZoN0ol00002ojO0
k004o`000?nW`>coYl3/o`0000;oYl3/0ol00003ojO0k004o`000?nW`>coYl3/ojO0k0?o00001?nW
`>`00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Gooooo000^ooooo`03o`000?oooooo
oooo00Kooooo0ol00005ojO0k003o`000?nW`>coYl3/00Co00001?nW`>`00ol0003oYl3/ojO0k004
o`0000CoYl3/00Co0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k002ojO0k004o`000?nW
`>co0000o`0000;oYl3/00?o0000ojO0k?nW`>`00_nW`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`0
0_nW`>`3o`0000;oYl3/00?o0000ofEof?mUOmP01Ol00003ofimdP05o`000?mgPm;oMh?BogN3d_l0
00000on0RM<00ol0003oR93DohR@e003o`0000;oT9GE00Co0000oiNJeOnGV]GoUi[E0ol00004oijU
fP03o`000?nSZ=WoXjSI00;oXjSI00Ko0000ojRZf?l0003o0000ojRbgol00005ojbcg@04o`000?n_
/][o[k;JojnbfP?o00001Ona]mh01_l0003o];CHo`000?l0003o/K_Qo`0000Go]KKI00?o0000okZa
dOl000000_l000000onf]]Wo0000ok^`c`04ok^`c`;o00001?nm[l`01?l0003o`Zc3ol:/`ol00003
ol2]a`07o`000?o5ZkooaJ^oolF[_ol0003oa:c2o`000006olVZ^P03o`000?o<ZKKoc:Vf00?oc:Vf
00?o0000olnY/oo?ZK<01?o?ZK<00ol0003odJZ`om6Z/002om6Z/004o`000?oBZ[3odZZ`o`0000;o
cjVb00Co0000omB[[ooDZjooe:^_0_l00005olnY/`03o`000?nfWl;o]Yo200;o]Yo200?o0000olfZ
]ol000000_nV[mh2o`000003ojnOb?l0003oYl3/00?oYl3/00?o0000ojO0k?l000000_l000000onW
`>co0000ojO0k003ojO0k0Co00000_nW`>`00ol0003oYl3/ojO0k002ojO0k0;o00005_ooool00ol0
003oooooooooo`0Dooooo`00;_ooool00ol0003oooooooooo`03ooooo`?o00000onW`>`00ol0003o
Yl3/ojO0k002ojO0k0?o00001?nW`>`00ol0003oYl3/ojO0k004o`0000CoYl3/00?o0000ojO0k?nW
`>`01?l00004ojO0k003o`000?nW`>coYl3/00Co00001?nW`>`01_l0003oYl3/o`000?l0003oYl3/
o`0000GoYl3/00Ko0000ojO0k?l0003o0000ojO0k?l00004ojO0k004o`000?mUOmSoIGoHo`0000;o
I7OA2Ol00003oh29d`co00000_nIX=X00ol0003oWZGJoijUfP03oijUfP04o`000?nSZ=WoXjSIoj>X
f@;o00001?nX/]l00ol0003o[;?Mojbcg@02ojbcg@Co00000_n^^n<00ol0003o/KONok6ggP03ok6g
gP;o00001?na^n400ol0003o]KKIokFff@02okFff@;o00001Onf]]T00ol0003o^k3?ok^`c`02o`00
0003okNde_l0003o_Jo<00?o_Jo<00?o0000ol:/`ol000001?o0[LL01?l0003oaJ^oolF[_ol00003
olB/`P03o`000?o9Z[[obJZj00;obJZj0_l00004olbY]P03o`000?o;Z[So000000CocjVc00?o0000
olnZ/ol000000_oAZ[001ol0003odZZ`om:Z/?oBZ[3o0000olnY/_l000001?oDZjl00ol0003ocjVc
olnY/`03olnY/`03o`000?oF[Jko000000;o]Yo200Ko0000olfZ]oo=Z[Oo0000ojJ_g_l00004ojnO
b003o`000?nW`>coYl3/00?o000000?oYl3/o`000?nW`>`00_nW`>`01_l0003oYl3/o`000?l0003o
Yl3/o`0000GoYl3/00Ko0000ojO0k?l0003o0000ojO0k?l0000Eooooo`03o`000?oooooo000001Go
oooo000^ooooo`04o`000?ooooooooooooooo`;o00000_nW`>`00ol0003oYl3/ojO0k002ojO0k004
o`000?nW`>co0000o`0000;oYl3/00?o0000ojO0k?nW`>`00_nW`>`3o`0000?oYl3/00?o0000ojO0
k?nW`>`00_nW`>`3o`0000CoYl3/00?o0000ojO0k?nW`>`01?l00004ojO0k003o`000?nW`>coYl3/
00?o00001?nW`>`01?l0003oYl3/ojO0k?nW`>`3o`0000CoYl3/00Go0000ojO0k?nW`>coYl3/o`00
0003ofEof004o`000?mTMm7oI7OAo`0000?oKgoB00?o0000ogZ6e?mjQ]@01ol00002oh^Ee`05o`00
0?nBVmWoTY_Ioi:KfOl000001OnIX=X00ol0003oWZGJoijUfP02oijUfP06o`000?nSZ=Wo0000o`00
0?nU/N7o00001OnX/]l01_l0003o[;?Mo`000?l0003oZkgWo`0000Go[[_S00?o0000ok6gg_l00000
0_l000000on/`NWo0000ok6kh@04ok6kh@06o`000?ne]]Wo0000o`000?n`_>?o00001Onf]]T00ol0
003o^k3?o`000004okNdeP04o`000?nm[lco_Jo<okf_c0;o00001Oo0[LL00ol0003oaJ^oo`000004
olB/`P05o`000?o9Z[[obJZjolVZ^_l000000_o7Zkd01?l0003oc:VfolbY]_l00002ol^Z^005o`00
0?o?ZK?ocjVcolnY/ol000000_o?Z[<01?l0003odJZ`om6Z/?l00004om:Z/0;o00001?oDZjl00ol0
003ocjVcolnY/`03olnY/`03o`000?oF[Jko000000;o]Yo200Go0000olfZ]oo=Z[OocJZgo`000006
ojnOb0;o00000onW`>`01?l0003oYl3/o`000?nW`>`3o`0000CoYl3/00Co0000ojO0k?nW`>coYl3/
0ol00004ojO0k003o`000?oooooooooo01Cooooo00?o0000ooooooooool04oooool002kooooo1Ol0
0004ojO0k003o`000?nW`>coYl3/00Co00001?nW`>`01?l0003oYl3/o`000?l00002ojO0k003o`00
0?nW`>coYl3/00;oYl3/00Co0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k002ojO0k0?o
00000onW`>`00ol0003oYl3/ojO0k002ojO0k0?o00000onW`>`00ol0003oYl3/ojO0k005o`0000?o
Yl3/00?o0000ojO0k?nW`>`02?l000000omUOmSo0000ofAgd@02ofAgd@04o`000?m_Om;oKgoBofmo
dPCo00000on3S]H00ol0003oRiGGoh^Ee`02oh^Ee`05o`000?nBVmWoTY_Ioi:KfOl000001?nIX=X0
1?l0003oWZGJoijUf_nNYMX3o`0000CoYK7Q00?o0000ojRbgonX/]l00_nX/]l2o`0000CoZkgW00?o
0000ojjkhon^^n<00_n^^n<2o`0000Go[<7Y00?o0000ok6khOna^n400_na^n42o`0000Co/;cS00?o
0000okJffOnf]]T00_nf]]T2o`0000Go]kCF00Ko0000okf_c?nm[lco0000okVbd_l00006ol2]a`03
o`000?o4[<;oa:c200?oa:c200Co0000olVZ^_o9Z[[o00000oo7Zkd01?l0003oc:VfolbY]_l00003
ol^Z^004o`000?o?ZK?ocjVco`0000;ocjZc00?o0000om6Z/?l000001OoBZ[000ol0003oe:^_omB[
[`02omB[[`03o`000?oE[:oo000000?ocjVc00Ko0000omJ][_oF[Jko0000okJO`_l00004olfZ]`03
o`000?n_WlSo[io800?o[io80_l00004ojO0k0Co00000onW`>`00ol0003oYl3/ojO0k005o`0000;o
Yl3/00Co0000ojO0k?nW`>coYl3/0ol0000Fooooo`03o`000?oooooooooo01;ooooo000]ooooo`;o
00001?nW`>`00ol0003oYl3/ojO0k004o`0000CoYl3/00?o0000ojO0k?nW`>`01?l00004ojO0k003
o`000?nW`>coYl3/00Co00001?nW`>`01?l0003oYl3/o`000?l00002ojO0k003o`000?nW`>coYl3/
00;oYl3/00Ko0000ojO0k?l0003o0000ojO0k?l00004ojO0k0?o00000onW`>`00ol0003oYl3/ojO0
k002ojO0k0?o00000_nW`>`01_l0003oJhgQof^=hOm[SN7o0000oeU`d0;o00000omTMm45o`0000?o
NXKD00Go0000oh>>e_n3S]KoPhkFo`000004oh^Ee`05o`000?nBVmWoTY_Ioi:KfOl000000_nIX=X5
o`0000;oXJkQ00?o0000ojFahOnU/N400onU/N401?l0003oZ;;Oo`000?l00002ojRnj@03o`000?n[
_NOoZkgW00;oZkgW00Co0000ojjkhol0003o00000_nXa^l00ol0003o[<7Yojc1j@02ojc1j@03o`00
0?na^n7o000000;o000000?oZ<C]o`000?n`_><01?n`_><01_l0003o][KIo`000?l0003o[k_So`00
00Go]kCF00?o0000okf_c?l000000oni/]800ol0003o`:g7ol2]a`02ol2]a`;o00001_o4[<82o`00
00Coaj^m00?o0000olbY]_l000001?o;Z[P00ol0003ocjVco`000004olnZ/`03o`000?oBZ[3odZZ`
00CodZZ`00?o0000omB[[ooDZjl00_oDZjl00ol0003oeJb_o`000003olnY/`05o`000?oF[JkoeZf^
omJ][_l000001?o=Z[L00ol0003oejn`o`000003ojnOb005o`000?o7Zkkoaj^no`000?nW`>`00_l0
00001OnTX=7o0000ojO0k?nW`>co000000;oYl3/0ol00002ojO0k003o`000?nW`>coYl3/00;oYl3/
1?l00003ojO0k003o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool002gooooo0_l0
0004ojO0k0?o00000onW`>`00ol0003oYl3/ojO0k002ojO0k0?o00001?nW`>`00ol0003oYl3/ojO0
k004o`0000CoYl3/00?o0000ojO0k?nW`>`01?l00004ojO0k003o`000?nW`>coYl3/00?o00001?nW
`>`01?l0003oYl3/o`000?l00002ojO0k003o`000?nW`>coYl3/00;oYl3/00Co0000ojO0k?l0003o
00000_nW`>`01Ol0003oYl3/ojO0k?nW`>co000000?oJhgQ00?o0000oeU`d?mIL=001?l00003ofmo
dP05o`000?mjQ]CoNXKDogZ6e?l000001?n3S]H01Ol0003oRiGGoh^Eeon;UMOo000000;oTY_I1?l0
0002oibYg`03o`000?nQ[^7oXJkQ00?oXJkQ00Co0000ojFahOnU/N7oYK7Q0ol00005ojRnj@03o`00
0?n[_NOoZkgW00?o00001OnXa^l00ol0003o[<7Yojc1j@04o`0000CoZ<C]00Co0000ok2lhon`_>?o
/;cS0ol00004ojnkh`03o`000?ng]=Ko]kCF00;o]kCF0_l00005okVbdP04o`000?o0[LOo`:g7o`00
00;o_:o=00?o0000olB/`_o4[<800_o4[<82o`0000Koaj^m00?o0000ol^Z^?o;Z[P01?o;Z[P00ol0
003ocjZcolnZ/`03olnZ/`03o`000?oBZ[3odZZ`00?odZZ`00?o0000om:[/Ol000000_oDZjl01ol0
003oeJb_omF/[ooE[:oo0000olnY/ol000001?oF[Jh00ol0003ocJZgolfZ]`02olfZ]`03o`000?oG
[k3o000000;o[io800?o0000olN[__o7Zkh00_o7Zkh00ol0003oY:3AojBPd@02ojBPd@03o`000?nW
`>co000000;o000000?oYl3/o`000?nW`>`00onW`>`01_l0003oYl3/o`000?l0003oYl3/o`0000Go
Yl3/0_l0000Eooooo`03o`000?oooooooooo017ooooo000Rooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool01?l0003oooooo`000?nW`>`2o`0000;oYl3/00?o0000ojO0k?nW`>`00_nW`>`01?l0
003oYl3/o`000?l00002ojO0k003o`000?nW`>coYl3/00;oYl3/0ol00003ojO0k003o`000?nW`>co
Yl3/00;oYl3/0ol00004ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004
o`0000CoYl3/00?o0000ojO0k?nW`>`01?l00004ojO0k005o`000?nW`>coYl3/ojO0k?l000000_m[
SN401?l0003oFG3@o`000?l00002ofIid@Wo00000on3S]H8o`0000;oUj?N00?o0000oibYgonLZMl0
0_nLZMl00ol0003oXJkQoj6^h@02oj6^h@Co00000_nV_NX00ol0003oZ;kYojRnj@03ojRnj@?o0000
0onVbO801?l0003oZ<K_ojS6konXa^l4o`0000CoXL_e00?o0000ojS4kOnXa>d01Ol00002ojC3l003
o`000?n_^n?o[k_S00?o[k_S00Ko0000okNde_l0003o0000ojnhh?l00005okVbdP03o`000?o0[LOo
000000Co_:o=00Ko0000olB/`_o4[<;o0000ol6]a_l00006olN[_@03o`000?o;Z[SobjZh00CobjZh
00?o0000olnZ/oo?Z[<00_o?Z[<00ol0003ocj^eo`000004om:Z/003o`000?oBZk7o000000;oe:^_
00Oo0000omF/[ooE[:ooeJb_o`000?o?ZK?o000000?oeZf^00?o0000omR^[_l000000_o=Z[L01_l0
003oejn`omN_/?l0003o[io8o`0000Goaj^n00?o0000ojBPdOnTX=400_nTX=42o`000003ojO0k?l0
003oYl3/00;oYl3/00?o0000ojO0k?nW`>`00ol00004ojO0k003o`000?nW`>co000000;o000000?o
Yl3/o`000?ooool05Oooool00ol0003oooooooooo`0@ooooo`008_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo00?o0000ooooooooool00_l00004ojO0k003o`000?nW`>coYl3/00Co00001?nW
`>`01?l0003oYl3/o`000?l00002ojO0k003o`000?nW`>coYl3/00;oYl3/00Co0000ojO0k?l0003o
00000_nW`>`00ol0003oYl3/ojO0k002ojO0k0?o00000_nW`>`00ol0003oYl3/ojO0k002ojO0k0?o
00001?nW`>`00ol0003oYl3/ojO0k004o`0000CoYl3/00?o0000ojO0k?nW`>`02_l00002oeU`d004
o`000?mVNM7oIWWAo`0000?oLh;D00?o0000ogj<e_mnS=H01?l00002ohRDf@05o`000?n@W=_oT9cK
oi2Lfol000001?nGXmh00ol0003oW:WOoibYg`02oibYg`04o`000?nQ[^7o0000o`0000;oXk[Y00?o
0000ojJmj_nV_NX00_nV_NX00ol0003oZ;kYo`000002o`000003ojG;m?l0003oY/Wb00?oY/Wb1?l0
0003oicAnP04o`000?nQboGoXL_eoj7;m@Co00000onGc?X00ol0003oY<?`ojC3l002ojC3l004o`00
0?n_^n?o[k_Sojnkh`?o00001?n_^>000ol0003o^K;BokVbdP02okVbdP;o00001Onl[ld00ol0003o
a:c2o`000003ol6]aP03o`000?o7Zkgoaj^m00;oaj^m00?o0000olJ/`?l000001?o;Z[P00ol0003o
bj^jo`000003olnZ/`03o`000?o?ZkGo000000?odZZ`00Ko0000om:[/OoBZk7o0000omB[[ol00005
omF/[`03o`000?oF[JkoeZf^00;oeZf^00?o0000omR^[_l000000_o=Z[L01Ol0003oejn`omN_/?oG
[k3o000000Goaj^n00?o0000omNc]?l000000_nTX=400ol0003o_Jg9o`000002ojO0k003o`000?nW
`>co000000?o00000onW`>`00ol0003oYl3/ojO0k003o`0000GoYl3/00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0@ooooo`008_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o
0000ooooooooool00_ooool00ol0003oYl3/ojO0k004o`0000CoYl3/00?o0000ojO0k?nW`>`01?l0
0004ojO0k003o`000?nW`>coYl3/00Co00001?nW`>`01_l0003oYl3/o`000?l0003oYl3/o`0000Co
Yl3/00Co0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k002ojO0k0?o00000onW`>`00ol0
003oYl3/ojO0k002ojO0k0?o00000onW`>`4o`000003odaWcOl0003o000000?oFG3@00Co0000ofIi
dOmVNM7o00000omcP]@01?l0003oOXcFogj<e_l00005ohRDf@05o`000?n@W=_oT9cKoi2Lfol00000
1?nGXmh00ol0003oW:WOoibYg`03o`0000GoXk[Y00?o0000ojJmj_nV_NX01?l00004ojG;m004o`00
0?nVbO;o0000o`0000?oV]Km00?o0000oicAn_nLdOX01Ol00003ohWBo`03o`000?nGc?[oUlcj00;o
Ulcj00?o0000ojC3l?nT`o001Ol00002oj70k`03o`000?n_^>3o[kSP00;o[kSP00?o0000okVbd_l0
00000_l000000onb]=_o0000okb_c@04okb_c@;o00001Oo1[LH01?l0003oaj^molN[_Ol00002olJ/
`005o`000?o;Z[SobjZhol^Z^?l000000_o;ZkX01?l0003ocjZcolnZ/ol00003oln[]@03o`000?oB
Z[3o000000CodZ^a0_l00005omF/[`05o`000?oF[JkoeZf^omJ][_l000000_oH[Zh00ol0003ocJZg
o`000004omN_/003o`000?o7Zkkoaj^n00?oaj^n00Go0000omNc]?l0003oY:3Ao`000003okf]b@06
o`000?nW`>co0000o`000?nW]>;o00001OnW`>`3o`0000?oYl3/00Co0000ojO0k?nW`>coYl3/0ol0
000Eooooo`03o`000?oooooooooo00oooooo000Rooooo`05o`000?ooooooooooooooool000001_oo
ool2o`0000Cooooo0_l00003ojO0k003o`000?nW`>coYl3/00;oYl3/0ol00004ojO0k003o`000?nW
`>coYl3/00Co00001?nW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/00?o0000ojO0k?nW`>`01?l0
0004ojO0k004o`000?nW`>co0000o`0000;oYl3/00?o0000ojO0k?nW`>`00_nW`>`01?l0003oYl3/
o`000?l00002ojO0k003o`000?nW`>co000000?o00000_mjZ?000ol0003oC6O=odaWc@04o`0000?o
IWWA00Go0000og>2e?mcP]CoLh;Do`000002ogj<eP03o`000?n8U=WoR9CI00;oR9CI00Go0000oi2L
fon@W=_oT9cKo`000003oiNSgPCo00000_nP]NL00ol0003oXk[Yoj>jj@03oj>jj@?o00001?nUbo@0
0ol0003oYL_dojG;m005o`0000;oV]Km1?l00004ogoGo`03o`000?n9d_ooRM;o00Wo00000_n;ao`0
0ol0003oXL3_oj70k`03oj70k`03o`000?n_^>3o[kSP00?o00001Onb]=/00ol0003o_:o=okb_c@02
o`000003okNadol0003o`Jg600Co`Jg600?o0000olN[_Ol000000oo6[<001?l0003objZhol^Z^?l0
0003ol^[^P03o`000?o?Z[?o000000Cocj^e00?o0000om:Z/?l000001?oBZk400ol0003oeJb_omF/
[`03omF/[`03o`000?oF[Joo000000;oeZf^00Co0000omR^[_oH[Zkof:j^0_l00003omN_/003o`00
0?oJ/Zoo000000?oaj^n00Go0000omNc]?oG/kCoek>do`000005okf]b@03o`000?nW]>;o000000;o
YkCR00?o0000ojO0k?l000000_l000000onW`>co0000ojO0k003ojO0k0Co00000_nW`>`00ol0003o
ooooooooo`0Cooooo`;o00004?ooool002;ooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo00Gooooo00?o0000ojO0k?nW`>`00_nW`>`01?l0003oYl3/o`000?l00002ojO0
k003o`000?nW`>coYl3/00;oYl3/0ol00003ojO0k003o`000?nW`>coYl3/00;oYl3/0ol00003ojO0
k003o`000?nW`>coYl3/00Co00001?nW`>`00ol0003oYl3/ojO0k004o`0000CoYl3/00?o0000ojO0
k?nW`>`01?l00002ojO0k0?o00000_nW`>`5o`0000;oC6O=00?o0000oeabd?mLL]001Ol00003og>2
e005o`000?mnS=KoOXcFogj<e_l000000on8U=T00ol0003oT9cKoi2Lf`05o`0000;oW:kT00?o0000
oj2eionP]NL00_nP]NL00ol0003oXk[Yo`000002o`0000;oYLSb00Co0000ojG;m?nUboCoYL_d1?l0
0003oi_Io@Co00000_mmfo`9o`0000CoElSf00Go0000og3:oom`b_ooL<[oo`000003oh_7o004o`00
0?nQ`>ooXL3_oj70k`Co00000onQ^n`00ol0003o/[CKok:df`02ok:df`03o`000?nl[lgo000000Co
]k7C00?o0000ol6]a_o1[LH00_o1[LH2o`0000GoaZc00_l00005ol^[^P;o00001Oo?ZkD00ol0003o
dZ^aom:[/@03om:[/@03o`000?oE[:ooeJb_00;oeJb_00Ko0000omJ][ooF[Joo0000omJ][_l00004
omR^[P03o`000?oG[k3oejn`00;oejn`00Ko0000omZb[ooJ/Zoo0000olN[__l00004omNc]003o`00
0?nm[LWo_Jg900?o_Jg900Go0000ojNdh_nW]>;o0000ojNdhP02o`0000GoYl3/00Ko0000ojO0k?l0
003o0000ojO0k?l00005ojO0k003o`000?oooooooooo01?ooooo00?o0000ooooooooool03_ooool0
02;ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo00Kooooo00?o0000
ojO0k?nW`>`01?l00004ojO0k004o`000?nW`>co0000o`0000;oYl3/00?o0000ojO0k?nW`>`00_nW
`>`01?l0003oYl3/o`000?l00002ojO0k004o`000?nW`>coYl3/ojO0k0?o00000onW`>`00ol0003o
Yl3/ojO0k002ojO0k0?o00001?nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/0ol000000onW`>co
0000o`000002o`0000;oW[g_00?o0000ocaMb_l000000om<Ild01?l0003oG7;@oeabd?l00002of]m
d`oo00000onFY^400ol0003oW:kToib^i002oib^i003o`000?nP]NOoX;GW00Co00001?nUb?84o`00
00?oX=[l1?l00002ohGPnago00000_n5`O/00ol0003oXK_/oj6kk003oj6kk003o`000?nb]=_o/[CK
00?o00001Ong/M<00ol0003o`Jg6ol6]aP02o`000003okf_c?l0003oaZc000CoaZc000?o0000ol^[
^_o;ZkX01?o;ZkX00ol0003ocj^eoln[]@04oln[]@03o`000?oBZk7odZ^a00;odZ^a00?o0000om>]
/_l000000ooE[:l01_l0003oeZf_omJ][ol0003oeZf^o`0000Cof:j^00Go0000omN_/?oG[k3oejn`
o`000003omZb[`03o`000?o7Zkko000000?oek>d00?o0000omZf]?l000000onm[LT01?l0003ockG1
o`000?nW]>82o`0000;o/:oG00Co0000ojO0k?nW`>coYl3/0ol00004ojO0k003o`000?nW`>coYl3/
00?o00005_ooool00ol0003oooooooooo`0=ooooo`008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo00?o0000ooooooooool01oooool2o`0000CoYl3/00?o0000ojO0k?nW`>`01?l00004ojO0
k003o`000?nW`>coYl3/00Co00001?nW`>`00ol0003oYl3/o`000002ojO0k003o`000?nW`>coYl3/
00;oYl3/00Co0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k002ojO0k0?o00000onW`>`4
o`000004ojO0k?l0003o0000o`0000?oYl3/00Ko0000oijmkonN_NooW[g_o`000?llGLX2o`000003
odaWcOl0003oG7;@00;oG7;@00Co0000of]mdom[OM?o00000omiR=H01Ol0003oQI?JohFCf_n5Tm[o
000000CoSYgM00?o0000oiJVhOnFY^400_nFY^400ol0003oW:kToib^i004o`0000CoYL?_00Co0000
ojG8l_l0003o00000onVfOX01?l0003oX=[lo`000?l00003oi;Un`co000000KomNZjo`000?odi;[o
m>Bjo`000?oag;X2o`000003onSF`ol0003o000000Wo00000on5`O/01?l0003oXK_/oj6kk?nQ^n`4
o`0000;oY[OU00?o0000okNadong/M<00ong/M<00ol0003o`Jg6o`000004okf_c004o`000?o6[<3o
aZc0olJ/`0;o00001_o;ZkX00ol0003ocj^eoln[]@03oln[]@03o`000?o>[;Oo000000?odZ^a00?o
0000om>]/_l000000_oE[:l00ol0003oeZf_omJ][`02omJ][`03o`000?oH[Zkof:j^00;of:j^00?o
0000omVa[ol000000_oG[k000ol0003of[:_omZb[`02omZb[`03o`000?oG/kCoek>d00;oek>d00?o
0000omZf]?l000000_nm[LT01ol0003ockG1olne`Oo?]L7o0000ok2_eol000000_n`[mL4o`0000;o
Yl3/00Co0000ojO0k?nW`>coYl3/1?l00003ojO0k003o`000?oooooooooo01Cooooo00?o0000oooo
ooooool03?ooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo
00Sooooo00?o0000ojO0k?nW`>`00_nW`>`3o`0000CoYl3/00?o0000ojO0k?nW`>`01?l00004ojO0
k003o`000?nW`>coYl3/00?o00001?nW`>`00ol0003oYl3/ojO0k004o`0000CoYl3/00Co0000ojO0
k?l0003o00000_nW`>`00ol0003oYl3/o`000003o`000005ojO0k?l0003o0000ojO0k?l000001?nW
`>`3o`000005oijmkol0003o?5g:o`000?m?JLd00_l00003oeabd005o`000?m[OM?oJggCof]mdol0
00000omiR=H01Ol0003oQI?JohFCf_n5Tm[o000000CoSYgM00?o0000oiJVhOnFY^401?l00003oj>l
j`03o`000?nU`nooYL?_00;oYL?_0ol00004ojKInPCo000000?oT^Gko`000?l000001?l000001oo=
o;Wo0000o`000?l0003ol_Bjo`000?odl;X00_l00002ooCT^P06o`000?oag;[olMbjo`000?o]e;[o
00000ooRbl401?l0003ofl6oom_1_ooK`Kl;o`0000;oQk_g00?o0000ojJgiOnV]nD00_nV]nD00ol0
003o]k7CokNad`02okNad`;o00001Onm[l`01?l0003oaZc0olJ/`?l00002ol>]a003o`000?o;Zk[o
bj^j00;obj^j00?o0000olV/_Ol000000oo?ZkD01?l0003ocZbgolj/]ol00002om:[/@04o`000?oC
[K;odjfbo`0000;oeJb_00?o0000omJ][ooF[Jl00_oF[Jl00ol0003of:j^omR^[P02omR^[P05o`00
0?oI/Joo0000omN_/?l000001OoJ/Zl01Ol0003oek>domNc]?oG/kCo000000;of[Jd00?o0000okf]
bOl000001?o?]L400ol0003o/:oGok2_e`02o`000003ol6hdOl0003oYl3/00?oYl3/1?l00002ojO0
k003o`000?nW`>coYl3/00;oYl3/0_l0000Eooooo`03o`000?oooooooooo00cooooo000/ooooo`03
o`000?oooooooooo00Wooooo00Co0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k002ojO0
k0?o00000onW`>`00ol0003oYl3/ojO0k002ojO0k0?o00000onW`>`00ol0003oYl3/ojO0k004o`00
00CoYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k0;o00000_nW`>`3o`0000CoYl3/00Oo0000ojO0
k?l0003o0000ojO0k?l0003o@g7I00;o00000_llGLX00ol0003oCfW=odmYc@04o`0000?oJggC00Go
0000ogV8e_miR=KoNHSFo`000003ohFCfP04o`000?n>WMgoSYgMohjMg@Co00000onN/^H00ol0003o
Xkc[oj>lj`02oj>lj`04o`000?nU`noo0000o`0000?oZMCf00Co0000ojKIn_l0003o00000_nQio/6
o`000003oi3X/?l0003o000000?o000000Kol_Bjo`000?odl;[o0000ooGZ^_l00002ooCT^P03o`00
0?oag;[o000000;okMBj0_l000000ooRbl7o0000om_1_`02om_1_`03o`000?oD]kgo000000;obK72
1ol00003ohNkm`03o`000?nV]nGoY[OU00;oY[OU00Ko0000okNadol0003o0000ojfcg?l00005okf_
c003o`000?o6[<3o000000Co`jg400Co0000ol^[^_o;Zk[o00000_o9[;d01?l0003ocj^eoln[]Ol0
0003olj/]`03o`000?oBZk7o000000Codjfb0_l00004omJ][`03o`000?oG/;3o000000;of:j^00Ko
0000omVa[ooI/Joo0000omN_/?l00004omZb[`03o`000?oL]K3o000000;oek>d00Go0000omZf]?oJ
][Cof[Jdo`000004olne`@04o`000?oH^kco0000ok2_e`;o00000_o1^=401_l0003oYl3/o`000?l0
003oYkOUo`0000GoYl3/00Ko0000ojO0k?l0003o0000ojO0k?l0000Fooooo`03o`000?oooooooooo
00_ooooo000/ooooo`;o00002oooool2o`0000CoYl3/00Co0000ojO0k?l0003o00000_nW`>`00ol0
003oYl3/ojO0k002ojO0k006o`000?nW`>co0000o`000?nW`>co00001?nW`>`3o`0000?oYl3/00?o
0000ojO0k?nW`>`00_nW`>`3o`0000CoYl3/1ol00003ojO0k003o`000?nW`>coYl3/00Co00000onW
`>`00ol0003o@g7Iod=af@02o`000004ocaMb_l0003oCfW=o`0000;oHWKA1Ol00003ogV8eP03o`00
0?n5Tm[oQI?J00Go00000_nGZ>800ol0003oW[;VoijbiP03oijbiP03o`000?nS_>_oXkc[00Co0000
0onYe?H7o`000003oiC^l_l0003o000000Go000000OocObio`000?o^n;_o0000oo;d^_l0003om?2j
00;o00000_odi;X01_l0003olMbjoo7L^_l0003okMBjo`0000;oj<bj00Go0000om_1_ooK`Koofl6o
o`000002omBg_@03o`000?o9/L;o000000;o`jNn0ol000000ol4R]_o0000o`000003o`0000?oY[OU
0ol00004ojfcg003o`000?nm[lco_Jo<00;o_Jo<0_l00005ol>]a003o`000?o;Zk[o000000?obJbm
00Co0000oln[]Oo?ZkGo00001?o>[;L2o`0000Codjfb00?o0000omJ][ooF[Jl00ooF[Jl00ol0003o
ek2`o`000002omR^[P05o`000?oI/JoofK6_omVa[ol000001OoJ/Zl01Ol0003og;F`o`000?oG/kCo
000000Cof[Jd00Go0000olne`Oo?]L7ockG1o`000003omRk_004o`000?o1^=7o`KSAo`0000;o`KSA
00?o0000ojNgiOnW]nD00_nW]nD01?l0003oYl3/ojO0k?nW`>`3o`0000CoYl3/00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`0=ooooo`03o`00
0?nW`>coYl3/00Co00001?nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00Co0000ojO0k?l0003o
00000_nW`>`00ol0003oYl3/ojO0k002ojO0k004o`000?nW`>co0000o`0000;oYl3/00?o0000ojO0
k?l000001Ol00003ojO0k003o`000?nW`>coYl3/00Co00001?nW`>`02?l0003oYl3/ojO0k?nW`>co
0000od=afOl0003o?Ug90_l00002odmYc@04o`000?mRM]7oHWKAo`0000;oLX?E1ol00002ohfLg@03
o`000?nGZ>;oUjSR00?oUjSR00?o0000oijbi_nN/^H00_nN/^H3o`0000?oZlca1?l00002ojgTn@04
o`000?n/lOKo[?7fojcamP;o000000?oW_CFo`000?l000000ol000001oo=o;Wo0000o`000?l0003o
l_Bjo`000?odl;X00_l00003ooCT^P03o`000?oag;[o000000;okMBj00Co0000onS<^_oXc;[o0000
0ooK`Kl01Ol0003oe;NmomBg_OoD]kgo000000Co`jNn00?o0000okJO`Ol000000ol000000omH[_[o
0000o`000002o`0000;oT;K`00?o0000ojfcg?n]/m`00_n]/m`00ol0003o_Jo<o`000002o`000003
okN`dol0003o`jg400Co`jg40_l00005olV/_@;o00001Oo>[;L00ol0003odjfbom>]/P03om>]/P03
o`000?oF[JooeZf_00;oeZf_00Ko0000omN`/?oG/;3o0000omR^[_l00004omVa[`03o`000?oJ/Zoo
f[:_00;of[:_00Ko0000ombe/?oL]K3o0000omNc]?l00003omZf]003o`000?oN^[Co000000;ockG1
00Go0000omRk_?oH^kcof;^lo`000002ol6hd@04o`000?o1^=7o0000o`0000CoYkOU1?l00003ojO0
k003o`000?nW`>coYl3/00?o00005Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003o
ooooooooo`0>ooooo`;o00001?nW`>`00ol0003oYl3/ojO0k004o`0000CoYl3/00?o0000ojO0k?nW
`>`00ol00004ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`3o`000005ojO0k?l0003o0000ojO0
k?l000001?nW`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`00_nW`>`5o`0000;o@g7I00?o0000ociM
bOlnGLT00_l000001Om?JLgo0000of9fdOmRM]7o000000;oLX?E00Go0000oh6@fOn1T=WoPI3Io`00
0004ohfLg@03o`000?nGZ>;oUjSR00;oUjSR00?o0000oijbi_l000000_l00002ojS1k004o`000?n[
c?7o0000o`0000?o/]ce00?o0000ojgTnOl000000_n/lOH6o`000003olCmb?l0003o000000Co0000
00Kol_Bjo`000?odl;[o0000ooGZ^_l00002ooCT^P03o`000?oag;[o000000;okMBj00So0000onS<
^_oXc;[o0000on;4^_l0003ofl6oo`0000Coe;Nm00?o0000ol>W__o3Ykh00oo3Ykh01?l0003o/INm
ok6G_OnaUkd5o`0000CoT;K`00Co0000ojfcg?n]/mco[K?L0_l00005okN`d`07o`000?o3[LCo`jg4
ol>]a?l0003o_jo9o`000005olV/_@03o`000?o>[;OocZbg00CocZbg00?o0000om>]/_oC[K800_oC
[K800ol0003odjndo`000003omJ][`04o`000?oG/;3oek2`omN`/0;o00000ooI/Jl00ol0003ofk>`
o`000003omZb[`05o`000?oL]K3og;F`ombe/?l000001?oJ][@01Ol0003og[Zdo`000?o?]L7o0000
00?of;^l00?o0000ombo_Ol000000_o1^=401Ol0003oc[o<oljoc?l0003oYkOU00;o000000?o/;_R
o`000?nW`>`01?nW`>`3o`0000?oYl3/00?o0000ooooooooool04oooool00ol0003oooooooooo`09
ooooo`00:oooool00ol0003oooooooooo`0?ooooo`03o`000?nW`>coYl3/00;oYl3/0ol00004ojO0
k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/0ol000000onW
`>co0000o`000002o`0000?oYl3/00Co0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k002
ojO0k004o`000?nW`>co0000o`0000;oYl3/00?o0000ofFVmOl000000_l000001Om3LMWo0000ociM
bOl0003oE6c>00;o00000omRM]401?l0003oLX?Eog:3eOl00003oh6@f@03o`000?n=W=goSIcM00;o
SIcM00?o0000oiNXh_nGZ>801?l00004ojS1k0?o00001?nbg?D:o`000003olCmb?l0003o000000?o
000000Gok_Rko`000?obm;[o0000ooC`^P04o`000006ooCT^_l0003olMbjo`000?o]e;[o00000ooX
c;X01?l0003oh/Bjon;4^_l00004omBg_@03o`000?o=[[_o000000?o`jNn0_l00004ok6G_@;o0000
00?o48_Uo`000?l000001?l000001On]/mco0000o`000?nN/nOo000000Go]k3C00Co0000ol>]a?o3
[LCo00000ono[lT01?l0003obJbmolV/_Oo9[;d2o`0000GocZbg00?o0000olj^^_l000000ooC[K80
1_l0003odjndom>_]?l0003oeZf_o`0000Coek2`00?o0000omVa[ooI/Jl00_oI/Jl01_l0003ofk>`
om^c/?l0003of[:_o`0000Cog;F`00Go0000omZf]?oJ][Cof[Jdo`000003omjj]003o`000?oH^kco
f;^l00;of;^l00Oo0000ombo_Ol0003o`KSAo`000?o>_lco000000;oc[o<00?o0000ok2kh_n`^n80
0_n`^n800ol0003oYl3/o`000002o`000003ojO1k?l0003oYl3/00?oYl3/0_l0000Cooooo`?o0000
2_ooool002_ooooo00?o0000ooooooooool04?ooool01?l0003oYl3/o`000?l00002ojO0k003o`00
0?nW`>coYl3/00;oYl3/0ol00002ojO0k003o`000?nW`>coYl3/00;oYl3/0ol00004ojO0k0Oo0000
1?nW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/00?o0000ojO0k?nW`>`01?l00004ojO0k004o`00
0?mUY_Go0000obY?a0;o00000_lnGLT00ol0003oE6c>oeA/cP04o`0000?oLX?E00Go0000oh6@fOn1
T=WoPI3Io`000002ohfLg@Co00001?nR]NH01?l0003oZ<7/o`000?l00003ok?Al005o`000?nbg?Go
0000o`000?njk?D00_l000001?nnmnoo0000ol7mhoo1oN<4o`000004on7mbOl0003o0000on[j_@Ko
000000Com^>eo`000?oeg[GomMje1?l000001Oo]e;[o0000onS<^_oXc;[o000000?oh/Bj00Go0000
omBg_OoD]kgoe;Nmo`000002olf^^`04o`000?o3Ykko`jNno`0000;o_9nk00?o0000ok6G_OnaUkd0
0_naUkd3o`000004oa2;iOl0003oK:khofb^n0;o00001?nN/nL00ol0003o]k3CokN`d`02okN`d`03
o`000?o3[LCo000000Co_jo900Co0000olV/_Oo9[;go00000_o7[/401Ol0003ocZbgolj/]oo>[;Oo
000000;ocZjj00Co0000om>]/_oC[K;o00000ooC[k@00ol0003oeZf_o`000004omN`/005o`000?oI
/JoofK6_omVa[ol000000ooK/k000ol0003of[:_o`000003ombe/005o`000?oO^K7o0000omZf]?l0
00001?oN^[@01Ol0003of;^lomRk_?oH^kco000000?og;nm00Go0000oljoc?o>_lco0000oljoc002
o`0000Co/;_R0_l00005ojO1k0Co000000?oYl3/o`000?ooool03oooool3o`0000;ooooo00?o0000
ooooooooool02?ooool002_ooooo0_l0000Booooo`;o00001?nW`>`01?l0003oYl3/o`000?l00002
ojO0k006o`000?nW`>coYl3/ojO0k?l0003oYl3/0_l00002ojO0k003o`000?nW`>co000000Go0000
0onW`>`00ol0003oYl3/ojO0k002ojO0k0?o00000onW`>`00ol0003oYl3/ojO0k004o`0000CoYl3/
00?o0000ojO0k?nW`>`00ol000001?mUY_Go0000obY?a?lZCl@3o`0000;oE6c>00?o0000ofYldomZ
O=<02ol00003oiRXh@03o`000?nR]NKoX[GV00;oX[GV0_l00005ok?Al0?o000000Go^^ceo`000?nn
mnoo__O_o`000002ol7mh`Co000000CohOg9o`000?l0003oj_Zm0ol000000ooek;So0000ooKX]P02
o`0000?omMje00Go0000oo?I]Ol0003ol=>eo`000002onS<^P09o`000?oRa;[oh/Bjon;4^_l0003o
g;bio`000?oD]kgo000000?ocJjk00?o0000ol>W__l000000onlWk/01?l0003o/INmok6G_OnaUkd3
o`000004oj69^_l0003o0000o`0000;oK:kh00?o0000oijcionN/nL00onN/nL01?l0003o]k3CokN`
dong/=<2o`0000Go_jo900?o0000olV/_Ol000001?o7[/401?l0003ocZbgolj/]ol00002olj^^P03
o`000?oC[K;o000000Godjnd00?o0000omN`/?oG/;000_oG/;000ol0003ofK:bo`000002omVa[`03
o`000?oK/k3ofk>`00;ofk>`00?o0000ombe/?oL]K000_oL]K001Ol0003ogkVao`000?oJ][Co0000
00?og[Zd00Go0000on6n]Ol0003of;^lo`000004ombo_@05o`000?o>_lcoc[o<oljoc?l000000_oC
aL`01?l0003o/;_Ro`000?l00002okS1h003o`000?nW`NcoYl7/00?o00001OnW`>`00ol0003ooooo
ooooo`0:ooooo`?o00001Oooool00ol0003oooooooooo`08ooooo`00:oooool00ol0003ooooooooo
o`0Cooooo`03o`000?nW`>coYl3/00Co00001?nW`>`00ol0003oYl3/ojO0k003o`0000?oYl3/0_l0
00000onW`>co0000o`000002ojO0k003o`000?nW`>coYl3/00;oYl3/00Ko0000ojO0k?l0003o0000
ojO0k?l00004ojO0k0?o00001?nW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/0ol00002obY?a003
o`000?m4H<[o000000?oE6c>00Co0000ofYldomZO=?o00000omlS=L01Ol0003oS9[LohbJg?n<V]co
000000GoV:SQ00Co0000oj:ei_l0003o00000_n^`nX00ol0003o/m7`o`000002o`0000;o_^3`2?l0
00001?oGo=go0000o`000?oQoLT4o`000008ooC_^ol0003omNbho`000?ofj;Ko0000ooKS]Ol00002
ooGN]@03o`000?ocfKGo000000;ol=>e0_l000001OoXc;[o0000on;4^_oRa;[o000000?og;bi00?o
0000olf^^oo=[[/00oo=[[/00ol0003o_9nkokbO^`02okbO^`06o`000?naUkgo0000o`000?n]TKWo
00001?nQRKX5o`0000CoW[?W00Ko0000okN`dol0003o0000ojfafol00005okn_b@;o00001Oo7[/40
0ol0003ocZbgo`000004olj^^P;o00001OoC[k@00ol0003oek2`omN`/002omN`/005o`000?oI/[;o
0000omVa[ol000001OoK/k001Ol0003og;F`ombe/?oL]K3o000000?ogkVa00?o0000omjj]?oN^[@0
0_oN^[@01Ol0003ohKjeo`000?oH^kco000000?og;nm00Oo0000omo5__l0003oc[o<o`000?oCaLco
000000;odlG<00?o0000okS1h?nh`N000_nh`N03o`0000?oYl;]00?o0000ojO0k?nW`>`00ol00008
ooooo`Co00002?ooool00ol0003oooooooooo`08ooooo`00:_ooool00ol0003oooooooooo`0Eoooo
o`;o00001?nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/1ol00004ojO0k003o`000?nW`>coYl3/
00?o00001?nW`>`01?l0003oYl3/o`000?l00002ojO0k003o`000?nW`>coYl3/00;oYl3/0ol00002
ojO0k003o`000?nW`>coYl3/00;oYl3/0_l00003obY?a006o`000?m4H<[o0000o`000?mDK<ko0000
0omZO=<01Ol0003oO8cGogb<eomlS=Oo000000?oS9[L00Co0000oiRXhOnHZ>7oV:SQ0ol00004ojk3
jP?o00000onnh?001ol0003ob>g]olS]kOo8kNgo0000om7gi_l000000_oGo=d2o`0000;ohOg90_l0
00000ooal[oo0000o`000002ooG/^004o`000?ofj;Ko0000o`0000;omMje00Ko0000oo?I]OocfKGo
0000oo3C]Ol00002onc=]@05o`000?oRa;[oh/Bjon;4^_l000000ooL_;T00ol0003ocJjkolf^^`02
olf^^`;o00001OnlWk/00ol0003o[I6iojfA^@02ojfA^@08o`000?nQRK[oXHVjoj69^_l0003oU8:l
o`000?lbU_47o`0000Co[K7K00?o0000okn_bOno[lT00_l000000onj/=3o0000olN^`@04olN^`@;o
00001Oo>[[X00ol0003odjndom>_]003om>_]003o`000?oD/KOo000000;oek2`00Ko0000omVb/_oI
/[;o0000omVa[ol00004om^c/003o`000?oM]k7o000000;og;F`00Go0000omni/OoO^K7ogkVao`00
0003omjj]005o`000?oQ_[GohKjeon6n]Ol000000ooL_kd01Ol0003oglFnomo5__oOaKko000000?o
dlG<0_l000000ooGblko0000okS1h002o`0000;o_/KP00?o0000ojO2kOnW`^d01?l00003ojO0k003
o`000?oooooooooo00;ooooo0ol0000<ooooo`03o`000?oooooooooo00Sooooo000Zooooo`03o`00
0?oooooooooo01Kooooo00?o0000ojO0k?nW`>`00_nW`>`3o`0000?oYl3/1ol00004ojO0k003o`00
0?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004o`0000CoYl3/00Ko0000ojO0k?l0003o
0000ojO0k?l00004ojO0k006o`000?nW`>coYl3/ojO0k?l0003o5TC00_l000001OlZClCo0000odAP
b_l0003oGG;@00;o00000omZO=<01Ol0003oO8cGogb<eomlS=Oo000000;oS9[L1Ol00002ojFei005
o`000?n^`n[o[/?Zojk3j_l000000onkd^/00ol0003o_^3`o`000003olS]k@03o`000?oAmnKo0000
00;oeocM0_l00002on7mb@;o000000[olO:oo`000?odkk_o0000ooG/^?l0003om^Rfo`000?ofhkGo
00000_oeg[D00ol0003olmVeo`000002oo3C]@03o`000?o/cKGok<fe00;o000000?oh/Bjo`000?oL
_;T00_oL_;T00ol0003oe[Bho`000002olf^^`04o`000?o6Y[WoaZJio`0000?o_9nk0_l00004ojfA
^@05o`000?nQRK[oXHVjoj69^_l000000_nDP[`3o`0000CoQZo`00?o0000ojfafon]/M/00_n]/M/0
0ol0003o_jo9o`000004okZ`d007o`000?o7[/7oajk1olN^`Ol0003oaK36o`000005olj^^P03o`00
0?oC[kCodjnd00?odjnd00?o0000omBa]ol000000_oG/;001Ol0003ofK:bomVb/_oI/[;o000000Go
fk>`00Go0000omfg/Ol0003og;F`o`000003omni/@05o`000?oR_K?o0000omjj]?l000001?oQ_[D0
1Ol0003og;nmombo_OoL_kgo000000?oglFn00Go0000om?5c?oCaLcodlG<o`000003omO;cP03o`00
0?nna^3o_/KP00;o_/KP0ol00002ojG0k@03o`000?nW`>coYl3/00;oYl3/1Ol0000@ooooo`03o`00
0?oooooooooo00Oooooo000Zooooo`03o`000?oooooooooo01Oooooo00Co0000ojO0k?l0003o0000
0_nW`>`00ol0003oYl3/o`000004o`0000?oYl3/00?o0000ojO0k?nW`>`00_nW`>`3o`0000?oYl3/
00?o0000ojO0k?nW`>`01?l00004ojO0k003o`000?nW`>coYl3/00?o00001?nW`>`00ol0003oYl3/
ojO0k006o`000003oaI4`?l0003o;U7400;o00000_m4H<X00ol0003oGG;@oeebd00:o`0000;oV:KO
00?o0000ojFei?nU]N@00onU]N@00ol0003o[/?Zo`000004ok_Bj`Co000000Cob>g]o`000?oAmnKo
00000_oGo=d6o`0000;olO:o0_l00002ooG/^007o`000?ofj;Ko0000ooKS]Ol0003omMjeo`000002
oo?I]@03o`000?o`dkGo000000;ok<fe00Co0000onO7]_oWakKo00000ooL_;T01_l0003oe[BhomJd
^?l0003ocJjko`0000?oaZJi00Ko0000okbO^onlWk_o0000okNH^?l00004ojfA^@03o`000?nQRK[o
XHVj00;oXHVj00Co0000oiB2_?nDP[coU8:l0_l00004ohJ_l003o`000?n]/M_o[K7K00?o00001Onj
/=001?l0003oajk1olN^`Ol00003olF`aP07o`000?o>[[[ocZjjolj^^_l0003ocK6mo`000003om>_
]006o`000?oD/KOoe;6go`000?oG/;3o00001?oI/[800ol0003ofk>`om^c/002om^c/006o`000?oM
]k7ogKNao`000?oL]K3o00000ooO^K401Ol0003oh[fco`000?oN^[Co000000?ohKje00Go0000onC4
^?l0003og;nmo`000003omo5_P08o`000?oRc<7o0000om?5c?l0003oel_>o`000?oGblh2o`0000;o
_/KP0_l000000oo3bn7o0000ojG0k@03ojG0k@06o`000?nW`>co0000o`000?nW`^go00004oooool0
0ol0003oooooooooo`07ooooo`00:_ooool00ol0003oooooooooo`0Hooooo`;o00000_nW`>`3o`00
0005ojO0k?l0003oYl3/ojO0k?l000001?nW`>`01?l0003oYl3/o`000?l00002ojO0k004o`000?nW
`>coYl3/ojO0k0?o00001?nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`0
1?l00003ojO0k003o`000?l`O^Oo000000?o000000Go;U74o`000?l0003oA63:o`000002oeebd005
o`000?mdQ=GoM8CEogB4eOl000000on8U]X00ol0003oV:KOoiRVg`02oiRVg`03o`000?nU]NCoYKGT
00;oYKGT0ol00003ok_Bj`04o`000?o8gnWob=oYolSOj@Oo000000Coi?CEo`000?oZmLgoj_G=0_l0
00002_oal[oo0000ooC_^ol0003omNbho`000?ofj;Ko0000ooKS]Ol00002ooGN]@03o`000?ocfKGo
000000;ol=>e00Co0000onc=]Oo/cKGo00000_oWakH01Ol0003og;biombl^OoL_;Wo000000?oe[Bh
00?o0000olJV^Oo6Y[T00_o6Y[T00ol0003o_9nko`000003okNH^003o`000?n]TKWo[I6i00;o[I6i
00?o0000oj69^_l000003_l00002oijai@03o`000?nj/=3o^[3@00?o^[3@00?o0000olN^`Ol00000
1?o5/<H01?l0003ocZjjolj^^_l00003olfa_@03o`000?oC[kCo000000Coe;6g0_l00003omVb/P03
o`000?oJ][Go000000?ofk>`00Go0000omfg/OoM]k7ogKNao`000003omni/@05o`000?oR_K?oh[fc
on:m/ol000001?oQ_[D01?l0003oi<BhonC4^?l00003omo5_P05o`000?oRc<7oh/c1on;<`Ol00000
0ooGblh00ol0003ofM7AomWAd@02o`0000Co`l_Q00?o0000ojG0kOnU`>d00ol00004ojO2k@03o`00
0?oooooooooo013ooooo00?o0000ooooooooool01oooool002[ooooo0_l0000Jooooo`?o000000Co
Yl3/o`000?l0003o00001?nW`>`00ol0003oYl3/ojO0k004o`0000CoYl3/00?o0000ojO0k?l00000
0_nW`>`00ol0003oYl3/ojO0k002ojO0k0?o00000onW`>`01?l0003oYl3/ojO0k?nW`>`3o`0000Co
Yl3/00So0000ojO0k?nW`>coYl3/o`000?l`O^Oo0000oa@o_0;o000000Go;U74o`000?l0003oA63:
o`000002oeebd005o`000?mdQ=GoM8CEogB4eOl000000on8U]X00ol0003oV:KOoiRVg`02oiRVg`04
o`000?nU]NCo0000o`0000?o/l;U00?o0000ok_Bjol000000_o8gnT2o`0000;oe>WU00Co0000omg`
gOoMl=gogO3M0_l00002on[ec@;o000000ColO:oo`000?odkk_o00000_oek;P01ol0003om^Rfo`00
0?ofhkGo0000ooGN]Ol000000_ocfKD00ol0003ol=>eo`000002onc=]@08o`000?oWakKoilNfo`00
0?oR`KKo0000ombl^Ol00004omJd^003o`000?o6Y[WoaZJi00?oaZJi00?o0000okNH^?ngV;P00_ng
V;P01?l0003o[I6iojfA^On]TKT3o`0000;oX8Fg00Ko0000oiIo^?nFOkSoUWnho`000?n;NKX3o`00
00;oGZ?e00?o0000oijaiOnN/ND00_nN/ND00ol0003o^[3@okZ`d002okZ`d0;o00001Oo5/<H00ol0
003ocZjjo`000004olfa_@03o`000?oC[kCo000000Coe;6g00?o0000omVb/_oI/[800_oI/[801_l0
003of[JeomZf]Ol0003ofk>`o`0000CogKNa00Go0000omni/OoO^K7ogkVao`000003on:m/`05o`00
0?oQ_[GohKjeon6n]Ol000000ooTa;P01Ol0003oglFnomo5__oOaKko000000?oh/c100So0000omO;
c_oGblko0000omWAdOl0003ofM7Ao`0000Co`l_Q1?l00002ojBok@04o`000?nW`^goYl;]ojO2k@?o
00004Oooool00ol0003oooooooooo`07ooooo`00:_ooool00ol0003oooooooooo`0Fooooo`?o0000
0_ooool2o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00004ojO0k003o`000?nW`>coYl3/00?o0000
1?nW`>`01?l0003oYl3/o`000?l00002ojO0k003o`000?nW`>coYl3/00;oYl3/00?o0000ojO0k?l0
00000_nW`>`00ol0003oYl3/ojO0k002ojO0k0Ko000000Oo<7kWo`000?lD?kco0000obiAa?l0003o
C6G<00;o00000omML]001Ol0003oM8CEogB4eOmdQ=Go000000?oR9KJ00?o0000oiRVgonHY]l01?l0
0004ok?2i@?o000000?ob=oYo`000?oDjND00_oDjND01?l0003ogO3Momg`gOoMl=d2o`0000;oj_G=
0_l00002oo7b_`03o`000?odkk_o000000co000000Gol=>eo`000?o/cKGok<feo`000002onO7]P04
o`000?oR`KKoh/6fo`0000Coe[Bh00?o0000oln^^?l000000oo6Y[T2o`0000Co]iRh00Ko0000ojfA
^On]TKWo0000ojV<]_l00003oj25]`03o`000?nFOkSoUWnh00;oUWnh00?o0000oh]i^_n;NKX01Ol0
0004oijai@06o`000?nj/=3o0000o`000?nb/]So00001Oo5/<H2o`0000KocK6m00?o0000omBa]ooD
/KL00ooD/KL01Ol0003ofK:bomVb/_oI/[;o000000?of[Je00?o0000om^c/?l000000ooM]k401Ol0
003oh;bdo`000?oO^K7o000000?oh[fc00Go0000onC3]_l0003ohKjeo`000003onC4^005o`000?oW
bk_o0000omo5__l000000ooRc<401?l0003oi=?5o`000?l00002omWAd@?o00000oo3bn401?l0003o
a<oSolC?hol00002ojBok@Go00000onUa>l00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00Oooooo000Zooooo`03o`000?oooooooooo01?ooooo0ol00007ooooo`03o`000?nW`>coYl3/00?o
00001?nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00004ojO0k003
o`000?nW`>coYl3/00?o00001?nW`>`01?l0003oYl3/o`000?l00002ojO0k003o`000?nH_?3oV;c`
00?o00000_lD?k`00ol0003o;U74o`000002odaUc0Co00000omdQ=D00ol0003oR9KJohRFfP04o`00
00CoY[;Q00Co0000ok?2iOl0003o00000_o1cnD4o`000003omCYiOl0003ogO3M00;ogO3M00Ko0000
onCdeOl0003oj_G=o`000?o^m<D6o`000008ooGT^?l0003om^:eo`000?ofg[?o0000ooGK/_l00002
oo?G/P03o`000?oadk;o000000;ok<fe00Co0000onO7]_oWakKo00000ooR`KH01Ol0003oe[BhomJd
^?oF];So000000;ocjjh00Co0000olJV^Oo6Y[Wo00000_o0WkP00ol0003o]iRhokNH^002okNH^0;o
00000_nYS;H00ol0003oX8Fgoj25]`02oj25]`05o`000?nFOkSoUWnhoiIo^?l000000on;NKX2o`00
0003obF9k?l0003o000000Go00001?nb/]P01ol0003oaK36olF`a_o5/<Ko0000ol6cc?l000001Oo=
/Kd2o`0000Coe;6g00Go0000omBe^_l0003ofK:bo`000005omZf]@03o`000?oM]k7ogKNa00;ogKNa
00Go0000on2l]?l0003ogkVao`000003on:m/`05o`000?oT`kKo0000on6n]Ol000000ooTa;P01?l0
003oil^konO;^ol00003on;<`@04o`000?oTdlGoi=?5o`0000?ofM7A0_l000001?oIf=Ko0000ol?;
hOl00003olC?h`?o00000onV`>`01?l0003oYLC_ojG4konUa>l3o`0000oooooo00?o0000oooooooo
ool01oooool002Wooooo00?o0000ooooooooool04_ooool2o`0000_ooooo0_l00002ojO0k003o`00
0?nW`>coYl3/00;oYl3/0ol00003ojO0k003o`000?nW`>coYl3/00Co00001?nW`>`00ol0003oYl3/
ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00004ojO0k003o`000?nH_?3oV;c`00;o0000
0_lD?k`3o`0000;oC6G<00?o0000ofQkd_mXNm801ol00002oiJQg003o`000?nV/^7oY[;Q00?oY[;Q
0_l00003ol7?i@03o`000?o>f^;oc][R00;oc][R0ol000000ooMl=go0000onCde@06o`00000<oo7Y
`Ol0003olnNlo`000?oei;So0000ooKR]Ol0003om]jco`000?oefk;o00000_ocek800ol0003olM>b
oo7C/P02o`000005onc=]Ol0003oilNfonO7]_l000000_oR`KH00ol0003ogK^go`000002omJd^006
o`000?o?[[Socjjho`000?o6Y[Wo00000oo0WkP01?l0003o]iRhokNH^?ngV;P2o`0000CoZHbf00Go
0000oj25]onPQKOoX8Fgo`000003oiIo^006o`000?n;NK[oRgVjoh]i^_l0003oOW>m0ol00004ohN]
k`03o`000?nb/]So/[;H00?o/[;H00?o0000olF`a_l000000oo1/l`01Ol0003ocK6molfa_Oo=/Kgo
000000;oc;C200Co0000omBa]ooD/KOo00000_oD]KX00ol0003ofK:bo`000005omZf]@05o`000?oM
]k7ogKNaomfg/Ol000000ooP_;@01Ol0003oh[fcon:m/ooR_K?o000000?oi<>f00Go0000onC4^?oT
a;Soi<Bho`000003onO;^`05o`000?oRc<7oh/c1on;<`Ol000000_oTdlD2o`000004omWAdOl0003o
fMSFomWHeP?o00000oo4cn<00ol0003o`]7Vo`000004ojK0k0Co00000_nQ_>`00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Oooooo000Yooooo`03o`000?oooooooooo00oooooo0ol0000=
ooooo`03o`000?nW`>coYl3/00;oYl3/00Co0000ojO0k?l0003o00000_nW`>`01?l0003oYl3/ojO0
k?nW`>`3o`0000CoYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co0000
1?nW`>`00ol0003oYl3/ojO0k005o`000004o`0^/ol0003o53nloa@o_0;o00000om<IL`01?l0003o
J7_BofQkd_l00003oh6>e`03o`000?nFXMcoUZ7L00;oUZ7L00?o0000ojJbhOl000000_l00002okFn
h@03o`000?o1cnGo000000Coc][R00?o0000omWRg?oIh]`01Ol000002_oYjLko0000onkYaol0003o
lNW1o`000?ocikco0000ooGT^?l00002ooKR]@05o`000?ofg[?o0000ooGK/_l000000_ocek800ol0
003olM>bo`000002onk?/P04o`000?oWakKoilNfo`0000?oh/6f00Go0000omfk]ol0003oe[Bho`00
0004oln^^003o`000?o0WkSo`9nh00;o`9nh00Ko0000okNH^?ngV;So0000ok6B]_l00004ojV<]P05
o`000?nPQKOoX8Fgoj25]ol000001?nFOkP01_l0003oRgVjoh]i^_n;NK[o0000ogic_@?o00001?n7
[Nl00ol0003o/[;Hok:bf002ok:bf0;o00001?o1/l`01?l0003ocK6molfa_Ol00003olbd`P04o`00
0?oD/KOoe;6go`0000?oe;Fj00?o0000omZf]OoJ][D00ooJ][D01Ol0003og;^ho`000?oM]k7o0000
00Coh;bd00Go0000on:m/ooR_K?oh[fco`000003onC3]P04o`000?oTa;Soi<Bho`0000?oil^k00Go
0000onWD_ol0003oh/c1o`000002onCCa@04o`000?oUg<_oiMc;o`0000?ofMSF0_l000001?oGg]go
0000olC?hol00003ol;AiP06o`000?nV`>co0000o`000?n[`N[o00001OnQ_>`00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Kooooo000Yooooo`?o00003?ooool3o`00017ooooo00?o0000
ojO0k?nW`>`01?l00004ojO0k003o`000?nW`>co000000;oYl3/00?o0000ojO0k?nW`>`00_nW`>`3
o`0000;oYl3/00?o0000ojO0k?nW`>`00_nW`>`3o`0000CoYl3/00?o0000ojO0k?nW`>`01?l00002
ojO0k004o`000?l7GMKo0000o`0^/`;o000000?o53nlo`000?leELD00_l000000om<ILco0000ofQk
dP02ofQkdP05o`000?n1S]OoPHkGoh6>eol000000onFXM`2o`0000Go]KkQ0ol00003olkJhP04o`00
0?oIh]cofN;Lo`0000?oh^OE00Oo0000onWYc_l0003ok^W7o`000?oajL7o000000;olnNl00Wo0000
ooGT^?l0003om^:eo`000?ofg[?o0000ooGK/_l000000_ocek801?l0003olM>boo7C/_l00002onk?
/P;o000000GoilNfo`000?oR`KKoh/6fo`000003omfk]`03o`000?o?[[Socjjh00?ocjjh00?o0000
ol2O^?o0WkP00oo0WkP2o`0000?o/I:f00Go0000ojV<]_nYS;KoZHbfo`000004oj25]`03o`000?nF
OkSo000000oo000000Ko/[;Ho`000?l0003o0000ojJch_l00004ol6cc003o`000?o=/Kgo000000Co
c;C200?o0000omBa]ol000001?oD]KX00ol0003of[JeomZf]@02omZf]@06o`000?oL^kSog;^ho`00
0?oM]k7o00000ooP_;@01Ol0003oh/:ho`000?oR_K?o000000?oi<>f00Go0000onO;^Ol0003oi<Bh
o`000003onO;^`04o`000?oYe;oojMBoo`0000;oi=?500Co0000onGLbooUg<_oiMc;0_l000001OoI
f=Ko0000omONgOl0003oemkM00;o00001?o2dNH2o`0000CoZl7Z00?o0000oj6lk?nQ_>`00ol0000?
ooooo`03o`000?oooooooooo00Kooooo000Yooooo`03o`000?oooooooooo00Wooooo0ol0000Eoooo
o`;o00001?nW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/00Co0000ojO0k?l0003o00000_nW`>`0
1_l0003oYl3/ojO0k?nW`>co0000ojO0k0;o00000_nW`>`00ol0003oYl3/ojO0k002ojO0k0?o0000
0onW`>`02?l0003oYl3/ojO0k?nW`>co0000o`MMe_l0003o02jc0ol000000oleELGo0000oeM]cP02
o`0000?oJ7_B00Ko0000oh6>eon1S]OoPHkGo`000?nFXM`2o`0000;oYJgM00Go0000okFnhOne_^7o
]KkQo`000003ol?9g`03o`000?o>f^;o000000;ofN;L00Oo0000on;WeOoRimGoh^OEo`000?oYjLko
000000;ok^W700Oo0000oo7Y`Ol0003olnNlo`000?oei;So000000;om^:e00Go0000ooKN/ol0003o
mM^bo`000002oo?G/P03o`000?oadk;o000000;ok/nb00Co0000on_:/oo[b[?o00000_oR`KH00ol0
003ogK^gomfk]`02omfk]`03o`000?o?[[Socjjh00;ocjjh00?o0000olRW^?l000000oo0WkP2o`00
00Co/I:f00?o0000ojV<]_nYS;H00_nYS;H00ol0003oX8Fgo`000003o`0000;oUgje00Go0000ohmj
]on?N[OoSgZgo`000002ohIf^@Co00000_mSXo@2o`0000GoY[?R00Co0000ol6cc?o1/lco`K?<0_l0
0005olbd`P;o00001?oD]KX00ol0003oeKZoo`000002omZf]@03o`000?oL^kSog;^h00;og;^h00?o
0000on2l]?oP_;@00_oP_;@01Ol0003oh/:ho`000?oR_K?o000000?oi<>f00Co0000onO;^OoWbkWo
00000ooWbk/01ol0003ojMBoonWD_ooYe;oo0000onCCaOl000000ooUg</01?l0003oi>KConCVdol0
0003omONg@05o`000?o@i>Kod>CVo`000?o2dNH00_l00002ok_Bj`03o`000?n[`N[oZl7Z00Co0000
0onS^^T00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00000ol0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`06ooooo`?o
00006_ooool00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00004ojO0k003
o`000?nW`>coYl3/00?o00001?nW`>`01_l0003oYl3/o`000?l0003oYl3/o`0000CoYl3/2Ol00000
1OlI@Kco0000o`000?leELGo000000;oEfg>2Ol00005ojF]g@03o`000?ne_^7o000000Go`lWO0_l0
00000ooIh]co0000on;We@02on;We@03o`000?oYjLko000000;ok^W700?o0000oo7Y`Ol000000_oc
ik`01ol0003omNBho`000?ofh[Go0000ooKN/ol000000_oefk801_l0003olmNboo?G/_l0003olM>b
o`0000;ok/nb00?o0000on_:/oo[b[<00_l000000ooR`KKo0000omfk]`02omfk]`03o`000?oG]KOo
000000;ocjjh00Co0000olRW^?o8YkSo00000_o0WkP00ol0003o^YVgo`000004ok6B]P04o`000?nY
S;KoZHbfojV<]P?o00000_nOPk@01Ol0003oUgjeoiMn]OnGO[Go000000?oSgZg00Co0000ohIf^On6
M[WoQWJi1?l00002of>Sm003o`000?nV/n;oY[?R00?oY[?R00Ko0000ol6cc?o1/lco0000okbge?l0
0004olbd`P03o`000?o;^LSo000000?oe;Fj00Co0000omFj_ooE^[oo00000_oJ][D00ol0003og;^h
ombk^002ombk^005o`000?oP_;Coh;bdon2l]?l000000ooR`[P01Ol0003oi<>fonC3]_oT`kKo0000
00?oil^i00Co0000onO;^ooWbk_o00000ooYe;l00ol0003ojmk5o`000003onGLb`0;o`000?oTi]?o
i>KCo`000?oOkm_o0000omONgOl0003od>CVo`000?o@i>H00_l00004ok_Bj`?o00000onZ`>T00ol0
003oXk[Yoj>jj@03o`0000gooooo00?o0000ooooooooool01_ooool00003oooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`?o00007_ooool2
o`0000CoYl3/00?o0000ojO0k?nW`>`00ol00004ojO0k003o`000?nW`>coYl3/00Co00000onW`>`0
0ol0003oYl3/ojO0k004o`0000?oYl3/00Co0000ojO0k?l0003o00000_nW`>`00ol0003oS[Scohjh
l`05o`000007oaU1_?l0003o0000ocEEaOl0003oEfg>o`000003ogJ4e003o`000?n@V]WoT9[I00;o
T9[I00?o0000ojF]gOnU[Md00_nU[Md2o`0000Go`lWO00?o0000om3Bfoo@d]/00ol000001ooRimGo
0000onWYc_oYjLko0000onkYaol000000_oajL401Ol0003olnNlo`000?oei;So000000;om^:e00Go
0000ooKN/ol0003omM^bo`000002oo?G/P06o`000?oadk;olM>bo`000?o^ck;o00000_o[b[<01?l0
003oilJdonO6]?l00004omfk]`06o`000?oG]KOoekFgo`000?o?[[So00000_o8YkP00ol0003o`9nh
o`000003okZI]`03o`000?naT[Ko/I:f00;o/I:f0ol000000onVR;Co0000oin3]002oin3]003o`00
0?nGO[GoUgje00;oUgje00Go0000ohmj]on?N[OoSgZgo`000002ohIf^@03o`000?mlL[goO7:m00Go
00001?nV/n800ol0003o`K?<o`000003okbge004o`000?o<]<;oc;C2o`0000?obkW800Co0000omBe
^_oD]K[o00000_oE^[l00ol0003of[Jeo`000004ombk^005o`000?oM`Kgo0000on2l]?l000001?oR
`[P01?l0003oi<>fonC3]_l00003onO;^@05o`000?oZe;ko0000onO;^ol000000_oYe;l00ol0003o
jmk5on_Na@02o`000005onGLbol0003oi>KConCVdol000000_oOkm/2o`000007om3Ti_l0003o0000
o`000?o4j>oo0000ok_Bj`03o`000003ok7=kol0003oZ/3Y00?oZ/3Y0ol00003ojO0k003o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01_ooool000;ooooo00?o410@ooooooooool02Oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo00Cooooo00Co0000oooooooooooooooo0ol0000Rooooo`03o`000?nW`>coYl3/00;o
Yl3/0ol00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004o`0000Co
Yl3/00?o0000ojO0k?nW`>`00ol00004ojO0k003o`000?n>^??oS[Sc00Co000000?o6D6lo`000?lo
G<P00_l00002oeM]cP05o`000?mfQ=CoMXCDogJ4e?l000001?n@V]T01?l0003oYJgMo`000?l00002
ok>hg005o`000?o3bMoo`lWOol?9gol000000oo@d]/00ol0003of]WFom[IeP02o`000007onWYc_l0
003ok^W7onkYaol0003olNW1o`000002oo?W_0So000000OomM^bo`000?ocek;olmNbo`000?oadk;o
000000;ok/nb00Co0000on_:/oo[b[?o00000_oWa[@2o`0000;ogK^g00?o0000omNe]ooG]KL00_oG
]KL00ol0003ob:NholRW^002olRW^003o`000?njVKOo^YVg00;o^YVg00Co0000ok6B]_naT[Ko/I:f
0_l00003ojJ8]003o`000?nOPkCoWh>d00;oWh>d00Go0000oiMn]OnGO[GoUgjeo`000003ohmj]`05
o`000?n6M[WoQWJiohIf^Ol000000_mlL[d2o`000003oc6>k_l0003o000000Go00001?nl]m@00ol0
003oc;C2o`000004ol^ib003o`000?oD]K[o000000CoeKZo00?o0000ombk^?oL^kP00ooL^kP01Ol0
003ogL6mo`000?oP_;Co000000?oh/:h00Go0000onG:_?l0003oi<>fo`000003onO;^@04o`000?oZ
e;koj]Bno`0000?ojMBo00?o0000on_NaOl000000_o[jL/2o`000006onCVdol0003ognoKomo_fol0
003odoOU0_l00002olCXk`04o`000?o4j>oo0000o`0000Go/Lg_1?l000000onW`>co0000ojO0k003
ojO0k0;o00002oooool00ol0003oooooooooo`06ooooo`000_ooool00ol0003oooooooooo`09oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool01?ooool4o`0002Kooooo00Ko0000ojO0k?l0003o0000ojO0k?l00004ojO0k0?o
00001?nW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003
o`000?nW`>coYl3/00Go000000Ko01ZVo`000?l0;;7o0000oaU1_?l00002ocmLb0Co00000omfQ=@0
0ol0003oT9[Ioi2Jf@03o`0000Go/kSL00?o0000ol?9gol000000oo@d]/01_l0003of]WFom[Ie_oJ
fMKo0000on?Mc`Wo000000Sol]jio`000?ocg;Kolmbfo`000?odf[?o0000ooCH/PGo000000ColM>b
o`000?o^ck;o00000_o[b[<01?l0003oilJdonO6]?l00002on?1]P03o`000?oM^kOo000000CoekFg
00?o0000olRW^?o8YkP00_o8YkP00ol0003o^YVgokZI]`02okZI]`06o`000?naT[Ko/I:fo`000?n]
SKGo00001?nVR;@01Ol0003oWh>doin3]?nOPkCo000000?oUgje00Go0000ohmj]on?N[OoSgZgo`00
0003ohIf^@04o`000?mlL[goO7:mogab_@Co00001?nD/n`00ol0003o_;ODokbge002okbge0;o0000
1_o;^LP00ol0003oeKZoomFj_`03omFj_`03o`000?oL^kSog;^h00;og;^h00Go0000omg1_OoM`Kgo
gL6mo`000004on;2^004o`000?oUb[coiLZlo`0000?oil^i00Co0000on[D__oZe;koj]Bn0_l00000
1?oYe;oo0000on_NaOl00003on_Yb`08o`000?oVm=;o0000o`000?oOkm_o0000om?giOl00002okci
k004o`000?o4j>oo0000o`0000;o/]of00?o0000ok7=konacNl00ol00005ojO0k0Co000000?oYl3/
o`000?ooool02_ooool00ol0003oooooooooo`06ooooo`000_ooool00ol0003oooooooooo`09oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool01?ooool2o`0002Wooooo0_l00003ojO0k004o`000?nW`>co0000o`0000;oYl3/
00?o0000ojO0k?nW`>`00_nW`>`3o`0000;oYl3/00?o0000ojO0k?nW`>`00_nW`>`3o`0000?oYl3/
00?o0000ojO0k?nW`>`01?l00002ojO0k003o`000?l0B/Wo000000;o01ZV1?l00002ocmLb003o`00
0?mTMm3oI7O@00Oo00000_nOYMX00ol0003o/kSLok>hg003ok>hg0;o00000oo@d]/01Ol0003of]WF
om[Ie_oJfMKo000000;ohmg?00Ko0000onWObOoYglWo0000ongO`ol00002oo3O_P;o00000_ocg;H0
0ol0003om=Zco`000002ooCH/P05o`000?oce[7olmJao`000?obdk400_l000001Oo^ck;o0000on_:
/oo[b[?o000000;oilJd00Go0000on?1]_oS`KKohl6fo`000004omNe]`03o`000?o@[kSo000000;o
b:Nh00?o0000ol:Q]ol000001?njVKL2o`0000;o[Hfe00?o0000ojJ8]?nVR;@00_nVR;@01Ol0003o
Wh>doin3]?nOPkCo000000?oUgje00?o0000ohmj]on?N[L00_n?N[L01?l0003oQWJiohIf^Ol00003
ogab_@03o`000?m`Kl;o000000;o00001?nD/n`01_l0003o_;ODo`000?l0003o];[No`0000GobkW8
0_l00004omFj_`03o`000?oF`<Go000000;og;^h00?o0000omg1_OoM`Kd00_oM`Kd01Ol0003oh/:h
on;2^?oR`[So000000?oiLZl00Co0000onO;^OoWbkWo00000ooZe;h01?l0003ok=k4oncNa?l00002
on_Na@07o`000?o[jL_ojnW;o`000?oVm=;o0000omWmf002o`000003om?giOl0003o_?W/00;o_?W/
0ol000000onbgoKo0000o`000003o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00005ojO0k003o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01Oooool000;ooooo00?o410@ooooooooool02Ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0:?ooool00ol0003oYl3/ojO0k003o`0000Co
Yl3/00Ko0000ojO0k?l0003o0000ojO0k?l00004ojO0k006o`000?nW`>co0000o`000?nW`>co0000
1?nW`>`3o`0000CoYl3/00Wo0000ojO0k?nW`>co0000o`1:bOl0003o01ZVo`000?l0;;400_l00003
ocmLb004o`000?mTMm3oI7O@o`0000?oQHoF00?o0000oinUf_nOYMX00_nOYMX00ol0003o/kSLo`00
0002o`0000;o`/;J00?o0000om3Bfol000000ooJfMH01?l0003ohmg?on?Mcol00002onWOb@03o`00
0?o]gl?o000000;ol=nn00?o0000oo;N^Ol000000_ocg;H01Ol0003om=Zco`000?odf;;o000000;o
lmJa00Ko0000oo;C/Oobdk7o0000oo3@/Ol00002on_:/`05o`000?oWa[CoilJdonO6]?l000000ooS
`KH01Ol0003oekFgomNe]ooG]KOo000000;od:nh00?o0000olRW^?l000000_o2XKL00ol0003o^YVg
okZI]`02okZI]`03o`000?n]SKGo[Hfe00;o[Hfe00Go0000ojJ8]?nVR;CoYXRdo`000004oin3]006
o`000?nGO[GoUgjeoiMn]Ol0003oSgZg1Ol000001On6M[Wo0000ogab_OmlL[go000000;oL6o22?l0
0004okBjgP05o`000?o;^LSobkW8ol^ib?l000000_o8_]001?l0003oeKZoomFj_ol00003omK0a@03
o`000?oL^kSo000000?ogL6m00Go0000omo9`_l0003oh/:ho`000003onG:_005o`000?oXdl7o0000
onO;^Ol000000_oZe;h01ol0003ok=k4oncNa?o/g/Co0000on_NaOl000000_o[jL/01_l0003oi_CB
o`000?oIoMSo0000okknf0?o000000Co_?W/o`000?l0003oZNkh1?l00003ojO0k003o`000?nW`>co
Yl3/00Co00000onW`>`00ol0003oYl3/ojO0k003o`0000_ooooo00?o0000ooooooooool01Oooool0
0003oooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Sooooo0_l0
0003ojO0k003o`000?nW`>coYl3/00?o00001?nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00Co
0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k002ojO0k0Ko00000_l06ZH2o`000005ob16
__l0003o0000ocmLb?l000000omTMm001Ol0003oQHoFohF?e_n5SmKo000000?oWjGJ0_l00005ol;2
fPCo000000Gof]WFo`000?oSgLoohmg?o`000002onWOb@04o`000?o]gl?okMo3o`0000;ol=nn0_l0
0002oo?L]P03o`000?odf[?o000000;om=Rb00Ko0000oo?F/Ooce[7o0000oo;C/Ol00002oo3@/@;o
000000GojlZco`000?oWa[CoilJdo`000003on?1]P03o`000?oM_;Oo000000;oekFg00Ko0000om2_
^?o@[kSo0000olRW^?l00003ol:Q]`03o`000?njVKOo^YVg00;o00001?n]SKD01Ol0003oYXRdojJ8
]?nVR;Co000000?oWh>d1ol00002oi=k]@03o`000?n>NKOoSWVg00Oo000000CoL6o2o`000?l0003o
00000omh[_@00ol0003o];[NokBjgP03okBjgP03o`000?o;^LSo000000?ob;k@00?o0000omFj_ol0
00001OoF`<D01Ol0003ogL6momg1_OoM`Kgo000000;oglW200?o0000on;2^?l000000ooUb[`01?l0
003oj=?1onSC`Ol00003on[D_P05o`000?o/g/Cok=k4o`000?o/jlX00_l000002Oo[jL_o0000onKd
d_l0003ofOgHo`000?nno]So0000oi?`c`06o`0000;oYl3/00Co0000ojO0k?l0003oYl3/1?l00003
ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Gooooo00000ol0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?oEEEEofIVI_l000002_ooool00ol0003ooooooooo
o`0Xooooo`03o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004o`0000CoYl3/00?o
0000ojO0k?nW`>`00ol00004ojO0k006o`000?nW`>co0000o`000?nW`>co00000_nA^_801?l0003o
04[9o`000?l06ZH2o`000003ob16__l0003oBfC;00;o00000omTMm001_l0003oQHoFohF?e_n5SmKo
0000oinUfP;o00000_n^/=T01Ol0003o`/;Jol;2f_o2`][o000000Coc/[F0_l000000ooSgLoo0000
onWOb@02onWOb@03o`000?o]gl?o000000;ol=nn00?o0000oo;N^Ol000000_ocg;H01Ol0003om=Zc
o`000?odf;;o000000;olmJa00Ko0000oo;C/Oobdk7o0000oo3@/Ol00002onk>/P;o00000_oWa[@0
2Ol0003ohl6fon?1]_oS`KKo0000omfl]ol0003oekFgo`000004om2_^003o`000?o2XKOo`Z6g00;o
`Z6g00Go0000okZI]ol0003o]9Bfo`000004ojf=]@03o`000?nVR;CoYXRd00;oYXRd0ol000000onN
PK?o0000oiUm/`02oiUm/`05o`000?nCNkGoTg^eoi=k]Ol000000on>NKL01_l0003oQgNkohMg^on7
Mk_o0000oh1g_`Go00000omh[_@01?l0003o];[NokBjg_nd^]h3o`0000Cob;k@0_l00005omK0a@;o
00000ooM`Kd01Ol0003oglW2omo9`_oObL;o000000?oiLZl00Co0000onSC`OoXdl7oj=?10_l00000
1OoZe;ko0000oncNa?o/g/Co000000;ok>_:00?o0000onOgcol000000_l000000ooIoMSo0000okkn
f005o`000003ojO0k?l0003oYl3/00?oYl3/1?l00002ojO0k004o`000?nW`>coYl3/ojO0k0Co0000
0_nW`>`01?l0003oYl3/ojO0k?nW`>`3o`0000Wooooo00?o0000ooooooooool01Oooool002gooooo
0_l0000Yooooo`;o00001?nW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/00?o0000ojO0k?nW`>`0
1?l00003ojO0k003o`000?nW`>coYl3/00?o00001?nW`>`00ol0003oTK[boi6jlP04o`000004o`0]
/_l0003o0000o`0000;oBfC;1?l00002ohF?eP?o00001On^/=T00ol0003o`/;Jo`000004olk:eP03
o`000?oHd=7of=3A00?o000000CojMo9o`000?o]gl?o00000_o`gkh01?l0003ol]jioo;N^Ol00002
oo?L]P05o`000?odf[?o0000ooCH/_l000000_oce[400ol0003ol]>ao`000002oo3@/@08o`000?o^
c[;ok/jbo`000?o[bkCo0000onO6]?l00002on?1]P05o`000?oM_;OogKbgomfl]ol000001Oo@[kP0
0ol0003o`Z6gol:Q]`03ol:Q]`05o`000?ndU;Ko]9BfokBD]_l000001?n]SKD00ol0003oYXRdo`00
0002o`0000?oWX6c00Go0000oiUm/onIOK?oVGfco`000004oi=k]@04o`000?n>NKOoSWVgo`0000?o
QgNk00Co0000oh1g_on0MkooP7No2_l00002ojRnj@07o`000?o8_]3ob;k@olRnd?l0003oaLGJo`00
0004omK0a@06o`000?oFb<goe/S=o`000?oM`Kgo00001?oObL801?l0003oiLZlonG:_?l00003onSC
`@04o`000?oZglSoj]o8o`0000?ok=k400Ko0000onc[b_l0003oioO?o`000?oHom08o`0000CoYl3/
00Ko0000ojO0k?l0003o0000ojO0k?l00002ojO0k003o`000?nW`>co000000?o00000_nW`>`01?l0
003oYl3/ojO0k?nW`>`4o`0000;oYl3/00?o0000ooooooooool01oooool00ol0003oooooooooo`05
ooooo`00;oooool00ol0003oooooooooo`0Wooooo`03o`000?nW`>coYl3/00;oYl3/0ol00003ojO0
k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0
k?nW`>`01?l000000onA^_;o0000o`000003o`000005obY=`_l0003o0000od]Tbol000000_mcP]<3
o`0000;oU9_G00?o0000ojj`fOn^/=T00on^/=T2o`0000Coc/[F00Go0000omS@dOoHd=7of=3Ao`00
0002on3Dc0;o000000OokMo3o`000?o`gkkol=nno`000?obg[Wo000000;olmbf00?o0000ooCJ/ol0
00000_odf;802?l0003olmJaoo?F/Ol0003ol]>ao`000?o`d;7o00000_o^c[801Ol0003ojl^don_;
]?o[bkCo000000;ohl6f00?o0000omfl]ooM_;L00_oM_;L00ol0003od:nhom2_^002om2_^003o`00
0?o:ZKWo000000?o`Z6g0_l00003okBD]P04o`000?n]SKGo[Hfeojf=]@?o00000_nSQK<00ol0003o
WX6coij1/`02oij1/`05o`000?nIOK?oVGfcoiUm/ol000000onCNkD01Ol0003oSWVgohii]on>NKOo
000000?oQgNk00Co0000oh1g_on0Mkoo00000_mgN<L2o`0000;oDJ;f00?o0000ojRnjOnX_^T00onX
_^T00ol0003ob;k@o`000003olG5fP04o`000?oF`<Goe/35o`0000?oe/S=0_l00004omo9`P05o`00
0?oQdlWo0000onG:_?l000000_oXdl401?l0003oj]o8on[Ob?oZglP2o`000007oncNa?l0003ok>_:
o`000?oWmloo0000omSod006o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00004ojO0k006o`000?nW
`>co0000o`000?nW`>co00001OnW`>`3o`000003ojO0k?l0003oYl3/00?oYl3/0_l00008ooooo`03
o`000?oooooooooo00Gooooo000`ooooo`03o`000?oooooooooo02Oooooo00Ko0000ojO0k?l0003o
0000ojO0k?l00004ojO0k0?o00000onW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0
k?nW`>`01?l00004ojO0k0?o000000Ko01JTo`000?l0;K;o0000obY=`_l00002od]Tb`04o`000?mc
P]?oLh;Co`0000CoU9_G00Oo0000ojj`fOn^/=Wo[[3Io`000?nl^MOo000000?oc/[F00Go0000omS@
dOoHd=7of=3Ao`000003on3Dc003o`000?oVelKo000000Co000000Wol]jio`000?ocg;Kolmbfo`00
0?odf[?o0000ooCH/_l000000_oce[401_l0003ol]>aoo;C/Ol0003ol=2ao`0000;ok/jb00Co0000
on_;]?o[bkCojl^d0_l000000ooS`KKo0000omfl]`02omfl]`03o`000?oH^;Wo000000;od:nh00Co
0000olZY^Oo:ZKWo00000_o2XKL00ol0003o^i^ho`000003okBD]P06o`000?n]SKGo[Hfeo`000?nY
RKCo00000onSQK<00ol0003oWX6coij1/`02oij1/`05o`000?nIOK?oVGfcoiUm/ol000000onCNkD0
1Ol0003oSWVgohii]on>NKOo000000?oQgNk00Go0000oh1g_on0MkooP7Noo`000002ogMha`Go0000
0onX_^T3o`0000CoaLGJ00?o0000omK0aOl000000ooFb<d00ol0003oeM;Fo`000003omo9`P05o`00
0?oQdlWohM?9on7CbOl000000ooXdl401Ol0003oj]o8on[Ob?l0003ojNc?00;o000000Gok>_:o`00
0?oWmloo0000omSod003o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>co
Yl3/00?o000000GoYl3/o`000?nW`>coYl3/o`000002ojO0k0?o00001?nW`>`01_l0003oYl3/o`00
0?l0003oYl3/o`0000Sooooo00?o0000ooooooooool01Oooool0037ooooo00?o0000ooooooooool0
9oooool2o`0000?oYl3/00Co0000ojO0k?l0003o00000_nW`>`01?l0003oYl3/ojO0k?nW`>`3o`00
00CoYl3/00?o0000ojO0k?nW`>`00ol00004ojO0k003o`000?nW`>coYl3/00So00000_lZCL82o`00
0005od]Tbol0003oLh;Cog>2dol000001?nDVmL00ol0003o[[3Io`000003okbie`03o`000?o>b]Ko
000000?of=3A00Go0000on3Dc?oPe<coh=C<o`000002onKGaP05o`000?oZf<7oj]S1o`000?o^f;d0
1ol000001oodf;;o0000oo?F/Ooce[7o0000oo;C/Ol000000_o`d;400ol0003ok/jbo`000003on_;
]004o`000?oXb;Koj<Rfo`0000?ogKbg00Ko0000omRh^OoH^;Wo0000om2_^?l00003olZY^@03o`00
0?o2XKOo000000?o^i^h00Co0000okBD]_ndU;Ko]9Bf0_l00002ojV9]003o`000?nSQK?oXhFc00;o
XhFc00Go0000oij1/onNPK?oWX6co`000003oiUm/`05o`000?nCNkGoTg^eoi=k]Ol000000on>NKL0
1Ol0003oQgNkohMg^on7Mk_o000000?oP7No00Co0000ogMhaomgN<OoMgS70_l000000olNRn_o0000
o`000002o`0000;oU/7e00?o0000olG5f_o5aMX00_o5aMX2o`0000?oe/S=00Oo0000omGBe_oEd]Ko
eM;Fo`000?oObL;o000000?ohM?900Go0000on;Od_l0003oj=?1o`000002on[Ob003o`000?oYk<oo
000000;ohoWC1ol00003ojO0k0Co00000_nW`>`01?l0003oYl3/ojO0k?nW`>`4o`0000?oYl3/00?o
0000ojO0k?l000001?l00003ojO0k003o`000?nW`>coYl3/00?o00001?nW`>`00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Cooooo000booooo`;o0000:Oooool00ol0003oYl3/ojO0k003
o`0000CoYl3/00?o0000ojO0k?l000000_nW`>`00ol0003oYl3/ojO0k002ojO0k0?o00000_nW`>`0
0ol0003oYl3/ojO0k002ojO0k0?o00000_nQ_nh3o`000007o`0FY?l0003o0000o`000?lZCL;o0000
oeU_cP02o`0000?oLh;C00?o0000oiBKeonDVmL00ol00004okbie`?o00000ooHd=401?l0003oh=C<
on3Dc?l00002onKGaP04o`000?oZf<7oj]S1o`0000;ok]Rm00Oo0000oo3H^Oo`f;Wo0000oo7G]_l0
003ol]Jd00Go000000Col]>ao`000?o`d;7o00000_o^c[801Ol0003ojl^don_;]?o[bkCo000000;o
j<Rf00Go0000omfl]ooM_;OogKbgo`000003omRh^@03o`000?o:ZKWobZVi00?obZVi00?o0000ok^K
^?nkVkP00_nkVkP01Ol0003o]9BfokBD]_ndU;Ko000000CoZHVd00Go0000oj>5/onSQK?oXhFco`00
0003oij1/`03o`000?nIOK?oVGfc00;oVGfc00Go0000oi=k]OnCNkGoTg^eo`000003ohii]`05o`00
0?n7Mk_oQgNkohMg^ol000000_n0Mkl01_l0003oMgS7ogMhaomgN<Oo0000of]jd0Co00001?nF`OD0
1?l0003oaLGJo`000?l00002oko>iP03o`000?oFb<go000000CoeM;F0_l00003on7Cb@04o`000?oR
gm;oh]oBon;OdP;o000000Coj]o8o`000?oYk<oo00000_oSnM<00ol0003odOoAo`000002o`0000;o
Yl3/1?l00002ojO0k003o`000?nW`>coYl3/00Go00000_nW`>`01?l0003oYl3/ojO0k?nW`>`4o`00
00?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o00001oooool00ol0
003oooooooooo`04ooooo`00=?ooool00ol0003oooooooooo`0Wooooo`;o00000onW`>`00ol0003o
Yl3/ojO0k003o`0000CoYl3/00Ko0000ojO0k?l0003o0000ojO0k?l00004ojO0k006o`000?nW`>co
0000o`000?nW`>co00001?nQ_nh4o`000005o`8a]?l0003o:Tg2obY=`_l000000_mIKlh6o`0000;o
XjGG00Go0000okbieonl^MOo_;WGo`000003olS1e003o`000?oHd=7o000000;oh=C<00Oo0000onKG
a_oVelKoi]O6o`000?oZf<7o000000;ok]Rm00Ko0000oo3H^Oo`f;Wo0000oo7G]_l00002oo;F]005
o`000?obeK?ol]Fco`000?obe;800_l000001?o`d;7o0000onk>/_l00003on_;]008o`000?oXb;Ko
j<Rfo`000?oTaKSo0000omfl]ol00004omRh^@03o`000?o:ZKWobZVi00?obZVi00?o0000ok^K^?nk
VkP00_nkVkP00ol0003o]9BfokBD]P02o`0000CoZHVd00Go0000oj>5/onSQK?oXhFco`000004oij1
/`03o`000?nIOK?o0000023o00001?noc^H2o`0000CoeM;F00Ko0000om?NhOoCg^7o0000on7CbOl0
0003on;OdP06o`000?oPk][o0000o`000?oYk<oo00000_oSnM<00ol0003odOoAo`000002o`000005
ojO0k?l0003o0000ojO0k?l000001?nW`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`01Ol00002ojO0
k004o`000?nW`>co0000ojO0k0Co00000_nW`>`01?l0003oYl3/ojO0k?nW`>`4o`0000?oYl3/00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`00=Oooool00ol0003oooooooooo`0W
ooooo`03o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/00?o0000
ojO0k?nW`>`01?l00003ojO0k004o`000?nQ_nkoXKo^oj6okPCo00000_l2<K@3o`0000;oFFo>00Go
0000oh>=eOn3SMGoPhgEo`000004oj>Ue`03o`000?nl^MOo000000Gob<7D0_l000000ooPe<co0000
onKGaP02onKGaP04o`000?oZf<7oj]S1o`0000;ok]Rm00?o0000oo3H^Ol000000_oaekH00ol0003o
l]Jdo`000002oo;E/`05o`000?obe;;ol]Bbo`000?oadk800_l000000oo^c[;o0000on_;]002on_;
]004o`000?oXb;Koj<Rfo`0000;oi<Fh00?o0000omRh^OoH^;T00_oH^;T00ol0003od[>ko`000003
olZY^@03o`000?o3Y;[o000000Co^i^h0_l00002ojj?]P05o`000?nYRKCoZHVdojV9]?l000000onS
QK<01?l0003oWX6coij1/onNPK<3o`0000;oVWfb00Go0000oiMl/onGO;?oUgbco`000003oiAk]P05
o`000?nAO;WoTGbioi5l^Ol000000on=O[d01Ol0003oRH74ohV1a?n9PLCo000000;oQ8O>1?l00004
ogZoo@06o`000?noc^Ko0000o`000?ndeo;o00000ooEd]H01?l0003odmkQom?NhOoCg^42o`0000?o
h]oB00?o0000on3^f_l000000_oGn]l2o`000005on?idol0003odOoAo`000?nW`>`00ol00004ojO0
k006o`000?nW`>co0000o`000?nW`>co00001?nW`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`01Ol0
0002ojO0k003o`000?nW`>coYl3/00Go00000_nW`>`01?l0003oYl3/ojO0k?nW`>`3o`0000Gooooo
00?o0000ooooooooool01?ooool003Kooooo00?o0000ooooooooool09oooool2o`0000?oYl3/00?o
0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co00001?nW`>`00ol0003oYl3/ojO0
k007o`000006o`0FXol0003o0S6do`000?lfE/Ko00000omIKlh01Ol0003oPhgEoh>=eOn3SMGo0000
00?oXjGG0_l00005olS1e003o`000?oBam3od/O@00;o00000_oVelH01?l0003oj]S1on[H`Ol00002
onkH_@06o`000?o`f;Wol=Rio`000?oaekKo00000_obe[@01_l0003ol]Fcoo;E/ol0003ol]Bbo`00
00;olM>b00Co0000oo3A/ol0003o00000_o[bk@01?l0003oj<RfonS8]_l00003onC5^005o`000?oH
^;Wof;RiomRh^Ol000000_oB/k/01?l0003obZViolZY^Ol00002ol>T^P04o`000?nkVkSo^i^hok^K
^0;o00000on^SkH01Ol0003oZHVdojV9]?nYRKCo000000CoXhFc0ol000000onMOk;o0000oiYm/P02
oiYm/P05o`000?nGO;?oUgbcoiMl/ol000000onDNkH00ol0003oTGbioi5l^@02oi5l^@05o`000?n=
O[goSGjmohen_Ol000000on9PL@01?l0003oQ8O>ohB7c_l00002ogf@f`Ko00001?ndeo800ol0003o
eM;Fo`000003om?Nh@08o`000?o<k>_oc>c[o`000?oRgm;o0000on3^f_l00002omOjg`03o`000?o0
o]_o000000Go00000onW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/00Ko0000ojO0k?l0003o0000
ojO0k?l00004ojO0k0?o00000_nW`>`01Ol0003oYl3/ojO0k?l0003oYl3/00?o00000onW`>`00ol0
003oYl3/ojO0k005o`0000;oYl3/00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`00=oooool2o`0002Wooooo00?o0000ojO0k?nW`>`00ol00004ojO0k003o`000?nW`>coYl3/00?o
00001?nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/1ol000000ol2<KCo0000ocIFaP02o`000003
oeU_c_l0003oPhgE00;oPhgE00Co0000oj>Ueol0003o00000_nb/=H01Ol0003ob<7DolS1e?o8`MCo
000000?od/O@00Go0000om_<bol0003oi]O6o`000002on[H`@06o`000?o^f;gok]Rmo`000?o`f;Wo
00000_oaekH00ol0003ol]Jdo`000002oo;E/`06o`000?obe;;ol]Bbo`000?oadk;o00000_o`dK<0
1Ol0003ok]2do`000?o[bkCo000000;oj<Rf00Ko0000onC5^?oTaKSo0000omo1^ol00002omRh^@06
o`000?oB/k_od[>ko`000?o:ZKWo00000oo3Y;X01_l0003o^i^hok^K^?l0003o]9Jho`0000Co[Xnf
00Ko0000ojV9]?nYRKCoZHVdo`000?nSQK<3o`0000?oWGnb00?o0000oiYm/_nJOK800_nJOK801Ol0
003oUgbcoiMl/onGO;?o000000?oU7^f00Go0000oi5l^OnAO;WoTGbio`000003ohen_@05o`000?n9
PLCoRH74ohV1a?l000000on4Qlh01?l0003oOI3Kogf@fol00004oe6enP03o`000?ndeo;o]=Ob00?o
00000ooCg^401?l0003oc>c[olc/joo<k>/2o`000006on3^f_l0003oeo[OomOjgol0003o`?kK0ol0
0003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/00Ko
0000ojO0k?l0003o0000ojO0k?l00004ojO0k006o`000?nW`>co0000o`000?nW`>co00001?nW`>`3
o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00004ooooo`03o`000?oooooooooo00Cooooo000ioooo
o`03o`000?oooooooooo02Oooooo0_l00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0
003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`01_l000001ol05Z?o0000o`000?l0003o
=UK6o`000?mYNm800_l00002oh>=e@?o00001Onb/=H00ol0003ob<7Do`000003om;7d004o`000?oK
c<_oflc;om_<b`;o000000Goj]S1o`000?o^f;gok]Rmo`000002oo3H^@08o`000?oaekKolMNfo`00
0?obe[Co0000oo;E/ol00002oo;D/P06o`000?oadk;olM>bo`000?o`dK?o00000oo^d;@01?l0003o
j<RfonS8]_l00003onC5^005o`000?oO`K_o0000omRh^Ol000001?oB/k/00ol0003o`jBjol>T^P03
ol>T^P;o00000ondU[P01Ol0003o[Xnfojj?]_n^SkKo000000;oZHVd0ol00002oj62/P03o`000?nM
Ok;oWGnb00;oWGnb00Go0000oiYm/_nJOK;oVWfbo`000003oiMl/`05o`000?nDNkKoU7^foiAk]_l0
00000onAO;T01Ol0003oSGjmohen_On=O[go000000?oRH7400Go0000ohB7c_n4QlkoQ8O>o`000002
ogf@f`So00000onQg_`00ol0003odmkQo`000002olc/j`;o000000Oo^oGao`000?l0003o0000omOj
gol0003o`?kK00;o000000CoYl3/o`000?nW`>coYl3/1?l00003ojO0k003o`000?nW`>coYl3/00Co
00000onW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/00?o0000ojO0k?nW`>`00ol000001_nW`>co
0000ojO0k?nW`>co0000ojO0k0;o000000?oYl3/o`000?nW`>`00onW`>`3o`0000?oYl3/00Go0000
ooooooooooooooooo`000006ooooo`00>_ooool00ol0003oooooooooo`0Vooooo`03o`000?nW`>co
Yl3/00;oYl3/0ol00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004
o`0000;oYl3/00?o0000o`E_gOl000000ol000001Ol:>;So0000ocIFa_lfE/Ko000000;oJG_B0_l0
0002oi>IeP03o`000?nb/=Ko/[3F00?o/[3F0_l00003om;7d003o`000?oKc<_oflc;00;oflc;00?o
0000on7@a_l000000_l000001?o^f;go0000oo3H^Ol00002oo7G]P06o`000?obe[Col]Jdo`000?ob
eK?o00000_obe;800ol0003olM>bo`000002oo3A/`04o`000?o^d;Cok]2donk@]0;o000000Goj<Rf
o`000?oTaKSoi<Fho`000003omo1^`03o`000?oB/k_od[>k00;od[>k0_l00004ol>T^P;o00001?nd
U[P02Ol0003o[Xnfojj?]_n^SkKo0000ojV9]?l0003oYHJdo`000003oj62/P03o`000?nMOk;oWGnb
00;oWGnb00Go0000oiYm/_nJOK;oVWfbo`000003oiMl/`05o`000?nDNkKoU7^foiAk]_l000001?nA
O;T01_l0003oSGjmohen_On=O[go0000ohV1a0So00000_nFXM`6o`0000;oXMkl1?l000000oo<k>_o
0000ok_el@02o`000003oi[cj?l0003o000000?o00000_nW`>`4o`0000;oYl3/00Co0000ojO0k?nW
`>coYl3/1?l00002ojO0k004o`000?nW`>coYl3/ojO0k0Co00000onW`>`00ol0003oYl3/ojO0k004
o`0000?oYl3/00?o0000ojO0k?l000000ol00004ojO0k006o`000?nW`>co0000o`000?nW`>co0000
1?nW`>`2o`0000?ooooo00?o0000ooooooooool00oooool003_ooooo00?o0000ooooooooool09_oo
ool01?l0003oYl3/o`000?l00002ojO0k004o`000?nW`>coYl3/ojO0k0?o00001?nW`>`00ol0003o
Yl3/ojO0k003o`0000?oYl3/00Co0000ojO0k?nW`>coYl3/1_l000001ol:>;So0000o`000?lfE/Ko
0000ofUkd_l000001?nCVMH01Ol0003o/[3Fok:`e_nb/=Ko000000;o_kSD00?o0000om;7d?l00000
1?oKc</01?l0003ohM36on7@a_l00002onKB`PGo000000KolMNfo`000?obe[Co0000oo;E/ol00003
oo;D/P05o`000?oadk;o0000oo3A/ol000000oo^d;@01?l0003ok<ngonc?]ol00002onC5^003o`00
0?oO`K_ogl6k00;ogl6k00Go0000om:c^ooB/k_od[>ko`000002ol^^_@06o`000?o3Y;[o`jBjo`00
0?nkWkco00001?ndU[P01?l0003o[Xnfojj?]_n^SkH2o`0000;oYHJd00?o0000oj62/_nQP[800_nQ
P[801Ol0003oWGnboieo/_nMOk;o000000?oVWfb00?o0000oiMl/onGO;<00_nGO;<01_l0003oU7^f
oiAk]_nDNkKo0000oi5l^@So00000_nHSlP01Ol0003oUiKAoiNFdOnGU]7o000000CoUZ7L00?o0000
oi:_j_nB[nX04?l000000onW`>co0000o`000002o`0000;oYl3/00Co0000ojO0k?nW`>coYl3/1?l0
0002ojO0k003o`000?nW`>coYl3/00Go00000_nW`>`01?l0003oYl3/ojO0k?nW`>`4o`0000;oYl3/
00Co0000ojO0k?nW`>coYl3/1Ol000000onW`>co0000ojO0k002ojO0k0?o00001?nW`>`4o`000003
ojO0k?l0003ooooo00;ooooo00?o0000ooooooooool00oooool003cooooo0_l0000Wooooo`;o0000
1?nW`>`00ol0003oYl3/o`000002ojO0k003o`000?nW`>coYl3/00;oYl3/0ol00003ojO0k003o`00
0?nW`>coYl3/00So000000Go01RUo`000?l:>;So0000odARb`02o`0000;oJG_B00?o0000oi>Ie_nC
VMH00_nCVMH00ol0003o/[3Fo`000004oknhe0;o00000ooKc</01?l0003ohM36on7@a_l00003onKB
`P03o`000?oZdkko000000;okMBk0_l000001?obe[Co0000oo;E/ol00002oo;D/P06o`000?oadk;o
lM>bo`000?o`dK?o00000oo^d;@00ol0003ok<ngonc?]`02o`000003onC5^?l0003ogl6k00;ogl6k
00Go0000omVn__l0003od[>ko`000003ol^^_@03o`000?o3Y;[o000000?o^inl00?o0000okBF^?nd
U[P00_ndU[P3o`000003ojV;]_l0003oYHJd00;oYHJd00Go0000oj62/_nQP[;oXH:bo`000003oieo
/P03o`000?nJOK;oVWfb00;oVWfb00?o0000oiMl/ol000001ol00002oiZ7_P05o`000?nIR/;oVH[2
oiV:`_l000001?nHSlP01Ol0003oUiKAoiNFdOnGU]7o000000;oUZ7L1?l00003ojO0k003o`000?nW
`>co000000Co00000onW`>`01_l0003oYl3/o`000?l0003oYl3/o`0000GoYl3/0ol000000onW`>co
0000ojO0k003ojO0k0?o00000onW`>`00ol0003oYl3/ojO0k005o`0000;oYl3/00?o0000ojO0k?nW
`>`01Ol00002ojO0k003o`000?nW`>co000000Go00000_nW`>`00ol0003oYl3/ojO0k003o`0000Go
Yl3/00Co0000oooooooooooo00001Oooool003kooooo00?o0000ooooooooool09_ooool00ol0003o
Yl3/ojO0k003o`0000CoYl3/00Ko0000ojO0k?l0003o0000ojO0k?l00004ojO0k0?o00000onW`>`6
o`000004o`0HYOl0003o2SRho`0000;oA6;;1?l00002oi>IeP?o00001?no^=@01_l0003ob/3Aol[0
dOl0003oflc;o`0000;ohM3600Oo0000onKB`_oVd/;oi];2o`000?oZdkko000000?okMBk00?o0000
onoE^?l000001?l000001?obe;;o0000oo7C/_l00002oo3A/`04o`000?o^d;Cok]2do`0000;ok<ng
00Co0000onW=^_oYcK[o00000ooO`K/01Ol0003ofKjnomVn__oI_[ko000000Gobjjm00?o0000ok^O
_?nkWk`00_nkWk`01?l0003o]9JhokBF^?ndU[P2o`0000?oZH^f00Go0000ojF6]?nUQ[CoYHJdo`00
0003oj62/P03o`000?nMOk;oWGnb00;oWGnb00?o0000oiYm/_l000000ol00002oib4^@05o`000?nK
QK_oVhFkoi^5^ol000001?nJQkh01Ol0003oVH[2oiV:`_nIR/;o000000?oV8o800?o0000oiNFdOnG
U]401?l00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k003o`0000Co
Yl3/00?o0000ojO0k?nW`>`00ol00004ojO0k006o`000?nW`>co0000o`000?nW`>co00001?nW`>`3
o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Go00000_nW`>`0
0ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00002ooooo`03o`000?oooooo
oooo00?ooooo000oooooo`03o`000?oooooooooo02Kooooo0_l00003ojO0k003o`000?nW`>coYl3/
00?o00001?nW`>`01_l0003oYl3/o`000?l0003oYl3/o`0000CoYl3/1_l000001?l06:Go0000o`00
0?l00002odARb`03o`000?miQmGoNHOE00?o00000_nRY=H01Ol0003o_kSDoknhe?no^=Co000000Co
b/3A00Go0000on7@a_oQd<KohM36o`000003onKB`P03o`000?oZdkko000000;okMBk00Ko0000onoE
^?o_eKSo0000oo3E]ol00002oo3F]P;o000000ColM>bo`000?o`dK?o00000oo^d;@01?l0003ok<ng
onc?]ol00002onW=^P;o000000?ogl6ko`000?oI_[h00ooI_[h00ol0003objjmol^^_@02ol^^_@;o
00001?nkWk`01_l0003o]9JhokBF^?l0003o[Y6io`0000CoZH^f00Co0000ojF6]?nUQ[Co00000onQ
P[801?l0003oWGnboieo/_nMOk83o`0000;oWHBh00Go0000oib4^OnLQ;WoW8Bio`000004oi^5^`05
o`000?nJQkkoVXNnoiZ7__l000000onIR/800ol0003oV8o8oiR?b004o`0000?oYl3/00?o0000ojO0
k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004o`00
00?oYl3/00?o0000ojO0k?nW`>`00ol00004ojO0k006o`000?nW`>co0000o`000?nW`>co00001?nW
`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>co000000Co00000onW
`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ooooool000001Oooool0043ooooo00?o0000
ooooooooool09_ooool00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00004
ojO0k005o`000?nW`>co0000o`000?nW`>`01_l000000ol06:Go0000o`000003odARb`04o`000?mi
QmGoNHOEo`0000CoXZCF00?o0000oknhe?l000001Oo:`=42o`000003on7@a_l0003oi];200;oi];2
00?o0000on[C__l000000oo]e;/01Ol0003okmFho`000?o`eKOo000000?ol=Jf00Ko0000oo7F]Ol0
003o0000oo3A/ol00002onk@]004o`000?o/ckOok<ngo`0000;ojLfj00Co0000onG<_OoUc;go0000
1?oI_[h00ol0003odk[2o`000002ol^^_@04o`000?o3ZL3o`jW0o`0000Co^inl0_l00002ojjA^@03
o`000?nYRkKoZH^f00;oZH^f00Co0000ojF6]?nUQ[Co00001?nQP[83o`000003oin5^?l0003oWHBh
00;oWHBh00?o0000oib4^OnLQ;T00_nLQ;T01Ol0003oVhFkoi^5^onKQK_o000000?oVXNn00Co0000
oiV:`_nIR/;oVH[20ol00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0
k004o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co00000onW
`>`00ol0003oYl3/ojO0k003o`0000CoYl3/00Ko0000ojO0k?l0003o0000ojO0k?l00004ojO0k0?o
00000onW`>`00ol0003oYl3/ojO0k005o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003
o`000?nW`>coYl3/00Co00001Oooool0047ooooo0_l0000Wooooo`;o00001?nW`>`00ol0003oYl3/
ojO0k003o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k0Oo000000Go546no`000?l0003o
A6;;o`000003ogV7e@04o`000?nRY=KoXZCFoj:TeP;o00001Oo:`=400ol0003odlK=om?6c@02o`00
00;oi];200Co0000on[C__oZdkko00000_o]e;/01_l0003okmFhonoE^?l0003ol=Fgo`0000;ol=Jf
00Go0000oo7F]Ooae[Go0000oo7F]P03o`000004onk@]?l0003ok<ngo`0000;ojLfj00Go0000onG<
_OoUc;goiLbmo`000003omVn_P06o`000?oC^/;odk[2o`000?o;[[go00000oo3ZL001?l0003o^inl
ok^O_?nkWk`2o`0000Co[Y6i00Go0000ojV;]_nYRkKoZH^fo`000003ojF6]003o`000?nQP[;o0000
00;o00000onOQKP00ol0003oWHBhoif4^002oif4^005o`000?nLQ;WoW8Bioib4^Ol000000onKQK/0
0ol0003oVXNnoiZ7_P02oiZ7_P?o000000?oYl3/o`000?nW`>`00onW`>`3o`0000?oYl3/00?o0000
ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004
o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o00001?nW`>`0
1_l0003oYl3/o`000?l0003oYl3/o`0000CoYl3/0ol00002ojO0k004o`000?nW`>co0000ojO0k0Co
00000_nW`>`01?l0003oYl3/ojO0k?nW`>`4o`0000;oYl3/0_l00005ooooo`00@oooool00ol0003o
ooooooooo`0Vooooo`03o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k003o`0000Co
Yl3/00?o0000ojO0k?nW`>`00ol000001ol008;o0000o`000?l0003o546no`000?mCK]000_l00003
ogV7e@04o`000?nRY=Ko0000o`0000;o/:kF00Go0000ol[0dOo:`=7ob/3Ao`000003om?6c@07o`00
0?oKb/Wo0000onKB`_l0003oj]>no`000003ongD^`05o`000?o_eKSo0000oo3E]ol000000oo`e[H0
0ol0003olMJeo`000002oo7F]P03o`000?o`e[Ool=Jg00;o000000Gok<ngo`000?oYcK[ojLfjo`00
0002onG<_@05o`000?oQb/;o0000omVn__l000001?oC^/800ol0003o`jW0ol>Y`002ol>Y`006o`00
0?nkWkco0000o`000?ncVKgo00001?n^TKT00ol0003oZH^fojV;]P02ojV;]P03o`000?nUQ[Co0000
00;o00000_nQQkT00ol0003oWhFhoin5^002oin5^005o`000?nMQ;SoWHBhoif4^?l000000onLQ;T0
0ol0003oVhFkoi^5^`02oi^5^`03o`000?nJQkko000000;o00001?nW`>`01_l0003oYl3/o`000?l0
003oYl3/o`0000CoYl3/0ol00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/
ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co0000
0onW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/1?l000000onW`>co0000ojO0k002ojO0k0Co0000
0_nW`>`00ol0003oYl3/ojO0k005o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00004ooooo`00A?oo
ool00ol0003oooooooooo`0Vooooo`;o00000onW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o
0000ojO0k?nW`>`01?l000001onA^_;o0000o`000?l0003o0022o`000?l07:P00ol00002oe=^d0Go
00001On`[]H00ol0003ob/3Ao`000003om?6c@04o`000?oKb/Wofl[9om_:b@;o000000Goj]>no`00
0?o]e;_okMBko`000002onoE^003o`000?o`eKOo000000;ol=Jf00Ko0000oo7F]Ooae[Go0000oo7F
]_l00003oo3F]`06o`000?o_e[Wo0000o`000?oYcK[o00000_oUc;d01Ol0003ohL[2on7:`_oQb/;o
000000Codk[20_l00004ol>Y`0;o00001?ncVKd01Ol0003o[Y6iojjA^On^TKWo000000?oZH^f0ol0
00000onSRk[o0000oj67^@03oj67^@05o`000?nOQKSoWhFhoin5^?l000000onMQ;P00ol0003oW8Bi
oib4^@02oib4^@03o`000?nKQK_o000000?o00000onW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/
00Ko0000ojO0k?l0003o0000ojO0k?l00004ojO0k0?o00000onW`>`00ol0003oYl3/ojO0k004o`00
00?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`01?l0
003oYl3/ojO0k?nW`>`4o`0000;oYl3/00?o0000ojO0k?nW`>`00ol00005ojO0k0?o00000_nW`>`0
0ol0003oYl3/o`000004o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ooooo`03o`000?oooooo
oooo00;ooooo0015ooooo`03o`000?oooooooooo02Kooooo00?o0000ojO0k?nW`>`01?l00003ojO0
k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oTK[boi6jlP02o`000005o`00P_l0003o0000
o`000?lPC<@00_l000000omCK]3o0000ohVDe`02ohVDe`03o`000?n`[]Ko/:kF00?o/:kF0_l00003
om?6c@05o`000?oKb/Wofl[9om_:bOl000000_oQc/H3o`000006ongD^ol0003okmFho`000?o`eKOo
00000oo`e[H00ol0003olMJeo`000002oo7F]P04o`000?o`e[Ool=Jgo`0000;okmJi00?o0000ongG
_Ol000000ooUc;d01Ol0003ohL[2on7:`_oQb/;o000000?odk[200Co0000ol^fa_o;]/Ko00000_o3
ZL000ol0003o^JC3o`000004ok>I_@03o`000?n^TKWo[Y6i00;o[Y6i0ol000000onVS[co0000oj>;
^P02oj>;^P05o`000?nQQkWoXHNioj67^Ol000000onOQKP00ol0003oWHBhoif4^002oif4^003o`00
0?nLQ;Wo000000?o00000onW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`0
0ol00004ojO0k006o`000?nW`>co0000o`000?nW`>co00001?nW`>`3o`0000?oYl3/00?o0000ojO0
k?nW`>`01?l00002ojO0k004o`000?nW`>coYl3/ojO0k0Co00000_nW`>`00ol0003oYl3/ojO0k005
o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o00001?nW`>`3
o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00007ooooo`03o`000?oooooooooo00;ooooo0016oooo
o`;o00009oooool2o`0000CoYl3/00?o0000ojO0k?nW`>`00ol00003ojO0k003o`000?nW`>coYl3/
00Oo000000Ko0022o`000?l07:So0000ob1<a?l00002oe=^d006o`000?n9U=OoRICGohVDeol0003o
/:kF0ol00002okfge003o`000?oCa/go000000?ofl[900Go0000on7>a_oQc/KohLk6o`000002onGA
`P;o000000CokmFho`000?o`eKOo00000_o`e[H01_l0003olMJeoo7F]Ol0003olMJfo`0000?ol=Jg
00?o0000onoF^Ol000000_o]ekd2o`000003onG<_Ol0003ohL[200;ohL[200Go0000om_9aol0003o
dk[2o`000003ol^faP03o`000?o3ZL3o000000?o^JC300Go0000ok>I_OncVKgo/iVmo`000003ojjA
^@;o00000onVS[`01Ol0003oXh^joj>;^_nSRk[o000000?oXHNi00?o0000oin5^?nOQKP00_nOQKP0
0ol0003oWHBho`000003o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>co
Yl3/00Co00000onW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/00Ko0000ojO0k?l0003o0000ojO0
k?l00004ojO0k0?o00000_nW`>`00ol0003oYl3/ojO0k005o`0000;oYl3/00?o0000ojO0k?nW`>`0
1?l00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/
00So0000ojO0k?l0003o0000ojO0k?l0003oYl3/o`0000;oYl3/0ol0000;ooooo`03o`000?oooooo
oooo00;ooooo0018ooooo`03o`000?oooooooooo02Kooooo00?o0000ojO0k?nW`>`01?l00003ojO0
k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003o;X[]o`000005o`0000;o84c40ol00002ohVD
e`?o00001_nm]m@01Ol0003ofl[9om_:bOoKb/Wo000000?ohLk600Ko0000onGA`_oUdL;oiM72o`00
0?oYdl05o`000006oo3F]_l0003olMJeo`000?oae[Ko00000oo`e[L01_l0003okmJionoF^Ol0003o
kMNmo`0000;ojmS100Go0000on7:`_oQb/;ohL[2o`000003om_9a`03o`000?o;]/KobkK600;obkK6
0_l00004okVT``03o`000?ncVKgo/iVm00;o/iVm0ol000000onYU<3o0000ojJ>_003ojJ>_005o`00
0?nSRk[oXh^joj>;^_l000000onQQkT00ol0003oWhFho`000003o`0000?oYl3/00?o0000ojO0k?nW
`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004o`0000?o
Yl3/00?o0000ojO0k?nW`>`00ol00004ojO0k006o`000?nW`>co0000o`000?nW`>co00000onW`>`3
o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`0
0ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00004ojO0k004o`000?nW`>co
0000o`0000kooooo00?o0000ooooooooool00_ooool004Wooooo00?o0000ooooooooool09_ooool2
o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00So00000_lPC<@0
0ol0003oI7cFofAleP02o`0000;oVJ3I00?o0000okfge?nm]m@00onm]m@01Ol0003ob;oBo`000?oK
b/Wo000000?ohLk600Go0000onGA`_oUdL;oiM72o`000002onWC`003o`000?o/e[go000000;ok]Nl
0_l000001?oae[Go0000oo7F]_l00002oo3F]`04o`000?o_e[WokmJio`0000;okMNm00?o0000on_H
`Oo[f<400_l000000ooQb/;o0000om_9a`02om_9a`;o00000oo;]/H00ol0003o`;;<o`000004okVT
``04o`000?ncVKgo/iVmok>I_@;o00001?nYU<001Ol0003oYXjlojJ>_?nVS[co000000?oXh^j00?o
0000oj67^OnQQkT00ol00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0
k004o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co00000onW
`>`00ol0003oYl3/ojO0k003o`0000CoYl3/0ol00002ojO0k003o`000?nW`>coYl3/00Co00000onW
`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW
`>coYl3/00Co00000_nW`>`01?l0003oYl3/ojO0k?nW`>`3o`000003ooooool0003ooooo00gooooo
00?o0000ooooooooool00_ooool004[ooooo00?o0000ooooooooool09Oooool00ol0003oYl3/ojO0
k002ojO0k0?o00000onW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/2?l000001?lPC<Co0000ofAl
e_l00004oiVPf@05o`000?nm]mCo_KODokfge?l000000oo8_m82o`0000?ohLk600Co0000onGA`_oU
dL;o00000_oYdl000ol0003ok=Jmo`000003onkG_003o`000?o_fK_o000000Co000000Col=Jgo`00
0?o_e[Wo00000_o]ekd01?l0003ojmS1on_H`Ol00002onOIa`05o`000?oKbLOoflW7om_9aol00000
0_oCalh00ol0003obkK6o`000003ol2bc003o`000?niY<?o^JC300;o^JC30ol000000on/VlGo0000
ojVD`003ojVD`005o`000?nVS[coYXjlojJ>_?l000000onSRkX01Ol0003oXHNio`000?nW`>co0000
00CoYl3/0ol00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004o`00
00?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`00ol0
003oYl3/ojO0k003o`0000CoYl3/0ol00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0
003oYl3/ojO0k004o`0000;oYl3/00Co0000ojO0k?nW`>coYl3/1?l00002ojO0k003o`000?nW`>co
Yl3/00Go00001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo001;oooo
o`03o`000?oooooooooo02Gooooo00Ko0000ojO0k?l0003o0000ojO0k?l00004ojO0k0?o00000onW
`>`01?l0003oYl3/ojO0k?nW`>`6o`000003obeIc?l0003o000000;oI7cF00?o0000oiVPfOnIX=T0
0_nIX=T00ol0003o_KODo`000003olRodP06o`000?oAa/oodLK?o`000?oQc/Ko00000_oUdL801ol0
003ojM?0onWC`?oYdl3o0000oncF_Ol000000_o^ek`01_l0003okmVkonoI^ol0003ol=^ko`0000;o
l=fl0_l000001?o_e[Wo0000ongG_Ol00002on_H`@04o`000?oWfLOoimW7onOIa`;o000000?oflW7
o`000?oCalh00ooCalh00ol0003o`;;<ol2bc002ol2bc003o`000?niY<?o^JC300?o00001?n/VlD0
1Ol0003oZIC0ojVD`?nYU<3o000000CoYXjl00?o0000oj>;^_l000000_l00003ojO0k006o`000?nW
`>co0000o`000?nW`>co00001?nW`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003
o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/00?o0000ojO0k?nW
`>`01?l00003ojO0k006o`000?nW`>co0000o`000?nW`>co00001?nW`>`3o`0000?oYl3/00?o0000
ojO0k?nW`>`01?l00002ojO0k003o`000?nW`>coYl3/00Go00000_nW`>`00ol0003oYl3/ojO0k004
o`0000[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`01ooooo`00C?ooool2o`00
02Kooooo0_l00003ojO0k004o`000?nW`>co0000o`0000;oYl3/00?o0000ojO0k?nW`>`03?l00002
obeIc0Co00000_nIX=T3o`0000?ob;oB00?o0000om76cooAa/l00_oAa/l01Ol0003oiM72onGA`_oU
dL;o000000;ojM?000?o0000oncF_Ol000000oo^ek`01Ol0003okmVko`000?o`fk_o000000?ol=fl
00Ko0000oo3O__l0003o0000ongG_Ol00002on_H`@04o`000?oWfLOoimW7o`0000;oh][>0_l00003
om?7cP;o00001?o0//`3o`0000;o/:G<00?o0000ojbKaOn/VlD00_n/VlD00ol0003oZIC0ojVD`002
ojVD`003o`000?nVS[co000000?o00000onW`>`00ol0003oYl3/ojO0k002o`0000CoYl3/00Co0000
ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`01?l0
0003ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o
0000ojO0k?nW`>`00ol00004ojO0k006o`000?nW`>co0000o`000?nW`>co00001?nW`>`3o`0000;o
Yl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co00003oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo007ooooo001>ooooo`03o`000?oooooooooo02Gooooo
00?o0000ojO0k?nW`>`00ol00003ojO0k0?o00001?nW`>`00ol0003oRKOdo`000004o`000004o`0/
]?l0003o;EW<o`0000;oM8_K0ol00003ojR/fP03o`000?o8_m;o000000GodLK?0_l000001OoUdL;o
0000onWC`?oYdl3o000000;ok=Jm00Co0000onkG_?o^ekco00000_o_fK/00ol0003ol=^ko`000002
oo3M_005o`000?o`gkkol=nno`000?o_h/800_l000001Oo[f<7o0000onOIaooWfLOo000000?oh][>
00Go0000om[Keol0003odlO>o`000002olS4eP06o`000?o0//co0000o`000?ne/MGo00001?n`YL`0
1Ol0003o[9_5ojbKaOn/VlGo000000;oZIC01?l00003ojO0k003o`000?nW`>coYl3/00Co00000_nW
`>`00ol0003oYl3/ojO0k003o`0000CoYl3/0ol00003ojO0k003o`000?nW`>coYl3/00Co00000onW
`>`00ol0003oYl3/ojO0k004o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW
`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/00Ko0000ojO0k?l0003o0000
ojO0k?l00003ojO0k0?o00000onW`>`00ol0003oYl3/ojO0k004o`0001Cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`01ooooo`00Coooool00ol0003oooooooooo`0Uooooo`;o0000
0onW`>`00ol0003oYl3/o`000002ojO0k003o`000?nW`>coYl3/00;oYl3/1ol00002o`0/]0?o0000
0_mdRm/00ol0003oZ:cJojR/fP02ojR/fP;o00001OoAa/l00ol0003ofLc=omW<c@03o`000004onWC
`?l0003ok=Jmo`0000?ok]Nl00Go0000onoI^ol0003ol=^ko`000003oo3M_003o`000?o`gkko0000
00;okn;200Ko0000ongUa_l0003o0000onOIaol00003on;JcP03o`000?oJfmOof]_G00;o00000oo8
a=H2o`0000Co]K7E00Go0000ok2Uc?n`YLco/:G<o`000002ojbKa@Co00000onW`>`00ol0003oYl3/
ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00003ojO0k006o`000?nW`>co0000o`000?nW
`>co00001?nW`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00002ojO0k003o`000?nW`>coYl3/
00Co00000onW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0
k003o`000?nW`>coYl3/00?o00001?nW`>`3o`0000;oYl3/00?o0000ojO0k?nW`>`01?l0000Hoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00Oooool0053ooooo00?o0000oooooooo
ool09Oooool00ol0003oYl3/ojO0k003o`0000CoYl3/00Ko0000ojO0k?l0003o0000ojO0k?l00002
oeVOm0Ko000000?o>fSDo`000?mdRm/00_mdRm/01?l0003oZ:cJo`000?l00002okJgfP05o`000?oA
a/oodLK?om76col000000ooIc<d00ol0003ogm7:omoAbP02o`000007oncF_Ol0003ok]NlonkG_?l0
003okmVko`000002oo3K^`06o`000?o`gKcol=flo`000?o`gkko00000_o_h/801Ol0003okNG6ongU
a_l0003oj^S<00?o000000Goh][>o`000?oJfmOof]_Go`000002olkKh`03o`000?o8a=Ko000000;o
^L7P00Go0000okFaeOne/MGo]K7Eo`000002ok2Uc0Co00000onW`>`00ol0003oYl3/ojO0k004o`00
00?oYl3/00?o0000ojO0k?nW`>`01?l00002ojO0k003o`000?nW`>coYl3/00?o00001?nW`>`01_l0
003oYl3/o`000?l0003oYl3/o`0000CoYl3/0ol00002ojO0k003o`000?nW`>coYl3/00Co00000onW
`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW
`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/0ol0000Mooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool00Oooool0057ooooo0_l0000Vooooo`;o00000onW`>`0
0ol0003oYl3/ojO0k003o`0000CoYl3/00?o0000oeVOm?l000000ol000001?l0=kco0000o`000?lk
J=@5o`0000Go][OJ00?o0000om76col000000ooIc<d01_l0003ogm7:omoAb_oOdL[o0000onCEb0?o
000000Kok]Nlo`000?o_fK_o0000oo3K^ol00002oo3M_006o`000?o`gkkol=nno`000?o_h/;o0000
0_o]iLH01Ol0003oj^S<on[Xc?l0003oiNgE00?o000000?of]_Go`000?o>fn<00_o>fn<2o`0000Co
^L7P00?o0000okFaeOne/MD00ol00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003o
Yl3/ojO0k004o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o
00001?nW`>`01?l0003oYl3/o`000?l00002ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0
003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/
00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00Co0000ojO0k?l0003o00008Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo007ooooo001Cooooo`03o`000?oooooooooo
02Gooooo00?o0000ojO0k?nW`>`00ol00003ojO0k003o`000?nW`>coYl3/00So000000Co03Nlo`00
0?lkJ=Co00001?n5V]l00ol0003o][OJokJgfP02okJgfP;o00000ooIc<d01Ol0003ogm7:omoAb_oO
dL[o000000;oi=G800?o0000onSIa_oXfLH01?l000001oo`fk_o0000oo3M_?o`gKco0000oo3O__l0
00000_o_h/800ol0003okNG6o`000002on[Xc003o`000?oUkMGo000000;ofo7O0ol000000oo>fn?o
0000o`000002ok[Ek@03o`000?ni`N3o^L7P00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0000?o
Yl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003o
Yl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00004ojO0k0?o00000_nW`>`00ol0003o
Yl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co
00000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol0000Sooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool005Cooooo00?o0000ooooooooool0
9Oooool2o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00003ojG0k007o`000?lcQ>[o0000o`000?l0
1IOo0000o`0g_003o`0000CoQI[O00Co0000okJgf_l0003o00000_o1`MT00ol0003ofLc=o`000003
omoAbP04o`000?oTeLSoi=G8o`0000?oj=W600Co0000on_MaOl0003okN751ol000001?o_h/;o0000
ongUa_l00002on[Xc003o`000?oUkMGo000000;ofo7O00?o0000ol_cjoo;ln/00_l00004ok[Ek@?o
00000onW`>`00ol0003oYl3/ojO0k003o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003
o`000?nW`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW
`>`01?l00003ojO0k006o`000?nW`>co0000o`000?nW`>co00000onW`>`3o`0000?oYl3/00?o0000
ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k004
o`0000?oYl3/00?o0000ojO0k?nW`>`01?l0000Wooooo`03o`000?oooooooooo00Sooooo0Ol00001
ooooo`7ooooo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ojO0k?nW`>`01?l00003ojO0
k003o`000?nU`>coYL3/00Go000000Co00FGo`000?l0003oBgWM0_l00002ohFJg`?o00001?o1`MT4
o`000005omoAb_l0003oi=G8onCEb?l000000ooXfLH00ol0003ojmg5o`000002ongQa@07o`000?o^
iLGok^G5o`000?o^jLKo0000ong^b@09o`000003om_agol0003obo?[00;o00000_nej?L01_l0003o
^]G]o`000?l0003oYl3/o`0000CoYl3/0ol00002ojO0k003o`000?nW`>coYl3/00Co00000onW`>`0
0ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00003ojO0k003o`000?nW`>co
Yl3/00Co00000onW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/0ol00002ojO0k003o`000?nW`>co
Yl3/00Co00000onW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00003
ojO0k003o`000?nW`>coYl3/00Co0000;?ooool00ol0003oooooooooo`07ooooo`7o00000Oooool1
ooooo`00E_ooool2o`0002Kooooo0_l00003ojO0k003o`000?nW`>coYl3/00Co00000_nK_O000ol0
003o7g[Uo`000004o`0000;oBgWM0_l00002oiFXh`05o`000?o1`MWo`L7Iol71fOl000001?o;b]P0
1Ol0003oi=G8onCEb?oTeLSo000000;oj=W600?o0000on_MaOl000000_o]hLD01_l0003ok^G5onkU
aOl0003ok^W6o`0000;okNk90_l00002onGhd@04o`000?oLo=Oo0000ol_ng@Go00000_nej?L3o`00
00CoYl3/00Co0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k003o`0000?oYl3/00?o0000
ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k004
o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00;o00001?nW`>`3
o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00002ojO0k003o`000?nW`>coYl3/00Co00000onW`>`0
0ol0003oYl3/ojO0k004o`00037ooooo00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool0
05Sooooo00?o0000ooooooooool09?ooool00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000oi^m
l?nK_O001ol00002od]ig@03o`000?nEZ>?oUJSS00;oUJSS00?o0000ol71fOl000001?o;b]P01Ol0
003oe=;Go`000?oTeLSo000000;oj=W600Ko0000on_MaOo[gLGo0000ongQaOl00002onkUa@03o`00
0?o^jLKo000000;okNk90_l00002onGhd@03o`000?oLo=Oo000000Co000000?oWo7co`000?l00000
0_l00003ojO0k003o`000?nW`>coYl3/00?o00001?nW`>`3o`0000;oYl3/00?o0000ojO0k?nW`>`0
1?l00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k003o`0000?oYl3/
00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`01?l0003oYl3/
o`000?l00002ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0000?o
Yl3/00?o0000ojO0k?nW`>`01?l0000eooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7o
oooo001Iooooo`03o`000?oooooooooo02Cooooo0_l00003ojO0k003o`000?nW`>coYl3/00Co0000
0onA_?@3o`000003o`14aOl0003o000000;o00000_nEZ><4o`0000?obl[H00Co0000omCBeooDd]Oo
e=;G0_l000001OoXfLKo0000on_MaOo[gLGo000000;okN7500Oo0000onkUaOo^iLGo0000onkYa_l0
003okNk900;o00000_oUn=400ol0003og?cGo`000006o`0000?oYl3/00?o0000ojO0k?nW`>`01?l0
0003ojO0k004o`000?nW`>co0000o`0000;oYl3/00?o0000ojO0k?nW`>`00ol00003ojO0k003o`00
0?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/00?o0000ojO0k?nW`>`0
1?l00003ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/
0ol00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k004o`0003[ooooo
00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool005[ooooo00?o0000ooooooooool09Ooo
ool00ol0003oYl3/ojO0k003o`0000?oYl3/00?o0000oi6lm?nA_?@01ol000001?mJRnKo0000o`00
0?l00004ojBgi`03o`000?o;b]So000000?oe=;G00?o0000om_Je_oKf]H01Ol000002?o]hLGo0000
onkUaOo^iLGo0000onkYa_l0003okNk92ol00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`0
0ol0003oYl3/ojO0k003o`0000CoYl3/0ol00002ojO0k003o`000?nW`>coYl3/00Co00000onW`>`0
0ol0003oYl3/ojO0k004o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>co
Yl3/00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00Co0000ojO0k?l0003o00000_nW
`>`00ol0003oYl3/ojO0k004o`0000;oYl3/00?o0000ojO0k?nW`>`01?l0000oooooo`03o`000?oo
oooooooo00Cooooo0Ol00001ooooo`7ooooo001Kooooo`;o00009_ooool2o`0000?oYl3/00?o0000
ojO0k?nW`>`00ol00003ohNimP;o000000?o05?@o`000?l000000_mJRnH00ol0003oY;OWojBgi`02
ojBgi`;o00000ooDd]L01?l0003ofm[Fom_Je_l00003on3Qe@03o`000?oTj=Co000000Oo000000?o
g?kBo`000?l000001?l00003ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0
k004o`0000?oYl3/00Co0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k003o`0000?oYl3/
00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/
ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00003ojO0k003o`000?nW`>coYl3/00?o0000
1?nW`>`3o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00014ooooo`03o`000?oooooooooo00?ooooo
0Ol00001ooooo`7ooooo001Mooooo`03o`000?oooooooooo02Cooooo00?o0000ojO0k?nW`>`01?l0
0002ojW1j`03o`000?n7^OKoQkWf00Co00000_l0Dm04o`000003ojBgiol0003o000000;o/LKY00?o
0000omCBeol000000_oKf]H01ol0003oh>7Eon3QeOoPhMGo0000onCXe?l000000ooVk]<2o`000003
on?jdol0003og?kB00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW
`>`00ol00003ojO0k003o`000?nW`>coYl3/00?o00001?nW`>`3o`0000;oYl3/00?o0000ojO0k?nW
`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0000?o
Yl3/00?o0000ojO0k?nW`>`01?l00002ojO0k003o`000?nW`>coYl3/00Co00000onW`>`01_l0003o
Yl3/o`000?l0003oYl3/o`0000;oYl3/1?l00018ooooo`03o`000?oooooooooo00Cooooo0Ol00001
ooooo`00G_ooool00ol0003oooooooooo`0Tooooo`;o00000onW`>`00ol0003oZL7[ojW1j`03o`00
00?oP[Kf1?l00002ofZNk`;o00001?naa^T3o`000003om_Je_l0003oh>7E00;oh>7E00?o0000onCX
e?l000000ooVk]<2o`000003on?jdol0003og?kB00?o000000CoYl3/o`000?nW`>coYl3/0ol00003
ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00Co0000
ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k003o`0000?oYl3/00?o0000ojO0k?nW`>`01?l0
0003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/00?o
0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`3o`0004gooooo00?o
0000ooooooooool00oooool1o`00007ooooo001Oooooo`03o`000?oooooooooo02Cooooo00?o0000
ojO0k?nW`>`01?l00003ojc2j@03o`000?n2]_KoP[Kf00Go00000omZW^l01?l0003o/LKYo`000?l0
0002okgCj`Co000000Coh>7Eo`000?oTj=Co00000ooVk]<2o`000003on?jdol0003o000000;o0000
0_nW`>`4o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o0000
0onW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/0ol00002ojO0k003o`000?nW`>coYl3/00Co0000
0onW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`00
0?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?l00000
DOooool00ol0003oooooooooo`02ooooo`7o00000Oooool0063ooooo0_l0000Uooooo`;o00000onW
`>`00ol0003o[<;Yojc2j@04o`0000?oQKGd00?o0000o`IUf_l000001?l00003okgCj`04o`000?o6
h>_oa^3[olKPj`Ko000000?oi^kCo`000?l000002?l00003ojO0k003o`000?nW`>coYl3/00?o0000
0onW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k004o`00
0?nW`>co0000o`0000;oYl3/00?o0000ojO0k?nW`>`00ol00003ojO0k003o`000?nW`>coYl3/00Co
00000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00002ojO0k003
o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k003o`0005?ooooo00Go0000oooooooo
ooooooooo`000001ooooo`00H_ooool00ol0003oooooooooo`0Tooooo`03o`000?nW`>coYl3/00?o
00000on]aN/9o`0000;oN;?g00?o0000okgCjol000000oo6h>/00ol0003oc>_[o`000003oloej@Co
000000Co/o_Ao`000?l0003o00000onW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/00?o0000ojO0
k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k003o`00
00CoYl3/0ol00002ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k003o`00
00?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0
003oYl3/ojO0k004o`0005Kooooo00Go0000ooooooooooooooooo`000001ooooo`00Hoooool00ol0
003oooooooooo`0Tooooo`;o00000_nW`>`01_l0003o[LG[o`000?l0003oZ/;[o`0000CoSkOa00?o
0000o`ahh_l000001_l000001?o6h>_o0000olc[jol00003oloej@03o`000?o<o>Co000000?o0000
0_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00003ojO0k003o`00
0?nW`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00Co0000ojO0k?l0003o
00000_nW`>`00ol0003oYl3/ojO0k003o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00002ojO0k003
o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/00?o0000ojO0k?nW
`>`01?l0001Kooooo`04o`000?ooooooooooo`00007ooooo001Tooooo`03o`000?oooooooooo02Co
oooo00?o0000ojO0k?nW`>`00ol00003oj[2j`03o`000?n?]o7oSkOa00Ko00000_n4aod7o`000003
oloejOl0003oc?cT00?o000000CoYl3/o`000?nW`>coYl3/0ol00003ojO0k003o`000?nW`>coYl3/
00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00003ojO0
k003o`000?nW`>coYl3/00Co00000_nW`>`4o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0
k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/00?o0000ojO0
k?nW`>`01?l0001Pooooo`03o`000?oooooo0000007ooooo001Uooooo`;o00009Oooool2o`0000?o
Zl7Z00?o0000oj[2jonZ`^/00ol00003oibjk@03o`000?nB`?Ko000000;o000000?oSMSoo`000?l0
00000_n?iO/6o`0000;oYl3/1?l00002ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003o
Yl3/ojO0k003o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00002ojO0k003o`000?nW`>coYl3/00Co
00000onW`>`3o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co
00000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol0001Tooooo`03
o`000?oooooooooo007o0000001Wooooo`03o`000?oooooooooo02?ooooo00?o0000oj_1j_n[`NX0
1?l00002ojJlj@03o`000?nL^^goW;[]00Co000000?oYl3/o`000?l000002?l000001?nW`>co0000
o`000?l00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k004o`0000;o
Yl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`01?l0003o
Yl3/o`000?l00002ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k004o`00
00;oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co0000J?ooool1o`00
007ooooo0Ol0000006Sooooo00?o0000ooooooooool08oooool2o`0000?o[<7Z00?o0000ojJljOnV
_>T00ol00003ojO0k0?o00000onW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/00?o0000ojO0k?nW
`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k003o`0000?o
Yl3/00?o0000ojO0k?nW`>`01?l00002ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`4o`0000;o
Yl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003o
Yl3/ojO0k004o`0006gooooo0_l0000006Wooooo00?o0000ooooooooool08oooool00ol0003o[<7Z
ojc1jP04o`0000?oYl3/00?o0000ojO0k?l000000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/
00?o0000ojO0k?nW`>`00ol00003ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`00ol0003oYl3/
ojO0k004o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o0000
0_nW`>`4o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00003ojO0k003o`000?nW`>coYl3/00Co0000
0_nW`>`00ol0003oYl3/ojO0k004o`00073ooooo0ol0000006[ooooo0_l0000Tooooo`;o00000onW
`>`00ol0003oYl3/ojO0k004o`0000;oYl3/0ol00003ojO0k003o`000?nW`>coYl3/00Co00000_nW
`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00003ojO0k003o`000?nW
`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/0ol00003ojO0k003o`000?nW
`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol0
001`ooooo`Co00000oooool006cooooo00?o0000ooooooooool08oooool00ol0003oYl3/ojO0k003
o`0000;oYl3/1?l00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k003
o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00002ojO0k003o`000?nW`>coYl3/00Co00000onW`>`0
0ol0003oYl3/ojO0k003o`0000?oYl3/00?o0000ojO0k?l000000_nW`>`00ol0003oYl3/ojO0k004
o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00003ojO0k003o`000?nW`>coYl3/00Co0000Koooool4
o`0000Oooooo001]ooooo`03o`000?oooooooooo02?ooooo0_l00002ojO0k0?o00000onW`>`00ol0
003oYl3/ojO0k004o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00002ojO0k003o`000?nW`>coYl3/
00Co00000onW`>`00ol0003oYl3/ojO0k003o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00002ojO0
k003o`000?nW`>coYl3/00Co00000_nW`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00002ojO0
k003o`000?nW`>coYl3/00Co0000L?ooool3o`0000_ooooo001^ooooo`03o`000?oooooooooo02?o
oooo00?o0000ojO0k?l000000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW
`>`00ol00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k004o`0000;o
Yl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o00000_nW`>`4o`0000;o
Yl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o0000L?ooool4o`0000ko
oooo001_ooooo`;o00009?ooool2o`0000;oYl3/0ol00003ojO0k003o`000?nW`>coYl3/00Co0000
0_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00003ojO0k003o`00
0?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k004o`000003ojO0k?l0003o000000;o0000
0onW`>`00ol0003oYl3/ojO0k003o`0000?oYl3/00?o0000ojO0k?nW`>`01?l0001_ooooo`Co0000
4_ooool0077ooooo00?o0000ooooooooool08oooool2o`0000?oYl3/00?o0000ojO0k?nW`>`00ol0
0003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/00?o
0000ojO0k?nW`>`01?l00002ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`3o`0000?oYl3/00?o
0000ojO0k?nW`>`01?l00002ojO0k003o`000?nW`>coYl3/00Co0000Koooool4o`0001Kooooo001b
ooooo`03o`000?oooooooooo02?ooooo00?o0000ojO0k?nW`>`01?l00002ojO0k003o`000?nW`>co
Yl3/00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00003
ojO0k003o`000?nW`>coYl3/00?o00000_nW`>`4o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00003
ojO0k003o`000?nW`>coYl3/00?o0000Koooool4o`0001[ooooo001cooooo`03o`000?oooooooooo
02?ooooo0_l00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k003o`00
00?oYl3/00?o0000ojO0k?nW`>`01?l00002ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`3o`00
00?oYl3/00?o0000ojO0k?nW`>`00ol00003ojO0k003o`000?nW`>coYl3/00Co0000K_ooool4o`00
01kooooo001dooooo`;o00009?ooool00ol0003oYl3/ojO0k004o`0000;oYl3/00?o0000ojO0k?nW
`>`01?l00002ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k003o`0000;o
Yl3/1?l00002ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0006oo
oooo0ol0000Rooooo`00M_ooool00ol0003oooooooooo`0Rooooo`;o00000onW`>`00ol0003oYl3/
ojO0k003o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00003ojO0k003o`000?nW`>coYl3/00Co0000
0_nW`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00003ojO0k003o`000?nW`>coYl3/00?o0000
Koooool4o`0002Gooooo001gooooo`03o`000?oooooooooo02;ooooo00?o0000ojO0k?nW`>`01?l0
0002ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k003o`0000;oYl3/1?l0
0002ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0006kooooo1?l0
000Yooooo`00N?ooool00ol0003oooooooooo`0Rooooo`;o00000onW`>`00ol0003oYl3/ojO0k003
o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00002ojO0k0?o00000onW`>`00ol0003oYl3/ojO0k003
o`0000?oYl3/00?o0000ojO0k?nW`>`00ol0001^ooooo`Co0000;Oooool007Wooooo0_l0000Toooo
o`03o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k003o`0000;oYl3/1?l00002ojO0
k003o`000?nW`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0006gooooo1?l0000aoooo
o`00Noooool00ol0003oooooooooo`0Rooooo`;o00000_nW`>`00ol0003oYl3/ojO0k004o`0000;o
Yl3/0ol00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k003o`0006go
oooo1?l0000eooooo`00O?ooool00ol0003oooooooooo`0Rooooo`03o`000?nW`>coYl3/00?o0000
0_nW`>`4o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00002ojO0k003o`000?nW`>coYl3/00Co0000
K?ooool4o`0003Wooooo001mooooo`03o`000?oooooooooo02;ooooo0_l00002ojO0k0?o00000onW
`>`00ol0003oYl3/ojO0k003o`0000?oYl3/00?o0000ojO0k?nW`>`00ol0001]ooooo`?o0000?Ooo
ool007kooooo0_l0000Tooooo`;o00000_nW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/00?o0000
ojO0k?nW`>`01?l0001/ooooo`Co0000@?ooool0083ooooo00?o0000ooooooooool08_ooool00ol0
003oYl3/ojO0k003o`0000?oYl3/00?o0000ojO0k?nW`>`00ol0001/ooooo`Co0000A?ooool0087o
oooo00?o0000ooooooooool08_ooool2o`0000;oYl3/00?o0000ojO0k?nW`>`01?l0001[ooooo`Co
0000B?ooool008;ooooo00?o0000ooooooooool08_ooool00ol0003oYl3/ojO0k003o`0006_ooooo
1?l0001<ooooo`00Poooool2o`0002?ooooo0_l0001Zooooo`Co0000D?ooool008Gooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`1Vooooo`?o0000E?ooool008Kooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`1Rooooo`Co0000Eoooool008Oooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`1Nooooo`Co0000Foooool008Sooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`1Jooooo`Co0000Goooool008Wooooo0_l0000Mooooo`03o`000?oo
oooooooo05Kooooo1?l0001Sooooo`00Roooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo05;ooooo1?l0001Wooooo`00S?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
04oooooo0ol0001[ooooo`00SOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04_o
oooo1?l0001^ooooo`00S_ooool2o`0001Sooooo00?o0000ooooooooool0Aoooool4o`0007;ooooo
002@ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@oooool4o`0007Kooooo002A
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?oooool4o`0007[ooooo002Boooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0>oooool4o`0007kooooo002Cooooo`;o
00004_ooool00ol0003oooooooooo`0iooooo`?o0000P_ooool009Gooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0eooooo`Co0000QOooool009Kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0aooooo`Co0000ROooool009Oooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0]ooooo`Co0000SOooool009Sooooo0_l0000=ooooo`03o`000?oooooooooo
02Wooooo1?l0002Aooooo`00V_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Go
oooo1?l0002Eooooo`00Voooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo
1?l0002Iooooo`00W?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo0ol0
002Mooooo`00WOooool2o`0000Sooooo00?o0000ooooooooool06_ooool4o`000:3ooooo002Ooooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool4o`000:Cooooo002Pooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool4o`000:Sooooo002Qooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool03_ooool4o`000:cooooo002Rooooo`;o00000ooo
ool00ol0003oooooooooo`0:ooooo`Co0000/?ooool00:Cooooo00Co0000oooooooooooo00002Ooo
ool3o`000;Cooooo002Uooooo`03o`000?oooooo000000Gooooo1?l0002gooooo`00Y_ooool2o`00
0003ooooool0003o000000;o0000^oooool00:Oooooo0_l0002oooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00_oooool3o`000003oa0@
4?oooooooooo0:?ooooo002Mooooo`03okZj^_lb<S;ooooo00;ooooo00Co0000oooooooooooo0000
1oooool2o`0000_ooooo00?o0000okZj^_ooool01?ooool00ol@413o^[Zjooooo`05ooooo`;o0000
1Oooool00ol0003o^[Zjooooo`2Eooooo`00W_ooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`;o<S8b1Oooool00onHV9So<S8b
ooooo`06ooooo`03o`000?oooooooooo00?ooooo0_lb<S:Fooooo`00W?ooool01onHV9So410@o`00
0?l0003oZJVYooooool000000_ooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooooooo
o`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool00ooMgMgo0000okZj^P06oooo
o`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X02oooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00Kooooo00GoV9RHoa0@4?l0003o<S8bolc<c01fooooo`00W?ooool0
1_l0003oZJVYoeEEEOnHV9SoEEEEokZj^P?o00002?ooool02_l0003oooooooooooooooook^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00?oEEEEogMgMom4A4@01_oo
ool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00cooooo00Go0000oooooooooooooooo
o`000002ooooo`Ko000000Kooooooa0@4?nj^[[oooooogMgMolb<S9fooooo`00W?ooool01_lb<S;o
k^k^oiRHV?mEEEGogMgMoa0@40_ooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<
c<`:ooooo`05omgMgOl@413oooooob4Q8OoMgMd01Oooool00ol0003oooooooooo`0Booooo`05o`00
0?ooooooooooooooool000003Oooool00ol0003oooooooooo`1dooooo`00W?ooool01onj^[[oA4A4
olc<c?lQ8B7ooooooa0@4?o<c<`02_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@
onk^kP[ooooo00GoIVIVohN7QoooooooV9RHoeEEE@05ooooo`03o`000?oooooooooo01;ooooo00Go
0000ooooooooooooooooo`000002ooooo`Ko00001?ooool00onYZJWo410@ooooo`1eooooo`00W?oo
ool01oo^k^ko0000ooooool0003oooooofIVI_n7QhL02_ooool00ol0003oooooooooo`02ooooo`04
ob4Q8OmgMgOoMgMgoc8b<PWooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`03oooo
o`03o`000?oooooooooo01;ooooo00Go0000ohN7QoooooooZJVYo`00000;ooooo`03oa0@4?l0003o
^[Zj07Kooooo002Looooo`04ofIVI_nHV9Sooooooc8b<P;o^[Zj00?o0000ooooooooool02?ooool0
1?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`04oa0@4?l0003o0000ooooo`;o0000
00?o410@ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003oMgMg00;o0000
00?oV9RHooooooooool02_ooool00onj^[[o8B4Qooooo`1eooooo`00Woooool00omVIVKoQhN7oooo
o`0;ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08?ooool01Ol@413oV9RHoooo
oonj^[[o000007Kooooo002Oooooo`03ojVYZOm4A4Cooooo00_ooooo0_l0000Jooooo`;o00008_oo
ool01OnYZJWo410@o`000?l@413oZJVY07Kooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.875, 0}} -> {-0.121594, 0.0187328, \
0.00374021, 0.00374021}}]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["6.3.4 WKB Eigenmodes", "Subsubtitle",
  CellTags->"c:38"],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["The Wave Equation", "Section",
  CellTags->"c:39"],

Cell["\<\
\tFor one-dimensional eigenmode problems, the WKB method can be \
used to determine analytic approximations to the eigenmodes. This provides an \
analytic alternative to the strictly numerical methods discussed \
previously.\
\>", "Text",
  CellTags->"i:43"],

Cell[TextData[{
  "\t Our model PDE for this section will be the 1D wave equation with \
arbitrary tension ",
  Cell[BoxData[
      \(TraditionalForm\`T(x)\)]],
  " and mass density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x)\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\^2\/\[PartialD]t\^2\) \(y(x, 
            t)\) = \(\(L\&^\) 
            y = \(1\/\(\[Rho](x)\)\) \(\[PartialD]\/\[PartialD]x\) \((\(T(
                  x)\)\ \(\[PartialD]\/\[PartialD]x\) \(y(x, t)\))\)\)\)]],
  ","
}], "NE3",
  CellTags->{"(3.1.7)", "(6.3.13)"}],

Cell[TextData[{
  "subject to homogeneous Dirichlet boundary conditions, ",
  Cell[BoxData[
      \(TraditionalForm\`y(0, t) = \(y(L, t) = 0\)\)]],
  ". "
}], "Text"],

Cell["\<\
\tApproximate eigenmodes and eigenvalues for this problem can be \
obtained using WKB theory.  The WKB solution to  the eigenmode \
equation,\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(1\/\(\[Rho](
                x)\)\) \(\[PartialD]\/\[PartialD]x\) \((\(T(
                x)\)\ \(\[PartialD]\/\[PartialD]x\) \[Psi]\_n)\) = \
\(\[Lambda]\_n\) \[Psi]\_n\)]],
  ","
}], "NE3",
  CellTags->"(6.3.14)"],

Cell["is", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_n\)(
          x) = \(C\_1\/\([\(T(x)\) \(\[Rho](x)\)]\)\^\(1/4\)\) \
\[ExponentialE]\^\(\[ImaginaryI] \(\[Integral]\_0\%x\(\( k\_n\)(x)\) \(\(\
\[DifferentialD]x\)\(\ \)\)\)\) + \(\(C\_2\/\([\(T(x)\) \
\(\[Rho](x)\)]\)\^\(1/4\)\) \(\[ExponentialE]\^\(\(-\[ImaginaryI]\) \(\
\[Integral]\_0\%x\(\( k\_n\)(
                        x)\) \(\(\[DifferentialD]x\)\(\ \)\)\)\)\)\(\ \
\)\)\)]],
  ","
}], "NE3",
  CellTags->"(6.3.15)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(k\_n\)(x)\  = \ \[Omega]\_n/\(c(x)\)\)]],
  " is the local wavenumber for the waves, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_n = \@\(-\[Lambda]\_n\)\)]],
  " is the eigenfequency, and ",
  Cell[BoxData[
      \(TraditionalForm\`c(x) = \@\(\(T(x)\)/\(\[Rho](x)\)\)\)]],
  "is the local wave speed [see Eq. ",
  ButtonBox["(5.2.62)",
    ButtonData:>{"Chapter5.nb", "(5.2.62)"},
    ButtonStyle->"Hyperlink"],
  "]. Eigenmodes can be formed from this general solution simply by matching \
the boundary conditions.  The condition ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](0) = 0\)]],
  " implies that ",
  Cell[BoxData[
      \(TraditionalForm\`C\_2 = \(-C\_1\)\)]],
  ", so that "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\[Psi]\_n\)(
        x)\  = \ \(\(2  \[ImaginaryI]\ C\_1\)\/\([\(T(x)\) \(\[Rho](x)\)]\)\^\
\(1/4\)\) 
        sin \(\[Integral]\_0\%x\(\( k\_n\)(
              x)\) \[DifferentialD]x\)\)]]], "NE3",
  CellTags->"(6.3.16)"],

Cell[TextData[{
  "In order to match the boundary condition ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](L) = 0\)]],
  ", we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%L\(\( k\_n\)(
              x)\) \[DifferentialD]x = n\ \[Pi]\)]],
  ",    ",
  Cell[BoxData[
      \(TraditionalForm\`n\  = 1, 2, 3,  ... \)]],
  "."
}], "NE3",
  CellTags->"(6.3.17)"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(6.3.17)",
    ButtonData:>"(6.3.17)",
    ButtonStyle->"Hyperlink"],
  " provides us with the eigenfrequencies ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_n\)]],
  " for the problem:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_n = n\ \[Pi]/\(\[Tau](L)\)\)]],
  ", "
}], "NE3",
  CellTags->"(6.3.18)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau](
          L) = \[Integral]\_0\%L\[DifferentialD]x\/\(c(x)\)\)]],
  " is the propagation time for waves to travel from ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(=\)\(0\)\(\ \)\)\)]],
  "to  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(=\)\(L\)\(\ \)\)\)]],
  ". In the WKB approximation, the eigenfrequencies are evenly spaced with a \
fundamental frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_1 = \[Pi]/\(\[Tau](L)\)\)]],
  ". Therefore the  resulting motion of the string is periodic in time, with \
this fundamental frequency. The eigenmodes of the string are "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_n\)(
          x)\  = \ \(1\/\([\(T(x)\) \(\[Rho](x)\)]\)\^\(1/4\)\) 
          sin\ \((n\ \[Pi] \( \[Tau](x)\)\/\(\[Tau](L)\))\)\)]],
  "."
}], "NE3",
  CellTags->"(6.3.19)"],

Cell[TextData[{
  "How well does the WKB approximation to the eigenmodes work?  The answer \
depends on how rapidly varying ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`T(x)\)]],
  " are compared to ",
  Cell[BoxData[
      \(TraditionalForm\`\(k\_n\)(x)\)]],
  ".   For high-order modes, where ",
  Cell[BoxData[
      \(TraditionalForm\`k\_n\)]],
  " is large, the WKB approximation should be very accurate. For low-order \
modes, where ",
  Cell[BoxData[
      \(TraditionalForm\`1/k\_n\)]],
  " is of order ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ", the method may not be very accurate.  "
}], "Text"],

Cell[TextData[{
  "\tLet's compare the WKB solution of the wave equation with a solution \
obtained using the Galerkin method. We will solve the wave equation, Eq. ",
  ButtonBox["(6.3.13)",
    ButtonData:>"(6.3.13)",
    ButtonStyle->"Hyperlink"],
  ", choosing  ",
  Cell[BoxData[
      \(TraditionalForm\`T(x) = constant\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x) = 1/\((1 + x)\)\^2\)]],
  " so that ",
  Cell[BoxData[
      \(TraditionalForm\`c(x) = \(\@\(T/\[Rho]\)\  = \ 1 + x\)\)]],
  ". We take ",
  Cell[BoxData[
      \(TraditionalForm\`L = 2\)]],
  ". With this choice for ",
  Cell[BoxData[
      \(TraditionalForm\`c(x)\)]],
  ", we have ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau](x)\  = \ ln(1 + x)\)]],
  ", and according to Eq. ",
  ButtonBox["(6.3.18)",
    ButtonData:>"(6.3.18)",
    ButtonStyle->"Hyperlink"],
  " the WKB  eigenfrequencies are ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_n = n\ \[Pi]/ln\ 3\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2, 3,  ... \)]],
  " ."
}], "Text"],

Cell[TextData[{
  "\tWe take initial conditions that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(y(0, x) = \(\(y\_o\)(x) = 
          sin\ \[Pi]\ x\)\)\(,\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]y\/\[PartialD]t\) \((x, 0)\) = 0\)]],
  ". Then the coefficients in the general solution, Eq. ",
  ButtonBox["(6.3.14)",
    ButtonData:>"(6.3.14)",
    ButtonStyle->"Hyperlink"],
  ", are ",
  Cell[BoxData[
      \(TraditionalForm\`B\_n = 0\)]],
  " and"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`A\_n = \ \(\((\[Psi]\_n, \ y\_o)\)\/\((\[Psi]\_n, \
\[Psi]\_n)\) = \(\[Integral]\_0\%L\( \[Rho](x)\)\ \(\(\[Psi]\_n\)(x)\)\ sin\ \
\[Pi]\ x \[DifferentialD]x\)\/\(\[Integral]\_0\%L\( \[Rho](x)\)\ \
\(\(\[Psi]\_n\%2\)(x)\)\ \[DifferentialD]x\)\)\)]],
  "."
}], "NE3",
  CellTags->"(6.3.20)"],

Cell[TextData[{
  "We will perform the required integrals numerically.  We construct the WKB \
solution for ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, t)\)]],
  " below:"
}], "Text"],

Cell[BoxData[{
    \(\(Clear["\<Global`*\>"];\)\), "\n", 
    \(\(\(L = 2;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Tau][x_]\  = Log[1 + x];\)\), "\n", 
    \(\(\[Rho][x_]\  = \ 1/\((1 + x)\)^2;\)\), "\n", 
    \(\(T[x_]\  = \ 1;\)\), "\n", 
    \(\(\(\[Psi]WKB[n_, x_]\  = \ 
        Sin[n\ Pi\ \[Tau][x]/\[Tau][L]]/\[Rho][x]^\((1/4)\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Omega]WKB[n_]\  = \ n\ Pi/\[Tau][L];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(y0[x_]\  = \ Sin[\ Pi\ x];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(A[n_]\  := \ \(A[n]\  = \ 
          NIntegrate[\[Rho][x]\ \[Psi]WKB[n, x]\ y0[x], {x, 0, L}]/
            NIntegrate[\[Rho][x]\ \[Psi]WKB[n, x]^2, {x, 0, L}]\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(y[x_, t_]\  = \ 
        Sum[A[n]\ Cos[\[Omega]WKB[n]\ t]\ \[Psi]WKB[n, x], {n, 1, 
            10}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.170"],

Cell[TextData[{
  "The solution found using WKB eigenmodes is a rather complex periodically \
repeating oscillation with fundamental period ",
  Cell[BoxData[
      \(TraditionalForm\`2\ \[Pi]/\[Omega]\_1\)]],
  ". In Fig. ",
  ButtonBox["6.12",
    ButtonData:>"Fig. 6.12",
    ButtonStyle->"Hyperlink"],
  " we plot the WKB solution (solid) superimposed on the solution found via \
the Galerkin method (dashed), over two periods of the WKB solution."
}], "Text"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -40.625 0 ]
[.5 .63053 40.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -101.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
140.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36897 L
.10458 .42975 L
.14415 .47855 L
.18221 .51463 L
.20178 .52826 L
.21267 .53427 L
.22272 .53879 L
.23293 .54236 L
.23832 .54382 L
.24402 .54504 L
.24641 .54546 L
.24897 .54584 L
.25119 .54611 L
.25361 .54635 L
.25507 .54647 L
.25643 .54655 L
.25773 .54662 L
.2584 .54665 L
.25912 .54667 L
.25983 .54669 L
.26048 .5467 L
.26176 .54672 L
.26293 .54671 L
.26416 .54669 L
.26538 .54666 L
.26607 .54663 L
.26671 .5466 L
.26912 .54646 L
.27131 .54627 L
.27364 .54602 L
.27847 .54532 L
.2838 .54427 L
.29326 .54169 L
.30213 .53843 L
.32232 .52812 L
.34082 .51523 L
.38045 .47762 L
.41855 .43067 L
.45912 .3724 L
.49816 .31194 L
.53966 .24751 L
.57964 .18973 L
.61811 .14196 L
.63759 .1217 L
.65902 .10299 L
.67938 .089 L
.69843 .07949 L
.70884 .0758 L
.71396 .07438 L
Mistroke
.71872 .0733 L
.72301 .07253 L
.72758 .07192 L
.7302 .07166 L
.73148 .07156 L
.73266 .07149 L
.73371 .07143 L
.73487 .07138 L
.73603 .07135 L
.73725 .07132 L
.73856 .07132 L
.73977 .07133 L
.7404 .07134 L
.7411 .07136 L
.74183 .07138 L
.74251 .07141 L
.7449 .07154 L
.74625 .07164 L
.74748 .07175 L
.75203 .07228 L
.7568 .07308 L
.76198 .0742 L
.7668 .07549 L
.77773 .0793 L
.78828 .08411 L
.79823 .08965 L
.81683 .10255 L
.85534 .13894 L
.89632 .1896 L
.93577 .24654 L
.97371 .30514 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36895 L
.10458 .42977 L
.14415 .47853 L
.18221 .51461 L
.20178 .52826 L
.21267 .53429 L
.22272 .53882 L
.23293 .54239 L
.23832 .54385 L
.24402 .54507 L
.24641 .54548 L
.24897 .54586 L
.25119 .54613 L
.25361 .54637 L
.25507 .54648 L
.25643 .54657 L
.25773 .54663 L
.2584 .54666 L
.25912 .54668 L
.25983 .5467 L
.26048 .54671 L
.26176 .54672 L
.26293 .54672 L
.26416 .5467 L
.26538 .54666 L
.26607 .54663 L
.26671 .5466 L
.26912 .54645 L
.27131 .54627 L
.27364 .54601 L
.27847 .54531 L
.2838 .54425 L
.29326 .54166 L
.30213 .5384 L
.32232 .52809 L
.34082 .51523 L
.38045 .47766 L
.41855 .43068 L
.45912 .37236 L
.49816 .3119 L
.53966 .24753 L
.57964 .18979 L
.61811 .14198 L
.63759 .12168 L
.65902 .10293 L
.67938 .08892 L
.69843 .0794 L
.70884 .07573 L
.71396 .07432 L
Mistroke
.71872 .07325 L
.72301 .07249 L
.72758 .07188 L
.7302 .07163 L
.73148 .07154 L
.73266 .07146 L
.73371 .07141 L
.73487 .07137 L
.73603 .07133 L
.73725 .07131 L
.73856 .07131 L
.73977 .07133 L
.7404 .07134 L
.7411 .07136 L
.74251 .07141 L
.74375 .07148 L
.74508 .07156 L
.74748 .07177 L
.74985 .07203 L
.75235 .07236 L
.7568 .07312 L
.76198 .07426 L
.7668 .07556 L
.77773 .07939 L
.78828 .08422 L
.79823 .08977 L
.81683 .10266 L
.85534 .13895 L
.89632 .18947 L
.93577 .24638 L
.97371 .30513 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000=Wooooo2Ooo001Rooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=Cooooo00?o0000ool00?oo0000
0_oo0009ooooo`?oo`000_l0001Mooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0=;ooooo0_l0000Cooooo`;o0000Foooool001[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3?ooooo`?o00005oooool3o`0005Sooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0cOooool2o`0001gooooo0_l0001Fooooo`006?ooool00omEEEGo
IVIVo`000006ooooo`03o`000?oooooooooo0<_ooooo00?oo`00o`000?ooool08?ooool00ooo003o
ooooooooo`1Cooooo`008Oooool00ol0003oooooooooo`39ooooo`;oo`009?ooool2ool005?ooooo
000Qooooo`03o`000?oooooooooo0<Sooooo00?oo`00ooooooooool09_ooool00ooo003ooooooooo
o`1@ooooo`008Oooool3o`000<Kooooo0_oo000Zooooo`;oo`00D?ooool0027ooooo00?o0000oooo
ooooool0aOooool00ooo003oooooooooo`0/ooooo`03ool00?oooooooooo04gooooo000Qooooo`03
o`000?oooooooooo0<?ooooo0_oo000`ooooo`03ool00?l0003ooooo04cooooo000Qooooo`03o`00
0?oooooooooo0<;ooooo00?oo`00ooooooooool0<Oooool00ooo003o0000ooooo`1;ooooo`008Ooo
ool00ol0003oooooooooo`31ooooo`03ool00?oooooooooo03?ooooo00?oo`00o`000?ooool0B_oo
ool0027ooooo00?o0000ooooooooool0`?ooool00ooo003oooooooooo`0eooooo`03ool00?l0003o
oooo04Wooooo000Qooooo`03o`000?oooooooooo0;oooooo00?oo`00ooooooooool0=oooool00ooo
003o0000ooooo`18ooooo`008Oooool3o`000;kooooo00?oo`00ooooooooool0>Oooool00ooo003o
0000ooooo`17ooooo`008Oooool00ol0003oooooooooo`2mooooo`03o`000?oooooooooo03cooooo
00?o0000ooooooooool0AOooool0027ooooo00?o0000ooooooooool0_?ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo04Cooooo000Qooooo`03o`000?oooooooooo0;_ooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`13ooooo`008Oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0@_ooool0027ooooo00?o0000oooooooo
ool0^Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo047ooooo000Qooooo`03o`00
0?oooooooooo0;Sooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`10ooooo`008Ooo
ool3o`000;Oooooo00?oo`00ooooooooool0Aoooool00ol0003oooooooooo`10ooooo`008Oooool0
0ol0003oooooooooo`2gooooo`03ool00?oooooooooo04Sooooo00?oo`00ooooooooool0?oooool0
027ooooo00?o0000ooooooooool0]_ooool00ooo003oooooooooo`19ooooo`03ool00?l0003ooooo
03oooooo000Qooooo`03o`000?oooooooooo0;Gooooo00?oo`00ooooooooool0Boooool00ooo003o
0000ooooo`0nooooo`008Oooool00ol0003oooooooooo`2dooooo`03ool00?oooooooooo04gooooo
00?oo`00o`000?ooool0?Oooool0027ooooo00?o0000ooooooooool0/oooool00ol0003oo`00oooo
o`1?ooooo`03ool00?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo0;?ooooo00?oo`00
ooooooooool0D?ooool00ooo003oooooooooo`0kooooo`008Oooool00ol0003oooooooooo`2boooo
o`03ool00?oooooooooo05;ooooo00?oo`00ooooooooool0>_ooool0027ooooo0ol0002aooooo`03
ool00?oooooooooo05?ooooo00?oo`00o`000?ooool0>_ooool0027ooooo00?o0000ooooooooool0
/?ooool00ooo003oooooooooo`1Eooooo`03ool00?l0003ooooo03Wooooo000Qooooo`03o`000?oo
oooooooo0:oooooo00?o0000ool00?ooool0Eoooool00ooo003o0000ooooo`0hooooo`008Oooool0
0ol0003oooooooooo`2_ooooo`03ool00?oooooooooo05Sooooo00?oo`00ooooooooool0=oooool0
027ooooo00?o0000ooooooooool0[_ooool00ooo003oooooooooo`1Jooooo`03ool00?oooooooooo
03Kooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0:gooooo00?oo`00ooooooooool0G?ooool0
0ooo003oooooooooo`0eooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`1N
ooooo`03o`000?oooooooooo03Cooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00;ooooo0ol0002[ooooo`03o`000?oooooooooo063ooooo00?o0000
ooooooooool0<oooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00?ooooo00?o0000ooooooooool0Zoooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo03?ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo03;ooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool0I?ooool00ol0003ooooooooo
o`0aooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0<Ooo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003ooooooooo
o`2Xooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0<?ooool0027ooooo00?o0000
ooooooooool0Yoooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo02oooooo000Qoooo
o`03o`000?oooooooooo0:Kooooo00?o0000ool00?ooool0JOooool00ooo003oooooooooo`0_oooo
o`008Oooool3o`000:Kooooo00?o0000ool00?ooool0JOooool00ooo003o0000ooooo`0_ooooo`00
8Oooool00ol0003oooooooooo`2Uooooo`03o`000?oo003ooooo06_ooooo00?oo`00o`000?ooool0
;_ooool0027ooooo00?o0000ooooooooool0Y?ooool00ol0003oo`00ooooo`1]ooooo`03ool00?oo
oooooooo02gooooo000Qooooo`03o`000?oooooooooo0:?ooooo00?o0000ool00?ooool0Koooool0
0ooo003oooooooooo`0/ooooo`008Oooool00ol0003oooooooooo`2Sooooo`03ool00?oooooooooo
06oooooo00?oo`00o`000?ooool0;?ooool0027ooooo00?o0000ooooooooool0X_ooool00ooo003o
ooooooooo`1aooooo`03ool00?oooooooooo02_ooooo000Qooooo`03o`000?oooooooooo0:7ooooo
00?o0000ool00?ooool0Loooool00ooo003oooooooooo`0Zooooo`008Oooool3o`000:7ooooo00?o
o`00ooooooooool0Loooool00ooo003o0000ooooo`0Zooooo`008Oooool00ol0003oooooooooo`2P
ooooo`03ool00?oooooooooo07Gooooo00?oo`00ooooooooool0:Oooool0027ooooo00?o0000oooo
ooooool0Woooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo02Sooooo000Qooooo`03
o`000?oooooooooo09kooooo00?oo`00ooooooooool0NOooool00ooo003oooooooooo`0Wooooo`00
8Oooool00ol0003oooooooooo`2Nooooo`03ool00?oooooooooo07Wooooo00?oo`00ooooooooool0
9oooool0027ooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`1kooooo`03ool00?oo
oooooooo02Kooooo000Qooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool0OOooool0
0ol0003oooooooooo`0Uooooo`008Oooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
07gooooo00?o0000ooooooooool09Oooool0027ooooo0ol0002Kooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool09?ooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`00
0003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0=?ooool4o`000003oa0@4?oooooooooo
00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0=oooool00ol0003oooooooooo`03
ooooo`Go00006oooool0027ooooo00?o0000ooooooooool0?Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo03Kooooo00?o0000ooooooooool00oooool01OnHV9So8B4Qonk^k_ooooooA4A401_ooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ
8B7ok^k^01cooooo000Qooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo03kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0>?ooool00ol0003ooooooooo
o`03ooooo`03oiRHV?lQ8B7ok^k^01_ooooo000Qooooo`03o`000?oooooooooo03gooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0?oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<03Wooooo00?o0000ooooooooool01?ooool00omgMgOoIVIVooooo`0Jooooo`00
8Oooool00ol0003oooooooooo`0mooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0>Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo03cooooo00?oo`00ooooooooool01?ooool00ol0003o
ooooooooo`0Iooooo`008Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool00_ooool00ol0003oo`00ooooo`0jooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0??ooool02?oo003o0000ooooool0003o^[Zj
oooooonHV9So410@6oooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000nooooo`03oeEEEOmVIVKo000000?ooooo00?o0000ool00?ooool0>Ooo
ool00omEEEGoIVIVo`00000=ooooo`Co0000??ooool01ooo003ooooooiRHV?l@413o0000ob4Q8Oo<
c<`06oooool0027ooooo00?o0000ooooooooool0U_ooool00ooo003oooooooooo`2:ooooo`03ool0
0?oooooooooo01kooooo000Qooooo`03o`000?oooooooooo09Gooooo00?o0000ool00?ooool0S?oo
ool00ooo003oooooooooo`0Mooooo`008Oooool00ol0003oooooooooo`2Eooooo`03ool00?oooooo
oooo08cooooo00?oo`00ooooooooool07Oooool0027ooooo00?o0000ooooooooool0U?ooool00ooo
003oooooooooo`2>ooooo`03ool00?oooooooooo01;ooooo0_l00002ooooo`;o00001?ooool0027o
oooo00?o0000ooooooooool0Toooool00ol0003oo`00ooooo`2@ooooo`03ool00?oooooooooo017o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0003o0000
09?o000000?oo`00o`000?l00000TOl000000ooo003o0000o`000005o`0000cooooo00CogMgMo`00
0?l@413oc<c<1Oooool0027ooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ool0
0?ooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Co8B4QogMg
MomgMgOo<S8b1Oooool0027ooooo00?o0000oooooooo0000TOooool00ooo003oooooooooo`2Voooo
o`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?ooooooo`00093ooooo00?oo`00oooooooo
ool0/Oooool0027ooooo00Co0000ooooooooooooo`00S_ooool00ooo003o0000ooooo`2booooo`00
8Oooool01Ol0003oooooooooool0003oo`0008gooooo00?o0000ooooooooool0/_ooool0027ooooo
00Ko0000ooooooooooooooooo`000?oo002;ooooo`03o`000?oooooooooo0;?ooooo000Qooooo`?o
00000_ooool00ooo003oooooooooo`29ooooo`03o`000?oooooooooo0;?ooooo000Qooooo`03o`00
0?oooooooooo00;ooooo00?o0000ool00?ooool0R?ooool00ol0003oooooooooo`2dooooo`008Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oo003ooooo08Kooooo00?o0000ooooooooool0]Ooo
ool0027ooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`24ooooo`03o`000?oooooo
oooo0;Kooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ool00?ooool0Q?ooool00ol0
003oooooooooo`2fooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo003ooooo08;o
oooo00?o0000ooooooooool0]oooool0027ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`20ooooo`03ool00?oooooooooo0;Sooooo000Qooooo`?o00001_ooool00ol0003ooooooooo
o`20ooooo`03ool00?oooooooooo0;Sooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0O_ooool00ooo003oooooooooo`2iooooo`008Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo07gooooo00?oo`00ooooooooool0^_ooool0027ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`1looooo`03ool00?oooooooooo0;[ooooo000Qooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0N_ooool00ooo003oooooooooo`2kooooo`008Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo07Wooooo00?oo`00ooooooooool0_?oo
ool0027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1hooooo`03ool00?oooooo
oooo0;cooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0M_ooool00ooo
003oooooooooo`2mooooo`008Oooool3o`0000cooooo00?oo`00ooooooooool0M?ooool00ol0003o
o`00ooooo`2nooooo`008Oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo07Cooooo
00?oo`00ooooooooool0__ooool0027ooooo00?o0000ooooooooool03Oooool00ooo003ooooooooo
o`1booooo`03ool00?oooooooooo0;oooooo000Qooooo`03o`000?oooooooooo00kooooo00?oo`00
ooooooooool0L?ooool00ol0003oo`00ooooo`30ooooo`008Oooool00ol0003oooooooooo`0?oooo
o`03ool00?oooooooooo06oooooo00?oo`00ooooooooool0`?ooool0027ooooo00?o0000oooooooo
ool03oooool00ooo003oooooooooo`1^ooooo`03o`000?oooooooooo0<7ooooo000Qooooo`03o`00
0?oooooooooo013ooooo00?oo`00ooooooooool0K?ooool00ol0003oooooooooo`32ooooo`008Ooo
ool3o`00017ooooo00?oo`00ooooooooool0Joooool00ol0003oooooooooo`32ooooo`008Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oo003ooooo06[ooooo00?o0000ooooooooool0`oooool0
027ooooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`1Xooooo`03o`000?oooooooooo
0<Cooooo000Qooooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool0Ioooool00ol0003o
ooooooooo`34ooooo`008Oooool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo06Gooooo
00?o0000ooooooooool0aOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool05?ooool00ol0003o
o`00ooooo`1Tooooo`03o`000?oooooooooo0<Kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo06;ooooo00?oo`00o`000?ooool0aoooool000Oooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0000Fooooo`03o`000?oooooooooo067o
oooo00?oo`00ooooooooool0aoooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Oooooo`03
ool00?oooooooooo0<Sooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Ooooo
o`03ool00?oooooooooo0<Sooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0GOooool00ooo
003oooooooooo`39ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05_ooooo00?oo`00oooo
ooooool0b_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo05Wooooo00?oo`00ooooooooool0boooool0027o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Gooooo`03ool00?oooooooooo0<co
oooo000Qooooo`03o`000?oooooooooo01_ooooo00?oo`00ooooooooool0Eoooool00ooo003ooooo
ooooo`3<ooooo`008Oooool3o`0001_ooooo00?oo`00o`000?ooool0E_ooool00ooo003ooooooooo
o`3=ooooo`008Oooool00ol0003oooooooooo`0Looooo`03ool00?l0003ooooo05Cooooo00?oo`00
ooooooooool0c_ooool0027ooooo00?o0000ooooooooool07Oooool00ooo003o0000ooooo`1Boooo
o`03ool00?oooooooooo0<oooooo000Qooooo`03o`000?oooooooooo01kooooo00?oo`00o`000?oo
ool0D?ooool00ooo003oooooooooo`3@ooooo`008Oooool00ol0003oooooooooo`0Oooooo`03ool0
0?oooooooooo04oooooo00?o0000ooooooooool0d?ooool0027ooooo00?o0000ooooooooool08?oo
ool00ooo003oooooooooo`1=ooooo`03o`000?oooooooooo0=7ooooo000Qooooo`03o`000?oooooo
oooo027ooooo00?oo`00ooooooooool0Boooool00ol0003oooooooooo`3Booooo`008Oooool3o`00
02;ooooo00?oo`00ooooooooool0BOooool00ol0003oooooooooo`3Cooooo`008Oooool00ol0003o
ooooooooo`0Sooooo`03ool00?oooooooooo04Kooooo0_l0003Fooooo`008Oooool00ol0003ooooo
ooooo`0Tooooo`03ool00?oooooooooo04Cooooo00?o0000ooooooooool0e_ooool0027ooooo00?o
0000ooooooooool09Oooool00ooo003oooooooooo`12ooooo`03o`000?oooooooooo0=Oooooo000Q
ooooo`03o`000?oooooooooo02Kooooo00?oo`00ooooooooool0@?ooool00ooo003oooooooooo`3H
ooooo`008Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03kooooo00?oo`00oooo
ooooool0fOooool0027ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0looooo`03
ool00?oooooooooo0=[ooooo000Qooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
>_ooool00ooo003oooooooooo`3Kooooo`008Oooool3o`0002[ooooo00?o0000ooooooooool0>?oo
ool00ooo003oooooooooo`3Looooo`008Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo03Kooooo00?oo`00ooooooooool0gOooool0027ooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0dooooo`03ool00?oooooooooo0=kooooo000Qooooo`03o`000?oooooooooo02go
oooo00?o0000ool00?ooool0<_ooool00ooo003oooooooooo`3Oooooo`008Oooool00ol0003ooooo
ooooo`0^ooooo`03ool00?oooooooooo033ooooo00?oo`00ooooooooool0h?ooool0027ooooo00?o
0000ooooooooool0;oooool2ool002kooooo00?o0000ool00?ooool0h_ooool0027ooooo00?o0000
ooooooooool0<Oooool00ooo003oooooooooo`0Zooooo`03o`000?oo003ooooo0>?ooooo000Qoooo
o`?o0000<_ooool2ool002Wooooo00?o0000ool00?ooool0i?ooool0027ooooo00?o0000oooooooo
ool0=?ooool00ooo003oooooooooo`0Uooooo`03o`000?oooooooooo0>Gooooo000Qooooo`03o`00
0?oooooooooo03Gooooo0_oo000Sooooo`;o0000j?ooool0027ooooo00?o0000ooooooooool0=ooo
ool00ooo003oooooooooo`0Mooooo`?o0000j_ooool0027ooooo00?o0000ooooooooool0>?ooool3
ool001[ooooo0_l0003]ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000oooo
ooooool0>oooool01?oo003o0000o`000?l0000Dooooo`;oo`00koooool001[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo0_oo003aoooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo043ooooo1ol00003ooooo`Oo
o`00loooool001[ooooo00?o0000ooooooooool01?ooool3o`0004Gooooo1Ooo003jooooo`006_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002_ooooo`03ogMgMomVIVKooooo
01Oooooo00?oIVIVogMgMoooool0W?ooool008kooooo0ol0000Dooooo`03ob4Q8OoMgMgooooo00Ko
oooo00?ogMgMoa0@4?o^k^h06?ooool00oo^k^ko410@omgMg@2Looooo`00Q_ooool01on7QhOo0000
oeEEEOmVIVKo0000oc8b<_o^k^h00_ooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o0000
odA4A?nj^[X00oooool00onHV9SoEEEEooooo`06ooooo`03oeEEEOnHV9Sooooo00;ooooo1Ol00009
ooooo`03oeEEEOnYZJWooooo00;ooooo00Ko^[ZjodA4A?ooooooooooohN7QomVIVHDooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0Poooool008Kooooo00Oo410@omgMgOmgMgOo8B4Qoooooon7QhOoIVIV
00;ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000
omgMgOooool01Oooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@02_oo
ool01_mEEEGoV9RHoooooooooooo410@okZj^P;ooooo00?ok^k^o`000?ooool02oooool6o`0000;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`23ooooo`00Q_ooool01ol0003oooooomgMgOlb<S;ooooo
onk^k_l@41000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo0_mgMgL6
ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool0
0004ooooo`03o`000?oooooooooo01;ooooo00Go410@oooooooooooooooooa0@4023ooooo`00Q_oo
ool01?mEEEGoZJVYooooool00002ooooo`04o`000?ooooooooooo`0000gooooo00?o0000oooooooo
ool01_ooool00oo^k^ko410@onk^kP05ooooo`03oc8b<_oooooooooo00Cooooo00?oV9RHob4Q8Oo^
k^h02oooool01?n7QhOoIVIVooooool00004ooooo`03o`000?oooooooooo00[ooooo1_l00002oooo
o`05o`000?ooooooooooooooool00000Poooool008Kooooo00?ogMgMob4Q8Oo^k^h00oooool01?l0
003oooooo`000?l0000=ooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool0
0ol0003ok^k^ooooo`05ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo00000ooo
ool00oo^k^ko0000ooooo`0Cooooo`05o`000?ooooooooooooooool00000Poooool008Oooooo00?o
V9RHogMgMoooool00_ooool00ol0003oooooooooo`0<ooooo`03oa0@4?l0003o000000?o00001_oo
ool00ooMgMgo410@ooooo`04ooooo`03oeEEEOmgMgOooooo00Kooooo00?o0000ooooooooool02?oo
ool7o`000003oooooomgMgOoEEEE01Cooooo00Go410@oooooooooooooooooa0@4023ooooo`00WOoo
ool00ol0003oooooooooo`08ooooo`03oeEEEOnHV9Sooooo00?ooooo00?ogMgMoa0@4?o^k^h00_oo
ool01Ol0003o^[ZjoooooonHV9So410@017ooooo00?ok^k^oa0@4?oMgMd05?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg08?ooooo002Mooooo`03o`000?oooooooooo00Sooooo00?o^[ZjodA4A?ooool0
1?ooool02OmgMgOoIVIVooooooooooooV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`03ofIVI_mgMgOo
oooo01Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP23ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36468 L
.10458 .42001 L
.14415 .46289 L
.16408 .48026 L
.18221 .49329 L
.20178 .50419 L
.21254 .50873 L
.22272 .51204 L
.23241 .51431 L
.2373 .51513 L
.24012 .5155 L
.24269 .51577 L
.24504 .51596 L
.24728 .5161 L
.2485 .51616 L
.24964 .5162 L
.25088 .51623 L
.25158 .51624 L
.25221 .51624 L
.25336 .51624 L
.25442 .51623 L
.25558 .51621 L
.2568 .51617 L
.25787 .51613 L
.25887 .51608 L
.26113 .51593 L
.26373 .5157 L
.26614 .51543 L
.27158 .51464 L
.27638 .51372 L
.28148 .51252 L
.2903 .50991 L
.30004 .50626 L
.31939 .49668 L
.34024 .48313 L
.38138 .44783 L
.42101 .4055 L
.45912 .36022 L
.49968 .31074 L
.53872 .26525 L
.58022 .22251 L
.60102 .20419 L
.6202 .18951 L
.64007 .17674 L
.65867 .16721 L
.67743 .16007 L
.68738 .15731 L
.69293 .15608 L
.69807 .15514 L
Mistroke
.70298 .15441 L
.7082 .15384 L
.71119 .1536 L
.71265 .1535 L
.714 .15343 L
.7152 .15337 L
.71652 .15332 L
.71785 .15329 L
.71857 .15327 L
.71924 .15326 L
.7205 .15325 L
.7212 .15325 L
.72186 .15325 L
.72305 .15326 L
.72433 .15328 L
.72546 .15331 L
.72653 .15335 L
.72895 .15346 L
.73157 .15363 L
.73396 .15382 L
.73935 .15439 L
.7441 .15506 L
.74918 .15594 L
.75831 .15795 L
.77902 .16441 L
.80041 .17365 L
.82057 .18449 L
.85909 .20996 L
.90006 .24213 L
.93952 .27616 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36461 L
.10458 .41979 L
.14415 .46266 L
.16408 .48001 L
.18221 .49301 L
.20178 .50387 L
.21254 .50838 L
.22272 .51169 L
.23241 .51395 L
.2373 .51476 L
.24012 .51513 L
.24269 .5154 L
.24504 .5156 L
.24728 .51574 L
.2485 .51579 L
.24964 .51583 L
.25088 .51586 L
.25158 .51587 L
.25221 .51588 L
.25336 .51588 L
.25442 .51587 L
.25558 .51585 L
.2568 .51582 L
.25787 .51577 L
.25887 .51572 L
.26113 .51558 L
.26373 .51535 L
.26614 .51509 L
.27158 .5143 L
.27638 .51339 L
.28148 .5122 L
.2903 .5096 L
.30004 .50595 L
.31939 .49639 L
.34024 .48284 L
.38138 .44755 L
.42101 .40533 L
.45912 .36018 L
.49968 .31078 L
.53872 .2653 L
.58022 .2226 L
.60102 .20434 L
.6202 .18972 L
.64007 .17703 L
.65867 .16756 L
.67743 .16045 L
.68738 .1577 L
.69293 .15647 L
.69807 .15553 L
Mistroke
.70298 .15481 L
.7082 .15423 L
.71119 .15398 L
.71265 .15388 L
.714 .15381 L
.7152 .15375 L
.71652 .1537 L
.71785 .15366 L
.71857 .15364 L
.71924 .15363 L
.7205 .15361 L
.7212 .15361 L
.72186 .15361 L
.72305 .15362 L
.72433 .15364 L
.72546 .15367 L
.72653 .1537 L
.72895 .15381 L
.73157 .15396 L
.73396 .15415 L
.73935 .15471 L
.7441 .15537 L
.74918 .15623 L
.75831 .15821 L
.76917 .16124 L
.77902 .16461 L
.81906 .18378 L
.85758 .20909 L
.89855 .24115 L
.938 .27497 L
.97594 .30879 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0coooool2ool000So0000
1ooo001Tooooo`008Oooool00ol0003oooooooooo`3;ooooo`Coo`004Oooool6ool005kooooo000Q
ooooo`03o`000?oooooooooo0<Sooooo0ooo000Kooooo`;oo`0000?o0000ooooooooool0FOooool0
027ooooo00?o0000ooooooooool0aOooool2o`000003ool00?oooooooooo01kooooo00?oo`00o`00
0?l00000FOooool0027ooooo0ol00033ooooo`;o00009_ooool3o`0005Kooooo000Qooooo`03o`00
0?oooooooooo0<7ooooo0_l0000[ooooo`;o0000E?ooool0027ooooo00?o0000ooooooooool0_ooo
ool2o`0002oooooo0_l0001Booooo`008Oooool00ol0003oooooooooo`2mooooo`;oo`00<oooool2
ool0053ooooo000Qooooo`03o`000?oooooooooo0;cooooo00?oo`00ooooooooool0=Oooool2ool0
04kooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0;[ooooo0_oo000jooooo`;oo`00C?ooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo0;Wooooo00?oo`00ooooooooool0??ooool00ooo003oooooooooo`19
ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02
ooooo`?o0000]oooool2ool0043ooooo00?oo`00o`000?ooool0B?ooool000Oooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0]_ooool0
0ooo003oooooooooo`11ooooo`;oo`00B?ooool000Oooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`2eooooo`03ool00?oo
oooooooo04Cooooo00?oo`00o`000?ooool0AOooool000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0]?ooool00ooo003ooooooooo
o`16ooooo`03ool00?l0003ooooo04Cooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;?ooooo00?oo`00ooooooooool0B?oo
ool00ooo003o0000o`000013ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
0005ooooo`03o`000?oooooooooo0;7ooooo0_oo001<ooooo`03ool00?oooooo000004;ooooo000Q
ooooo`03o`000?oooooooooo0;3ooooo00?o0000ooooooooool0Coooool2o`00043ooooo000Qoooo
o`03o`000?oooooooooo0:kooooo0_l0001Dooooo`03o`000?oooooooooo03gooooo000Qooooo`?o
0000[Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo03cooooo000Qooooo`03o`00
0?oooooooooo0:cooooo00?o0000ooooooooool0Eoooool2o`0003cooooo000Qooooo`03o`000?oo
oooooooo0:_ooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0iooooo`008Oooool0
0ol0003oooooooooo`2[ooooo`03o`000?oooooooooo05[ooooo0_oo000jooooo`008Oooool00ol0
003oooooooooo`2Zooooo`03o`000?oooooooooo05gooooo00?oo`00ooooooooool0=oooool0027o
oooo00?o0000ooooooooool0ZOooool00ooo003oooooooooo`1Oooooo`;oo`00=oooool0027ooooo
00?o0000ooooooooool0Z?ooool00ooo003oooooooooo`1Rooooo`03ool00?oooooooooo03Cooooo
000Qooooo`?o0000Yoooool00ooo003oooooooooo`1Tooooo`03ool00?oooooooooo03?ooooo000Q
ooooo`03o`000?oooooooooo0:Kooooo00?oo`00ooooooooool0I_ooool00ooo003o0000ooooo`0b
ooooo`008Oooool00ol0003oooooooooo`2Uooooo`03ool00?oooooooooo06Sooooo00?oo`00o`00
0?ooool0<Oooool0027ooooo00?o0000ooooooooool0Y?ooool00ooo003oooooooooo`1Zooooo`03
ool00?l0003ooooo033ooooo000Qooooo`03o`000?oooooooooo0:?ooooo00?oo`00ooooooooool0
K?ooool00ooo003o0000ooooo`0_ooooo`008Oooool00ol0003oooooooooo`2Rooooo`03ool00?oo
oooooooo06kooooo00?oo`00o`000?ooool0;_ooool0027ooooo00?o0000ooooooooool0XOooool0
0ooo003oooooooooo`1`ooooo`03ool00?l0003ooooo02gooooo000Qooooo`03o`000?oooooooooo
0:3ooooo00?oo`00ooooooooool0Loooool00ol0003oooooooooo`0[ooooo`008Oooool3o`0009oo
oooo00?oo`00ooooooooool0MOooool00ol0003oooooooooo`0Zooooo`008Oooool00ol0003ooooo
ooooo`0mooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@0mooooo`Co000000?o410@ooooooooool01oooool00ooo003oooooooooo`0aoooo
o`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0a
ooooo`03o`000?oooooooooo00Wooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0moooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01?ooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool0<Oooool00ol0003oooooooooo`08ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@06oooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00Sooooo00?oV9RHob4Q8Oo^k^h07?ooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03_ooool00omgMgOo<S8boooo
o`0cooooo`;o00002Oooool00onHV9So8B4Qonk^kP0Kooooo`008Oooool00ol0003oooooooooo`0m
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<03oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00_ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00eooooo`;oo`002Oooool00omgMgOoIVIVooooo`0Jooooo`00
8Oooool00ol0003oooooooooo`0mooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo03Wooooo00?oo`00ooooooooool01oooool00ol0003o
ooooooooo`0Iooooo`008Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0>_ooool00ooo003oooooooooo`02ooooo`05
o`000?nj^[[ooooooiRHV?l@41006oooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo1?l0000nooooo`03oeEEEOmVIVKo000000Gooooo00?o0000oooo
ooooool0=oooool00omEEEGoIVIVo`00000=ooooo`Co0000>_ooool02Ooo003ooooooooooooooooo
V9RHoa0@4?l0003o8B4Qolc<c00Kooooo`008Oooool00ol0003oooooooooo`2Gooooo`03ool00?l0
003ooooo08Oooooo0_oo000Qooooo`008Oooool00ol0003oooooooooo`2Gooooo`03ool00?oooooo
oooo08Wooooo00?oo`00ooooooooool07_ooool0027ooooo00?o0000ooooooooool0U_ooool00ooo
003oooooooooo`2;ooooo`03ool00?oooooooooo01gooooo000Qooooo`03o`000?oooooooooo09Go
oooo00?oo`00ooooooooool0SOooool00ooo003oooooooooo`0Booooo`;o00000_ooool2o`0000Co
oooo000Qooooo`03o`000?oooooooooo09Cooooo00?oo`00ooooooooool0Soooool00ooo003ooooo
ooooo`0Aooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool001[oooooWOl000000ooo003o
0000o`00002Ao`000003ool00?l0003o000000Go00003?ooool01?oMgMgo0000oa0@4?o<c<`5oooo
o`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool04Oooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool2o`0000gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?oo`00oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Aooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03
o`000?oooooo0000097ooooo00?oo`00ooooooooool0Y_ooool2o`0000;ooooo0_l00004ooooo`00
8Oooool00ol0003oooooo`00002@ooooo`03ool00?oooooooooo0;7ooooo000Qooooo`04o`000?oo
ooooooooo`0008kooooo00?oo`00ooooooooool0/_ooool0027ooooo00Go0000oooooooooooooooo
o`00002<ooooo`03ool00?oooooooooo0;?ooooo000Qooooo`05o`000?ooooooooooooooool00000
Roooool00ooo003oooooooooo`2dooooo`008Oooool3o`0000;ooooo00?oo`00ooooooooool0Qooo
ool00ol0003oooooooooo`2eooooo`008Oooool00ol0003oooooooooo`02ooooo`03ool00?l0003o
oooo08Kooooo00?o0000ooooooooool0]_ooool0027ooooo00?o0000ooooooooool00oooool00ooo
003oooooooooo`25ooooo`03o`000?oooooooooo0;Kooooo000Qooooo`03o`000?oooooooooo00Co
oooo00?oo`00ooooooooool0Poooool00ol0003oooooooooo`2gooooo`008Oooool00ol0003ooooo
ooooo`04ooooo`03ool00?l0003ooooo08;ooooo00?o0000ooooooooool0^?ooool0027ooooo00?o
0000ooooooooool01Oooool00ooo003oooooooooo`20ooooo`03o`000?oooooooooo0;Wooooo000Q
ooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool0O_ooool00ol0003oooooooooo`2j
ooooo`008Oooool3o`0000Oooooo00?oo`00ooooooooool0O?ooool00ol0003oooooooooo`2koooo
o`008Oooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo07_ooooo0_oo002mooooo`00
8Oooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo07[ooooo00?oo`00ooooooooool0
_?ooool0027ooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`1hooooo`03ool00?oo
oooooooo0;gooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ool00?ooool0Moooool0
0ooo003oooooooooo`2nooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo003ooooo
07Gooooo00?oo`00ooooooooool0_oooool0027ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`1cooooo`03o`000?oo003ooooo0<3ooooo000Qooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0LOooool00ol0003oo`00ooooo`31ooooo`008Oooool3o`0000gooooo00?o
0000ooooooooool0Koooool00ol0003oo`00ooooo`32ooooo`008Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo06kooooo00?oo`00ooooooooool0`_ooool0027ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`1]ooooo`03o`000?oo003ooooo0<?ooooo000Qooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0Joooool00ol0003oo`00ooooo`34ooooo`00
8Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06Wooooo00?o0000ool00?ooool0
aOooool0027ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Wooooo`03o`000?oo
003ooooo0<Kooooo000Qooooo`03o`000?oooooooooo01;ooooo00?oo`00ooooooooool0IOooool0
0ol0003oooooooooo`37ooooo`008Oooool3o`0001;ooooo00?oo`00ooooooooool0I?ooool00ol0
003oooooooooo`38ooooo`008Oooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo06?o
oooo00?o0000ooooooooool0b?ooool0027ooooo00?o0000ooooooooool05?ooool00ooo003ooooo
ooooo`1Qooooo`03o`000?oooooooooo0<Wooooo000Qooooo`03o`000?oooooooooo01Gooooo00?o
o`00ooooooooool0Goooool00ol0003oooooooooo`3:ooooo`008Oooool00ol0003oooooooooo`0F
ooooo`03ool00?oooooooooo05gooooo00?o0000ooooooooool0boooool000Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o
0000ooooooooool05oooool00ooo003oooooooooo`1Kooooo`03o`000?oooooooooo0<cooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo05[ooooo00?oo`00ooooooooool0cOoo
ool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0
000Hooooo`03ool00?oooooooooo05Sooooo00?o0000ool00?ooool0c_ooool000Oooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool06Ooo
ool00ooo003oooooooooo`1Gooooo`03ool00?oooooooooo0<kooooo0007ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0
6_ooool00ooo003oooooooooo`1Eooooo`03ool00?oooooooooo0<oooooo0007ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01_ooooo
00?oo`00ooooooooool0Doooool00ooo003oooooooooo`3@ooooo`001oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Looooo`03ool0
0?oooooooooo057ooooo00?oo`00ooooooooool0dOooool000Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04oooooo
00?oo`00ooooooooool0d_ooool0027ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`1=ooooo`03ool00?oooooooooo0=?ooooo000Qooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0B_ooool2ool00=Kooooo000Qooooo`?o00008?ooool00ol0003oooooooooo`18oooo
o`03ool00?oooooooooo0=Kooooo000Qooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool0A_ooool00ooo003oooooooooo`3Gooooo`008Oooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo04Cooooo00?oo`00ooooooooool0f?ooool0027ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo0=Wooooo000Qooooo`03o`000?oooooo
oooo02Cooooo00?oo`00ooooooooool0?oooool2o`000=cooooo000Qooooo`03o`000?oooooooooo
02Gooooo00?oo`00ooooooooool0?Oooool00ol0003oooooooooo`3Looooo`008Oooool00ol0003o
ooooooooo`0Vooooo`03ool00?oooooooooo03_ooooo00?o0000ooooooooool0gOooool0027ooooo
0ol0000Wooooo`03ool00?oooooooooo03Wooooo00?o0000ooooooooool0g_ooool0027ooooo00?o
0000ooooooooool0:?ooool00ooo003oooooooooo`0gooooo`03o`000?oooooooooo0=oooooo000Q
ooooo`03o`000?oooooooooo02Wooooo0_oo000fooooo`03ool00?oooooooooo0>3ooooo000Qoooo
o`03o`000?oooooooooo02_ooooo00?oo`00ooooooooool0<Oooool2ool00>?ooooo000Qooooo`03
o`000?oooooooooo02cooooo0_oo000`ooooo`03ool00?oooooooooo0>?ooooo000Qooooo`03o`00
0?oooooooooo02kooooo00?oo`00ooooooooool0:oooool2ool00>Kooooo000Qooooo`03o`000?oo
oooooooo02oooooo0_oo000Zooooo`03ool00?oooooooooo0>Kooooo000Qooooo`03o`000?oooooo
oooo037ooooo0_l0000Vooooo`;oo`00jOooool0027ooooo0ol0000cooooo`;o00008_ooool2ool0
0>_ooooo000Qooooo`03o`000?oooooooooo03Gooooo0_l0000Nooooo`;oo`00kOooool0027ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Iooooo`03o`000?oo003ooooo0>kooooo
000Qooooo`03o`000?oooooooooo03Sooooo0_l00002ool001Cooooo0ol0003aooooo`008Oooool0
0ol0003oooooooooo`0kooooo`03o`000?oo003oo`0000;oo`003?ooool4o`000?Cooooo000Qoooo
o`03o`000?oooooooooo043ooooo2_oo0002o`000?Sooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo1?l000000ol@413ooooo
ooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`?o0000oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Tooooo`03ogMgMomV
IVKooooo01Oooooo00?oIVIVogMgMoooool0Yoooool008?ooooo0ol0000Dooooo`03ob4Q8OoMgMgo
oooo00Kooooo00?ogMgMoa0@4?o^k^h06?ooool00oo^k^ko410@omgMg@2Wooooo`00Noooool01on7
QhOo0000oeEEEOmVIVKo0000oc8b<_o^k^h00_ooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0
003o0000odA4A?nj^[X00oooool00onHV9SoEEEEooooo`06ooooo`03oeEEEOnHV9Sooooo00;ooooo
1Ol00009ooooo`03oeEEEOnYZJWooooo00;ooooo00Ko^[ZjodA4A?ooooooooooohN7QomVIVHDoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0MOooool007_ooooo00Oo410@omgMgOmgMgOo8B4Q
oooooon7QhOoIVIV00;ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@
00Cooooo00?o0000omgMgOooool01Oooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@02_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P;ooooo00?ok^k^o`000?ooool0
2oooool6o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Oooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00Oo0000oooooooM
gMgo<S8booooooo^k^ko410@00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06
ooooo`;oMgMg1_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co410@
omgMgOoooooo00001?ooool00ol0003oooooooooo`0Booooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0Loooool007_ooooo
00CoEEEEojVYZOoooooo00000_ooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo
00Kooooo00?ok^k^oa0@4?o^k^h01Oooool00olb<S;oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^
00_ooooo00CoQhN7ofIVI_oooooo00001?ooool00ol0003oooooooooo`0:ooooo`Ko00000_ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000007ooooo`03ogMg
Molb<S;ooooo07Cooooo001kooooo`03omgMgOlQ8B7ok^k^00?ooooo00Co0000ooooool0003o0000
3Oooool00ol0003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00?o0000onk^k_ooool0
1Oooool00omgMgOoIVIVooooo`0:ooooo`04omgMgOl@413oooooo`0000?ooooo00?ok^k^o`000?oo
ool04oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0MOooool007cooooo00?oV9RHogMgMoooool00_ooool0
0ol0003oooooooooo`0<ooooo`03oa0@4?l0003o000000?o00001_ooool00ooMgMgo410@ooooo`04
ooooo`03oeEEEOmgMgOooooo00Kooooo00?o0000ooooooooool02?ooool7o`000003oooooomgMgOo
EEEE01Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@4100
1?ooool00ol0003oooooooooo`1gooooo`00T_ooool00ol0003oooooooooo`08ooooo`03oeEEEOnH
V9Sooooo00?ooooo00?ogMgMoa0@4?o^k^h00_ooool01Ol0003o^[ZjoooooonHV9So410@017ooooo
00?ok^k^oa0@4?oMgMd05?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`04ooooo`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo00So
oooo00?o^[ZjodA4A?ooool01?ooool02OmgMgOoIVIVooooooooooooV9RHoa0@4?l0003o8B4Qolc<
c00Aooooo`03ofIVI_mgMgOooooo01Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01?ooool4o`0007Kooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .35043 L
.10458 .38922 L
.12507 .40438 L
.14415 .41594 L
.16254 .42461 L
.17277 .42837 L
.18221 .43117 L
.19242 .43349 L
.19781 .43441 L
.20351 .43517 L
.2059 .43542 L
.20846 .43565 L
.21068 .43581 L
.2131 .43595 L
.21456 .43602 L
.21592 .43607 L
.21722 .4361 L
.21795 .43612 L
.21861 .43613 L
.21986 .43614 L
.22056 .43614 L
.22121 .43614 L
.2224 .43614 L
.22365 .43612 L
.22487 .43609 L
.2262 .43605 L
.22861 .43595 L
.23096 .43582 L
.23313 .43567 L
.23806 .43522 L
.24329 .43458 L
.25201 .43318 L
.26163 .43115 L
.28097 .42568 L
.30183 .41796 L
.34297 .39872 L
.38259 .3778 L
.4207 .35825 L
.46126 .34046 L
.48 .33382 L
.50031 .32795 L
.51141 .32538 L
.52165 .3234 L
.53144 .32189 L
.53686 .3212 L
.5418 .32068 L
.54632 .32027 L
.55124 .31992 L
.55394 .31976 L
Mistroke
.55644 .31964 L
.55899 .31954 L
.56138 .31947 L
.56362 .31941 L
.56488 .31939 L
.56603 .31938 L
.56701 .31937 L
.56808 .31936 L
.5692 .31936 L
.57025 .31936 L
.57148 .31937 L
.57264 .31938 L
.57368 .3194 L
.57481 .31942 L
.57735 .31948 L
.57969 .31955 L
.58434 .31974 L
.58934 .32003 L
.59839 .32073 L
.60916 .32184 L
.61901 .32311 L
.65869 .32983 L
.69685 .33714 L
.71814 .34079 L
.73746 .34351 L
.74712 .3446 L
.75758 .34555 L
.76239 .34589 L
.76746 .3462 L
.77213 .34642 L
.77656 .34659 L
.77893 .34665 L
.78018 .34668 L
.78151 .34671 L
.78262 .34672 L
.78385 .34674 L
.78497 .34675 L
.78602 .34676 L
.78726 .34677 L
.78857 .34677 L
.78968 .34676 L
.7909 .34676 L
.79222 .34675 L
.79363 .34673 L
.79496 .34671 L
.79617 .34668 L
.80069 .34656 L
.80324 .34647 L
.80559 .34637 L
.8145 .34585 L
Mistroke
.81916 .3455 L
.82418 .34506 L
.83324 .34409 L
.85387 .34114 L
.87502 .33712 L
.89511 .33251 L
.93333 .32209 L
.97399 .3097 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .35001 L
.10458 .38865 L
.12507 .40366 L
.14415 .41508 L
.16254 .42363 L
.17277 .42733 L
.18221 .43009 L
.19242 .43236 L
.19781 .43327 L
.20351 .43401 L
.2059 .43426 L
.20846 .43448 L
.21068 .43464 L
.2131 .43478 L
.21456 .43484 L
.21592 .43488 L
.21722 .43492 L
.21795 .43493 L
.21861 .43494 L
.21986 .43495 L
.22056 .43495 L
.22121 .43495 L
.2224 .43494 L
.22365 .43492 L
.22487 .43489 L
.2262 .43485 L
.22861 .43475 L
.23096 .43461 L
.23313 .43446 L
.23806 .434 L
.24329 .43336 L
.25201 .43195 L
.26163 .42993 L
.28097 .42447 L
.30183 .41681 L
.34297 .39779 L
.38259 .3771 L
.4207 .35768 L
.46126 .34006 L
.48 .33354 L
.50031 .32784 L
.51141 .32537 L
.52165 .3235 L
.53144 .32208 L
.53686 .32145 L
.5418 .32097 L
.54632 .32061 L
.55124 .3203 L
.55394 .32017 L
Mistroke
.55644 .32007 L
.55883 .31999 L
.56016 .31996 L
.56138 .31993 L
.56251 .31991 L
.56376 .3199 L
.56501 .31989 L
.56633 .31988 L
.5675 .31988 L
.56874 .31989 L
.56992 .3199 L
.57099 .31991 L
.5721 .31992 L
.57313 .31994 L
.57546 .32 L
.57751 .32006 L
.57969 .32014 L
.5846 .32038 L
.58909 .32065 L
.5992 .32148 L
.60812 .32243 L
.61749 .32361 L
.65566 .32995 L
.69627 .3377 L
.71504 .34098 L
.73537 .34398 L
.7465 .3453 L
.75675 .34628 L
.76655 .34698 L
.77149 .34724 L
.77409 .34735 L
.77692 .34745 L
.77963 .34752 L
.78083 .34755 L
.78215 .34758 L
.7833 .3476 L
.78455 .34761 L
.78587 .34762 L
.7871 .34763 L
.78823 .34763 L
.78947 .34763 L
.79075 .34763 L
.79195 .34762 L
.79308 .34761 L
.7941 .34759 L
.7964 .34755 L
.79908 .34748 L
.80156 .3474 L
.80715 .34715 L
.81208 .34686 L
Mistroke
.81731 .34648 L
.82673 .3456 L
.83686 .34439 L
.85516 .34154 L
.89641 .33244 L
.93614 .3213 L
.97435 .30959 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`3ooooooc_ooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0003o00000?oo0000:?l0
00000ooo003o0000o`000005o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?o
0000ool00?ooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`04o`000?oo003oo`00o`0001?ooooo
00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo0_l000000ooo003oooooooooo`0:ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Cooooo1Ol00003ooooo`03o`000?oooooooooo017ooooo00Co8B4QogMgMomgMgOo
<S8b1Oooool0027ooooo00Co0000ooooool0003oo`00oooooolKooooo`Co00006oooool2o`0000;o
oooo0_l00004ooooo`008Oooool01Ol0003oooooooooool0003oo`0009Wooooo1ol0000?ool000Ko
0000HOooool00ol0003oo`00ool0000Yooooo`008Oooool01_l0003ooooooooooooooooo0000ool0
097ooooo1?oo0003o`0001cooooo1?l0001Jooooo`04o`000?oo003oo`00ool002_ooooo000Qoooo
o`03o`000?oooooooooo00;ooooo00?o0000ool00?ooool0S?ooool3ool002Oooooo1Ooo0002o`00
053ooooo00Co0000ool00?oo003oo`00;_ooool0027ooooo00?o0000ooooooooool00oooool00ol0
003oo`00ooooo`28ooooo`?oo`00;oooool8ool004Oooooo00Co0000ool00?oo003oo`00<Oooool0
027ooooo0ol00004ooooo`03o`000?oo003ooooo08?ooooo1?oo000jooooo`?oo`000ol0000loooo
o`03o`000?oo003oo`0000?oo`00=?ooool0027ooooo00?o0000ooooooooool01Oooool00ol0003o
o`00ooooo`20ooooo`;oo`0000?o0000ooooooooool0@Oooool6o`00033ooooo1_l0000jooooo`00
8Oooool00ol0003oooooooooo`06ooooo`03o`000?oo003ooooo07cooooo0ol0001<ooooo`03o`00
0?oo003oo`0000?oo`009?ooool6o`00043ooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o
0000ool00?ooool0NOooool2o`0005Gooooo1Ooo0003o`0001Oooooo00?o0000ool00?oo00001_oo
0012ooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07Kooooo0_l0001L
ooooo`Ooo`002_l0000:ool004[ooooo000Qooooo`03o`000?oooooooooo00Wooooo0_l0001coooo
o`?o0000`oooool0027ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1^ooooo`03
o`000?oo003oo`000<Gooooo000Qooooo`?o00003?ooool00ol0003oooooooooo`1[ooooo`?oo`00
aoooool0027ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Xooooo`;oo`00b_oo
ool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Uooooo`;oo`00c?ooool0
027ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Qooooo`?oo`00c_ooool0027o
oooo00?o0000ooooooooool04?ooool2ool005oooooo0_oo00000ol0003oooooooooo`3>ooooo`00
8Oooool00ol0003oooooooooo`0Booooo`03ool00?oooooooooo05_ooooo00?oo`00o`000?ooool0
dOooool0027ooooo00?o0000ooooooooool04oooool00ooo003oooooooooo`1Hooooo`;o0000e?oo
ool0027ooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`1Eooooo`;o0000e_ooool0
027ooooo0ol0000Eooooo`03ool00?oooooooooo05;ooooo0_l0003Hooooo`008Oooool00ol0003o
ooooooooo`0Fooooo`03ool00?oooooooooo04oooooo0_l0003Jooooo`008Oooool00ol0003ooooo
ooooo`0Gooooo`;oo`00C?ooool2ool00003o`000?oooooooooo0=[ooooo000Qooooo`03o`000?oo
oooooooo01Wooooo00?oo`00ooooooooool0Aoooool2ool00003o`000?oooooooooo0=cooooo000Q
ooooo`03o`000?oooooooooo01[ooooo00?oo`00ooooooooool0AOooool00ooo003o0000ooooo`3O
ooooo`008Oooool00ol0003oooooooooo`0Kooooo`03ool00?oooooooooo04;ooooo0_oo003Roooo
o`008Oooool00ol0003oooooooooo`0Looooo`03ool00?oooooooooo03oooooo0_oo003Tooooo`00
8Oooool3o`0001gooooo0_l0000looooo`?oo`00i_ooool0027ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0gooooo`;oo`0000?o0000ooooooooool0i_ooool0027ooooo00?o0000
ooooooooool08?ooool2o`0003Gooooo00?o0000ool00?ooool0j_ooool0027ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0`ooooo`;o0000kOooool0027ooooo00?o0000oooooooo
ool08oooool2o`0000;oo`00;?ooool2o`000>oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo
02Kooooo00?o0000ool00?oo0000:?ooool2o`000?7ooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Yoooo
o`?oo`008Oooool2ool000;o0000loooool000Oooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00;ooooo0ol0000[ooooo`04o`000?oo003oo`00ool001_ooooo0ooo0002
o`000?Gooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo02cooooo0ol00003ool001Gooooo0ooo00000ol0003oooooooooo`3g
ooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo03;ooooo0ooo000;ooooo`Ooo`00oOooool000Oooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=?oo
ool;o`000003ool00?l0003o000000;o0000ooooool1ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodGooooo0007
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`006?oo
ool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Co
oooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOoo
ool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Hoooo
o`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0
003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00:Sooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2Sooooo`00Qoooool3o`00
01?ooooo00?o8B4QomgMgOooool01oooool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@413ogMgM
0:?ooooo001nooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP03ooooo`03o`000?oooooo
oooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P02ooooo`03oiRHV?mEEEGooooo00Oooooo00Co
EEEEoiRHV?oooooooooo1Ol00009ooooo`03oeEEEOnYZJWooooo00;ooooo00?o^[ZjodA4A?ooool0
0_ooool00on7QhOoIVIVooooo`0Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo1?l000000ol@413oooooooooo`1hooooo`00O_ooool01ol@413ogMgMogMgMolQ8B7oooooohN7
QomVIVH00oooool00ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool0
0ol0003ogMgMooooo`06ooooo`09o`000?oooooooooooooooonHV9So8B4Qonk^k_ooooooA4A400[o
oooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X3ooooo`03onk^k_l0003ooooo00_ooooo1_l00000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo07[ooooo
001nooooo`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@4003ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool01Oooool2ogMgM`Oooooo00?o<S8booooooooool00_ooool00onHV9So
8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`0000Gooooo00?o0000ooooooooool04Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0N_ooool007kooooo00CoEEEEojVY
ZOoooooo00000_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool01Ooo
ool00oo^k^ko410@onk^kP06ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h02ooo
ool01?n7QhOoIVIVooooool00005ooooo`03o`000?oooooooooo00[ooooo1_l000000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0N_ooool007kooooo00?o
gMgMob4Q8Oo^k^h00oooool00ol0003oooooooooo`02o`0000gooooo00?o0000ooooooooool01_oo
ool00omEEEGoV9RHooooo`05ooooo`03o`000?o^k^kooooo00Cooooo00?oMgMgofIVI_ooool02_oo
ool01?oMgMgo410@ooooool00004ooooo`03onk^k_l0003ooooo01;ooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03o`000?oooooooooo07[ooooo001oooooo`03oiRHV?mgMgOooooo00;ooooo
00?o0000ooooooooool03Oooool00ol@413o0000o`000003o`0000Gooooo00?ogMgMoa0@4?ooool0
1Oooool00omEEEGoMgMgooooo`05ooooo`03o`000?oooooooooo00Sooooo1ol00002ooooo`03ogMg
MomEEEGooooo01;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo07[o
oooo002Fooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool02OoMgMgo410@
onk^k_oooooo0000okZj^_ooooooV9RHoa0@400Booooo`03onk^k_l@413ogMgM01?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo07[ooooo002Fooooo`03o`000?oooooo
oooo00Oooooo00?o^[ZjodA4A?ooool01Oooool02?mgMgOoIVIVoooooonHV9So410@o`000?lQ8B7o
c<c<4_ooool00omVIVKoMgMgooooo`0Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omE
EEGoIVIVo`00001looooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .31688 L
.06244 .32452 L
.08426 .33148 L
.0949 .33416 L
.10458 .33613 L
.11403 .33761 L
.11837 .33814 L
.12297 .3386 L
.1253 .33879 L
.12787 .33897 L
.13024 .33911 L
.1324 .33921 L
.13494 .3393 L
.13635 .33933 L
.137 .33935 L
.13768 .33936 L
.13891 .33937 L
.14005 .33938 L
.14075 .33939 L
.14141 .33938 L
.14264 .33938 L
.1438 .33937 L
.14504 .33935 L
.14622 .33932 L
.14729 .33929 L
.14991 .3392 L
.1524 .33908 L
.15734 .33877 L
.16271 .33831 L
.17231 .33721 L
.18119 .33588 L
.19985 .33229 L
.22045 .32739 L
.26066 .31691 L
.27913 .31259 L
.2896 .31051 L
.29934 .30887 L
.30903 .30759 L
.31446 .30704 L
.31938 .30665 L
.32191 .30649 L
.32459 .30635 L
.32599 .30629 L
.32753 .30624 L
.32893 .3062 L
.33024 .30618 L
.33087 .30617 L
.33156 .30616 L
.33282 .30615 L
Mistroke
.33404 .30615 L
.33518 .30615 L
.33587 .30616 L
.33653 .30617 L
.33775 .30619 L
.33906 .30622 L
.34048 .30626 L
.34287 .30636 L
.34542 .3065 L
.35001 .30684 L
.35548 .30739 L
.36046 .30805 L
.37129 .30995 L
.38154 .31238 L
.40149 .31891 L
.41992 .32704 L
.45924 .3507 L
.49704 .38001 L
.5373 .41497 L
.57604 .4481 L
.59572 .46336 L
.61723 .47806 L
.63803 .48982 L
.65691 .49809 L
.66702 .50151 L
.67655 .50406 L
.68145 .50511 L
.68662 .50603 L
.68932 .50643 L
.69229 .50681 L
.69501 .50709 L
.69752 .50731 L
.70002 .50748 L
.70132 .50755 L
.70275 .50761 L
.70399 .50765 L
.70515 .50768 L
.70638 .5077 L
.70707 .50771 L
.70771 .50771 L
.70883 .5077 L
.70987 .50769 L
.71101 .50767 L
.71223 .50764 L
.71352 .50759 L
.71473 .50753 L
.717 .5074 L
.71954 .5072 L
.72222 .50694 L
.72703 .50635 L
Mistroke
.73221 .50552 L
.73791 .50438 L
.74806 .50179 L
.75733 .49879 L
.77822 .48993 L
.79722 .47949 L
.81795 .46573 L
.85861 .43258 L
.89776 .39464 L
.93936 .35014 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .31681 L
.06244 .32413 L
.08255 .33017 L
.09409 .33289 L
.10458 .33484 L
.1094 .33556 L
.11464 .33623 L
.11917 .3367 L
.12415 .3371 L
.12688 .33727 L
.12944 .3374 L
.13213 .3375 L
.13365 .33755 L
.13504 .33758 L
.13632 .3376 L
.1375 .33761 L
.1388 .33761 L
.13953 .33761 L
.14019 .33761 L
.1414 .3376 L
.14271 .33758 L
.14395 .33756 L
.14509 .33753 L
.14755 .33745 L
.14979 .33736 L
.15482 .33706 L
.15949 .3367 L
.16391 .33627 L
.17381 .33504 L
.18458 .33331 L
.22536 .32412 L
.26462 .31399 L
.28432 .30961 L
.30238 .30655 L
.3118 .30542 L
.31654 .30499 L
.32172 .30464 L
.32446 .3045 L
.32695 .30441 L
.32832 .30437 L
.32905 .30435 L
.32982 .30434 L
.33049 .30433 L
.33123 .30432 L
.33253 .30431 L
.33383 .30431 L
.33503 .30432 L
.33569 .30433 L
.33641 .30434 L
Mistroke
.33772 .30437 L
.33894 .3044 L
.34024 .30444 L
.34258 .30454 L
.34519 .30469 L
.34795 .30489 L
.35289 .30535 L
.3582 .30601 L
.36403 .30691 L
.37447 .30904 L
.38421 .31163 L
.4046 .31892 L
.42317 .32774 L
.46307 .35306 L
.50145 .38369 L
.54229 .41941 L
.58161 .45266 L
.61941 .47973 L
.63879 .49069 L
.64877 .49541 L
.65966 .49979 L
.66938 .50298 L
.67974 .50562 L
.68548 .50673 L
.69069 .50753 L
.6932 .50784 L
.69592 .50812 L
.6983 .50831 L
.70086 .50848 L
.70217 .50854 L
.70342 .50859 L
.70454 .50863 L
.70576 .50865 L
.70692 .50867 L
.70814 .50867 L
.70919 .50867 L
.71035 .50865 L
.711 .50864 L
.71169 .50862 L
.71293 .50858 L
.71426 .50852 L
.71572 .50844 L
.71834 .50826 L
.72077 .50805 L
.7261 .50742 L
.73095 .50667 L
.74183 .50434 L
.75179 .50145 L
.76099 .49817 L
.78178 .48867 L
Mistroke
.82115 .46366 L
.859 .43252 L
.89931 .39352 L
.9381 .35181 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`1Fooooo`[oo`0000?o0000
ooooooooool00_ooool3ool00=;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_oo
oomKo`0000Goo`004_l00006ool00<7o00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Ooo
ool01?l0003oooooo`000?l0000;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo
oooo1_l00005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool4o`0000?o
o`000oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Aooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`04
o`000?ooooooooooooooo`;o00002Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`Co00002oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00Go0000ool00?oo003oo`00o`00000>
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool2o`0001?ooooo00Co8B4Q
ogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000ooooooooool00oooool3ool003kooooo0ooo0002
o`0002[ooooo00?o0000ool00?ooool0[oooool00ol0003oooooooooo`0Booooo`;o00000_ooool2
o`0000Cooooo000Qooooo`03o`000?oooooooooo00Kooooo0ooo000fooooo`Goo`0000?o0000oooo
ooooool0;_ooool2o`000:gooooo00?o0000ooooooooool07Oooool0027ooooo00?o0000oooooooo
ool02Oooool3ool002kooooo1Ooo0002o`0003Kooooo0_l0002Zooooo`03o`000?oooooooooo01ko
oooo000Qooooo`03o`000?oooooooooo00cooooo0ooo000Xooooo`?oo`000ol0000looooo`;o0000
Yoooool00ol0003oooooooooo`0Oooooo`008Oooool00ol0003oooooooooo`0?ooooo`?oo`0000?o
0000ooooooooool08Oooool3o`0004;ooooo0_l0002Tooooo`03ool00?oooooooooo023ooooo000Q
ooooo`?o00004_ooool00ooo003o0000o`000002o`0001_ooooo1?l00017ooooo`;oo`00XOooool0
0ol0003oo`00ooooo`0Qooooo`008Oooool00ol0003oooooooooo`0Gooooo`Go000000?oooooool0
0?oo00003_oo0005o`0004cooooo00?o0000ool00?oo0000W_ooool00ol0003oo`00ooooo`0Roooo
o`008Oooool00ol0003oooooooooo`0Looooo`oo0000EOooool00ol0003oo`00ooooo`2Kooooo`03
o`000?oo003ooooo02?ooooo000Qooooo`03o`000?oooooooooo08;ooooo0_oo002Iooooo`03o`00
0?oo003ooooo02Cooooo000Qooooo`03o`000?oooooooooo08?ooooo00?o0000ool00?oo0000U_oo
ool00ol0003oo`00ooooo`0Uooooo`008Oooool00ol0003oooooooooo`25ooooo`03o`000?oo003o
oooo09?ooooo00?o0000ool00?ooool09_ooool0027ooooo00?o0000ooooooooool0Qoooool00ooo
003oooooooooo`2Aooooo`03ool00?oooooooooo02Kooooo000Qooooo`?o0000R?ooool00ooo003o
ooooooooo`2?ooooo`03ool00?oooooooooo02Oooooo000Qooooo`03o`000?oooooooooo08Wooooo
00?oo`00ooooooooool0SOooool00ooo003oooooooooo`0Xooooo`008Oooool00ol0003ooooooooo
o`2:ooooo`03ool00?oooooooooo08_ooooo00?oo`00ooooooooool0:Oooool0027ooooo00?o0000
ooooooooool0Roooool2o`0008[ooooo00?oo`00ooooooooool0:_ooool0027ooooo00?o0000oooo
ooooool0SOooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo02_ooooo000Qooooo`03
o`000?oooooooooo08kooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0/ooooo`00
8Oooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0
;Oooool0027ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`20ooooo`03o`000?oo
oooooooo02kooooo000Qooooo`?o0000TOooool2o`0007oooooo00?o0000ooooooooool0;oooool0
027ooooo00?o0000ooooooooool0Toooool2ool007cooooo00?o0000ooooooooool0<?ooool0027o
oooo00?o0000ooooooooool0U?ooool00ol0003oo`00ooooo`1iooooo`03o`000?oooooooooo037o
oooo000Qooooo`03o`000?oooooooooo09Gooooo00?o0000ool00?ooool0Moooool00ooo003ooooo
ooooo`0booooo`008Oooool00ol0003oooooooooo`2Gooooo`03ool00?oooooooooo07Cooooo0_oo
000dooooo`008Oooool00ol0003oooooooooo`2Hooooo`03ool00?oooooooooo07;ooooo00?oo`00
ooooooooool0=?ooool0027ooooo00?o0000ooooooooool0VOooool2ool0077ooooo00?oo`00oooo
ooooool0=Oooool0027ooooo0ol0002Jooooo`03o`000?oo003ooooo06kooooo00?oo`00oooooooo
ool0=_ooool0027ooooo00?o0000ooooooooool0W?ooool00ooo003oooooooooo`1[ooooo`03ool0
0?oooooooooo03Oooooo000Qooooo`03o`000?oooooooooo09gooooo00?oo`00ooooooooool0JOoo
ool00ooo003oooooooooo`0hooooo`008Oooool00ol0003oooooooooo`2Nooooo`03ool00?l0003o
oooo06Oooooo00?oo`00ooooooooool0>Oooool0027ooooo00?o0000ooooooooool0Woooool00ooo
003o0000ooooo`1Uooooo`03ool00?oooooooooo03[ooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooo
oooo0:7ooooo00?o0000ooooooooool0H_ooool00ooo003oooooooooo`0kooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000
ooooooooool0X_ooool00ol0003oooooooooo`1Pooooo`03ool00?oooooooooo03cooooo0007oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000Xoooool0
0ol0003oooooooooo`1Nooooo`03ool00?oooooooooo03gooooo0007ooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooooooool0G?ooool00ol0003oooooooooo`0nooooo`001oooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0:Gooooo00?o
0000ooooooooool0FOooool2o`00047ooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool0Eooo
ool00ol0003oooooooooo`11ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`2Wooooo`;oo`00E_ooool00ol0003ooooooooo
o`12ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oo
oooooooo0:Sooooo00?o0000ool00?ooool0D_ooool2o`0004Gooooo000Qooooo`03o`000?oooooo
oooo0:Wooooo00?o0000ool00?ooool0D?ooool00ol0003oooooooooo`15ooooo`008Oooool00ol0
003oooooooooo`2Zooooo`03o`000?oo003ooooo04kooooo0_oo0017ooooo`008Oooool3o`000:co
oooo0_oo001<ooooo`03ool00?oooooooooo04Oooooo000Qooooo`03o`000?oooooooooo0:gooooo
00?o0000ool00?ooool0B?ooool00ol0003oo`00ooooo`19ooooo`008Oooool00ol0003ooooooooo
o`2^ooooo`03o`000?oo003ooooo04Kooooo00?o0000ool00?ooool0B_ooool0027ooooo00?o0000
ooooooooool0[oooool00ol0003oo`00ooooo`14ooooo`03o`000?oo003ooooo04_ooooo000Qoooo
o`03o`000?oooooooooo0;3ooooo00?o0000ool00?ooool0@Oooool00ol0003oo`00ool0001=oooo
o`008Oooool00ol0003oooooooooo`2booooo`03ool00?l0003ooooo03kooooo0_oo001?ooooo`00
8Oooool00ol0003oooooooooo`2cooooo`03ool00?l0003ooooo03cooooo00?oo`00ooooooooool0
Coooool0027ooooo0ol0002eooooo`;o0000>Oooool2ool005;ooooo000Qooooo`03o`000?oooooo
oooo0;Oooooo0_l0000fooooo`03ool00?l0003ooooo05;ooooo000Qooooo`03o`000?oooooooooo
0;Wooooo00?o0000ooooooooool0<_ooool2o`0005Cooooo000Qooooo`03o`000?oooooooooo0;[o
oooo0_l0000`ooooo`;o0000E_ooool0027ooooo00?o0000ooooooooool0_?ooool00ol0003ooooo
ooooo`0[ooooo`;o0000F?ooool0027ooooo00?o0000ooooooooool0_Oooool2ool00003o`000?oo
oooooooo02Kooooo0_l0001Jooooo`008Oooool00ol0003oooooooooo`2oooooo`;oo`000_l0000R
ooooo`?o0000G?ooool0027ooooo00?o0000ooooooooool0`Oooool3ool000;o00007Oooool3ool0
05kooooo000Qooooo`?o0000a?ooool3ool000;o00005oooool3ool0067ooooo000Qooooo`03o`00
0?oooooooooo0<Oooooo0ooo00000ol0003oooooooooo`0?ooooo`Coo`0000?o0000ooooooooool0
HOooool0027ooooo00?o0000ooooooooool0b_ooool2ool000co00001?oo001Xooooo`008Oooool0
0ol0003oooooooooo`3Fooooo`;oo`00K?ooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo1?l000000ol@413ooooooooo
o`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`?o0000oooooom5ooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006oooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Tooooo`03ogMgMomVIVKo
oooo01Oooooo00?oIVIVogMgMoooool0Yoooool008?ooooo0ol0000Dooooo`03ob4Q8OoMgMgooooo
00Kooooo00?ogMgMoa0@4?o^k^h06?ooool00oo^k^ko410@omgMg@2Wooooo`00Noooool01on7QhOo
0000oeEEEOmVIVKo0000oc8b<_o^k^h00_ooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o
0000odA4A?nj^[X00oooool00onHV9SoEEEEooooo`06ooooo`03oeEEEOnHV9Sooooo00;ooooo1Ol0
0009ooooo`03oeEEEOnYZJWooooo00;ooooo00Ko^[ZjodA4A?ooooooooooohN7QomVIVHDooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000001Ol@413ooooooooooooooooo
A4A400;o000000?o<S8bomgMgOooool0M?ooool007_ooooo00Oo410@omgMgOmgMgOo8B4Qoooooon7
QhOoIVIV00;ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo
00?o0000omgMgOooool01Oooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@02_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P;ooooo00?ok^k^o`000?ooool02oooool6
o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo07Cooooo001kooooo`07o`000?oooooogMgMoc8b<_ooooook^k^
oa0@4002ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool2ogMgM`Kooooo
00?o<S8booooooooool00oooool00onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`0000Co
oooo00?o0000ooooooooool04_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1cooooo`00Noooool01?mEEEGoZJVYooooool00002oooo
o`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool01_ooool00oo^k^ko410@onk^kP05
ooooo`03oc8b<_oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7QhOoIVIVooooool0
0004ooooo`03o`000?oooooooooo00[ooooo1_l00002ooooo`05o`000?ooooooooooooooool00000
3_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo07Cooooo001kooooo`03omgMgOlQ
8B7ok^k^00?ooooo00Co0000ooooool0003o00003Oooool00ol0003oooooooooo`07ooooo`03oeEE
EOnHV9Sooooo00Cooooo00?o0000onk^k_ooool01Oooool00omgMgOoIVIVooooo`0:ooooo`04omgM
gOl@413oooooo`0000?ooooo00?ok^k^o`000?ooool04oooool01Ol0003ooooooooooooooooo0000
00kooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<07Gooooo001loooo
o`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool03?ooool00ol@413o0000o`000003o`00
00Kooooo00?ogMgMoa0@4?ooool01?ooool00omEEEGoMgMgooooo`06ooooo`03o`000?oooooooooo
00Sooooo1ol000000oooooooMgMgoeEEE@0Dooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo
00Sooooo00?oEEEEoiRHV?ooool00oooool00ooMgMgo410@onk^kP02ooooo`05o`000?nj^[[ooooo
oiRHV?l@41004Oooool00oo^k^ko410@omgMg@0Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooo
oooo00Sooooo00?o^[ZjodA4A?ooool01?ooool02OmgMgOoIVIVooooooooooooV9RHoa0@4?l0003o
8B4Qolc<c00Aooooo`03ofIVI_mgMgOooooo01Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`03oeEEEOmVIVKo000000Gooooo1?l0001fooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28891 L
.10458 .26589 L
.14415 .24424 L
.18221 .22597 L
.20178 .21869 L
.21274 .21551 L
.21758 .21435 L
.22272 .21328 L
.22745 .21246 L
.23267 .21174 L
.23496 .21149 L
.23742 .21127 L
.23974 .2111 L
.24186 .21099 L
.24314 .21093 L
.24384 .21091 L
.24451 .21089 L
.24579 .21087 L
.24696 .21086 L
.24763 .21085 L
.24835 .21086 L
.24963 .21087 L
.25034 .21089 L
.25101 .21091 L
.25252 .21096 L
.25383 .21102 L
.25508 .2111 L
.25741 .21127 L
.25992 .21151 L
.26265 .21183 L
.26749 .21257 L
.27205 .21346 L
.28242 .21619 L
.29253 .21984 L
.30343 .22487 L
.32347 .23711 L
.34457 .25411 L
.38268 .29454 L
.42324 .34795 L
.46228 .40387 L
.50378 .46112 L
.54376 .5082 L
.58223 .54229 L
.6021 .55497 L
.61225 .5601 L
.62315 .5646 L
.63338 .56787 L
.64272 .57007 L
.64722 .57085 L
Mistroke
.64959 .5712 L
.65212 .57152 L
.65455 .57177 L
.65674 .57196 L
.65896 .5721 L
.66104 .5722 L
.6622 .57224 L
.66345 .57228 L
.66463 .57229 L
.66571 .5723 L
.66697 .57229 L
.66768 .57229 L
.66834 .57227 L
.66954 .57224 L
.67082 .5722 L
.67205 .57214 L
.67336 .57207 L
.67574 .5719 L
.67856 .57164 L
.68115 .57135 L
.69016 .56992 L
.69469 .56897 L
.69964 .56775 L
.71929 .56114 L
.74025 .55114 L
.7818 .52332 L
.82184 .48811 L
.86035 .44824 L
.90132 .40124 L
.94078 .35321 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .28797 L
.10458 .26394 L
.14415 .24225 L
.18221 .22399 L
.20178 .2166 L
.21267 .21334 L
.22272 .21098 L
.22768 .21007 L
.23293 .20929 L
.23548 .20899 L
.23821 .20873 L
.23978 .2086 L
.24121 .2085 L
.24257 .20842 L
.24402 .20836 L
.24471 .20833 L
.24536 .20831 L
.24658 .20828 L
.24772 .20827 L
.24896 .20826 L
.24961 .20827 L
.25032 .20827 L
.25107 .20829 L
.25177 .2083 L
.25301 .20834 L
.25435 .2084 L
.25698 .20856 L
.25948 .20876 L
.26416 .2093 L
.26875 .21003 L
.27382 .21107 L
.28407 .21392 L
.29357 .21749 L
.30249 .22166 L
.32267 .23405 L
.34118 .24891 L
.3808 .2908 L
.41891 .34077 L
.45947 .39873 L
.49852 .45311 L
.54002 .50332 L
.56082 .52403 L
.58 .53999 L
.59868 .55246 L
.60822 .55763 L
.61846 .56226 L
.62869 .56595 L
.63804 .5685 L
.64253 .56946 L
Mistroke
.64743 .5703 L
.65206 .57091 L
.65415 .57112 L
.65635 .57131 L
.65762 .57139 L
.65901 .57147 L
.66028 .57153 L
.66144 .57158 L
.6621 .5716 L
.66282 .57161 L
.66358 .57163 L
.66429 .57164 L
.66496 .57164 L
.66567 .57164 L
.66695 .57163 L
.66812 .57161 L
.66939 .57157 L
.67059 .57153 L
.67169 .57148 L
.67424 .57132 L
.67691 .5711 L
.68153 .57058 L
.68581 .56996 L
.69553 .56802 L
.70608 .56512 L
.71603 .56167 L
.73463 .55341 L
.77315 .52954 L
.81412 .49542 L
.85358 .45557 L
.89151 .41247 L
.93191 .36376 L
.97078 .31582 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0?Oooool>ool00?Wooooo000Qooooo`03o`000?oooooooooo
03_ooooo0_oo000=o`000003ool00?oooooooooo0?Oooooo000Qooooo`?o0000=oooool4o`00013o
oooo1Ol0003dooooo`008Oooool00ol0003oooooooooo`0dooooo`?o00006Oooool00ol0003ooooo
ooooo`3aooooo`008Oooool00ol0003oooooooooo`0`ooooo`;oo`000_l0000Mooooo`?o000000?o
ooooool00?oo0000kOooool0027ooooo00?o0000ooooooooool0;_ooool2ool00003o`000?oooooo
oooo027ooooo0ol000000ooo003oooooooooo`3Zooooo`008Oooool00ol0003oooooooooo`0/oooo
o`;oo`00:Oooool00ol0003oo`00ool0003Zooooo`008Oooool00ol0003oooooooooo`0Zooooo`;o
o`00;?ooool2o`000003ool00?oooooooooo0>Oooooo000Qooooo`03o`000?oooooooooo02Sooooo
0_oo000`ooooo`03o`000?oo003ooooo0>Oooooo000Qooooo`?o00009_ooool2ool003?ooooo00?o
0000ool00?ooool0i_ooool0027ooooo00?o0000ooooooooool09?ooool2ool003Oooooo00?oo`00
ooooooooool0i?ooool0027ooooo00?o0000ooooooooool08_ooool2ool003[ooooo00?oo`00o`00
0?ooool0hoooool0027ooooo00?o0000ooooooooool08?ooool2o`0003gooooo00?oo`00o`000?oo
ool0h_ooool0027ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0nooooo`;oo`00
h_ooool0027ooooo00?o0000ooooooooool07Oooool2o`0004?ooooo00?o0000ooooooooool0gooo
ool0027ooooo00?o0000ooooooooool06oooool2o`0004Gooooo00?o0000ooooooooool0goooool0
027ooooo00?o0000ooooooooool06?ooool2ool00003o`000?oooooooooo04Kooooo00?o0000oooo
ooooool0g_ooool0027ooooo0ol0000Fooooo`;oo`000_l0001:ooooo`03o`000?oooooooooo0=go
oooo000Qooooo`03o`000?oooooooooo01Cooooo0_oo0002o`0002Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01;ooooo00?o0000oooo
ooooool0:?ooool4o`000003oa0@4?oooooooooo03_ooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03gooooo1Ol0000Kooooo`008Oooool00ol0
003oooooooooo`0Cooooo`03ool00?l0003o000002Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Booooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0l
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0027ooooo00?o0000ooooooooool04Oooool2
ool00003o`000?oooooooooo02Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0??ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool0
0ol0003oooooooooo`0?ooooo`;oo`0000?o0000ooooooooool0:Oooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool05?ooool00ol0003oo`00ooooo`0Wooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0nooooo`03oiRHV?lQ
8B7ok^k^01_ooooo000Qooooo`03o`000?oooooooooo00kooooo00?oo`00o`000?ooool0;?ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Eooooo`03o`00
0?oo003ooooo02Oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0@?ooool00omgMgOoIVIVooooo`0Jooooo`008Oooool00ol0003ooooo
ooooo`0<ooooo`;oo`00;oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooooooo
ool06?ooool00ol0003oo`00ooooo`0Vooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Wooooo000Qooooo`?o0000
2_ooool00ol0003oo`00ooooo`0`ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oo003ooooo02Gooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo03oooooo00Go0000okZj^_ooooooV9RHoa0@400Koooo
o`008Oooool00ol0003oooooooooo`08ooooo`;o0000<oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l0000Iooooo`03o`000?oo003ooooo02;ooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo00Kooooo0_l0001Tooooo`03o`000?oo003ooooo0=Gooooo000Qooooo`03
o`000?oooooooooo00Cooooo0_l0001Wooooo`03ool00?oooooooooo0=Cooooo000Qooooo`03o`00
0?oooooooooo00;ooooo0_l0001Yooooo`03o`000?oo003ooooo0=Cooooo000Qooooo`04o`000?oo
ooooooooo`0000;oo`00Joooool00ol0003oo`00ooooo`39ooooo`;o00000_ooool2o`0000Cooooo
000Qooooo`04o`000?oo003oo`00ool006kooooo00?o0000ool00?ooool0b?ooool01_o^k^ko8B4Q
ohN7Qonj^[[o0000omgMg@Cooooo000Jooooo`Oo000000?oo`00o`000?l00000LOl000000ooo003o
0000o`00002co`000003ool00?l0003o000000Go00003?ooool01?oMgMgo0000oa0@4?o<c<`5oooo
o`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00Go0000oooooooo
003oooooo`00000>ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ooo
003o0000ooooo`0Booooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02Oooool01?l0003oooooool00?l0000>ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02_ooool00ooo003o0000o`00000Cooooo`04ob4Q8OmgMgOo
MgMgoc8b<PGooooo000Qooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0/?ooool0
0ooo003oooooooooo`0Booooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo
07?ooooo00?o0000ooooooooool0[_ooool00ooo003oooooooooo`0Mooooo`008Oooool00ol0003o
ooooooooo`1dooooo`03o`000?oooooooooo0:cooooo00?oo`00ooooooooool07_ooool0027ooooo
00?o0000ooooooooool0M?ooool00ol0003oooooooooo`2[ooooo`03ool00?l0003ooooo01oooooo
000Qooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0Z_ooool00ooo003ooooooooo
o`0Oooooo`008Oooool3o`0007Kooooo00?o0000ooooooooool0Z?ooool00ooo003oooooooooo`0P
ooooo`008Oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo0:Kooooo00?oo`00oooo
ooooool08Oooool0027ooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`2Vooooo`03
ool00?oooooooooo027ooooo000Qooooo`03o`000?oooooooooo07Sooooo00?o0000ool00?ooool0
Y?ooool00ooo003oooooooooo`0Rooooo`008Oooool00ol0003oooooooooo`1iooooo`03ool00?oo
oooooooo0:;ooooo00?oo`00ooooooooool08oooool0027ooooo00?o0000ooooooooool0N_ooool0
0ooo003oooooooooo`2Pooooo`03ool00?oooooooooo02Cooooo000Qooooo`03o`000?oooooooooo
07[ooooo00?o0000ool00?ooool0Woooool00ol0003oooooooooo`0Uooooo`008Oooool3o`0007_o
oooo00?oo`00ooooooooool0W_ooool00ol0003oooooooooo`0Uooooo`008Oooool00ol0003ooooo
ooooo`1looooo`03ool00?oooooooooo09cooooo00?o0000ooooooooool09_ooool0027ooooo00?o
0000ooooooooool0O?ooool00ol0003oo`00ooooo`2Kooooo`03o`000?oooooooooo02Oooooo000Q
ooooo`03o`000?oooooooooo07gooooo00?o0000ool00?ooool0VOooool00ol0003oooooooooo`0X
ooooo`008Oooool00ol0003oooooooooo`1nooooo`03ool00?oooooooooo09Oooooo00?o0000oooo
ooooool0:Oooool0027ooooo00?o0000ooooooooool0Ooooool00ooo003oooooooooo`2Eooooo`03
o`000?oooooooooo02[ooooo000Qooooo`03o`000?oooooooooo07oooooo00?o0000ool00?ooool0
U?ooool00ooo003oooooooooo`0[ooooo`008Oooool00ol0003oooooooooo`20ooooo`03ool00?oo
oooooooo09;ooooo00?o0000ool00?ooool0;?ooool0027ooooo0ol00021ooooo`03ool00?oooooo
oooo097ooooo00?oo`00ooooooooool0;?ooool0027ooooo00?o0000ooooooooool0POooool00ol0
003oo`00ooooo`2@ooooo`03ool00?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo08;o
oooo00?o0000ooooooooool0S_ooool00ooo003oooooooooo`0^ooooo`008Oooool00ol0003ooooo
ooooo`23ooooo`03o`000?oooooooooo08cooooo00?oo`00ooooooooool0;oooool0027ooooo00?o
0000ooooooooool0Q?ooool00ol0003oooooooooo`2:ooooo`03ool00?oooooooooo033ooooo000Q
ooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool0ROooool00ol0003oo`00ooooo`0a
ooooo`008Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo08Oooooo00?o0000ool0
0?ooool0<_ooool0027ooooo0ol00026ooooo`03o`000?oooooooooo08Kooooo00?oo`00oooooooo
ool0<_ooool0027ooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`25ooooo`03ool0
0?oooooooooo03?ooooo000Qooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool0Pooo
ool00ooo003oooooooooo`0dooooo`008Oooool00ol0003oooooooooo`28ooooo`03o`000?oo003o
oooo087ooooo00?oo`00ooooooooool0=Oooool0027ooooo00?o0000ooooooooool0ROooool00ooo
003oooooooooo`1oooooo`03o`000?oooooooooo03Kooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooo
oooo08Wooooo00?o0000ool00?ooool0Ooooool00ol0003oooooooooo`0fooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000
ooooooooool0R_ooool00ol0003oo`00ooooo`1mooooo`03o`000?oooooooooo03Oooooo0007oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000Roooool0
0ol0003oo`00ooooo`1kooooo`03o`000?oooooooooo03Sooooo0007ooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo08_ooooo00?o0000
ool00?ooool0N_ooool00ol0003oooooooooo`0iooooo`001oooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo08cooooo00?o
0000ool00?ooool0N?ooool00ol0003oooooooooo`0jooooo`001oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2=ooooo`03o`000?oo
003ooooo07Oooooo00?o0000ooooooooool0>_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0S_ooool00ol0003oo`00oooo
o`1dooooo`03ool00?l0003ooooo03cooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0000Gooooo00?o0000ooooooooool0S_ooool00ol0003oo`00ooooo`1cooooo`03ool00?l0
003ooooo03gooooo000Qooooo`03o`000?oooooooooo08oooooo00?o0000ool00?ooool0LOooool0
0ooo003o0000ooooo`0nooooo`008Oooool00ol0003oooooooooo`2@ooooo`03o`000?oo003ooooo
06oooooo00?oo`00o`000?ooool0?oooool0027ooooo0ol0002@ooooo`03o`000?ooooooo`0006ko
oooo00?oo`00o`000?ooool0@?ooool0027ooooo00?o0000ooooooooool0TOooool00ol0003ooooo
ooooo`1/ooooo`03ool00?l0003ooooo047ooooo000Qooooo`03o`000?oooooooooo09;ooooo00?o
0000ooooooooool0Joooool00ooo003oooooooooo`11ooooo`008Oooool00ol0003oooooooooo`2C
ooooo`03o`000?oooooooooo06Wooooo00?oo`00ooooooooool0@_ooool0027ooooo00?o0000oooo
ooooool0Toooool00ol0003oooooooooo`1Xooooo`03ool00?oooooooooo04?ooooo000Qooooo`03
o`000?oooooooooo09Cooooo00?o0000ooooooooool0I_ooool00ooo003oooooooooo`14ooooo`00
8Oooool00ol0003oooooooooo`2Eooooo`03o`000?oooooooooo06Cooooo00?oo`00ooooooooool0
AOooool0027ooooo0ol0002Fooooo`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool0A_oo
ool0027ooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`1Pooooo`03ool00?oooooo
oooo04Oooooo000Qooooo`03o`000?oooooooooo09Sooooo00?o0000ool00?ooool0G_ooool00ol0
003oooooooooo`18ooooo`008Oooool00ol0003oooooooooo`2Iooooo`03ool00?oooooooooo05co
oooo00?o0000ooooooooool0BOooool0027ooooo00?o0000ooooooooool0V_ooool00ooo003ooooo
ooooo`1Iooooo`;o0000C?ooool0027ooooo00?o0000ooooooooool0V_ooool00ol0003oo`00oooo
o`1Hooooo`03o`000?oooooooooo04cooooo000Qooooo`03o`000?oooooooooo09_ooooo00?o0000
ool00?ooool0E_ooool00ol0003oooooooooo`1=ooooo`008Oooool00ol0003oooooooooo`2Loooo
o`03o`000?oo003ooooo05Cooooo00?o0000ooooooooool0C_ooool0027ooooo0ol0002Mooooo`03
o`000?oo003ooooo057ooooo0_oo001Aooooo`008Oooool00ol0003oooooooooo`2Nooooo`03o`00
0?oo003ooooo04oooooo00?oo`00o`000?ooool0DOooool0027ooooo00?o0000ooooooooool0Wooo
ool00ooo003oooooooooo`1=ooooo`03ool00?oooooooooo05;ooooo000Qooooo`03o`000?oooooo
oooo0:3ooooo00?oo`00o`000?ooool0Boooool00ooo003oooooooooo`1Cooooo`008Oooool00ol0
003oooooooooo`2Qooooo`03ool00?l0003ooooo04Sooooo0_oo001Fooooo`008Oooool00ol0003o
ooooooooo`2Rooooo`03ool00?l0003ooooo04Kooooo00?oo`00o`000?ooool0E_ooool0027ooooo
00?o0000ooooooooool0Xoooool00ooo003o0000ooooo`14ooooo`03ool00?l0003ooooo05Oooooo
000Qooooo`?o0000YOooool00ol0003oooooooooo`11ooooo`03ool00?l0003ooooo05Sooooo000Q
ooooo`03o`000?oooooooooo0:Kooooo0_l00010ooooo`03ool00?oooooooooo05Wooooo000Qoooo
o`03o`000?oooooooooo0:Sooooo00?o0000ooooooooool0>oooool00ol0003oo`00ooooo`1Koooo
o`008Oooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo03Wooooo00?o0000ool00?oo
ool0G?ooool0027ooooo00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`0fooooo`;o0000
Goooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0:_ooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`1Oooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0:_ooooo0_oo00000ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo063ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[Oooool2ool0
033ooooo0_l0001Sooooo`006_ooool00ol0003oooooooooo`04ooooo`?o0000[oooool2ool002go
oooo00?o0000ooooooooool0Hoooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2aooooo`;oo`00:Oooool2ool006Kooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0/_ooool00ol0003oo`00ooooo`0Uooooo`;oo`00J?ooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`2dooooo`?oo`008?ooool3ool006[ooooo000Hoooo
o`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0]Oooool2o`0000;oo`006oooool3ool0
0003o`000?oooooooooo06[ooooo000Qooooo`03o`000?oooooooooo0;Sooooo00Co0000ool00?l0
003o00005Oooool3ool00003o`000?oooooooooo06gooooo000Qooooo`03o`000?oooooooooo0;co
oooo0ol0000?ooooo`?oo`0000?o0000ooooooooool0L?ooool0027ooooo0ol0002oooooo`Goo`00
1?ooool8o`0007Cooooo000Qooooo`03o`000?oooooooooo0<Cooooo1Ol0001kooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00Z?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:?ooooo0027
ooooo`?o00004oooool00olQ8B7ogMgMooooo`07ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^
oa0@4?oMgMd0Xoooool007kooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00?ooooo00?o
0000ooooooooool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00?oV9RHoeEEEOooool0
1oooool01?mEEEGoV9RHooooooooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool00onj^[[o
A4A4ooooo`02ooooo`03ohN7QomVIVKooooo01;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0007_ooooo001nooooo`07oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP03
ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oM
gMgooooo00Kooooo00Wo0000oooooooooooooooooiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mE
EEGoV9RHoooooooooooo410@okZj^P?ooooo00?ok^k^o`000?ooool02oooool6o`000006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A01koooo
o`00O_ooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@41000oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Gooooo0_mgMgL7ooooo`03oc8b<_oooooooooo00;ooooo00?oV9RH
ob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool00005ooooo`03o`000?oooooooooo017ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^07cooooo001nooooo`04oeEEEOnY
ZJWoooooo`0000;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00Go
oooo00?ok^k^oa0@4?o^k^h01_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00_o
oooo00CoQhN7ofIVI_oooooo00001Oooool00ol0003oooooooooo`0:ooooo`Ko000000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^07_ooooo001nooooo`03
omgMgOlQ8B7ok^k^00?ooooo00?o0000ooooooooool00_l0000=ooooo`03o`000?oooooooooo00Ko
oooo00?oEEEEoiRHV?ooool01Oooool00ol0003ok^k^ooooo`04ooooo`03ogMgMomVIVKooooo00[o
oooo00CogMgMoa0@4?oooooo00001?ooool00oo^k^ko0000ooooo`0Booooo`05o`000?oooooooooo
ooooool000003_ooool00omgMgOoIVIVooooo`1jooooo`00Ooooool00onHV9SoMgMgooooo`02oooo
o`03o`000?oooooooooo00gooooo00?o410@o`000?l000000ol00005ooooo`03omgMgOl@413ooooo
00Gooooo00?oEEEEogMgMoooool01Oooool00ol0003oooooooooo`08ooooo`Oo00000_ooool00omg
MgOoEEEEooooo`0Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`1i
ooooo`00U_ooool00ol0003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00WogMgMoa0@
4?o^k^koooooo`000?nj^[[ooooooiRHV?l@41004_ooool00oo^k^ko410@omgMg@0Cooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@07_ooooo002Fooooo`03
o`000?oooooooooo00Oooooo00?o^[ZjodA4A?ooool01Oooool02?mgMgOoIVIVoooooonHV9So410@
o`000?lQ8B7oc<c<4_ooool00omVIVKoMgMgooooo`0Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<07_ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .25154 L
.10458 .19627 L
.12507 .17427 L
.14415 .15756 L
.16254 .14545 L
.17284 .14055 L
.18221 .13731 L
.18704 .13611 L
.18969 .1356 L
.19216 .1352 L
.19427 .13493 L
.19654 .13471 L
.19783 .13462 L
.19905 .13455 L
.20015 .13451 L
.20135 .13448 L
.20203 .13448 L
.20276 .13448 L
.20345 .13449 L
.20409 .1345 L
.2053 .13454 L
.20657 .13461 L
.20794 .13471 L
.20922 .13482 L
.21213 .13517 L
.21466 .13557 L
.21696 .13602 L
.22214 .1373 L
.22694 .13883 L
.23205 .14082 L
.24122 .1453 L
.26198 .15973 L
.28145 .1783 L
.29973 .1997 L
.33842 .25468 L
.37956 .32064 L
.41919 .38294 L
.45729 .43548 L
.47854 .46022 L
.49785 .47952 L
.51817 .49647 L
.5369 .50904 L
.55608 .51896 L
.56619 .52302 L
.57688 .52648 L
.58632 .52882 L
.59152 .52985 L
.59646 .53064 L
.60103 .53123 L
Mistroke
.60345 .53148 L
.60603 .53171 L
.60841 .53188 L
.61056 .532 L
.6116 .53205 L
.61273 .53209 L
.61378 .53212 L
.61477 .53215 L
.61602 .53217 L
.61715 .53218 L
.61837 .53219 L
.61906 .53219 L
.6197 .53218 L
.62076 .53217 L
.62193 .53215 L
.62315 .53211 L
.6243 .53208 L
.62693 .53196 L
.62933 .53181 L
.63475 .53136 L
.63966 .5308 L
.64502 .53003 L
.65582 .52799 L
.67547 .52274 L
.69644 .51513 L
.73799 .49483 L
.77802 .47002 L
.81654 .44253 L
.85751 .41047 L
.89697 .37769 L
.93491 .34508 L
.9753 .3098 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .24997 L
.10458 .19598 L
.12507 .17365 L
.14415 .15624 L
.16254 .14335 L
.17284 .13805 L
.18221 .13451 L
.18704 .13319 L
.18969 .13261 L
.19216 .13217 L
.19445 .13184 L
.19654 .1316 L
.19773 .1315 L
.19886 .13142 L
.20005 .13136 L
.20135 .13132 L
.20203 .13131 L
.20276 .13131 L
.20345 .13131 L
.20409 .13132 L
.2053 .13136 L
.20657 .13142 L
.20794 .13151 L
.20922 .13163 L
.21213 .13198 L
.21466 .13239 L
.21696 .13285 L
.22214 .13418 L
.22694 .13578 L
.23205 .13786 L
.24122 .14257 L
.26198 .15762 L
.28145 .17678 L
.29973 .19856 L
.33842 .25355 L
.37956 .31854 L
.41919 .37995 L
.45729 .4323 L
.47854 .45722 L
.49785 .47679 L
.51817 .49402 L
.5369 .50683 L
.55608 .5169 L
.56619 .521 L
.57688 .52446 L
.58632 .52679 L
.59152 .5278 L
.59646 .52857 L
.60103 .52913 L
Mistroke
.60345 .52937 L
.60603 .52958 L
.60841 .52973 L
.61056 .52984 L
.6116 .52988 L
.61273 .52991 L
.61379 .52994 L
.61477 .52996 L
.61604 .52997 L
.61724 .52997 L
.61831 .52997 L
.61948 .52995 L
.62076 .52993 L
.62211 .52989 L
.62453 .52979 L
.62676 .52967 L
.62886 .52953 L
.63363 .52911 L
.63883 .52849 L
.64359 .5278 L
.65431 .52578 L
.67327 .52075 L
.69399 .51336 L
.7346 .49404 L
.7737 .47061 L
.81525 .44178 L
.85528 .41112 L
.8938 .3797 L
.93477 .34493 L
.97422 .31073 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`0fooooo`Goo`00ooooool:ooooo`008Oooool00ol0003oooooooooo`0`ooooo`_o
00000ooo003oooooo`Oooooo000Qooooo`03o`000?oooooooooo02_ooooo0_oo00000ooooooo0000
o`00000;ooooo`?o00000ooo003oooooo`Cooooo000Qooooo`?o0000:_ooool01?oo003o0000o`00
0?l0000@ooooo`?o000000?oo`00ooooooooool0ooooool1ooooo`008Oooool00ol0003ooooooooo
o`0Xooooo`;oo`0000?o0000ooooooooool05?ooool00ol0003oo`00ooooo`3oooooo`7ooooo000Q
ooooo`03o`000?oooooooooo02Oooooo00?oo`00ooooooooool06Oooool00ooo003oooooooooo`3n
ooooo`008Oooool00ol0003oooooooooo`0Uooooo`;oo`007Oooool00ooo003o0000ooooo`3moooo
o`008Oooool00ol0003oooooooooo`0Tooooo`03ool00?oooooooooo01oooooo00?o0000oooooooo
ool0noooool0027ooooo00?o0000ooooooooool08_ooool2ool002?ooooo00?o0000ooooooooool0
n_ooool0027ooooo00?o0000ooooooooool08Oooool00ooo003oooooooooo`0Tooooo`03o`000?oo
oooooooo0?Wooooo000Qooooo`03o`000?oooooooooo023ooooo00?oo`00ooooooooool09_ooool0
0ol0003oooooooooo`3hooooo`008Oooool3o`0001oooooo00?oo`00ooooooooool0:?ooool00ol0
003oooooooooo`3gooooo`008Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool0m_ooool0027ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oo003ooooo0?Gooooo000Qooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0;Oooool00ol0003oo`00ooooo`3dooooo`008Oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo02oooooo00?oo`00ooooooooool0loooool000Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0aooooo`03ool00?oooooooooo0?;ooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03?ooooo00?oo`00ooooooooool0lOoo
ool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_oo
ool3o`0001Wooooo00?o0000ooooooooool0=Oooool00ooo003oooooooooo`3`ooooo`001oooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooooooo
o`0Gooooo`03ool00?l0003ooooo03Sooooo00?oo`00ooooooooool0koooool000Oooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooo
ooooo`0Gooooo`03ool00?oooooooooo03Wooooo00?oo`00ooooooooool0k_ooool000Oooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
5oooool00ooo003oooooooooo`0jooooo`03ool00?oooooooooo0>gooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Kooooo
00?oo`00ooooooooool0>oooool00ooo003oooooooooo`3]ooooo`001oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool0
?Oooool00ooo003oooooooooo`3/ooooo`008Oooool00ol0003oooooooooo`0Dooooo`03ool00?oo
oooooooo03kooooo00?oo`00o`000?ooool0k?ooool0027ooooo00?o0000ooooooooool04oooool0
0ooo003oooooooooo`10ooooo`03ool00?oooooooooo0>_ooooo000Qooooo`?o00004_ooool00ooo
003oooooooooo`12ooooo`03o`000?oooooooooo0>[ooooo000Qooooo`03o`000?oooooooooo01;o
oooo00?oo`00ooooooooool0@oooool00ol0003oooooooooo`3Yooooo`008Oooool00ol0003ooooo
ooooo`0Aooooo`03ool00?oooooooooo04Gooooo00?o0000ooooooooool0j?ooool0027ooooo00?o
0000ooooooooool04?ooool00ooo003oooooooooo`16ooooo`03o`000?oooooooooo0>Sooooo000Q
ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool0B?ooool00ol0003oooooooooo`3W
ooooo`008Oooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo04[ooooo00?o0000oooo
ooooool0i_ooool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo0>Kooooo000Qooooo`?o00003Oooool00ol0003oooooooooo`1<ooooo`03o`00
0?oooooooooo0>Gooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0C_oo
ool00ooo003oooooooooo`3Tooooo`008Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo04oooooo00?oo`00o`000?ooool0i?ooool0027ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`1Aooooo`03ool00?oooooooooo0>?ooooo000Qooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0Doooool00ooo003oooooooooo`3Rooooo`008Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo05Cooooo00?oo`00ooooooooool0hOooool0027ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1Eooooo`03ool00?oooooooooo0>7ooooo000Q
ooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool0Eoooool00ooo003oooooooooo`3P
ooooo`008Oooool3o`0000Oooooo00?oo`00ooooooooool0Eoooool00ooo003oooooooooo`3Poooo
o`008Oooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo03Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00?oo`00
ooooooooool0:oooool4o`000003oa0@4?oooooooooo03_ooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03gooooo1Ol0000Kooooo`008Oooool0
0ol0003oooooooooo`05ooooo`03ool00?oooooooooo03Gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0?ooooo`03ool00?oooooooooo02cooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`0looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0027ooooo00?o0000ooooooooool01Ooo
ool00ooo003oooooooooo`0eooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooo
ooooo`0>ooooo`03ool00?oooooooooo02cooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo03cooooo00?oV9RHob4Q8Oo^k^h07?ooool0027ooooo00?o
0000ooooooooool01?ooool00ooo003oooooooooo`0fooooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`0@ooooo`03ool00?oooooooooo02_ooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h0
6oooool0027ooooo00?o0000ooooooooool00oooool00ol0003oo`00ooooo`0gooooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<017ooooo00?oo`00oooooooo
ool0:oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c010ooooo`03ogMgMomVIVKooooo01[ooooo000Qooooo`03o`000?oooooooooo00?o
oooo00?oo`00ooooooooool0=oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool05?ooool00ooo003oooooooooo`0Zooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Wooooo000Qooooo`?o
00000_ooool00ooo003oooooooooo`0hooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo03oooooo00Go0000okZj^_ooooooV9RHoa0@400K
ooooo`008Oooool01_l0003ooooooooooooooooo0000ool003[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00005?ooool00ol0003oooooooooo`0Wooooo`03oeEEEOmVIVKo000003oooooo
00?oEEEEofIVI_l000003Oooool4o`0003kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Kooooo`00
8Oooool01Ol0003oooooooooooooooooo`0006Gooooo00?o0000ooooooooool0f_ooool0027ooooo
00Go0000oooooooooooo0000ool0001Uooooo`03o`000?oooooooooo0=[ooooo000Qooooo`04o`00
0?oooooo0000ool006Oooooo00?o0000ooooooooool0fOooool0027ooooo00?o0000oooooooo0000
J?ooool00ol0003oooooooooo`3?ooooo`;o00000_ooool2o`0000Cooooo000Qooooo`;o0000J_oo
ool00ol0003oooooooooo`3>ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool001[ooooo
ool0000bo`000003ool00?l0003o000000Go00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`00
8Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ool00?ooool0
1oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2_ooool00ol0003oo`00o`00000Cooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`06ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`04o`00
0?oo003oooooo`0001?ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000oooooooo
ool0Joooool00ol0003oo`00ooooo`2eooooo`03o`000?oo003ooooo01Cooooo0_l00002ooooo`;o
00001?ooool0027ooooo00?o0000ooooooooool0K?ooool00ooo003oooooooooo`2cooooo`03o`00
0?oooooooooo01oooooo000Qooooo`03o`000?oooooooooo06cooooo00?o0000ool00?ooool0/_oo
ool00ol0003oooooooooo`0Pooooo`008Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo003o
oooo0;3ooooo00?o0000ooooooooool08Oooool0027ooooo00?o0000ooooooooool0K_ooool00ooo
003oooooooooo`2^ooooo`03o`000?oooooooooo02;ooooo000Qooooo`?o0000K_ooool00ol0003o
o`00ooooo`2]ooooo`03o`000?oooooooooo02?ooooo000Qooooo`03o`000?oooooooooo06oooooo
00?o0000ool00?ooool0Zoooool00ol0003oooooooooo`0Tooooo`008Oooool00ol0003ooooooooo
o`1`ooooo`03ool00?oooooooooo0:Wooooo00?oo`00ooooooooool09Oooool0027ooooo00?o0000
ooooooooool0L?ooool00ol0003oo`00ooooo`2Xooooo`03ool00?oooooooooo02Kooooo000Qoooo
o`03o`000?oooooooooo077ooooo00?oo`00ooooooooool0YOooool2ool002Wooooo000Qooooo`03
o`000?oooooooooo07;ooooo00?oo`00ooooooooool0Xoooool00ooo003oooooooooo`0Yooooo`00
8Oooool00ol0003oooooooooo`1cooooo`03ool00?oooooooooo0:7ooooo00?oo`00ooooooooool0
:_ooool0027ooooo0ol0001cooooo`03o`000?oooooooooo0:3ooooo00?oo`00ooooooooool0:ooo
ool0027ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`2Mooooo`;oo`00;_ooool0
027ooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`2Kooooo`03ool00?l0003ooooo
02kooooo000Qooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0V_ooool00ooo003o
ooooooooo`0_ooooo`008Oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo09Sooooo
00?oo`00ooooooooool0<?ooool0027ooooo00?o0000ooooooooool0Moooool00ol0003ooooooooo
o`2Fooooo`03ool00?oooooooooo037ooooo000Qooooo`03o`000?oooooooooo07Oooooo00?o0000
ooooooooool0UOooool00ol0003oooooooooo`0booooo`008Oooool00ol0003oooooooooo`1hoooo
o`03o`000?oooooooooo09;ooooo0_l0000eooooo`008Oooool3o`0007Wooooo00?oo`00oooooooo
ool0T?ooool00ol0003oooooooooo`0eooooo`008Oooool00ol0003oooooooooo`1iooooo`03ool0
0?oooooooooo08oooooo00?o0000ooooooooool0=_ooool0027ooooo00?o0000ooooooooool0N_oo
ool00ooo003oooooooooo`2=ooooo`03o`000?oooooooooo03Oooooo000Qooooo`03o`000?oooooo
oooo07_ooooo00?oo`00ooooooooool0Roooool00ol0003oooooooooo`0hooooo`008Oooool00ol0
003oooooooooo`1kooooo`03o`000?oo003ooooo08Sooooo0_oo00000ol0003oooooooooo`0ioooo
o`008Oooool00ol0003oooooooooo`1looooo`03ool00?oooooooooo08Kooooo00?oo`00o`000?oo
ool0??ooool0027ooooo00?o0000ooooooooool0OOooool00ooo003oooooooooo`24ooooo`03ool0
0?l0003ooooo03gooooo000Qooooo`?o0000O_ooool00ooo003oooooooooo`22ooooo`03ool00?l0
003ooooo03kooooo000Qooooo`03o`000?oooooooooo07kooooo00?o0000ool00?ooool0POooool0
0ooo003o0000ooooo`0oooooo`008Oooool00ol0003oooooooooo`1oooooo`03o`000?oo003ooooo
07kooooo0_oo00000ol0003oooooooooo`0oooooo`008Oooool00ol0003oooooooooo`20ooooo`03
ool00?oooooooooo07cooooo00?oo`00o`000?ooool0@_ooool0027ooooo00?o0000ooooooooool0
P?ooool00ol0003oo`00ooooo`1kooooo`03ool00?l0003ooooo04?ooooo0007ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03
o`000?oooooooooo087ooooo00?o0000ool00?ooool0NOooool00ooo003o0000ooooo`14ooooo`00
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?o
oooo00?o0000ooooooooool0P_ooool00ol0003oo`00ooooo`1gooooo`03ool00?oooooooooo04Go
oooo0007ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o
0000Poooool00ol0003oooooooooo`1eooooo`03ool00?oooooooooo04Kooooo0007ooooo`05o`00
0?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo08?o
oooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`17ooooo`001oooool01Ol0003ooooo
oooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo
08Cooooo00?o0000ooooooooool0LOooool2o`0004[ooooo0007ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08Gooooo00?o0000oooo
ooooool0Koooool00ol0003oooooooooo`1:ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool0Boooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00001Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo06_ooooo0_l0001>oooo
o`008Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo06Oooooo0_oo00000ol0003o
ooooooooo`1>ooooo`008Oooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo06Gooooo
00?oo`00ooooool00000DOooool0027ooooo0ol00028ooooo`03o`000?ooooooo`0006Cooooo00?o
o`00o`000?l00000D_ooool0027ooooo00?o0000ooooooooool0ROooool00ol0003oo`00ooooo`1R
ooooo`03ool00?l0003ooooo05?ooooo000Qooooo`03o`000?oooooooooo08[ooooo00?o0000ool0
0?ooool0Goooool2ool00003o`000?oooooooooo05?ooooo000Qooooo`03o`000?oooooooooo08_o
oooo00?o0000ool00?ooool0GOooool00ooo003o0000o`00001Fooooo`008Oooool00ol0003ooooo
ooooo`2<ooooo`03o`000?oo003ooooo05_ooooo00?oo`00o`000?ooool0Eoooool0027ooooo00?o
0000ooooooooool0SOooool00ol0003oo`00ooooo`1Iooooo`03ool00?l0003ooooo05Sooooo000Q
ooooo`03o`000?oooooooooo08kooooo00?o0000ool00?ooool0E_ooool2ool00003o`000?oooooo
oooo05Sooooo000Qooooo`?o0000Soooool00ol0003oo`00ooooo`1Cooooo`;oo`0000?o0000oooo
ooooool0F_ooool0027ooooo00?o0000ooooooooool0T?ooool00ol0003oo`00ool0001Aooooo`;o
0000G_ooool0027ooooo00?o0000ooooooooool0TOooool2o`0000;oo`00COooool2o`00063ooooo
000Qooooo`03o`000?oooooooooo09?ooooo00?o0000oooooooo0000Boooool00ol0003ooooooooo
o`1Pooooo`008Oooool00ol0003oooooooooo`2Dooooo`;o0000BOooool2o`0006?ooooo000Qoooo
o`03o`000?oooooooooo09Kooooo00?o0000ooooooooool0A?ooool2o`0006Gooooo000Qooooo`03
o`000?oooooooooo09Oooooo00?o0000ooooooooool0@?ooool3ool006Oooooo000Qooooo`03o`00
0?oooooooooo09Sooooo0_l0000nooooo`;oo`0000?o0000ooooooooool0Ioooool0027ooooo0ol0
002Jooooo`03o`000?oooooooooo03Wooooo0_oo00000ol0003oooooooooo`1Yooooo`008Oooool0
0ol0003oooooooooo`2Kooooo`;o0000=oooool2ool00003o`000?oooooooooo06_ooooo000Qoooo
o`03o`000?oooooooooo09gooooo0ooo000booooo`;oo`0000?o0000ooooooooool0KOooool0027o
oooo00?o0000ooooooooool0W_ooool2o`0000;oo`00;_ooool2ool000;o0000L?ooool0027ooooo
00?o0000ooooooooool0X?ooool2o`0000;oo`00:_ooool2ool000;o0000L_ooool0027ooooo00?o
0000ooooooooool0X_ooool2o`0000;oo`00:?ooool2o`0007Cooooo000Qooooo`03o`000?oooooo
oooo0:Cooooo0_l000000ooo003oooooooooo`0Rooooo`?o0000M_ooool0027ooooo0ol0002Woooo
o`?oo`007_ooool3o`0007Wooooo000Qooooo`03o`000?oooooooooo0:[ooooo0ooo000Dooooo`Co
o`000ol0001looooo`008Oooool00ol0003oooooooooo`2]ooooo`?o00001?ooool=ool000Co0000
Ooooool0027ooooo00?o0000ooooooooool0/?ooool?o`0008Gooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo
0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGo
oooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_oo
ool00ol0003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo002Tooooo`03ogMgMomVIVKooooo01Oooooo00?oIVIVogMgMooo
ool0Yoooool008?ooooo0ol0000Dooooo`03ob4Q8OoMgMgooooo00Kooooo00?ogMgMoa0@4?o^k^h0
6?ooool00oo^k^ko410@omgMg@2Wooooo`00Noooool01on7QhOo0000oeEEEOmVIVKo0000oc8b<_o^
k^h00_ooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool00onH
V9SoEEEEooooo`06ooooo`03oeEEEOnHV9Sooooo00;ooooo1Ol00009ooooo`03oeEEEOnYZJWooooo
00;ooooo00Ko^[ZjodA4A?ooooooooooohN7QomVIVHDooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0MOooool007_ooooo
00Oo410@omgMgOmgMgOo8B4Qoooooon7QhOoIVIV00;ooooo00?o0000ooooooooool02oooool01Ol@
413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000omgMgOooool01Oooool00ol0003oooooooooo`02
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P;o
oooo00?ok^k^o`000?ooool02oooool6o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0M?ooool0
07_ooooo00Oo0000oooooooMgMgo<S8booooooo^k^ko410@00;ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`06ooooo`;oMgMg1_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ
8B7ok^k^00cooooo00Co410@omgMgOoooooo00001?ooool00ol0003oooooooooo`0Booooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo07?o
oooo001kooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Co0000oooooooooooo00003Oooool00ol0
003oooooooooo`06ooooo`03onk^k_l@413ok^k^00Gooooo00?o<S8booooooooool01?ooool00onH
V9So8B4Qonk^kP0;ooooo`04ohN7QomVIVKoooooo`0000Cooooo00?o0000ooooooooool02_ooool6
o`0000;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool0M?ooool007_ooooo00?ogMgMob4Q8Oo^k^h00oooool01?l0003oooooo`000?l0
000=ooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool00ol0003ok^k^oooo
o`05ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo00000oooool00oo^k^ko0000
ooooo`0Cooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`0MOooool007cooooo00?oV9RHogMgMoooool00_ooool00ol0003o
ooooooooo`0<ooooo`03oa0@4?l0003o000000?o00001_ooool00ooMgMgo410@ooooo`04ooooo`03
oeEEEOmgMgOooooo00Kooooo00?o0000ooooooooool02?ooool7o`000003oooooomgMgOoEEEE01Co
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0Moooool009;ooooo00?o0000ooooooooool02?ooool00omEEEGoV9RHooooo`03ooooo`03
omgMgOl@413ok^k^00;ooooo00Go0000okZj^_ooooooV9RHoa0@400Aooooo`03onk^k_l@413ogMgM
01Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?oo
ool00ol0003oooooooooo`1gooooo`00T_ooool00ol0003oooooooooo`08ooooo`03okZj^_m4A4Co
oooo00Cooooo00WoMgMgofIVI_oooooooooooiRHV?l@413o0000ob4Q8Oo<c<`04Oooool00omVIVKo
MgMgooooo`0Dooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l0001fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .22809 L
.08255 .19129 L
.10458 .15782 L
.11448 .14552 L
.12507 .13442 L
.13499 .12602 L
.14415 .12002 L
.14911 .11749 L
.15437 .11536 L
.15964 .11379 L
.16265 .11315 L
.16399 .11292 L
.16546 .11271 L
.1668 .11256 L
.16805 .11246 L
.16925 .11238 L
.17052 .11233 L
.17178 .11232 L
.17296 .11234 L
.17401 .11237 L
.17516 .11244 L
.17642 .11254 L
.1778 .11269 L
.1806 .1131 L
.18318 .11362 L
.1856 .11422 L
.1906 .11582 L
.19605 .11808 L
.20595 .12357 L
.21559 .13051 L
.22451 .13824 L
.26377 .18409 L
.30152 .23854 L
.34173 .29654 L
.38041 .34459 L
.40006 .36475 L
.42155 .38326 L
.44231 .39766 L
.46118 .40792 L
.48079 .41591 L
.49156 .41924 L
.50174 .42173 L
.51146 .42356 L
.51678 .42434 L
.52175 .42494 L
.52634 .42539 L
.53054 .4257 L
.53277 .42584 L
.5352 .42596 L
Mistroke
.53777 .42606 L
.53895 .42609 L
.5402 .42612 L
.54154 .42615 L
.54277 .42617 L
.54409 .42618 L
.54484 .42618 L
.54553 .42618 L
.5468 .42618 L
.54796 .42617 L
.5486 .42616 L
.54929 .42615 L
.55055 .42613 L
.55291 .42606 L
.55542 .42598 L
.55992 .42576 L
.56507 .42542 L
.5699 .42501 L
.5809 .42381 L
.60112 .42068 L
.61964 .41695 L
.65932 .40694 L
.69748 .39568 L
.73809 .38286 L
.77719 .37025 L
.81874 .35694 L
.85877 .34438 L
.89729 .33258 L
.93826 .32028 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .23002 L
.08255 .19216 L
.10458 .15723 L
.11448 .14436 L
.12507 .13279 L
.13499 .12411 L
.14415 .11799 L
.14911 .11545 L
.15437 .11334 L
.15691 .11254 L
.15964 .11183 L
.16121 .1115 L
.16265 .11124 L
.16401 .11104 L
.16546 .11086 L
.16615 .11079 L
.1668 .11074 L
.16802 .11066 L
.16916 .11062 L
.17039 .1106 L
.17104 .11061 L
.17176 .11062 L
.1725 .11065 L
.1732 .11068 L
.17445 .11077 L
.17578 .1109 L
.17842 .11126 L
.18092 .11173 L
.1856 .11294 L
.19019 .11454 L
.19525 .11677 L
.20551 .12266 L
.22393 .13749 L
.24327 .15796 L
.26413 .18417 L
.30527 .24235 L
.34489 .298 L
.383 .34426 L
.40425 .36551 L
.42356 .38166 L
.44388 .39538 L
.46261 .40517 L
.48179 .41253 L
.4919 .41541 L
.50259 .41777 L
.51203 .41931 L
.51732 .41996 L
.52216 .42043 L
.52666 .42077 L
Mistroke
.52903 .42091 L
.53156 .42103 L
.53399 .42112 L
.53619 .42118 L
.53725 .4212 L
.5384 .42122 L
.53948 .42123 L
.54048 .42123 L
.54175 .42123 L
.54295 .42123 L
.54402 .42122 L
.54519 .42121 L
.54647 .42118 L
.54782 .42115 L
.55024 .42108 L
.55457 .4209 L
.55934 .42063 L
.56448 .42025 L
.57001 .41975 L
.58002 .41861 L
.6001 .41558 L
.62121 .4115 L
.65937 .40245 L
.69998 .39117 L
.73908 .37926 L
.78063 .36603 L
.82067 .35332 L
.85918 .34162 L
.90015 .32988 L
.93961 .31886 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool09_ooool00ooo003o0000o`000007o`000?oooooo5Oooool0027ooooo00?o0000oooo
ooooool09?ooool2ool00003o`000?oooooooooo00Oooooo00?o0000ool00?oo00000_oo003ooooo
oa3ooooo000Qooooo`?o00008_ooool2ool000;o00003Oooool2o`000003ool00?oooooooooo0?oo
oooo3Oooool0027ooooo00?o0000ooooooooool08Oooool00ooo003oooooooooo`0Booooo`;oo`00
ooooool=ooooo`008Oooool00ol0003oooooooooo`0Oooooo`;oo`005_ooool00ol0003oo`00oooo
o`3oooooo`_ooooo000Qooooo`03o`000?oooooooooo01kooooo00?oo`00o`000?ooool05oooool0
0ol0003oo`00ooooo`3oooooo`[ooooo000Qooooo`03o`000?oooooooooo01gooooo00?oo`00o`00
0?ooool06Oooool00ol0003oo`00ooooo`3oooooo`Wooooo000Qooooo`03o`000?oooooooooo01go
oooo00?oo`00ooooooooool06oooool00ooo003oooooooooo`3oooooo`Oooooo000Qooooo`03o`00
0?oooooooooo01cooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`3oooooo`Kooooo
000Qooooo`?o00006oooool00ooo003oooooooooo`0Nooooo`03ool00?oooooooooo0?oooooo1_oo
ool0027ooooo00?o0000ooooooooool06_ooool00ooo003oooooooooo`0Pooooo`03ool00?oooooo
oooo0?oooooo1Oooool0027ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo0?oooooo1?ooool0027ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo0?oooooo0oooool0027ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo0?oooooo0_ooool0027ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0?oooooo0Ooo
ool0027ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo0?oooooo000Qooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`3oooooo`008Oooool3o`0001Gooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`3nooooo`008Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02cooooo
00?o0000ool00?ooool0oOooool0027ooooo00?o0000ooooooooool05?ooool00ooo003ooooooooo
o`0^ooooo`03ool00?oooooooooo0?cooooo000Qooooo`03o`000?oooooooooo01?ooooo00?o0000
ool00?ooool0<?ooool00ooo003oooooooooo`3kooooo`008Oooool00ol0003oooooooooo`0Coooo
o`03ool00?oooooooooo037ooooo00?oo`00ooooooooool0n_ooool000Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000
ooooooooool04_ooool00ooo003oooooooooo`0cooooo`03ool00?oooooooooo0?Wooooo0007oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool0
0ol0003oooooooooo`0Booooo`03ool00?oooooooooo03?ooooo00?oo`00ooooooooool0nOooool0
00Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3
o`00017ooooo00?oo`00ooooooooool0=Oooool00ooo003oooooooooo`3hooooo`001oooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0@
ooooo`03ool00?oooooooooo03Oooooo00?oo`00ooooooooool0moooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`0@ooooo`03ool00?oooooooooo03Oooooo00?o0000ool00?ooool0moooool000Oooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03ooo
ool00ooo003oooooooooo`0iooooo`03ool00?oooooooooo0?Kooooo0007ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o
0000ool00?ooool0>oooool00ooo003oooooooooo`3eooooo`001oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0??oo
ool00ooo003oooooooooo`3dooooo`008Oooool00ol0003oooooooooo`0=ooooo`03ool00?oooooo
oooo03gooooo00?o0000ool00?ooool0m?ooool0027ooooo00?o0000ooooooooool03?ooool00ol0
003oo`00ooooo`0oooooo`03o`000?oooooooooo0??ooooo000Qooooo`?o00003?ooool00ooo003o
ooooooooo`10ooooo`03o`000?oooooooooo0?;ooooo000Qooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0@Oooool00ol0003oooooooooo`3booooo`008Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0lOooool0027ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo0?3ooooo000Qoooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`3_oooo
o`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool0koooool0027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`18ooooo`03o`00
0?oooooooooo0>kooooo000Qooooo`?o00002?ooool00ol0003oooooooooo`19ooooo`03ool00?oo
oooooooo0>gooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0B_ooool0
0ooo003oooooooooo`3]ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
04_ooooo00?oo`00ooooooooool0k?ooool0027ooooo00?o0000ooooooooool01_ooool00ol0003o
o`00ooooo`1<ooooo`03ool00?l0003ooooo0>cooooo000Qooooo`03o`000?oooooooooo00Kooooo
00?o0000ool00?ooool0COooool00ooo003o0000ooooo`3[ooooo`008Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oo003ooooo04oooooo00?oo`00ooooooooool0j_ooool0027ooooo00?o0000
ooooooooool01Oooool00ol0003oo`00ooooo`1@ooooo`03ool00?oooooooooo0>Wooooo000Qoooo
o`03o`000?oooooooooo00Cooooo00?o0000ool00?ooool0DOooool00ooo003o0000ooooo`3Yoooo
o`008Oooool3o`0000Cooooo00?o0000ool00?ooool0D_ooool00ooo003oooooooooo`3Xooooo`00
8Oooool00ol0003oooooooooo`03ooooo`03o`000?oo003ooooo03Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Oooooo00?oo`00oooo
ooooool0<oooool4o`000003oa0@4?oooooooooo03_ooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03gooooo1Ol0000Kooooo`008Oooool00ol0
003oooooooooo`03ooooo`03o`000?oo003ooooo03Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`06ooooo`03ool00?l0003ooooo03Gooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0l
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0027ooooo00?o0000ooooooooool00oooool0
0ooo003oooooooooo`0gooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`06ooooo`03ool00?l0003ooooo03Cooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo03cooooo00?oV9RHob4Q8Oo^k^h07?ooool0027ooooo00?o0000
ooooooooool00_ooool00ol0003oo`00ooooo`0hooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`08ooooo`03ool00?oooooooooo03?ooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06ooo
ool0027ooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0hooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00[ooooo00?oo`00ooooooooool0
<_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c010ooooo`03ogMgMomVIVKooooo01[ooooo000Qooooo`06o`000?ooooooooooooooool0
003oo`00>_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Wooooo000Qooooo`?o000000?oooooool0
0?ooool0>_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0oooooo`05o`000?nj^[[ooooooiRHV?l@41006oooool0027ooooo00Go0000
oooooooooooo0000ool0000kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000gooooo
00?o0000ooooooooool0;_ooool00omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo
1?l0000nooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`06oooool0027ooooo00Co0000oooooooooooo
o`00Goooool00ol0003oooooooooo`3Qooooo`008Oooool00ol0003oooooo`00001Qooooo`03o`00
0?oooooooooo0>3ooooo000Qooooo`03o`000?oooooo0000067ooooo00?o0000ooooooooool0h?oo
ool0027ooooo0_l0001Sooooo`03o`000?oooooooooo0=Gooooo0_l00002ooooo`;o00001?ooool0
027ooooo0_l0001Tooooo`03o`000?oooooooooo0=Cooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oM
gMd4ooooo`006_oooom^o`000003ool00?l0003o00000;oo00000_oo0007o`0000cooooo00CogMgM
o`000?l@413oc<c<1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool00ooo003o0000ooooo`0=
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08
ooooo`?oo`0000?oooooo`000?ooool04_ooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000ool00?oo00001?ooool0
0ol0003oooooooooo`0Aooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03o`000?oooooo
oooo06Kooooo00?oo`00ooooooooool0]?ooool3o`0001[ooooo0_l00002ooooo`;o00001?ooool0
027ooooo00?o0000ooooooooool0Ioooool00ooo003oooooooooo`2_ooooo`Co00009oooool0027o
oooo00?o0000ooooooooool0J?ooool00ooo003oooooooooo`2Yooooo`?oo`000_l0000[ooooo`00
8Oooool00ol0003oooooooooo`1Yooooo`03ool00?oooooooooo0:Gooooo0ooo0002o`0002kooooo
000Qooooo`03o`000?oooooooooo06Wooooo00?o0000ool00?ooool0XOooool4ool000;o0000<Ooo
ool0027ooooo0ol0001Zooooo`03o`000?oo003ooooo09cooooo1?oo0003o`0003Cooooo000Qoooo
o`03o`000?oooooooooo06_ooooo00?o0000ool00?ooool0VOooool2ool000?o0000>?ooool0027o
oooo00?o0000ooooooooool0K?ooool00ol0003oo`00ooooo`2Eooooo`Co0000??ooool0027ooooo
00?o0000ooooooooool0KOooool00ol0003oo`00ooooo`2Aooooo`?o0000@?ooool0027ooooo00?o
0000ooooooooool0KOooool00ol0003oo`00ooooo`2;ooooo`?oo`000ol00013ooooo`008Oooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo08Oooooo0ooo0003o`0004Kooooo000Qoooo
o`03o`000?oooooooooo06oooooo00?o0000ooooooooool0Poooool3ool000?o0000BOooool0027o
oooo0ol0001`ooooo`03o`000?oooooooooo07oooooo0ooo0003o`0004cooooo000Qooooo`03o`00
0?oooooooooo077ooooo00?o0000ooooooooool0Noooool3ool000;o0000D?ooool0027ooooo00?o
0000ooooooooool0L_ooool00ol0003oooooooooo`1iooooo`03ool00?l0003o000005?ooooo000Q
ooooo`03o`000?oooooooooo07?ooooo0_l0001fooooo`?o0000E_ooool0027ooooo00?o0000oooo
ooooool0MOooool00ol0003oo`00ooooo`1_ooooo`Co0000FOooool0027ooooo00?o0000oooooooo
ool0M_ooool00ol0003oo`00ooooo`1Yooooo`;oo`000ol0001Mooooo`008Oooool00ol0003ooooo
ooooo`1gooooo`03o`000?oo003ooooo06Gooooo0ooo0002o`00063ooooo000Qooooo`03o`000?oo
oooooooo07Sooooo00?o0000ool00?ooool0HOooool3ool000;o0000Hoooool0027ooooo0ol0001i
ooooo`03o`000?oo003oo`0005gooooo0ooo0002o`0006Kooooo000Qooooo`03o`000?oooooooooo
07[ooooo0_l00002ool005Sooooo0ooo0002o`0006Wooooo000Qooooo`03o`000?oooooooooo07co
oooo00?o0000oooooooo0000EOooool2ool000;o0000K?ooool0027ooooo00?o0000ooooooooool0
OOooool2o`0000;oo`00DOooool3o`0006oooooo000Qooooo`03o`000?oooooooooo07oooooo00?o
0000oooooooo0000COooool3o`0007;ooooo000Qooooo`03o`000?oooooooooo083ooooo0_l00000
0ooo003oooooooooo`14ooooo`;oo`0000Coooooo`000?l0003o0000MOooool0027ooooo00?o0000
ooooooooool0P_ooool2o`0004;ooooo0ooo0003o`0007Sooooo000Qooooo`?o0000Q?ooool2o`00
03cooooo1?oo0003o`0007_ooooo000Qooooo`03o`000?oooooooooo08Kooooo0_l0000eooooo`Go
o`001?l0001nooooo`008Oooool00ol0003oooooooooo`28ooooo`;o0000<Oooool2ool000Go0000
P_ooool0027ooooo00?o0000ooooooooool0R_ooool2o`0000?oo`00:_ooool4o`0008Oooooo000Q
ooooo`03o`000?oooooooooo08cooooo0ol00007ool001Sooooo0ooo0004ooooo`Co0000Roooool0
00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Cooooo00?o0000ooooooooool0Soooool3o`0000Cooooo1Ooo0005ooooo`koo`0000?o
ooooo`000?l000001?l0002?ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0T_ooool7o`00017ooooo1Ol0
002Eooooo`001oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_oo
ool3o`0009Wooooo4Ol0002Jooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0
oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co0000
00?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3o`00
0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGo
oooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEE
ofIVI_l000001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z?oo
ool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:?ooooo0027ooooo`?o00004oooool0
0olQ8B7ogMgMooooo`07ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Xoooool0
07kooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool02ooo
ool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00?oV9RHoeEEEOooool01oooool01?mEEEGoV9RH
ooooooooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool00onj^[[oA4A4ooooo`02ooooo`03
ohN7QomVIVKooooo01;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnH
V9So410@o`000?lb<S;oc<c<07_ooooo001nooooo`07oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIV
IP03ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`00
0?oMgMgooooo00Kooooo00Wo0000oooooooooooooooooiRHV?lQ8B7ok^k^oooooom4A4@02_ooool0
1_mEEEGoV9RHoooooooooooo410@okZj^P?ooooo00?ok^k^o`000?ooool02oooool6o`000006oooo
oomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P1k
ooooo`00O_ooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@41000oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Gooooo0_mgMgL7ooooo`03oc8b<_oooooooooo00;ooooo00?o
V9RHob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool00005ooooo`03o`000?oooooooooo017ooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo07Wooooo001nooooo`04oeEE
EOnYZJWoooooo`0000;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo
00Gooooo00?ok^k^oa0@4?o^k^h01_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^
00_ooooo00CoQhN7ofIVI_oooooo00001Oooool00ol0003oooooooooo`0:ooooo`Ko000000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ojVYZOl@413ooooo07[ooooo001noooo
o`03omgMgOlQ8B7ok^k^00?ooooo00?o0000ooooooooool00_l0000=ooooo`03o`000?oooooooooo
00Kooooo00?oEEEEoiRHV?ooool01Oooool00ol0003ok^k^ooooo`04ooooo`03ogMgMomVIVKooooo
00[ooooo00CogMgMoa0@4?oooooo00001?ooool00oo^k^ko0000ooooo`0Booooo`05o`000?oooooo
ooooooooool000003Oooool00ol@413o0000okZj^P1kooooo`00Ooooool00onHV9SoMgMgooooo`02
ooooo`03o`000?oooooooooo00gooooo00?o410@o`000?l000000ol00005ooooo`03omgMgOl@413o
oooo00Gooooo00?oEEEEogMgMoooool01Oooool00ol0003oooooooooo`08ooooo`Oo00000_ooool0
0omgMgOoEEEEooooo`0Booooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qoooo
o`1jooooo`00U_ooool00ol0003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00WogMgM
oa0@4?o^k^koooooo`000?nj^[[ooooooiRHV?l@41004_ooool00oo^k^ko410@omgMg@0Cooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RHoooooonj^[[o000007_ooooo002Foooo
o`03o`000?oooooooooo00Oooooo00?o^[ZjodA4A?ooool01Oooool02?mgMgOoIVIVoooooonHV9So
410@o`000?lQ8B7oc<c<4_ooool00omVIVKoMgMgooooo`0Cooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnYZJWo410@o`000?l@413oZJVY07_ooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .2729 L
.06244 .23786 L
.08426 .20581 L
.0949 .19333 L
.10458 .18398 L
.11403 .17675 L
.12297 .17168 L
.12787 .16962 L
.1324 .16817 L
.13476 .16758 L
.13737 .16707 L
.13868 .16686 L
.14009 .16668 L
.14142 .16654 L
.14264 .16645 L
.14392 .16638 L
.14514 .16635 L
.14622 .16635 L
.1474 .16637 L
.14869 .16642 L
.14934 .16646 L
.15005 .16651 L
.15132 .16662 L
.15248 .16676 L
.15476 .16709 L
.15721 .16755 L
.16162 .16864 L
.16672 .17032 L
.17226 .1726 L
.18234 .1779 L
.20212 .19176 L
.22313 .2098 L
.26088 .24447 L
.28185 .2622 L
.30108 .27638 L
.32112 .28865 L
.33977 .29763 L
.35869 .30437 L
.3687 .30702 L
.37939 .30919 L
.38963 .31067 L
.39541 .31125 L
.39816 .31147 L
.40074 .31164 L
.40317 .31178 L
.4054 .31187 L
.40787 .31195 L
.40923 .31198 L
.41053 .31201 L
Mistroke
.41177 .31202 L
.41247 .31203 L
.4131 .31203 L
.41433 .31203 L
.41548 .31202 L
.41614 .31202 L
.41684 .31201 L
.41808 .31199 L
.41942 .31196 L
.42089 .31192 L
.42341 .31184 L
.42615 .31171 L
.43112 .31142 L
.43596 .31104 L
.44044 .31062 L
.46137 .30786 L
.48007 .3045 L
.50068 .30011 L
.54094 .29065 L
.57968 .28184 L
.59937 .27788 L
.62087 .27411 L
.64167 .27113 L
.66055 .26903 L
.67066 .26815 L
.6802 .26749 L
.69026 .26696 L
.69594 .26674 L
.69867 .26665 L
.70116 .26659 L
.70341 .26654 L
.70585 .26649 L
.70719 .26647 L
.70843 .26646 L
.7097 .26644 L
.71088 .26643 L
.71189 .26643 L
.71297 .26642 L
.71418 .26642 L
.71528 .26642 L
.71637 .26642 L
.71756 .26642 L
.7188 .26643 L
.71996 .26644 L
.72125 .26645 L
.72265 .26647 L
.72519 .26651 L
.72994 .26661 L
.73549 .26678 L
.74062 .26698 L
Mistroke
.75029 .26748 L
.75936 .26808 L
.77999 .26993 L
.80025 .27235 L
.81878 .27503 L
.85851 .28207 L
.89672 .29013 L
.93739 .29959 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .273 L
.06244 .23719 L
.08255 .20715 L
.09409 .19365 L
.10458 .18392 L
.1094 .18027 L
.11464 .1769 L
.11917 .17448 L
.12415 .17231 L
.12944 .17059 L
.13233 .16989 L
.13504 .16938 L
.13633 .16919 L
.13757 .16904 L
.13869 .16893 L
.13988 .16884 L
.14117 .16877 L
.14237 .16873 L
.1431 .16872 L
.1438 .16872 L
.14509 .16874 L
.14625 .16879 L
.1475 .16886 L
.14867 .16896 L
.14974 .16907 L
.15237 .16942 L
.15485 .16986 L
.15979 .17102 L
.16517 .17271 L
.17476 .17672 L
.18364 .18144 L
.22291 .21027 L
.26066 .24263 L
.30086 .27345 L
.31934 .28479 L
.33955 .2947 L
.35959 .30185 L
.37052 .30464 L
.38069 .30656 L
.38574 .30728 L
.39121 .3079 L
.39372 .30813 L
.39638 .30833 L
.39868 .30847 L
.40114 .3086 L
.40237 .30865 L
.40353 .30869 L
.40467 .30872 L
.40572 .30874 L
Mistroke
.40671 .30876 L
.40776 .30877 L
.40893 .30878 L
.41 .30878 L
.41125 .30878 L
.41241 .30877 L
.41367 .30875 L
.41501 .30872 L
.41726 .30865 L
.41973 .30855 L
.42499 .30825 L
.42996 .30786 L
.43928 .30687 L
.44931 .30547 L
.46021 .30362 L
.50104 .29455 L
.54036 .2846 L
.57816 .27574 L
.59918 .27154 L
.61842 .26826 L
.6385 .26549 L
.65716 .26354 L
.66633 .26281 L
.67612 .26218 L
.68171 .2619 L
.68698 .26169 L
.69171 .26154 L
.69418 .26148 L
.69684 .26142 L
.6994 .26138 L
.70174 .26135 L
.70287 .26134 L
.70409 .26133 L
.70525 .26133 L
.70633 .26133 L
.70756 .26132 L
.70873 .26133 L
.71 .26133 L
.71072 .26133 L
.71138 .26134 L
.71263 .26135 L
.71399 .26136 L
.71675 .2614 L
.71951 .26145 L
.72202 .26151 L
.72765 .26168 L
.73287 .26189 L
.73781 .26213 L
.74751 .26272 L
.7578 .26353 L
Mistroke
.77624 .26541 L
.79579 .26802 L
.8141 .27099 L
.85289 .27875 L
.89413 .28848 L
.93386 .2983 L
.97207 .30791 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`0001oooooo2Ol0003ooooooago
oooo000Qooooo`03o`000?oooooooooo01cooooo0ol000000oooooooo`00ool00008ool000;o0000
oooooolIooooo`008Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00cooooo0ooo
0002o`000?oooooo5_ooool0027ooooo00?o0000ooooooooool06Oooool2o`0001;ooooo0_oo0002
o`000?oooooo5?ooool0027ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Doooo
o`03ool00?oooooo00000?oooooo4oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0?oooooo4?ooool000Oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo01Gooooo0_oo000Looooo`03o`000?oooooooooo0?oooooo3oooool000Go00000_ooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`0001Cooooo00?oo`00
o`000?ooool07Oooool00ol0003oooooooooo`3oooooo`kooooo0007ooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01?ooooo00?oo`00
o`000?ooool07oooool2o`000?oooooo3_ooool000Oooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0Cooooo`03ool00?oo
oooooooo027ooooo00?o0000ooooooooool0ooooool;ooooo`001oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03ool00?oo
oooooooo02?ooooo0_l0003oooooo`_ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool09?oo
ool2ool00003o`000?oooooooooo0?oooooo2?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo003ooooo02Oooooo00?o
o`00o`000?ooool0ooooool8ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03ool00?oooooo
oooo02Sooooo00?oo`00o`000?ooool0ooooool7ooooo`008Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oo003ooooo02[ooooo0_oo003oooooo`Oooooo000Qooooo`?o00003_ooool00ol0003o
o`00ooooo`0]ooooo`03ool00?oooooooooo0?oooooo1?ooool0027ooooo00?o0000ooooooooool0
3_ooool00ooo003oooooooooo`0^ooooo`03ool00?oooooooooo0?oooooo0oooool0027ooooo00?o
0000ooooooooool03Oooool00ooo003oooooooooo`0`ooooo`03ool00?oooooooooo0?oooooo0_oo
ool0027ooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`0booooo`03ool00?oooooo
oooo0?oooooo0Oooool0027ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0doooo
o`03ool00?oooooooooo0?oooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0=Oooool00ooo003oooooooooo`3nooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo03Oooooo00?oo`00ooooooooool0oOooool0027ooooo0ol00009ooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool0o?ooool0027ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo0?_ooooo000Qooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0??ooool2o`000?_ooooo000Qooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`3hooooo`008Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0moooool0027ooooo00?o
0000ooooooooool01oooool00ooo003oooooooooo`11ooooo`03o`000?oo003oo`000?Kooooo000Q
ooooo`03o`000?oooooooooo00Kooooo00?o0000ool00?ooool0@oooool00ol0003oooooool0003e
ooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo003ooooo04Gooooo00?o0000oooo
oooo0000P?ooool2ool007;ooooo000Qooooo`?o00001Oooool00ooo003oooooooooo`16ooooo`;o
00000_oo001`ooooo`koo`003?ooool;ool005gooooo000Qooooo`03o`000?oooooooooo00Cooooo
00?o0000ool00?ooool0=_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oo0000?Oooool4o`000003oa0@4?oooooooooo03;ooooo7?l000000olb
<S;ogMgMool00004ool003Sooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`04ooooo`03
ool00?oooooooooo03Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool2o`00
0003ool00?oooooooooo03cooooo00?o0000ooooooooool07oooool4ool000Wooooo2?l0000;oooo
o`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`Wo00001_oo000booooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@06oooool0027ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0goooo
o`05oa0@4?ooooooooooooooool@41004?ooool2o`0000;oo`00??ooool00ol0003oooooooooo`0I
ooooo`Koo`000_ooool;o`0001?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05
ooooo`Ko0000<Oooool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003oooooooooo`03oooo
o`03ool00?oooooooooo03Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00;o00000_oo000jooooo`03o`000?oooooooooo01Cooooo1Ooo0005ooooo`?o00007_ooool0
0ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00cooooo1_l00002ooooo`?oo`009oooool0
0onHV9So8B4Qonk^kP0Kooooo`008Oooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo
03Sooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00ooo
ool00ol0003oooooool0000iooooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool00ooo
ool5o`00027ooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo
1Ol00005ool002?ooooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool00_oo
ool00ooo003oooooooooo`0hooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`06ooooo`;o000000?oo`00ooooooooool0=_ooool00ol0003oooooooooo`0Dooooo`Go0000
9_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_ooooo1?l00005ool001oooooo
00?o0000ooooooooool06Oooool0027ooooo0ol000000oooooooo`00ooooo`0jooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool01_ooool3ool000Oooooo1?l0000[ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool08Oooool3o`0000?oo`006?ooool01Ol0003o^[ZjoooooonHV9So410@01_o
oooo000Qooooo`05o`000?oooooooooooooooooo0000>oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l00008ooooo`;o0000=?ooool00omEEEGoIVIVo`000004ooooo`Coo`001_ooool4o`00
02gooooo00?oEEEEofIVI_l000003Oooool4o`0002Kooooo1Ol0000Cooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`06oooool0027ooooo00Co0000ooooooooooooo`00Foooool2o`0003Kooooo0ooo0006
ooooo`Co0000L?ooool5o`0002kooooo000Qooooo`04o`000?oooooo0000ool005gooooo0_l0000`
ooooo`Coo`001?ooool5o`0007Wooooo0ooo00000ol0003oooooooooo`0Xooooo`008Oooool00ol0
003oooooool0001Pooooo`?o00000ooo000Xooooo`;oo`001?ooool4o`00087ooooo1?oo00000ol0
003oooooooooo`0Tooooo`008Oooool2o`0006Cooooo0ol00003ool002Kooooo1Ol00029ooooo`Co
o`0000?o0000ooooooooool05_ooool2o`0000;ooooo0_l00004ooooo`008Oooool2o`0006Oooooo
0ol00004ool001Cooooo0ooo0005ooooo`Ko0000T_ooool3ool000;o00005?ooool01_o^k^ko8B4Q
ohN7Qonj^[[o0000omgMg@Cooooo000JooooogOo00001_oo0002o`0000coo`00Xol00002ool000Wo
00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Oooooo5Ol0000>ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool04Oooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool01?lQ8B7oMgMgogMgMolb<S85oooo
o`008Oooool00ol0003oooooooooo`3ooooooc_ooooo0_l00002ooooo`;o00001?ooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0003oooooodGo
oooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo1?l000000ol@413oooooooooo`02oooo
o`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo002Tooooo`03ogMgMomVIVKooooo01Oo
oooo00?oIVIVogMgMoooool0Yoooool008?ooooo0ol0000Dooooo`03ob4Q8OoMgMgooooo00Kooooo
00?ogMgMoa0@4?o^k^h06?ooool00oo^k^ko410@omgMg@2Wooooo`00Noooool01on7QhOo0000oeEE
EOmVIVKo0000oc8b<_o^k^h00_ooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o0000odA4
A?nj^[X00oooool00onHV9SoEEEEooooo`06ooooo`03oeEEEOnHV9Sooooo00;ooooo1Ol00009oooo
o`03oeEEEOnYZJWooooo00;ooooo00Ko^[ZjodA4A?ooooooooooohN7QomVIVHDooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd0MOooool007_ooooo00Oo410@omgMgOmgMgOo8B4Qoooooon7QhOo
IVIV00;ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o
0000omgMgOooool01Oooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
2_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P;ooooo00?ok^k^o`000?ooool02oooool6o`00
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[Zjoooooomg
MgOo<S8b00Oooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00Oo0000oooooooMgMgo<S8boooo
ooo^k^ko410@00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`;oMgMg
1_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co410@omgMgOoooooo
00001?ooool00ol0003oooooooooo`0Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo07?ooooo001kooooo`04oeEEEOnYZJWoooooo`00
00;ooooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`06ooooo`03onk^k_l@413o
k^k^00Gooooo00?o<S8booooooooool01?ooool00onHV9So8B4Qonk^kP0;ooooo`04ohN7QomVIVKo
ooooo`0000Cooooo00?o0000ooooooooool02_ooool6o`0000;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ojVYZOl@413ooooo00Kooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00?o
gMgMob4Q8Oo^k^h00oooool01?l0003oooooo`000?l0000=ooooo`03o`000?oooooooooo00Oooooo
00?oEEEEoiRHV?ooool01?ooool00ol0003ok^k^ooooo`05ooooo`03ogMgMomVIVKooooo00[ooooo
00CogMgMoa0@4?oooooo00000oooool00oo^k^ko0000ooooo`0Cooooo`05o`000?oooooooooooooo
ool000003Oooool00ol@413o0000okZj^P04ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0MOooool0
07cooooo00?oV9RHogMgMoooool00_ooool00ol0003oooooooooo`0<ooooo`03oa0@4?l0003o0000
00?o00001_ooool00ooMgMgo410@ooooo`04ooooo`03oeEEEOmgMgOooooo00Kooooo00?o0000oooo
ooooool02?ooool7o`000003oooooomgMgOoEEEE01Cooooo00Go410@oooooooooooooooooa0@400>
ooooo`03okZj^_lQ8B7ooooo00?ooooo00?o0000ooooooooool0Moooool009;ooooo00?o0000oooo
ooooool02?ooool00omEEEGoV9RHooooo`03ooooo`03omgMgOl@413ok^k^00;ooooo00Go0000okZj
^_ooooooV9RHoa0@400Aooooo`03onk^k_l@413ogMgM01Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001?ooool00ol0003oooooooooo`1gooooo`00T_oo
ool00ol0003oooooooooo`08ooooo`03okZj^_m4A4Cooooo00Cooooo00WoMgMgofIVI_oooooooooo
oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool00omVIVKoMgMgooooo`0Dooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Cooooo1?l0001fooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .2992 L
.06244 .2907 L
.06747 .28902 L
.07286 .28747 L
.07751 .28635 L
.08255 .28536 L
.08564 .28488 L
.08848 .28452 L
.0912 .28424 L
.09259 .28412 L
.09409 .28402 L
.09543 .28394 L
.09666 .28389 L
.0979 .28385 L
.09908 .28382 L
.09974 .28381 L
.10044 .28381 L
.10171 .2838 L
.10248 .28381 L
.10321 .28382 L
.10387 .28384 L
.10458 .28385 L
.10582 .2839 L
.10695 .28395 L
.1095 .28409 L
.11185 .28427 L
.11409 .28448 L
.11908 .28507 L
.12452 .28588 L
.14558 .29021 L
.16497 .29472 L
.17526 .29687 L
.18067 .29785 L
.18637 .29876 L
.19141 .29943 L
.19693 .30001 L
.19936 .30021 L
.20195 .30038 L
.2044 .30051 L
.20662 .3006 L
.2078 .30063 L
.20906 .30065 L
.21013 .30067 L
.21131 .30068 L
.21258 .30067 L
.21329 .30067 L
.21394 .30066 L
.2152 .30063 L
.2164 .3006 L
Mistroke
.21869 .30051 L
.22082 .3004 L
.22315 .30025 L
.22563 .30004 L
.23101 .29946 L
.23594 .29875 L
.24708 .2966 L
.2569 .29406 L
.26727 .29078 L
.30529 .27423 L
.34577 .25127 L
.38473 .22714 L
.42614 .20245 L
.46604 .18192 L
.50442 .16653 L
.52423 .16048 L
.53436 .15791 L
.54525 .15554 L
.55544 .15369 L
.56476 .15232 L
.57368 .15128 L
.58306 .15049 L
.58807 .15019 L
.59263 .14999 L
.59515 .14992 L
.59648 .14988 L
.59788 .14985 L
.59911 .14983 L
.59976 .14983 L
.60046 .14982 L
.60169 .14981 L
.60284 .14981 L
.60406 .14981 L
.6052 .14981 L
.60645 .14982 L
.60708 .14983 L
.60777 .14984 L
.61018 .14989 L
.61245 .14995 L
.61667 .1501 L
.62122 .15034 L
.62617 .15067 L
.63077 .15105 L
.64123 .15217 L
.65143 .15358 L
.66233 .15544 L
.68365 .16008 L
.70379 .16562 L
.74222 .17899 L
.78311 .19671 L
Mistroke
.82248 .21655 L
.86034 .23763 L
.90064 .26165 L
.93944 .28575 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .29823 L
.0522 .2938 L
.06244 .29011 L
.0679 .28861 L
.07286 .28752 L
.07784 .28668 L
.08008 .28639 L
.08255 .28613 L
.08522 .28591 L
.08668 .28582 L
.08805 .28575 L
.08932 .2857 L
.09049 .28567 L
.09113 .28566 L
.09184 .28565 L
.09312 .28564 L
.09389 .28565 L
.09462 .28565 L
.09528 .28566 L
.09599 .28568 L
.09759 .28573 L
.09906 .28579 L
.10174 .28595 L
.10458 .28617 L
.10954 .28669 L
.11406 .28728 L
.12422 .28897 L
.14255 .29279 L
.16325 .29721 L
.17235 .29889 L
.1824 .30041 L
.18701 .30096 L
.19198 .30144 L
.19427 .30162 L
.19668 .30177 L
.19893 .30189 L
.20098 .30197 L
.2022 .30201 L
.20334 .30204 L
.20455 .30206 L
.20587 .30207 L
.20702 .30208 L
.20823 .30207 L
.20927 .30206 L
.21041 .30204 L
.2111 .30202 L
.21175 .30201 L
.21298 .30197 L
.21574 .30184 L
Mistroke
.21813 .30169 L
.22073 .30149 L
.22606 .30094 L
.23107 .30026 L
.24044 .29856 L
.25053 .29611 L
.26142 .29276 L
.2814 .28486 L
.30248 .27442 L
.3405 .25179 L
.38098 .2255 L
.41994 .20123 L
.46135 .17905 L
.48209 .16982 L
.50125 .16253 L
.52106 .15629 L
.53963 .15164 L
.55834 .14814 L
.56826 .14677 L
.5738 .14615 L
.57895 .14566 L
.58398 .14527 L
.58855 .14499 L
.59362 .14476 L
.59641 .14468 L
.59766 .14464 L
.59903 .14462 L
.60036 .14459 L
.6016 .14458 L
.60291 .14457 L
.60364 .14457 L
.60431 .14456 L
.6055 .14456 L
.6068 .14457 L
.60803 .14458 L
.60917 .1446 L
.61047 .14462 L
.6117 .14465 L
.61449 .14473 L
.61721 .14483 L
.62014 .14496 L
.62509 .14526 L
.6297 .14561 L
.64016 .14665 L
.65035 .14802 L
.66125 .14984 L
.68257 .15449 L
.70272 .16015 L
.74115 .17409 L
.78204 .19269 L
Mistroke
.82141 .21328 L
.85926 .23476 L
.89957 .25907 L
.93836 .28399 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0Z_ooool;ool008oooooo000Qooooo`03o`000?oooooooooo0:Gooooo1Ooo000Eoooo
o`Goo`00P?ooool0027ooooo00?o0000ooooooooool0YOoooolLo`0000?ooooo1Ooo001kooooo`00
8Oooool00ol0003oooooooooo`2Jooooo`03ool00?oooooooooo00;ooooo1_l0000Looooo`Oo0000
00?oooooool00?oo00000ooo001fooooo`008Oooool00ol0003oooooooooo`2Gooooo`?oo`000_oo
ool3o`0002Wooooo0ol00003ooooo`03ool00?oooooooooo07?ooooo000Qooooo`03o`000?oooooo
oooo09Cooooo0ooo00000ooooooo0000o`000002o`0002oooooo0ol0001fooooo`008Oooool00ol0
003oooooooooo`2Aooooo`?oo`0000Coooooo`000?l0003o0000=_ooool3o`0007?ooooo000Qoooo
o`?o0000S_ooool3ool00004ooooool0003o0000o`0003cooooo1?l0001_ooooo`008Oooool00ol0
003oooooooooo`2;ooooo`?oo`0000Coooooo`000?l0003o0000@oooool3o`000004oooooooo003o
o`00ool006Sooooo000Qooooo`03o`000?oooooooooo08gooooo0_l00019ooooo`?o000000Cooooo
ool00?oo003oo`00IOooool0027ooooo00?o0000ooooooooool0Roooool2o`0004kooooo0ol00000
0oooooooo`00ool0001Sooooo`008Oooool00ol0003oooooooooo`28ooooo`?o0000Doooool2o`00
0003oooooooo003oo`00067ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo08Kooooo0_l0001H
ooooo`?o00000_oo001Oooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0P?ooool2ool000;ooooo0_l0001M
ooooo`;o00000_oo001Mooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`02ooooo`?o0000Ooooool00ooo003oooooooooo`02o`00067ooooo0_l00000
0ooo003oooooooooo`1Jooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`1mooooo`;oo`0000?oooooo`000?l00000IOooool3
o`0000;oo`00F?ooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`1kooooo`;oo`0000?oooooo`000?l00000J_oo
ool2o`000003ool00?oooooooooo05Gooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07[ooooo00Coo`00ooooool0003o0000
K_ooool2o`0005Kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo07Sooooo0_oo0002o`0007;ooooo0_l0001Dooooo`001ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo07Kooooo
0_oo00000ooooooo0000ooooo`1eooooo`?o0000DOooool0027ooooo00?o0000ooooooooool0MOoo
ool01?oo003oooooo`000?l0001jooooo`;o0000Coooool0027ooooo00?o0000ooooooooool0M?oo
ool00ooo003o0000o`00001nooooo`?oo`00C?ooool0027ooooo0ol0001dooooo`03o`000?oooooo
oooo083ooooo00?o0000ool00?oo0000B_ooool0027ooooo00?o0000ooooooooool0L_ooool2o`00
08Gooooo00?o0000ool00?ooool0B?ooool0027ooooo00?o0000ooooooooool0L?ooool2o`0008Wo
oooo0_oo0017ooooo`008Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo08[ooooo
00?o0000ool00?oo0000AOooool0027ooooo00?o0000ooooooooool0KOooool2o`0008oooooo00?o
0000ool00?ooool0@oooool0027ooooo00?o0000ooooooooool0J_ooool2ool00003o`000?oooooo
oooo097ooooo0_oo0012ooooo`008Oooool00ol0003oooooooooo`1Xooooo`;oo`0000?o0000oooo
ooooool0U?ooool00ol0003oo`00ooooo`10ooooo`008Oooool3o`0006Kooooo0_oo0002o`0009Wo
oooo00?oo`00o`000?ooool0?_ooool0027ooooo00?o0000ooooooooool0IOooool00ooo003o0000
o`00002Mooooo`03o`000?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo06?ooooo0_oo
00000ol0003oooooooooo`2Nooooo`;o0000??ooool0027ooooo00?o0000ooooooooool0HOooool2
ool000;o0000Xoooool00ol0003oooooooooo`0iooooo`008Oooool00ol0003oooooooooo`1Ooooo
o`;oo`000_l0002Vooooo`;o0000>Oooool0027ooooo00?o0000ooooooooool0G_ooool00ooo003o
0000o`00002Zooooo`03o`000?oo003oo`0003Kooooo000Qooooo`03o`000?oooooooooo05gooooo
00?oo`00o`000?ooool0[?ooool2o`000003ool00?oooooooooo03?ooooo000Qooooo`03o`000?oo
oooooooo05_ooooo0_l0002aooooo`03o`000?oo003oo`0003?ooooo000Qooooo`?o0000F_ooool0
0ol0003oooooooooo`2booooo`;o000000?oo`00ooooooooool0<?ooool0027ooooo00?o0000oooo
ooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool2o`0003Kooooo1?l000000ol@413oooooooooo`0kooooo`Co000000?o
410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Zooooo`03o`00
0?oo003oo`00013ooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00_ooool2o`0003[ooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`0[ooooo`03o`000?oo003ooooo00kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`00
8Oooool00ol0003oooooooooo`0mooooo`05oa0@4?ooooooooooooooool@41004?ooool01?l0003o
ooooo`000?l0000looooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0[ooooo`03o`000?oo003ooooo00kooooo00?oV9RHob4Q8Oo^k^h07?ooool0027o
oooo00?o0000ooooooooool0?Oooool01Ol0003ooooooooooooooooo000000oooooo00CoMgMgo`00
0?oo003oo`00?Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00kooooo00?oMgMg
oc8b<_ooool0;_ooool2ool000kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000oooo
ooooool0?Oooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ob4Q8Ol000000_oo000o
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<037ooooo00?oo`00ooooooooool03?ooool00omgMgOoIVIVooooo`0Jooooo`008Oooool0
0ol0003oooooooooo`0Eooooo`;o00009_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ool00?oo0000@Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0=?ooool00ooo003o0000ooooo`0<ooooo`03o`000?oooooooooo01Wooooo000Q
ooooo`?o00003_ooool<ool000Oo00007?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?o
0000ool00?oo0000@oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0=_ooool2o`0000Oooooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Ooo
ool00ol0003oooooooooo`0:ooooo`Co000000?oo`00ooooooooool02Oooool4ool000?ooooo1Ol0
000Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool3ool00003ooooool0003o000000;o0000
?_ooool00omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000gooooo`;o0000
1Oooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qooooo`03o`000?oooooooooo00Sooooo
0_l0000Looooo`?o00007_ooool3ool00=Gooooo00?o0000ooooooooool08_ooool0027ooooo00?o
0000ooooooooool01Oooool3o`00023ooooo00Coo`00o`000?l0003o00005_ooool4o`000003ool0
0?l0003ooooo0=Oooooo0_l0000Rooooo`008Oooool00ol0003oooooooooo`02ooooo`;oo`0000?o
0000ooooooooool08_ooool6ool000Co00002_ooool5o`000>3ooooo0_l0000Pooooo`008Oooool0
0ol0003oooooooooo`02ool002gooooo2Ooo00001Ol0003oo`00ool00?oo003o00000>Kooooo0_oo
000Eooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oo003oo`000?oooooo9_ooool2
ool001?ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0
003o00000?oo0000:?l000000ooo003o0000o`000005o`0000cooooo00CogMgMo`000?l@413oc<c<
1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Co8B4QogMgMomgMgOo<S8b
1Oooool0027ooooo00?o0000ooooooooool0oooooolkooooo`;o00000_ooool2o`0000Cooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?oo
ool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodGooooo0007
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooo
oom5ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`00
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool0
0_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_ooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z?ooool00omgMgOoIVIVoooo
o`0Gooooo`03ofIVI_mgMgOooooo0:?ooooo0027ooooo`?o00004oooool00olQ8B7ogMgMooooo`07
ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Xoooool007kooooo00OoQhN7o`00
0?mEEEGoIVIVo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool02oooool01OnHV9So0000o`00
0?m4A4Co^[Zj00;ooooo00?oV9RHoeEEEOooool01oooool01?mEEEGoV9RHooooooooool5o`0000Wo
oooo00?oEEEEojVYZOooool00_ooool00onj^[[oA4A4ooooo`02ooooo`03ohN7QomVIVKooooo01;o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo
07Wooooo001nooooo`07oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP03ooooo`03o`000?oooooo
oooo00_ooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oMgMgooooo00Kooooo00Wo
0000oooooooooooooooooiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooooooooooo
410@okZj^P?ooooo00?ok^k^o`000?ooool02oooool6o`000006oooooomgMgOoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool0N_ooool007kooooo00Oo0000oooooooMgMgo
<S8booooooo^k^ko410@00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05oooo
o`;oMgMg1oooool00olb<S;oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co410@omgM
gOoooooo00001Oooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0007_ooooo001nooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Go0000oooooooooooooooo
o`00000=ooooo`03o`000?oooooooooo00Gooooo00?ok^k^oa0@4?o^k^h01_ooool00olb<S;ooooo
ooooo`03ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001Oooool00ol0003o
ooooooooo`0:ooooo`Ko000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04
odA4A?oMgMgoooooo`0007cooooo001nooooo`03omgMgOlQ8B7ok^k^00?ooooo00?o0000oooooooo
ool00_l0000=ooooo`03o`000?oooooooooo00Kooooo00?oEEEEoiRHV?ooool01Oooool00ol0003o
k^k^ooooo`04ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo00001?ooool00oo^
k^ko0000ooooo`0Booooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0
001looooo`00Ooooool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo00gooooo00?o410@
o`000?l000000ol00005ooooo`03omgMgOl@413ooooo00Gooooo00?oEEEEogMgMoooool01Oooool0
0ol0003oooooooooo`08ooooo`Oo00000_ooool00omgMgOoEEEEooooo`0Booooo`05oa0@4?oooooo
ooooooooool@41003?ooool00omgMgOoc<c<o`00001looooo`00U_ooool00ol0003oooooooooo`07
ooooo`03oeEEEOnHV9Sooooo00Cooooo00WogMgMoa0@4?o^k^koooooo`000?nj^[[ooooooiRHV?l@
41004_ooool00oo^k^ko410@omgMg@0Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^
k^koA4A4o`00001looooo`00U_ooool00ol0003oooooooooo`07ooooo`03okZj^_m4A4Cooooo00Go
oooo00SoMgMgofIVI_ooooooV9RHoa0@4?l0003o8B4Qolc<c1;ooooo00?oIVIVogMgMoooool04ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0Noooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .33801 L
.06244 .36625 L
.08426 .39201 L
.0949 .40185 L
.10458 .40899 L
.10911 .41171 L
.11403 .41421 L
.11828 .41597 L
.12297 .41749 L
.12553 .41813 L
.12793 .41861 L
.13047 .41899 L
.13189 .41915 L
.13319 .41926 L
.13439 .41933 L
.13551 .41937 L
.13673 .41939 L
.13803 .41937 L
.13928 .41932 L
.14045 .41925 L
.1415 .41916 L
.14264 .41905 L
.14501 .41872 L
.14755 .41825 L
.15214 .4171 L
.1576 .41523 L
.16257 .41307 L
.17339 .40696 L
.18364 .39951 L
.22197 .36041 L
.26275 .30668 L
.30202 .25136 L
.33977 .20064 L
.37997 .15341 L
.41866 .11673 L
.43831 .10168 L
.4598 .08802 L
.48033 .07767 L
.49942 .07035 L
.50995 .06725 L
.51988 .0649 L
.5288 .06327 L
.53379 .06255 L
.53847 .062 L
.54303 .06158 L
.54793 .06124 L
.55072 .06111 L
.5521 .06106 L
.55337 .06102 L
Mistroke
.55452 .06099 L
.55575 .06096 L
.55645 .06096 L
.55711 .06095 L
.55834 .06094 L
.55957 .06094 L
.56026 .06095 L
.56091 .06095 L
.56222 .06097 L
.56295 .06098 L
.56362 .061 L
.5661 .06107 L
.56846 .06117 L
.57118 .06132 L
.5737 .06149 L
.57939 .06198 L
.58904 .06315 L
.59809 .06462 L
.61871 .06928 L
.63893 .07546 L
.65744 .08241 L
.69712 .10093 L
.73528 .12273 L
.77589 .14938 L
.81499 .17768 L
.85654 .20988 L
.89658 .24235 L
.93509 .2744 L
.97607 .30891 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .34079 L
.06244 .37024 L
.08255 .39386 L
.09396 .404 L
.09905 .40772 L
.10458 .41119 L
.11004 .41404 L
.11508 .41615 L
.11989 .41771 L
.12235 .41833 L
.125 .41888 L
.12738 .41925 L
.12956 .4195 L
.13061 .41959 L
.13175 .41966 L
.13283 .41971 L
.13384 .41974 L
.13511 .41974 L
.13631 .41972 L
.13738 .41967 L
.13855 .4196 L
.13982 .4195 L
.14117 .41936 L
.14357 .41902 L
.14612 .41856 L
.14853 .41801 L
.15305 .41672 L
.15792 .41495 L
.16321 .41259 L
.18154 .40116 L
.20132 .38382 L
.22233 .36084 L
.26008 .3116 L
.30028 .2544 L
.33897 .20095 L
.38011 .15082 L
.41973 .11204 L
.45784 .08474 L
.47745 .07455 L
.4984 .06646 L
.50864 .06351 L
.51975 .06102 L
.52484 .06012 L
.53023 .05933 L
.53528 .05874 L
.5399 .05832 L
.54222 .05815 L
.54474 .058 L
.54712 .05789 L
Mistroke
.54934 .05781 L
.55066 .05778 L
.55191 .05775 L
.55303 .05774 L
.55425 .05773 L
.55488 .05773 L
.55557 .05773 L
.5563 .05773 L
.55697 .05773 L
.55818 .05775 L
.55947 .05777 L
.5607 .0578 L
.56183 .05784 L
.5644 .05794 L
.56666 .05806 L
.56906 .0582 L
.57779 .05897 L
.58269 .05956 L
.58718 .06018 L
.5973 .06191 L
.61559 .06607 L
.63455 .07171 L
.65527 .07927 L
.69588 .09783 L
.73498 .11981 L
.77653 .14699 L
.81656 .17634 L
.85508 .20685 L
.89605 .24086 L
.9355 .27425 L
.97344 .30664 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0Voooool7ool000Wooooo0_oo002Gooooo`008Ooo
ool00ol0003oooooooooo`2Loooooa7o00001_oo002Aooooo`006?ooool4o`000003oa0@4?oooooo
oooo00;ooooo00?o0000ooooooooool0Uoooool5o`0001;ooooo1Ol00003ool008kooooo000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0T?ooool2ool000;ooooo0ol0000Moooo
o`;o00000ooo002;ooooo`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`0008go
oooo0ooo00001?oooooo0000o`000?l0000Sooooo`;o00000_oo0029ooooo`006_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo08[ooooo0ooo00001?oooooo0000o`000?l0000Zoooo
o`Co0000QOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`28ooooo`;o
o`0000Coooooo`000?l0003o0000<Oooool2o`0008?ooooo000Jooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0Q_ooool2ool00003ooooool0003o000003Kooooo0_l00021ooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Gooooo00Coo`00ooooool0003o
0000>_ooool2o`0000;oo`00OOooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003ooooo
ooooo`24ooooo`03ool00?l0003o000003kooooo0_l00003ool007[ooooo000Qooooo`03o`000?oo
oooooooo08?ooooo00?oo`00o`000?ooool0@_ooool2o`0000;oo`00N?ooool0027ooooo00?o0000
ooooooooool0P_ooool2o`0004Oooooo00Co0000ool00?oo003oo`00MOooool0027ooooo0ol00021
ooooo`03o`000?oooooooooo04Wooooo0_l00002ool007?ooooo000Qooooo`03o`000?oooooooooo
083ooooo00?o0000ooooooooool0COooool00ol0003oo`00ool0001aooooo`008Oooool00ol0003o
ooooooooo`1nooooo`;o0000D_ooool00ol0003oo`00ooooo`1_ooooo`008Oooool00ol0003ooooo
ooooo`1mooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0KOooool0027ooooo00?o
0000ooooooooool0N_ooool00ooo003o0000o`00001Hooooo`;o0000KOooool0027ooooo00?o0000
ooooooooool0NOooool00ooo003o0000ooooo`1Kooooo`;o0000Joooool0027ooooo00?o0000oooo
ooooool0N?ooool00ooo003o0000ooooo`1Nooooo`03o`000?oooooooooo06Sooooo000Qooooo`?o
0000Moooool00ooo003o0000ooooo`1Pooooo`;o0000J?ooool0027ooooo00?o0000ooooooooool0
M_ooool00ooo003o0000ooooo`1Sooooo`;oo`00I_ooool0027ooooo00?o0000ooooooooool0MOoo
ool00ooo003o0000ooooo`1Vooooo`03ool00?oooooooooo06?ooooo000Qooooo`03o`000?oooooo
oooo07Cooooo00?oo`00o`000?ooool0J?ooool2ool006?ooooo000Qooooo`03o`000?oooooooooo
07?ooooo00?oo`00o`000?ooool0J_ooool00ol0003oo`00ooooo`1Qooooo`008Oooool00ol0003o
ooooooooo`1booooo`03ool00?l0003ooooo06gooooo0_oo001Pooooo`008Oooool00ol0003ooooo
ooooo`1aooooo`03ool00?l0003ooooo06oooooo00?o0000ool00?ooool0G_ooool0027ooooo0ol0
001`ooooo`03ool00?l0003ooooo077ooooo00?o0000ool00?oo0000GOooool0027ooooo00?o0000
ooooooooool0Koooool00ooo003o0000ooooo`1dooooo`03o`000?oo003ooooo05_ooooo000Qoooo
o`03o`000?oooooooooo06oooooo00?o0000ooooooooool0MOooool00ol0003oo`00ool0001Joooo
o`008Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo07Oooooo0_l0001Jooooo`00
8Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0
Eoooool0027ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1kooooo`;o0000Eooo
ool0027ooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1nooooo`03o`000?oooooo
oooo05Cooooo000Qooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0P?ooool2o`00
05Cooooo000Qooooo`?o0000J_ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo057o
oooo000Qooooo`03o`000?oooooooooo06Oooooo00?oo`00ooooool00000Qoooool00ol0003oo`00
ool0001@ooooo`008Oooool00ol0003oooooooooo`1Wooooo`03ool00?l0003ooooo08Wooooo00?o
0000ool00?ooool0C_ooool0027ooooo00?o0000ooooooooool0I_ooool00ooo003o0000ooooo`2;
ooooo`03o`000?oo003oo`0004gooooo000Qooooo`03o`000?oooooooooo06Gooooo00?oo`00o`00
0?ooool0S_ooool00ol0003oo`00ooooo`1;ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`1U
ooooo`03ool00?l0003ooooo08oooooo00?o0000ool00?ooool0B_ooool000Oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo06Cooooo00?oo`00o`000?ooool0TOooool00ol0003oo`00ool00019ooooo`001Ol00002oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000Hoooool0
0ooo003o0000ooooo`2Dooooo`03o`000?oo003ooooo04Oooooo0007ooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo06;ooooo00?oo`00
o`000?ooool0U_ooool00ol0003oo`00ooooo`16ooooo`001oooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo06;ooooo00?o
o`00ooooooooool0Uoooool00ol0003oo`00ooooo`15ooooo`001oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Qooooo`03ool00?oo
oooooooo09Wooooo00?o0000ool00?ooool0A?ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0H?ooool00ooo003ooooooooo
o`2Looooo`03o`000?oooooooooo04;ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0000Gooooo00?o0000ooooooooool0Goooool00ooo003o0000ooooo`2Nooooo`03o`000?oo
oooooooo047ooooo000Qooooo`03o`000?oooooooooo05kooooo00?oo`00o`000?ooool0X?ooool2
o`00047ooooo000Qooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0X_ooool00ol0
003oooooooooo`0nooooo`008Oooool3o`0005gooooo00?o0000ooooooooool0Y?ooool00ol0003o
ooooooooo`0mooooo`008Oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo0:Kooooo
00?o0000ooooooooool0??ooool0027ooooo00?o0000ooooooooool0G?ooool00ol0003ooooooooo
o`2Wooooo`03o`000?oo003oo`0003_ooooo000Qooooo`03o`000?oooooooooo05_ooooo00?o0000
ooooooooool0ZOooool2o`000003ool00?oooooooooo03Sooooo000Qooooo`03o`000?oooooooooo
05[ooooo00?o0000ooooooooool0[?ooool00ol0003oo`00ooooo`0hooooo`008Oooool00ol0003o
ooooooooo`1Iooooo`03o`000?oooooooooo0:kooooo00?o0000ool00?ooool0=oooool0027ooooo
00?o0000ooooooooool0F?ooool00ol0003oooooooooo`2`ooooo`03o`000?oo003ooooo03Kooooo
000Qooooo`?o0000Eoooool00ooo003o0000ooooo`2booooo`03o`000?oo003ooooo03Gooooo000Q
ooooo`03o`000?oooooooooo05Oooooo00?oo`00ooooooooool0/oooool00ol0003oo`00ool0000d
ooooo`008Oooool00ol0003oooooooooo`1Fooooo`03ool00?oooooooooo0;Gooooo0_l000000ooo
003oooooooooo`0aooooo`008Oooool00ol0003oooooooooo`1Eooooo`03ool00?oooooooooo0;So
oooo00?o0000ool00?ooool0<Oooool0027ooooo00?o0000ooooooooool0E?ooool00ol0003oo`00
ooooo`2jooooo`03o`000?oo003ooooo033ooooo000Qooooo`03o`000?oooooooooo05Cooooo00?o
o`00ooooooooool0^oooool00ol0003oo`00ooooo`0_ooooo`008Oooool00ol0003oooooooooo`1C
ooooo`03o`000?oo003ooooo0;gooooo00?o0000ooooooooool0;_ooool0027ooooo00?o0000oooo
ooooool0D_ooool00ol0003oo`00ooooo`2oooooo`;o0000;_ooool0027ooooo0ol0001Booooo`03
ool00?oooooooooo0<7ooooo00?o0000ooooooooool0:oooool0027ooooo00?o0000ooooooooool0
?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000ool0
0?oMgMd0?Oooool4o`000003oa0@4?oooooooooo03_ooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM033ooooo00?o0000ooooooooool02_ooool5
o`0001_ooooo000Qooooo`03o`000?oooooooooo03gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1oooool00ol0003oo`00oc8b<P0oooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0<?ooool00ol0003oooooooooo`09
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol@413ooooooooooooooooo410@00kooooo00?oo`00ooooool00000?oooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`09ooooo`03oiRHV?lQ8B7ok^k^01cooooo000Qooooo`03o`000?oooooooooo03gooooo00Go0000
ooooooooooooooooo`00000=ooooo`04ool00?ooooooMgMgoc8b<Soooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03;ooooo0_l0000:ooooo`03oiRH
V?lQ8B7ok^k^01_ooooo000Qooooo`03o`000?oooooooooo03gooooo00Go0000oooooooooooooooo
o`00000<ooooo`05ool00?lQ8B7o0000oc8b<_o<c<`0?oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00dooooo`;oo`002_ooool00omg
MgOoIVIVooooo`0Jooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0hooooo`03ool00?oooooooooo00Sooooo00?o0000oooo
ooooool06Oooool0027ooooo0ol0000mooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool2o`00
04?ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
03Wooooo00?oo`00o`000?ooool00oooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qoooo
o`03o`000?oooooooooo03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`03o`000?oooooo
000000?o0000?_ooool00omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000i
ooooo`03ool00?l0003ooooo00;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Kooooo`008Oooool0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo0=7ooooo0_oo000Rooooo`008Oooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo0=Cooooo00?oo`00ooooooooool07oooool0027o
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`3Fooooo`03ool00?l0003ooooo01ko
oooo000Qooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0eoooool00ooo003o0000
ooooo`0Cooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo04Wooooo00?o
0000ooooooooool0fOooool00ooo003o0000ooooo`0Booooo`06onk^k_lQ8B7oQhN7okZj^_l0003o
gMgM1?ooool001[oooooD_l000000ooo003o0000o`00003Ko`0000;oo`001ol0000<ooooo`04omgM
gOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2oooool00ooo003o0000ooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Aooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`;o0000
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`03ool00?l0003ooooo00gooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Co8B4QogMgMomgMgOo
<S8b1Oooool0027ooooo00?o0000ooooool00000A_ooool00ooo003oooooooooo`3aooooo`;o0000
0_ooool2o`0000Cooooo000Qooooo`03o`000?oooooo000004Gooooo00?oo`00ooooooooool0o?oo
ool0027ooooo00Co0000oooooooooooo0000@oooool00ooo003oooooooooo`3mooooo`008Oooool0
1Ol0003ooooooooooooooooo000004;ooooo00?oo`00ooooooooool0oOooool0027ooooo00Go0000
ooooooooooooooooo`000011ooooo`03ool00?oooooooooo0?kooooo000Qooooo`?o00000_ooool0
0ol0003oooooooooo`0mooooo`03ool00?oooooooooo0?oooooo000Qooooo`03o`000?oooooooooo
00?ooooo00?oo`00ooooooooool0>oooool00ol0003oo`00ooooo`3oooooo`7ooooo000Qooooo`03
o`000?oooooooooo00?ooooo00?oo`00ooooooooool0>_ooool00ol0003oo`00ooooo`3oooooo`;o
oooo000Qooooo`03o`000?oooooooooo00?ooooo00?oo`00o`000?ooool0>Oooool00ol0003oo`00
ooooo`3oooooo`?ooooo000Qooooo`03o`000?oooooooooo00Cooooo00?oo`00o`000?ooool0>?oo
ool00ooo003oooooooooo`3oooooo`?ooooo000Qooooo`03o`000?oooooooooo00Gooooo00?oo`00
ooooooooool0=_ooool00ol0003oooooooooo`3oooooo`Cooooo000Qooooo`03o`000?oooooooooo
00Gooooo00?oo`00o`000?ooool0=Oooool00ol0003oooooooooo`3oooooo`Gooooo000Qooooo`?o
00001_ooool00ooo003o0000ooooo`0cooooo`03o`000?oooooooooo0?oooooo1_ooool0027ooooo
00?o0000ooooooooool01oooool00ooo003oooooooooo`0aooooo`03o`000?oooooooooo0?oooooo
1oooool0027ooooo00?o0000ooooooooool01oooool00ooo003o0000ooooo`0aooooo`03o`000?oo
oooooooo0?oooooo1oooool0027ooooo00?o0000ooooooooool02?ooool00ooo003o0000ooooo`0_
ooooo`03o`000?oooooooooo0?oooooo2?ooool0027ooooo00?o0000ooooooooool02Oooool00ooo
003oooooooooo`0]ooooo`03o`000?oooooooooo0?oooooo2Oooool0027ooooo00?o0000oooooooo
ool02_ooool00ooo003oooooooooo`0[ooooo`03o`000?oooooooooo0?oooooo2_ooool0027ooooo
00?o0000ooooooooool02oooool00ooo003oooooooooo`0Yooooo`03o`000?oo003ooooo0?oooooo
2oooool0027ooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`0Wooooo`03o`000?oo
003ooooo0?oooooo3?ooool0027ooooo0ol0000=ooooo`03o`000?oooooooooo02Gooooo00?o0000
ool00?ooool0ooooool=ooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
02?ooooo0_oo003oooooo`oooooo000Qooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool08Oooool00ooo003oooooooooo`3oooooo`oooooo000Qooooo`03o`000?oooooooooo013ooooo
0_l0000Pooooo`03ool00?oooooooooo0?oooooo4?ooool0027ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Looooo`03ool00?oooooooooo0?oooooo4Oooool0027ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Jooooo`03ool00?oooooooooo0?oooooo4_ooool0
027ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Gooooo`;oo`00oooooolEoooo
o`008Oooool3o`0001?ooooo0_oo00000ol0003oooooooooo`0Eooooo`03ool00?oooooooooo0?oo
oooo5Oooool0027ooooo00?o0000ooooooooool05Oooool2ool001Cooooo00?o0000ool00?ooool0
oooooolGooooo`008Oooool00ol0003oooooooooo`0Gooooo`03ool00?l0003o0000013ooooo00?o
0000ooooooooool0oooooolHooooo`008Oooool00ol0003oooooooooo`0Hooooo`;oo`0000?o0000
ooooooooool02oooool2o`000?oooooo6oooool0027ooooo00?o0000ooooooooool06_ooool3ool0
0003o`000?oooooooooo00Cooooo1?l0003ooooooagooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooo
oooo01gooooo1_oo00000ol0003oooooooooo`3ooooooaoooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02
ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o
410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3o`000?oo
ooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo
000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIV
I_l000001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool0
0omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:Oooooo0023ooooo`?o00005?ooool00olQ
8B7ogMgMooooo`06ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Yoooool007_o
oooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool02oooool0
1OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?oV9RHoeEEEOooool01_ooool00omEEEGoV9RHoooo
o`02ooooo`Go00002Oooool00omEEEGoZJVYooooo`02ooooo`06okZj^_m4A4Cooooooooooon7QhOo
IVIV5?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@oooo
ooooool00_ooool01Om4A4Co0000o`000?lb<S;ogMgM07Gooooo001kooooo`07oa0@4?oMgMgoMgMg
ob4Q8OooooooQhN7ofIVIP02ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_o^k^koMgMg
oa0@4004ooooo`03o`000?oMgMgooooo00Gooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Q
onk^k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X2ooooo`03onk^k_l0003o
oooo00_ooooo1_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`1dooooo`00Noooool01ol0003oooooomgMgOlb
<S;oooooonk^k_l@41000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
0_mgMgL6ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgM
ooooool00004ooooo`03o`000?oooooooooo01;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`Go00002?ooool00ol0003oooooooooo`1cooooo`00Noooool01?mEEEGoZJVYooooool00002oooo
o`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool01_ooool00oo^k^ko410@onk^kP05
ooooo`03oc8b<_oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7QhOoIVIVooooool0
0004ooooo`03o`000?oooooooooo00[ooooo1_l00002ooooo`05o`000?ooooooooooooooool00000
2oooool01?m4A4CogMgMooooool00008ooooo`03ogMgMolb<S;ooooo07Cooooo001kooooo`03omgM
gOlQ8B7ok^k^00?ooooo00Co0000ooooool0003o00003Oooool00ol0003oooooooooo`07ooooo`03
oeEEEOnHV9Sooooo00Cooooo00?o0000onk^k_ooool01Oooool00omgMgOoIVIVooooo`0:ooooo`04
omgMgOl@413oooooo`0000?ooooo00?ok^k^o`000?ooool04oooool01Ol0003ooooooooooooooooo
000000_ooooo00CogMgMoeEEEOoooooo00001Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<07Gooooo
001looooo`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool03?ooool00ol@413o0000o`00
0003o`0000Kooooo00?ogMgMoa0@4?ooool01?ooool00omEEEGoMgMgooooo`06ooooo`03o`000?oo
oooooooo00Sooooo1ol000000oooooooMgMgoeEEE@0Dooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00omgMgOoc<c<o`000005ooooo`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oo
oooooooo00Sooooo00?oEEEEoiRHV?ooool00oooool00ooMgMgo410@onk^kP02ooooo`05o`000?nj
^[[ooooooiRHV?l@41004Oooool00oo^k^ko410@omgMg@0Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00oo^k^koA4A4o`000005ooooo`03o`000?oooooooooo07Oooooo002Booooo`03o`00
0?oooooooooo00Sooooo00?o^[ZjodA4A?ooool01?ooool02OmgMgOoIVIVooooooooooooV9RHoa0@
4?l0003o8B4Qolc<c00Aooooo`03ofIVI_mgMgOooooo01Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00Cooooo1?l0001fooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .35892 L
.06244 .4054 L
.08255 .44165 L
.09396 .45642 L
.09905 .4616 L
.10458 .46626 L
.11004 .46986 L
.11243 .47113 L
.11508 .47232 L
.1174 .47319 L
.11989 .47393 L
.12127 .47425 L
.12253 .4745 L
.12372 .47469 L
.125 .47485 L
.12624 .47495 L
.12736 .47501 L
.12849 .47503 L
.12955 .47501 L
.13079 .47495 L
.13194 .47485 L
.13319 .4747 L
.13452 .4745 L
.13675 .47404 L
.13884 .4735 L
.14357 .47182 L
.14858 .46942 L
.15402 .4661 L
.16392 .45834 L
.18248 .43849 L
.22326 .37753 L
.26253 .30785 L
.30028 .24068 L
.34048 .17577 L
.37917 .12341 L
.39882 .10119 L
.42031 .08041 L
.44107 .06382 L
.45994 .05166 L
.47955 .04185 L
.49045 .0376 L
.5005 .0344 L
.50981 .03205 L
.51968 .03017 L
.5248 .02943 L
.52958 .02889 L
.53484 .02846 L
.53778 .02829 L
.53917 .02822 L
Mistroke
.54048 .02817 L
.54168 .02814 L
.54299 .02811 L
.54417 .02809 L
.54526 .02808 L
.54644 .02807 L
.54774 .02808 L
.54839 .02808 L
.54909 .02809 L
.55035 .02812 L
.55153 .02815 L
.55281 .02819 L
.55514 .02829 L
.55741 .02841 L
.5595 .02855 L
.56429 .02895 L
.56956 .02954 L
.58024 .03116 L
.59036 .03321 L
.59962 .03552 L
.62049 .04209 L
.66017 .05934 L
.69833 .08087 L
.73894 .10798 L
.77804 .13721 L
.81959 .17076 L
.85963 .20482 L
.89814 .2387 L
.93912 .27545 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .35778 L
.06244 .40451 L
.08255 .44142 L
.09396 .45658 L
.09905 .46193 L
.10458 .46675 L
.11004 .47048 L
.11243 .47181 L
.11508 .47306 L
.1174 .47397 L
.11989 .47475 L
.12127 .47509 L
.12253 .47536 L
.12372 .47556 L
.125 .47573 L
.12624 .47585 L
.12736 .47591 L
.12849 .47594 L
.12955 .47593 L
.13079 .47588 L
.13194 .47579 L
.13319 .47564 L
.13452 .47544 L
.13675 .47499 L
.13884 .47444 L
.14357 .47274 L
.14858 .47029 L
.15402 .46691 L
.16392 .45898 L
.18248 .43872 L
.22326 .37689 L
.26253 .30699 L
.30028 .24019 L
.34048 .17608 L
.37917 .12446 L
.42031 .08176 L
.44084 .06522 L
.45994 .05261 L
.47836 .04294 L
.49804 .03524 L
.50829 .03227 L
.51368 .03098 L
.51939 .02983 L
.52438 .029 L
.52987 .02826 L
.53228 .028 L
.53487 .02776 L
.53732 .02757 L
.53954 .02743 L
Mistroke
.54209 .0273 L
.54348 .02725 L
.5448 .02721 L
.54602 .02719 L
.54714 .02717 L
.54837 .02717 L
.54967 .02717 L
.55099 .02718 L
.55173 .02719 L
.5524 .0272 L
.5537 .02723 L
.55494 .02727 L
.55771 .02739 L
.56072 .02757 L
.56579 .028 L
.57116 .0286 L
.58082 .03009 L
.59021 .03202 L
.60033 .03459 L
.61862 .04049 L
.65981 .05896 L
.69949 .08218 L
.73765 .10814 L
.77826 .13849 L
.81736 .16963 L
.85891 .20441 L
.89894 .23932 L
.93746 .27382 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`2Sooooo`Coo`00WOooool0027ooooo00?o0000ooooooooool0Uooo
ool6ool000[o00001ooo002Fooooo`008Oooool00ol0003oooooooooo`2Cooooo`Coo`005?ooool3
o`0000?oo`00Toooool0027ooooo00?o0000ooooooooool0T?ooool3ool00003o`000?oooooooooo
01_ooooo0_oo00000ol0003oooooooooo`2>ooooo`008Oooool00ol0003oooooooooo`2>ooooo`;o
o`0000?o0000ooooooooool08Oooool3o`0008gooooo000Qooooo`03o`000?oooooooooo08_ooooo
0_l000000ooo003oooooooooo`0Wooooo`?o0000R_ooool0027ooooo00?o0000ooooooooool0ROoo
ool2o`0002oooooo0ol00027ooooo`008Oooool3o`0008Oooooo0_l0000cooooo`;oo`0000?o0000
ooooooooool0Poooool0027ooooo00?o0000ooooooooool0QOooool2o`0003Oooooo0ooo0023oooo
o`008Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo03[ooooo0ooo0020ooooo`00
8Oooool00ol0003oooooooooo`22ooooo`;oo`00@?ooool2ool007kooooo000Qooooo`03o`000?oo
oooooooo087ooooo00?oo`00ooooooooool0@_ooool00ooo003o0000ooooo`1kooooo`006?ooool4
o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0Ooooool2ool004Kooooo0_oo001k
ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07kooooo00?oo`00oooo
ooooool0B?ooool00ooo003o0000ooooo`1hooooo`003oooool6o`0000Gooooo00?o0000oooooooo
ool01?ooool3o`0007cooooo0_oo001<ooooo`03ool00?l0003o000007Oooooo000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0Noooool00ooo003oooooooooo`1?ooooo`03o`00
0?oooooooooo07Cooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0N_oo
ool00ooo003oooooooooo`1Aooooo`;o0000M?ooool001[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1hooooo`03o`000?oo003ooooo05Gooooo0_l0001booooo`006_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo07Oooooo00?o0000oooooooo0000F?ooool00ol0
003oooooooooo`1_ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo07Ko
oooo00?o0000oooooooo0000F_ooool2o`0006oooooo000Qooooo`03o`000?oooooooooo07Gooooo
00?o0000oooooooo0000Foooool2ool00003o`000?oooooooooo06cooooo000Qooooo`03o`000?oo
oooooooo07Cooooo00?o0000ooooooooool0G_ooool00ooo003o0000o`00001/ooooo`008Oooool3
o`0007?ooooo00?o0000ooooooooool0H?ooool2ool00003o`000?oooooooooo06Wooooo000Qoooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Hoooool00ooo003o0000ooooo`1Yoooo
o`008Oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo06Cooooo0_oo00000ol0003o
ooooooooo`1Vooooo`008Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo06Oooooo
00?oo`00o`000?ooool0I_ooool0027ooooo00?o0000ooooooooool0L?ooool00ol0003ooooooooo
o`1Yooooo`;oo`0000?o0000ooooooooool0Hoooool0027ooooo00?o0000ooooooooool0Koooool0
0ol0003oo`00ooooo`1/ooooo`03ool00?l0003ooooo06?ooooo000Qooooo`03o`000?oooooooooo
06kooooo00?o0000ool00?ooool0K_ooool00ooo003o0000ooooo`1Rooooo`008Oooool3o`0006go
oooo00?o0000ool00?ooool0L?ooool00ooo003o0000o`00001Qooooo`008Oooool00ol0003ooooo
ooooo`1/ooooo`03o`000?oo003ooooo07Cooooo00?o0000ooooooooool0G_ooool0027ooooo00?o
0000ooooooooool0K?ooool00ooo003oooooooooo`1eooooo`03o`000?oooooooooo05gooooo000Q
ooooo`03o`000?oooooooooo06_ooooo00?o0000ool00?ooool0Moooool2o`0005gooooo000Qoooo
o`03o`000?oooooooooo06[ooooo00?o0000ool00?ooool0N_ooool00ol0003oooooooooo`1Joooo
o`008Oooool00ol0003oooooooooo`1Zooooo`03ool00?oooooooooo07_ooooo00?o0000oooooooo
ool0FOooool0027ooooo00?o0000ooooooooool0JOooool00ol0003oo`00ooooo`1mooooo`;oo`00
FOooool0027ooooo0ol0001Xooooo`03o`000?oo003ooooo083ooooo00?oo`00ooooooooool0E_oo
ool0027ooooo00?o0000ooooooooool0Ioooool00ol0003oo`00ooooo`22ooooo`03ool00?oooooo
oooo05Gooooo000Qooooo`03o`000?oooooooooo06Oooooo00?o0000ool00?ooool0Poooool00ooo
003o0000ooooo`1Dooooo`008Oooool00ol0003oooooooooo`1Vooooo`03o`000?oo003ooooo08Go
oooo00?oo`00o`000?ooool0Doooool0027ooooo00?o0000ooooooooool0IOooool00ol0003oo`00
ooooo`27ooooo`;oo`00Doooool0027ooooo00?o0000ooooooooool0IOooool00ol0003ooooooooo
o`29ooooo`03ool00?oooooooooo053ooooo000Qooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool0Roooool00ooo003o0000ooooo`1?ooooo`008Oooool00ol0003oooooooooo`1Soooo
o`03o`000?oooooooooo08gooooo00?oo`00o`000?ooool0C_ooool0027ooooo0ol0001Rooooo`03
o`000?oooooooooo08oooooo00?oo`00o`000?ooool0COooool0027ooooo00?o0000ooooooooool0
H_ooool00ol0003oooooooooo`2@ooooo`03ool00?l0003o000004cooooo000Qooooo`03o`000?oo
oooooooo067ooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`19ooooo`008Oooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool0B?ooool0
027ooooo00?o0000ooooooooool0Goooool00ooo003o0000ooooo`2Hooooo`03o`000?oooooooooo
04Oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo05oooooo00?oo`00ooooooooool0VOooool0
0ol0003oooooooooo`16ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0G_ooool00ooo003oooooooooo`2K
ooooo`03o`000?oooooooooo04Gooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00;ooooo0ol0001Nooooo`03ool00?oooooooooo09cooooo00?o0000
ooooooooool0A?ooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00?ooooo00?o0000ooooooooool0GOooool00ooo003oooooooooo`2Mooooo`;oo`00AOooool0
00Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?oo
ool00ol0003oooooooooo`1Looooo`03ool00?l0003ooooo0:3ooooo00?oo`00ooooooooool0@_oo
ool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0G?ooool00ooo003oooooooooo`2Qooooo`03ool00?oooooooooo047ooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo05_ooooo00?oo`00ooooooooool0Xoooool00ooo003oooooooooo`10ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo05_ooooo00?o
o`00ooooooooool0Y?ooool2ool0043ooooo000Qooooo`03o`000?oooooooooo05[ooooo00?oo`00
ooooooooool0Yoooool00ooo003oooooooooo`0mooooo`008Oooool00ol0003oooooooooo`1Joooo
o`03ool00?oooooooooo0:Sooooo00?oo`00ooooooooool0??ooool0027ooooo0ol0001Iooooo`03
ool00?oooooooooo0:[ooooo00?oo`00ooooooooool0>oooool0027ooooo00?o0000ooooooooool0
F?ooool00ooo003oooooooooo`2/ooooo`03ool00?oooooooooo03[ooooo000Qooooo`03o`000?oo
oooooooo05Sooooo00?oo`00ooooooooool0[Oooool00ooo003o0000ooooo`0iooooo`008Oooool0
0ol0003oooooooooo`1Gooooo`03ool00?oooooooooo0:oooooo00?oo`00o`000?ooool0>?ooool0
027ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo
03Kooooo000Qooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0/oooool00ol0003o
ooooooooo`0eooooo`008Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo0;Gooooo
00?o0000ooooooooool0=?ooool0027ooooo0ol0001Eooooo`03o`000?oooooooooo0;Kooooo0_l0
000dooooo`008Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo0;Wooooo00?o0000
ooooooooool0<Oooool0027ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo033ooooo000Qooooo`03o`000?oooooooooo05?ooooo00?o0000oooooooo
ool0_?ooool2ool0033ooooo000Qooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0
_Oooool00ol0003oo`00ooooo`0^ooooo`008Oooool00ol0003oooooooooo`1Aooooo`03ool00?l0
003ooooo0<3ooooo00?o0000ool00?ooool0;Oooool0027ooooo00?o0000ooooooooool0DOooool0
0ooo003oooooooooo`31ooooo`03o`000?oo003ooooo02cooooo000Qooooo`03o`000?oooooooooo
053ooooo00?oo`00o`000?ooool0`oooool00ol0003oo`00ooooo`0[ooooo`008Oooool3o`00053o
oooo00?oo`00ooooooooool0a?ooool00ol0003oo`00ooooo`0Zooooo`008Oooool00ol0003ooooo
ooooo`0mooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4ool00?l0
003o<S8bomgMg@0mooooo`Co000000?o410@ooooooooool0>oooool4o`000003oa0@4?oooooooooo
00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0<Oooool00ol0003oo`00ooooo`09
ooooo`Go00006oooool0027ooooo00?o0000ooooooooool0?Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B46ooooo`04ool00?ooooooMgMgoc8b<Soooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0aooooo`03o`000?oo
003ooooo00Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003ooooooooo
o`0mooooo`05oa0@4?ooooooooooooooool@41003?ooool01Ooo003o0000oooooooooooo000003oo
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo037o
oooo00?o0000ool00?ooool02?ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003ooooo
ooooo`0mooooo`05o`000?ooooooooooooooool000003?ooool01Ooo003ooooooooooomgMgOo<S8b
03oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo
03?ooooo00?oo`00o`000?ooool02?ooool00onHV9So8B4Qonk^kP0Kooooo`008Oooool00ol0003o
ooooooooo`0mooooo`05o`000?ooooooooooooooool000002oooool01_oo003o0000ob4Q8Ol0003o
<S8bolc<c3oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`0=Oooool00ooo003o0000ooooo`08ooooo`03ogMgMomVIVKooooo01[ooooo
000Qooooo`03o`000?oooooooooo03gooooo00Go410@oooooooooooooooooa0@400;ooooo`03ool0
0?l0003ooooo04;ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo03Sooooo00?oo`00o`000?ooool02?ooool00ol0003oooooooooo`0Iooooo`008Ooo
ool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`03ool00?oooooo000004?ooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool00_ooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`03o`00
0?oooooooooo03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`03ool00?oooooo000000?o
0000?_ooool00omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000jooooo`09
o`000?oooooooooooooooonHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qooooo`03o`000?oooooo
oooo04_ooooo00?oo`00ooooooooool0doooool2o`00027ooooo000Qooooo`03o`000?oooooooooo
04_ooooo00?oo`00ooooooooool0eOooool00ol0003oooooooooo`0Nooooo`008Oooool00ol0003o
ooooooooo`1:ooooo`03ool00?oooooooooo0=Oooooo00?o0000ooooooooool07Oooool0027ooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`3Iooooo`03o`000?oooooooooo01;ooooo
0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`3Iooooo`;oo`004oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooooooo0000
<_l000000ooo003o0000o`000005o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo
00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo0_l0000=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
0_l0000>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Aooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`;o0000B?ooool00ol0003ooooo
ooooo`3`ooooo`;o00000_ooool2o`0000Cooooo000Qooooo`;o000000?oo`00ooooooooool0A?oo
ool00ol0003oooooooooo`3kooooo`008Oooool00ol0003oooooool00016ooooo`03o`000?oooooo
oooo0?_ooooo000Qooooo`04o`000?oooooo0000ool004?ooooo00?oo`00o`000?ooool0oOooool0
027ooooo00Co0000ooooool0003oo`00@oooool00ooo003oooooooooo`3mooooo`008Oooool3o`00
0003ool00?oooooooooo043ooooo00?oo`00o`000?ooool0o_ooool0027ooooo00Go0000oooooooo
oooo0000ool00011ooooo`03ool00?oooooooooo0?kooooo000Qooooo`05o`000?oooooooooooooo
oooo0000@?ooool00ooo003o0000ooooo`3oooooo`008Oooool01Ol0003oooooooooooooooooo`00
043ooooo00?oo`00ooooooooool0ooooool0027ooooo00Ko0000ooooooooooooooooo`000?oo000n
ooooo`03ool00?l0003ooooo0?oooooo0Oooool0027ooooo00?o0000ooooooooool00_ooool00ooo
003oooooooooo`0looooo`03ool00?oooooooooo0?oooooo0Oooool0027ooooo00?o0000oooooooo
ool00_ooool00ooo003oooooooooo`0kooooo`03ool00?l0003ooooo0?oooooo0_ooool0027ooooo
0ol00002ooooo`03o`000?oo003ooooo03_ooooo00?oo`00ooooooooool0ooooool2ooooo`008Ooo
ool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo03Wooooo00?oo`00o`000?ooool0oooo
ool3ooooo`008Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo03Wooooo00?oo`00
ooooooooool0ooooool3ooooo`008Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo
03Oooooo00?oo`00ooooooooool0ooooool4ooooo`008Oooool00ol0003oooooooooo`04ooooo`03
o`000?oo003ooooo03Oooooo00?oo`00ooooooooool0ooooool4ooooo`008Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo03Gooooo00?oo`00ooooooooool0ooooool5ooooo`008Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0oooo
ool5ooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool0ooooool6ooooo`008Oooool3o`0000Kooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`3oooooo`Kooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`3oooooo`Oooooo000Qooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`3oooooo`Sooooo000Qooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`3oooooo`Sooooo000Q
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`3o
ooooo`Wooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`3oooooo`[ooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ool00?oo
ool0;?ooool00ooo003o0000ooooo`3oooooo`_ooooo000Qooooo`?o00002Oooool00ooo003ooooo
ooooo`0[ooooo`03ool00?oooooooooo0?oooooo2oooool0027ooooo00?o0000ooooooooool02Ooo
ool00ooo003oooooooooo`0Zooooo`03ool00?oooooooooo0?oooooo3?ooool0027ooooo00?o0000
ooooooooool02_ooool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo0?oooooo3Oooool0
027ooooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo
0?oooooo3Oooool0027ooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`0Vooooo`03
ool00?oooooooooo0?oooooo3_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool03?ooool00ooo
003oooooooooo`0Tooooo`03ool00?oooooooooo0?oooooo3oooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo
00cooooo00?oo`00ooooooooool09?ooool00ooo003oooooooooo`3oooooo`oooooo0007ooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o00003Oooool00ooo
003oooooooooo`0Rooooo`03ool00?oooooooooo0?oooooo4?ooool000Oooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool03Oooool00ooo
003oooooooooo`0Qooooo`03ool00?oooooooooo0?oooooo4Oooool000Oooooo00Go0000oooooooo
ooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0>
ooooo`03ool00?oooooooooo023ooooo00?oo`00ooooooooool0oooooolAooooo`001oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?
ooooo`03ool00?oooooooooo01kooooo00?oo`00ooooooooool0oooooolBooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?
ooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool0oooooolCooooo`001oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo013ooooo00?oo`00
ooooooooool06oooool00ooo003oooooooooo`3ooooooaCooooo000Qooooo`03o`000?oooooooooo
013ooooo00?oo`00ooooooooool06_ooool00ol0003oooooooooo`3ooooooaGooooo000Qooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`3ooooooaKo
oooo000Qooooo`?o00004_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0?oooooo
5oooool0027ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo0?oooooo6?ooool0027ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0A
ooooo`;o0000oooooolKooooo`008Oooool00ol0003oooooooooo`0Eooooo`;o00004?ooool00ol0
003oooooooooo`3ooooooa_ooooo000Qooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool02oooool00ol0003oo`00ooooo`3ooooooagooooo000Qooooo`03o`000?oooooooooo01Oooooo
00?o0000ool00?ooool02_ooool00ol0003oo`00ool0003ooooooakooooo000Qooooo`03o`000?oo
oooooooo01Sooooo0_oo00000ol0003oooooooooo`05ooooo`?oo`00oooooolPooooo`008Oooool3
o`0001[ooooo2?oo003oooooob?ooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00Z?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo
0:?ooooo0027ooooo`?o00004oooool00olQ8B7ogMgMooooo`07ooooo`03omgMgOl@413ok^k^01So
oooo00?ok^k^oa0@4?oMgMd0Xoooool007kooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^
00?ooooo00?o0000ooooooooool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00?oV9RH
oeEEEOooool01oooool01?mEEEGoV9RHooooooooool5o`0000Wooooo00?oEEEEojVYZOooool00_oo
ool00onj^[[oA4A4ooooo`02ooooo`03ohN7QomVIVKooooo01;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM07[ooooo001nooooo`07oa0@
4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP03ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj
^_o^k^koMgMgoa0@4003ooooo`03o`000?oMgMgooooo00Kooooo00Wo0000oooooooooooooooooiRH
V?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P?ooooo00?ok^k^
o`000?ooool02oooool6o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0NOooool007kooooo00Oo0000oooooooMgMgo<S8booooooo^k^ko410@00?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`;oMgMg1oooool00olb<S;o
ooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co410@omgMgOoooooo00001Oooool00ol0
003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`1h
ooooo`00O_ooool01?mEEEGoZJVYooooool00002ooooo`05o`000?ooooooooooooooool000003Ooo
ool00ol0003oooooooooo`05ooooo`03onk^k_l@413ok^k^00Kooooo00?o<S8booooooooool00ooo
ool00onHV9So8B4Qonk^kP0;ooooo`04ohN7QomVIVKoooooo`0000Gooooo00?o0000ooooooooool0
2_ooool6o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool03Oooool00omgMgOo<S8b
ooooo`1iooooo`00O_ooool00ooMgMgo8B4Qonk^kP03ooooo`03o`000?oooooooooo00;o00003Ooo
ool00ol0003oooooooooo`06ooooo`03oeEEEOnHV9Sooooo00Gooooo00?o0000onk^k_ooool01?oo
ool00omgMgOoIVIVooooo`0:ooooo`04omgMgOl@413oooooo`0000Cooooo00?ok^k^o`000?ooool0
4_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c01joooo
o`00Ooooool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo00gooooo00?o410@o`000?l0
00000ol00005ooooo`03omgMgOl@413ooooo00Gooooo00?oEEEEogMgMoooool01Oooool00ol0003o
ooooooooo`08ooooo`Oo00000_ooool00omgMgOoEEEEooooo`0Booooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`1looooo`00U_ooool00ol0003oooooooooo`07ooooo`03
oeEEEOnHV9Sooooo00Cooooo00WogMgMoa0@4?o^k^koooooo`000?nj^[[ooooooiRHV?l@41004_oo
ool00oo^k^ko410@omgMg@0Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`1looooo`00U_ooool00ol0003oooooooooo`07ooooo`03okZj^_m4A4Cooooo00Gooooo00So
MgMgofIVI_ooooooV9RHoa0@4?l0003o8B4Qolc<c1;ooooo00?oIVIVogMgMoooool04oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0001kooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.55) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .33801 L
.06244 .36625 L
.08426 .39201 L
.0949 .40185 L
.10458 .40899 L
.10911 .41171 L
.11403 .41421 L
.11828 .41597 L
.12297 .41749 L
.12553 .41813 L
.12793 .41861 L
.13047 .41899 L
.13189 .41915 L
.13319 .41926 L
.13439 .41933 L
.13551 .41937 L
.13673 .41939 L
.13803 .41937 L
.13928 .41932 L
.14045 .41925 L
.1415 .41916 L
.14264 .41905 L
.14501 .41872 L
.14755 .41825 L
.15214 .4171 L
.1576 .41523 L
.16257 .41307 L
.17339 .40696 L
.18364 .39951 L
.22197 .36041 L
.26275 .30668 L
.30202 .25136 L
.33977 .20064 L
.37997 .15341 L
.41866 .11673 L
.43831 .10168 L
.4598 .08802 L
.48033 .07767 L
.49942 .07035 L
.50995 .06725 L
.51988 .0649 L
.5288 .06327 L
.53379 .06255 L
.53847 .062 L
.54303 .06158 L
.54793 .06124 L
.55072 .06111 L
.5521 .06106 L
.55337 .06102 L
Mistroke
.55452 .06099 L
.55575 .06096 L
.55645 .06096 L
.55711 .06095 L
.55834 .06094 L
.55957 .06094 L
.56026 .06095 L
.56091 .06095 L
.56222 .06097 L
.56295 .06098 L
.56362 .061 L
.5661 .06107 L
.56846 .06117 L
.57118 .06132 L
.5737 .06149 L
.57939 .06198 L
.58904 .06315 L
.59809 .06462 L
.61871 .06928 L
.63893 .07546 L
.65744 .08241 L
.69712 .10093 L
.73528 .12273 L
.77589 .14938 L
.81499 .17768 L
.85654 .20988 L
.89658 .24235 L
.93509 .2744 L
.97607 .30891 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36391 L
.08255 .38793 L
.0932 .39807 L
.10458 .40662 L
.11009 .40988 L
.11531 .4124 L
.11999 .41421 L
.1224 .41497 L
.12507 .41568 L
.12739 .41618 L
.12988 .41661 L
.13126 .41679 L
.13252 .41692 L
.13379 .41703 L
.13499 .4171 L
.13609 .41714 L
.13726 .41715 L
.13837 .41714 L
.13937 .41712 L
.14055 .41706 L
.14183 .41697 L
.14304 .41685 L
.14415 .41672 L
.14661 .41635 L
.14885 .41592 L
.15389 .41462 L
.15855 .41301 L
.16298 .41114 L
.17287 .40581 L
.18364 .39831 L
.20341 .38054 L
.22442 .3571 L
.26217 .30757 L
.30238 .25138 L
.34106 .20025 L
.3822 .15348 L
.42183 .11792 L
.45994 .09294 L
.47955 .08349 L
.5005 .0758 L
.51074 .07292 L
.52184 .07041 L
.53233 .06861 L
.54199 .06743 L
.54667 .06703 L
.54924 .06685 L
.55169 .06671 L
.55396 .0666 L
.55515 .06655 L
Mistroke
.55643 .06651 L
.55761 .06648 L
.55867 .06645 L
.55975 .06644 L
.56076 .06642 L
.56196 .06641 L
.56327 .06641 L
.56394 .06641 L
.56465 .06642 L
.56593 .06643 L
.56721 .06645 L
.56841 .06648 L
.57068 .06654 L
.57335 .06665 L
.57582 .06678 L
.5814 .06717 L
.58604 .06759 L
.59105 .06816 L
.6001 .06945 L
.61086 .07142 L
.62072 .07364 L
.63968 .079 L
.66039 .0864 L
.701 .10526 L
.7401 .12814 L
.78165 .15637 L
.82169 .1861 L
.8602 .21601 L
.90118 .24852 L
.94063 .28029 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`2Loooooa;o0000U_ooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooo
oooo09Oooooo1Ol0000Booooo`Ko0000T?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`2Dooooo`?o00002Oooool5ool000[ooooo0_oo0003ooooo`?o0000SOooool000oo
oooo1_l00005ooooo`03o`000?oooooooooo00Cooooo0ol0002Aooooo`?o00007Oooool7ool000?o
0000ROooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2>ooooo`?o0000
0oooool2ool002;ooooo0ooo0004o`0008Gooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0Roooool3o`0000?ooooo0ooo000Wooooo`?oo`0000?oooooo`000?l00000Pooo
ool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`29ooooo`;o00000oooool3
ool002gooooo00?oo`00ooooooooool00_l00021ooooo`006_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo08Oooooo0_l00002ooooo`?oo`00=Oooool2o`0007oooooo000Hooooo`03
oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0QOooool2o`000004oooooooo003oo`00ool0
03[ooooo0ol0001looooo`008Oooool00ol0003oooooooooo`24ooooo`04o`000?ooooooooooool0
043ooooo0ol0001iooooo`008Oooool00ol0003oooooooooo`22ooooo`;o0000A?ooool2ool00003
ooooool0003o000007Oooooo000Qooooo`?o0000POooool00ol0003oooooooooo`16ooooo`;oo`00
00Coooooo`000?l0003o0000M?ooool0027ooooo00?o0000ooooooooool0P?ooool00ol0003ooooo
ooooo`19ooooo`?oo`0000?oooooo`000?l00000L_ooool0027ooooo00?o0000ooooooooool0O_oo
ool2o`0004oooooo0_oo00000ooooooo0000o`00001`ooooo`008Oooool00ol0003oooooooooo`1m
ooooo`03o`000?oooooooooo057ooooo0_oo00000ooooooo0000ooooo`1^ooooo`008Oooool00ol0
003oooooooooo`1kooooo`;o00000_oo001Dooooo`;oo`000_l0001]ooooo`008Oooool00ol0003o
ooooooooo`1jooooo`03o`000?ooooooo`0005Sooooo00Coo`00ooooool0003o0000Joooool0027o
oooo00?o0000ooooooooool0NOooool00ol0003oooooool0001Jooooo`04ool00?ooooooooooo`00
06[ooooo000Qooooo`?o0000N?ooool00ol0003oo`00ool0001Oooooo`;o0000J?ooool0027ooooo
00?o0000ooooooooool0Moooool00ol0003oo`00ooooo`1Rooooo`;o0000I_ooool0027ooooo00?o
0000ooooooooool0M_ooool00ol0003oo`00ooooo`1Uooooo`03o`000?oooooooooo06?ooooo000Q
ooooo`03o`000?oooooooooo07Gooooo00?o0000ool00?ooool0Ioooool00ol0003oooooooooo`1R
ooooo`008Oooool00ol0003oooooooooo`1dooooo`03o`000?oo003ooooo06Wooooo0_l0001Roooo
o`008Oooool00ol0003oooooooooo`1cooooo`03o`000?oo003ooooo06Wooooo0_oo00000ooooooo
0000ooooo`1Pooooo`008Oooool00ol0003oooooooooo`1booooo`03o`000?oo003ooooo06cooooo
00?oo`00ooooool00000H?ooool0027ooooo0ol0001aooooo`03o`000?oo003ooooo06kooooo0_oo
0002o`0005kooooo000Qooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool2
ool00003o`000?oooooooooo05_ooooo000Qooooo`03o`000?oooooooooo06oooooo00?o0000oooo
ooooool0M?ooool00ooo003o0000ooooo`1Kooooo`008Oooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo07Kooooo0_oo00000ol0003oooooooooo`1Hooooo`008Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo07Wooooo00?oo`00o`000?ooool0F?ooool0027ooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`1jooooo`;oo`0000?o0000ooooooooool0EOoo
ool0027ooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1mooooo`03ool00?l0003o
oooo05Gooooo000Qooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0P?ooool2o`00
05Cooooo000Qooooo`?o0000J_ooool00ooo003oooooooooo`23ooooo`03o`000?oooooooooo057o
oooo000Qooooo`03o`000?oooooooooo06Wooooo00?oo`00ooooooooool0QOooool2o`00057ooooo
000Qooooo`03o`000?oooooooooo06Sooooo00?oo`00ooooooooool0R?ooool00ol0003ooooooooo
o`1>ooooo`008Oooool00ol0003oooooooooo`1Wooooo`03ool00?oooooooooo08[ooooo0_l0001>
ooooo`008Oooool00ol0003oooooooooo`1Vooooo`03ool00?oooooooooo08gooooo00?o0000oooo
ooooool0Boooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0IOooool00ooo003o0000ooooo`2=
ooooo`;oo`0000?o0000ooooooooool0B_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo06Cooooo00?oo`00
o`000?ooool0T?ooool2ool00003o`000?oooooooooo04Sooooo0005o`0000;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0001Sooooo`03ool00?l0003o
oooo09?ooooo00?oo`00o`000?ooool0B?ooool000Oooooo00Go0000ooooooooooooooooo`00000?
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0H_ooool00ooo003o0000ooooo`2E
ooooo`03ool00?l0003ooooo04Oooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0HOooool00ooo003o0000oooo
o`2Gooooo`03ool00?l0003ooooo04Kooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo063ooooo00?oo`00o`000?ooool0VOoo
ool00ooo003o0000o`000015ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`1Pooooo`03ool00?oooooooooo09[ooooo00?o
o`00ooooool00000A?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`1Pooooo`03ool00?oooooooooo09_ooooo00?oo`00ooooool00000@ooo
ool0027ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`2Mooooo`04ool00?oooooo
0000o`00047ooooo000Qooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0Woooool0
1?oo003oooooooooool00010ooooo`008Oooool3o`0005gooooo00?o0000ooooooooool0XOooool0
1?oo003oooooooooool0000oooooo`008Oooool00ol0003oooooooooo`1Looooo`03o`000?oooooo
oooo0:Kooooo00?o0000ooooooooool0??ooool0027ooooo00?o0000ooooooooool0G?ooool00ol0
003oooooooooo`2Wooooo`03o`000?oooooooooo03_ooooo000Qooooo`03o`000?oooooooooo05_o
oooo00?o0000ooooooooool0ZOooool2o`0003_ooooo000Qooooo`03o`000?oooooooooo05[ooooo
00?o0000ooooooooool0[?ooool00ol0003oooooooooo`0hooooo`008Oooool00ol0003ooooooooo
o`1Iooooo`03ool00?oooooooooo0:kooooo00?o0000ooooooooool0=oooool0027ooooo00?o0000
ooooooooool0F?ooool00ol0003oo`00ooooo`2_ooooo`;oo`00>?ooool0027ooooo0ol0001Hoooo
o`03ool00?oooooooooo0;7ooooo00?oo`00ooooooooool0=Oooool0027ooooo00?o0000oooooooo
ool0Eoooool00ooo003oooooooooo`2cooooo`03ool00?oooooooooo03Cooooo000Qooooo`03o`00
0?oooooooooo05Kooooo00?oo`00ooooooooool0]Oooool00ooo003o0000ooooo`0cooooo`008Ooo
ool00ol0003oooooooooo`1Eooooo`03ool00?oooooooooo0;Oooooo0_oo000cooooo`008Oooool0
0ol0003oooooooooo`1Dooooo`03ool00?oooooooooo0;[ooooo00?oo`00ooooooooool0<?ooool0
027ooooo00?o0000ooooooooool0E?ooool00ooo003oooooooooo`2kooooo`03ool00?oooooooooo
02oooooo000Qooooo`03o`000?oooooooooo05?ooooo00?oo`00ooooooooool0_Oooool00ooo003o
ooooooooo`0^ooooo`008Oooool00ol0003oooooooooo`1Booooo`03o`000?oo003ooooo0;oooooo
00?oo`00o`000?ooool0;Oooool0027ooooo0ol0001Booooo`03ool00?oooooooooo0<3ooooo00?o
o`00o`000?ooool0;?ooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000ool00?oMgMd0?Oooool4o`000003oa0@
4?oooooooooo03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM02oooooo00?oo`00o`000?ooool02oooool5o`0001_ooooo000Qooooo`03o`00
0?oooooooooo03gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003o
o`00oc8b<P0oooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01?ooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool0<?ooool00ol0003oooooooooo`09ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@06oooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo410@
00kooooo00?oo`00ooooool00000?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`09ooooo`03oiRHV?lQ8B7ok^k^
01cooooo000Qooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000=oooo
o`04o`000?ooooooMgMgoc8b<Soooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>
ooooo`03ogMgMolb<S;ooooo03;ooooo0_l0000:ooooo`03oiRHV?lQ8B7ok^k^01_ooooo000Qoooo
o`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`0?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00eooooo`03o`000?oooooooooo00Sooooo00?oMgMgofIVI_ooool0
6_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Wooooo
000Qooooo`?o0000?Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo0_l00013ooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0iooooo`;o0000
1?ooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`03o`000?oooooooooo03gooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`03o`000?oooooo000000?o0000?_ooool00omEEEGo
IVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000iooooo`;oo`000oooool01OnHV9So
410@o`000?lQ8B7oc<c<01_ooooo000Qooooo`03o`000?oooooooooo04cooooo00?o0000oooooooo
ool0d_ooool00ooo003oooooooooo`0Pooooo`008Oooool00ol0003oooooooooo`1;ooooo`03o`00
0?oooooooooo0=Cooooo00?oo`00ooooooooool07oooool0027ooooo00?o0000ooooooooool0B_oo
ool00ol0003oooooooooo`3Fooooo`;oo`007oooool0027ooooo00?o0000ooooooooool0BOooool0
0ooo003o0000ooooo`3Iooooo`03ool00?oooooooooo01;ooooo0_l00002ooooo`;o00001?ooool0
027ooooo00?o0000ooooooooool0BOooool00ooo003oooooooooo`3Jooooo`03ool00?oooooooooo
017ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0003o
000004So000000?oo`00o`000?l00000g?l000000ooo003o0000o`000005o`0000cooooo00CogMgM
o`000?l@413oc<c<1Oooool0027ooooo00?o0000ool00?ooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo0_l0000=
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?oo`00o`000?ooool03Oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool01?lQ8B7oMgMgogMgMolb
<S85ooooo`008Oooool00ol0003oooooo`000016ooooo`03ool00?oooooooooo0?7ooooo0_l00002
ooooo`;o00001?ooool0027ooooo00?o0000ooooool00000AOooool00ooo003oooooooooo`3loooo
o`008Oooool01?l0003oooooooooool00013ooooo`03ool00?oooooooooo0?gooooo000Qooooo`05
o`000?ooooooooooooooool00000@_ooool00ooo003oooooooooo`3mooooo`008Oooool01Ol0003o
oooooooooooooooo0000047ooooo00?oo`00ooooooooool0o_ooool0027ooooo0ol00002ooooo`03
o`000?oooooooooo03gooooo00?oo`00ooooooooool0ooooool0027ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0kooooo`03ool00?oooooooooo0?oooooo0Oooool0027ooooo00?o
0000ooooooooool00oooool00ol0003oo`00ooooo`0jooooo`03ool00?oooooooooo0?oooooo0_oo
ool0027ooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`0hooooo`03o`000?oooooo
oooo0?oooooo0oooool0027ooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`0goooo
o`03o`000?oooooooooo0?oooooo0oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003o
o`00ooooo`0fooooo`03o`000?oooooooooo0?oooooo1?ooool0027ooooo00?o0000ooooooooool0
1_ooool00ol0003oo`00ooooo`0dooooo`03o`000?oooooooooo0?oooooo1Oooool0027ooooo0ol0
0007ooooo`03ool00?oooooooooo03;ooooo00?o0000ooooooooool0ooooool6ooooo`008Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oo003ooooo037ooooo00?o0000ooooooooool0ooooool7
ooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oo003ooooo033ooooo00?o0000oooo
ooooool0ooooool7ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oo003ooooo02ko
oooo00?o0000ooooooooool0ooooool8ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`00
0?ooooooo`0002gooooo00?oo`00ooooooooool0ooooool9ooooo`008Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?ooooooo`0002_ooooo00?oo`00ooooooooool0ooooool:ooooo`008Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?ooooooo`0002Wooooo00?oo`00ooooooooool0ooooool;
ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?ooooooo`0002Oooooo00?oo`00oooo
ooooool0ooooool<ooooo`008Oooool3o`0000gooooo00?o0000ooooooooool09?ooool2ool00?oo
oooo3oooool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Rooooo`03ool0
0?l0003ooooo0?oooooo3oooool0027ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Pooooo`03ool00?l0003ooooo0?oooooo4?ooool0027ooooo00?o0000ooooooooool04?ooool2
o`0001oooooo00?oo`00o`000?ooool0oooooolAooooo`008Oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo01_ooooo00?oo`00o`000?ooool0oooooolBooooo`008Oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01Wooooo00?oo`00o`000?ooool0oooooolCooooo`00
8Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Oooooo00?oo`00o`000?ooool0
oooooolDooooo`008Oooool3o`0001Gooooo0_oo000Fooooo`03o`000?oooooooooo0?oooooo5Ooo
ool0027ooooo00?o0000ooooooooool05_ooool00ol0003oo`00ooooo`0Booooo`;o0000oooooolH
ooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`000?oo003oo`00013ooooo00?o0000oooo
ooooool0oooooolHooooo`008Oooool00ol0003oooooooooo`0Jooooo`?oo`002oooool2o`000?oo
oooo6oooool0027ooooo00?o0000ooooooooool06oooool2o`0000Soo`000ol0003ooooooagooooo
0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@04ooooo`03o`000?oooooooooo01kooooo1_l0003oooooob7ooooo0007ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003o
ooooooooo`02ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooo
ooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0
003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hoooo
o`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?oo
ool3o`000?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo
00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`00
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00Y?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:Oooooo0023ooooo`?o0000
5?ooool00olQ8B7ogMgMooooo`06ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0
Yoooool007_ooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00;ooooo00?o0000oooooooo
ool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?oV9RHoeEEEOooool01_ooool00omE
EEGoV9RHooooo`02ooooo`Go00002Oooool00omEEEGoZJVYooooo`02ooooo`06okZj^_m4A4Cooooo
oooooon7QhOoIVIV5?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd00oooool01Om4A4Co0000o`000?lb<S;ogMgM07Gooooo001kooooo`07
oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP02ooooo`03o`000?oooooooooo00_ooooo00Go410@
okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oMgMgooooo00Gooooo00?o0000ooooooooool00_oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X2oooo
o`03onk^k_l0003ooooo00_ooooo1_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool01Oooool00omgMgOo<S8booooo`1dooooo`00Noooool01ol0
003oooooomgMgOlb<S;oooooonk^k_l@41000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Kooooo0_mgMgL6ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h03?oo
ool01?l@413ogMgMooooool00004ooooo`03o`000?oooooooooo01;ooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Loooool007_ooooo
00CoEEEEojVYZOoooooo00000_ooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo
00Kooooo00?ok^k^oa0@4?o^k^h01Oooool00olb<S;oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^
00_ooooo00CoQhN7ofIVI_oooooo00001?ooool00ol0003oooooooooo`0:ooooo`Ko00000_ooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01Oooool00omgMgOo<S8boooo
o`1dooooo`00Noooool00ooMgMgo8B4Qonk^kP03ooooo`04o`000?oooooo0000o`0000gooooo00?o
0000ooooooooool01oooool00omEEEGoV9RHooooo`04ooooo`03o`000?o^k^kooooo00Gooooo00?o
MgMgofIVI_ooool02_ooool01?oMgMgo410@ooooool00003ooooo`03onk^k_l0003ooooo01?ooooo
00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<07Gooooo001looooo`03oiRHV?mgMgOooooo00;ooooo00?o0000oooo
ooooool03?ooool00ol@413o0000o`000003o`0000Kooooo00?ogMgMoa0@4?ooool01?ooool00omE
EEGoMgMgooooo`06ooooo`03o`000?oooooooooo00Sooooo1ol000000oooooooMgMgoeEEE@0Doooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo07Oooooo002Booooo`03o`000?oooooooooo00Sooooo00?oEEEEoiRHV?ooool00oooool00ooM
gMgo410@onk^kP02ooooo`05o`000?nj^[[ooooooiRHV?l@41004Oooool00oo^k^ko410@omgMg@0D
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo07Oooooo002Booooo`03o`000?oooooooooo00Sooooo00?o^[ZjodA4A?ooool01?ooool0
2OmgMgOoIVIVooooooooooooV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`03ofIVI_mgMgOooooo01Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001?ooool4o`0007Kooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .2992 L
.06244 .2907 L
.06747 .28902 L
.07286 .28747 L
.07751 .28635 L
.08255 .28536 L
.08564 .28488 L
.08848 .28452 L
.0912 .28424 L
.09259 .28412 L
.09409 .28402 L
.09543 .28394 L
.09666 .28389 L
.0979 .28385 L
.09908 .28382 L
.09974 .28381 L
.10044 .28381 L
.10171 .2838 L
.10248 .28381 L
.10321 .28382 L
.10387 .28384 L
.10458 .28385 L
.10582 .2839 L
.10695 .28395 L
.1095 .28409 L
.11185 .28427 L
.11409 .28448 L
.11908 .28507 L
.12452 .28588 L
.14558 .29021 L
.16497 .29472 L
.17526 .29687 L
.18067 .29785 L
.18637 .29876 L
.19141 .29943 L
.19693 .30001 L
.19936 .30021 L
.20195 .30038 L
.2044 .30051 L
.20662 .3006 L
.2078 .30063 L
.20906 .30065 L
.21013 .30067 L
.21131 .30068 L
.21258 .30067 L
.21329 .30067 L
.21394 .30066 L
.2152 .30063 L
.2164 .3006 L
Mistroke
.21869 .30051 L
.22082 .3004 L
.22315 .30025 L
.22563 .30004 L
.23101 .29946 L
.23594 .29875 L
.24708 .2966 L
.2569 .29406 L
.26727 .29078 L
.30529 .27423 L
.34577 .25127 L
.38473 .22714 L
.42614 .20245 L
.46604 .18192 L
.50442 .16653 L
.52423 .16048 L
.53436 .15791 L
.54525 .15554 L
.55544 .15369 L
.56476 .15232 L
.57368 .15128 L
.58306 .15049 L
.58807 .15019 L
.59263 .14999 L
.59515 .14992 L
.59648 .14988 L
.59788 .14985 L
.59911 .14983 L
.59976 .14983 L
.60046 .14982 L
.60169 .14981 L
.60284 .14981 L
.60406 .14981 L
.6052 .14981 L
.60645 .14982 L
.60708 .14983 L
.60777 .14984 L
.61018 .14989 L
.61245 .14995 L
.61667 .1501 L
.62122 .15034 L
.62617 .15067 L
.63077 .15105 L
.64123 .15217 L
.65143 .15358 L
.66233 .15544 L
.68365 .16008 L
.70379 .16562 L
.74222 .17899 L
.78311 .19671 L
Mistroke
.82248 .21655 L
.86034 .23763 L
.90064 .26165 L
.93944 .28575 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .30003 L
.06244 .29044 L
.07286 .28645 L
.08255 .28366 L
.08813 .28249 L
.0932 .28169 L
.096 .28136 L
.09748 .28121 L
.09905 .28108 L
.10042 .28099 L
.10192 .2809 L
.1033 .28085 L
.10458 .28081 L
.10583 .28078 L
.10652 .28078 L
.10715 .28077 L
.10838 .28078 L
.10954 .28079 L
.1102 .2808 L
.1109 .28082 L
.11214 .28087 L
.11349 .28093 L
.11496 .28101 L
.11742 .28118 L
.12006 .28141 L
.12483 .28195 L
.13452 .28345 L
.14335 .28518 L
.16405 .28991 L
.1832 .29416 L
.19278 .29593 L
.20178 .29725 L
.2063 .29776 L
.21117 .2982 L
.2138 .29838 L
.21657 .29853 L
.21894 .29862 L
.22028 .29866 L
.22153 .29868 L
.2228 .2987 L
.22345 .2987 L
.22415 .2987 L
.22541 .29869 L
.22658 .29868 L
.22728 .29867 L
.22795 .29865 L
.22921 .29862 L
.23057 .29857 L
.23205 .2985 L
Mistroke
.23455 .29835 L
.2372 .29815 L
.24198 .29768 L
.24701 .29702 L
.25174 .29625 L
.26057 .29441 L
.27036 .2918 L
.28069 .28842 L
.29917 .28091 L
.3372 .26089 L
.37768 .2362 L
.41664 .21291 L
.45805 .1917 L
.47879 .18303 L
.49795 .17631 L
.51776 .17065 L
.53633 .16653 L
.55503 .16349 L
.56496 .16231 L
.5705 .16177 L
.57565 .16136 L
.58068 .16102 L
.58524 .16078 L
.59032 .16058 L
.5931 .1605 L
.59435 .16047 L
.59573 .16044 L
.59696 .16042 L
.59829 .16041 L
.59903 .1604 L
.59969 .16039 L
.601 .16039 L
.6022 .16038 L
.6035 .16039 L
.60473 .16039 L
.60586 .1604 L
.60717 .16041 L
.60839 .16043 L
.61118 .16048 L
.6139 .16056 L
.61684 .16066 L
.62179 .16087 L
.62639 .16113 L
.63686 .16192 L
.64705 .16295 L
.65795 .16434 L
.67927 .16791 L
.69941 .1723 L
.73785 .18339 L
.77873 .19891 L
Mistroke
.8181 .21704 L
.85596 .23679 L
.89627 .25969 L
.93506 .28317 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0:Gooooo7?l00023ooooo`008Oooool00ol0003oooooooooo`2Oooooo`Ko0000
7?ooool7o`0007cooooo000Qooooo`03o`000?oooooooooo09cooooo0ol0000Yooooo`?o0000NOoo
ool0027ooooo00?o0000ooooooooool0V?ooool4o`0001?ooooo4?oo000<ooooo`?o0000M_ooool0
027ooooo00?o0000ooooooooool0UOooool3o`0000Sooooo1Ooo000Jooooo`03ool00?oooooooooo
00cooooo0ol0001cooooo`008Oooool3o`0009;ooooo0ol00006ooooo`Goo`00:_ooool3ool000Co
oooo1?l0001_ooooo`008Oooool00ol0003oooooooooo`2?ooooo`?o00001Oooool4ool003;ooooo
0ooo0005ooooo`?o0000K?ooool0027ooooo00?o0000ooooooooool0SOooool2o`0000Kooooo0_oo
000iooooo`?oo`001Oooool3o`0006Wooooo000Qooooo`03o`000?oooooooooo08_ooooo0_l00016
ooooo`Goo`000oooool3o`0006Kooooo000Qooooo`03o`000?oooooooooo08Sooooo0ol0001=oooo
o`;oo`001?ooool2o`0006Cooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo08Kooooo0_l00002
ooooo`;oo`00E?ooool3o`00067ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`24ooooo`;o00000_ooool2
ool005Wooooo0_l0001Oooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`02ooooo`?o0000P_ooool2o`0000;ooooo0_oo001Mooooo`;o0000GOooool0
00Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000
ooooooooool0P?ooool2o`0000;ooooo0_oo001Mooooo`?oo`0000Coooooo`000?l0003o0000F_oo
ool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1?ooool00ol0003oooooooooo`1nooooo`;o00000_ooool2ool006;ooooo0ooo00000ooooooo0000
o`00001Hooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1looooo`;o00000_ooool2ool006Oooooo0_oo00000ooooooo0000
o`00001Fooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1jooooo`;o00000_ooool2ool006_ooooo0ooo0002o`0005Cooooo
0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0
NOooool01Ol0003oooooooooooooooooo`00073ooooo00?oo`00ooooool000000_l0001Aooooo`00
8Oooool00ol0003oooooooooo`1gooooo`;o0000N_ooool2o`0004oooooo000Qooooo`03o`000?oo
oooooooo07Gooooo0_l0001nooooo`;o0000COooool0027ooooo0ol0001dooooo`03o`000?oooooo
oooo083ooooo0_l0001;ooooo`008Oooool00ol0003oooooooooo`1booooo`;o0000QOooool2o`00
04Wooooo000Qooooo`03o`000?oooooooooo073ooooo0_l00002ool008Cooooo0_oo00000ooooooo
0000ooooo`17ooooo`008Oooool00ol0003oooooooooo`1_ooooo`03o`000?ooooooo`0008Sooooo
0_oo0002o`0004Kooooo000Qooooo`03o`000?oooooooooo06gooooo0_l00002ool008_ooooo0_oo
0002o`0004Cooooo000Qooooo`03o`000?oooooooooo06_ooooo0_l000000oooooooo`00ooooo`2>
ooooo`03ool00?oooooo000004?ooooo000Qooooo`03o`000?oooooooooo06[ooooo00Co0000oooo
ooooooooo`00TOooool2ool000;o0000@Oooool0027ooooo0ol0001Xooooo`;o000000?oooooool0
0?oo0000U?ooool2ool000;o0000?oooool0027ooooo00?o0000ooooooooool0I_ooool2o`000003
oooooooo003oo`0009Sooooo0_oo00000ol0003oooooooooo`0looooo`008Oooool00ol0003ooooo
ooooo`1Uooooo`04o`000?ooooooo`00ool009cooooo00?oo`00o`000?l00000??ooool0027ooooo
00?o0000ooooooooool0Hoooool2o`000003oooooooo003ooooo0:3ooooo00?o0000ooooooooool0
>Oooool0027ooooo00?o0000ooooooooool0HOooool2o`000:Kooooo0_l0000iooooo`008Oooool0
0ol0003oooooooooo`1Oooooo`;o0000Z_ooool00ol0003oooooooooo`0fooooo`008Oooool00ol0
003oooooooooo`1Mooooo`;o0000[Oooool2o`0003Kooooo000Qooooo`03o`000?oooooooooo05_o
oooo0_l0002aooooo`03o`000?oooooooooo03?ooooo000Qooooo`?o0000F_ooool00ol0003ooooo
ooooo`2booooo`;oo`00<oooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool2o`000003
oooooooo003oo`0003?ooooo1?l000000ol@413oooooooooo`0kooooo`Co000000?o410@oooooooo
ool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Zooooo`;oo`004Oooool5o`00
01_ooooo000Qooooo`03o`000?oooooooooo03gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`02ooooo`;o000000?oooooool00?oo0000=oooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
02_ooooo0_oo000?ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0027ooooo00?o0000oooo
ooooool0?Oooool01Ol@413ooooooooooooooooo410@013ooooo00Go0000ooooool0003o0000oooo
o`02ool003Wooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo02_ooooo00?o0000ool00?ooool03_ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool0
0ol0003oooooooooo`0mooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo0000o`00
0002ooooo`03ool00?oooooooooo03Wooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`0>ooooo`03ogMgMolb<S;ooooo02kooooo0_oo000>ooooo`03oiRHV?lQ8B7ok^k^01_ooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000<ooooo`06o`000?lQ
8B7o0000o`000?o<c<cooooo0_oo000looooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<037ooooo0_oo000=ooooo`03ogMgMomVIVKooooo
01[ooooo000Qooooo`03o`000?oooooooooo00oooooo2_oo000Tooooo`05oa0@4?oooooooooooooo
ool@41003?ooool2o`0000;ooooo0_oo000nooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0dooooo`03o`000?oo003ooooo00cooooo00?o0000oooo
ooooool06Oooool0027ooooo0ol0000<ooooo`?oo`001ol000000ooooooo0000o`000008o`000003
oooooooo003oo`0000?oo`005_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo0ol00003ool0
043ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
03Kooooo00?oo`00o`000?ooool01_ooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qoooo
o`03o`000?oooooooooo00[ooooo0_oo0002o`0001?ooooo1Ol000000oooooooo`00ool00003ool0
017ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o00000_ooool01?oo003o0000o`000?l0
000nooooo`03oeEEEOmVIVKo000003oooooo00?oEEEEofIVI_l000003Oooool4o`0003Kooooo00?o
o`00o`000?l000001Oooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qooooo`03o`000?oo
oooooooo00Sooooo0_oo000Looooo`?o00000oooool3ool001Wooooo0_l0003Eooooo`03o`000?oo
oooooooo02;ooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0000Qooooo`?o00000oooool4
ool000oooooo1_l0003Hooooo`;o00008_ooool0027ooooo00?o0000ooooooooool00_ooool3o`00
02Oooooo1ol0000:ooooo`Soo`00gOooool2o`00023ooooo000Qooooo`03o`000?oooooooooo00;o
0000<Oooool:o`000>Oooooo00?o0000ooooooooool04oooool2o`0000;ooooo0_l00004ooooo`00
8Oooool3o`000?oooooo9_ooool2o`0001?ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4oooo
o`006_ooool7o`0000?oo`00ool0000Wo`0000;oo`001ol0000<ooooo`04omgMgOl0003o410@olc<
c0Gooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Aooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`04ob4Q8OmgMgOoMgMgoc8b
<PGooooo000Qooooo`03o`000?oooooooooo0?oooooo>oooool2o`0000;ooooo0_l00004ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Co
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`000?oo
ooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?o
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0
003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool4o`000003oa0@4?oooooooooo
00;ooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo0ol0003oooooodGooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Sooooo00?oMgMgofIVI_oo
ool05oooool00omVIVKoMgMgooooo`2Sooooo`00Qoooool3o`0001?ooooo00?o8B4QomgMgOooool0
1oooool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@413ogMgM0:?ooooo001nooooo`07ohN7Qol0
003oEEEEofIVI_l0003o<S8bonk^kP03ooooo`03o`000?oooooooooo00_ooooo00GoV9RHo`000?l0
003oA4A4okZj^P02ooooo`03oiRHV?mEEEGooooo00Oooooo00CoEEEEoiRHV?oooooooooo1Ol00009
ooooo`03oeEEEOnYZJWooooo00;ooooo00?o^[ZjodA4A?ooool00_ooool00on7QhOoIVIVooooo`0B
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@
olc<c01kooooo`00O_ooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00oooool00ol0003o
ooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0003ogMgMooooo`06oooo
o`09o`000?oooooooooooooooonHV9So8B4Qonk^k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooo
oooooa0@4?nj^[X3ooooo`03onk^k_l0003ooooo00_ooooo1_l000001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40Noooool007kooooo00Oo
0000oooooooMgMgo<S8booooooo^k^ko410@00?ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`05ooooo`;oMgMg1oooool00olb<S;oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00co
oooo00Co410@omgMgOoooooo00001Oooool00ol0003oooooooooo`0Aooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000007_ooooo001nooooo`04oeEEEOnYZJWo
ooooo`0000;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00Gooooo
00?ok^k^oa0@4?o^k^h01_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00_ooooo
00CoQhN7ofIVI_oooooo00001Oooool00ol0003oooooooooo`0:ooooo`Ko000000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B40Noooool007ko
oooo00?ogMgMob4Q8Oo^k^h00oooool00ol0003oooooooooo`02o`0000gooooo00?o0000oooooooo
ool01_ooool00omEEEGoV9RHooooo`05ooooo`03o`000?o^k^kooooo00Cooooo00?oMgMgofIVI_oo
ool02_ooool01?oMgMgo410@ooooool00004ooooo`03onk^k_l0003ooooo01;ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0Noooool007oooooo00?oV9RH
ogMgMoooool00_ooool00ol0003oooooooooo`0=ooooo`03oa0@4?l0003o000000?o00001Oooool0
0ooMgMgo410@ooooo`05ooooo`03oeEEEOmgMgOooooo00Gooooo00?o0000ooooooooool02?ooool7
o`0000;ooooo00?oMgMgoeEEEOooool04_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o
EEEEohN7Qoooool0OOooool009Kooooo00?o0000ooooooooool01oooool00omEEEGoV9RHooooo`04
ooooo`09omgMgOl@413ok^k^ooooool0003o^[ZjoooooonHV9So410@01;ooooo00?ok^k^oa0@4?oM
gMd04oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0OOooool009Ko
oooo00?o0000ooooooooool01oooool00onj^[[oA4A4ooooo`05ooooo`08ogMgMomVIVKooooooiRH
V?l@413o0000ob4Q8Oo<c<`Booooo`03ofIVI_mgMgOooooo01?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@47_ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.65) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .2729 L
.06244 .23786 L
.08426 .20581 L
.0949 .19333 L
.10458 .18398 L
.11403 .17675 L
.12297 .17168 L
.12787 .16962 L
.1324 .16817 L
.13476 .16758 L
.13737 .16707 L
.13868 .16686 L
.14009 .16668 L
.14142 .16654 L
.14264 .16645 L
.14392 .16638 L
.14514 .16635 L
.14622 .16635 L
.1474 .16637 L
.14869 .16642 L
.14934 .16646 L
.15005 .16651 L
.15132 .16662 L
.15248 .16676 L
.15476 .16709 L
.15721 .16755 L
.16162 .16864 L
.16672 .17032 L
.17226 .1726 L
.18234 .1779 L
.20212 .19176 L
.22313 .2098 L
.26088 .24447 L
.28185 .2622 L
.30108 .27638 L
.32112 .28865 L
.33977 .29763 L
.35869 .30437 L
.3687 .30702 L
.37939 .30919 L
.38963 .31067 L
.39541 .31125 L
.39816 .31147 L
.40074 .31164 L
.40317 .31178 L
.4054 .31187 L
.40787 .31195 L
.40923 .31198 L
.41053 .31201 L
Mistroke
.41177 .31202 L
.41247 .31203 L
.4131 .31203 L
.41433 .31203 L
.41548 .31202 L
.41614 .31202 L
.41684 .31201 L
.41808 .31199 L
.41942 .31196 L
.42089 .31192 L
.42341 .31184 L
.42615 .31171 L
.43112 .31142 L
.43596 .31104 L
.44044 .31062 L
.46137 .30786 L
.48007 .3045 L
.50068 .30011 L
.54094 .29065 L
.57968 .28184 L
.59937 .27788 L
.62087 .27411 L
.64167 .27113 L
.66055 .26903 L
.67066 .26815 L
.6802 .26749 L
.69026 .26696 L
.69594 .26674 L
.69867 .26665 L
.70116 .26659 L
.70341 .26654 L
.70585 .26649 L
.70719 .26647 L
.70843 .26646 L
.7097 .26644 L
.71088 .26643 L
.71189 .26643 L
.71297 .26642 L
.71418 .26642 L
.71528 .26642 L
.71637 .26642 L
.71756 .26642 L
.7188 .26643 L
.71996 .26644 L
.72125 .26645 L
.72265 .26647 L
.72519 .26651 L
.72994 .26661 L
.73549 .26678 L
.74062 .26698 L
Mistroke
.75029 .26748 L
.75936 .26808 L
.77999 .26993 L
.80025 .27235 L
.81878 .27503 L
.85851 .28207 L
.89672 .29013 L
.93739 .29959 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .27199 L
.06244 .23587 L
.08255 .20557 L
.09409 .19184 L
.10458 .18186 L
.11464 .17456 L
.11926 .17195 L
.12415 .16968 L
.12937 .16783 L
.13169 .16718 L
.13419 .16661 L
.13687 .16614 L
.13807 .16597 L
.13938 .16582 L
.14017 .16575 L
.14091 .16569 L
.14167 .16564 L
.14236 .16561 L
.14368 .16557 L
.14441 .16556 L
.14509 .16556 L
.14625 .16558 L
.1475 .16563 L
.14867 .16571 L
.14974 .16579 L
.15237 .1661 L
.15485 .1665 L
.15979 .16759 L
.16517 .16924 L
.17476 .17324 L
.18364 .17803 L
.2023 .19093 L
.22291 .2083 L
.26311 .24579 L
.3018 .27888 L
.32144 .29264 L
.34294 .30467 L
.35286 .30911 L
.36346 .31307 L
.3734 .31605 L
.38256 .3182 L
.3928 .31995 L
.3982 .32061 L
.40095 .32088 L
.40391 .32112 L
.4065 .32129 L
.40886 .32141 L
.41 .32146 L
.41124 .3215 L
Mistroke
.41241 .32154 L
.4135 .32156 L
.41417 .32157 L
.41489 .32159 L
.41616 .3216 L
.41687 .3216 L
.41763 .3216 L
.41827 .3216 L
.41898 .3216 L
.42025 .32158 L
.42096 .32157 L
.42161 .32156 L
.42406 .32149 L
.42635 .32141 L
.42888 .32128 L
.434 .32095 L
.43874 .32054 L
.44318 .32008 L
.46396 .31706 L
.48418 .31309 L
.5027 .30891 L
.54237 .29954 L
.58053 .29144 L
.60182 .28768 L
.62115 .2848 L
.6415 .2823 L
.66024 .28047 L
.67947 .27902 L
.69022 .27839 L
.70028 .27791 L
.70935 .27756 L
.71908 .27729 L
.72462 .27717 L
.72735 .27713 L
.72988 .2771 L
.73212 .27707 L
.7346 .27705 L
.73588 .27704 L
.73709 .27704 L
.73836 .27703 L
.73907 .27703 L
.73973 .27703 L
.74101 .27703 L
.74221 .27703 L
.74329 .27703 L
.74446 .27704 L
.74574 .27704 L
.74709 .27705 L
.74952 .27707 L
.75176 .27709 L
Mistroke
.75386 .27712 L
.75863 .27721 L
.76384 .27733 L
.7686 .27747 L
.77932 .2779 L
.78918 .27843 L
.79832 .27904 L
.81905 .28087 L
.83959 .28331 L
.8582 .28604 L
.89829 .29317 L
.93686 .30077 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`0001kooooo3?oo003ooooooa_o
oooo000Qooooo`03o`000?oooooooooo01cooooo0_oo00000ol0003oooooooooo`07ooooo`;o0000
00?oo`00o`000?ooool0oooooolHooooo`008Oooool00ol0003oooooooooo`0Kooooo`03ool00?oo
oooooooo00kooooo0ol0003ooooooaKooooo000Qooooo`03o`000?oooooooooo01Wooooo0_l0000D
ooooo`;o0000oooooolDooooo`008Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0oooooolAooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0ooooool@ooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0Jooooo`;oo`00ooooool@ooooo`001Ol00002oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o00005Oooool0
0ol0003oooooooooo`0Looooo`03o`000?oo003oo`000?oooooo3_ooool000Oooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Nooooo`;o000000?oo`00ooooooooool0ooooool;ooooo`001oooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oo
oooooooo01;ooooo00?oo`00o`000?ooool08_ooool00ol0003oo`00ooooo`3oooooo`_ooooo0007
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01;ooooo00?oo`00ooooooooool08oooool00ol0003oo`00ooooo`3oooooo`[ooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo017ooooo00?oo`00ooooooooool09_ooool00ooo003oooooooooo`3oooooo`Sooooo0007
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool04?oo
ool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo0?oooooo1oooool0027ooooo00?o0000
ooooooooool04?ooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo0?oooooo1_ooool0
027ooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`0[ooooo`03ool00?oooooooooo
0?oooooo1Oooool0027ooooo0ol0000>ooooo`03ool00?oooooooooo02gooooo00?oo`00oooooooo
ool0ooooool4ooooo`008Oooool00ol0003oooooooooo`0=ooooo`03ool00?l0003ooooo02oooooo
00?oo`00ooooooooool0ooooool3ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03ool00?l0
003ooooo037ooooo00?o0000ooooooooool0ooooool2ooooo`008Oooool00ol0003oooooooooo`0<
ooooo`03ool00?oooooooooo03;ooooo00?o0000ooooooooool0ooooool1ooooo`008Oooool00ol0
003oooooooooo`0;ooooo`03ool00?oooooooooo03Cooooo00?o0000ooooooooool0ooooool0027o
oooo00?o0000ooooooooool02_ooool00ooo003o0000ooooo`0fooooo`03o`000?oooooooooo0?ko
oooo000Qooooo`03o`000?oooooooooo00Wooooo00?oo`00o`000?ooool0>?ooool00ol0003ooooo
ooooo`3mooooo`008Oooool3o`0000Wooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`3looooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool0noooool0027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0loooo
o`03ool00?l0003ooooo0?[ooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0?Oooool2ool00?[ooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
@?ooool00ooo003oooooooooo`3gooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo047ooooo00?oo`00ooooooooool0m_ooool0027ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`13ooooo`03ool00?oooooooooo0?Gooooo000Qooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0AOooool2ool00?Gooooo000Qooooo`?o00001Oooool00ol0003o
ooooooooo`16ooooo`03o`000?oo003ooooo0??ooooo000Qooooo`03o`000?oooooooooo00Cooooo
00?oo`00ooooooooool0=_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003oo`00oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo03;ooooo7?l000000olb
<S;ogMgMooooo`0looooo`Go00006oooool0027ooooo00?o0000ooooooooool01?ooool00ooo003o
ooooooooo`0fooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oo`00o`00
0?ooool0?_ooool00ol0003oooooooooo`0/ooooo`So00002oooool00ol0003oooooooooo`04oooo
o`;o8B4Q1_ooool;o`0003Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0
003oooooooooo`03ooooo`03ool00?oooooooooo03Oooooo00Go410@oooooooooooooooooa0@400@
ooooo`03ool00?l0003ooooo03gooooo00?o0000ooooooooool08Oooool;o`0001?ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`05ooooo`Ko0000<Oooool00onHV9So8B4Qonk^kP0L
ooooo`008Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo03Oooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;oo`0000;o0000??ooool00ol0003oooooooooo`0N
ooooo`?o00007_ooool00ol0003oooooooooo`06ooooo`Woo`0000?o<S8booooooooool02oooool6
o`0002cooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool00_ooool00ooo
003oooooooooo`0hooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00?ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Iooooo`Go00004Ooo
ool?ool00003ooooool0003ooooo00cooooo00Co0000ob4Q8Ol0003o<S8b2Ooo000;ooooo`Ko0000
9oooool00omgMgOoIVIVooooo`0Jooooo`008Oooool00ol0003oooooooooo`02ooooo`03ool00?oo
oooooooo03Sooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo
0_l0000iooooo`03o`000?oooooooooo01Cooooo1Ol0000Eooooo`03ool00?oooooooooo00kooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Dooooo`Ooo`001_l0000Rooooo`03o`00
0?oooooooooo01Wooooo000Qooooo`?o000000?oooooool00?ooool0>_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo013ooooo1?l0000<ooooo`Coo`006oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01_ooooo1_oo0006o`0001Sooooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`00
8Oooool01Ol0003oooooooooooooooooo`0003_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00002?ooool2o`0003Cooooo00?oEEEEofIVI_l000003_ooool4o`0000[ooooo1_oo000Moooo
o`03oeEEEOmVIVKo000000gooooo1?l0000Pooooo`?oo`000oooool5o`0001?ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00Kooooo`008Oooool01?l0003ooooooooooooo001Kooooo`;o0000?oooool4
o`0000Oooooo1ooo001Rooooo`Go0000;_ooool0027ooooo00?o0000oooooooo0000G?ooool2ool0
00;o0000>?ooool5o`0007Kooooo0ooo0004o`0002[ooooo000Qooooo`03o`000?ooooooo`0005ko
oooo0_oo0003o`00037ooooo1?l0001nooooo`?oo`0000?oooooo`000?l000000_l0000Vooooo`00
8Oooool00ol0003oo`00ooooo`1Pooooo`03ool00?oooooooooo00?o0000:Oooool5o`0000Oooooo
1?oo001jooooo`Ooo`000_l0000Hooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oo
003ooooo067ooooo0ooo0002ooooo`?o00008?ooool6o`0000Oooooo1Ooo0025ooooo`Coo`000_l0
000Dooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool001[ooooo1ol000000ooo003o0000
o`00001To`0000;oo`00:ol00005ool009Wo00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`00
8Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo003ooooo00Oooooo5Ol0000;ooooo`;oo`00
00?oooooo`000?ooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`04onk^k_lQ8B7o410@onk^kPGo
oooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo00000ooo0009ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo017ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000ooooooooool0
P_ooool3ool00;Gooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool0MOoo
ool=ool00<;ooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0
oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`000?ooooooAOooool000Oooooo00Go
0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0
oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o
<S8bolc<c004ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Go
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000oooooooo
ool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
AOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000J
ooooo`03o`000?oooooooooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00:Cooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMg
ooooo`2Wooooo`00Poooool3o`0001Cooooo00?o8B4QomgMgOooool01_ooool00ooMgMgo410@onk^
kP0Hooooo`03onk^k_l@413ogMgM0:Oooooo001kooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8b
onk^kP02ooooo`03o`000?oooooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03
oiRHV?mEEEGooooo00Kooooo00?oEEEEoiRHV?ooool00_ooool5o`0000Wooooo00?oEEEEojVYZOoo
ool00_ooool01_nj^[[oA4A4ooooooooooooQhN7ofIVIQCooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@1eooooo`00Noooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00_ooool00ol0
003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ogMgMooooo`05
ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00:ooooo`06oeEEEOnH
V9Soooooooooool@413o^[Zj0_ooool00oo^k^ko0000ooooo`0;ooooo`Ko00000_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401oooool0
0omgMgOo<S8booooo`1dooooo`00Noooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@41000_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo0_mgMgL6ooooo`03oc8b<_oo
oooooooo00?ooooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool00004ooooo`03o`00
0?oooooooooo01;ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool000002?ooool00ol0003oooooooooo`1cooooo`00Noooool01?mEEEGoZJVYooooool00002oooo
o`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool01_ooool00oo^k^ko410@onk^kP05
ooooo`03oc8b<_oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7QhOoIVIVooooool0
0004ooooo`03o`000?oooooooooo00[ooooo1_l00002ooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oV9RHoooooonHV9So8B4Q00Oooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo
00?ogMgMob4Q8Oo^k^h00oooool01?l0003oooooo`000?l0000=ooooo`03o`000?oooooooooo00Oo
oooo00?oEEEEoiRHV?ooool01?ooool00ol0003ok^k^ooooo`05ooooo`03ogMgMomVIVKooooo00[o
oooo00CogMgMoa0@4?oooooo00000oooool00oo^k^ko0000ooooo`0Cooooo`05o`000?oooooooooo
ooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c01eooooo`00O?ooool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo00cooooo00?o
410@o`000?l000000ol00006ooooo`03omgMgOl@413ooooo00Cooooo00?oEEEEogMgMoooool01_oo
ool00ol0003oooooooooo`08ooooo`Oo000000?oooooogMgMomEEED05?ooool01Ol@413ooooooooo
oooooooo410@00_ooooo00?oEEEEohN7Qoooool01_ooool00ol0003oooooooooo`1gooooo`00T_oo
ool00ol0003oooooooooo`08ooooo`03oeEEEOnHV9Sooooo00?ooooo00?ogMgMoa0@4?o^k^h00_oo
ool01Ol0003o^[ZjoooooonHV9So410@017ooooo00?ok^k^oa0@4?oMgMd05?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P01_ooool00ol0003oooooooooo`1gooooo`00
T_ooool00ol0003oooooooooo`08ooooo`03okZj^_m4A4Cooooo00Cooooo00WoMgMgofIVI_oooooo
oooooiRHV?l@413o0000ob4Q8Oo<c<`04Oooool00omVIVKoMgMgooooo`0Dooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4104ooooo`Co0000M_ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .22809 L
.08255 .19129 L
.10458 .15782 L
.11448 .14552 L
.12507 .13442 L
.13499 .12602 L
.14415 .12002 L
.14911 .11749 L
.15437 .11536 L
.15964 .11379 L
.16265 .11315 L
.16399 .11292 L
.16546 .11271 L
.1668 .11256 L
.16805 .11246 L
.16925 .11238 L
.17052 .11233 L
.17178 .11232 L
.17296 .11234 L
.17401 .11237 L
.17516 .11244 L
.17642 .11254 L
.1778 .11269 L
.1806 .1131 L
.18318 .11362 L
.1856 .11422 L
.1906 .11582 L
.19605 .11808 L
.20595 .12357 L
.21559 .13051 L
.22451 .13824 L
.26377 .18409 L
.30152 .23854 L
.34173 .29654 L
.38041 .34459 L
.40006 .36475 L
.42155 .38326 L
.44231 .39766 L
.46118 .40792 L
.48079 .41591 L
.49156 .41924 L
.50174 .42173 L
.51146 .42356 L
.51678 .42434 L
.52175 .42494 L
.52634 .42539 L
.53054 .4257 L
.53277 .42584 L
.5352 .42596 L
Mistroke
.53777 .42606 L
.53895 .42609 L
.5402 .42612 L
.54154 .42615 L
.54277 .42617 L
.54409 .42618 L
.54484 .42618 L
.54553 .42618 L
.5468 .42618 L
.54796 .42617 L
.5486 .42616 L
.54929 .42615 L
.55055 .42613 L
.55291 .42606 L
.55542 .42598 L
.55992 .42576 L
.56507 .42542 L
.5699 .42501 L
.5809 .42381 L
.60112 .42068 L
.61964 .41695 L
.65932 .40694 L
.69748 .39568 L
.73809 .38286 L
.77719 .37025 L
.81874 .35694 L
.85877 .34438 L
.89729 .33258 L
.93826 .32028 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .2282 L
.08255 .19146 L
.10458 .15819 L
.11448 .14607 L
.12507 .13522 L
.13499 .12711 L
.14415 .12143 L
.14911 .11909 L
.15437 .11716 L
.15709 .11639 L
.15964 .1158 L
.16245 .11531 L
.16402 .1151 L
.16546 .11496 L
.1667 .11487 L
.16802 .1148 L
.16926 .11478 L
.17039 .11478 L
.17109 .11479 L
.17173 .11481 L
.17243 .11485 L
.17317 .11489 L
.17441 .11499 L
.17578 .11513 L
.17823 .11548 L
.18086 .11598 L
.1856 .11722 L
.19088 .11909 L
.19577 .12126 L
.20684 .12769 L
.22696 .14425 L
.24562 .16432 L
.26622 .19047 L
.30643 .24823 L
.34512 .30452 L
.38626 .35718 L
.40678 .37897 L
.42588 .39611 L
.44548 .41045 L
.46399 .42098 L
.4738 .42542 L
.48444 .42938 L
.49405 .43223 L
.50303 .4343 L
.5125 .4359 L
.51752 .43652 L
.52291 .43702 L
.52561 .4372 L
.52855 .43736 L
Mistroke
.5299 .43742 L
.53133 .43746 L
.53268 .4375 L
.5339 .43752 L
.5352 .43754 L
.53639 .43755 L
.5377 .43755 L
.53836 .43755 L
.53908 .43754 L
.5403 .43753 L
.5416 .4375 L
.54283 .43747 L
.54395 .43744 L
.54625 .43735 L
.54877 .43723 L
.55389 .4369 L
.55863 .43649 L
.56307 .43603 L
.58385 .43298 L
.60407 .42887 L
.62259 .42442 L
.66227 .41361 L
.70043 .40257 L
.74104 .39062 L
.78014 .37884 L
.82169 .36563 L
.86172 .35195 L
.90024 .33794 L
.94121 .32244 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool09oooool9o`000?oooooo5Oooool0027ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`06ooooo`?oo`0000?o0000ooooooooool0ooooool@ooooo`008Oooool3o`0002;o
oooo0_l00002ool000cooooo00Coo`00o`000?l0003o0000ooooool?ooooo`008Oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oo003oo`0000oooooo0_oo00000ooooooo0000ooooo`3oooooo`go
oooo000Qooooo`03o`000?oooooooooo023ooooo00?o0000ool00?ooool04_ooool2ool00003o`00
0?oooooooooo0?oooooo2oooool0027ooooo00?o0000ooooooooool07oooool2ool001Kooooo0_oo
003oooooo`cooooo000Qooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool06?ooool0
0ooo003o0000ooooo`3oooooo`Wooooo000Qooooo`03o`000?oooooooooo01gooooo00?oo`00oooo
ooooool06_ooool00ooo003o0000ooooo`3oooooo`Sooooo000Qooooo`03o`000?oooooooooo01co
oooo00?oo`00ooooooooool07?ooool00ooo003o0000ooooo`3oooooo`Oooooo000Qooooo`?o0000
6oooool00ooo003oooooooooo`0Nooooo`03ool00?oooooooooo0?oooooo1_ooool0027ooooo00?o
0000ooooooooool06_ooool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo0?oooooo1Ooo
ool0027ooooo00?o0000ooooooooool06_ooool00ooo003oooooooooo`0Qooooo`03o`000?oooooo
oooo0?oooooo1?ooool0027ooooo00?o0000ooooooooool06Oooool00ooo003oooooooooo`0Soooo
o`03o`000?oooooooooo0?oooooo0oooool0027ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo0?oooooo0_ooool0027ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0?oooooo0Oooool0027ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0?oooooo000Q
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3o
ooooo`008Oooool3o`0001Gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`3noooo
o`008Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02cooooo00?oo`00oooooooo
ool0oOooool0027ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0]ooooo`03ool0
0?l0003ooooo0?gooooo000Qooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;ooo
ool00ooo003o0000ooooo`3looooo`008Oooool00ol0003oooooooooo`0Booooo`03ool00?l0003o
oooo037ooooo00?oo`00o`000?ooool0noooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool04_oo
ool00ooo003oooooooooo`0booooo`03ool00?l0003ooooo0?[ooooo0007ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooooooo
o`0Aooooo`03ool00?l0003ooooo03Cooooo00?oo`00ooooooooool0nOooool000Go00000_ooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`00017ooooo00?o
o`00ooooooooool0=Oooool00ooo003oooooooooo`3hooooo`001oooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0@ooooo`03ool00?oo
oooooooo03Kooooo00?oo`00o`000?ooool0n?ooool000Oooooo00Go0000ooooooooooooooooo`00
000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0@ooooo`03ool0
0?oooooooooo03Oooooo00?oo`00ooooooooool0moooool000Oooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03oooool00ooo003ooooo
ooooo`0iooooo`03ool00?oooooooooo0?Kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000ool00?ooool0
>_ooool00ooo003o0000ooooo`3fooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l00005ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0>oooool00ooo003o0000
ooooo`3eooooo`008Oooool00ol0003oooooooooo`0=ooooo`03ool00?oooooooooo03gooooo00?o
o`00ooooooooool0m?ooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oo`00ooooo`0o
ooooo`03o`000?oooooooooo0??ooooo000Qooooo`?o00003?ooool00ooo003oooooooooo`10oooo
o`03o`000?oooooooooo0?;ooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000ool00?oo
ool0@Oooool00ol0003oooooooooo`3booooo`008Oooool00ol0003oooooooooo`0;ooooo`03ool0
0?oooooooooo04;ooooo00?o0000ooooooooool0lOooool0027ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo0?3ooooo000Qooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`3_ooooo`008Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0koooool0027o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo0>ko
oooo000Qooooo`?o00002?ooool00ol0003oooooooooo`18ooooo`03ool00?l0003ooooo0>kooooo
000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0B_ooool00ooo003ooooooooo
o`3]ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04_ooooo00?oo`00
ooooooooool0k?ooool0027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1=oooo
o`03ool00?oooooooooo0>_ooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0COooool00ooo003o0000ooooo`3[ooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oo003ooooo04oooooo00?oo`00ooooooooool0j_ooool0027ooooo00?o0000ooooooooool01Ooo
ool00ol0003oo`00ooooo`1@ooooo`03ool00?oooooooooo0>Wooooo000Qooooo`03o`000?oooooo
oooo00Cooooo00?o0000ool00?ooool0DOooool00ooo003o0000ooooo`3Yooooo`008Oooool3o`00
00Cooooo00?o0000ool00?ooool0D_ooool00ooo003oooooooooo`3Xooooo`008Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oo003ooooo03Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Kooooo00?oo`00o`000?ooool0=?ooool4
o`000003oa0@4?oooooooooo03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`03
ooooo`03o`000?oo003ooooo03Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`06ooooo`03ool00?l0003ooooo03Gooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0looooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@06oooool0027ooooo00?o0000ooooooooool00oooool00ooo003ooooooooo
o`0gooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`06ooooo`03ool0
0?l0003ooooo03Cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo03cooooo00?oV9RHob4Q8Oo^k^h07?ooool0027ooooo00?o0000ooooooooool00_oo
ool00ol0003oo`00ooooo`0hooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`07ooooo`03ool00?l0003ooooo03Cooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`0>ooooo`03ogMgMolb<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o
0000ooooooooool00_ooool00ooo003oooooooooo`0hooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Wooooo00?oo`00o`000?ooool0<oooool00ol0003o
ooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c010oooo
o`03ogMgMomVIVKooooo01[ooooo000Qooooo`06o`000?ooooooooooooooool0003oo`00>_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo01Wooooo000Qooooo`?o000000?oooooool00?ooool0>_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0oooooo`05o`000?nj^[[ooooooiRHV?l@41006oooool0027ooooo00Go0000oooooooooooo0000
ool0000kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000gooooo00?o0000oooooooo
ool0;_ooool00omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000nooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`06oooool0027ooooo00Co0000ooooooooooooo`00Goooool00ol0
003oooooooooo`3Qooooo`008Oooool01?l0003oooooo`000?oo001Pooooo`03o`000?oooooooooo
0>3ooooo000Qooooo`03o`000?ooooooo`00067ooooo00?o0000ooooooooool0h?ooool0027ooooo
0_l0001Sooooo`03o`000?oooooooooo0=Gooooo0_l00002ooooo`;o00001?ooool0027ooooo0_l0
001Tooooo`03o`000?oooooooooo0=Cooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`00
6_oooom]o`000003ool00?l0003o00000<3o00000_oo0007o`0000cooooo00CogMgMo`000?l@413o
c<c<1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ooo003oooooo`00000>ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`05o`00
0?oo003oo`00ooooool000004oooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0:ooooo`03ool00?l0003ooooo00gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00Co0000ool00?oo003oo`000oooool00ol0
003oooooooooo`0Aooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03o`000?oooooooooo
06Gooooo00?oo`00o`000?ooool0]Oooool2o`0000;oo`006Oooool2o`0000;ooooo0_l00004oooo
o`008Oooool00ol0003oooooooooo`1Vooooo`03ool00?l0003ooooo0;3ooooo1?l000000ooooooo
o`00ooooo`0Tooooo`008Oooool00ol0003oooooooooo`1Vooooo`03ool00?oooooo00000:gooooo
0ol0000[ooooo`008Oooool00ol0003oooooooooo`1Wooooo`03ool00?oooooo00000:Wooooo0ol0
000^ooooo`008Oooool00ol0003oooooooooo`1Xooooo`03ool00?l0003ooooo0:Gooooo0ol0000a
ooooo`008Oooool3o`0006Wooooo00?oo`00o`000?ooool0X?ooool4o`0000;ooooo0ooo000_oooo
o`008Oooool00ol0003oooooooooo`1Yooooo`03ool00?oooooo000009cooooo1?l00002ooooo`Co
o`00<_ooool0027ooooo00?o0000ooooooooool0J_ooool00ooo003oooooo`00002Gooooo`Co0000
0oooool3ool003Kooooo000Qooooo`03o`000?oooooooooo06_ooooo00?oo`00ooooool00000Tooo
ool3o`0000Gooooo0_oo000iooooo`008Oooool00ol0003oooooooooo`1/ooooo`03ool00?l0003o
oooo08oooooo0ol00005ooooo`?oo`00>oooool0027ooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`2:ooooo`?o00001oooool00ooo003oooooooooo`0looooo`008Oooool00ol0003o
ooooooooo`1_ooooo`03o`000?oooooooooo08Kooooo0ol00019ooooo`008Oooool3o`00073ooooo
00?o0000ooooooooool0POooool4o`0004cooooo000Qooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool0OOooool3o`00053ooooo000Qooooo`03o`000?oooooooooo07;ooooo00?o0000
ooooooooool0NOooool3o`0000Sooooo0ooo0018ooooo`008Oooool00ol0003oooooooooo`1coooo
o`;o0000M_ooool3o`0000Oooooo1?oo001;ooooo`008Oooool00ol0003oooooooooo`1eooooo`03
o`000?oooooooooo06oooooo1?l00006ooooo`Coo`00Coooool0027ooooo00?o0000ooooooooool0
M_ooool00ol0003oooooooooo`1[ooooo`?o00001oooool3ool005?ooooo000Qooooo`03o`000?oo
oooooooo07?ooooo0_oo0002ooooo`03o`000?oooooooooo06Oooooo0ol00008ooooo`;oo`00E_oo
ool0027ooooo00?o0000ooooooooool0MOooool01?oo003oooooooooool0001Uooooo`?o0000Hooo
ool0027ooooo0ol0001fooooo`04ool00?ooooooooooo`00067ooooo0ol0001Vooooo`008Oooool0
0ol0003oooooooooo`1gooooo`03ool00?oooooooooo00;o0000G?ooool3o`0006Wooooo000Qoooo
o`03o`000?oooooooooo07Sooooo00Goo`00ooooooooooooooooo`00001Hooooo`?o00001oooool3
ool006;ooooo000Qooooo`03o`000?oooooooooo07Wooooo00Coo`00oooooooooooooooo0_l0001C
ooooo`?o00001_ooool4ool006Gooooo000Qooooo`03o`000?oooooooooo07[ooooo00?oo`00oooo
ooooool00_ooool00ol0003oooooooooo`1=ooooo`?o00001Oooool4ool006Wooooo000Qooooo`03
o`000?oooooooooo07_ooooo0_oo0003ooooo`;o0000B_ooool3o`0000Gooooo0ooo001]ooooo`00
8Oooool00ol0003oooooooooo`1mooooo`03ool00?oooooooooo00;ooooo0_l00015ooooo`?o0000
1_ooool2ool0073ooooo000Qooooo`?o0000O_ooool00ooo003oooooooooo`03ooooo`;o0000@?oo
ool3o`0007_ooooo000Qooooo`03o`000?oooooooooo07oooooo00?oo`00ooooooooool01?ooool2
o`0003[ooooo1?l0001nooooo`008Oooool00ol0003oooooooooo`28ooooo`;o0000<oooool5o`00
00Gooooo0_oo001kooooo`008Oooool00ol0003oooooooooo`2:ooooo`;o0000;Oooool4o`0000Ko
oooo1?oo001mooooo`008Oooool00ol0003oooooooooo`2<ooooo`?o00009_ooool4o`0000Kooooo
1?oo0021ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`2?ooooo`?o00007Oooool6o`0000Ko
oooo1?oo0025ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0ROooool00ooo003oooooooooo`06ooooo`Oo
00004Oooool5o`0000[ooooo0_oo0029ooooo`001oooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00_ooool3o`0008[ooooo0ooo000<oooooa7o0000V_ooool000Oooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooooooo
ool0SOooool3ool00;Cooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0T?ooool6ool001?ooooo1_oo002Eoooo
o`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`2Fooooo`?oo`001_ooool:ool009_ooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0
003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hoooo
o`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?oo
ool3o`000?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo
00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`00
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00Z?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:?ooooo0027ooooo`?o0000
4oooool00olQ8B7ogMgMooooo`07ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0
Xoooool007kooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00?ooooo00?o0000oooooooo
ool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00?oV9RHoeEEEOooool01oooool01?mE
EEGoV9RHooooooooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool00onj^[[oA4A4ooooo`02
ooooo`03ohN7QomVIVKooooo01;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool00ol0003ok^k^ooooo`1kooooo`00O_ooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH0
0oooool00ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0003o
gMgMooooo`06ooooo`09o`000?oooooooooooooooonHV9So8B4Qonk^k_ooooooA4A400[ooooo00Ko
EEEEoiRHV?oooooooooooa0@4?nj^[X3ooooo`03onk^k_l0003ooooo00_ooooo1_l000001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo07_ooooo001noooo
o`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@4003ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01Oooool2ogMgM`Oooooo00?o<S8booooooooool00_ooool00onHV9So8B4Qonk^
kP0<ooooo`04oa0@4?oMgMgoooooo`0000Gooooo00?o0000ooooooooool04Oooool01Ol@413ooooo
oooooooooooo410@00gooooo00?oZJVYoeEEEOooool0Noooool007kooooo00CoEEEEojVYZOoooooo
00000_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool01Oooool00oo^
k^ko410@onk^kP06ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7
QhOoIVIVooooool00005ooooo`03o`000?oooooooooo00[ooooo1_l000000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00cooooo00?o8B4Qooooooooool0N_ooool007kooooo00?ogMgMob4Q
8Oo^k^h00oooool00ol0003oooooooooo`02o`0000gooooo00?o0000ooooooooool01_ooool00omE
EEGoV9RHooooo`05ooooo`03o`000?o^k^kooooo00Cooooo00?oMgMgofIVI_ooool02_ooool01?oM
gMgo410@ooooool00004ooooo`03onk^k_l0003ooooo01;ooooo00Go0000ooooooooooooooooo`00
000>ooooo`03oeEEEOo<c<cooooo07[ooooo001oooooo`03oiRHV?mgMgOooooo00;ooooo00?o0000
ooooooooool03Oooool00ol@413o0000o`000003o`0000Gooooo00?ogMgMoa0@4?ooool01Oooool0
0omEEEGoMgMgooooo`05ooooo`03o`000?oooooooooo00Sooooo1ol00002ooooo`03ogMgMomEEEGo
oooo01;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo07[ooooo002F
ooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool02OoMgMgo410@onk^k_oo
oooo0000okZj^_ooooooV9RHoa0@400Booooo`03onk^k_l@413ogMgM01?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S80Noooool009Kooooo00?o0000oooo
ooooool01oooool00onj^[[oA4A4ooooo`05ooooo`08ogMgMomVIVKooooooiRHV?l@413o0000ob4Q
8Oo<c<`Booooo`03ofIVI_mgMgOooooo01?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go
0000Noooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .25154 L
.10458 .19627 L
.12507 .17427 L
.14415 .15756 L
.16254 .14545 L
.17284 .14055 L
.18221 .13731 L
.18704 .13611 L
.18969 .1356 L
.19216 .1352 L
.19427 .13493 L
.19654 .13471 L
.19783 .13462 L
.19905 .13455 L
.20015 .13451 L
.20135 .13448 L
.20203 .13448 L
.20276 .13448 L
.20345 .13449 L
.20409 .1345 L
.2053 .13454 L
.20657 .13461 L
.20794 .13471 L
.20922 .13482 L
.21213 .13517 L
.21466 .13557 L
.21696 .13602 L
.22214 .1373 L
.22694 .13883 L
.23205 .14082 L
.24122 .1453 L
.26198 .15973 L
.28145 .1783 L
.29973 .1997 L
.33842 .25468 L
.37956 .32064 L
.41919 .38294 L
.45729 .43548 L
.47854 .46022 L
.49785 .47952 L
.51817 .49647 L
.5369 .50904 L
.55608 .51896 L
.56619 .52302 L
.57688 .52648 L
.58632 .52882 L
.59152 .52985 L
.59646 .53064 L
.60103 .53123 L
Mistroke
.60345 .53148 L
.60603 .53171 L
.60841 .53188 L
.61056 .532 L
.6116 .53205 L
.61273 .53209 L
.61378 .53212 L
.61477 .53215 L
.61602 .53217 L
.61715 .53218 L
.61837 .53219 L
.61906 .53219 L
.6197 .53218 L
.62076 .53217 L
.62193 .53215 L
.62315 .53211 L
.6243 .53208 L
.62693 .53196 L
.62933 .53181 L
.63475 .53136 L
.63966 .5308 L
.64502 .53003 L
.65582 .52799 L
.67547 .52274 L
.69644 .51513 L
.73799 .49483 L
.77802 .47002 L
.81654 .44253 L
.85751 .41047 L
.89697 .37769 L
.93491 .34508 L
.9753 .3098 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .25452 L
.10458 .20111 L
.12507 .17917 L
.14415 .16236 L
.16254 .15021 L
.17284 .14535 L
.1773 .1437 L
.18221 .14222 L
.18704 .1411 L
.18969 .14063 L
.19216 .14028 L
.19335 .14015 L
.19448 .14004 L
.1955 .13996 L
.19659 .13989 L
.19777 .13984 L
.19887 .1398 L
.20017 .13979 L
.20135 .1398 L
.20266 .13983 L
.20331 .13986 L
.20403 .13989 L
.20531 .13997 L
.2065 .14007 L
.20918 .14037 L
.21206 .14081 L
.21733 .14194 L
.22214 .14332 L
.23205 .14724 L
.24122 .1521 L
.26198 .16731 L
.28065 .18551 L
.30125 .20983 L
.34145 .26663 L
.38014 .32713 L
.42128 .39051 L
.4609 .44482 L
.49901 .48706 L
.52026 .50556 L
.53957 .51906 L
.54921 .52461 L
.55966 .52974 L
.56945 .53372 L
.57862 .53674 L
.58808 .53914 L
.5931 .54014 L
.59849 .54098 L
.60119 .54133 L
.60414 .54164 L
Mistroke
.60673 .54186 L
.60815 .54196 L
.60949 .54204 L
.61081 .54211 L
.61223 .54217 L
.61352 .54221 L
.6147 .54223 L
.61583 .54225 L
.61706 .54226 L
.61834 .54226 L
.61954 .54224 L
.6208 .54222 L
.62144 .5422 L
.62215 .54218 L
.62456 .54208 L
.62592 .542 L
.62738 .54191 L
.63002 .5417 L
.63519 .54117 L
.63993 .54053 L
.64898 .53891 L
.6585 .53669 L
.67828 .53046 L
.69666 .52291 L
.73576 .50216 L
.77731 .47473 L
.81734 .44464 L
.85586 .41344 L
.89683 .37867 L
.93629 .34424 L
.97422 .31075 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo033ooooo2ol0003oooooo`[o
oooo000Qooooo`03o`000?oooooooooo02kooooo0_l0000;ooooo`?o0000ooooool7ooooo`008Ooo
ool3o`0002_ooooo0ol0000:ooooo`?oo`000oooool3o`000?oooooo1?ooool0027ooooo00?o0000
ooooooooool0:?ooool3o`0000Coo`003?ooool3ool000?ooooo0_l0003oooooo`;ooooo000Qoooo
o`03o`000?oooooooooo02Oooooo00Co0000ooooooooooooo`004oooool3ool000;ooooo00?o0000
ooooooooool0o_ooool0027ooooo00?o0000ooooooooool09Oooool2o`000003oooooooo003oo`00
01Oooooo0_oo00000ooooooo0000o`00003nooooo`008Oooool00ol0003oooooooooo`0Tooooo`04
o`000?ooooooooooool001_ooooo00Coo`00oooooooooooo0000oOooool0027ooooo00?o0000oooo
ooooool08_ooool2o`000003oooooooo003oo`0001gooooo00Coo`00oooooooooooo0000o?ooool0
027ooooo00?o0000ooooooooool08Oooool01?l0003ooooooooooooo000Pooooo`04ool00?oooooo
ooooo`000?_ooooo000Qooooo`03o`000?oooooooooo023ooooo00Co0000oooooooo003oo`008_oo
ool01?oo003oooooooooool0003jooooo`008Oooool3o`0001oooooo00?o0000oooooooo0000:?oo
ool00ol0003oooooooooo`3gooooo`008Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
o`0002[ooooo00?o0000ooooooooool0m_ooool0027ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo0?Gooooo000Qooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`3dooooo`008Oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0loooool000Oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Co
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo0?;o
oooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo037ooooo00?oo`00ooooool0
0000loooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooooooo
ool00_ooool3o`0001Wooooo00?o0000ooooooooool0<_ooool01?oo003oooooooooool0003boooo
o`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo03Cooooo00Coo`00oooooooooooo0000lOooool0
00Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?oo
ool00ol0003oooooooooo`0Gooooo`03o`000?ooooooo`0003Kooooo00Coo`00oooooooooooo0000
l?ooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool05oooool00ol0003oo`00ooooo`0gooooo`04ool00?ooooooooooo`000>oo
oooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01Kooooo00?o0000ool00?ooool0>Oooool00ooo003oooooo`00003_ooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01Go
oooo00?o0000oooooooo0000>oooool00ooo003oooooo`00003^ooooo`008Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?ooooooo`0003gooooo00?oo`00ooooool00000kOooool0027ooooo00?o
0000ooooooooool04oooool00ol0003oooooool0000nooooo`03ool00?oooooo00000>gooooo000Q
ooooo`?o00004_ooool00ol0003oooooool00010ooooo`03ool00?oooooo00000>cooooo000Qoooo
o`03o`000?oooooooooo01;ooooo00?o0000ool00?ooool0@Oooool00ooo003oooooo`00003[oooo
o`008Oooool00ol0003oooooooooo`0Aooooo`03o`000?ooooooo`0004;ooooo00Coo`00oooooooo
oooo0000j_ooool0027ooooo00?o0000ooooooooool04?ooool00ol0003oooooool00014ooooo`03
ool00?oooooo00000>[ooooo000Qooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo0000
A_ooool00ooo003oooooo`00003Yooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
ooooo`0004[ooooo00?o0000ooooooooool0i_ooool0027ooooo00?o0000ooooooooool03_ooool0
0ol0003oo`00ooooo`1:ooooo`03o`000?oooooooooo0>Kooooo000Qooooo`?o00003Oooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo0>Gooooo000Qooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`3Tooooo`008Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0hoooool0027ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo0>?ooooo000Q
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`3R
ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Cooooo00?o0000oooo
ooooool0hOooool0027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Cooooo`03
ool00?oooooo00000>?ooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ool00?ooool0
EOooool00ooo003oooooo`00003Rooooo`008Oooool3o`0000Oooooo00?o0000ool00?ooool0E_oo
ool00ooo003o0000ooooo`3Qooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oo003o
oooo03Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00kooooo00?oo`00o`000?ooool0;?ooool4o`000003oa0@4?oooooooooo03_ooooo
1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03go
oooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo003ooooo03Gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0=ooooo`03
ool00?oooooo000002kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0027o
oooo00?o0000ooooooooool01Oooool00ol0003oo`00ooooo`0eooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`0=ooooo`03ool00?l0003ooooo02gooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03cooooo00?oV9RHob4Q
8Oo^k^h07?ooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oo`00ooooo`0fooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0?ooooo`03ool00?l0003ooooo
02cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo
03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool00oooool00ol0003o
o`00ooooo`0gooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<013ooooo00?oo`00o`000?ooool0;?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooo
oooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c010ooooo`03ogMgMomVIVKooooo01[ooooo000Q
ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0=oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool04oooool00ooo003o0000ooooo`0[ooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo01Wooooo000Qooooo`?o00000_ooool00ol0003oo`00ooooo`0hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Cooooo`03ool00?l0003ooooo02_ooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oooooo00Go
0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool01_l0003ooooooooooooooooo0000ool003[o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004oooool00ooo003o0000ooooo`0Xoooo
o`03oeEEEOmVIVKo000003oooooo00?oEEEEofIVI_l000003Oooool4o`0003kooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00Kooooo`008Oooool01Ol0003oooooooooooooooooo`0006Cooooo00?oo`00
o`000?ooool0foooool0027ooooo00Go0000oooooooooooo0000ool0001Tooooo`03ool00?l0003o
oooo0=_ooooo000Qooooo`04o`000?oooooo0000ool006Kooooo00?oo`00o`000?ooool0f_ooool0
027ooooo00?o0000oooooooo0000J?ooool00ol0003oooooooooo`3?ooooo`;o00000_ooool2o`00
00Cooooo000Qooooo`;o0000J_ooool00ol0003oooooooooo`3>ooooo`06onk^k_lQ8B7oQhN7okZj
^_l0003ogMgM1?ooool001[oooooool0000bo`000003ool00?l0003o000000Go00003?ooool01?oM
gMgo0000oa0@4?o<c<`5ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02_ooool2ool00003o`000?oooooooooo017ooooo00Cok^k^ob4Q
8Ol@413ok^k^1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Wooooo00Coo`00oooooooooooo00004oooool01?lQ8B7oMgMgogMgMolb
<S85ooooo`008Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo0;Gooooo00?oo`00
ooooooooool05?ooool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`1/oooo
o`03o`000?oooooooooo0;?ooooo00?o0000ooooooooool07oooool0027ooooo00?o0000oooooooo
ool0K?ooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo023ooooo000Qooooo`03o`00
0?oooooooooo06cooooo0_oo002booooo`03o`000?oooooooooo027ooooo000Qooooo`03o`000?oo
oooooooo06gooooo00?oo`00o`000?ooool0[oooool00ol0003oooooooooo`0Rooooo`008Oooool3
o`0006kooooo00?oo`00ooooooooool0[Oooool00ol0003oooooooooo`0Sooooo`008Oooool00ol0
003oooooooooo`1_ooooo`03ool00?oooooooooo0:_ooooo00?o0000ooooooooool09?ooool0027o
oooo00?o0000ooooooooool0Koooool00ooo003o0000ooooo`2Zooooo`03o`000?oooooooooo02Go
oooo000Qooooo`03o`000?oooooooooo073ooooo00?oo`00ooooooooool0Y_ooool3ool002Sooooo
000Qooooo`03o`000?oooooooooo073ooooo00?oo`00o`000?ooool0YOooool00ooo003o0000o`00
000Yooooo`008Oooool00ol0003oooooooooo`1aooooo`03ool00?l0003ooooo0:?ooooo00?oo`00
o`000?ooool0:_ooool0027ooooo00?o0000ooooooooool0L_ooool00ooo003o0000ooooo`2Qoooo
o`03ool00?l0003ooooo02_ooooo000Qooooo`?o0000L_ooool00ooo003o0000ooooo`2Pooooo`03
ool00?l0003ooooo02cooooo000Qooooo`03o`000?oooooooooo07?ooooo00?oo`00o`000?ooool0
W_ooool00ooo003o0000ooooo`0]ooooo`008Oooool00ol0003oooooooooo`1cooooo`03ool00?oo
oooo000009gooooo00?oo`00o`000?ooool0;_ooool0027ooooo00?o0000ooooooooool0M?ooool0
0ooo003o0000ooooo`2Kooooo`03ool00?oooooooooo02oooooo000Qooooo`03o`000?oooooooooo
07Gooooo00?oo`00o`000?ooool0VOooool00ooo003oooooooooo`0`ooooo`008Oooool00ol0003o
ooooooooo`1gooooo`03o`000?oooooooooo09Kooooo00?oo`00ooooooooool0<Oooool0027ooooo
00?o0000ooooooooool0Moooool00ol0003oooooooooo`2Eooooo`03ool00?oooooooooo03;ooooo
000Qooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0T_ooool2o`0003Gooooo000Q
ooooo`?o0000NOooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo03Gooooo000Qoooo
o`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`0foooo
o`008Oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo08gooooo00?o0000oooooooo
ool0=oooool0027ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`2;ooooo`03o`00
0?oooooooooo03Sooooo000Qooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0ROoo
ool2o`0003_ooooo000Qooooo`03o`000?oooooooooo07_ooooo00?oo`00o`000?ooool0R?ooool2
ool003cooooo000Qooooo`03o`000?oooooooooo07_ooooo00?oo`00ooooool00000Qoooool00ooo
003oooooooooo`0looooo`008Oooool3o`0007cooooo00?oo`00ooooool00000QOooool00ooo003o
ooooooooo`0mooooo`008Oooool00ol0003oooooooooo`1mooooo`03ool00?l0003ooooo08?ooooo
00?oo`00ooooooooool0?_ooool0027ooooo00?o0000ooooooooool0OOooool00ooo003oooooo`00
0021ooooo`03o`000?oo003ooooo043ooooo000Qooooo`03o`000?oooooooooo07kooooo00?oo`00
ooooool00000Ooooool2ool004;ooooo000Qooooo`03o`000?oooooooooo07oooooo00?oo`00o`00
0?ooool0OOooool00ooo003oooooooooo`12ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`20
ooooo`03ool00?l0003ooooo07[ooooo00?o0000ool00?ooool0A?ooool000Oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo083ooooo00?oo`00ooooool00000NOooool00ol0003oo`00ooooo`15ooooo`001oooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`00087ooooo00?oo`00
ooooool00000Moooool00ol0003oo`00ooooo`16ooooo`001oooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`22ooooo`03ool00?l0003o
oooo07Gooooo00?o0000ool00?ooool0Aoooool000Oooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`22ooooo`03ool00?oo
oooo000007?ooooo0_l0001:ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`23ooooo`03ool00?oooooo0000077ooooo00?o
0000ooooooooool0B_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0Q?ooool00ooo003o0000ooooo`1_ooooo`03o`000?oo
oooooooo04_ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o
0000ooooooooool0Q_ooool00ol0003oooooooooo`1[ooooo`;o0000C_ooool0027ooooo00?o0000
ooooooooool0Qoooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo04kooooo000Qoooo
o`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`1?oooo
o`008Oooool3o`0008Sooooo00?o0000ooooooooool0IOooool2o`0000;oo`00D?ooool0027ooooo
00?o0000ooooooooool0ROooool00ol0003oooooooooo`1Sooooo`03o`000?ooooooo`0005;ooooo
000Qooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool0HOooool00ol0003oo`00ool0
001Cooooo`008Oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo05kooooo0_l00000
0ooo003oooooooooo`1Cooooo`008Oooool00ol0003oooooooooo`2;ooooo`03ool00?l0003ooooo
05gooooo00?o0000oooooooo0000E_ooool0027ooooo00?o0000ooooooooool0S?ooool00ooo003o
0000ooooo`1Kooooo`03o`000?oo003oo`0005Oooooo000Qooooo`03o`000?oooooooooo08gooooo
00?oo`00o`000?ooool0F?ooool2o`000003ool00?oooooooooo05Oooooo000Qooooo`?o0000S_oo
ool00ooo003o0000ooooo`1Eooooo`;o00000_oo001Jooooo`008Oooool00ol0003oooooooooo`2?
ooooo`03ool00?l0003ooooo05;ooooo0_l000000oooooooo`00ooooo`1Kooooo`008Oooool00ol0
003oooooooooo`2@ooooo`03ool00?l0003o000004oooooo0_l00002ooooo`03ool00?oooooooooo
05_ooooo000Qooooo`03o`000?oooooooooo097ooooo00?oo`00ooooool00000COooool00ol0003o
ooooooooo`1Pooooo`008Oooool00ol0003oooooooooo`2Booooo`04ool00?oooooo0000o`0004Wo
oooo0_l0001Sooooo`008Oooool00ol0003oooooooooo`2Cooooo`04ool00?ooooooooooo`0004Ko
oooo0_l0001Uooooo`008Oooool00ol0003oooooooooo`2Dooooo`04ool00?ooooooooooo`0004?o
oooo0_l0001Wooooo`008Oooool00ol0003oooooooooo`2Eooooo`03ool00?oooooooooo00;o0000
?oooool2o`0006Wooooo000Qooooo`?o0000U_ooool01Ooo003ooooooooooooooooo000003cooooo
0_l00004ooooo`03ool00?oooooooooo06Cooooo000Qooooo`03o`000?oooooooooo09_ooooo0_l0
000hooooo`;o00001?ooool2ool006Oooooo000Qooooo`03o`000?oooooooooo09gooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`;oo`00JOooool0027ooooo00?o0000oooo
ooooool0W_ooool2o`0003;ooooo0_l00003ooooo`;oo`00Joooool0027ooooo00?o0000oooooooo
ool0X?ooool2o`0002kooooo0_l00002ooooo`?oo`00KOooool0027ooooo00?o0000ooooooooool0
X_ooool2o`0002[ooooo0_l00002ooooo`;oo`00L?ooool0027ooooo00?o0000ooooooooool0Wooo
ool00ooo003oooooooooo`02ooooo`?o00009?ooool3o`0000;ooooo0_oo001booooo`008Oooool3
o`000:3ooooo00?oo`00ooooooooool01?ooool3o`0001kooooo0ol00004ooooo`03ool00?oooooo
oooo07;ooooo000Qooooo`03o`000?oooooooooo0:7ooooo0ooo0006ooooo`?o00006?ooool3o`00
07cooooo000Qooooo`03o`000?oooooooooo0:Cooooo0ooo0006ooooo`?o00003oooool6o`0007oo
oooo000Qooooo`03o`000?oooooooooo0:Oooooo00?oo`00ooooooooool01_ooool?o`0008Gooooo
000Qooooo`03o`000?oooooooooo0:Sooooo1_oo000Eooooo`?oo`00O_ooool001Sooooo1?l00000
0ol@413oooooooooo`02ooooo`03o`000?oooooooooo0:kooooo00?oo`00ooooooooool03oooool3
ool0087ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0]Oooool;ool0
08Cooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`00
6_ooool00ol0003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo002Tooooo`03ogMgMomVIVKooooo01Oooooo00?oIVIVogMg
Moooool0Yoooool008?ooooo0ol0000Dooooo`03ob4Q8OoMgMgooooo00Kooooo00?ogMgMoa0@4?o^
k^h06?ooool00oo^k^ko410@omgMg@2Wooooo`00Noooool01on7QhOo0000oeEEEOmVIVKo0000oc8b
<_o^k^h00_ooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool0
0onHV9SoEEEEooooo`06ooooo`03oeEEEOnHV9Sooooo00;ooooo1Ol00009ooooo`03oeEEEOnYZJWo
oooo00;ooooo00Ko^[ZjodA4A?ooooooooooohN7QomVIVHDooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
07Gooooo001kooooo`07oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP02ooooo`03o`000?oooooo
oooo00_ooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oMgMgooooo00Gooooo00?o
0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooo
oooooa0@4?nj^[X2ooooo`03onk^k_l0003ooooo00_ooooo1_l00002ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`1d
ooooo`00Noooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@41000_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Kooooo0_mgMgL6ooooo`03oc8b<_oooooooooo00?ooooo00?o
V9RHob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool00004ooooo`03o`000?oooooooooo01;ooooo
00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000oooooooo
ool0Loooool007_ooooo00CoEEEEojVYZOoooooo00000_ooool01?l0003oooooooooool0000=oooo
o`03o`000?oooooooooo00Kooooo00?ok^k^oa0@4?o^k^h01Oooool00olb<S;oooooooooo`04oooo
o`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001?ooool00ol0003oooooooooo`0:
ooooo`Ko00000_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_oo
ool00omgMgOo<S8booooo`1dooooo`00Noooool00ooMgMgo8B4Qonk^kP03ooooo`04o`000?oooooo
0000o`0000gooooo00?o0000ooooooooool01oooool00omEEEGoV9RHooooo`04ooooo`03o`000?o^
k^kooooo00Gooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgo410@ooooool00003ooooo`03onk^
k_l0003ooooo01?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c01eooooo`00O?ooool00onHV9SoMgMgooooo`02ooooo`03
o`000?oooooooooo00cooooo00?o410@o`000?l000000ol00006ooooo`03omgMgOl@413ooooo00Co
oooo00?oEEEEogMgMoooool01_ooool00ol0003oooooooooo`08ooooo`Oo000000?oooooogMgMomE
EED05?ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0
003oooooooooo`1gooooo`00T_ooool00ol0003oooooooooo`08ooooo`03oeEEEOnHV9Sooooo00?o
oooo00?ogMgMoa0@4?o^k^h00_ooool01Ol0003o^[ZjoooooonHV9So410@017ooooo00?ok^k^oa0@
4?oMgMd05?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo00Sooooo00?o^[Zj
odA4A?ooool01?ooool02OmgMgOoIVIVooooooooooooV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`03
ofIVI_mgMgOooooo01Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00
07Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28891 L
.10458 .26589 L
.14415 .24424 L
.18221 .22597 L
.20178 .21869 L
.21274 .21551 L
.21758 .21435 L
.22272 .21328 L
.22745 .21246 L
.23267 .21174 L
.23496 .21149 L
.23742 .21127 L
.23974 .2111 L
.24186 .21099 L
.24314 .21093 L
.24384 .21091 L
.24451 .21089 L
.24579 .21087 L
.24696 .21086 L
.24763 .21085 L
.24835 .21086 L
.24963 .21087 L
.25034 .21089 L
.25101 .21091 L
.25252 .21096 L
.25383 .21102 L
.25508 .2111 L
.25741 .21127 L
.25992 .21151 L
.26265 .21183 L
.26749 .21257 L
.27205 .21346 L
.28242 .21619 L
.29253 .21984 L
.30343 .22487 L
.32347 .23711 L
.34457 .25411 L
.38268 .29454 L
.42324 .34795 L
.46228 .40387 L
.50378 .46112 L
.54376 .5082 L
.58223 .54229 L
.6021 .55497 L
.61225 .5601 L
.62315 .5646 L
.63338 .56787 L
.64272 .57007 L
.64722 .57085 L
Mistroke
.64959 .5712 L
.65212 .57152 L
.65455 .57177 L
.65674 .57196 L
.65896 .5721 L
.66104 .5722 L
.6622 .57224 L
.66345 .57228 L
.66463 .57229 L
.66571 .5723 L
.66697 .57229 L
.66768 .57229 L
.66834 .57227 L
.66954 .57224 L
.67082 .5722 L
.67205 .57214 L
.67336 .57207 L
.67574 .5719 L
.67856 .57164 L
.68115 .57135 L
.69016 .56992 L
.69469 .56897 L
.69964 .56775 L
.71929 .56114 L
.74025 .55114 L
.7818 .52332 L
.82184 .48811 L
.86035 .44824 L
.90132 .40124 L
.94078 .35321 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .29243 L
.10458 .27268 L
.14415 .25276 L
.18221 .23522 L
.20178 .22811 L
.21274 .225 L
.21758 .22385 L
.22272 .22281 L
.22745 .222 L
.23267 .2213 L
.23496 .22105 L
.23742 .22083 L
.23974 .22067 L
.24186 .22055 L
.24314 .2205 L
.24384 .22048 L
.24451 .22046 L
.24579 .22044 L
.24696 .22043 L
.24763 .22043 L
.24835 .22043 L
.24963 .22045 L
.25034 .22047 L
.25101 .22048 L
.25252 .22054 L
.25383 .2206 L
.25508 .22068 L
.25741 .22085 L
.25992 .22109 L
.26265 .22141 L
.26749 .22215 L
.27205 .22304 L
.28242 .22576 L
.29253 .22939 L
.30343 .23437 L
.32347 .24644 L
.34457 .26309 L
.38268 .30223 L
.42324 .35344 L
.46228 .40714 L
.50378 .46295 L
.54376 .51004 L
.58223 .5451 L
.6021 .55839 L
.61225 .56382 L
.62315 .56859 L
.63338 .57206 L
.64272 .5744 L
.64722 .57523 L
Mistroke
.64959 .57559 L
.65212 .57593 L
.65455 .57619 L
.65674 .57638 L
.65896 .57653 L
.66004 .57659 L
.66104 .57663 L
.6622 .57667 L
.66345 .5767 L
.66461 .57672 L
.66571 .57672 L
.66698 .57671 L
.66816 .57668 L
.66945 .57664 L
.67082 .57659 L
.67336 .57644 L
.67574 .57624 L
.68115 .57562 L
.6858 .57489 L
.69005 .57406 L
.69964 .57163 L
.70947 .56838 L
.7186 .56469 L
.73931 .55407 L
.77841 .52656 L
.81996 .48883 L
.86 .44661 L
.89851 .4025 L
.93949 .35357 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`0koooo
oa3o0000nOooool0027ooooo0ol0000gooooo`Co00004?ooool5o`000?Cooooo000Qooooo`03o`00
0?oooooooooo03Cooooo0ol0000Iooooo`03o`000?oooooooooo0?7ooooo000Qooooo`03o`000?oo
oooooooo037ooooo0ol0000;ooooo`coo`001_ooool3o`000?3ooooo000Qooooo`03o`000?oooooo
oooo02kooooo0ol0000Jooooo`Coo`001Oooool3o`000>gooooo000Qooooo`03o`000?oooooooooo
02cooooo0_l00005ooooo`;oo`008_ooool00ol0003oooooooooo`3Zooooo`008Oooool00ol0003o
ooooooooo`0Zooooo`;o00001?ooool3ool002Gooooo0_l0003Zooooo`008Oooool00ol0003ooooo
ooooo`0Xooooo`;o00001?ooool2ool002[ooooo00?o0000ooooooooool0ioooool0027ooooo0ol0
000Vooooo`;o00001?ooool2ool002gooooo0_l0003Wooooo`008Oooool00ol0003oooooooooo`0T
ooooo`;o00001?ooool2ool002cooooo0_oo0003ooooo`03o`000?oooooooooo0>Cooooo000Qoooo
o`03o`000?oooooooooo02;ooooo0_l00005ooooo`03ool00?oooooooooo02kooooo00Coo`00oooo
oooooooooooo0_l0003Tooooo`008Oooool00ol0003oooooooooo`0Pooooo`;o00001Oooool2ool0
03;ooooo0_oo0003ooooo`03o`000?oooooooooo0>7ooooo000Qooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`0dooooo`05ool00?oooooooooooooo
ool00000h_ooool0027ooooo00?o0000ooooooooool07Oooool2o`0003oooooo0_oo0002ooooo`03
o`000?oooooooooo0=oooooo000Qooooo`03o`000?oooooooooo01_ooooo0_l00013ooooo`03ool0
0?oooooo00000>7ooooo000Qooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0A?oo
ool00ooo003oooooo`00003Pooooo`008Oooool3o`0001Sooooo0_l000000oooooooo`00ool00015
ooooo`03ool00?oooooo00000=oooooo000Qooooo`03o`000?oooooooooo01Kooooo0_l000000ooo
ooooo`00ool0000Rooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@0?ooooo`04ool00?ooooooooooo`0002[ooooo1?l000000ol@413ooooo
ooooo`0kooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@0mooooo`Go00006oooool0027ooooo00?o0000ooooooooool05?ooool2o`0000;ooooo
00?oo`00ooooooooool08_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00oooooo00Coo`00oooooooooooo0000:oooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0Booooo`;o00000_ooool2ool0
02Gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00oooooo00Coo`00
oooooooooooo0000:_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0??ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003oooooooooo`0@
ooooo`;o00000_ooool2ool002Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo01Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo00kooooo00?oMgMgoc8b<_ooool0?_ooool00onHV9So8B4Qonk^kP0Kooooo`008Oooool0
0ol0003oooooooooo`0>ooooo`;o000000Coooooool00?oo003oo`00:Oooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Eooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`0@?ooool00omgMgOoIVIVooooo`0Jooooo`008Oooool00ol0003oooooooooo`0<ooooo`;o
000000?oooooool00?oo0000;?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Wooooo000Qooooo`?o
00002_ooool2o`0000;ooooo00?oo`00ooooooooool0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0oooooo`05o`000?nj^[[ooooo
oiRHV?l@41006oooool0027ooooo00?o0000ooooooooool02?ooool2o`0003?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00006Oooool00ol0003oooooooooo`0Rooooo`03oeEEEOmVIVKo
000003oooooo00?oEEEEofIVI_l000003Oooool4o`0003kooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00Kooooo`008Oooool00ol0003oooooooooo`06ooooo`;o0000I?ooool00ol0003oooooooooo`3E
ooooo`008Oooool00ol0003oooooooooo`04ooooo`;o0000Ioooool00ol0003oooooooooo`3Doooo
o`008Oooool00ol0003oooooooooo`02ooooo`;o0000J?ooool00ooo003o0000ooooo`3Eooooo`00
8Oooool00ol0003oooooooooo`02o`0000?oo`00J?ooool00ooo003o0000ooooo`3:ooooo`;o0000
0_ooool2o`0000Cooooo000Qooooo`;o00000ooo001[ooooo`03ool00?oooooo00000<[ooooo00Ko
k^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`0000;oo`00Kol000000ooo003o0000
o`00002fo`000003ool00?l0003o000000Go00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`00
8Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?oo`00o`000?ooool0
0_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ooo003oooooooooo`0Aooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02?ooool01Ooo003o0000oooooooooooo000000ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03ool00?l0003ooooo01;o
oooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000ooooooooool0LOooool00ooo003o
0000ooooo`2aooooo`03ool00?oooooooooo01;ooooo0_l00002ooooo`;o00001?ooool0027ooooo
00?o0000ooooooooool0L_ooool00ooo003o0000ooooo`2_ooooo`03ool00?oooooooooo01gooooo
000Qooooo`03o`000?oooooooooo07;ooooo00?oo`00ooooool00000[_ooool00ooo003ooooooooo
o`0Nooooo`008Oooool00ol0003oooooooooo`1cooooo`03ool00?l0003ooooo0:gooooo00?oo`00
ooooooooool07_ooool0027ooooo00?o0000ooooooooool0M?ooool00ooo003o0000ooooo`2[oooo
o`03ool00?oooooooooo01oooooo000Qooooo`?o0000MOooool00ooo003o0000ooooo`2Yooooo`03
ool00?oooooooooo023ooooo000Qooooo`03o`000?oooooooooo07Kooooo00?oo`00o`000?ooool0
Yoooool00ooo003oooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`1gooooo`03o`000?oo
oooooooo0:Gooooo00?oo`00o`000?ooool08_ooool0027ooooo00?o0000ooooooooool0N?ooool0
0ol0003oooooooooo`2Tooooo`03o`000?oooooooooo02;ooooo000Qooooo`03o`000?oooooooooo
07Wooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`0Sooooo`008Oooool00ol0003o
ooooooooo`1jooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool09?ooool0027ooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo02Gooooo
000Qooooo`?o0000Noooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo02Gooooo000Q
ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0V
ooooo`008Oooool00ol0003oooooooooo`1looooo`03ool00?oooooooooo09_ooooo00?o0000oooo
ooooool09oooool0027ooooo00?o0000ooooooooool0O?ooool00ooo003o0000ooooo`2Jooooo`03
o`000?oooooooooo02Sooooo000Qooooo`03o`000?oooooooooo07gooooo00?oo`00o`000?ooool0
V?ooool00ooo003oooooooooo`0Yooooo`008Oooool00ol0003oooooooooo`1nooooo`03ool00?l0
003ooooo09Kooooo00?o0000ool00?ooool0:_ooool0027ooooo00?o0000ooooooooool0O_ooool0
0ooo003o0000ooooo`2Eooooo`03o`000?oo003ooooo02_ooooo000Qooooo`03o`000?oooooooooo
07oooooo00?oo`00o`000?ooool0Toooool00ol0003oo`00ooooo`0/ooooo`008Oooool3o`00083o
oooo00?oo`00o`000?ooool0T_ooool00ooo003oooooooooo`0/ooooo`008Oooool00ol0003ooooo
ooooo`21ooooo`03ool00?oooooooooo093ooooo00?oo`00ooooooooool0;Oooool0027ooooo00?o
0000ooooooooool0POooool00ooo003o0000ooooo`2?ooooo`03ool00?oooooooooo02kooooo000Q
ooooo`03o`000?oooooooooo08;ooooo00?oo`00o`000?ooool0SOooool00ol0003oo`00ooooo`0_
ooooo`008Oooool00ol0003oooooooooo`23ooooo`03ool00?l0003ooooo08_ooooo00?o0000ool0
0?ooool0<?ooool0027ooooo00?o0000ooooooooool0Poooool00ooo003o0000ooooo`2:ooooo`03
o`000?oo003ooooo037ooooo000Qooooo`03o`000?oooooooooo08Cooooo00?oo`00o`000?ooool0
R?ooool00ol0003oo`00ooooo`0booooo`008Oooool3o`0008Gooooo00?oo`00o`000?ooool0Qooo
ool00ooo003oooooooooo`0booooo`008Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooo
oooo08Gooooo00?oo`00ooooooooool0<oooool0027ooooo00?o0000ooooooooool0Qoooool00ol0
003oooooooooo`23ooooo`03o`000?oooooooooo03Cooooo000Qooooo`03o`000?oooooooooo08So
oooo00?o0000ooooooooool0POooool00ol0003oooooooooo`0eooooo`008Oooool00ol0003ooooo
ooooo`29ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0=_ooool000Oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Co
oooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo03Ko
oooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo07gooooo00?o0000oooooooo
ool0=oooool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;o
oooo0ol0002;ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0>?ooool000Oooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooooooo
ool0Roooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Wooooo0007ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooo
ooooool0S?ooool00ooo003oooooooooo`1gooooo`03ool00?l0003ooooo03_ooooo0007ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
08cooooo00?oo`00o`000?ooool0M_ooool00ooo003oooooo`00000looooo`001oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2=oooo
o`03ool00?l0003ooooo07Cooooo00?oo`00ooooool00000?Oooool000Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`2>ooooo`03ool00?oooooooooo
07;ooooo00?oo`00ooooool00000?_ooool0027ooooo00?o0000ooooooooool0Soooool00ooo003o
ooooooooo`1`ooooo`03ool00?oooooo000003oooooo000Qooooo`03o`000?oooooooooo093ooooo
00?oo`00ooooooooool0Koooool00ooo003o0000ooooo`0oooooo`008Oooool3o`00093ooooo00?o
o`00ooooooooool0K_ooool00ooo003o0000ooooo`10ooooo`008Oooool00ol0003oooooooooo`2A
ooooo`03ool00?oooooooooo06cooooo00?oo`00o`000?ooool0@Oooool0027ooooo00?o0000oooo
ooooool0T_ooool00ooo003oooooooooo`1Zooooo`03ool00?l0003ooooo04;ooooo000Qooooo`03
o`000?oooooooooo09?ooooo00?oo`00ooooooooool0J?ooool00ooo003o0000ooooo`13ooooo`00
8Oooool00ol0003oooooooooo`2Cooooo`03ool00?oooooooooo06Oooooo00?oo`00o`000?ooool0
A?ooool0027ooooo00?o0000ooooooooool0U?ooool00ooo003oooooooooo`1Uooooo`03ool00?l0
003ooooo04Gooooo000Qooooo`03o`000?oooooooooo09Gooooo00?oo`00ooooooooool0I?ooool0
0ol0003oooooooooo`15ooooo`008Oooool3o`0009Kooooo00?o0000ooooooooool0H_ooool00ol0
003oooooooooo`16ooooo`008Oooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0Aoooool0027ooooo00?o0000ooooooooool0V?ooool00ol0003ooooo
ooooo`1Nooooo`03o`000?oooooooooo04Sooooo000Qooooo`03o`000?oooooooooo09Wooooo00?o
0000ooooooooool0G?ooool00ol0003oooooooooo`19ooooo`008Oooool00ol0003oooooooooo`2J
ooooo`03o`000?oooooooooo05Wooooo0_l0001<ooooo`008Oooool00ol0003oooooooooo`2Joooo
o`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0C?ooool0027ooooo00?o0000oooooooo
ool0Voooool00ol0003oooooooooo`1Eooooo`;oo`00Coooool0027ooooo00?o0000ooooooooool0
W?ooool00ol0003oo`00ooooo`1Cooooo`03ool00?l0003ooooo04oooooo000Qooooo`?o0000WOoo
ool00ooo003oooooooooo`1Aooooo`03ool00?l0003ooooo053ooooo000Qooooo`03o`000?oooooo
oooo09kooooo00?oo`00ooooooooool0Coooool00ooo003o0000ooooo`1Aooooo`008Oooool00ol0
003oooooooooo`2Oooooo`03ool00?oooooooooo04gooooo00?oo`00ooooooooool0D_ooool0027o
oooo00?o0000ooooooooool0X?ooool2ool004cooooo00?oo`00ooooooooool0Doooool0027ooooo
00?o0000ooooooooool0X_ooool00ooo003oooooooooo`18ooooo`03ool00?oooooooooo05Cooooo
000Qooooo`03o`000?oooooooooo0:?ooooo00?oo`00ooooooooool0A_ooool00ooo003ooooooooo
o`1Eooooo`008Oooool00ol0003oooooooooo`2Tooooo`03ool00?oooooooooo04Cooooo00?oo`00
ooooooooool0E_ooool0027ooooo0ol0002Uooooo`03ool00?oooooooooo047ooooo00?o0000ool0
0?ooool0F?ooool0027ooooo00?o0000ooooooooool0Y_ooool00ooo003o0000ooooo`0oooooo`03
o`000?oo003ooooo05Wooooo000Qooooo`03o`000?oooooooooo0:Oooooo00?oo`00o`000?ooool0
??ooool2o`000003oooooooo003ooooo05Wooooo000Qooooo`03o`000?oooooooooo0:Sooooo00?o
o`00o`000?ooool0>_ooool00ol0003oooooooooo`1Looooo`008Oooool00ol0003oooooooooo`2Z
ooooo`03o`000?oooooooooo03Kooooo0_l0001Oooooo`006?ooool4o`000003oa0@4?oooooooooo
00;ooooo00?o0000ooooooooool0Zoooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
05oooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[?ooool2o`0003?o
oooo00?o0000ooooooooool0H?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2^ooooo`03o`000?oooooooooo02kooooo0_l0001Sooooo`006_ooool00ol0003ooooooooo
o`04ooooo`?o0000[oooool2o`0002gooooo00?o0000ool00?oo0000Hoooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo02Sooooo0_l00000
0ooo003oooooooooo`1Sooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0;3ooooo0_oo0002o`0002Kooooo0_l00002ool006Kooooo000Jooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0/_ooool2ool00003o`000?oooooooooo027ooooo00Co0000ool00?oo
003oo`00J?ooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`2dooooo`04
ool00?l0003o0000o`0001gooooo0_l00002ool006_ooooo000Qooooo`03o`000?oooooooooo0;Go
oooo0ooo0004o`0001Kooooo0ol00002ool006gooooo000Qooooo`03o`000?oooooooooo0;Sooooo
1?oo0003o`00017ooooo0_l000000oooooooo`00ool0001_ooooo`008Oooool3o`000;cooooo0_oo
00000ooooooo0000o`000003o`0000Cooooo2?l00002ooooo`03ool00?oooooooooo06oooooo000Q
ooooo`03o`000?oooooooooo0;kooooo00?oo`00oooooooo00000oooool5o`0007_ooooo000Qoooo
o`03o`000?oooooooooo0<7ooooo1ooo001looooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00:Sooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2S
ooooo`00Qoooool3o`0001?ooooo00?o8B4QomgMgOooool01oooool00ooMgMgo410@onk^kP0Hoooo
o`03onk^k_l@413ogMgM0:?ooooo001nooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP03
ooooo`03o`000?oooooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P02ooooo`03oiRHV?mE
EEGooooo00Oooooo00CoEEEEoiRHV?oooooooooo1Ol00009ooooo`03oeEEEOnYZJWooooo00;ooooo
00?o^[ZjodA4A?ooool00_ooool00on7QhOoIVIVooooo`0Booooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c01kooooo`00O_ooool01ol@413o
gMgMogMgMolQ8B7oooooohN7QomVIVH00oooool00ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41000oooool00ol0003ogMgMooooo`06ooooo`09o`000?oooooooooooooooonHV9So
8B4Qonk^k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X3ooooo`03onk^k_l0
003ooooo00_ooooo1_l000001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40Noooool007kooooo00Oo0000oooooooMgMgo<S8booooooo^k^ko
410@00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`;oMgMg1oooool0
0olb<S;oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co410@omgMgOoooooo00001Ooo
ool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000007_ooooo001nooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03o`000?oooooooooo00Gooooo00?ok^k^oa0@4?o^k^h01_ooool00olb
<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001Oooool0
0ol0003oooooooooo`0:ooooo`Ko000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80Noooool007kooooo00?ogMgMob4Q8Oo^k^h00oooool0
0ol0003oooooooooo`02o`0000gooooo00?o0000ooooooooool01_ooool00omEEEGoV9RHooooo`05
ooooo`03o`000?o^k^kooooo00Cooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgo410@ooooool0
0004ooooo`03onk^k_l0003ooooo01;ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<
c?l0003o0000o`000?o<c<`0Noooool007oooooo00?oV9RHogMgMoooool00_ooool00ol0003ooooo
ooooo`0=ooooo`03oa0@4?l0003o000000?o00001Oooool00ooMgMgo410@ooooo`05ooooo`03oeEE
EOmgMgOooooo00Gooooo00?o0000ooooooooool02?ooool7o`0000;ooooo00?oMgMgoeEEEOooool0
4_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@401koooo
o`00U_ooool00ol0003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00WogMgMoa0@4?o^
k^koooooo`000?nj^[[ooooooiRHV?l@41004_ooool00oo^k^ko410@omgMg@0Cooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000007_ooooo002Fooooo`03o`00
0?oooooooooo00Oooooo00?o^[ZjodA4A?ooool01Oooool02?mgMgOoIVIVoooooonHV9So410@o`00
0?lQ8B7oc<c<4_ooool00omVIVKoMgMgooooo`0Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY07_ooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.85) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .31688 L
.06244 .32452 L
.08426 .33148 L
.0949 .33416 L
.10458 .33613 L
.11403 .33761 L
.11837 .33814 L
.12297 .3386 L
.1253 .33879 L
.12787 .33897 L
.13024 .33911 L
.1324 .33921 L
.13494 .3393 L
.13635 .33933 L
.137 .33935 L
.13768 .33936 L
.13891 .33937 L
.14005 .33938 L
.14075 .33939 L
.14141 .33938 L
.14264 .33938 L
.1438 .33937 L
.14504 .33935 L
.14622 .33932 L
.14729 .33929 L
.14991 .3392 L
.1524 .33908 L
.15734 .33877 L
.16271 .33831 L
.17231 .33721 L
.18119 .33588 L
.19985 .33229 L
.22045 .32739 L
.26066 .31691 L
.27913 .31259 L
.2896 .31051 L
.29934 .30887 L
.30903 .30759 L
.31446 .30704 L
.31938 .30665 L
.32191 .30649 L
.32459 .30635 L
.32599 .30629 L
.32753 .30624 L
.32893 .3062 L
.33024 .30618 L
.33087 .30617 L
.33156 .30616 L
.33282 .30615 L
Mistroke
.33404 .30615 L
.33518 .30615 L
.33587 .30616 L
.33653 .30617 L
.33775 .30619 L
.33906 .30622 L
.34048 .30626 L
.34287 .30636 L
.34542 .3065 L
.35001 .30684 L
.35548 .30739 L
.36046 .30805 L
.37129 .30995 L
.38154 .31238 L
.40149 .31891 L
.41992 .32704 L
.45924 .3507 L
.49704 .38001 L
.5373 .41497 L
.57604 .4481 L
.59572 .46336 L
.61723 .47806 L
.63803 .48982 L
.65691 .49809 L
.66702 .50151 L
.67655 .50406 L
.68145 .50511 L
.68662 .50603 L
.68932 .50643 L
.69229 .50681 L
.69501 .50709 L
.69752 .50731 L
.70002 .50748 L
.70132 .50755 L
.70275 .50761 L
.70399 .50765 L
.70515 .50768 L
.70638 .5077 L
.70707 .50771 L
.70771 .50771 L
.70883 .5077 L
.70987 .50769 L
.71101 .50767 L
.71223 .50764 L
.71352 .50759 L
.71473 .50753 L
.717 .5074 L
.71954 .5072 L
.72222 .50694 L
.72703 .50635 L
Mistroke
.73221 .50552 L
.73791 .50438 L
.74806 .50179 L
.75733 .49879 L
.77822 .48993 L
.79722 .47949 L
.81795 .46573 L
.85861 .43258 L
.89776 .39464 L
.93936 .35014 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .32735 L
.08255 .33538 L
.0932 .33907 L
.10458 .34248 L
.11531 .34513 L
.12507 .34704 L
.12977 .34777 L
.13488 .34843 L
.1397 .34891 L
.14415 .34925 L
.14658 .34938 L
.14881 .34948 L
.15004 .34952 L
.15138 .34955 L
.15264 .34958 L
.15382 .34959 L
.155 .3496 L
.15612 .34959 L
.15712 .34959 L
.1582 .34957 L
.15939 .34955 L
.16064 .34952 L
.16288 .34944 L
.16533 .34933 L
.16796 .34917 L
.17271 .34879 L
.17836 .3482 L
.1835 .34752 L
.20259 .34403 L
.22335 .33886 L
.26413 .32697 L
.28438 .32155 L
.2943 .31928 L
.3034 .3175 L
.31207 .31611 L
.31666 .31552 L
.32156 .31499 L
.32415 .31476 L
.32651 .31458 L
.3289 .31443 L
.3311 .31431 L
.33358 .31421 L
.33489 .31418 L
.33555 .31416 L
.33627 .31415 L
.33747 .31413 L
.33859 .31412 L
.33928 .31412 L
.33993 .31412 L
Mistroke
.34115 .31413 L
.3424 .31414 L
.3431 .31416 L
.34375 .31417 L
.34491 .3142 L
.34619 .31425 L
.34841 .31435 L
.35076 .31449 L
.35605 .31492 L
.36099 .31548 L
.36988 .31686 L
.37939 .31887 L
.38959 .32166 L
.40067 .32541 L
.42081 .33406 L
.46164 .35801 L
.50096 .38679 L
.53876 .41657 L
.57902 .44698 L
.61776 .47188 L
.63744 .48207 L
.65895 .49091 L
.6689 .49412 L
.67951 .4969 L
.68467 .498 L
.68953 .49889 L
.69423 .4996 L
.69862 .50015 L
.70327 .50059 L
.70573 .50077 L
.70837 .50092 L
.7097 .50097 L
.71114 .50102 L
.7118 .50104 L
.7125 .50106 L
.71376 .50108 L
.71497 .50109 L
.7161 .50109 L
.71734 .50108 L
.71804 .50107 L
.71868 .50106 L
.71975 .50103 L
.7209 .501 L
.72297 .50091 L
.72543 .50077 L
.72767 .50061 L
.73254 .50015 L
.73714 .49957 L
.74685 .49788 L
.75713 .49541 L
Mistroke
.77558 .48923 L
.79513 .48025 L
.81343 .46966 L
.85222 .44069 L
.89347 .40168 L
.9332 .3586 L
.97141 .31462 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`1Looooo`Go0000fOooool0
1_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooooooo0000>_l0000<ooooo`04omgMgOl0
003o410@olc<c0Gooooo000Qooooo`04o`000?oooooo0000o`0000_ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool01?l0003oooooooooooooool6o`0000Gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`02ooooo`Ko00001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`04onk^k_lQ8B7o410@onk^
kPGooooo000Qooooo`04o`000?ooooooooooooooo`;oo`002Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`Co00002oooool00ol0003oo`00ool00004ool000;ooooo1_oo000:ooooo`?o000000?oooooo`00
0?ooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0_l0000Coooo
o`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03o`000?oooooooooo00?ooooo0_oo00000ol0
003oooooooooo`0mooooo`Co00002oooool4ool001_ooooo0_l0002`ooooo`03o`000?oooooooooo
01;ooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool01Oooool2ool000;o
0000>?ooool4o`0000Wooooo1_oo000Looooo`?oo`000_ooool2o`000:gooooo00?o0000oooooooo
ool07Oooool0027ooooo00?o0000ooooooooool01oooool2ool000?o0000<Oooool4o`0000cooooo
00?oo`00ooooooooool08oooool2ool000;ooooo0_l0002Zooooo`03ool00?oooooooooo01kooooo
000Qooooo`03o`000?oooooooooo00Wooooo0ooo0003o`0002[ooooo1?l0000hooooo`;oo`000_oo
ool2o`000:Oooooo00?o0000ool00?ooool07oooool0027ooooo00?o0000ooooooooool03?ooool3
ool000Co00008oooool3o`0003kooooo0_oo0002ooooo`;o0000Y?ooool00ol0003oo`00ooooo`0P
ooooo`008Oooool3o`0000oooooo00Coo`00oooooooooooooooo1?l0000Kooooo`Co00002oooool3
ool003Gooooo0_oo0002ooooo`03o`000?oooooooooo0:3ooooo00?o0000ool00?ooool08Oooool0
027ooooo00?o0000ooooooooool05oooool5o`0000oooooo1ol0000<ooooo`?oo`00>_ooool2ool0
0003ooooool0003o000009oooooo00?o0000ool00?ooool08_ooool0027ooooo00?o0000oooooooo
ool07?ooool?o`0000kooooo1Ooo000oooooo`03ool00?oooooooooo00;o0000W?ooool00ol0003o
o`00ooooo`0Sooooo`008Oooool00ol0003oooooooooo`0eooooo`Coo`00AOooool01Ooo003ooooo
oooooooooooo000009[ooooo00?o0000ool00?ooool09?ooool0027ooooo00?o0000ooooooooool0
6_ooool6ool001Cooooo00?oo`00ooooooooool0C?ooool2o`0009Oooooo00?o0000ool00?ooool0
9Oooool0027ooooo00?o0000ooooooooool08?ooool:ool005_ooooo0_l0002Dooooo`03o`000?oo
003ooooo02Kooooo000Qooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool0TOooool0
0ooo003oooooooooo`0Vooooo`008Oooool3o`0008Sooooo00?o0000ooooooooool0Soooool00ooo
003oooooooooo`0Wooooo`008Oooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo08go
oooo00?oo`00ooooooooool0:?ooool0027ooooo00?o0000ooooooooool0R?ooool2ool00003o`00
0?oooooooooo08_ooooo00?o0000ool00?ooool0:Oooool0027ooooo00?o0000ooooooooool0R_oo
ool00ooo003o0000o`00002:ooooo`03o`000?oooooooooo02[ooooo000Qooooo`03o`000?oooooo
oooo08_ooooo00?oo`00ooooool00000R?ooool00ol0003oooooooooo`0[ooooo`008Oooool00ol0
003oooooooooo`2<ooooo`03ool00?oooooo000008Kooooo00?o0000ooooooooool0;?ooool0027o
oooo00?o0000ooooooooool0SOooool2ool00003o`000?oooooooooo08;ooooo00?o0000oooooooo
ool0;Oooool0027ooooo00?o0000ooooooooool0Soooool00ooo003o0000ooooo`21ooooo`03o`00
0?oooooooooo02kooooo000Qooooo`?o0000T?ooool00ooo003o0000o`00001oooooo`03o`000?oo
oooooooo02oooooo000Qooooo`03o`000?oooooooooo097ooooo00?oo`00ooooool00000OOooool0
0ol0003oooooooooo`0`ooooo`008Oooool00ol0003oooooooooo`2Booooo`;oo`0000?o0000oooo
ooooool0NOooool00ol0003oo`00ooooo`0aooooo`008Oooool00ol0003oooooooooo`2Dooooo`03
ool00?l0003o000007Sooooo00?o0000ool00?ooool0<_ooool0027ooooo00?o0000ooooooooool0
Uoooool00ol0003oooooooooo`1dooooo`03o`000?oo003ooooo03?ooooo000Qooooo`03o`000?oo
oooooooo09Sooooo00?o0000ooooooooool0L_ooool00ol0003oo`00ooooo`0dooooo`008Oooool0
0ol0003oooooooooo`2Iooooo`03o`000?oooooooooo073ooooo00?o0000ool00?ooool0=Oooool0
027ooooo0ol0002Jooooo`;o0000Koooool00ol0003oo`00ooooo`0fooooo`008Oooool00ol0003o
ooooooooo`2Looooo`03o`000?oooooooooo06_ooooo00?o0000ool00?ooool0=oooool0027ooooo
00?o0000ooooooooool0WOooool00ol0003oooooooooo`1Yooooo`03o`000?oo003ooooo03Sooooo
000Qooooo`03o`000?oooooooooo09gooooo00?oo`00o`000?l00000J?ooool00ol0003oo`00oooo
o`0iooooo`008Oooool00ol0003oooooooooo`2Nooooo`;oo`0000?o0000ooooooooool0I?ooool0
0ol0003oo`00ooooo`0jooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`2Pooooo`03ool00?l0
003ooooo06?ooooo00?o0000ool00?ooool0>oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0:7ooooo00?o
o`00o`000?ooool0HOooool00ol0003oo`00ooooo`0looooo`001oooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o0000ooooooooool00_ooool3o`000:;ooooo0_oo001Pooooo`03o`000?oo
oooooooo03gooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8boooo
o`03ooooo`03o`000?oooooooooo0:Cooooo00?oo`00ooooooooool0G?ooool00ol0003ooooooooo
o`0nooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo0:Gooooo0_oo001Jooooo`;o0000@Oooool000Oooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
Y_ooool00ol0003oo`00ooooo`1Gooooo`03o`000?oooooooooo047ooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0:Oooooo
00?o0000ool00?ooool0EOooool00ol0003oooooooooo`12ooooo`001oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0:Sooooo00?o0000ool00?ooool0
D_ooool2o`0004Gooooo000Qooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool0D?oo
ool00ol0003oo`00ool00015ooooo`008Oooool00ol0003oooooooooo`2Zooooo`;o0000Coooool0
0ol0003oo`00ooooo`16ooooo`008Oooool3o`000:cooooo00?o0000ooooooooool0Boooool00ol0
003oo`00ooooo`17ooooo`008Oooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo04So
oooo0_l000000ooo003oooooooooo`17ooooo`008Oooool00ol0003oooooooooo`2^ooooo`03o`00
0?oooooooooo04Kooooo00?o0000ool00?oo0000B_ooool0027ooooo00?o0000ooooooooool0[ooo
ool00ol0003oooooooooo`02ool004;ooooo00?o0000ool00?ooool0Boooool0027ooooo00?o0000
ooooooooool0/?ooool2o`0000;ooooo0_oo000nooooo`;o000000?oo`00ooooooooool0Boooool0
027ooooo00?o0000ooooooooool0/_ooool2o`0000;ooooo00?oo`00ooooooooool0>_ooool00ol0
003oooooool0001>ooooo`008Oooool00ol0003oooooooooo`2dooooo`03o`000?oooooooooo00;o
o`00>Oooool00ol0003oo`00ool0001?ooooo`008Oooool3o`000;Gooooo0_l00002ooooo`;oo`00
=_ooool2ool0057ooooo000Qooooo`03o`000?oooooooooo0;Oooooo0_l00002ooooo`;oo`00<ooo
ool00ol0003oooooooooo`1Aooooo`008Oooool00ol0003oooooooooo`2iooooo`04o`000?oooooo
ooooooooo`;oo`00;oooool2o`0005Cooooo000Qooooo`03o`000?oooooooooo0;[ooooo0_l00003
ooooo`03ool00?oooooooooo02[ooooo0_l0001Fooooo`008Oooool00ol0003oooooooooo`2loooo
o`05o`000?oooooooooooooooooo0000:Oooool2o`0005Sooooo000Qooooo`03o`000?oooooooooo
0;gooooo0ol0000Vooooo`;oo`000_l0001Jooooo`008Oooool00ol0003oooooooooo`30ooooo`?o
00008?ooool3ool000;o0000G?ooool0027ooooo00?o0000ooooooooool0`oooool3o`0000Cooooo
0ooo000Eooooo`03ool00?l0003o000005oooooo000Qooooo`?o0000a_ooool3o`0000Cooooo3_oo
0006ooooo`;o0000HOooool0027ooooo00?o0000ooooooooool0bOooool2o`00017ooooo1Ol0001S
ooooo`008Oooool00ol0003oooooooooo`3;oooooa7o0000J?ooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`00
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000oooo
ooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oo
ooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo
000Jooooo`03o`000?oooooooooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00:Cooooo00?oMgMgofIVI_ooool05oooool00omVIVKo
MgMgooooo`2Wooooo`00Poooool3o`0001Cooooo00?o8B4QomgMgOooool01_ooool00ooMgMgo410@
onk^kP0Hooooo`03onk^k_l@413ogMgM0:Oooooo001kooooo`07ohN7Qol0003oEEEEofIVI_l0003o
<S8bonk^kP02ooooo`03o`000?oooooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P03oooo
o`03oiRHV?mEEEGooooo00Kooooo00?oEEEEoiRHV?ooool00_ooool5o`0000Wooooo00?oEEEEojVY
ZOooool00_ooool01_nj^[[oA4A4ooooooooooooQhN7ofIVIQCooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@1eooooo`00Noooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00_ooool0
0ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ogMgMoooo
o`05ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00:ooooo`06oeEE
EOnHV9Soooooooooool@413o^[Zj0_ooool00oo^k^ko0000ooooo`0;ooooo`Ko00000_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401ooo
ool00omgMgOo<S8booooo`1dooooo`00Noooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@4100
0_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo0_mgMgL6ooooo`03oc8b
<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool00004ooooo`03
o`000?oooooooooo01;ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooo
ooooool000002?ooool00ol0003oooooooooo`1cooooo`00Noooool01?mEEEGoZJVYooooool00002
ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool01_ooool00oo^k^ko410@onk^
kP05ooooo`03oc8b<_oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7QhOoIVIVoooo
ool00004ooooo`03o`000?oooooooooo00[ooooo1_l00002ooooo`05o`000?ooooooooooooooool0
00002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Oooooo00?oMgMgoc8b<_ooool0M?ooool007_o
oooo00?ogMgMob4Q8Oo^k^h00oooool01?l0003oooooo`000?l0000=ooooo`03o`000?oooooooooo
00Oooooo00?oEEEEoiRHV?ooool01?ooool00ol0003ok^k^ooooo`05ooooo`03ogMgMomVIVKooooo
00[ooooo00CogMgMoa0@4?oooooo00000oooool00oo^k^ko0000ooooo`0Cooooo`05o`000?oooooo
ooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Cooooo00Go0000ob4Q8Ol0003o
<S8bolc<c01eooooo`00O?ooool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo00cooooo
00?o410@o`000?l000000ol00006ooooo`03omgMgOl@413ooooo00Cooooo00?oEEEEogMgMoooool0
1_ooool00ol0003oooooooooo`08ooooo`Oo000000?oooooogMgMomEEED05?ooool01Ol@413ooooo
oooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4004ooooo`03o`000?oooooooooo
07Oooooo002Booooo`03o`000?oooooooooo00Sooooo00?oEEEEoiRHV?ooool00oooool00ooMgMgo
410@onk^kP02ooooo`05o`000?nj^[[ooooooiRHV?l@41004Oooool00oo^k^ko410@omgMg@0Doooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Cooooo00?o
0000ooooooooool0Moooool009;ooooo00?o0000ooooooooool02?ooool00onj^[[oA4A4ooooo`04
ooooo`09ogMgMomVIVKooooooooooonHV9So410@o`000?lQ8B7oc<c<017ooooo00?oIVIVogMgMooo
ool05?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@04
ooooo`Co0000M_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .35043 L
.10458 .38922 L
.12507 .40438 L
.14415 .41594 L
.16254 .42461 L
.17277 .42837 L
.18221 .43117 L
.19242 .43349 L
.19781 .43441 L
.20351 .43517 L
.2059 .43542 L
.20846 .43565 L
.21068 .43581 L
.2131 .43595 L
.21456 .43602 L
.21592 .43607 L
.21722 .4361 L
.21795 .43612 L
.21861 .43613 L
.21986 .43614 L
.22056 .43614 L
.22121 .43614 L
.2224 .43614 L
.22365 .43612 L
.22487 .43609 L
.2262 .43605 L
.22861 .43595 L
.23096 .43582 L
.23313 .43567 L
.23806 .43522 L
.24329 .43458 L
.25201 .43318 L
.26163 .43115 L
.28097 .42568 L
.30183 .41796 L
.34297 .39872 L
.38259 .3778 L
.4207 .35825 L
.46126 .34046 L
.48 .33382 L
.50031 .32795 L
.51141 .32538 L
.52165 .3234 L
.53144 .32189 L
.53686 .3212 L
.5418 .32068 L
.54632 .32027 L
.55124 .31992 L
.55394 .31976 L
Mistroke
.55644 .31964 L
.55899 .31954 L
.56138 .31947 L
.56362 .31941 L
.56488 .31939 L
.56603 .31938 L
.56701 .31937 L
.56808 .31936 L
.5692 .31936 L
.57025 .31936 L
.57148 .31937 L
.57264 .31938 L
.57368 .3194 L
.57481 .31942 L
.57735 .31948 L
.57969 .31955 L
.58434 .31974 L
.58934 .32003 L
.59839 .32073 L
.60916 .32184 L
.61901 .32311 L
.65869 .32983 L
.69685 .33714 L
.71814 .34079 L
.73746 .34351 L
.74712 .3446 L
.75758 .34555 L
.76239 .34589 L
.76746 .3462 L
.77213 .34642 L
.77656 .34659 L
.77893 .34665 L
.78018 .34668 L
.78151 .34671 L
.78262 .34672 L
.78385 .34674 L
.78497 .34675 L
.78602 .34676 L
.78726 .34677 L
.78857 .34677 L
.78968 .34676 L
.7909 .34676 L
.79222 .34675 L
.79363 .34673 L
.79496 .34671 L
.79617 .34668 L
.80069 .34656 L
.80324 .34647 L
.80559 .34637 L
.8145 .34585 L
Mistroke
.81916 .3455 L
.82418 .34506 L
.83324 .34409 L
.85387 .34114 L
.87502 .33712 L
.89511 .33251 L
.93333 .32209 L
.97399 .3097 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .35303 L
.10458 .39523 L
.12507 .41151 L
.14415 .42385 L
.16254 .43312 L
.17277 .43716 L
.18221 .44021 L
.19242 .44277 L
.19781 .44382 L
.20351 .4447 L
.20846 .44528 L
.2131 .44568 L
.21575 .44584 L
.21818 .44594 L
.21952 .44598 L
.22028 .446 L
.22099 .44601 L
.22228 .44603 L
.223 .44603 L
.22365 .44603 L
.22486 .44603 L
.22598 .44601 L
.22721 .44599 L
.22853 .44595 L
.22991 .4459 L
.23122 .44583 L
.23368 .44569 L
.2381 .44534 L
.2429 .44482 L
.24814 .44409 L
.25371 .44314 L
.26372 .44098 L
.28319 .43525 L
.30147 .42823 L
.34016 .40931 L
.3813 .38564 L
.42092 .3626 L
.45903 .34299 L
.48028 .33395 L
.49959 .32719 L
.50923 .32438 L
.51968 .32177 L
.52947 .31974 L
.53864 .3182 L
.5481 .31697 L
.55312 .31646 L
.55851 .31603 L
.56121 .31586 L
.56415 .3157 L
Mistroke
.56675 .31558 L
.56951 .31549 L
.57092 .31545 L
.57224 .31542 L
.57344 .3154 L
.57472 .31539 L
.57595 .31538 L
.57724 .31537 L
.57835 .31537 L
.57956 .31538 L
.58087 .31539 L
.58208 .31541 L
.5834 .31543 L
.58481 .31546 L
.58718 .31553 L
.58979 .31562 L
.5946 .31584 L
.5991 .31612 L
.60918 .31693 L
.62003 .31808 L
.66122 .32428 L
.7009 .3311 L
.72091 .33415 L
.73906 .33643 L
.7485 .33739 L
.75871 .33822 L
.76433 .33859 L
.7695 .33887 L
.77445 .33908 L
.77713 .33917 L
.77967 .33924 L
.78204 .3393 L
.78329 .33932 L
.78462 .33934 L
.78574 .33936 L
.78697 .33937 L
.78808 .33938 L
.78914 .33938 L
.79038 .33939 L
.79168 .33939 L
.7928 .33938 L
.79402 .33938 L
.79534 .33937 L
.79675 .33935 L
.79929 .33931 L
.80165 .33926 L
.80422 .33919 L
.80889 .33902 L
.81761 .33858 L
.82706 .33792 L
Mistroke
.83747 .33698 L
.8585 .33442 L
.87792 .33136 L
.89881 .32741 L
.94005 .31805 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`3ooooooc_ooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0003o00000?oo00009ol0
0002ool000Oo00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool00ol0003oo`00oooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Sooooo0ooo0002o`0001?ooooo00Cok^k^ob4Q8Ol@413ok^k^
1Oooool0027ooooo0_l000000ooo003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00Co
0000oooooooooooooooo1ooo0004ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
1?ooool3o`000003ool00?l0003ooooo00;ooooo00?o0000ooooooooool04Oooool01?lQ8B7oMgMg
ogMgMolb<S85ooooo`008Oooool01?l0003oooooo`000?oo002Looooo`Soo`004Oooool6ool005oo
oooo1?l0000Kooooo`;o00000_ooool2o`0000Cooooo000Qooooo`05o`000?ooooooooooo`000?oo
0000U_ooool5ool001[o00001Oooool6ool005?ooooo0ooo0003o`0002Wooooo000Qooooo`06o`00
0?ooooooooooooooool0003oo`00TOooool3o`000004ool00?l0003o0000o`0001cooooo1?l00007
ooooo`Coo`00Boooool4ool000?o0000;?ooool0027ooooo00?o0000ooooooooool00_ooool00ol0
003oo`00ooooo`2<ooooo`?o00009oooool7o`0004[ooooo1Ooo00001?oooooo0000o`000?l0000_
ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Sooooo0ol0000aoooo
o`Ko00002?ooool5ool003?ooooo1?oo0003ooooo`?o0000<_ooool0027ooooo0ol00004ooooo`03
o`000?oooooooooo08Cooooo0ooo000jooooo`Ko00001oooool6ool002oooooo1Ol0000eooooo`00
8Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo083ooooo0ooo0013ooooo`Ko0000
1oooool6ool001Kooooo1ooo0006ooooo`Ko0000>_ooool0027ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1looooo`03o`000?oo003oo`0004cooooo1_l0000@ooooo`goo`001ooo
ool6o`00043ooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0NOooool0
0ol0003oo`00ool0001Dooooo`So00005oooool5o`0004Kooooo000Qooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0M_ooool00ol0003oo`00ool0001NoooooaOo0000Boooool0027o
oooo00?o0000ooooooooool02Oooool2o`0007?ooooo0ol000000ooo003oooooooooo`30ooooo`00
8Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06kooooo0_l000000oooooooo`00
ool00033ooooo`008Oooool3o`0000[ooooo00?oo`00ooooool00000KOooool2o`0000;ooooo00?o
o`00ooooooooool0`oooool0027ooooo00?o0000ooooooooool02oooool00ooo003oooooo`00001Z
ooooo`;o0000b_ooool0027ooooo00?o0000ooooooooool03?ooool00ooo003oooooo`00001Woooo
o`;o0000c?ooool0027ooooo00?o0000ooooooooool03Oooool00ooo003oooooo`00001Tooooo`;o
0000c_ooool0027ooooo00?o0000ooooooooool03_ooool01?oo003oooooo`000?l0001Pooooo`;o
0000d?ooool0027ooooo00?o0000ooooooooool03oooool01?oo003oooooooooool0001Mooooo`;o
00000_ooool2ool00<kooooo000Qooooo`03o`000?oooooooooo013ooooo00Coo`00oooooooooooo
0000F_ooool2o`0000;ooooo0_oo003@ooooo`008Oooool00ol0003oooooooooo`0Aooooo`04ool0
0?ooooooooooo`0005Oooooo0_l00002ooooo`;oo`00d_ooool0027ooooo0ol0000Booooo`04ool0
0?ooooooooooo`0005Cooooo0_l00002ooooo`;oo`00e?ooool0027ooooo00?o0000ooooooooool0
4oooool01?oo003oooooooooool0001Aooooo`;o00000_ooool2ool00=Kooooo000Qooooo`03o`00
0?oooooooooo01Cooooo00?oo`00ooooooooool00_l0001=ooooo`;o00000oooool00ooo003ooooo
ooooo`3Fooooo`008Oooool00ol0003oooooooooo`0Eooooo`05ool00?ooooooooooooooool00000
B_ooool2o`0000?ooooo0_oo003Iooooo`008Oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo04Gooooo0_l00004ooooo`03ool00?oooooooooo0=Wooooo000Qooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool0@_ooool2o`0000Gooooo00?oo`00ooooooooool0f_ooool0
027ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0oooooo`;o0000i?ooool0027o
oooo0ol0000Mooooo`;o0000?Oooool2o`000>Kooooo000Qooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool0=oooool3o`000>Sooooo000Qooooo`03o`000?oooooooooo023ooooo0_l0
000eooooo`;o0000joooool0027ooooo00?o0000ooooooooool07Oooool2ool000?ooooo00?o0000
ooooooooool0<?ooool2o`0000Kooooo0_oo003Uooooo`008Oooool00ol0003oooooooooo`0Ooooo
o`;oo`000_ooool3o`0002gooooo0_l00006ooooo`;oo`00ioooool000Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000
ooooooooool08Oooool2ool000?ooooo0ol0000Xooooo`;o00001_ooool2ool00>Wooooo0007oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool0
0ol0003oooooooooo`0Sooooo`;oo`001?ooool2o`0002Cooooo0_l00006ooooo`;oo`00joooool0
00Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0000U
ooooo`;oo`001?ooool00ol0003oooooooooo`0Mooooo`Co00001_ooool2ool00>gooooo0007oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo02Oooooo0_oo0003ooooo`Ko00005Oooool4o`0000Oooooo0ooo003_ooooo`001oooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oo
oooooooo02Wooooo0_oo0007ooooo`;o00004?ooool3o`0000Wooooo0_oo003booooo`001oooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0[ooooo`03ool00?oooooooooo00Kooooo4?l0003oooooo`7ooooo0007ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003ooooooooo
o`14ooooo`;oo`00o_ooool0027ooooo00?o0000ooooooooool0=_ooool>ool00?oooooo0Oooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003ooooooooo
o`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5
ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[o
oooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00Z?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOo
oooo0:?ooooo0027ooooo`?o00004oooool00olQ8B7ogMgMooooo`07ooooo`03omgMgOl@413ok^k^
01Sooooo00?ok^k^oa0@4?oMgMd0Xoooool007kooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;o
k^k^00?ooooo00?o0000ooooooooool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00?o
V9RHoeEEEOooool01oooool01?mEEEGoV9RHooooooooool5o`0000Wooooo00?oEEEEojVYZOooool0
0_ooool00onj^[[oA4A4ooooo`02ooooo`03ohN7QomVIVKooooo01;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01?l@413o0000odA4A?o<c<alooooo`00O_ooool01ol@413o
gMgMogMgMolQ8B7oooooohN7QomVIVH00oooool00ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41000oooool00ol0003ogMgMooooo`06ooooo`09o`000?oooooooooooooooonHV9So
8B4Qonk^k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X3ooooo`03onk^k_l0
003ooooo00_ooooo1_l000001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B46ooooo`03
oiRHV?l@413ogMgM07_ooooo001nooooo`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@4003oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool2ogMgM`Oooooo00?o<S8boooo
ooooool00_ooool00onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`0000Gooooo00?o0000
ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00kooooo00?oQhN7oeEEEOooool0N_oo
ool007kooooo00CoEEEEojVYZOoooooo00000_ooool01Ol0003ooooooooooooooooo000000gooooo
00?o0000ooooooooool01Oooool00oo^k^ko410@onk^kP06ooooo`03oc8b<_oooooooooo00?ooooo
00?oV9RHob4Q8Oo^k^h02oooool01?n7QhOoIVIVooooool00005ooooo`03o`000?oooooooooo00[o
oooo1_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<ob4Q8Ol0
003oEEEEo`00001kooooo`00O_ooool00ooMgMgo8B4Qonk^kP03ooooo`03o`000?oooooooooo00;o
00003Oooool00ol0003oooooooooo`06ooooo`03oeEEEOnHV9Sooooo00Gooooo00?o0000onk^k_oo
ool01?ooool00omgMgOoIVIVooooo`0:ooooo`04omgMgOl@413oooooo`0000Cooooo00?ok^k^o`00
0?ooool04_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go8B4QohN7QoooooooV9RHo`00
001kooooo`00Ooooool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo00gooooo00?o410@
o`000?l000000ol00005ooooo`03omgMgOl@413ooooo00Gooooo00?oEEEEogMgMoooool01Oooool0
0ol0003oooooooooo`08ooooo`Oo00000_ooool00omgMgOoEEEEooooo`0Booooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol0003ooooooooooooooooo000007_ooooo002Fooooo`03o`000?oo
oooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool02OoMgMgo410@onk^k_oooooo0000okZj^_oo
ooooV9RHoa0@400Booooo`03onk^k_l@413ogMgM01?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ob4Q8OnHV9SoooooogMgMomEEED0Noooool009Kooooo00?o0000ooooooooool01oooool0
0onj^[[oA4A4ooooo`05ooooo`08ogMgMomVIVKooooooiRHV?l@413o0000ob4Q8Oo<c<`Booooo`03
ofIVI_mgMgOooooo01?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05olc<c?l@413o0000
oc8b<_o^k^h0Noooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36468 L
.10458 .42001 L
.14415 .46289 L
.16408 .48026 L
.18221 .49329 L
.20178 .50419 L
.21254 .50873 L
.22272 .51204 L
.23241 .51431 L
.2373 .51513 L
.24012 .5155 L
.24269 .51577 L
.24504 .51596 L
.24728 .5161 L
.2485 .51616 L
.24964 .5162 L
.25088 .51623 L
.25158 .51624 L
.25221 .51624 L
.25336 .51624 L
.25442 .51623 L
.25558 .51621 L
.2568 .51617 L
.25787 .51613 L
.25887 .51608 L
.26113 .51593 L
.26373 .5157 L
.26614 .51543 L
.27158 .51464 L
.27638 .51372 L
.28148 .51252 L
.2903 .50991 L
.30004 .50626 L
.31939 .49668 L
.34024 .48313 L
.38138 .44783 L
.42101 .4055 L
.45912 .36022 L
.49968 .31074 L
.53872 .26525 L
.58022 .22251 L
.60102 .20419 L
.6202 .18951 L
.64007 .17674 L
.65867 .16721 L
.67743 .16007 L
.68738 .15731 L
.69293 .15608 L
.69807 .15514 L
Mistroke
.70298 .15441 L
.7082 .15384 L
.71119 .1536 L
.71265 .1535 L
.714 .15343 L
.7152 .15337 L
.71652 .15332 L
.71785 .15329 L
.71857 .15327 L
.71924 .15326 L
.7205 .15325 L
.7212 .15325 L
.72186 .15325 L
.72305 .15326 L
.72433 .15328 L
.72546 .15331 L
.72653 .15335 L
.72895 .15346 L
.73157 .15363 L
.73396 .15382 L
.73935 .15439 L
.7441 .15506 L
.74918 .15594 L
.75831 .15795 L
.77902 .16441 L
.80041 .17365 L
.82057 .18449 L
.85909 .20996 L
.90006 .24213 L
.93952 .27616 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36768 L
.10458 .42297 L
.14415 .46615 L
.18221 .49767 L
.20178 .50932 L
.21274 .51436 L
.22272 .51798 L
.22755 .51939 L
.23267 .52064 L
.2371 .52152 L
.24186 .52225 L
.24453 .52256 L
.24697 .52279 L
.24814 .52288 L
.24942 .52296 L
.25062 .52302 L
.25175 .52306 L
.25244 .52308 L
.25319 .5231 L
.25449 .52312 L
.25523 .52312 L
.25601 .52312 L
.25667 .52311 L
.2574 .5231 L
.25871 .52306 L
.25945 .52303 L
.26011 .523 L
.26265 .52285 L
.26493 .52265 L
.26745 .52238 L
.27256 .52164 L
.27729 .52072 L
.28173 .51967 L
.29172 .51661 L
.30249 .51227 L
.32253 .50141 L
.34363 .48635 L
.38174 .45111 L
.4223 .40527 L
.46135 .35685 L
.50284 .30502 L
.54283 .25836 L
.58129 .21926 L
.60078 .20226 L
.62221 .18604 L
.6428 .17306 L
.66161 .16356 L
.68106 .15615 L
.69178 .15314 L
Mistroke
.69712 .15193 L
.70195 .15099 L
.70657 .15025 L
.71157 .1496 L
.71431 .14932 L
.71684 .1491 L
.71941 .14892 L
.7218 .1488 L
.72386 .14872 L
.72502 .14869 L
.72607 .14867 L
.72722 .14866 L
.72848 .14865 L
.72966 .14866 L
.73075 .14867 L
.73188 .14869 L
.73293 .14872 L
.73409 .14876 L
.73534 .14881 L
.73787 .14895 L
.7402 .14912 L
.74495 .14956 L
.75003 .15021 L
.75916 .15178 L
.77002 .15436 L
.77988 .15735 L
.7991 .1649 L
.81991 .17552 L
.86088 .20305 L
.90034 .23607 L
.93828 .27159 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3Eooooo`[oo`00IOooool0027o
oooo00?o0000ooooooooool0goooool5ool0063ooooo000Qooooo`03o`000?oooooooooo0<gooooo
0_oo000Ao`0000Cooooo00?oo`00ooooooooool0GOooool0027ooooo00?o0000ooooooooool0b_oo
ool3ool000;o00004Oooool6o`0005kooooo000Qooooo`03o`000?oooooooooo0<Oooooo0ooo0000
0ol0003oooooooooo`0Iooooo`?o0000Foooool0027ooooo00?o0000ooooooooool0a?ooool3ool0
0003o`000?oooooooooo01oooooo0_l00004ooooo`;oo`00Doooool0027ooooo0ol00033ooooo`03
ool00?l0003ooooo02Gooooo0ol00003ooooo`;oo`00DOooool0027ooooo00?o0000ooooooooool0
`Oooool2o`0002_ooooo0_l00003ooooo`03ool00?oooooooooo04kooooo000Qooooo`03o`000?oo
oooooooo0;oooooo0_l0000_ooooo`;o00000_ooool2ool004kooooo000Qooooo`03o`000?oooooo
oooo0;gooooo0_l0000cooooo`;o00000_ooool2ool004cooooo000Qooooo`03o`000?oooooooooo
0;cooooo00?o0000ooooooooool0=Oooool2o`0000;ooooo00?oo`00ooooooooool0BOooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Cooooo00?o0000ooooooooool0^Oooool00ooo003o0000o`00000jooooo`;o000000?ooooo
ool00?oo0000BOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0;Oooooo0_oo00000ol0003oooooooooo`0l
ooooo`04o`000?ooooooooooool004Sooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00;ooooo0ol0002fooooo`03ool00?l0003o0000043ooooo0_l0
00000oooooooo`00ooooo`16ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool00oooool00ol0003oooooooooo`2eooooo`03ool00?l0003ooooo04?ooooo00?o
0000ooooooooool0A_ooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`2dooooo`03ool00?l0003ooooo04Gooooo
0_l00016ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`2cooooo`03ool00?l0003ooooo04Sooooo00?o0000ooooooooool0
@oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0/Oooool2ool00003o`000?oooooooooo04Wooooo0_l00013ooooo`001ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0;3ooooo
00?oo`00o`000?l00000C_ooool00ol0003oooooooooo`10ooooo`008Oooool00ol0003ooooooooo
o`2_ooooo`03ool00?l0003ooooo053ooooo0_l000000oooooooo`00ool0000mooooo`008Oooool0
0ol0003oooooooooo`2^ooooo`03ool00?l0003ooooo05?ooooo00Co0000ooooooooooooo`00??oo
ool0027ooooo0ol0002]ooooo`03ool00?oooooooooo05Gooooo00Co0000ooooooooooooo`00>ooo
ool0027ooooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`1Gooooo`;o000000?ooooo
ool00?ooool0>Oooool0027ooooo00?o0000ooooooooool0Zoooool00ol0003oooooooooo`1Joooo
o`03o`000?ooooooo`0003Wooooo000Qooooo`03o`000?oooooooooo0:_ooooo00?o0000oooooooo
ool0Foooool00ol0003oooooool0000hooooo`008Oooool00ol0003oooooooooo`2Zooooo`03o`00
0?oooooooooo05gooooo00?o0000oooooooo0000=oooool0027ooooo00?o0000ooooooooool0ZOoo
ool00ol0003oooooooooo`1Oooooo`;o000000?oo`00ooooooooool0=?ooool0027ooooo00?o0000
ooooooooool0Z?ooool00ol0003oooooooooo`1Rooooo`03o`000?oo003ooooo03Cooooo000Qoooo
o`?o0000Yoooool00ol0003oooooooooo`1Tooooo`03o`000?oo003oo`0003?ooooo000Qooooo`03
o`000?oooooooooo0:Gooooo00?oo`00o`000?ooool0Ioooool2o`000003ool00?oooooooooo033o
oooo000Qooooo`03o`000?oooooooooo0:Cooooo00?oo`00o`000?ooool0J_ooool00ol0003ooooo
ooooo`0`ooooo`008Oooool00ol0003oooooooooo`2Sooooo`03ool00?l0003ooooo06cooooo00?o
0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool0X_ooool00ooo003o0000ooooo`1^
ooooo`03o`000?oooooooooo02kooooo000Qooooo`03o`000?oooooooooo0:7ooooo00?oo`00o`00
0?ooool0L?ooool00ol0003oooooooooo`0]ooooo`008Oooool00ol0003oooooooooo`2Pooooo`03
ool00?l0003ooooo07;ooooo00?o0000ooooooooool0;?ooool0027ooooo00?o0000ooooooooool0
Woooool00ooo003o0000ooooo`1dooooo`03o`000?oooooooooo02_ooooo000Qooooo`?o0000Wooo
ool00ooo003oooooooooo`1eooooo`03o`000?oooooooooo02[ooooo000Qooooo`03o`000?oooooo
oooo03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM03gooooo1?l000000ol@413oooooooooo`07ooooo`03ool00?oooooooooo037ooooo
1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM037o
oooo00?o0000ool00?ooool02Oooool5o`0001_ooooo000Qooooo`03o`000?oooooooooo03gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0nooooo`03
o`000?oooooooooo00Sooooo00?oo`00o`000?ooool0=?ooool00ol0003oooooooooo`04ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0aooooo`03o`000?oo003ooooo00Sooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Oooooo00?oo`00o`00
0?ooool0=Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo037ooooo00?o0000ool0
0?ooool02?ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003oooooooooo`0mooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0nooooo`03o`000?oooooooooo
00Kooooo00?oo`00o`000?ooool0=_ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo
03?ooooo00?o0000ool00?ooool02?ooool00onHV9So8B4Qonk^kP0Kooooo`008Oooool00ol0003o
ooooooooo`0mooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<03oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00fooooo`03ool00?oooooooooo00Oooooo00?o
MgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0iooooo`03ool00?oo
oooooooo00Oooooo00?o0000ooooooooool06Oooool0027ooooo0ol0000mooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03[ooooo00?o
o`00ooooooooool00_ooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`03o`000?oo
oooooooo03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000?_ooool00omEEEGoIVIV
o`000005ooooo`03o`000?oooooooooo03Oooooo00?oEEEEofIVI_l000003Oooool4o`0003[ooooo
00Woo`00oooooooooooooooooiRHV?l@413o0000ob4Q8Oo<c<`06oooool0027ooooo00?o0000oooo
ooooool0V?ooool00ol0003oooooooooo`26ooooo`03ool00?l0003ooooo023ooooo000Qooooo`03
o`000?oooooooooo09Oooooo00?o0000ooooooooool0R?ooool00ooo003o0000ooooo`0Oooooo`00
8Oooool00ol0003oooooooooo`2Fooooo`03o`000?oooooooooo08[ooooo00?oo`00o`000?ooool0
7_ooool0027ooooo00?o0000ooooooooool0UOooool00ol0003oooooooooo`2<ooooo`03ool00?l0
003ooooo01?ooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool0Toooool0
0ooo003o0000ooooo`2@ooooo`03o`000?oooooooooo017ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`00
0?oMgMd4ooooo`006_oooonMo`000003ool00?l0003o000009Wo00003?ooool01?oMgMgo0000oa0@
4?o<c<`5ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool04Oooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool2o`0000gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o
o`00o`000?ooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo
000Qooooo`03o`000?oooooo0000093ooooo00?oo`00o`000?ooool0Yoooool2o`0000;ooooo0_l0
0004ooooo`008Oooool00ol0003oooooo`00002@ooooo`03ool00?oooooooooo0;7ooooo000Qoooo
o`04o`000?ooooooooooo`0008kooooo00?oo`00ooooooooool0/_ooool0027ooooo00Go0000oooo
ooooooooooooool0002<ooooo`03ool00?oooooooooo0;?ooooo000Qooooo`05o`000?oooooooooo
oooooooo0000Roooool00ooo003oooooooooo`2dooooo`008Oooool3o`0000;ooooo00?oo`00oooo
ooooool0Qoooool00ol0003oo`00ooooo`2eooooo`008Oooool00ol0003oooooooooo`03ooooo`03
ool00?oooooooooo08Gooooo00?o0000ool00?ooool0]_ooool0027ooooo00?o0000ooooooooool0
0oooool00ooo003oooooooooo`25ooooo`03ool00?oooooooooo0;Kooooo000Qooooo`03o`000?oo
oooooooo00Cooooo00?oo`00ooooooooool0Poooool00ooo003oooooooooo`2gooooo`008Oooool0
0ol0003oooooooooo`04ooooo`03ool00?l0003ooooo08;ooooo00?o0000ooooooooool0^?ooool0
027ooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`20ooooo`03o`000?oooooooooo
0;Wooooo000Qooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool0O_ooool00ol0003o
ooooooooo`2jooooo`008Oooool3o`0000Kooooo00?oo`00o`000?ooool0OOooool00ol0003ooooo
ooooo`2kooooo`008Oooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo07_ooooo00?o
0000ooooooooool0_?ooool0027ooooo00?o0000ooooooooool01oooool00ooo003o0000ooooo`1k
ooooo`03o`000?oooooooooo0;cooooo000Qooooo`03o`000?oooooooooo00Sooooo00?oo`00o`00
0?ooool0NOooool00ol0003oooooooooo`2mooooo`008Oooool00ol0003oooooooooo`09ooooo`;o
o`00N?ooool00ooo003oooooooooo`2nooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo07Gooooo00?o0000ool00?ooool0_oooool0027ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1cooooo`03o`000?oo003ooooo0<3ooooo000Qooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0LOooool00ol0003oo`00ooooo`31ooooo`008Oooool3o`00
00gooooo00?o0000ooooooooool0Koooool00ol0003oo`00ooooo`32ooooo`008Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo06kooooo00?oo`00ooooooooool0`_ooool0027ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`1]ooooo`03ool00?oooooooooo0<?ooooo
000Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Joooool00ol0003oo`00oooo
o`34ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06Wooooo00?o0000
ool00?ooool0aOooool0027ooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`1Woooo
o`03o`000?oo003ooooo0<Kooooo000Qooooo`03o`000?oooooooooo017ooooo00?oo`00o`000?oo
ool0I_ooool00ol0003oo`00ooooo`37ooooo`008Oooool3o`0001;ooooo00?oo`00ooooooooool0
I?ooool00ol0003oo`00ooooo`38ooooo`008Oooool00ol0003oooooooooo`0Cooooo`03ool00?oo
oooooooo06?ooooo00?oo`00ooooooooool0b?ooool0027ooooo00?o0000ooooooooool05?ooool0
0ooo003oooooooooo`1Qooooo`03o`000?oooooooooo0<Wooooo000Qooooo`03o`000?oooooooooo
01Cooooo00?oo`00o`000?ooool0H?ooool00ol0003oooooooooo`3:ooooo`008Oooool00ol0003o
ooooooooo`0Eooooo`03ool00?l0003ooooo05kooooo00?o0000ooooooooool0boooool000Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Cooooo00?o0000ooooooooool05_ooool00ooo003o0000ooooo`1Looooo`03o`000?oooooooooo
0<cooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool00oooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo05[ooooo00?o0000oooo
ooooool0cOooool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo
00;ooooo0ol0000Gooooo`03ool00?l0003ooooo05Wooooo00?o0000ooooooooool0c_ooool000Oo
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooo
ooooool06?ooool00ooo003o0000ooooo`1Hooooo`03o`000?oooooooooo0<kooooo0007ooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000
ooooooooool06Oooool00ooo003o0000ooooo`1Fooooo`03o`000?oooooooooo0<oooooo0007oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01[ooooo00?oo`00o`000?ooool0E?ooool00ol0003oo`00ooooo`3@ooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo057ooooo00?o0000ool00?ooool0dOooool000Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo04oooooo00?o0000ool00?ooool0d_ooool0027ooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1=ooooo`03o`000?oo003ooooo0=?ooooo000Qooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool0B_ooool2o`000003ool00?oooooooooo0=?ooooo000Qooooo`?o0000
8?ooool00ol0003oooooooooo`18ooooo`03o`000?ooooooo`000=Kooooo000Qooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0A_ooool00ol0003oooooool0003Gooooo`008Oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04Cooooo00?o0000oooooooo0000f?ooool0
027ooooo00?o0000ooooooooool08_ooool00ooo003o0000ooooo`13ooooo`03o`000?ooooooo`00
0=Wooooo000Qooooo`03o`000?oooooooooo02?ooooo0_oo0011ooooo`;o000000?oooooool00?oo
ool0fOooool0027ooooo00?o0000ooooooooool09Oooool00ooo003oooooooooo`0mooooo`04o`00
0?ooooooooooool00=_ooooo000Qooooo`03o`000?oooooooooo02Kooooo00?oo`00ooooooooool0
>oooool01?l0003ooooooooooooo003Looooo`008Oooool3o`0002Oooooo00?oo`00ooooooooool0
>Oooool00ol0003oooooooooo`3Nooooo`008Oooool00ol0003oooooooooo`0Xooooo`;oo`00>?oo
ool00ol0003oooooooooo`3Oooooo`008Oooool00ol0003oooooooooo`0Yooooo`03o`000?oo003o
oooo03Gooooo00?o0000ooooooooool0h?ooool0027ooooo00?o0000ooooooooool0:oooool00ooo
003oooooooooo`0aooooo`;o0000hoooool0027ooooo00?o0000ooooooooool0;?ooool00ooo003o
0000ooooo`0_ooooo`03o`000?oooooooooo0>?ooooo000Qooooo`03o`000?oooooooooo02gooooo
00?oo`00o`000?ooool0;?ooool2o`000>Kooooo000Qooooo`03o`000?oooooooooo02kooooo00?o
o`00o`000?l00000:_ooool01?l0003oooooool00?oo003Uooooo`008Oooool00ol0003ooooooooo
o`0aooooo`;o00009_ooool2o`000003oooooooo003ooooo0>Kooooo000Qooooo`?o0000<oooool2
o`0002;ooooo0_l000000oooooooo`00ool0003Xooooo`008Oooool00ol0003oooooooooo`0eoooo
o`;o00007_ooool2o`000003oooooooo003oo`000>[ooooo000Qooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool06Oooool2o`0000;ooooo00?oo`00ooooooooool0j_ooool0027ooooo
00?o0000ooooooooool0>?ooool3o`0001Gooooo0ol00002ooooo`;oo`00kOooool0027ooooo00?o
0000ooooooooool0=oooool3ool00003ooooool0003o000000?o00003?ooool4o`0000?ooooo0_oo
003_ooooo`008Oooool00ol0003oooooooooo`0jooooo`;oo`001?ooool<o`0000Gooooo0_oo003a
ooooo`008Oooool00ol0003oooooooooo`0looooo`Coo`00ooooool5ooooo`008Oooool3o`00043o
oooo1ooo003mooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003o
ooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOoo
ool001[ooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0
003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIV
I_mgMgOooooo0:Oooooo0023ooooo`?o00005?ooool00olQ8B7ogMgMooooo`06ooooo`03omgMgOl@
413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Yoooool007_ooooo00OoQhN7o`000?mEEEGoIVIVo`00
0?lb<S;ok^k^00;ooooo00?o0000ooooooooool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00?o
oooo00?oV9RHoeEEEOooool01_ooool00omEEEGoV9RHooooo`02ooooo`Go00002Oooool00omEEEGo
ZJVYooooo`02ooooo`06okZj^_m4A4Cooooooooooon7QhOoIVIV5?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`04oa0@4?l0003oA4A4olc<c0Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@1eooooo`00Noooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00_ooool00ol0
003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ogMgMooooo`05
ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00:ooooo`06oeEEEOnH
V9Soooooooooool@413o^[Zj0_ooool00oo^k^ko0000ooooo`0;ooooo`Ko00000_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oiRHV?l@413ogMgM00Oooooo00?oMgMgoc8b
<_ooool0M?ooool007_ooooo00Oo0000oooooooMgMgo<S8booooooo^k^ko410@00;ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`06ooooo`;oMgMg1_ooool00olb<S;oooooooooo`03
ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co410@omgMgOoooooo00001?ooool00ol0003ooooooooo
o`0Booooo`05oa0@4?ooooooooooooooool@41003_ooool00on7QhOoEEEEooooo`07ooooo`03o`00
0?oooooooooo07?ooooo001kooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Co0000oooooooooooo
00003Oooool00ol0003oooooooooo`06ooooo`03onk^k_l@413ok^k^00Gooooo00?o<S8boooooooo
ool01?ooool00onHV9So8B4Qonk^kP0;ooooo`04ohN7QomVIVKoooooo`0000Cooooo00?o0000oooo
ooooool02_ooool6o`0000;ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?lQ8B7o
0000oeEEEOl000001oooool00omgMgOo<S8booooo`1dooooo`00Noooool00ooMgMgo8B4Qonk^kP03
ooooo`04o`000?oooooo0000o`0000gooooo00?o0000ooooooooool01oooool00omEEEGoV9RHoooo
o`04ooooo`03o`000?o^k^kooooo00Gooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgo410@oooo
ool00003ooooo`03onk^k_l0003ooooo01?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
ob4Q8On7QhOooooooiRHV?l000001?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<07Gooooo001loooo
o`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool03?ooool00ol@413o0000o`000003o`00
00Kooooo00?ogMgMoa0@4?ooool01?ooool00omEEEGoMgMgooooo`06ooooo`03o`000?oooooooooo
00Sooooo1ol000000oooooooMgMgoeEEE@0Dooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0Moooool009;ooooo00?o0000
ooooooooool02?ooool00omEEEGoV9RHooooo`03ooooo`03omgMgOl@413ok^k^00;ooooo00Go0000
okZj^_ooooooV9RHoa0@400Aooooo`03onk^k_l@413ogMgM01Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05ob4Q8OnHV9SoooooogMgMomEEED01?ooool00ol0003oooooooooo`1gooooo`00
T_ooool00ol0003oooooooooo`08ooooo`03okZj^_m4A4Cooooo00Cooooo00WoMgMgofIVI_oooooo
oooooiRHV?l@413o0000ob4Q8Oo<c<`04Oooool00omVIVKoMgMgooooo`0Dooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01Oo<c<co410@o`000?lb<S;ok^k^00Cooooo1?l0001fooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -43.625 0 ]
[.5 .63053 43.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -104.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
146.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36897 L
.10458 .42975 L
.14415 .47855 L
.18221 .51463 L
.20178 .52826 L
.21267 .53427 L
.22272 .53879 L
.23293 .54236 L
.23832 .54382 L
.24402 .54504 L
.24641 .54546 L
.24897 .54584 L
.25119 .54611 L
.25361 .54635 L
.25507 .54647 L
.25643 .54655 L
.25773 .54662 L
.2584 .54665 L
.25912 .54667 L
.25983 .54669 L
.26048 .5467 L
.26176 .54672 L
.26293 .54671 L
.26416 .54669 L
.26538 .54666 L
.26607 .54663 L
.26671 .5466 L
.26912 .54646 L
.27131 .54627 L
.27364 .54602 L
.27847 .54532 L
.2838 .54427 L
.29326 .54169 L
.30213 .53843 L
.32232 .52812 L
.34082 .51523 L
.38045 .47762 L
.41855 .43067 L
.45912 .3724 L
.49816 .31194 L
.53966 .24751 L
.57964 .18973 L
.61811 .14196 L
.63759 .1217 L
.65902 .10299 L
.67938 .089 L
.69843 .07949 L
.70884 .0758 L
.71396 .07438 L
Mistroke
.71872 .0733 L
.72301 .07253 L
.72758 .07192 L
.7302 .07166 L
.73148 .07156 L
.73266 .07149 L
.73371 .07143 L
.73487 .07138 L
.73603 .07135 L
.73725 .07132 L
.73856 .07132 L
.73977 .07133 L
.7404 .07134 L
.7411 .07136 L
.74183 .07138 L
.74251 .07141 L
.7449 .07154 L
.74625 .07164 L
.74748 .07175 L
.75203 .07228 L
.7568 .07308 L
.76198 .0742 L
.7668 .07549 L
.77773 .0793 L
.78828 .08411 L
.79823 .08965 L
.81683 .10255 L
.85534 .13894 L
.89632 .1896 L
.93577 .24654 L
.97371 .30514 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36745 L
.10458 .42888 L
.14415 .47887 L
.18221 .51541 L
.20178 .52887 L
.21274 .53472 L
.22272 .53897 L
.22755 .54066 L
.23267 .54218 L
.2371 .54328 L
.24186 .54424 L
.24453 .54467 L
.24697 .545 L
.24945 .54527 L
.25175 .54547 L
.25305 .54556 L
.25442 .54563 L
.25521 .54566 L
.25595 .54569 L
.25662 .54571 L
.25734 .54572 L
.25798 .54573 L
.25868 .54574 L
.25942 .54574 L
.2601 .54573 L
.26133 .54571 L
.26265 .54567 L
.26386 .54561 L
.26521 .54554 L
.26793 .54533 L
.27045 .54507 L
.27282 .54476 L
.27815 .54388 L
.28389 .54261 L
.29438 .53945 L
.30401 .53563 L
.32293 .52562 L
.34363 .51103 L
.38419 .47244 L
.42324 .42464 L
.46474 .3653 L
.50472 .30334 L
.54318 .24316 L
.5841 .18312 L
.62351 .13374 L
.66139 .09783 L
.68084 .08474 L
.69176 .07912 L
.70173 .07511 L
Mistroke
.70651 .07357 L
.7116 .07221 L
.716 .07126 L
.72076 .07048 L
.72368 .07013 L
.72496 .07 L
.72636 .06988 L
.7276 .0698 L
.72893 .06972 L
.72966 .06969 L
.73033 .06967 L
.73164 .06963 L
.7329 .06962 L
.73407 .06962 L
.73535 .06964 L
.73599 .06966 L
.7367 .06968 L
.73789 .06974 L
.73918 .06981 L
.74149 .06999 L
.7439 .07024 L
.74647 .07057 L
.75109 .07135 L
.75659 .07257 L
.76157 .07396 L
.77244 .07788 L
.78269 .08268 L
.80274 .09498 L
.8212 .10949 L
.86066 .14929 L
.8986 .19655 L
.93899 .25354 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000=Gooooo3Ooo001Rooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=Cooooo1Ol00009ooooo`?oo`00
0_l0001Mooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=;ooooo0_l0
000Cooooo`;o0000Foooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3=
ooooo`;oo`000ol0000Gooooo`?o0000F?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3:ooooo`?oo`000_l0000Mooooo`;o0000E_ooool001Sooooo00?oEEEEofIVI_l0
00001_ooool00ol0003oooooooooo`38ooooo`;oo`0000?oooooo`000?l000008Oooool00ol0003o
ooooooooo`1Cooooo`008Oooool00ol0003oooooooooo`37ooooo`04ool00?oooooo0000o`0002?o
oooo0_oo00000ol0003oooooooooo`1Aooooo`008Oooool00ol0003oooooooooo`35ooooo`;oo`00
00?oooooo`000?ooool09_ooool00ooo003o0000ooooo`1Aooooo`008Oooool3o`000<Cooooo00Co
o`00ooooool0003o0000:Oooool2ool00003o`000?oooooooooo04kooooo000Qooooo`03o`000?oo
oooooooo0<Cooooo00?oo`00o`000?ooool0;?ooool00ooo003o0000ooooo`1>ooooo`008Oooool0
0ol0003oooooooooo`33ooooo`03ool00?l0003ooooo02kooooo00?oo`00o`000?l00000COooool0
027ooooo00?o0000ooooooooool0`_ooool00ooo003oooooooooo`0`ooooo`03ool00?oooooo0000
04cooooo000Qooooo`03o`000?oooooooooo0<7ooooo00?oo`00ooooooooool0<_ooool00ooo003o
ooooo`00001;ooooo`008Oooool00ol0003oooooooooo`30ooooo`03o`000?oooooooooo03Cooooo
00?oo`00ooooool00000B_ooool0027ooooo00?o0000ooooooooool0_oooool00ol0003ooooooooo
o`0fooooo`03ool00?oooooo000004Wooooo000Qooooo`?o0000__ooool00ol0003oooooooooo`0h
ooooo`03ool00?oooooo000004Sooooo000Qooooo`03o`000?oooooooooo0;gooooo00?o0000oooo
ooooool0>_ooool00ooo003oooooo`000017ooooo`008Oooool00ol0003oooooooooo`2looooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0A?ooool0027ooooo00?o0000ooooooooool0
^oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo04?ooooo000Qooooo`03o`000?oo
oooooooo0;Wooooo00?oo`00o`000?ooool0@oooool00ol0003oooooooooo`12ooooo`008Oooool0
0ol0003oooooooooo`2iooooo`03ool00?oooooooooo04Cooooo00?o0000ooooooooool0@Oooool0
027ooooo00?o0000ooooooooool0^?ooool00ol0003oo`00ooooo`16ooooo`03o`000?oooooooooo
043ooooo000Qooooo`?o0000]oooool00ol0003oo`00ooooo`17ooooo`03o`000?oooooooooo043o
oooo000Qooooo`03o`000?oooooooooo0;Oooooo00?oo`00ooooooooool0B?ooool00ooo003ooooo
ooooo`0oooooo`008Oooool00ol0003oooooooooo`2fooooo`03ool00?oooooooooo04[ooooo00?o
o`00ooooooooool0?_ooool0027ooooo00?o0000ooooooooool0]Oooool00ooo003oooooooooo`1;
ooooo`03ool00?l0003ooooo03kooooo000Qooooo`03o`000?oooooooooo0;Cooooo00?oo`00oooo
ooooool0COooool00ooo003o0000ooooo`0mooooo`008Oooool00ol0003oooooooooo`2cooooo`03
ool00?oooooooooo04oooooo00?oo`00ooooooooool0??ooool0027ooooo00?o0000ooooooooool0
/_ooool00ooo003o0000ooooo`1Aooooo`03ool00?oooooooooo03_ooooo000Qooooo`03o`000?oo
oooooooo0;7ooooo00?oo`00o`000?ooool0D_ooool00ooo003o0000ooooo`0kooooo`008Oooool3
o`000;3ooooo00?oo`00o`000?ooool0E?ooool00ooo003o0000ooooo`0jooooo`008Oooool00ol0
003oooooooooo`2_ooooo`03ool00?l0003ooooo05Kooooo00?oo`00o`000?ooool0>Oooool0027o
oooo00?o0000ooooooooool0[oooool00ol0003oooooooooo`1Fooooo`03ool00?oooooo000003Wo
oooo000Qooooo`03o`000?oooooooooo0:oooooo00?o0000ooooooooool0Eoooool00ooo003o0000
ooooo`0hooooo`008Oooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo05Wooooo00?o
o`00o`000?ooool0=oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0[Oooool00ol0003ooooo
ooooo`1Kooooo`03ool00?l0003ooooo03Kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2/ooooo`03o`00
0?oooooooooo05kooooo00?o0000ooooooooool0=?ooool000Go00000_ooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`000:_ooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`0cooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo063ooooo
00?o0000ooooooooool0<oooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo06;o
oooo00?o0000ooooooooool0<_ooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0ZOooool00ooo003oooooooooo`1Tooooo`03
o`000?oooooooooo037ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0:Sooooo00?o0000ool00?ooool0IOooool00ol0003o
ooooooooo`0aooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03
o`000?oooooooooo0:Sooooo00?oo`00ooooooooool0I_ooool00ol0003oooooooooo`0`ooooo`00
8Oooool00ol0003oooooooooo`2Wooooo`03ool00?oooooooooo06Sooooo00?o0000ooooooooool0
;oooool0027ooooo00?o0000ooooooooool0Y_ooool00ol0003oo`00ooooo`1Yooooo`03ool00?oo
oooooooo02oooooo000Qooooo`?o0000Y_ooool00ooo003oooooooooo`1Yooooo`03ool00?l0003o
oooo02oooooo000Qooooo`03o`000?oooooooooo0:Gooooo00?oo`00ooooooooool0Joooool00ooo
003o0000ooooo`0^ooooo`008Oooool00ol0003oooooooooo`2Tooooo`03ool00?oooooooooo06go
oooo00?oo`00ooooooooool0;Oooool0027ooooo00?o0000ooooooooool0Xoooool00ol0003oo`00
ooooo`1^ooooo`03ool00?l0003ooooo02gooooo000Qooooo`03o`000?oooooooooo0:?ooooo00?o
o`00ooooooooool0Koooool00ooo003o0000ooooo`0/ooooo`008Oooool00ol0003oooooooooo`2R
ooooo`03ool00?oooooooooo077ooooo00?oo`00ooooooooool0:oooool0027ooooo00?o0000oooo
ooooool0XOooool00ol0003oo`00ooooo`1cooooo`03ool00?oooooooooo02[ooooo000Qooooo`?o
0000XOooool00ooo003oooooooooo`1cooooo`03ool00?l0003ooooo02[ooooo000Qooooo`03o`00
0?oooooooooo0:3ooooo00?oo`00ooooooooool0MOooool00ooo003oooooooooo`0Yooooo`008Ooo
ool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo07Oooooo00?oo`00ooooooooool0:?oo
ool0027ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`1hooooo`03ool00?l0003o
oooo02Sooooo000Qooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0NOooool00ooo
003oooooooooo`0Wooooo`008Oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo07_o
oooo00?oo`00ooooooooool09_ooool0027ooooo00?o0000ooooooooool0W?ooool00ol0003ooooo
ooooo`1mooooo`03o`000?oooooooooo02Gooooo000Qooooo`03o`000?oooooooooo09cooooo00?o
0000ooooooooool0OOooool00ol0003oooooooooo`0Uooooo`008Oooool3o`0009_ooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`0moooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@0mooooo`Co000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0dooooo`Co000000?o
410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0gooooo`03o`00
0?oooooooooo00?ooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003ooooo
ooooo`05ooooo`03ool00?oooooooooo03Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0=_ooool00ol0003oooooooooo`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@06oooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`04ooooo`03o`000?oo003ooooo03So
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00?o
oooo00?oV9RHob4Q8Oo^k^h07?ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol0003ooooo
oooooooooooo000000oooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`04ooooo`03
ool00?oooooooooo03Sooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0hooooo`03
o`000?oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0
?Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00ooooo
o`03o`000?oooooooooo00?ooooo00?o0000ool00?ooool0>Oooool00ol0003oooooooooo`0;oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`0>Oooool00ol0003oooooooooo`04ooooo`03ogMgMomVIVKo
oooo01[ooooo000Qooooo`03o`000?oooooooooo03gooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0i
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0??ooool00ooo003oooooooooo`04
ooooo`03o`000?oooooooooo01Wooooo000Qooooo`?o0000?Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`02ooooo`03o`000?oo003o
oooo03[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0looooo`08ool00?l0003o
ooooo`000?nj^[[ooooooiRHV?l@410Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l000000oooool00ol0003o
o`00ooooo`0iooooo`03oeEEEOmVIVKo000000gooooo1?l0000looooo`07ool00?ooooooV9RHoa0@
4?l0003o8B4Qolc<c00Kooooo`008Oooool00ol0003oooooooooo`2Fooooo`03ool00?oooooooooo
08[ooooo00?oo`00ooooooooool07_ooool0027ooooo00?o0000ooooooooool0UOooool00ol0003o
o`00ooooo`2<ooooo`03ool00?oooooooooo01gooooo000Qooooo`03o`000?oooooooooo09Gooooo
00?oo`00ooooooooool0S?ooool00ooo003oooooooooo`0Mooooo`008Oooool00ol0003ooooooooo
o`2Dooooo`03o`000?oo003ooooo08kooooo00?oo`00ooooooooool04_ooool2o`0000;ooooo0_l0
0004ooooo`008Oooool00ol0003oooooooooo`2Cooooo`03o`000?oo003ooooo093ooooo00?oo`00
ooooooooool04Oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooooigo000000?o
o`00o`000?l00000TOl000000ooo003o0000o`000005o`0000cooooo00CogMgMo`000?l@413oc<c<
1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo0_l0000=ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool04Oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Ooo
ool00ol0003oooooool0002Aooooo`03o`000?oooooooooo0:Kooooo0_l00002ooooo`;o00001?oo
ool0027ooooo00?o0000oooooooo0000T?ooool00ol0003oooooooooo`2aooooo`008Oooool01?l0
003ooooooooooooo002?ooooo`03o`000?oooooooooo0;7ooooo000Qooooo`05o`000?oooooooooo
o`000?oo0000SOooool00ol0003oooooooooo`2booooo`008Oooool01Ol0003ooooooooooooooooo
o`0008cooooo00?o0000ooooooooool0/oooool0027ooooo0ol00002ooooo`03ool00?oooooooooo
08Wooooo00?o0000ooooooooool0/oooool0027ooooo00?o0000ooooooooool00_ooool00ol0003o
o`00ooooo`28ooooo`03o`000?oooooooooo0;Cooooo000Qooooo`03o`000?oooooooooo00?ooooo
00?o0000ool00?ooool0Q_ooool00ol0003oooooooooo`2eooooo`008Oooool00ol0003ooooooooo
o`04ooooo`03ool00?oooooooooo08Cooooo00?o0000ool00?ooool0]_ooool0027ooooo00?o0000
ooooooooool01?ooool00ol0003oo`00ooooo`24ooooo`03o`000?oo003ooooo0;Kooooo000Qoooo
o`03o`000?oooooooooo00Gooooo00?o0000ool00?ooool0P_ooool00ol0003oo`00ooooo`2goooo
o`008Oooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo083ooooo00?o0000ool00?oo
ool0^?ooool0027ooooo0ol00006ooooo`03o`000?oo003ooooo083ooooo00?oo`00ooooooooool0
^?ooool0027ooooo00?o0000ooooooooool01oooool00ol0003oo`00ooooo`1nooooo`03o`000?oo
003ooooo0;Wooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0OOooool0
0ol0003oo`00ooooo`2jooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
07cooooo00?oo`00ooooooooool0^_ooool0027ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1jooooo`03o`000?oo003ooooo0;_ooooo000Qooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0NOooool00ol0003oo`00ooooo`2looooo`008Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo07Sooooo00?oo`00ooooooooool0_?ooool0027ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1fooooo`03o`000?oo003ooooo0;gooooo000Qoooo
o`?o00003?ooool00ol0003oooooooooo`1dooooo`03o`000?oo003ooooo0;kooooo000Qooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0M?ooool00ooo003oooooooooo`2nooooo`00
8Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo003ooooo07;ooooo00?o0000ooooooooool0
_oooool0027ooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`1`ooooo`03o`000?oo
oooooooo0<3ooooo000Qooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool0Koooool0
0ol0003oooooooooo`30ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo003ooooo
06kooooo00?o0000ooooooooool0`Oooool0027ooooo00?o0000ooooooooool04?ooool00ooo003o
ooooooooo`1/ooooo`03o`000?oooooooooo0<;ooooo000Qooooo`?o00004Oooool00ooo003ooooo
ooooo`1[ooooo`03o`000?oooooooooo0<;ooooo000Qooooo`03o`000?oooooooooo017ooooo00?o
0000ool00?ooool0J_ooool00ol0003oooooooooo`33ooooo`008Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oo003ooooo06Sooooo00?o0000ooooooooool0a?ooool0027ooooo00?o0000oooo
ooooool04oooool00ooo003oooooooooo`1Wooooo`03ool00?oooooooooo0<Cooooo000Qooooo`03
o`000?oooooooooo01Cooooo00?oo`00ooooooooool0IOooool00ooo003oooooooooo`35ooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo003ooooo06Cooooo00?oo`00oooo
ooooool0a_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`03ooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool0H_ooool00ooo
003o0000ooooo`37ooooo`001oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool00_ooool3o`0001Kooooo00?oo`00ooooooooool0HOooool00ooo003oooooooooo`37oooo
o`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0
003oooooooooo`0Gooooo`03ool00?oooooooooo05oooooo00?oo`00ooooooooool0b?ooool000Oo
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo05kooooo00?oo`00o`000?ooool0bOooool0
00Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`1Looooo`03ool00?l0003ooooo0<[ooooo0007oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0F_ooool00ooo003o0000ooooo`3;ooooo`001oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0FOooool00ooo003oooooooooo`3;ooooo`008Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo05Oooooo00?oo`00ooooooooool0c?ooool0027ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`1Fooooo`03ool00?l0003ooooo0<gooooo000Qooooo`?o0000
7?ooool00ol0003oooooooooo`1Dooooo`03ool00?l0003ooooo0<kooooo000Qooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`3>ooooo`008Oooool0
0ol0003oooooooooo`0Nooooo`03ool00?oooooooooo057ooooo00?o0000ooooooooool0coooool0
027ooooo00?o0000ooooooooool07_ooool00ooo003o0000ooooo`1@ooooo`03o`000?oooooooooo
0=3ooooo000Qooooo`03o`000?oooooooooo01oooooo00?oo`00ooooooooool0Coooool00ol0003o
ooooooooo`3@ooooo`008Oooool00ol0003oooooooooo`0Pooooo`03ool00?oooooooooo04gooooo
00?o0000ooooooooool0dOooool0027ooooo00?o0000ooooooooool08Oooool00ooo003ooooooooo
o`1;ooooo`03o`000?oooooooooo0=;ooooo000Qooooo`?o00008_ooool00ooo003oooooooooo`19
ooooo`03o`000?oooooooooo0=?ooooo000Qooooo`03o`000?oooooooooo02?ooooo00?oo`00oooo
ooooool0AOooool2ool00003o`000?oooooooooo0=Cooooo000Qooooo`03o`000?oooooooooo02Co
oooo00?oo`00ooooooooool0@oooool00ooo003o0000ooooo`3Gooooo`008Oooool00ol0003ooooo
ooooo`0Uooooo`03ool00?oooooooooo047ooooo00?oo`00o`000?ooool0f?ooool0027ooooo00?o
0000ooooooooool09_ooool00ooo003oooooooooo`0oooooo`03ool00?l0003ooooo0=Wooooo000Q
ooooo`03o`000?oooooooooo02Oooooo00?oo`00ooooooooool0?Oooool00ooo003o0000ooooo`3J
ooooo`008Oooool00ol0003oooooooooo`0Xooooo`03ool00?oooooooooo03_ooooo00?oo`00o`00
0?ooool0foooool0027ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0iooooo`03
ool00?l0003ooooo0=cooooo000Qooooo`?o0000:_ooool00ol0003oooooooooo`0gooooo`03ool0
0?l0003ooooo0=gooooo000Qooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0=Ooo
ool00ooo003o0000ooooo`3Nooooo`008Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo03?ooooo00?oo`00o`000?ooool0goooool0027ooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0aooooo`03ool00?l0003ooooo0>3ooooo000Qooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0<?ooool00ooo003oooooooooo`3Pooooo`008Oooool00ol0003ooooo
ooooo`0_ooooo`;o0000;_ooool2o`000>?ooooo000Qooooo`03o`000?oooooooooo033ooooo0_oo
000/ooooo`03o`000?oooooooooo0>?ooooo000Qooooo`?o0000<_ooool2ool002Wooooo00?o0000
ooooooooool0i?ooool0027ooooo00?o0000ooooooooool0=?ooool00ooo003oooooooooo`0Uoooo
o`03o`000?oooooooooo0>Gooooo000Qooooo`03o`000?oooooooooo03Gooooo0_oo000Sooooo`;o
0000j?ooool0027ooooo00?o0000ooooooooool0=oooool00ooo003oooooooooo`0Mooooo`;oo`00
00?o0000ooooooooool0j?ooool0027ooooo00?o0000ooooooooool0>?ooool3ool001Wooooo0ooo
003]ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0>oooool2
ool000;o00004_ooool3ool00003o`000?oooooooooo0>gooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0?Oooool2ool00003o`000?oooooooooo00cooooo0ooo0002o`00
0?7ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@?ooool7o`0000;o
oooo1Ooo0003o`000??ooooo000Jooooo`03o`000?oooooooooo00Cooooo0ol00016ooooo`Co0000
n_ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l0
00001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool00omg
MgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo09oooooo002;ooooo`?o00004oooool00olQ8B7o
gMgMooooo`07ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Woooool008;ooooo
00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool02oooool01OnH
V9So0000o`000?m4A4Co^[Zj00;ooooo00?oV9RHoeEEEOooool01oooool01?mEEEGoV9RHoooooooo
ool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool00onj^[[oA4A4ooooo`02ooooo`03ohN7QomV
IVKooooo01?ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4QP?ooool008;ooooo00Oo410@
omgMgOmgMgOo8B4Qoooooon7QhOoIVIV00?ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zj
onk^k_mgMgOo410@00?ooooo00?o0000omgMgOooool01_ooool02Ol0003oooooooooooooooooV9RH
ob4Q8Oo^k^koooooodA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj0oooool00oo^k^ko
0000ooooo`0;ooooo`Ko00001?ooool00ol0003oooooooooo`04ooooo`;o8B4QP?ooool008;ooooo
00Oo0000oooooooMgMgo<S8booooooo^k^ko410@00?ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`05ooooo`;oMgMg1oooool00olb<S;oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^
00cooooo00Co410@omgMgOoooooo00001Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo08Kooooo0022ooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Go0000ooooooooooooooooo`00
000=ooooo`03o`000?oooooooooo00Gooooo00?ok^k^oa0@4?o^k^h01_ooool00olb<S;ooooooooo
o`03ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001Oooool00ol0003ooooo
ooooo`0:ooooo`Ko00001?ooool00ol0003oooooooooo`26ooooo`00P_ooool00ooMgMgo8B4Qonk^
kP03ooooo`03o`000?oooooooooo00;o00003Oooool00ol0003oooooooooo`06ooooo`03oeEEEOnH
V9Sooooo00Gooooo00?o0000onk^k_ooool01?ooool00omgMgOoIVIVooooo`0:ooooo`04omgMgOl@
413oooooo`0000Cooooo00?ok^k^o`000?ooool05Oooool00ol0003oooooooooo`26ooooo`00Pooo
ool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo00gooooo00?o410@o`000?l000000ol0
0005ooooo`03omgMgOl@413ooooo00Gooooo00?oEEEEogMgMoooool01Oooool00ol0003ooooooooo
o`08ooooo`Oo00000_ooool00omgMgOoEEEEooooo`0Eooooo`03o`000?oooooooooo08Kooooo002J
ooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool02OoMgMgo410@onk^k_oo
oooo0000okZj^_ooooooV9RHoa0@400Booooo`03onk^k_l@413ogMgM01Kooooo00?o0000oooooooo
ool0Q_ooool009[ooooo00?o0000ooooooooool01oooool00onj^[[oA4A4ooooo`05ooooo`08ogMg
MomVIVKooooooiRHV?l@413o0000ob4Q8Oo<c<`Booooo`03ofIVI_mgMgOooooo01Cooooo00?oEEEE
ofIVI_l00000R?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36468 L
.10458 .42001 L
.14415 .46289 L
.16408 .48026 L
.18221 .49329 L
.20178 .50419 L
.21254 .50873 L
.22272 .51204 L
.23241 .51431 L
.2373 .51513 L
.24012 .5155 L
.24269 .51577 L
.24504 .51596 L
.24728 .5161 L
.2485 .51616 L
.24964 .5162 L
.25088 .51623 L
.25158 .51624 L
.25221 .51624 L
.25336 .51624 L
.25442 .51623 L
.25558 .51621 L
.2568 .51617 L
.25787 .51613 L
.25887 .51608 L
.26113 .51593 L
.26373 .5157 L
.26614 .51543 L
.27158 .51464 L
.27638 .51372 L
.28148 .51252 L
.2903 .50991 L
.30004 .50626 L
.31939 .49668 L
.34024 .48313 L
.38138 .44783 L
.42101 .4055 L
.45912 .36022 L
.49968 .31074 L
.53872 .26525 L
.58022 .22251 L
.60102 .20419 L
.6202 .18951 L
.64007 .17674 L
.65867 .16721 L
.67743 .16007 L
.68738 .15731 L
.69293 .15608 L
.69807 .15514 L
Mistroke
.70298 .15441 L
.7082 .15384 L
.71119 .1536 L
.71265 .1535 L
.714 .15343 L
.7152 .15337 L
.71652 .15332 L
.71785 .15329 L
.71857 .15327 L
.71924 .15326 L
.7205 .15325 L
.7212 .15325 L
.72186 .15325 L
.72305 .15326 L
.72433 .15328 L
.72546 .15331 L
.72653 .15335 L
.72895 .15346 L
.73157 .15363 L
.73396 .15382 L
.73935 .15439 L
.7441 .15506 L
.74918 .15594 L
.75831 .15795 L
.77902 .16441 L
.80041 .17365 L
.82057 .18449 L
.85909 .20996 L
.90006 .24213 L
.93952 .27616 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36178 L
.10458 .41672 L
.14415 .45819 L
.16408 .4745 L
.18221 .48653 L
.20178 .49648 L
.21254 .50059 L
.22272 .50359 L
.23241 .50565 L
.2373 .50639 L
.24012 .50672 L
.24269 .50697 L
.24504 .50715 L
.24728 .50728 L
.2485 .50733 L
.24964 .50737 L
.25088 .50739 L
.25158 .50741 L
.25221 .50741 L
.25336 .50741 L
.25442 .50741 L
.25558 .50739 L
.2568 .50735 L
.25787 .50732 L
.25887 .50727 L
.26113 .50714 L
.26373 .50694 L
.26614 .5067 L
.27158 .50599 L
.27638 .50516 L
.28148 .50407 L
.2903 .5017 L
.30004 .49835 L
.31939 .48951 L
.34024 .47686 L
.38138 .44339 L
.42101 .40266 L
.45912 .35859 L
.49968 .31013 L
.53872 .26562 L
.58022 .22428 L
.60102 .20685 L
.6202 .19306 L
.64007 .18126 L
.65867 .17261 L
.67743 .16628 L
.68738 .1639 L
.69293 .16286 L
.69807 .16209 L
Mistroke
.70298 .16151 L
.70549 .16128 L
.7082 .16107 L
.70976 .16098 L
.71119 .1609 L
.71253 .16084 L
.714 .16079 L
.71532 .16076 L
.71655 .16074 L
.71785 .16073 L
.71858 .16073 L
.71924 .16073 L
.72049 .16074 L
.72112 .16075 L
.72182 .16076 L
.72305 .16079 L
.7242 .16083 L
.72679 .16095 L
.72957 .16112 L
.73468 .16155 L
.73935 .16209 L
.74918 .16366 L
.75831 .16562 L
.77902 .17177 L
.79952 .18004 L
.81812 .18924 L
.85815 .21372 L
.89667 .24208 L
.93764 .27574 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0cooooolAo`0006Cooooo
000Qooooo`03o`000?oooooooooo0<_ooooo1?l0000Aooooo`Ko0000G_ooool0027ooooo00?o0000
ooooooooool0b?ooool3o`0000Gooooo0ooo000Cooooo`?o0000Foooool0027ooooo00?o0000oooo
ooooool0aOooool3o`0001Gooooo1_oo0006ooooo`;o0000FOooool0027ooooo0ol00033ooooo`;o
00007_ooool3ool000Gooooo0ol0001Fooooo`008Oooool00ol0003oooooooooo`31ooooo`;o0000
0_ooool00ooo003oooooooooo`0Nooooo`?oo`001Oooool2o`0005Cooooo000Qooooo`03o`000?oo
oooooooo0;oooooo0_l00002ooooo`;oo`009?ooool3ool000Cooooo0_l0001Booooo`008Oooool0
0ol0003oooooooooo`2mooooo`;o000000Coooooool00?oo003oo`00:Oooool00ooo003ooooooooo
o`03ooooo`;o0000D?ooool0027ooooo00?o0000ooooooooool0_?ooool01?l0003oo`00ool00?oo
000dooooo`;o0000C_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0^_ooool2o`000003ool0
0?oooooooooo03Oooooo0_l0001<ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0^Oooool00ol0003oo`00
ool0000looooo`03o`000?oooooooooo04Wooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0002gooooo`;o000000?oo`00ooooooooool0
>_ooool2ool00003ooooool0003o000004Wooooo0007ooooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0;Kooooo00?o0000oooooooo0000
?oooool01?oo003oooooooooool00018ooooo`001oooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0;Gooooo00?o0000oooo
ooooool0@Oooool2ool00003ooooool0003o000004Kooooo0007ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;Cooooo00?o0000oooo
ooooool0A?ooool01?oo003oooooooooool00015ooooo`001oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2cooooo`03o`000?oooooo
oooo04Kooooo0_oo00000ooooooo0000o`000013ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0;7ooooo0_l0001;ooooo`04ool00?oooooo
ooooo`0004;ooooo000Qooooo`03o`000?oooooooooo0;3ooooo00?o0000ooooooooool0C?ooool2
ool00003ooooool0003o0000043ooooo000Qooooo`03o`000?oooooooooo0:kooooo0_l0001Aoooo
o`04ool00?ooooooooooo`0003oooooo000Qooooo`?o0000[Oooool00ol0003oo`00ool0001Boooo
o`04ool00?ooooooooooo`0003kooooo000Qooooo`03o`000?oooooooooo0:cooooo00?o0000ool0
0?ooool0E?ooool00ooo003oooooooooo`02o`0003cooooo000Qooooo`03o`000?oooooooooo0:_o
oooo00?o0000ool00?ooool0F_ooool00ol0003oooooooooo`0iooooo`008Oooool00ol0003ooooo
ooooo`2[ooooo`03ool00?oooooooooo05_ooooo00?o0000ooooooooool0>?ooool0027ooooo00?o
0000ooooooooool0Z_ooool00ooo003oooooooooo`1Mooooo`03o`000?oooooooooo03Oooooo000Q
ooooo`03o`000?oooooooooo0:Wooooo00?oo`00ooooooooool0Goooool2o`0003Oooooo000Qoooo
o`03o`000?oooooooooo0:Sooooo00?oo`00ooooooooool0H_ooool00ol0003oooooooooo`0doooo
o`008Oooool3o`000:Oooooo00?oo`00ooooooooool0H_ooool2ool00003o`000?oooooooooo03?o
oooo000Qooooo`03o`000?oooooooooo0:Kooooo00?oo`00ooooooooool0IOooool2ool00003o`00
0?oooooooooo037ooooo000Qooooo`03o`000?oooooooooo0:Gooooo00?oo`00ooooooooool0J?oo
ool00ooo003o0000ooooo`0aooooo`008Oooool00ol0003oooooooooo`2Tooooo`03ool00?oooooo
oooo06[ooooo00?oo`00o`000?ooool0<?ooool0027ooooo00?o0000ooooooooool0Xoooool00ooo
003oooooooooo`1/ooooo`03ool00?l0003ooooo02oooooo000Qooooo`03o`000?oooooooooo0:;o
oooo00?o0000ooooooooool0K_ooool00ooo003o0000ooooo`0^ooooo`008Oooool00ol0003ooooo
ooooo`2Qooooo`03o`000?oooooooooo073ooooo00?oo`00o`000?ooool0;Oooool0027ooooo00?o
0000ooooooooool0X?ooool00ol0003oooooooooo`1booooo`03ool00?l0003ooooo02cooooo000Q
ooooo`?o0000Woooool00ol0003oooooooooo`1dooooo`03ool00?l0003ooooo02_ooooo000Qoooo
o`03o`000?oooooooooo03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM03gooooo1?l000000ol@413oooooooooo`07ooooo`03o`000?oo
oooooooo037ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM033ooooo00?oo`00o`000?ooool02_ooool5o`0001_ooooo000Qooooo`03o`000?oo
oooooooo03gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`0nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0`ooooo`03ool00?l0003ooooo00Wooooo
00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Oo
oooo00?oo`00o`000?ooool0=Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool02?ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003ooooo
ooooo`0mooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0nooooo`03
o`000?oooooooooo00Oooooo00?oo`00ooooooooool0=Oooool00ol0003oooooooooo`0>ooooo`03
ogMgMolb<S;ooooo03?ooooo0_l00009ooooo`03oiRHV?lQ8B7ok^k^01_ooooo000Qooooo`03o`00
0?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`0?oooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo03Kooooo00?o0000oooo
ooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<03Kooooo00?o0000ooooooooool01oooool0
0omgMgOoIVIVooooo`0Jooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Gooooo00?oo`00
ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Iooooo`008Oooool3o`0003gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool01?ooool0
0ooo003oooooooooo`0hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@41006oooool0027ooooo00?o0000
ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000nooooo`03oeEEEOmV
IVKo000000Gooooo00?oo`00ooooooooool0=oooool00omEEEGoIVIVo`00000=ooooo`Co0000>_oo
ool02Ol0003oooooooooooooooooV9RHoa0@4?l0003o8B4Qolc<c00Kooooo`008Oooool00ol0003o
ooooooooo`2Gooooo`03ool00?l0003ooooo08Oooooo0_oo000Qooooo`008Oooool00ol0003ooooo
ooooo`2Gooooo`03ool00?oooooooooo08Wooooo00?oo`00ooooooooool07_ooool0027ooooo00?o
0000ooooooooool0U_ooool00ooo003oooooooooo`2;ooooo`03ool00?oooooooooo01gooooo000Q
ooooo`03o`000?oooooooooo09Gooooo00?oo`00ooooooooool0SOooool00ooo003oooooooooo`0B
ooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo09Cooooo00?oo`00oooo
ooooool0Soooool00ooo003oooooooooo`0Aooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?oo
ool001[ooooo1ol000000ooo003o0000o`00002Co`000003ool00?l0003o0000097o000000?oo`00
o`000?l000001Ol0000<ooooo`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oo003o
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`04onk^k_lQ8B7o
410@onk^kPGooooo000Qooooo`;o000000?oo`00ooooooooool02_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo017ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000
ooooool00000TOooool00ol0003oooooooooo`2Vooooo`;o00000_ooool2o`0000Cooooo000Qoooo
o`03o`000?oooooo0000093ooooo00?o0000ooooooooool0/Oooool0027ooooo00Co0000oooooooo
oooo0000S_ooool00ol0003oooooooooo`2booooo`008Oooool01Ol0003ooooooooooooooooo0000
08cooooo00?o0000ooooooooool0/oooool0027ooooo00Go0000ooooooooooooooooo`00002;oooo
o`03o`000?oooooooooo0;Cooooo000Qooooo`?o00000_ooool00ol0003oooooooooo`27ooooo`03
o`000?oooooooooo0;Gooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
QOooool00ol0003oooooooooo`2fooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo08Gooooo00?oo`00ooooooooool0]_ooool0027ooooo00?o0000ooooooooool01?ooool0
0ol0003oo`00ooooo`23ooooo`03ool00?oooooooooo0;Oooooo000Qooooo`03o`000?oooooooooo
00Gooooo00?oo`00ooooooooool0POooool00ooo003oooooooooo`2hooooo`008Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oo003ooooo083ooooo00?oo`00ooooooooool0^Oooool0027ooooo
00?o0000ooooooooool01_ooool00ol0003oo`00ooooo`1nooooo`03ool00?oooooooooo0;[ooooo
000Qooooo`?o00001oooool00ooo003oooooooooo`1looooo`03ool00?oooooooooo0;_ooooo000Q
ooooo`03o`000?oooooooooo00Oooooo00?o0000ool00?ooool0Noooool00ooo003oooooooooo`2l
ooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oo003ooooo07Wooooo00?oo`00o`00
0?ooool0_Oooool0027ooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`1gooooo`03
ool00?l0003ooooo0;kooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ool00?ooool0
M_ooool00ooo003o0000ooooo`2oooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
003ooooo07Cooooo00?oo`00o`000?ooool0`?ooool0027ooooo00?o0000ooooooooool02oooool0
0ol0003oo`00ooooo`1booooo`03ool00?l0003ooooo0<7ooooo000Qooooo`03o`000?oooooooooo
00cooooo00?o0000ool00?ooool0LOooool00ol0003oooooooooo`31ooooo`008Oooool3o`0000go
oooo00?o0000ool00?ooool0Koooool00ol0003oooooooooo`32ooooo`008Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oo003ooooo06kooooo00?o0000ooooooooool0`_ooool0027ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo0<?ooooo000Q
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`34
ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06Wooooo00?o0000oooo
ooooool0aOooool0027ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Wooooo`03
o`000?oooooooooo0<Kooooo000Qooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
IOooool00ol0003oooooooooo`37ooooo`008Oooool3o`0001;ooooo00?o0000ooooooooool0I?oo
ool00ooo003oooooooooo`38ooooo`008Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo06;ooooo00?oo`00o`000?ooool0bOooool0027ooooo00?o0000ooooooooool05?ooool00ol0
003oo`00ooooo`1Pooooo`03ool00?l0003ooooo0<[ooooo000Qooooo`03o`000?oooooooooo01Go
oooo00?o0000ool00?ooool0G_ooool00ooo003o0000ooooo`3;ooooo`008Oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oo003ooooo05cooooo00?oo`00o`000?ooool0c?ooool000Oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Co
oooo00?o0000ooooooooool05oooool00ooo003oooooooooo`1Jooooo`03ool00?l0003ooooo0<go
oooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`0Gooooo`03o`000?oo003ooooo05Wooooo00?oo`00o`000?oo
ool0c_ooool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;o
oooo0ol0000Hooooo`03o`000?oo003ooooo05Oooooo00?oo`00o`000?ooool0coooool000Oooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooooooo
ool06Oooool00ol0003oo`00ooooo`1Eooooo`03ool00?oooooo00000=3ooooo0007ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooo
ooooool06_ooool00ol0003oo`00ooooo`1Cooooo`03ool00?oooooo00000=7ooooo0007ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01_ooooo00?o0000ool00?ooool0DOooool00ooo003oooooo`00003Booooo`001oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oo003ooooo04oooooo00?oo`00ooooool00000doooool000Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0Mooooo`03o`000?oo003ooooo
04oooooo00?o0000ooooooooool0d_ooool0027ooooo00?o0000ooooooooool07_ooool00ol0003o
o`00ooooo`1=ooooo`03o`000?oooooooooo0=?ooooo000Qooooo`03o`000?oooooooooo01oooooo
00?o0000ool00?ooool0B_ooool2o`000=Kooooo000Qooooo`?o00008?ooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo0=Kooooo000Qooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`3Gooooo`008Oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0f?ooool0027ooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`0oooooo`;oo`0000?oooooo`000?ooool0f_ooool0027ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0mooooo`04ool00?oooooo0000o`000=co
oooo000Qooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>oooool00ooo003ooooo
o`00003Nooooo`008Oooool00ol0003oooooooooo`0Vooooo`03o`000?ooooooo`0003Wooooo00?o
o`00ooooool00000goooool0027ooooo0ol0000Wooooo`04o`000?ooooooo`00ool003Kooooo00?o
o`00ooooool00000h?ooool0027ooooo00?o0000ooooooooool0:?ooool01?l0003ooooooooooooo
000cooooo`;oo`0000?oooooo`000?ooool0h?ooool0027ooooo00?o0000ooooooooool0:Oooool2
o`000003oooooooo003oo`00033ooooo00Coo`00oooooooooooo0000h_ooool0027ooooo00?o0000
ooooooooool0:oooool01?l0003ooooooooooooo000]ooooo`;oo`0000?oooooo`000?l00000hooo
ool0027ooooo00?o0000ooooooooool0;?ooool2o`000003oooooooo003oo`0002[ooooo00Coo`00
oooooooooooo0000iOooool0027ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`02
ool002Kooooo0_oo00000ooooooo0000o`00003Vooooo`008Oooool00ol0003oooooooooo`0_oooo
o`;o00000_ooool2ool002Kooooo00?o0000ooooooooool0i_ooool0027ooooo00?o0000oooooooo
ool0<Oooool2o`0000;ooooo00?oo`00ooooooooool08Oooool2o`000>Wooooo000Qooooo`?o0000
<oooool2o`0002;ooooo0_l0003[ooooo`008Oooool00ol0003oooooooooo`0eooooo`;o00005_oo
ool3ool000Gooooo0_l0003]ooooo`008Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo00Kooooo3Ooo0006ooooo`;o0000koooool0027ooooo00?o0000ooooooooool0>?ooool3o`00
01Gooooo0ol0003aooooo`008Oooool00ol0003oooooooooo`0kooooo`Go00003?ooool4o`000?Co
oooo000Qooooo`03o`000?oooooooooo043ooooo3?l0003hooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o410@
ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3o`000?oooooo
AOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l0
00001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool00omg
MgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:Oooooo0023ooooo`?o00005?ooool00olQ8B7o
gMgMooooo`06ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Yoooool007_ooooo
00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool02oooool01OnH
V9So0000o`000?m4A4Co^[Zj00?ooooo00?oV9RHoeEEEOooool01_ooool00omEEEGoV9RHooooo`02
ooooo`Go00002Oooool00omEEEGoZJVYooooo`02ooooo`06okZj^_m4A4Cooooooooooon7QhOoIVIV
5Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01?ooool01Om4A4Co0000o`000?lb<S;ogMgM07Gooooo001kooooo`07oa0@4?oMgMgoMgMgob4Q
8OooooooQhN7ofIVIP02ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_o^k^koMgMgoa0@
4004ooooo`03o`000?oMgMgooooo00Gooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^
k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X2ooooo`03onk^k_l0003ooooo
00_ooooo1_l00005ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01oooool00omgMgOo<S8booooo`1dooooo`00Noooool01ol0003oooooomgMgOlb<S;o
ooooonk^k_l@41000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo0_mg
MgL6ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgMoooo
ool00004ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool01Ol@413ooooo
oooooooooooo410@00Sooooo00?o0000ooooooooool0Loooool007_ooooo00CoEEEEojVYZOoooooo
00000_ooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00Kooooo00?ok^k^oa0@
4?o^k^h01Oooool00olb<S;oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIV
I_oooooo00001?ooool00ol0003oooooooooo`0:ooooo`Ko00001Oooool00ol0003oooooooooo`0:
ooooo`05o`000?ooooooooooooooool000001oooool00omgMgOo<S8booooo`1dooooo`00Noooool0
0ooMgMgo8B4Qonk^kP03ooooo`04o`000?oooooo0000o`0000gooooo00?o0000ooooooooool01ooo
ool00omEEEGoV9RHooooo`04ooooo`03o`000?o^k^kooooo00Gooooo00?oMgMgofIVI_ooool02_oo
ool01?oMgMgo410@ooooool00003ooooo`03onk^k_l0003ooooo01Kooooo00?o0000ooooooooool0
2_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c01eoooo
o`00O?ooool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo00cooooo00?o410@o`000?l0
00000ol00006ooooo`03omgMgOl@413ooooo00Cooooo00?oEEEEogMgMoooool01_ooool00ol0003o
ooooooooo`08ooooo`Oo000000?oooooogMgMomEEED05oooool00ol0003oooooooooo`0:ooooo`05
oa0@4?ooooooooooooooool@41001?ooool00ol0003oooooooooo`1gooooo`00T_ooool00ol0003o
ooooooooo`08ooooo`03oeEEEOnHV9Sooooo00?ooooo00?ogMgMoa0@4?o^k^h00_ooool01Ol0003o
^[ZjoooooonHV9So410@017ooooo00?ok^k^oa0@4?oMgMd05oooool00ol0003oooooooooo`0:oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`1gooooo`00T_ooool00ol0
003oooooooooo`08ooooo`03okZj^_m4A4Cooooo00Cooooo00WoMgMgofIVI_oooooooooooiRHV?l@
413o0000ob4Q8Oo<c<`04Oooool00omVIVKoMgMgooooo`0Eooooo`03oeEEEOmVIVKo000000cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co0000M_ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .35043 L
.10458 .38922 L
.12507 .40438 L
.14415 .41594 L
.16254 .42461 L
.17277 .42837 L
.18221 .43117 L
.19242 .43349 L
.19781 .43441 L
.20351 .43517 L
.2059 .43542 L
.20846 .43565 L
.21068 .43581 L
.2131 .43595 L
.21456 .43602 L
.21592 .43607 L
.21722 .4361 L
.21795 .43612 L
.21861 .43613 L
.21986 .43614 L
.22056 .43614 L
.22121 .43614 L
.2224 .43614 L
.22365 .43612 L
.22487 .43609 L
.2262 .43605 L
.22861 .43595 L
.23096 .43582 L
.23313 .43567 L
.23806 .43522 L
.24329 .43458 L
.25201 .43318 L
.26163 .43115 L
.28097 .42568 L
.30183 .41796 L
.34297 .39872 L
.38259 .3778 L
.4207 .35825 L
.46126 .34046 L
.48 .33382 L
.50031 .32795 L
.51141 .32538 L
.52165 .3234 L
.53144 .32189 L
.53686 .3212 L
.5418 .32068 L
.54632 .32027 L
.55124 .31992 L
.55394 .31976 L
Mistroke
.55644 .31964 L
.55899 .31954 L
.56138 .31947 L
.56362 .31941 L
.56488 .31939 L
.56603 .31938 L
.56701 .31937 L
.56808 .31936 L
.5692 .31936 L
.57025 .31936 L
.57148 .31937 L
.57264 .31938 L
.57368 .3194 L
.57481 .31942 L
.57735 .31948 L
.57969 .31955 L
.58434 .31974 L
.58934 .32003 L
.59839 .32073 L
.60916 .32184 L
.61901 .32311 L
.65869 .32983 L
.69685 .33714 L
.71814 .34079 L
.73746 .34351 L
.74712 .3446 L
.75758 .34555 L
.76239 .34589 L
.76746 .3462 L
.77213 .34642 L
.77656 .34659 L
.77893 .34665 L
.78018 .34668 L
.78151 .34671 L
.78262 .34672 L
.78385 .34674 L
.78497 .34675 L
.78602 .34676 L
.78726 .34677 L
.78857 .34677 L
.78968 .34676 L
.7909 .34676 L
.79222 .34675 L
.79363 .34673 L
.79496 .34671 L
.79617 .34668 L
.80069 .34656 L
.80324 .34647 L
.80559 .34637 L
.8145 .34585 L
Mistroke
.81916 .3455 L
.82418 .34506 L
.83324 .34409 L
.85387 .34114 L
.87502 .33712 L
.89511 .33251 L
.93333 .32209 L
.97399 .3097 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .34994 L
.10458 .3822 L
.12507 .3944 L
.14415 .40388 L
.16254 .41125 L
.18221 .41715 L
.19242 .41937 L
.19781 .42031 L
.20351 .42112 L
.2085 .42168 L
.21114 .42191 L
.21399 .42212 L
.21659 .42228 L
.21898 .42238 L
.22012 .42242 L
.22137 .42245 L
.22256 .42248 L
.22365 .42249 L
.22494 .4225 L
.22559 .4225 L
.2263 .4225 L
.22756 .42249 L
.22873 .42247 L
.22944 .42245 L
.23012 .42244 L
.23138 .4224 L
.23422 .42228 L
.2367 .42214 L
.23899 .42198 L
.24418 .4215 L
.24846 .421 L
.2532 .42032 L
.26278 .4186 L
.28213 .4137 L
.30299 .40654 L
.34413 .38818 L
.38375 .36806 L
.42186 .3497 L
.44311 .34093 L
.46242 .33426 L
.47206 .33146 L
.4825 .32886 L
.4923 .32683 L
.50147 .32529 L
.51093 .32408 L
.51595 .3236 L
.52134 .32319 L
.52404 .32303 L
.52698 .32289 L
Mistroke
.52976 .32278 L
.53109 .32275 L
.53234 .32272 L
.53356 .32269 L
.53421 .32269 L
.53489 .32268 L
.5361 .32267 L
.5372 .32266 L
.53848 .32266 L
.53967 .32267 L
.54098 .32268 L
.54172 .32269 L
.54238 .3227 L
.54468 .32275 L
.54721 .32282 L
.54985 .32293 L
.55232 .32305 L
.56151 .32367 L
.56673 .32414 L
.57151 .32464 L
.58228 .326 L
.62196 .33302 L
.66012 .34097 L
.68141 .3451 L
.70073 .3483 L
.71039 .34965 L
.72086 .35089 L
.73066 .35183 L
.73983 .3525 L
.74441 .35276 L
.74932 .35298 L
.75212 .35308 L
.75477 .35316 L
.75715 .35321 L
.75849 .35323 L
.75974 .35325 L
.76095 .35327 L
.76226 .35328 L
.76297 .35328 L
.76371 .35328 L
.76435 .35328 L
.76504 .35328 L
.76578 .35328 L
.76645 .35328 L
.76723 .35328 L
.76796 .35327 L
.76926 .35326 L
.77068 .35324 L
.77323 .3532 L
.77594 .35313 L
Mistroke
.7808 .35297 L
.78572 .35275 L
.79022 .35249 L
.80035 .35174 L
.80974 .35084 L
.81865 .3498 L
.85687 .3435 L
.87656 .33919 L
.89753 .33385 L
.93914 .32124 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`3ooooooc_ooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0003o00000?oo0000<?l0
000<ooooo`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oo003ooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02Oooool4o`0001?ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo0_l0
000=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Cooooo1Ol00003ooooo`03o`000?oooooooooo017ooooo00Co
8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000ooooool00000oooooolLooooo`04o`000?oo
003oo`00o`0001_ooooo0_l00002ooooo`;o00001?ooool0027ooooo00Co0000oooooooooooo0000
V_oooolLo`00067ooooo00Co0000ool00?oo003oo`00:?ooool0027ooooo00Go0000oooooooooooo
ooooo`00002Booooo`;o00001ooo000:ooooo`Coo`003?ooool4o`0005[ooooo00Co0000ool00?oo
003oo`00:oooool0027ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2<ooooo`?o
00005oooool5ool000_ooooo1ol0001@ooooo`04o`000?oo003oo`00ool002kooooo000Qooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0P_ooool5ool00004ooooool0003o0000o`00
01oooooo1Ooo000=ooooo`Ko0000Aoooool01?l0003oo`00ool00?oo000aooooo`008Oooool3o`00
00Cooooo00?o0000ooooooooool0O_ooool3ool000?ooooo0ol0000Wooooo`;oo`004Oooool6o`00
03cooooo1?l00002ool003Cooooo000Qooooo`03o`000?oooooooooo00Gooooo00?oo`00oooooooo
ool0N_ooool3ool000?ooooo0ol00013ooooo`Ko0000<?ooool6o`0003[ooooo000Qooooo`03o`00
0?oooooooooo00Kooooo00?oo`00ooooooooool0M_ooool3ool000?ooooo0ol0000iooooo`Koo`00
3Oooool6o`0002Cooooo1_l00010ooooo`008Oooool00ol0003oooooooooo`07ooooo`03ool00?oo
oooooooo07Cooooo00?oo`00ooooooooool00_ooool2o`0004;ooooo0ooo000@ooooo`So00005ooo
ool5o`000003oooooooo003oo`0000Coo`00?oooool0027ooooo00?o0000ooooooooool02?ooool0
0ooo003oooooooooo`1booooo`04ool00?ooooooooooooooo`;o0000Aoooool5ool001?ooooo5ol0
0006ool004Gooooo000Qooooo`03o`000?oooooooooo00Wooooo0_oo001cooooo`?o0000C_ooool2
ool002?ooooo1Ooo001;ooooo`008Oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo
06kooooo0_l0001Moooooa3oo`00FOooool0027ooooo0ol0000<ooooo`03ool00?oooooooooo06_o
oooo0_l00038ooooo`008Oooool00ol0003oooooooooo`0=ooooo`;oo`00Hoooool2ool000Cooooo
0_l0003:ooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo003ooooo05oooooo0_oo
0004ooooo`;o0000c?ooool0027ooooo00?o0000ooooooooool03oooool00ol0003oo`00ooooo`1M
ooooo`03ool00?oooooooooo00;ooooo0_l0003>ooooo`008Oooool00ol0003oooooooooo`0@oooo
o`03o`000?oo003ooooo05[ooooo0_oo0003ooooo`;o0000d?ooool0027ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`1Fooooo`;oo`000oooool2o`000=;ooooo000Qooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0D_ooool3ool000?ooooo0_l0003Dooooo`008Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04oooooo0_oo0004ooooo`;o0000e_oo
ool0027ooooo0ol0000Eooooo`03o`000?oooooooooo04gooooo00?oo`00ooooooooool00_ooool2
o`000=Sooooo000Qooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Coooool2o`00
0=[ooooo000Qooooo`03o`000?oooooooooo01Oooooo0_l000000oooooooo`00ool0001:ooooo`;o
0000g?ooool0027ooooo00?o0000ooooooooool06Oooool01?l0003ooooooooooooo0017ooooo`;o
0000g_ooool0027ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ool004?ooooo
0_l0003Pooooo`008Oooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooooooo`;oo`00
>Oooool2ool000Cooooo0_l0003Rooooo`008Oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo00;ooooo0_oo000eooooo`;oo`001?ooool2o`000>Cooooo000Qooooo`?o00007Oooool2
o`0000Cooooo0_oo000aooooo`;oo`001?ooool2o`000>Kooooo000Qooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool00oooool3ool002_ooooo0ooo0003ooooo`?o0000j?ooool0027o
oooo00?o0000ooooooooool08?ooool2o`0000Kooooo00?oo`00ooooooooool09Oooool3ool000Co
oooo0_l0003[ooooo`008Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02Oooooo
1?oo0005ooooo`;o0000kOooool0027ooooo00?o0000ooooooooool08oooool3o`0002gooooo0_l0
003_ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Vooooo`?o00002Oooool5ool001[ooooo
0_l0003aooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00?ooooo00?o0000ooooooooool0:Oooool2o`0000cooooo3?oo000<ooooo`;o0000
loooool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo
0ol0000[ooooo`03o`000?oooooooooo01gooooo1?l0003eooooo`001oooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0/ooooo`Ko0000
5Oooool4o`000?Wooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0<_ooool2o`00013ooooo0ol0003mooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0doooooa3o0000ooooool1ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool4o`000003
oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo0ol0003o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmV
IVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Sooooo
00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2Sooooo`00Qoooool3o`0001?ooooo00?o
8B4QomgMgOooool01oooool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@413ogMgM0:?ooooo001n
ooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP03ooooo`03o`000?oooooooooo00_ooooo
00GoV9RHo`000?l0003oA4A4okZj^P02ooooo`03oiRHV?mEEEGooooo00Oooooo00CoEEEEoiRHV?oo
oooooooo1Ol00009ooooo`03oeEEEOnYZJWooooo00;ooooo00?o^[ZjodA4A?ooool00_ooool00on7
QhOoIVIVooooo`0Cooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo1?l000000ol@
413oooooooooo`1hooooo`00O_ooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00oooool0
0ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0003ogMgMoooo
o`06ooooo`09o`000?oooooooooooooooonHV9So8B4Qonk^k_ooooooA4A400[ooooo00KoEEEEoiRH
V?oooooooooooa0@4?nj^[X3ooooo`03onk^k_l0003ooooo00_ooooo1_l00004ooooo`03o`000?oo
oooooooo00Cooooo0_lQ8B47ooooo`03o`000?oooooooooo07[ooooo001nooooo`07o`000?oooooo
gMgMoc8b<_ooooook^k^oa0@4003ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1Oooool2ogMgM`Oooooo00?o<S8booooooooool00_ooool00onHV9So8B4Qonk^kP0<ooooo`04oa0@
4?oMgMgoooooo`0000Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo07[ooooo001nooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03o`000?oooooooooo00Gooooo00?ok^k^oa0@4?o^k^h01_ooool00olb
<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001Oooool0
0ol0003oooooooooo`0:ooooo`Ko00001?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo07[ooooo001nooooo`03omgMgOlQ8B7ok^k^00?ooooo00?o0000ooooooooool00_l0000=oooo
o`03o`000?oooooooooo00Kooooo00?oEEEEoiRHV?ooool01Oooool00ol0003ok^k^ooooo`04oooo
o`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo00001?ooool00oo^k^ko0000ooooo`0E
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0N_ooool007oooooo00?oV9RHogMg
Moooool00_ooool00ol0003oooooooooo`0=ooooo`03oa0@4?l0003o000000?o00001Oooool00ooM
gMgo410@ooooo`05ooooo`03oeEEEOmgMgOooooo00Gooooo00?o0000ooooooooool02?ooool7o`00
00;ooooo00?oMgMgoeEEEOooool05Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
07[ooooo002Fooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool02OoMgMgo
410@onk^k_oooooo0000okZj^_ooooooV9RHoa0@400Booooo`03onk^k_l@413ogMgM01Kooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`1jooooo`00U_ooool00ol0003oooooooooo`07
ooooo`03okZj^_m4A4Cooooo00Gooooo00SoMgMgofIVI_ooooooV9RHoa0@4?l0003o8B4Qolc<c1;o
oooo00?oIVIVogMgMoooool05?ooool00omEEEGoIVIVo`00000=ooooo`03oeEEEOmVIVKo000007co
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .31688 L
.06244 .32452 L
.08426 .33148 L
.0949 .33416 L
.10458 .33613 L
.11403 .33761 L
.11837 .33814 L
.12297 .3386 L
.1253 .33879 L
.12787 .33897 L
.13024 .33911 L
.1324 .33921 L
.13494 .3393 L
.13635 .33933 L
.137 .33935 L
.13768 .33936 L
.13891 .33937 L
.14005 .33938 L
.14075 .33939 L
.14141 .33938 L
.14264 .33938 L
.1438 .33937 L
.14504 .33935 L
.14622 .33932 L
.14729 .33929 L
.14991 .3392 L
.1524 .33908 L
.15734 .33877 L
.16271 .33831 L
.17231 .33721 L
.18119 .33588 L
.19985 .33229 L
.22045 .32739 L
.26066 .31691 L
.27913 .31259 L
.2896 .31051 L
.29934 .30887 L
.30903 .30759 L
.31446 .30704 L
.31938 .30665 L
.32191 .30649 L
.32459 .30635 L
.32599 .30629 L
.32753 .30624 L
.32893 .3062 L
.33024 .30618 L
.33087 .30617 L
.33156 .30616 L
.33282 .30615 L
Mistroke
.33404 .30615 L
.33518 .30615 L
.33587 .30616 L
.33653 .30617 L
.33775 .30619 L
.33906 .30622 L
.34048 .30626 L
.34287 .30636 L
.34542 .3065 L
.35001 .30684 L
.35548 .30739 L
.36046 .30805 L
.37129 .30995 L
.38154 .31238 L
.40149 .31891 L
.41992 .32704 L
.45924 .3507 L
.49704 .38001 L
.5373 .41497 L
.57604 .4481 L
.59572 .46336 L
.61723 .47806 L
.63803 .48982 L
.65691 .49809 L
.66702 .50151 L
.67655 .50406 L
.68145 .50511 L
.68662 .50603 L
.68932 .50643 L
.69229 .50681 L
.69501 .50709 L
.69752 .50731 L
.70002 .50748 L
.70132 .50755 L
.70275 .50761 L
.70399 .50765 L
.70515 .50768 L
.70638 .5077 L
.70707 .50771 L
.70771 .50771 L
.70883 .5077 L
.70987 .50769 L
.71101 .50767 L
.71223 .50764 L
.71352 .50759 L
.71473 .50753 L
.717 .5074 L
.71954 .5072 L
.72222 .50694 L
.72703 .50635 L
Mistroke
.73221 .50552 L
.73791 .50438 L
.74806 .50179 L
.75733 .49879 L
.77822 .48993 L
.79722 .47949 L
.81795 .46573 L
.85861 .43258 L
.89776 .39464 L
.93936 .35014 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .31783 L
.08255 .32215 L
.0932 .32407 L
.10458 .32572 L
.11009 .32635 L
.11531 .32682 L
.11999 .32716 L
.12263 .3273 L
.12507 .32741 L
.12616 .32745 L
.12734 .32749 L
.12836 .32751 L
.12947 .32754 L
.13077 .32756 L
.13201 .32757 L
.13321 .32757 L
.13433 .32757 L
.13561 .32756 L
.13682 .32755 L
.13791 .32753 L
.13908 .3275 L
.14172 .32742 L
.14415 .32731 L
.14885 .32703 L
.15389 .32662 L
.16298 .32558 L
.17378 .32391 L
.18364 .32199 L
.22348 .31151 L
.26181 .30033 L
.28159 .29555 L
.29157 .29364 L
.29694 .29278 L
.3026 .29201 L
.30742 .29148 L
.30997 .29125 L
.31269 .29104 L
.3152 .29088 L
.31748 .29077 L
.31858 .29072 L
.31978 .29068 L
.32082 .29065 L
.32194 .29063 L
.32324 .29061 L
.32445 .2906 L
.32519 .2906 L
.3259 .2906 L
.32721 .29061 L
.32789 .29062 L
Mistroke
.3286 .29064 L
.32988 .29067 L
.33141 .29072 L
.33279 .29078 L
.33527 .29091 L
.33795 .2911 L
.3428 .29155 L
.34773 .29216 L
.35233 .29288 L
.36278 .29503 L
.37296 .29782 L
.38385 .30158 L
.40514 .31116 L
.42527 .32281 L
.46365 .35089 L
.50448 .38643 L
.5438 .42231 L
.58161 .45462 L
.60262 .47044 L
.62186 .48308 L
.64194 .49405 L
.6606 .50197 L
.66977 .50501 L
.67956 .5076 L
.68515 .50878 L
.69042 .50968 L
.69515 .51033 L
.69763 .5106 L
.70028 .51084 L
.70284 .51102 L
.70518 .51114 L
.70631 .51119 L
.70754 .51123 L
.70869 .51126 L
.70977 .51127 L
.711 .51128 L
.71217 .51128 L
.71344 .51127 L
.71416 .51125 L
.71482 .51124 L
.71607 .5112 L
.71744 .51114 L
.72019 .51099 L
.72295 .51078 L
.72546 .51055 L
.7311 .50984 L
.73632 .50899 L
.74125 .508 L
.75095 .50553 L
.76124 .50219 L
Mistroke
.77968 .49435 L
.79923 .48358 L
.81754 .47134 L
.85633 .43934 L
.89757 .39818 L
.9373 .35412 L
.97551 .30981 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo05Cooooo2_oo003Vooooo`008Oooool00ol0003oooooooooo`1Wooooo`?o
o`00f_ooool0027ooooo00?o0000ooooooooool0BOooool2ool001oooooo0ooo003Gooooo`008Ooo
ool00ol0003oooooooooo`16ooooo`?oo`009?ooool3ool00<[ooooo0_l00002ooooo`;o00001?oo
ool0027ooooo00?o0000ooooooooool0@_ooool4ool001Kooooo1Ol0000?ooooo`;oo`00b?ooool0
1_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000JooooodSo00001?oo000`o`0000;oo`00/ol0
00000ooo003o0000o`000005o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00Co
0000ooooool0003o00002oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooool00002ool000[ooooo00Co0000oooooooooooo
oooo1_l00005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool6o`0000Co
oooo0_oo000=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ooo003o
ooooooooo`0Aooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`04o`000?oooooooooooooo
o`;o00000oooool3ool000?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool4o`0000_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`08ooooo`?o000000Coooooo`000?ooooooo`003?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0_l0000Cooooo`04ob4Q8OmgMgOo
MgMgoc8b<PGooooo000Qooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`Goo`00=oooool4
o`0002[ooooo0_l0002`ooooo`03o`000?oooooooooo01;ooooo0_l00002ooooo`;o00001?ooool0
027ooooo00?o0000ooooooooool01_ooool3o`0000Gooooo1Ooo000Kooooo`?oo`004?ooool4o`00
033ooooo0_l0002]ooooo`03o`000?oooooooooo01gooooo000Qooooo`03o`000?oooooooooo00Wo
oooo0ol00007ooooo`Coo`005?ooool3ool000oooooo1?l0000fooooo`;o0000Z_ooool00ol0003o
ooooooooo`0Nooooo`008Oooool00ol0003oooooooooo`0<ooooo`?o00004_ooool:ool000kooooo
1?l0000looooo`;o0000Yoooool00ol0003oooooooooo`0Oooooo`008Oooool00ol0003ooooooooo
o`0?ooooo`Co00008oooool3o`0004;ooooo0_l0002Tooooo`03o`000?oooooooooo023ooooo000Q
ooooo`?o00004oooool4o`0001_ooooo1?l00017ooooo`04o`000?ooooooo`00ool009oooooo00?o
0000ooooooooool08Oooool0027ooooo00?o0000ooooooooool05oooool5o`0000oooooo1ol0001<
ooooo`;o000000?oooooool00?ooool0W?ooool00ooo003oooooooooo`0Rooooo`008Oooool00ol0
003oooooooooo`0Looooo`oo0000EOooool2o`0000;oo`00V_ooool00ol0003oo`00ooooo`0Soooo
o`008Oooool00ol0003oooooooooo`22ooooo`04o`000?ooooooo`00ool009Oooooo00?o0000ool0
0?ooool09?ooool0027ooooo00?o0000ooooooooool0Poooool2o`000003oooooooo003ooooo09Co
oooo00?o0000ool00?ooool09Oooool0027ooooo00?o0000ooooooooool0QOooool2o`000003ool0
0?oooooooooo097ooooo00?o0000ool00?ooool09_ooool0027ooooo00?o0000ooooooooool0Qooo
ool00ol0003oo`00ooooo`2Aooooo`03ool00?oooooooooo02Kooooo000Qooooo`?o0000R?ooool0
0ol0003oo`00ooooo`2?ooooo`03o`000?oo003ooooo02Oooooo000Qooooo`03o`000?oooooooooo
08Wooooo00?o0000ool00?ooool0SOooool00ol0003oo`00ooooo`0Xooooo`008Oooool00ol0003o
ooooooooo`2:ooooo`03o`000?oo003ooooo08_ooooo00?o0000ool00?ooool0:Oooool0027ooooo
00?o0000ooooooooool0Roooool2o`0008[ooooo00?o0000ool00?ooool0:_ooool0027ooooo00?o
0000ooooooooool0SOooool00ol0003oooooooooo`26ooooo`03o`000?oo003ooooo02_ooooo000Q
ooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool0Q?ooool00ol0003oo`00ooooo`0/
ooooo`008Oooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo08;ooooo00?o0000ool0
0?ooool0;Oooool0027ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`20ooooo`03
o`000?oooooooooo02kooooo000Qooooo`?o0000TOooool2o`0007oooooo00?o0000ooooooooool0
;oooool0027ooooo00?o0000ooooooooool0Toooool00ol0003oooooooooo`1kooooo`03o`000?oo
oooooooo033ooooo000Qooooo`03o`000?oooooooooo09?ooooo0_oo001kooooo`03o`000?oooooo
oooo037ooooo000Qooooo`03o`000?oooooooooo09Gooooo00?oo`00o`000?ooool0Moooool00ol0
003oooooooooo`0booooo`008Oooool00ol0003oooooooooo`2Fooooo`03ool00?l0003ooooo07Go
oooo00?o0000ooooooooool0<oooool0027ooooo00?o0000ooooooooool0Uoooool00ooo003o0000
ooooo`1cooooo`03o`000?oooooooooo03Cooooo000Qooooo`03o`000?oooooooooo09Sooooo00?o
o`00o`000?ooool0LOooool00ol0003oooooool0000eooooo`008Oooool3o`0009Wooooo0_oo0000
0ol0003oooooooooo`1]ooooo`03o`000?ooooooo`0003Kooooo000Qooooo`03o`000?oooooooooo
09_ooooo00?oo`00o`000?ooool0K?ooool00ol0003oooooool0000gooooo`008Oooool00ol0003o
ooooooooo`2Looooo`03ool00?l0003ooooo06[ooooo00?o0000oooooooo0000>?ooool0027ooooo
00?o0000ooooooooool0WOooool00ooo003o0000o`00001Xooooo`03o`000?ooooooo`0003Wooooo
000Qooooo`03o`000?oooooooooo09kooooo00?oo`00ooooool00000I_ooool00ol0003oooooool0
000jooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`2Oooooo`03ool00?oooooo000006Cooooo
00?o0000oooooooo0000>oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool0
H?ooool00ol0003oooooool0000looooo`001oooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool00_ooool3o`000:?ooooo00?o0000ooooooooool0G_ooool00ol0003ooooo
ool0000mooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0
0oooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo05cooooo00?o0000oooooooo0000
?_ooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01?ooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo05Wooooo0_l000000ooooooo
o`00ooooo`0nooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo05Oooooo00Co0000oooooooo
ooooo`00@?ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo
04;ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000oooo
ooooool0Yoooool2ool005Cooooo0_l00015ooooo`008Oooool00ol0003oooooooooo`2Yooooo`03
ool00?oooooooooo053ooooo00?o0000ooooooooool0AOooool0027ooooo00?o0000ooooooooool0
Z_ooool00ooo003o0000ooooo`1>ooooo`03o`000?oooooooooo04Kooooo000Qooooo`?o0000Zooo
ool00ooo003o0000ooooo`1<ooooo`03o`000?oooooooooo04Oooooo000Qooooo`03o`000?oooooo
oooo0:cooooo0_oo001:ooooo`;o0000B_ooool0027ooooo00?o0000ooooooooool0[_ooool00ooo
003oooooooooo`16ooooo`04o`000?ooooooo`00ool004Wooooo000Qooooo`03o`000?oooooooooo
0:oooooo00?oo`00ooooooooool0A?ooool00ol0003oooooool0001;ooooo`008Oooool00ol0003o
ooooooooo`2`ooooo`03ool00?l0003ooooo047ooooo0_l000000oooooooo`00ooooo`1;ooooo`00
8Oooool00ol0003oooooooooo`2aooooo`03ool00?l0003o000003oooooo00Co0000oooooooooooo
o`00COooool0027ooooo00?o0000ooooooooool0/_ooool2ool00003o`000?oooooooooo03_ooooo
00Co0000oooooooo003oo`00C_ooool0027ooooo0ol0002dooooo`03ool00?l0003o000003[ooooo
00?o0000oooooooo0000D?ooool0027ooooo00?o0000ooooooooool0]oooool2o`0003Oooooo00?o
0000oooooooo0000DOooool0027ooooo00?o0000ooooooooool0^Oooool00ol0003oooooooooo`0b
ooooo`;o000000?oooooool00?ooool0DOooool0027ooooo00?o0000ooooooooool0^_ooool2o`00
033ooooo0_l000000oooooooo`00ool0001Cooooo`008Oooool00ol0003oooooooooo`2looooo`03
o`000?oooooooooo02_ooooo0_l00002ooooo`03ool00?oooooooooo05?ooooo000Qooooo`03o`00
0?oooooooooo0;gooooo00?oo`00o`000?l00000:?ooool2o`0005[ooooo000Qooooo`03o`000?oo
oooooooo0;kooooo0_oo0003o`0002;ooooo0ol0001Looooo`008Oooool00ol0003oooooooooo`30
ooooo`;oo`0000Coooooo`000?l0003o00007Oooool2o`0005oooooo000Qooooo`?o0000`_ooool2
ool000;ooooo0ol0000Hooooo`;o0000HOooool0027ooooo00?o0000ooooooooool0a?ooool3ool0
00;ooooo0_l0000Aooooo`Go000000Coooooool00?oo003oo`00Goooool0027ooooo00?o0000oooo
ooooool0aoooool5ool0013o000000?oooooool00?oo00000ooo001Rooooo`008Oooool00ol0003o
ooooooooo`3<ooooo`03ool00?oooooooooo00Oooooo1ooo001Wooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool4o`00
0003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo0ol0
003oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5
ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`03oeEE
EOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Co
oooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2Wooooo`00Poooool3o`0001Cooooo
00?o8B4QomgMgOooool01_ooool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@413ogMgM0:Oooooo
001kooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo00_o
oooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03oiRHV?mEEEGooooo00Kooooo00?oEEEEoiRH
V?ooool00_ooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool01_nj^[[oA4A4oooooooooooo
QhN7ofIVIQGooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`1dooooo`00Noooool01ol@413ogMgMogMg
MolQ8B7oooooohN7QomVIVH00_ooool00ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMg
Mol@41001?ooool00ol0003ogMgMooooo`05ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q
8Oo^k^koooooodA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj0_ooool00oo^k^ko0000
ooooo`0;ooooo`Ko00001Oooool00ol0003oooooooooo`04ooooo`;o8B4Q1oooool00ol0003ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo07Cooooo001kooooo`07o`000?oooooogMgMoc8b<_oooooo
k^k^oa0@4002ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool2ogMgM`Ko
oooo00?o<S8booooooooool00oooool00onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`00
00Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0Loooool007_ooooo00CoEEEEojVYZOoooooo00000_ooool01?l0
003oooooooooool0000=ooooo`03o`000?oooooooooo00Kooooo00?ok^k^oa0@4?o^k^h01Oooool0
0olb<S;oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001?oo
ool00ol0003oooooooooo`0:ooooo`Ko00001Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Kooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00?ogMgMob4Q8Oo^k^h00oooool0
1?l0003oooooo`000?l0000=ooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?oo
ool00ol0003ok^k^ooooo`05ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo0000
0oooool00oo^k^ko0000ooooo`0Fooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<07Gooooo001looooo`03oiRHV?mgMgOooooo00;ooooo
00?o0000ooooooooool03?ooool00ol@413o0000o`000003o`0000Kooooo00?ogMgMoa0@4?ooool0
1?ooool00omEEEGoMgMgooooo`06ooooo`03o`000?oooooooooo00Sooooo1ol000000oooooooMgMg
oeEEE@0Gooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1gooooo`00T_ooool00ol0003oooooooooo`08ooooo`03oeEEEOnHV9Sooooo00?ooooo00?o
gMgMoa0@4?o^k^h00_ooool01Ol0003o^[ZjoooooonHV9So410@017ooooo00?ok^k^oa0@4?oMgMd0
5oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Moooool009;ooooo00?o0000ooooooooool02?ooool00onj^[[oA4A4ooooo`04ooooo`09ogMgMomV
IVKooooooooooonHV9So410@o`000?lQ8B7oc<c<017ooooo00?oIVIVogMgMoooool05Oooool00omE
EEGoIVIVo`00000=ooooo`03oeEEEOmVIVKo000000Gooooo1?l0001fooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28891 L
.10458 .26589 L
.14415 .24424 L
.18221 .22597 L
.20178 .21869 L
.21274 .21551 L
.21758 .21435 L
.22272 .21328 L
.22745 .21246 L
.23267 .21174 L
.23496 .21149 L
.23742 .21127 L
.23974 .2111 L
.24186 .21099 L
.24314 .21093 L
.24384 .21091 L
.24451 .21089 L
.24579 .21087 L
.24696 .21086 L
.24763 .21085 L
.24835 .21086 L
.24963 .21087 L
.25034 .21089 L
.25101 .21091 L
.25252 .21096 L
.25383 .21102 L
.25508 .2111 L
.25741 .21127 L
.25992 .21151 L
.26265 .21183 L
.26749 .21257 L
.27205 .21346 L
.28242 .21619 L
.29253 .21984 L
.30343 .22487 L
.32347 .23711 L
.34457 .25411 L
.38268 .29454 L
.42324 .34795 L
.46228 .40387 L
.50378 .46112 L
.54376 .5082 L
.58223 .54229 L
.6021 .55497 L
.61225 .5601 L
.62315 .5646 L
.63338 .56787 L
.64272 .57007 L
.64722 .57085 L
Mistroke
.64959 .5712 L
.65212 .57152 L
.65455 .57177 L
.65674 .57196 L
.65896 .5721 L
.66104 .5722 L
.6622 .57224 L
.66345 .57228 L
.66463 .57229 L
.66571 .5723 L
.66697 .57229 L
.66768 .57229 L
.66834 .57227 L
.66954 .57224 L
.67082 .5722 L
.67205 .57214 L
.67336 .57207 L
.67574 .5719 L
.67856 .57164 L
.68115 .57135 L
.69016 .56992 L
.69469 .56897 L
.69964 .56775 L
.71929 .56114 L
.74025 .55114 L
.7818 .52332 L
.82184 .48811 L
.86035 .44824 L
.90132 .40124 L
.94078 .35321 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .28165 L
.10458 .25635 L
.14415 .23311 L
.18221 .21278 L
.20178 .20445 L
.21267 .20076 L
.22272 .19809 L
.22758 .19707 L
.23293 .19618 L
.23553 .19583 L
.23832 .19552 L
.23985 .19538 L
.24126 .19526 L
.2426 .19518 L
.24402 .1951 L
.24536 .19504 L
.24658 .19501 L
.24781 .19499 L
.24896 .19498 L
.24961 .19498 L
.25031 .19499 L
.25155 .19501 L
.25224 .19503 L
.25288 .19505 L
.25435 .19511 L
.25562 .19518 L
.25683 .19527 L
.25908 .19546 L
.26152 .19573 L
.26416 .19608 L
.26901 .19692 L
.27356 .19793 L
.28394 .20104 L
.29405 .20516 L
.30494 .21083 L
.32498 .22451 L
.34608 .24326 L
.38419 .28677 L
.42475 .34253 L
.4638 .39954 L
.5053 .45708 L
.54528 .50409 L
.58374 .53802 L
.60362 .5506 L
.61377 .55568 L
.62466 .56012 L
.63489 .56334 L
.64424 .56549 L
.64873 .56626 L
Mistroke
.65111 .56659 L
.65363 .5669 L
.65606 .56715 L
.65826 .56733 L
.66047 .56747 L
.66255 .56756 L
.66372 .5676 L
.66497 .56763 L
.66615 .56765 L
.66722 .56765 L
.66848 .56764 L
.66919 .56764 L
.66985 .56762 L
.67106 .56759 L
.67234 .56755 L
.67488 .56742 L
.67725 .56725 L
.67986 .56702 L
.68267 .56671 L
.68737 .56605 L
.69232 .56518 L
.70115 .56318 L
.71072 .56038 L
.72093 .5567 L
.73931 .54834 L
.78086 .52197 L
.8209 .48802 L
.85942 .44886 L
.90039 .4021 L
.93984 .35429 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`0mooooo`Ooo`00ooooool1ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0jooooo`?oo`004?ooool2ool00?Gooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo03Oooooo0ooo000Eooooo`?oo`00l_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0dooooo`?oo`006oooool2ool00?3ooooo000Q
ooooo`03o`000?oooooooooo05Cooooo00?oo`00ooooooooool0kOooool0027ooooo00?o0000oooo
ooooool0>oooool@o`0000[ooooo0_oo003]ooooo`008Oooool3o`0003Oooooo1?l0000@ooooo`Go
00001oooool00ooo003oooooooooo`3Zooooo`008Oooool00ol0003oooooooooo`0dooooo`?o0000
6Oooool00ol0003oooooooooo`05ooooo`;oo`00j_ooool0027ooooo00?o0000ooooooooool0:Ooo
ool2ool000Kooooo0ol0000Mooooo`?o00001_ooool00ooo003oooooooooo`3Wooooo`008Oooool0
0ol0003oooooooooo`0Wooooo`;oo`001Oooool3o`0002?ooooo0ol00004ooooo`03ool00?oooooo
oooo0>Kooooo000Qooooo`03o`000?oooooooooo02Kooooo00?oo`00ooooooooool00oooool2o`00
02Wooooo00?o0000ooooooooool0j_ooool0027ooooo00?o0000ooooooooool09?ooool2ool000Co
oooo0_l0000/ooooo`;o0000j_ooool0027ooooo00?o0000ooooooooool08_ooool2ool000Cooooo
0_l0000`ooooo`03o`000?oooooooooo0>Oooooo000Qooooo`?o00008?ooool2ool000Cooooo0_l0
000cooooo`;o0000ioooool0027ooooo00?o0000ooooooooool07oooool00ooo003oooooooooo`02
ooooo`;o0000=oooool00ol0003oooooooooo`3Tooooo`008Oooool00ol0003oooooooooo`0Moooo
o`;oo`000oooool2o`0003[ooooo0_l0003Tooooo`008Oooool00ol0003oooooooooo`0Looooo`04
ool00?ooooooooooooooo`;o0000?_ooool01?l0003ooooooooooooo003Pooooo`008Oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo0000h?ooool0027o
oooo00?o0000ooooooooool07Oooool2o`0004?ooooo00?o0000oooooooo0000goooool0027ooooo
00?o0000ooooooooool06oooool2o`0004Gooooo00Co0000ooooooooooooo`00g_ooool0027ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`16ooooo`04o`000?ooooooooooool00=go
oooo000Qooooo`?o00004_ooool2ool000Cooooo0_l0001:ooooo`04o`000?ooooooooooool00=co
oooo000Qooooo`03o`000?oooooooooo013ooooo0_oo0004ooooo`;o00009Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd04_ooool01?l0
003ooooooooooooo000Wooooo`Co000000?o410@ooooooooool0>oooool4o`000003oa0@4?oooooo
oooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool5o`0001_ooooo000Q
ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool00_ooool2o`0002Oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Booooo`03o`000?oo
ooooo`0002Wooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0027ooooo00?o
0000ooooooooool03Oooool2ool000?ooooo0_l0000Yooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol0003oooooooooo`0Booooo`03o`000?ooooooo`0002Sooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03cooooo00?oV9RHob4Q8Oo^k^h0
7?ooool0027ooooo00?o0000ooooooooool02oooool2ool000?ooooo0_l0000[ooooo`05o`000?oo
ooooooooooooool000003oooool00omgMgOo<S8booooo`0Dooooo`03o`000?ooooooo`0002Oooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03kooooo
00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool02_ooool01?oo003ooooooooo
ooooool2o`0002gooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`05Oooool01?l0003ooooooooooooo000Vooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043ooooo00?oMgMgofIVI_ooool06_oo
ool0027ooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`02o`0002oooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01Sooooo00Co0000ooooooooooooo`00
9Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
@oooool00ol0003oooooooooo`0Iooooo`008Oooool3o`0000Sooooo00Coo`00ooooool0003o0000
<Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool06Oooool01?l0003o
oooooooooooo000Tooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0oooooo`05o`000?nj^[[ooooooiRHV?l@41006oooool0027ooooo00?o0000oooo
ooooool01oooool00ooo003o0000o`00000cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0001Wooooo00?o0000ooooooooool08_ooool00omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo
000000gooooo1?l0000nooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`06oooool0027ooooo00?o0000
ooooooooool01_ooool00ooo003o0000ooooo`1Sooooo`03o`000?oooooooooo0=Gooooo000Qoooo
o`03o`000?oooooooooo00Cooooo0_l0001Wooooo`03o`000?oooooooooo0=Cooooo000Qooooo`03
o`000?oooooooooo00;ooooo0_l0001Yooooo`03o`000?oooooooooo0=Cooooo000Qooooo`03o`00
0?oooooooooo00;o0000K?ooool00ol0003oooooooooo`39ooooo`;o00000_ooool2o`0000Cooooo
000Qooooo`?o0000Koooool00ol0003oooooooooo`38ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003o
gMgM1?ooool001[oooooool0000jo`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool0
00003_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool04Oooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Wooooo00Co0000ooooooooooooo`003_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo0_l0000Cooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qoooo
o`03o`000?oooooooooo07;ooooo00?o0000oooooooo0000/?ooool00ooo003oooooooooo`0Boooo
o`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo07?ooooo00?o0000oooooooo
0000[_ooool00ol0003oo`00ooooo`0Mooooo`008Oooool00ol0003oooooooooo`1dooooo`03o`00
0?ooooooo`000:cooooo00?o0000ool00?ooool07_ooool0027ooooo00?o0000ooooooooool0M?oo
ool01?l0003ooooooooooooo002[ooooo`03ool00?oooooooooo01kooooo000Qooooo`03o`000?oo
oooooooo07Gooooo00Co0000ooooooooooooo`00ZOooool00ooo003oooooooooo`0Oooooo`008Ooo
ool3o`0007Kooooo00?o0000oooooooo0000Z?ooool00ooo003oooooooooo`0Pooooo`008Oooool0
0ol0003oooooooooo`1gooooo`03o`000?ooooooo`000:Kooooo00?oo`00ooooooooool08Oooool0
027ooooo00?o0000ooooooooool0Moooool01?l0003ooooooooooooo002Tooooo`03ool00?l0003o
oooo02;ooooo000Qooooo`03o`000?oooooooooo07Sooooo00Co0000ooooooooooooo`00X_ooool0
0ooo003o0000ooooo`0Sooooo`008Oooool00ol0003oooooooooo`1iooooo`03o`000?ooooooo`00
0:7ooooo00?oo`00o`000?ooool09?ooool0027ooooo00?o0000ooooooooool0N_ooool00ol0003o
ooooool0002Oooooo`03ool00?l0003ooooo02Gooooo000Qooooo`03o`000?oooooooooo07[ooooo
00Co0000ooooooooooooo`00WOooool00ooo003o0000ooooo`0Vooooo`008Oooool3o`0007_ooooo
00?o0000ooooooooool0WOooool00ooo003o0000ooooo`0Vooooo`008Oooool00ol0003ooooooooo
o`1looooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool09_ooool0027ooooo00?o0000
ooooooooool0O?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo02Oooooo000Qoooo
o`03o`000?oooooooooo07gooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`0Xoooo
o`008Oooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo09Oooooo00?o0000oooooooo
ool0:Oooool0027ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`2Eooooo`03o`00
0?oooooooooo02[ooooo000Qooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0U?oo
ool00ol0003oooooooooo`0[ooooo`008Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooo
oooo09;ooooo00?o0000ooooooooool0;?ooool0027ooooo0ol00021ooooo`03o`000?ooooooo`00
097ooooo00?o0000ooooooooool0;?ooool0027ooooo00?o0000ooooooooool0POooool00ol0003o
ooooool0002@ooooo`03ool00?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo08;ooooo
00?o0000oooooooo0000S_ooool00ooo003oooooooooo`0^ooooo`008Oooool00ol0003ooooooooo
o`23ooooo`03o`000?ooooooo`0008cooooo00?oo`00ooooooooool0;oooool0027ooooo00?o0000
ooooooooool0Q?ooool00ol0003oo`00ooooo`2:ooooo`03ool00?oooooooooo033ooooo000Qoooo
o`03o`000?oooooooooo08Cooooo00?o0000oooooooo0000ROooool00ooo003oooooooooo`0aoooo
o`008Oooool00ol0003oooooooooo`25ooooo`03o`000?ooooooo`0008Oooooo00?oo`00oooooooo
ool0<_ooool0027ooooo0ol00026ooooo`03o`000?oo003ooooo08Kooooo00?oo`00ooooooooool0
<_ooool0027ooooo00?o0000ooooooooool0Q_ooool00ol0003oooooool00025ooooo`03ool00?oo
oooooooo03?ooooo000Qooooo`03o`000?oooooooooo08Oooooo00?o0000oooooooo0000Poooool0
0ooo003oooooooooo`0dooooo`008Oooool00ol0003oooooooooo`28ooooo`03o`000?ooooooo`00
087ooooo00?oo`00ooooooooool0=Oooool0027ooooo00?o0000ooooooooool0ROooool00ol0003o
o`00ooooo`1oooooo`03ool00?oooooooooo03Kooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo
08Wooooo00?o0000oooooooo0000O_ooool00ooo003o0000ooooo`0gooooo`001oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooo
ooooool0R_ooool00ol0003oooooool0001mooooo`03o`000?oooooooooo03Oooooo0007ooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000Roooool00ol0
003oooooooooo`1kooooo`03o`000?oooooooooo03Sooooo0007ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo08_ooooo00?o0000oooo
ooooool0N_ooool00ol0003oooooooooo`0iooooo`001oooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo08cooooo00?o0000
ooooooooool0N?ooool00ol0003oooooooooo`0jooooo`001oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2=ooooo`03o`000?oooooo
oooo07Oooooo00?o0000ooooooooool0>_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`1e
ooooo`03o`000?oooooooooo03_ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Gooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`1dooooo`03o`000?oooooo
oooo03cooooo000Qooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`0mooooo`008Oooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo06oo
oooo0_oo0010ooooo`008Oooool3o`00093ooooo00Co0000ooooooooooooo`00K_ooool00ooo003o
ooooooooo`0oooooo`008Oooool00ol0003oooooooooo`2Aooooo`03o`000?ooooooo`0006gooooo
00?oo`00ooooooooool0@?ooool0027ooooo00?o0000ooooooooool0T_ooool00ol0003oooooool0
001[ooooo`03ool00?oooooooooo047ooooo000Qooooo`03o`000?oooooooooo09?ooooo00?o0000
ool00?ooool0JOooool00ooo003oooooooooo`12ooooo`008Oooool00ol0003oooooooooo`2Coooo
o`03o`000?ooooooo`0006Sooooo00?oo`00ooooooooool0@oooool0027ooooo00?o0000oooooooo
ool0U?ooool00ol0003oooooool0001Vooooo`03ool00?oooooooooo04Cooooo000Qooooo`03o`00
0?oooooooooo09Gooooo00?o0000oooooooo0000I?ooool00ooo003oooooooooo`15ooooo`008Ooo
ool3o`0009Kooooo00?o0000oooooooo0000H_ooool00ooo003oooooooooo`16ooooo`008Oooool0
0ol0003oooooooooo`2Gooooo`03o`000?ooooooo`00063ooooo00?oo`00ooooooooool0Aoooool0
027ooooo00?o0000ooooooooool0V?ooool00ol0003oooooool0001Nooooo`03ool00?oooooooooo
04Sooooo000Qooooo`03o`000?oooooooooo09Wooooo00?o0000oooooooo0000G?ooool00ooo003o
ooooooooo`19ooooo`008Oooool00ol0003oooooooooo`2Jooooo`03o`000?ooooooo`0005Wooooo
0_l0001<ooooo`008Oooool00ol0003oooooooooo`2Jooooo`04o`000?ooooooooooool005Oooooo
00?o0000ooooooooool0C?ooool0027ooooo00?o0000ooooooooool0Voooool00ol0003ooooooooo
o`1Fooooo`03o`000?oooooooooo04gooooo000Qooooo`03o`000?oooooooooo09cooooo00?o0000
ooooooooool0E?ooool00ol0003oooooooooo`1>ooooo`008Oooool3o`0009gooooo00?o0000oooo
ooooool0D_ooool00ol0003oooooooooo`1?ooooo`008Oooool00ol0003oooooooooo`2Nooooo`03
o`000?oooooooooo04oooooo0_l0001Booooo`008Oooool00ol0003oooooooooo`2Oooooo`03o`00
0?oooooooooo04gooooo00?oo`00ooooooooool0D_ooool0027ooooo00?o0000ooooooooool0X?oo
ool2o`0004cooooo00?oo`00ooooooooool0Doooool0027ooooo00?o0000ooooooooool0X_ooool0
0ol0003oooooooooo`18ooooo`03ool00?oooooooooo05Cooooo000Qooooo`03o`000?oooooooooo
0:?ooooo00?o0000ool00?oo0000A_ooool00ooo003oooooooooo`1Eooooo`008Oooool00ol0003o
ooooooooo`2Tooooo`03o`000?ooooooo`0004Cooooo00?oo`00ooooooooool0E_ooool0027ooooo
0ol0002Uooooo`03o`000?ooooooo`00047ooooo0_oo001Iooooo`008Oooool00ol0003ooooooooo
o`2Vooooo`;o000000?oo`00ooooooooool0??ooool2ool005_ooooo000Qooooo`03o`000?oooooo
oooo0:Sooooo00?o0000ool00?ooool0>oooool00ooo003o0000ooooo`1Kooooo`008Oooool00ol0
003oooooooooo`2Yooooo`03o`000?oo003ooooo03Sooooo0_oo001Nooooo`008Oooool00ol0003o
ooooooooo`2Zooooo`03o`000?oo003ooooo03Kooooo00?oo`00o`000?ooool0G_ooool001Sooooo
1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0:_ooooo00?o0000ool00?oo0000
=?ooool00ol0003oooooooooo`1Oooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0:cooooo0_l000000ooo003oooooooooo`0`ooooo`03o`000?oooooooooo063ooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[_ooool00ol0003oo`00ooooo`0^
ooooo`;o0000Hoooool001[ooooo00?o0000ooooooooool01?ooool3o`000:oooooo00?o0000ool0
0?ooool0;?ooool00ol0003oooooooooo`1Sooooo`006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0;7ooooo00?o0000ooooooooool0:?ooool2o`0006Kooooo000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0/_ooool2o`0002Cooooo0_oo0002o`0006Sooooo
000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0]?ooool00ol0003ooooooooo
o`0Oooooo`;oo`000_l0001Zooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooo
oooo0;Gooooo0ol00002ooooo`;oo`005oooool3ool000;o0000K?ooool0027ooooo00?o0000oooo
ooooool0^?ooool4o`0000Goo`003Oooool5ool000;o0000Koooool0027ooooo00?o0000oooooooo
ool0_?ooool3o`0000;ooooo00?oo`00ooooooooool01_ooool4ool000;ooooo0_l0001booooo`00
8Oooool3o`000;oooooo1Ol00004ooooo`So0000M?ooool0027ooooo00?o0000ooooooooool0a?oo
ool5o`0007_ooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3
o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo002Xooooo`03ogMgMomVIVKooooo01Oooooo00?o
IVIVogMgMoooool0Xoooool008Oooooo0ol0000Cooooo`03ob4Q8OoMgMgooooo00Oooooo00?ogMgM
oa0@4?o^k^h06?ooool00oo^k^ko410@omgMg@2Sooooo`00O_ooool01on7QhOo0000oeEEEOmVIVKo
0000oc8b<_o^k^h00oooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o0000odA4A?nj^[X0
0_ooool00onHV9SoEEEEooooo`07ooooo`04oeEEEOnHV9Soooooooooo`Go00002Oooool00omEEEGo
ZJVYooooo`02ooooo`03okZj^_m4A4Cooooo00;ooooo00?oQhN7ofIVI_ooool04oooool4o`000003
oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go0000Noooool007kooooo00Oo410@omgMgOmgMgOo
8B4Qoooooon7QhOoIVIV00?ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo
410@00?ooooo00?o0000omgMgOooool01_ooool02Ol0003oooooooooooooooooV9RHob4Q8Oo^k^ko
ooooodA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj0oooool00oo^k^ko0000ooooo`0;
ooooo`Ko00001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A407_ooooo001nooooo`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@4003ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01Oooool2ogMgM`Oooooo00?o<S8booooooooool0
0_ooool00onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`0000Gooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^07cooooo001nooooo`04oeEE
EOnYZJWoooooo`0000;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo
00Gooooo00?ok^k^oa0@4?o^k^h01_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^
00_ooooo00CoQhN7ofIVI_oooooo00001Oooool00ol0003oooooooooo`0:ooooo`Ko00001?ooool0
0ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^07_ooooo001nooooo`03omgMgOlQ8B7ok^k^
00?ooooo00?o0000ooooooooool00_l0000=ooooo`03o`000?oooooooooo00Kooooo00?oEEEEoiRH
V?ooool01Oooool00ol0003ok^k^ooooo`04ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@
4?oooooo00001?ooool00oo^k^ko0000ooooo`0Eooooo`03o`000?oooooooooo00gooooo00?oMgMg
ofIVI_ooool0N_ooool007oooooo00?oV9RHogMgMoooool00_ooool00ol0003oooooooooo`0=oooo
o`03oa0@4?l0003o000000?o00001Oooool00ooMgMgo410@ooooo`05ooooo`03oeEEEOmgMgOooooo
00Gooooo00?o0000ooooooooool02?ooool7o`0000;ooooo00?oMgMgoeEEEOooool05Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo07Wooooo002Fooooo`03o`000?oooooooooo00Oo
oooo00?oEEEEoiRHV?ooool01?ooool02OoMgMgo410@onk^k_oooooo0000okZj^_ooooooV9RHoa0@
400Booooo`03onk^k_l@413ogMgM01Kooooo00?o0000ooooooooool02_ooool01Ol0003o^[Zjoooo
oonHV9So410@07_ooooo002Fooooo`03o`000?oooooooooo00Oooooo00?o^[ZjodA4A?ooool01Ooo
ool02?mgMgOoIVIVoooooonHV9So410@o`000?lQ8B7oc<c<4_ooool00omVIVKoMgMgooooo`0Doooo
o`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c01kooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .25154 L
.10458 .19627 L
.12507 .17427 L
.14415 .15756 L
.16254 .14545 L
.17284 .14055 L
.18221 .13731 L
.18704 .13611 L
.18969 .1356 L
.19216 .1352 L
.19427 .13493 L
.19654 .13471 L
.19783 .13462 L
.19905 .13455 L
.20015 .13451 L
.20135 .13448 L
.20203 .13448 L
.20276 .13448 L
.20345 .13449 L
.20409 .1345 L
.2053 .13454 L
.20657 .13461 L
.20794 .13471 L
.20922 .13482 L
.21213 .13517 L
.21466 .13557 L
.21696 .13602 L
.22214 .1373 L
.22694 .13883 L
.23205 .14082 L
.24122 .1453 L
.26198 .15973 L
.28145 .1783 L
.29973 .1997 L
.33842 .25468 L
.37956 .32064 L
.41919 .38294 L
.45729 .43548 L
.47854 .46022 L
.49785 .47952 L
.51817 .49647 L
.5369 .50904 L
.55608 .51896 L
.56619 .52302 L
.57688 .52648 L
.58632 .52882 L
.59152 .52985 L
.59646 .53064 L
.60103 .53123 L
Mistroke
.60345 .53148 L
.60603 .53171 L
.60841 .53188 L
.61056 .532 L
.6116 .53205 L
.61273 .53209 L
.61378 .53212 L
.61477 .53215 L
.61602 .53217 L
.61715 .53218 L
.61837 .53219 L
.61906 .53219 L
.6197 .53218 L
.62076 .53217 L
.62193 .53215 L
.62315 .53211 L
.6243 .53208 L
.62693 .53196 L
.62933 .53181 L
.63475 .53136 L
.63966 .5308 L
.64502 .53003 L
.65582 .52799 L
.67547 .52274 L
.69644 .51513 L
.73799 .49483 L
.77802 .47002 L
.81654 .44253 L
.85751 .41047 L
.89697 .37769 L
.93491 .34508 L
.9753 .3098 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .25198 L
.10458 .19094 L
.12507 .16576 L
.14415 .14666 L
.16254 .13303 L
.16783 .13006 L
.17284 .12765 L
.17768 .1257 L
.18221 .12421 L
.18682 .12304 L
.18927 .12256 L
.1919 .12215 L
.19322 .12199 L
.19466 .12185 L
.19601 .12174 L
.19727 .12167 L
.19852 .12162 L
.19965 .1216 L
.20095 .12161 L
.20218 .12164 L
.20325 .12168 L
.20443 .12175 L
.20565 .12185 L
.2068 .12196 L
.20884 .12221 L
.21104 .12255 L
.21605 .12363 L
.22062 .12495 L
.23054 .12891 L
.23971 .13388 L
.26047 .14942 L
.27913 .16793 L
.29973 .19252 L
.33994 .24927 L
.37862 .30891 L
.41976 .37076 L
.45939 .42348 L
.4975 .46454 L
.51875 .48266 L
.53806 .49601 L
.55814 .50675 L
.5771 .514 L
.58682 .51666 L
.59214 .51782 L
.59712 .51871 L
.60171 .51939 L
.6059 .51987 L
.61056 .52027 L
.61313 .52042 L
Mistroke
.61557 .52053 L
.61682 .52057 L
.61748 .52058 L
.61817 .5206 L
.61944 .52062 L
.62061 .52062 L
.62174 .52062 L
.62279 .52061 L
.62395 .52059 L
.62518 .52056 L
.6265 .52052 L
.62793 .52046 L
.63054 .52032 L
.63307 .52015 L
.63541 .51995 L
.64434 .51889 L
.64885 .51817 L
.65381 .51725 L
.6732 .51236 L
.69407 .505 L
.73526 .48518 L
.77494 .46103 L
.8131 .43471 L
.85371 .40468 L
.89281 .37465 L
.93436 .34205 L
.97439 .31042 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`0`ooooo`_oo`00ooooool:ooooo`008Ooo
ool00ol0003oooooooooo`0^ooooo`;oo`002oooool3ool00?oooooo1oooool0027ooooo00?o0000
ooooooooool0?_ooool00ooo003oooooooooo`3oooooo`Cooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0<?ooool;o`000?oooooo2_ooool0027ooooo
00?o0000ooooooooool0;_ooool2o`0000_ooooo0ol0003oooooo`Oooooo000Qooooo`?o00009Ooo
ool00ooo003oooooooooo`03ooooo`?o00004?ooool3o`000?oooooo1?ooool0027ooooo00?o0000
ooooooooool09?ooool01?oo003oooooooooooooool3o`0001Kooooo0_l0003oooooo`;ooooo000Q
ooooo`03o`000?oooooooooo02?ooooo00Goo`00ooooooooooooooooo`00000Kooooo`05o`000?oo
oooooooooooooooo0000o?ooool0027ooooo00?o0000ooooooooool08_ooool00ooo003ooooooooo
o`02o`0001gooooo0_l000000oooooooo`00ool0003kooooo`008Oooool00ol0003oooooooooo`0Q
ooooo`04ool00?ooooooooooo`00027ooooo00Co0000ooooooooooooo`00n_ooool0027ooooo00?o
0000ooooooooool08?ooool01?oo003oooooo`000?l0000Sooooo`04o`000?ooooooooooool00?Wo
oooo000Qooooo`03o`000?oooooooooo01oooooo00?oo`00ooooool000009_ooool01?l0003ooooo
oooooooo003hooooo`008Oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooo000002Sooooo
00Co0000ooooooooooooo`00moooool0027ooooo0ol0000Mooooo`03ool00?oooooo000002[ooooo
00Co0000ooooooooooooo`00m_ooool0027ooooo00?o0000ooooooooool07?ooool00ooo003ooooo
o`00000/ooooo`03o`000?ooooooo`000?Kooooo000Qooooo`03o`000?oooooooooo01_ooooo00?o
o`00ooooool00000;_ooool00ol0003oooooool0003eooooo`008Oooool00ol0003oooooooooo`0J
ooooo`04ool00?ooooooooooo`0002oooooo00?o0000oooooooo0000m?ooool0027ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0_ooooo`03o`000?ooooooo`000??ooooo0007oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@04ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0<Oooool00ol0003oooooool0
003booooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo0?7ooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo00;ooooo0ol0000Iooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0l?oo
ool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo0>oooooo0007
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo0>kooooo
0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`3]ooooo`001ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0kOooool000Oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0Cooooo`03ool0
0?oooooo000003oooooo00?o0000ooooooooool0k?ooool0027ooooo00?o0000ooooooooool04ooo
ool00ooo003o0000ooooo`10ooooo`03o`000?oooooooooo0>_ooooo000Qooooo`03o`000?oooooo
oooo01;ooooo00?oo`00o`000?ooool0@Oooool00ol0003oooooool0003[ooooo`008Oooool3o`00
017ooooo00?oo`00o`000?ooool0@oooool00ol0003oo`00ooooo`3Zooooo`008Oooool00ol0003o
ooooooooo`0Aooooo`03ool00?l0003ooooo04Cooooo00?o0000ool00?ooool0jOooool0027ooooo
00?o0000ooooooooool04?ooool00ooo003o0000ooooo`16ooooo`03o`000?oo003ooooo0>Sooooo
000Qooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0A_ooool00ol0003oo`00oooo
o`3Xooooo`008Oooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo04Sooooo00?o0000
ool00?ooool0ioooool0027ooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`1:oooo
o`03o`000?oo003ooooo0>Kooooo000Qooooo`03o`000?oooooooooo00kooooo00?oo`00oooooooo
ool0B_ooool00ol0003oo`00ooooo`3Vooooo`008Oooool3o`0000gooooo00?oo`00ooooooooool0
C?ooool00ol0003oo`00ooooo`3Uooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
003ooooo04kooooo00?o0000ool00?ooool0i?ooool0027ooooo00?o0000ooooooooool02oooool0
0ol0003oo`00ooooo`1@ooooo`03ool00?oooooooooo0>?ooooo000Qooooo`03o`000?oooooooooo
00[ooooo00?o0000ool00?ooool0DOooool00ol0003oo`00ooooo`3Sooooo`008Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo05?ooooo00?o0000ool00?ooool0h_ooool0027ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Dooooo`03o`000?oo003ooooo0>7ooooo
000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0EOooool00ol0003ooooooooo
o`3Qooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Oooooo00?o0000
ooooooooool0h?ooool0027ooooo0ol00007ooooo`03o`000?oooooooooo05Oooooo00?o0000oooo
ooooool0h?ooool0027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0dooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?
ooooo`03o`000?oooooooooo02_ooooo1?l000000ol@413oooooooooo`0kooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0mooooo`Go00006ooo
ool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0eooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03oooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool0??ooool01OnHV9So8B4Qonk^k_ooooooA4A401_ooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0=Oooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo
000Qooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0=_ooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool04?ooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0nooooo`03oiRH
V?lQ8B7ok^k^01_ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?ooool0=ooo
ool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Aooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`0@?ooool00omgMgOoIVIVooooo`0Jooooo`008Oooool00ol0003o
ooooooooo`03ooooo`03ool00?oooooooooo03Oooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo01Cooooo00?o0000oooooooo0000:_ooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Ioooo
o`008Oooool3o`0000;ooooo00?oo`00ooooooooool0>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool05?ooool00ol0003oooooool0000Zooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0oooooo`05o`000?nj^[[ooooo
oiRHV?l@41006oooool0027ooooo00Ko0000ooooooooooooooooo`000?oo000jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0001Cooooo00?o0000oooooooo00009oooool00omEEEGoIVIV
o`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000nooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`06oooool0027ooooo00Go0000ooooooooooooooooool0001Uooooo`03o`000?ooooooo`000=[o
oooo000Qooooo`04o`000?ooooooooooool006Kooooo00?o0000oooooooo0000f_ooool0027ooooo
00?o0000oooooooo0000J?ooool00ol0003oooooool0003Iooooo`008Oooool00ol0003oooooool0
001Xooooo`03o`000?ooooooo`000<oooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000
ool00?ooool0JOooool00ol0003oooooool0003>ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM
1?ooool001[ooooo1ol000000ooo003o0000o`00001/o`000003ool00?l0003o00000;So000000?o
o`00o`000?l000001Ol0000<ooooo`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooool00007ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
003o000001?ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`03ooooo`03o`000?ooooooo`0000Kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00Co0000ool00?oooooo0000
4oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003oooooooooo`1[ooooo`04o`00
0?ooooooooooool00;Cooooo00?o0000ool00?ooool05?ooool2o`0000;ooooo0_l00004ooooo`00
8Oooool00ol0003oooooooooo`1/ooooo`03o`000?ooooooo`000;?ooooo00?o0000ooooooooool0
7oooool0027ooooo00?o0000ooooooooool0K?ooool01?l0003ooooooooooooo002aooooo`03o`00
0?oooooooooo023ooooo000Qooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0/?oo
ool00ol0003oooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo0:kooooo00?o0000ooooooooool08_ooool0027ooooo0ol0001^ooooo`03o`000?oooooooooo
0:gooooo00?o0000ooooooooool08oooool0027ooooo00?o0000ooooooooool0Koooool00ol0003o
ooooooooo`2Yooooo`03ool00?oooooo000002Kooooo000Qooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool0Z?ooool00ooo003o0000ooooo`0Vooooo`008Oooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo0:Kooooo0_oo00000ol0003oooooooooo`0Vooooo`008Oooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo0:Cooooo00?oo`00o`000?l00000:Oooool0
027ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`2Rooooo`03ool00?l0003ooooo
02[ooooo000Qooooo`03o`000?oooooooooo07?ooooo00?o0000oooooooo0000Woooool2ool00003
o`000?oooooooooo02[ooooo000Qooooo`?o0000Loooool00ol0003oooooool0002Nooooo`03ool0
0?oooooo000002gooooo000Qooooo`03o`000?oooooooooo07Cooooo00?o0000oooooooo0000Vooo
ool2ool00003ooooool0003ooooo02gooooo000Qooooo`03o`000?oooooooooo07Gooooo00?o0000
oooooooo0000VOooool01?oo003oooooo`000?l0000_ooooo`008Oooool00ol0003oooooooooo`1e
ooooo`03o`000?ooooooo`0009Sooooo00?oo`00ooooool00000<Oooool0027ooooo00?o0000oooo
ooooool0M_ooool00ol0003oooooool0002Fooooo`03ool00?oooooo000003;ooooo000Qooooo`03
o`000?oooooooooo07Oooooo00?o0000oooooooo0000U_ooool00ol0003oooooooooo`0aooooo`00
8Oooool00ol0003oooooooooo`1gooooo`03o`000?ooooooo`0009Gooooo00?o0000ooooooooool0
<_ooool0027ooooo00?o0000ooooooooool0N?ooool00ol0003oooooool0002Booooo`;o0000=Ooo
ool0027ooooo0ol0001iooooo`03o`000?ooooooo`00093ooooo00?o0000ooooooooool0=Oooool0
027ooooo00?o0000ooooooooool0NOooool01?l0003ooooooooooooo002>ooooo`03o`000?oooooo
oooo03Kooooo000Qooooo`03o`000?oooooooooo07[ooooo00?o0000oooooooo0000SOooool00ol0
003oooooooooo`0gooooo`008Oooool00ol0003oooooooooo`1kooooo`03o`000?ooooooo`0008Oo
oooo0_oo0002ooooo`03o`000?oooooooooo03Sooooo000Qooooo`03o`000?oooooooooo07_ooooo
00Co0000ooooooooooooo`00QOooool00ooo003oooooooooo`02o`0003_ooooo000Qooooo`03o`00
0?oooooooooo07cooooo00?o0000ooooooooool0Q?ooool01?oo003oooooooooool0000mooooo`00
8Oooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo08;ooooo00Coo`00oooooooooooo
0000?_ooool0027ooooo0ol0001nooooo`03o`000?oooooooooo07oooooo0_oo0002ooooo`03o`00
0?oooooooooo03gooooo000Qooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0O_oo
ool01Ooo003ooooooooooooooooo0000043ooooo000Qooooo`03o`000?oooooooooo07oooooo00?o
0000ooooooooool0Noooool2ool000;ooooo0_l00011ooooo`008Oooool00ol0003oooooooooo`20
ooooo`03o`000?oooooooooo07Wooooo00Goo`00ooooooooooooooooo`000013ooooo`008Oooool0
0ol0003oooooooooo`20ooooo`03o`000?oooooooooo07Sooooo00Goo`00ooooooooooooooooo`00
0014ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo07Kooooo
00?oo`00ooooooooool00_l00015ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0P_ooool01?l0003ooooo
oooooooo001fooooo`03o`000?oooooooooo04Gooooo0007ooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol0003oooooooooo`02ooooo`?o0000Poooool01?l0003ooooooooooooo001doooo
o`03o`000?oooooooooo04Kooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omg
MgOo<S8booooo`03ooooo`03o`000?oooooooooo08?ooooo00Go0000ooooooooooooooooool0001b
ooooo`03o`000?oooooooooo04Oooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0Q?ooool01Ol0003ooooooooo
ooooooooo`0006oooooo0_l0001:ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`25ooooo`05o`000?oooooooooooooooooo
0000KOooool00ol0003oooooooooo`1:ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo00;o
oooo00?oo`00ooooooooool0JOooool00ol0003oooooooooo`1;ooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo08Kooooo00?o0000oooooooo
ool00_ooool00ooo003oooooooooo`1Rooooo`;oo`000_ooool2o`0004kooooo000Qooooo`03o`00
0?oooooooooo08Oooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`1Pooooo`05ool0
0?ooooooooooooooool00000D?ooool0027ooooo00?o0000ooooooooool0R?ooool00ol0003ooooo
ooooo`02ooooo`03ool00?oooooooooo05gooooo0_oo0003ooooo`03o`000?oooooooooo04oooooo
000Qooooo`?o0000R?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo05_ooooo00Co
o`00oooooooooooooooo0_l0001Booooo`008Oooool00ol0003oooooooooo`29ooooo`03o`000?oo
oooooooo00?ooooo00?oo`00ooooooooool0F?ooool2ool000?ooooo00?o0000ooooooooool0D_oo
ool0027ooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`03ooooo`03ool00?oooooo
oooo05Kooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`1Cooooo`008Oooool00ol0
003oooooooooo`2;ooooo`03o`000?oooooooooo05Wooooo0_oo0003ooooo`;o0000E_ooool0027o
oooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1Fooooo`;oo`001?ooool00ol0003o
ooooooooo`1Fooooo`008Oooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo05Cooooo
00?oo`00ooooooooool00oooool00ol0003oooooooooo`1Gooooo`008Oooool00ol0003ooooooooo
o`2>ooooo`03o`000?oooooooooo05Oooooo0_l0001Jooooo`008Oooool3o`0008oooooo00?o0000
ooooooooool0E?ooool2o`0005cooooo000Qooooo`03o`000?oooooooooo093ooooo00?o0000oooo
ooooool0DOooool2o`0005kooooo000Qooooo`03o`000?oooooooooo097ooooo0_l00005ooooo`03
ool00?oooooooooo04Oooooo0_l0001Pooooo`008Oooool00ol0003oooooooooo`2Cooooo`03o`00
0?oooooooooo00;ooooo0_oo0017ooooo`03o`000?oooooooooo063ooooo000Qooooo`03o`000?oo
oooooooo09Cooooo0_l00004ooooo`03ool00?oooooooooo03gooooo0_oo0003ooooo`;o0000Hooo
ool0027ooooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`02ooooo`;oo`00>oooool2
ool000?ooooo0_l0001Uooooo`008Oooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo
00?ooooo00?oo`00ooooooooool0=_ooool2ool000?ooooo0_l0001Wooooo`008Oooool00ol0003o
ooooooooo`2Hooooo`;o00001?ooool2ool003Cooooo0_oo0003ooooo`;o0000JOooool0027ooooo
0ol0002Jooooo`03o`000?oooooooooo00?ooooo0_oo000`ooooo`;oo`000oooool2o`0006_ooooo
000Qooooo`03o`000?oooooooooo09_ooooo0_l00005ooooo`;oo`00;?ooool2ool000?ooooo0_l0
001]ooooo`008Oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Cooooo0_oo000V
ooooo`Coo`001?ooool00ol0003oooooooooo`1]ooooo`008Oooool00ol0003oooooooooo`2Noooo
o`;o0000<_ooool2o`00073ooooo000Qooooo`03o`000?oooooooooo0:3ooooo0_l0000^ooooo`;o
0000L_ooool0027ooooo00?o0000ooooooooool0X_ooool2o`0001kooooo00?oo`00ooooooooool0
2Oooool2o`0007Cooooo000Qooooo`03o`000?oooooooooo0:Cooooo0ol00008oooooa?oo`002Ooo
ool3o`0007Kooooo000Qooooo`?o0000Yoooool3o`0001kooooo0ol0001iooooo`008Oooool00ol0
003oooooooooo`2Zooooo`?o00006?ooool3o`0007cooooo000Qooooo`03o`000?oooooooooo0:go
oooo0ol0000?ooooo`Ko0000Ooooool0027ooooo00?o0000ooooooooool0/?ooool?o`0008Gooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo1?l000000ol@413oooooooooo`02
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Tooooo`03ogMgMomVIVKooooo
01Oooooo00?oIVIVogMgMoooool0Yoooool008?ooooo0ol0000Dooooo`03ob4Q8OoMgMgooooo00Ko
oooo00?ogMgMoa0@4?o^k^h06?ooool00oo^k^ko410@omgMg@2Wooooo`00Noooool01on7QhOo0000
oeEEEOmVIVKo0000oc8b<_o^k^h00_ooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o0000
odA4A?nj^[X00oooool00onHV9SoEEEEooooo`06ooooo`03oeEEEOnHV9Sooooo00;ooooo1Ol00009
ooooo`03oeEEEOnYZJWooooo00;ooooo00Ko^[ZjodA4A?ooooooooooohN7QomVIVHEooooo`Co0000
00?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd0MOooool007_ooooo00Oo410@omgMgOmgMgOo8B4Qoooooon7QhOoIVIV00;ooooo00?o0000oooo
ooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000omgMgOooool01Oooool0
0ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooo
oooooooo410@okZj^P;ooooo00?ok^k^o`000?ooool02oooool6o`0000Gooooo00?o0000oooooooo
ool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
07Cooooo001kooooo`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@4002ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01_ooool2ogMgM`Kooooo00?o<S8booooooooool00oooool0
0onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`0000Cooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0Looo
ool007_ooooo00CoEEEEojVYZOoooooo00000_ooool01?l0003oooooooooool0000=ooooo`03o`00
0?oooooooooo00Kooooo00?ok^k^oa0@4?o^k^h01Oooool00olb<S;oooooooooo`04ooooo`03oiRH
V?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001?ooool00ol0003oooooooooo`0:ooooo`Ko
00001Oooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_oo
ool0M?ooool007_ooooo00?ogMgMob4Q8Oo^k^h00oooool01?l0003oooooo`000?l0000=ooooo`03
o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool00ol0003ok^k^ooooo`05ooooo`03
ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo00000oooool00oo^k^ko0000ooooo`0Foooo
o`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<07Gooooo001looooo`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool03?ooool00ol@
413o0000o`000003o`0000Kooooo00?ogMgMoa0@4?ooool01?ooool00omEEEGoMgMgooooo`06oooo
o`03o`000?oooooooooo00Sooooo1ol000000oooooooMgMgoeEEE@0Gooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1gooooo`00T_ooool00ol0003o
ooooooooo`08ooooo`03oeEEEOnHV9Sooooo00?ooooo00?ogMgMoa0@4?o^k^h00_ooool01Ol0003o
^[ZjoooooonHV9So410@017ooooo00?ok^k^oa0@4?oMgMd05oooool00ol0003oooooooooo`0:oooo
o`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`1gooooo`00T_ooool00ol0
003oooooooooo`08ooooo`03okZj^_m4A4Cooooo00Cooooo00WoMgMgofIVI_oooooooooooiRHV?l@
413o0000ob4Q8Oo<c<`04Oooool00omVIVKoMgMgooooo`0Eooooo`03oeEEEOmVIVKo000000cooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000M_ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .22809 L
.08255 .19129 L
.10458 .15782 L
.11448 .14552 L
.12507 .13442 L
.13499 .12602 L
.14415 .12002 L
.14911 .11749 L
.15437 .11536 L
.15964 .11379 L
.16265 .11315 L
.16399 .11292 L
.16546 .11271 L
.1668 .11256 L
.16805 .11246 L
.16925 .11238 L
.17052 .11233 L
.17178 .11232 L
.17296 .11234 L
.17401 .11237 L
.17516 .11244 L
.17642 .11254 L
.1778 .11269 L
.1806 .1131 L
.18318 .11362 L
.1856 .11422 L
.1906 .11582 L
.19605 .11808 L
.20595 .12357 L
.21559 .13051 L
.22451 .13824 L
.26377 .18409 L
.30152 .23854 L
.34173 .29654 L
.38041 .34459 L
.40006 .36475 L
.42155 .38326 L
.44231 .39766 L
.46118 .40792 L
.48079 .41591 L
.49156 .41924 L
.50174 .42173 L
.51146 .42356 L
.51678 .42434 L
.52175 .42494 L
.52634 .42539 L
.53054 .4257 L
.53277 .42584 L
.5352 .42596 L
Mistroke
.53777 .42606 L
.53895 .42609 L
.5402 .42612 L
.54154 .42615 L
.54277 .42617 L
.54409 .42618 L
.54484 .42618 L
.54553 .42618 L
.5468 .42618 L
.54796 .42617 L
.5486 .42616 L
.54929 .42615 L
.55055 .42613 L
.55291 .42606 L
.55542 .42598 L
.55992 .42576 L
.56507 .42542 L
.5699 .42501 L
.5809 .42381 L
.60112 .42068 L
.61964 .41695 L
.65932 .40694 L
.69748 .39568 L
.73809 .38286 L
.77719 .37025 L
.81874 .35694 L
.85877 .34438 L
.89729 .33258 L
.93826 .32028 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .22711 L
.08255 .19021 L
.10458 .15642 L
.11448 .14394 L
.12507 .13264 L
.13499 .12407 L
.14415 .11794 L
.14911 .11535 L
.15437 .11316 L
.15964 .11154 L
.16265 .11088 L
.16399 .11064 L
.16546 .11042 L
.1668 .11026 L
.16805 .11015 L
.16925 .11006 L
.17052 .11001 L
.17178 .10998 L
.17296 .10999 L
.17401 .11002 L
.17516 .11008 L
.17642 .11017 L
.1778 .11031 L
.1806 .1107 L
.18318 .1112 L
.1856 .11178 L
.1906 .11333 L
.19605 .11553 L
.20595 .12086 L
.22451 .13503 L
.24428 .15517 L
.26529 .18083 L
.30304 .23283 L
.34324 .28824 L
.38193 .33429 L
.40158 .35351 L
.42307 .37091 L
.4436 .38396 L
.46269 .3931 L
.47322 .39697 L
.48315 .39992 L
.49207 .40203 L
.49706 .403 L
.50174 .40377 L
.50668 .40445 L
.5112 .40496 L
.51622 .40541 L
.51902 .4056 L
.52161 .40575 L
Mistroke
.52412 .40586 L
.52678 .40595 L
.5283 .40599 L
.52905 .406 L
.52973 .40601 L
.53102 .40603 L
.5317 .40603 L
.53241 .40604 L
.53363 .40604 L
.53494 .40603 L
.53617 .40602 L
.5373 .40601 L
.53862 .40598 L
.54005 .40595 L
.54266 .40587 L
.545 .40577 L
.54752 .40565 L
.55208 .40537 L
.56247 .4045 L
.57344 .40325 L
.58349 .40186 L
.62317 .39461 L
.66133 .38598 L
.70194 .37584 L
.74104 .36554 L
.78259 .35444 L
.82262 .3441 L
.86114 .33485 L
.90211 .32564 L
.94157 .31673 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo02Wooooo0_oo003ooooooa[ooooo000Q
ooooo`03o`000?oooooooooo02Kooooo0ooo0007o`000?oooooo5Oooool0027ooooo00?o0000oooo
ooooool09?ooool2ool00003o`000?oooooooooo00Oooooo0ol0003ooooooa;ooooo000Qooooo`?o
00008_ooool2ool000;o00003Oooool00ol0003oo`00ool0003oooooo`oooooo000Qooooo`03o`00
0?oooooooooo027ooooo00?oo`00ooooooooool04_ooool2ool00?oooooo3Oooool0027ooooo00?o
0000ooooooooool07oooool2ool001Kooooo00?o0000ool00?ooool0ooooool;ooooo`008Oooool0
0ol0003oooooooooo`0Nooooo`03ool00?l0003ooooo01Oooooo00?o0000ool00?oo0000ooooool:
ooooo`008Oooool00ol0003oooooooooo`0Mooooo`03ool00?l0003ooooo01Wooooo0_l000000ooo
003oooooooooo`3oooooo`Oooooo000Qooooo`03o`000?oooooooooo01gooooo00?oo`00oooooooo
ool06oooool00ol0003oo`00ooooo`3oooooo`Oooooo000Qooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool07Oooool00ooo003oooooooooo`3oooooo`Kooooo000Qooooo`?o00006ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oo003ooooo0?oooooo1_ooool0027ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Pooooo`03o`000?oo003ooooo0?oooooo1Oooool0
027ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Qooooo`03o`000?oo003ooooo
0?oooooo1?ooool0027ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oo003ooooo0?oooooo0oooool0027ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo0?oooooo0_ooool0027ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0?oooooo0Oooool0027ooooo00?o0000
ooooooooool05_ooool00ooo003o0000ooooo`0Yooooo`03o`000?oooooooooo0?oooooo000Qoooo
o`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool0:Oooool00ol0003oooooooooo`3ooooo
o`008Oooool3o`0001Gooooo00?oo`00ooooooooool0:oooool00ol0003oooooooooo`3nooooo`00
8Oooool00ol0003oooooooooo`0Dooooo`03ool00?l0003ooooo02gooooo00?o0000ooooooooool0
oOooool0027ooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`0^ooooo`03o`000?oo
oooooooo0?cooooo000Qooooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool0<?ooool0
0ol0003oooooool0003kooooo`008Oooool00ol0003oooooooooo`0Booooo`03ool00?l0003ooooo
03;ooooo00?o0000oooooooo0000n_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool04_ooool0
0ooo003oooooooooo`0cooooo`03o`000?oo003ooooo0?Wooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0A
ooooo`03ool00?l0003ooooo03Cooooo00?o0000oooooooo0000nOooool000Go00000_ooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`00013ooooo00?oo`00
o`000?ooool0=_ooool00ol0003oooooool0003hooooo`001oooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0@ooooo`03ool00?oooooo
oooo03Oooooo00?o0000oooooooo0000moooool000Oooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0?ooooo`03ool00?l0
003ooooo03Sooooo00?o0000oooooooo0000moooool000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ooo003o0000oooo
o`0jooooo`03o`000?ooooooo`000?Kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00gooooo00?oo`00o`000?ooool0??oo
ool00ol0003oooooool0003eooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
0005ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0??ooool00ol0003oo`00oooo
o`3dooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03gooooo00?o0000
oooooooo0000m?ooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0ooooo
o`03o`000?ooooooo`000??ooooo000Qooooo`?o00003?ooool00ol0003oooooooooo`10ooooo`03
o`000?ooooooo`000?;ooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`3booooo`008Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo04;ooooo00?o0000ooooooooool0lOooool0027ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`14ooooo`03o`000?oooooooooo0?3ooooo000Qooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`3_ooooo`008Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0koooool0027ooooo
00?o0000ooooooooool02?ooool00ooo003oooooooooo`18ooooo`03o`000?oooooooooo0>kooooo
000Qooooo`?o00002?ooool00ooo003oooooooooo`19ooooo`03o`000?oooooooooo0>gooooo000Q
ooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool0B_ooool00ol0003oooooooooo`3]
ooooo`008Oooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo04_ooooo00?o0000oooo
oooo0000k?ooool0027ooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`1=ooooo`03
o`000?oo003ooooo0>_ooooo000Qooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool0
C_ooool00ol0003oo`00ooooo`3Zooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
003ooooo04oooooo00?o0000oooooooo0000j_ooool0027ooooo00?o0000ooooooooool01Oooool0
0ooo003oooooooooo`1@ooooo`03o`000?oo003ooooo0>Wooooo000Qooooo`03o`000?oooooooooo
00Cooooo00?o0000ool00?ooool0D_ooool00ol0003oo`00ooooo`3Xooooo`008Oooool3o`0000Co
oooo00?oo`00ooooooooool0D_ooool00ol0003oooooool0003Xooooo`008Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oo003ooooo03Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Oooooo00?o0000oooooooo0000<oooool4o`00
0003oa0@4?oooooooooo03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`03oooo
o`03ool00?oooooooooo03Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`07ooooo`03o`000?oo003ooooo03Cooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0looooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@06oooool0027ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0g
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
003ooooo03?ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo03cooooo00?oV9RHob4Q8Oo^k^h07?ooool0027ooooo00?o0000ooooooooool00_ooool0
0ol0003oo`00ooooo`0hooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8boooo
o`08ooooo`03o`000?ooooooo`0003?ooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`0>ooooo`03ogMgMolb<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000
ooooooooool00_ooool00ooo003oooooooooo`0hooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00[ooooo00?o0000ool00?ooool0<_ooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c010ooooo`03
ogMgMomVIVKooooo01[ooooo000Qooooo`05o`000?ooooooooooooooool00000>oooool01Ol@413o
oooooooooooooooo410@00cooooo00?o0000ooooooooool03Oooool00ol0003oo`00ooooo`0aoooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo01Wooooo000Qooooo`?o000000?oooooo`000?ooool0>_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool03Oooool00ol0003oooooool0000aoooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0ooooo
o`05o`000?nj^[[ooooooiRHV?l@41006oooool0027ooooo00Co0000oooooooooooo0000??ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000=ooooo`03o`000?oooooooooo02kooooo00?o
EEEEofIVI_l00000?oooool00omEEEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`00
0?lQ8B7oc<c<01_ooooo000Qooooo`04o`000?ooooooooooo`0005oooooo00?o0000ooooooooool0
hOooool0027ooooo00?o0000ooooool00000HOooool00ol0003oooooooooo`3Pooooo`008Oooool0
0ol0003oooooo`00001Qooooo`03o`000?oooooooooo0>3ooooo000Qooooo`;o0000Hoooool00ol0
003oooooooooo`3Eooooo`;o00000_ooool2o`0000Cooooo000Qooooo`;o0000I?ooool00ol0003o
ooooooooo`3Dooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool001[oooooool0000ao`00
00;oo`001ol0000<ooooo`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000oooooooo00003?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02?ooool01Ol0003oo`00ool00?oooooo000001?ooooo00Cok^k^
ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooool0000<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05
ooooo`?o00001?ooool00ol0003oooooooooo`0Aooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Q
ooooo`03o`000?oooooooooo06Kooooo00?o0000oooooooo0000[oooool3ool000;ooooo0ol0000J
ooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo06Oooooo00?o0000oooo
oooo0000Zoooool3ool00003ooooool0003o000000;o00009oooool0027ooooo00?o0000oooooooo
ool0J?ooool00ol0003oooooool0002Wooooo`?oo`0000Coooooo`000?l0003o0000:oooool0027o
oooo00?o0000ooooooooool0JOooool00ol0003oooooool0002Qooooo`Goo`0000Coooooo`000?l0
003o0000;_ooool0027ooooo00?o0000ooooooooool0JOooool01?l0003ooooooooooooo002Moooo
o`?oo`000oooool3o`00037ooooo000Qooooo`?o0000J_ooool01?l0003ooooooooooooo002Noooo
o`Co0000=?ooool0027ooooo00?o0000ooooooooool0Joooool01?l0003ooooooooooooo002?oooo
o`?oo`001oooool4o`0003Sooooo000Qooooo`03o`000?oooooooooo06cooooo00Co0000oooooooo
ooooo`00ROooool5ool000Kooooo1?l0000looooo`008Oooool00ol0003oooooooooo`1]ooooo`04
o`000?ooooooooooool008Cooooo1?oo0008ooooo`?o0000@?ooool0027ooooo00?o0000oooooooo
ool0KOooool01Ol0003oooooooooooooooooo`00083ooooo0ooo0009ooooo`?o0000@oooool0027o
oooo00?o0000ooooooooool0K_ooool01Ol0003oooooooooooooooooo`0007gooooo0_oo0009oooo
o`?o0000A_ooool0027ooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`26ooooo`?o
0000BOooool0027ooooo0ol0001`ooooo`03o`000?oooooooooo087ooooo1?l0001<ooooo`008Ooo
ool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo073ooooo0ooo000:ooooo`?o0000D?oo
ool0027ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1Zooooo`Goo`002_ooool3
o`0005?ooooo000Qooooo`03o`000?oooooooooo07?ooooo0_l0001Wooooo`?oo`003?ooool3o`00
05Kooooo000Qooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0HOooool3ool000_o
oooo1?l0001Iooooo`008Oooool00ol0003oooooooooo`1fooooo`04o`000?ooooooooooooooo`;o
o`00Foooool2ool000_ooooo0ol0001Mooooo`008Oooool00ol0003oooooooooo`1gooooo`03o`00
0?oooooooooo00;ooooo00?oo`00ooooooooool0H_ooool3o`00063ooooo000Qooooo`03o`000?oo
oooooooo07Sooooo00?o0000ooooooooool00_ooool2ool004_ooooo0ooo000Aooooo`?o0000Hooo
ool0027ooooo0ol0001iooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0A?ooool4
ool0017ooooo0ol0001Vooooo`008Oooool00ol0003oooooooooo`1jooooo`;o00001?ooool2ool0
043ooooo1?oo000Booooo`?o0000JOooool0027ooooo00?o0000ooooooooool0O?ooool00ol0003o
ooooooooo`03ooooo`;oo`00>oooool3ool001?ooooo0ol0001/ooooo`008Oooool00ol0003ooooo
ooooo`1mooooo`;o00001Oooool2ool003Oooooo0_oo000Cooooo`?o0000Koooool0027ooooo00?o
0000ooooooooool0Ooooool00ol0003oooooooooo`04ooooo`?oo`00A_ooool3o`0007;ooooo000Q
ooooo`03o`000?oooooooooo083ooooo0_l0000]ooooo`Coo`006Oooool3o`0007Gooooo000Qoooo
o`03o`000?oooooooooo08;ooooo0_l0000Wooooo`Coo`006_ooool3o`0007Sooooo000Qooooo`?o
0000Q?ooool2o`0000cooooo1_oo000;ooooo`Soo`006oooool3o`0007_ooooo000Qooooo`03o`00
0?oooooooooo08Kooooo0_l0000@ooooo`;oo`00:?ooool4o`0007kooooo000Qooooo`03o`000?oo
oooooooo08Sooooo0_l0000cooooo`Go0000P_ooool0027ooooo00?o0000ooooooooool0R_ooool2
o`0002gooooo1?l00027ooooo`008Oooool00ol0003oooooooooo`2<ooooo`?o00009_ooool4o`00
08_ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo08oooooo0ol0000Mooooo`Ko0000Soooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo09;ooooo1ol0000Aooooo`Go0000UOooool000Oooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0002Ioooooa7o0000V_ooool0
00Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000
ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o
0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooo
odGooooo000Jooooo`03o`000?oooooooooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00:Sooooo00?oMgMgofIVI_ooool05oooool0
0omVIVKoMgMgooooo`2Sooooo`00Qoooool3o`0001?ooooo00?o8B4QomgMgOooool01oooool00ooM
gMgo410@onk^kP0Hooooo`03onk^k_l@413ogMgM0:?ooooo001nooooo`07ohN7Qol0003oEEEEofIV
I_l0003o<S8bonk^kP03ooooo`03o`000?oooooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj
^P02ooooo`03oiRHV?mEEEGooooo00Oooooo00CoEEEEoiRHV?oooooooooo1Ol00009ooooo`03oeEE
EOnYZJWooooo00;ooooo00?o^[ZjodA4A?ooool00_ooool00on7QhOoIVIVooooo`0Cooooo`Co0000
00?o410@ooooooooool00_ooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c01kooooo`00
O_ooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00oooool00ol0003oooooooooo`0;oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0003ogMgMooooo`06ooooo`09o`000?oooooo
oooooooooonHV9So8B4Qonk^k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X3
ooooo`03onk^k_l0003ooooo00_ooooo1_l00004ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44
ooooo`05oa0@4?nj^[[oooooogMgMolb<S80Noooool007kooooo00Oo0000oooooooMgMgo<S8boooo
ooo^k^ko410@00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`;oMgMg
1oooool00olb<S;oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co410@omgMgOoooooo
00001Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0NOooool007kooooo00CoEEEEojVYZOoooooo00000_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?o0000ooooooooool01Oooool00oo^k^ko410@onk^kP06ooooo`03oc8b<_oooooooooo
00?ooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7QhOoIVIVooooool00005ooooo`03o`000?oooooo
oooo00[ooooo1_l00004ooooo`03o`000?oooooooooo00gooooo00?oZJVYoa0@4?ooool0N_ooool0
07kooooo00?ogMgMob4Q8Oo^k^h00oooool00ol0003oooooooooo`02o`0000gooooo00?o0000oooo
ooooool01_ooool00omEEEGoV9RHooooo`05ooooo`03o`000?o^k^kooooo00Cooooo00?oMgMgofIV
I_ooool02_ooool01?oMgMgo410@ooooool00004ooooo`03onk^k_l0003ooooo01Gooooo00?o0000
ooooooooool03?ooool00ol@413o0000okZj^P1kooooo`00Ooooool00onHV9SoMgMgooooo`02oooo
o`03o`000?oooooooooo00gooooo00?o410@o`000?l000000ol00005ooooo`03omgMgOl@413ooooo
00Gooooo00?oEEEEogMgMoooool01Oooool00ol0003oooooooooo`08ooooo`Oo00000_ooool00omg
MgOoEEEEooooo`0Eooooo`03o`000?oooooooooo00gooooo00?o^[Zjob4Q8Oooool0N_ooool009Ko
oooo00?o0000ooooooooool01oooool00omEEEGoV9RHooooo`04ooooo`09omgMgOl@413ok^k^oooo
ool0003o^[ZjoooooonHV9So410@01;ooooo00?ok^k^oa0@4?oMgMd05_ooool00ol0003ooooooooo
o`0:ooooo`05oa0@4?nHV9SooooookZj^_l00000Noooool009Kooooo00?o0000ooooooooool01ooo
ool00onj^[[oA4A4ooooo`05ooooo`08ogMgMomVIVKooooooiRHV?l@413o0000ob4Q8Oo<c<`Boooo
o`03ofIVI_mgMgOooooo01Cooooo00?oEEEEofIVI_l000003?ooool01OnYZJWo410@o`000?l@413o
ZJVY07_ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.35) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .2729 L
.06244 .23786 L
.08426 .20581 L
.0949 .19333 L
.10458 .18398 L
.11403 .17675 L
.12297 .17168 L
.12787 .16962 L
.1324 .16817 L
.13476 .16758 L
.13737 .16707 L
.13868 .16686 L
.14009 .16668 L
.14142 .16654 L
.14264 .16645 L
.14392 .16638 L
.14514 .16635 L
.14622 .16635 L
.1474 .16637 L
.14869 .16642 L
.14934 .16646 L
.15005 .16651 L
.15132 .16662 L
.15248 .16676 L
.15476 .16709 L
.15721 .16755 L
.16162 .16864 L
.16672 .17032 L
.17226 .1726 L
.18234 .1779 L
.20212 .19176 L
.22313 .2098 L
.26088 .24447 L
.28185 .2622 L
.30108 .27638 L
.32112 .28865 L
.33977 .29763 L
.35869 .30437 L
.3687 .30702 L
.37939 .30919 L
.38963 .31067 L
.39541 .31125 L
.39816 .31147 L
.40074 .31164 L
.40317 .31178 L
.4054 .31187 L
.40787 .31195 L
.40923 .31198 L
.41053 .31201 L
Mistroke
.41177 .31202 L
.41247 .31203 L
.4131 .31203 L
.41433 .31203 L
.41548 .31202 L
.41614 .31202 L
.41684 .31201 L
.41808 .31199 L
.41942 .31196 L
.42089 .31192 L
.42341 .31184 L
.42615 .31171 L
.43112 .31142 L
.43596 .31104 L
.44044 .31062 L
.46137 .30786 L
.48007 .3045 L
.50068 .30011 L
.54094 .29065 L
.57968 .28184 L
.59937 .27788 L
.62087 .27411 L
.64167 .27113 L
.66055 .26903 L
.67066 .26815 L
.6802 .26749 L
.69026 .26696 L
.69594 .26674 L
.69867 .26665 L
.70116 .26659 L
.70341 .26654 L
.70585 .26649 L
.70719 .26647 L
.70843 .26646 L
.7097 .26644 L
.71088 .26643 L
.71189 .26643 L
.71297 .26642 L
.71418 .26642 L
.71528 .26642 L
.71637 .26642 L
.71756 .26642 L
.7188 .26643 L
.71996 .26644 L
.72125 .26645 L
.72265 .26647 L
.72519 .26651 L
.72994 .26661 L
.73549 .26678 L
.74062 .26698 L
Mistroke
.75029 .26748 L
.75936 .26808 L
.77999 .26993 L
.80025 .27235 L
.81878 .27503 L
.85851 .28207 L
.89672 .29013 L
.93739 .29959 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .27247 L
.06244 .237 L
.08255 .20801 L
.09396 .19543 L
.10458 .18633 L
.10961 .1829 L
.11508 .17979 L
.11989 .17759 L
.125 .17577 L
.12959 .17458 L
.13221 .17408 L
.13346 .17389 L
.13466 .17373 L
.13573 .17362 L
.1369 .17351 L
.13796 .17344 L
.13895 .17339 L
.14012 .17335 L
.14119 .17334 L
.14242 .17335 L
.14357 .17338 L
.14473 .17344 L
.14598 .17352 L
.14823 .17374 L
.1509 .1741 L
.15334 .17452 L
.15863 .17575 L
.16365 .17727 L
.1725 .18071 L
.18212 .18544 L
.22291 .21286 L
.26217 .24277 L
.29992 .26786 L
.31927 .27805 L
.34013 .28664 L
.35051 .28996 L
.36017 .29248 L
.37024 .29453 L
.37553 .29538 L
.38127 .29613 L
.38674 .29668 L
.38914 .29687 L
.39179 .29705 L
.39411 .29717 L
.39661 .29728 L
.39799 .29732 L
.39925 .29735 L
.40052 .29738 L
.40172 .29739 L
Mistroke
.4029 .2974 L
.40396 .29741 L
.40518 .2974 L
.40634 .29739 L
.40741 .29738 L
.40839 .29736 L
.41062 .29731 L
.41287 .29723 L
.41533 .29711 L
.42031 .29681 L
.42557 .29637 L
.43054 .29586 L
.43986 .29466 L
.46079 .29093 L
.49917 .28146 L
.54 .26972 L
.57932 .25898 L
.61712 .25081 L
.63651 .24782 L
.6474 .24654 L
.65738 .24565 L
.66214 .24532 L
.66721 .24503 L
.672 .24482 L
.67411 .24475 L
.67634 .24469 L
.67761 .24466 L
.67901 .24463 L
.68029 .24461 L
.68146 .24459 L
.68212 .24459 L
.68284 .24458 L
.68361 .24457 L
.68433 .24457 L
.685 .24457 L
.68572 .24457 L
.687 .24457 L
.68819 .24458 L
.68947 .24459 L
.69067 .2446 L
.69178 .24462 L
.69435 .24467 L
.69706 .24474 L
.70205 .24492 L
.70659 .24514 L
.71677 .24583 L
.72621 .2467 L
.73513 .24771 L
.75512 .2506 L
.77357 .25393 L
Mistroke
.81294 .2627 L
.85079 .27247 L
.8911 .28362 L
.92989 .29495 L
.97114 .30751 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`0001oooooo2Ol0003ooooooago
oooo000Qooooo`03o`000?oooooooooo01cooooo0ol00009ooooo`Co0000oooooolIooooo`008Ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo0ooo0004ooooo`?o0000oooo
oolFooooo`008Oooool00ol0003oooooooooo`0Iooooo`;o00003Oooool4ool000?ooooo0_l0003o
oooooaCooooo000Qooooo`03o`000?oooooooooo01Sooooo00Co0000ool00?oo003oo`004?ooool2
ool000?ooooo00?o0000ooooooooool0oooooolAooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oo003ooooo01Cooooo00Goo`00ooooooooooooooooo`00003ooooooa;ooooo
0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
0oooool00ol0003oooooooooo`0Fooooo`;oo`005oooool2ool000;ooooo00?o0000ooooooooool0
ooooool?ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooo
ooooo`02ooooo`?o00005Oooool00ooo003oooooooooo`0Iooooo`04ool00?ooooooooooo`000?oo
oooo4?ooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?o
oooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`0Kooooo`03ool00?oooooooooo00;o
0000ooooool>ooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0
003o<S8bolc<c004ooooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool07Oooool01Ooo
003ooooooooooooooooo00000?oooooo3Oooool000Oooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oo`00ooooo`0S
ooooo`;o0000ooooool;ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo003ooooo02Kooooo00?o0000
ooooooooool0ooooool8ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005
ooooo`03o`000?oooooooooo013ooooo00?o0000ool00?ooool0:?ooool00ol0003oooooooooo`3o
ooooo`Oooooo000Qooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0:Oooool00ol0
003oooooooooo`3oooooo`Kooooo000Qooooo`03o`000?oooooooooo00oooooo00?oo`00oooooooo
ool0:oooool00ol0003oooooooooo`3oooooo`Gooooo000Qooooo`?o00003_ooool00ol0003ooooo
ooooo`0[ooooo`;oo`0000?o0000ooooooooool0ooooool4ooooo`008Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo02gooooo00?oo`00o`000?ooool0ooooool4ooooo`008Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02oooooo00?oo`00o`000?ooool0ooooool3
ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo037ooooo0_oo003ooooo
o`?ooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=?ooool00ooo003o
ooooooooo`3oooooo`008Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Gooooo
00?oo`00ooooooooool0o_ooool0027ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0gooooo`;oo`00o_ooool0027ooooo0ol00009ooooo`03o`000?oooooooooo03Wooooo00?o0000
ool00?ooool0o?ooool0027ooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`0joooo
o`03o`000?oo003ooooo0?_ooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ool00?oo
ool0??ooool00ol0003oo`00ool0001jooooo`_oo`00MOooool0027ooooo00?o0000ooooooooool0
2?ooool00ooo003oooooooooo`0nooooo`03o`000?oooooooooo07;ooooo1_oo000Dooooo`Soo`00
I?ooool0027ooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`10ooooo`03o`000?oo
oooooooo09?ooooo1_oo001Nooooo`008Oooool00ol0003oooooooooo`07ooooo`03ool00?oooooo
oooo047ooooo00?o0000ooooooooool0Hoooool3ool003;ooooo1?oo001Jooooo`008Oooool00ol0
003oooooooooo`06ooooo`03ool00?oooooooooo04?ooooo00?o0000ooooooooool0G_ooool4ool0
03Wooooo1Ooo001Eooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo003ooooo04Go
oooo00?o0000ooooooooool0FOooool4ool004;ooooo1?oo001Aooooo`008Oooool3o`0000Gooooo
00?oo`00ooooooooool0A_ooool2o`0000;ooooo00?oo`00ooooooooool0DOooool3ool004[ooooo
0_oo001?ooooo`008Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo03Kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01_m4A4Co0000o`000?lb<S;ogMgMool0
03cooooo1?l000000ol@413oooooooooo`0=ooooo`;oo`008ooooolLo`000003oc8b<_oMgMgooooo
03cooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo03Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool2o`000003oooooooo003oo`00
03cooooo00?o0000ooooooooool0;?ooool8o`0000_ooooo00?o0000ooooooooool01?ooool2ob4Q
8@Kooooo2ol0000fooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0027ooooo00?o0000oooo
ooooool00oooool00ooo003oooooooooo`0gooooo`05oa0@4?ooooooooooooooool@41004?ooool2
o`0000;ooooo0_oo000jooooo`03o`000?oooooooooo027ooooo2ol0000Cooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool01Oooool6o`0000[ooooo1Ooo000Rooooo`03oiRHV?lQ8B7o
k^k^01cooooo000Qooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0=oooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00_l00002ooooo`;oo`00>?ooool0
0ol0003oooooooooo`03ooooo`?oo`006?ooool3o`0001kooooo00?o0000ooooooooool03_ooool0
0omgMgOo<S8booooo`0<ooooo`Ko00002Oooool4ool001oooooo00?oV9RHob4Q8Oo^k^h06oooool0
027ooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0hooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00?ooooo00Co0000oooooooooooooooo
0ooo000eooooo`03o`000?ooooooo`0000?oo`005_ooool5o`00027ooooo00?o0000ooooooooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo1_l00007ooooo`Coo`007?ooool00omgMgOo
IVIVooooo`0Jooooo`008Oooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo03Sooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo0_l00004ooooo`?o
o`00<?ooool4ool001Gooooo1Ol0000Vooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool06oooool6o`0000Gooooo0_oo000Kooooo`03o`000?oooooooooo01Wooooo000Qooooo`?o0000
00?oooooool00?ooool0>_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo02Wooooo1?oo0002ooooo`03
o`000?oooooooooo013ooooo1?l0000[ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool08Oooool6o`000003oooooooo003ooooo01Gooooo00Go0000okZj^_ooooooV9RHoa0@400Koooo
o`008Oooool01Ol0003ooooooooooooooooo000003_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co00002?ooool2o`0002kooooo0_oo0004ooooo`03oeEEEOmVIVKo000000kooooo1?l0000]
ooooo`03oeEEEOmVIVKo000000gooooo1?l0000Vooooo`Go00004oooool01OnHV9So410@o`000?lQ
8B7oc<c<01_ooooo000Qooooo`04o`000?ooooooooooo`0005_ooooo0_l0000oooooo`Co0000L?oo
ool5o`0002kooooo000Qooooo`03o`000?oooooo000005kooooo0_l0000;ooooo`Coo`002oooool7
ool001Oooooo1Ol0001iooooo`;o00000ooo000Yooooo`008Oooool00ol0003oooooo`00001Poooo
o`?o00003?ooool;ool001[ooooo1?l00022ooooo`04o`000?oo003oo`00ool002Kooooo000Qoooo
o`;o0000I?ooool3o`0002Wooooo1Ol0002:ooooo`?oo`0000?o0000ooooooooool05_ooool2o`00
00;ooooo0_l00004ooooo`008Oooool2o`0006Oooooo0ol0000Pooooo`Ko0000T_ooool3ool000;o
00005?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooooooo0000;ol00004ool0
00Oo00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Oooooo5Ol0000>ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool04Oooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool01?lQ8B7oMgMgogMgMolb<S85
ooooo`008Oooool00ol0003oooooooooo`3ooooooc_ooooo0_l00002ooooo`;o00001?ooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04oooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0003ooooo
odGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03oooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`3oooooodGooooo0007oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo1?l000000ol@413oooooooooo`02
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Tooooo`03ogMgMomVIVKooooo
01Oooooo00?oIVIVogMgMoooool0Yoooool008?ooooo0ol0000Dooooo`03ob4Q8OoMgMgooooo00Ko
oooo00?ogMgMoa0@4?o^k^h06?ooool00oo^k^ko410@omgMg@2Wooooo`00Noooool01on7QhOo0000
oeEEEOmVIVKo0000oc8b<_o^k^h00_ooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o0000
odA4A?nj^[X00oooool00onHV9SoEEEEooooo`06ooooo`03oeEEEOnHV9Sooooo00;ooooo1Ol00009
ooooo`03oeEEEOnYZJWooooo00;ooooo00Ko^[ZjodA4A?ooooooooooohN7QomVIVHEooooo`Co0000
00?o410@ooooooooool00_ooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd0MOooool007_ooooo00Oo410@omgMgOmgMgOo8B4Qoooooon7QhOo
IVIV00;ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o
0000omgMgOooool01Oooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
2_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P;ooooo00?ok^k^o`000?ooool02oooool6o`00
00Gooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P07
ooooo`03ogMgMolb<S;ooooo07Cooooo001kooooo`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@
4002ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool2ogMgM`Kooooo00?o
<S8booooooooool00oooool00onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`0000Cooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0Loooool007_ooooo00CoEEEEojVYZOoooooo00000_ooool01?l0003ooooo
ooooool0000=ooooo`03o`000?oooooooooo00Kooooo00?ok^k^oa0@4?o^k^h01Oooool00olb<S;o
ooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001?ooool00ol0
003oooooooooo`0:ooooo`Ko00001Oooool00ol0003oooooooooo`0=ooooo`03ojVYZOl@413ooooo
00Kooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00?ogMgMob4Q8Oo^k^h00oooool01?l0003o
ooooo`000?l0000=ooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool00ol0
003ok^k^ooooo`05ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo00000oooool0
0oo^k^ko0000ooooo`0Fooooo`03o`000?oooooooooo00cooooo00?o410@o`000?nj^[X01?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<07Gooooo001looooo`03oiRHV?mgMgOooooo00;ooooo00?o0000
ooooooooool03?ooool00ol@413o0000o`000003o`0000Kooooo00?ogMgMoa0@4?ooool01?ooool0
0omEEEGoMgMgooooo`06ooooo`03o`000?oooooooooo00Sooooo1ol000000oooooooMgMgoeEEE@0G
ooooo`03o`000?oooooooooo00gooooo00?o^[Zjob4Q8Oooool00oooool00ol0003oooooooooo`1g
ooooo`00T_ooool00ol0003oooooooooo`08ooooo`03oeEEEOnHV9Sooooo00?ooooo00?ogMgMoa0@
4?o^k^h00_ooool01Ol0003o^[ZjoooooonHV9So410@017ooooo00?ok^k^oa0@4?oMgMd05oooool0
0ol0003oooooooooo`0:ooooo`05oa0@4?nHV9SooooookZj^_l000001?ooool00ol0003ooooooooo
o`1gooooo`00T_ooool00ol0003oooooooooo`08ooooo`03okZj^_m4A4Cooooo00Cooooo00WoMgMg
ofIVI_oooooooooooiRHV?l@413o0000ob4Q8Oo<c<`04Oooool00omVIVKoMgMgooooo`0Eooooo`03
oeEEEOmVIVKo000000cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@04ooooo`Co0000M_ooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .2992 L
.06244 .2907 L
.06747 .28902 L
.07286 .28747 L
.07751 .28635 L
.08255 .28536 L
.08564 .28488 L
.08848 .28452 L
.0912 .28424 L
.09259 .28412 L
.09409 .28402 L
.09543 .28394 L
.09666 .28389 L
.0979 .28385 L
.09908 .28382 L
.09974 .28381 L
.10044 .28381 L
.10171 .2838 L
.10248 .28381 L
.10321 .28382 L
.10387 .28384 L
.10458 .28385 L
.10582 .2839 L
.10695 .28395 L
.1095 .28409 L
.11185 .28427 L
.11409 .28448 L
.11908 .28507 L
.12452 .28588 L
.14558 .29021 L
.16497 .29472 L
.17526 .29687 L
.18067 .29785 L
.18637 .29876 L
.19141 .29943 L
.19693 .30001 L
.19936 .30021 L
.20195 .30038 L
.2044 .30051 L
.20662 .3006 L
.2078 .30063 L
.20906 .30065 L
.21013 .30067 L
.21131 .30068 L
.21258 .30067 L
.21329 .30067 L
.21394 .30066 L
.2152 .30063 L
.2164 .3006 L
Mistroke
.21869 .30051 L
.22082 .3004 L
.22315 .30025 L
.22563 .30004 L
.23101 .29946 L
.23594 .29875 L
.24708 .2966 L
.2569 .29406 L
.26727 .29078 L
.30529 .27423 L
.34577 .25127 L
.38473 .22714 L
.42614 .20245 L
.46604 .18192 L
.50442 .16653 L
.52423 .16048 L
.53436 .15791 L
.54525 .15554 L
.55544 .15369 L
.56476 .15232 L
.57368 .15128 L
.58306 .15049 L
.58807 .15019 L
.59263 .14999 L
.59515 .14992 L
.59648 .14988 L
.59788 .14985 L
.59911 .14983 L
.59976 .14983 L
.60046 .14982 L
.60169 .14981 L
.60284 .14981 L
.60406 .14981 L
.6052 .14981 L
.60645 .14982 L
.60708 .14983 L
.60777 .14984 L
.61018 .14989 L
.61245 .14995 L
.61667 .1501 L
.62122 .15034 L
.62617 .15067 L
.63077 .15105 L
.64123 .15217 L
.65143 .15358 L
.66233 .15544 L
.68365 .16008 L
.70379 .16562 L
.74222 .17899 L
.78311 .19671 L
Mistroke
.82248 .21655 L
.86034 .23763 L
.90064 .26165 L
.93944 .28575 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .30282 L
.06244 .29659 L
.06747 .29535 L
.07286 .29422 L
.07751 .29342 L
.08255 .29274 L
.08564 .29242 L
.08848 .2922 L
.0912 .29203 L
.09258 .29197 L
.09335 .29195 L
.09409 .29192 L
.09474 .29191 L
.09545 .29189 L
.0967 .29187 L
.0974 .29187 L
.09815 .29187 L
.09886 .29187 L
.0995 .29188 L
.10076 .29189 L
.10147 .29191 L
.10212 .29192 L
.10338 .29196 L
.10458 .29201 L
.10704 .29214 L
.10928 .29228 L
.11432 .29271 L
.1234 .2938 L
.14407 .29727 L
.16229 .30065 L
.17266 .30236 L
.17774 .30308 L
.1824 .30366 L
.18694 .30414 L
.19191 .30456 L
.1945 .30473 L
.19691 .30485 L
.19945 .30495 L
.20088 .30499 L
.20217 .30501 L
.20348 .30503 L
.20414 .30503 L
.20487 .30503 L
.20615 .30503 L
.20736 .30501 L
.20808 .305 L
.20877 .30499 L
.21007 .30495 L
.21146 .3049 L
Mistroke
.21298 .30483 L
.21554 .30468 L
.21827 .30447 L
.22318 .30398 L
.22855 .30325 L
.23349 .3024 L
.24463 .29987 L
.25445 .29693 L
.26481 .29312 L
.30284 .27354 L
.34331 .24574 L
.38227 .21646 L
.42369 .1871 L
.46359 .16373 L
.50197 .14739 L
.52178 .14146 L
.5319 .13907 L
.5428 .13696 L
.55299 .13542 L
.56231 .13436 L
.57123 .13364 L
.57571 .13338 L
.57826 .13327 L
.5806 .13319 L
.58315 .13312 L
.58449 .13309 L
.58591 .13306 L
.58714 .13305 L
.58829 .13304 L
.58955 .13303 L
.59026 .13303 L
.59091 .13303 L
.5921 .13304 L
.5932 .13305 L
.59442 .13306 L
.5957 .13308 L
.59787 .13313 L
.60025 .13319 L
.60545 .1334 L
.61106 .13371 L
.62122 .13452 L
.63077 .13554 L
.64123 .13695 L
.66233 .14065 L
.68191 .14509 L
.70285 .15086 L
.74432 .16543 L
.78427 .18339 L
.8227 .20419 L
.86359 .22958 L
Mistroke
.90296 .25632 L
.94082 .28324 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`2[ooooo`;oo`00Uoooool0027ooooo00?o0000ooooooooool0XOooool:ool000co
oooo1ooo0026ooooo`008Oooool00ol0003oooooooooo`2Looooo`Goo`007Oooool5ool0087ooooo
000Qooooo`?o0000`oooool4ool007gooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0TOooool2ool00;7ooooo000Qooooo`03o`000?oooooooooo08oo
oooo0_oo000Doooooaco00004?ooool2ool0077ooooo000Qooooo`03o`000?oooooooooo08cooooo
0ooo000@ooooo`Ko00007?ooool7o`0000_ooooo0ooo001^ooooo`008Oooool00ol0003ooooooooo
o`2:ooooo`;oo`004?ooool3o`0002Wooooo0ol0000;ooooo`?oo`00Joooool0027ooooo00?o0000
ooooooooool0R?ooool2ool000kooooo1?l0000_ooooo`?o00002oooool2ool006Wooooo000Qoooo
o`03o`000?oooooooooo08Kooooo0_oo000=ooooo`?o0000=_ooool3o`0000[ooooo0ooo001Voooo
o`008Oooool3o`0008Gooooo00?oo`00ooooooooool02_ooool3o`0003cooooo1?l00009ooooo`;o
o`00I?ooool0027ooooo00?o0000ooooooooool0Q?ooool00ooo003oooooooooo`08ooooo`?o0000
@oooool3o`0006cooooo000Qooooo`03o`000?oooooooooo08gooooo0_l00019ooooo`?o0000JOoo
ool0027ooooo00?o0000ooooooooool0Roooool2o`0004kooooo0ol0001Vooooo`008Oooool00ol0
003oooooooooo`28ooooo`?o0000Doooool2o`0000Wooooo0_oo001Iooooo`001oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool0
0ol0003oooooooooo`26ooooo`;o0000F?ooool3o`0000Sooooo0_oo001Gooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000
ooooooooool0NOooool2ool000Wooooo0_l0001Mooooo`;o00002?ooool2ool005Gooooo0005o`00
00;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0001h
ooooo`03ool00?oooooooooo00Oooooo0_l0001Qooooo`;o00002?ooool00ooo003oooooooooo`1B
ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool0
0ol0003oooooooooo`1fooooo`;oo`002?ooool2o`0006Gooooo0ol00006ooooo`;oo`00D_ooool0
00Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?oo
ool00ol0003oooooooooo`1eooooo`03ool00?oooooooooo00Kooooo0_l0001Zooooo`;o00001_oo
ool2ool0053ooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo07?ooooo0_oo0007ooooo`;o0000K_ooool2o`0000Kooooo00?o
o`00ooooooooool0COooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0L_ooool00ooo003oooooooooo`05ooooo`;o0000L_oo
ool2o`0000Gooooo0_oo001=ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
0005ooooo`03o`000?oooooooooo077ooooo00?oo`00ooooooooool01Oooool00ol0003ooooooooo
o`1dooooo`?o00001?ooool00ooo003oooooooooo`1:ooooo`008Oooool00ol0003oooooooooo`1_
ooooo`;oo`001_ooool2o`0007[ooooo0_l0001?ooooo`008Oooool00ol0003oooooooooo`1^oooo
o`03ool00?oooooooooo00Cooooo0_l0001nooooo`;o0000COooool0027ooooo0ol0001]ooooo`03
ool00?oooooooooo00Cooooo00?o0000ooooooooool0P?ooool2o`0004_ooooo000Qooooo`03o`00
0?oooooooooo07;ooooo0_l00025ooooo`;o0000BOooool0027ooooo00?o0000ooooooooool0L?oo
ool2o`0008Wooooo00?o0000ooooooooool0A_ooool0027ooooo00?o0000ooooooooool0Koooool0
0ol0003oooooooooo`2:ooooo`;o00000_ooool2ool004;ooooo000Qooooo`03o`000?oooooooooo
06gooooo0_l0002?ooooo`;o00000_ooool2ool0043ooooo000Qooooo`03o`000?oooooooooo06_o
oooo0_l0002Cooooo`05o`000?oooooooooooooooooo0000?oooool0027ooooo00?o0000oooooooo
ool0J_ooool00ol0003oooooooooo`2Dooooo`;o0000@Oooool0027ooooo0ol0001Tooooo`;oo`00
0_ooool2o`0009Wooooo0_l0000oooooo`008Oooool00ol0003oooooooooo`1Sooooo`03ool00?oo
oooooooo00;o0000WOooool00ol0003oooooooooo`0looooo`008Oooool00ol0003oooooooooo`1R
ooooo`04ool00?ooooooooooo`000:3ooooo0_l00002ooooo`;oo`00>?ooool0027ooooo00?o0000
ooooooooool0H?ooool2ool00003ooooool0003o00000:?ooooo00Go0000ooooooooooooooooool0
000gooooo`008Oooool00ol0003oooooooooo`1Oooooo`04ool00?oooooo0000o`000:Kooooo0_l0
0002ooooo`;oo`00=Oooool0027ooooo00?o0000ooooooooool0GOooool2ool000;o0000Z_ooool0
1Ol0003oooooooooooooooooo`0003Cooooo000Qooooo`03o`000?oooooooooo05cooooo00?oo`00
o`000?l00000[Oooool2o`0000;ooooo0_oo000booooo`008Oooool00ol0003oooooooooo`1Joooo
o`;oo`0000?o0000ooooooooool0[oooool01Ol0003oooooooooooooooooo`00037ooooo000Qoooo
o`?o0000FOooool00ooo003o0000ooooo`2cooooo`;o00000_ooool2ool002oooooo000Qooooo`03
o`000?oooooooooo03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?oo`00o`000?ooool0=Oooool4o`000003oa0@4?oooooo
oooo03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM02[ooooo0_l00002ooooo`03ool00?oooooooooo00cooooo1Ol0000Kooooo`008Oooool0
0ol0003oooooooooo`0mooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool00_ooool2o`0003[ooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0[ooooo`04o`000?ooooooooooool000gooooo
00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@
4?ooooooooooooooool@41004?ooool01?l0003oooooo`000?l0000looooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0[ooooo`;o000000?oooooool0
0?ooool03?ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003oooooooooo`0mooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo0000o`00000nooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0^ooooo`;o00003_ooool00onH
V9So8B4Qonk^kP0Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?l0003oc<c<03oooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0<Oooool00ol0003ooooooooo
o`0<ooooo`03ogMgMomVIVKooooo01[ooooo000Qooooo`03o`000?oooooooooo01Gooooo0_l0000V
ooooo`05oa0@4?ooooooooooooooool@41002oooool2ool00003o`000?oooooooooo043ooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Cooooo0_l0
000=ooooo`03o`000?oooooooooo01Wooooo000Qooooo`?o00003_ooool8o`000003ooooool0003o
000000So00007?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo0_oo0002o`0004?ooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Kooooo0_l0
0007ooooo`05o`000?nj^[[ooooooiRHV?l@41006oooool0027ooooo00?o0000ooooooooool02_oo
ool4o`0001?ooooo1Ol0000Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool01?oo003o0000
ooooooooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omEEEGoIVIVo`00000=ooooo`Co
0000=oooool2o`0000Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Kooooo`008Oooool00ol0003o
ooooooooo`08ooooo`;o00001oooool<ool000Wooooo0ol0000Oooooo`;oo`00eOooool00ol0003o
o`00ool0000Rooooo`008Oooool00ol0003oooooooooo`05ooooo`?o00005Oooool4ool000Sooooo
0ol0000Fooooo`Co00000_oo003Hooooo`;o000000?oo`00ooooooooool07oooool0027ooooo00?o
0000ooooooooool00_ooool3o`0002Oooooo1ol0000:ooooo`Go00000_ooool2ool00=cooooo00?o
0000ool00?oo00007oooool0027ooooo00?o0000ooooooooool00_l00005ool002Cooooo0_oo0006
ooooo`[o00000oooool4ool00>3ooooo00?o0000ool00?ooool04oooool2o`0000;ooooo0_l00004
ooooo`008Oooool2o`0000?oo`00:oooool<ool00>cooooo00?o0000ool00?ooool04_ooool01_o^
k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Jooooo`Oo00000_oo003oo`0002Wo000000?oo`00
o`000?l000001Ol0000<ooooo`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`04onk^k_lQ8B7o
410@onk^kPGooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Aooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03o`000?oooooo
oooo0?oooooo>oooool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0oooooom5
ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo
410@013ooooo00?o0000ooooooooool00_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooooom5
ooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooo
oom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool0
01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03
o`000?oooooooooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
ooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00:Sooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2S
ooooo`00Qoooool3o`0001?ooooo00?o8B4QomgMgOooool01oooool00ooMgMgo410@onk^kP0Hoooo
o`03onk^k_l@413ogMgM0:?ooooo001nooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP03
ooooo`03o`000?oooooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P02ooooo`03oiRHV?mE
EEGooooo00Oooooo00CoEEEEoiRHV?oooooooooo1Ol00009ooooo`03oeEEEOnYZJWooooo00;ooooo
00?o^[ZjodA4A?ooool00_ooool00on7QhOoIVIVooooo`0Cooooo`Co000000?o410@ooooooooool0
0_ooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`1iooooo`00O_ooool01ol@413ogMgMogMg
MolQ8B7oooooohN7QomVIVH00oooool00ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMg
Mol@41000oooool00ol0003ogMgMooooo`06ooooo`09o`000?oooooooooooooooonHV9So8B4Qonk^
k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X3ooooo`03onk^k_l0003ooooo
00_ooooo1_l00004ooooo`03o`000?oooooooooo00Cooooo0_lQ8B47ooooo`03o`000?oooooooooo
07[ooooo001nooooo`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@4003ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01Oooool2ogMgM`Oooooo00?o<S8booooooooool00_ooool0
0onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`0000Gooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0:ooooo`Go0000Noooool007kooooo00CoEEEEojVYZOoooooo00000_oo
ool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool01Oooool00oo^k^ko410@
onk^kP06ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7QhOoIVIV
ooooool00005ooooo`03o`000?oooooooooo00[ooooo1_l00004ooooo`03o`000?oooooooooo00[o
oooo00CoA4A4omgMgOoooooo0000O?ooool007kooooo00?ogMgMob4Q8Oo^k^h00oooool00ol0003o
ooooooooo`02o`0000gooooo00?o0000ooooooooool01_ooool00omEEEGoV9RHooooo`05ooooo`03
o`000?o^k^kooooo00Cooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgo410@ooooool00004oooo
o`03onk^k_l0003ooooo01Gooooo00?o0000ooooooooool02_ooool01?oMgMgoEEEEooooool0001l
ooooo`00Ooooool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo00gooooo00?o410@o`00
0?l000000ol00005ooooo`03omgMgOl@413ooooo00Gooooo00?oEEEEogMgMoooool01Oooool00ol0
003oooooooooo`08ooooo`Oo00000_ooool00omgMgOoEEEEooooo`0Eooooo`03o`000?oooooooooo
00_ooooo00?oMgMgolc<c?l00000O?ooool009Kooooo00?o0000ooooooooool01oooool00omEEEGo
V9RHooooo`04ooooo`09omgMgOl@413ok^k^ooooool0003o^[ZjoooooonHV9So410@01;ooooo00?o
k^k^oa0@4?oMgMd05_ooool00ol0003oooooooooo`0;ooooo`03onk^k_m4A4Co000007cooooo002F
ooooo`03o`000?oooooooooo00Oooooo00?o^[ZjodA4A?ooool01Oooool02?mgMgOoIVIVoooooonH
V9So410@o`000?lQ8B7oc<c<4_ooool00omVIVKoMgMgooooo`0Dooooo`03oeEEEOmVIVKo000000ko
oooo00?oMgMgo`000?ooool0Noooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.45) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .33801 L
.06244 .36625 L
.08426 .39201 L
.0949 .40185 L
.10458 .40899 L
.10911 .41171 L
.11403 .41421 L
.11828 .41597 L
.12297 .41749 L
.12553 .41813 L
.12793 .41861 L
.13047 .41899 L
.13189 .41915 L
.13319 .41926 L
.13439 .41933 L
.13551 .41937 L
.13673 .41939 L
.13803 .41937 L
.13928 .41932 L
.14045 .41925 L
.1415 .41916 L
.14264 .41905 L
.14501 .41872 L
.14755 .41825 L
.15214 .4171 L
.1576 .41523 L
.16257 .41307 L
.17339 .40696 L
.18364 .39951 L
.22197 .36041 L
.26275 .30668 L
.30202 .25136 L
.33977 .20064 L
.37997 .15341 L
.41866 .11673 L
.43831 .10168 L
.4598 .08802 L
.48033 .07767 L
.49942 .07035 L
.50995 .06725 L
.51988 .0649 L
.5288 .06327 L
.53379 .06255 L
.53847 .062 L
.54303 .06158 L
.54793 .06124 L
.55072 .06111 L
.5521 .06106 L
.55337 .06102 L
Mistroke
.55452 .06099 L
.55575 .06096 L
.55645 .06096 L
.55711 .06095 L
.55834 .06094 L
.55957 .06094 L
.56026 .06095 L
.56091 .06095 L
.56222 .06097 L
.56295 .06098 L
.56362 .061 L
.5661 .06107 L
.56846 .06117 L
.57118 .06132 L
.5737 .06149 L
.57939 .06198 L
.58904 .06315 L
.59809 .06462 L
.61871 .06928 L
.63893 .07546 L
.65744 .08241 L
.69712 .10093 L
.73528 .12273 L
.77589 .14938 L
.81499 .17768 L
.85654 .20988 L
.89658 .24235 L
.93509 .2744 L
.97607 .30891 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .34081 L
.06244 .37178 L
.08255 .3972 L
.09396 .40818 L
.09905 .41222 L
.10458 .41598 L
.11004 .41906 L
.11508 .42133 L
.11989 .42301 L
.12232 .42367 L
.125 .42425 L
.12741 .42465 L
.12962 .42492 L
.13084 .42502 L
.13153 .42506 L
.13217 .42509 L
.13334 .42513 L
.13459 .42514 L
.13575 .42513 L
.13701 .42508 L
.1382 .425 L
.1393 .42491 L
.14138 .42466 L
.14357 .42432 L
.14612 .4238 L
.14853 .4232 L
.15305 .42179 L
.16321 .4173 L
.17199 .41206 L
.18154 .40502 L
.22233 .36247 L
.26159 .30927 L
.29934 .25431 L
.33955 .19786 L
.37823 .14972 L
.41937 .10801 L
.4399 .09132 L
.459 .07836 L
.4786 .06762 L
.49711 .05984 L
.50692 .05663 L
.51756 .05383 L
.52724 .0519 L
.53615 .05062 L
.54083 .05013 L
.5434 .04992 L
.54585 .04975 L
.54811 .04963 L
.54931 .04958 L
Mistroke
.55058 .04953 L
.55176 .04949 L
.55283 .04947 L
.55391 .04945 L
.55492 .04944 L
.55612 .04943 L
.55743 .04943 L
.55809 .04943 L
.5588 .04944 L
.56009 .04946 L
.56136 .04949 L
.56257 .04952 L
.56484 .04961 L
.56751 .04974 L
.56997 .0499 L
.57555 .05038 L
.5802 .0509 L
.58521 .05157 L
.59426 .05311 L
.61487 .05801 L
.63495 .0645 L
.65607 .07296 L
.69423 .09184 L
.73484 .11603 L
.77394 .14238 L
.81549 .173 L
.85552 .20465 L
.89404 .23679 L
.93501 .27241 L
.97447 .30748 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000X?ooool2
ool000Gooooo0ooo002Jooooo`008Oooool00ol0003oooooooooo`2Jooooo`Koo`002_ooool9ool0
097ooooo000Qooooo`03o`000?oooooooooo09Kooooo1?oo000Iooooo`?oo`00S_ooool0027ooooo
00?o0000ooooooooool0Toooool3ool0023ooooo0_oo002<ooooo`008Oooool00ol0003ooooooooo
o`2Loooooa;o0000U_ooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooo
oooo09Oooooo1Ol0000Booooo`Ko0000T?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`2Dooooo`?o00007Oooool3o`0008gooooo000?ooooo`Ko00001Oooool00ol0003o
ooooooooo`04ooooo`?o0000R?ooool2ool000Oooooo0ol0000Sooooo`Co00001_ooool2ool0087o
oooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Q_ooool2ool000Kooooo
0ol0000Zooooo`Co00001?ooool2ool007oooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0Q?ooool2ool000Gooooo0ol0000aooooo`;o00001?ooool2ool007gooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Poooool00ooo003oooooooooo`03
ooooo`;o0000=_ooool2o`0000Cooooo0_oo001kooooo`006_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo087ooooo0_oo0004ooooo`;o0000>_ooool2o`0000Cooooo0_oo001ioooo
o`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo083ooooo00?oo`00oooooooo
ool00_ooool2o`0003kooooo0ol00003ooooo`;oo`00Moooool0027ooooo00?o0000ooooooooool0
Ooooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo047ooooo0ol00002ooooo`;oo`00
MOooool0027ooooo00?o0000ooooooooool0O_ooool01?oo003oooooooooooooool2o`0004Oooooo
0_l00002ooooo`03ool00?oooooooooo07;ooooo000Qooooo`?o0000OOooool01Ooo003ooooooooo
oooooooo000004_ooooo0ol0001dooooo`008Oooool00ol0003oooooooooo`1looooo`05ool00?oo
ooooooooooooool00000Coooool2o`0007;ooooo000Qooooo`03o`000?oooooooooo07kooooo0_l0
001Booooo`;o0000L?ooool0027ooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo06gooooo000Qooooo`03o`000?oooooooooo07_ooooo0_l0001Hoooo
o`;o000000?oooooool00?oo0000J_ooool0027ooooo00?o0000ooooooooool0N_ooool00ol0003o
ooooooooo`1Jooooo`;o000000?oooooool00?ooool0J?ooool0027ooooo00?o0000ooooooooool0
NOooool00ol0003oooooooooo`1Mooooo`04o`000?ooooooo`00ool006Oooooo000Qooooo`?o0000
N?ooool00ol0003oooooooooo`1Oooooo`;o000000?oooooool00?ooool0IOooool0027ooooo00?o
0000ooooooooool0M?ooool01?oo003oooooooooool0001Tooooo`;o00000_oo001Tooooo`008Ooo
ool00ol0003oooooooooo`1dooooo`03ool00?oooooo000006Oooooo00?o0000oooooooo0000Hooo
ool0027ooooo00?o0000ooooooooool0Loooool00ooo003oooooo`00001Yooooo`03o`000?oooooo
o`0006;ooooo000Qooooo`03o`000?oooooooooo07;ooooo00?oo`00ooooool00000Joooool2o`00
00;oo`00H?ooool0027ooooo00?o0000ooooooooool0LOooool00ooo003oooooo`00001^ooooo`03
o`000?ooooooo`0005oooooo000Qooooo`03o`000?oooooooooo073ooooo00?oo`00ooooool00000
L?ooool00ol0003oooooool0001Nooooo`008Oooool3o`0006oooooo00?oo`00ooooool00000L_oo
ool2o`0005kooooo000Qooooo`03o`000?oooooooooo06kooooo00?oo`00ooooool00000MOooool0
0ol0003oooooooooo`1Kooooo`008Oooool00ol0003oooooooooo`1]ooooo`03ool00?oooooo0000
07Oooooo00?o0000ooooooooool0F_ooool0027ooooo00?o0000ooooooooool0K?ooool00ooo003o
ooooo`00001iooooo`;o0000F_ooool0027ooooo00?o0000ooooooooool0K?ooool00ooo003o0000
ooooo`1kooooo`03o`000?oooooooooo05Oooooo000Qooooo`03o`000?oooooooooo06_ooooo00?o
o`00ooooool00000OOooool2o`000003oooooooo003oo`0005Cooooo000Qooooo`03o`000?oooooo
oooo06[ooooo00?oo`00ooooool00000P?ooool01?l0003ooooooooooooo001Cooooo`008Oooool0
0ol0003oooooooooo`1[ooooo`03o`000?oooooooooo083ooooo0_l000000oooooooo`00ool0001A
ooooo`008Oooool3o`0006[ooooo00?o0000ooooooooool0Poooool01?l0003ooooooooooooo001@
ooooo`008Oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo08Gooooo0_l000000ooo
ooooo`00ooooo`1>ooooo`008Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo08So
oooo00Co0000oooooooo003oo`00COooool0027ooooo00?o0000ooooooooool0Ioooool00ol0003o
ooooooooo`2:ooooo`;o000000?oooooool00?ooool0Boooool0027ooooo00?o0000ooooooooool0
I_ooool00ol0003oooooooooo`2=ooooo`03o`000?ooooooo`0004_ooooo0007ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03
o`000?oooooooooo06Kooooo00?o0000ooooooooool0S_ooool00ol0003oooooool0001:ooooo`00
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?o
oooo00?o0000ooooooooool0Hoooool00ooo003oooooo`00002Booooo`;o000000?oo`00oooooooo
ool0Aoooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooooooo
ool00_ooool3o`0006?ooooo00?oo`00o`000?ooool0U?ooool00ol0003oo`00ooooo`17ooooo`00
1oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003o
ooooooooo`1Rooooo`03ool00?l0003ooooo09Kooooo00?o0000ooooooooool0A_ooool000Oooooo
00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0
003oooooooooo`1Qooooo`03ool00?l0003ooooo09Sooooo00?o0000ooooooooool0AOooool000Oo
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0H?ooool00ooo003o0000ooooo`2Jooooo`;o0000AOooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0H?ooool00ooo
003oooooooooo`2Looooo`03o`000?oooooooooo04;ooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0Goooool00ooo003o0000ooooo`2Noooo
o`03o`000?oooooooooo047ooooo000Qooooo`03o`000?oooooooooo05kooooo00?oo`00o`000?oo
ool0X?ooool2o`00047ooooo000Qooooo`03o`000?oooooooooo05gooooo00?oo`00o`000?ooool0
Xoooool2ool003oooooo000Qooooo`?o0000G?ooool00ooo003o0000ooooo`2Uooooo`03o`000?oo
003ooooo03gooooo000Qooooo`03o`000?oooooooooo05cooooo00?oo`00ooooooooool0Y_ooool0
0ol0003oo`00ooooo`0looooo`008Oooool00ol0003oooooooooo`1Kooooo`03ool00?l0003ooooo
0:Sooooo00?o0000ool00?ooool0>oooool0027ooooo00?o0000ooooooooool0F_ooool00ooo003o
0000ooooo`2Zooooo`03o`000?oo003oo`0003[ooooo000Qooooo`03o`000?oooooooooo05Wooooo
00?oo`00o`000?ooool0[Oooool00ol0003oo`00ooooo`0hooooo`008Oooool00ol0003ooooooooo
o`1Iooooo`03o`000?oooooooooo0:kooooo00?o0000ool00?ooool0=oooool0027ooooo00?o0000
ooooooooool0F?ooool00ol0003oooooooooo`2`ooooo`03o`000?oo003ooooo03Kooooo000Qoooo
o`?o0000F?ooool00ol0003oooooooooo`2aooooo`03o`000?oo003ooooo03Gooooo000Qooooo`03
o`000?oooooooooo05Oooooo00?o0000ooooooooool0/oooool00ol0003oo`00ooooo`0dooooo`00
8Oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo0;Gooooo00?o0000ool00?ooool0
<oooool0027ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`2hooooo`03o`000?oo
oooooooo037ooooo000Qooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`0`ooooo`008Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo
0;_ooooo00?o0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool0Doooool00ooo003o
ooooooooo`2mooooo`03o`000?oooooooooo02kooooo000Qooooo`03o`000?oooooooooo05;ooooo
00?o0000ool00?ooool0_oooool2o`0002kooooo000Qooooo`?o0000D_ooool00ooo003ooooooooo
o`31ooooo`03o`000?oooooooooo02_ooooo000Qooooo`03o`000?oooooooooo03gooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?oo003ogMgM03gooooo
1?l000000ol@413oooooooooo`0kooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@0`ooooo`;oo`002oooool5o`0001_ooooo000Qooooo`03o`00
0?oooooooooo03gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003o
o`00oc8b<P0oooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01?ooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool0<?ooool00ol0003oo`00ooooo`09ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@06oooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo410@
00kooooo00?oo`00ooooool00000?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0<?ooool00ol0003oo`00ool00009ooooo`03oiRHV?lQ8B7ok^k^
01cooooo000Qooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000=oooo
o`04ool00?ooooooMgMgoc8b<Soooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>
ooooo`03ogMgMolb<S;ooooo03;ooooo0_l000000ooo003oooooooooo`07ooooo`03oiRHV?lQ8B7o
k^k^01_ooooo000Qooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000<
ooooo`05ool00?lQ8B7o0000oc8b<_o<c<`0?oooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00eooooo`03o`000?oo003ooooo00Sooooo
00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oo`00ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0>?ooool00ol0003oo`00ooooo`08ooooo`03o`00
0?oooooooooo01Wooooo000Qooooo`?o0000?Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00?oo`00o`000?ooool0@_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0>Oooool00ol0003oo`00ooooo`03ooooo`05o`000?nj^[[ooooooiRHV?l@
41006oooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[o
oooo00?oo`00ooooool000000ol0000nooooo`03oeEEEOmVIVKo000003oooooo00?oEEEEofIVI_l0
00003Oooool4o`0003[ooooo00Woo`00oooooooooooooooooiRHV?l@413o0000ob4Q8Oo<c<`06ooo
ool0027ooooo00?o0000ooooooooool0C?ooool00ooo003oooooooooo`3Booooo`03ool00?oooooo
oooo023ooooo000Qooooo`03o`000?oooooooooo04_ooooo00?oo`00ooooooooool0e?ooool00ooo
003oooooooooo`0Oooooo`008Oooool00ol0003oooooooooo`1:ooooo`03ool00?oooooooooo0=Ko
oooo00?oo`00o`000?ooool07_ooool0027ooooo00?o0000ooooooooool0B_ooool00ol0003ooooo
ooooo`3Hooooo`03o`000?oooooooooo01;ooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`3Jooooo`03o`000?oooooooooo017ooooo00Ko
k^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooooooo`0003[o00003?ooool01?oMgMgo0000
oa0@4?o<c<`5ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool04Oooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool2o`0000gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool2o`0000kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo017ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo
00?o0000ooooool00000A_ooool00ol0003oooooooooo`3aooooo`;o00000_ooool2o`0000Cooooo
000Qooooo`03o`000?oooooo000004Gooooo00?o0000ooooooooool0o?ooool0027ooooo00Co0000
oooooooooooo0000@oooool00ol0003oooooooooo`3mooooo`008Oooool01Ol0003ooooooooooooo
003o000004;ooooo00?oo`00ooooooooool0oOooool0027ooooo00Go0000ooooooooooooo`00o`00
0011ooooo`03o`000?oo003ooooo0?kooooo000Qooooo`?o000000?oooooool00?l00000?oooool0
0ol0003oo`00ooooo`3oooooo`008Oooool00ol0003oooooooooo`02ooooo`03ool00?l0003ooooo
03cooooo00?o0000ool00?ooool0ooooool1ooooo`008Oooool00ol0003oooooooooo`03ooooo`03
ool00?oooooooooo03[ooooo00?o0000ool00?ooool0ooooool2ooooo`008Oooool00ol0003ooooo
ooooo`03ooooo`03ool00?l0003ooooo03Wooooo00?o0000ool00?ooool0ooooool3ooooo`008Ooo
ool00ol0003oooooooooo`04ooooo`03ool00?l0003ooooo03Sooooo00?oo`00ooooooooool0oooo
ool3ooooo`008Oooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo03Kooooo00?o0000
ool00?ooool0ooooool4ooooo`008Oooool00ol0003oooooooooo`05ooooo`03ool00?l0003ooooo
03Gooooo00?o0000ool00?ooool0ooooool5ooooo`008Oooool3o`0000Kooooo00?oo`00o`000?oo
ool0<oooool00ol0003oo`00ooooo`3oooooo`Kooooo000Qooooo`03o`000?oooooooooo00Oooooo
00?oo`00ooooooooool0<Oooool00ol0003oo`00ooooo`3oooooo`Oooooo000Qooooo`03o`000?oo
oooooooo00Oooooo00?oo`00o`000?ooool0<Oooool00ooo003oooooooooo`3oooooo`Oooooo000Q
ooooo`03o`000?oooooooooo00Sooooo00?oo`00o`000?ooool0;oooool00ol0003oo`00ooooo`3o
ooooo`Sooooo000Qooooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool0;Oooool00ol0
003oooooooooo`3oooooo`Wooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`3oooooo`[ooooo000Qooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3oooooo`_ooooo000Qooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`3oooooo`cooooo000Q
ooooo`?o00003Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo0?oooooo3Oooool0
027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
0?oooooo3_ooool0027ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo0?oooooo3oooool0027ooooo00?o0000ooooooooool04?ooool2o`00023ooooo
00?o0000ool00?ooool0ooooool@ooooo`008Oooool00ol0003oooooooooo`0?ooooo`04ool00?oo
ooooooooo`0001kooooo00?o0000ool00?ooool0oooooolAooooo`008Oooool00ol0003ooooooooo
o`0@ooooo`04ool00?ooooooooooo`0001cooooo00?o0000ool00?ooool0oooooolBooooo`008Ooo
ool00ol0003oooooooooo`0Aooooo`04ool00?ooooooooooo`0001Wooooo0_l000000ooo003ooooo
ooooo`3ooooooa;ooooo000Qooooo`?o00004_ooool01?oo003oooooooooool0000Gooooo`03o`00
0?ooooooo`000?oooooo5Oooool0027ooooo00?o0000ooooooooool04oooool01?oo003ooooooooo
ool0000Dooooo`;o000000?oooooool00?ooool0oooooolEooooo`008Oooool00ol0003ooooooooo
o`0Dooooo`03ool00?oooooooooo00?o00004?ooool01?l0003ooooooooooooo003ooooooaOooooo
000Qooooo`03o`000?oooooooooo01Gooooo0_oo0003ooooo`03o`000?oooooooooo00_ooooo0_l0
00000oooooooo`00ool0003ooooooaSooooo000Qooooo`03o`000?oooooooooo01Oooooo00Coo`00
oooooooooooooooo0ol00006ooooo`Co00000ooo003ooooooa[ooooo0007ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`00
0?oooooooooo01Sooooo0ooo0003ooooo`Ko00000oooool00ooo003oooooooooo`3ooooooa_ooooo
0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
0oooool00ol0003oooooooooo`0Kooooo`;oo`00oooooolXooooo`001oooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`000?ooooooAOooool000Oooooo00Go
0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0
oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o
<S8bolc<c004ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Go
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000oooooooo
ool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
AOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000J
ooooo`03o`000?oooooooooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00:Cooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMg
ooooo`2Wooooo`00Poooool3o`0001Cooooo00?o8B4QomgMgOooool01_ooool00ooMgMgo410@onk^
kP0Hooooo`03onk^k_l@413ogMgM0:Oooooo001kooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8b
onk^kP02ooooo`03o`000?oooooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03
oiRHV?mEEEGooooo00Kooooo00?oEEEEoiRHV?ooool00_ooool5o`0000Wooooo00?oEEEEojVYZOoo
ool00_ooool01_nj^[[oA4A4ooooooooooooQhN7ofIVIQGooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00;ooooo00GoA4A4o`000?l0003o<S8bomgM
g@1eooooo`00Noooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00_ooool00ol0003ooooo
ooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ogMgMooooo`05ooooo`03
o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00:ooooo`06oeEEEOnHV9Sooooo
ooooool@413o^[Zj0_ooool00oo^k^ko0000ooooo`0;ooooo`Ko00001Oooool00ol0003ooooooooo
o`04ooooo`;o8B4Q1oooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo07Cooooo001k
ooooo`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@4002ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01_ooool2ogMgM`Kooooo00?o<S8booooooooool00oooool00onHV9So8B4Q
onk^kP0<ooooo`04oa0@4?oMgMgoooooo`0000Cooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0:ooooo`Go00002?ooool00ol0003oooooooooo`1cooooo`00Noooool01?mEEEGoZJVY
ooooool00002ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool01_ooool00oo^
k^ko410@onk^kP05ooooo`03oc8b<_oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7
QhOoIVIVooooool00004ooooo`03o`000?oooooooooo00[ooooo1_l00005ooooo`03o`000?oooooo
oooo00[ooooo00CoA4A4omgMgOoooooo00002?ooool00omgMgOo<S8booooo`1dooooo`00Noooool0
0ooMgMgo8B4Qonk^kP03ooooo`04o`000?oooooo0000o`0000gooooo00?o0000ooooooooool01ooo
ool00omEEEGoV9RHooooo`04ooooo`03o`000?o^k^kooooo00Gooooo00?oMgMgofIVI_ooool02_oo
ool01?oMgMgo410@ooooool00003ooooo`03onk^k_l0003ooooo01Kooooo00?o0000ooooooooool0
2_ooool01?oMgMgoEEEEooooool00005ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0MOooool007co
oooo00?oV9RHogMgMoooool00_ooool00ol0003oooooooooo`0<ooooo`03oa0@4?l0003o000000?o
00001_ooool00ooMgMgo410@ooooo`04ooooo`03oeEEEOmgMgOooooo00Kooooo00?o0000oooooooo
ool02?ooool7o`000003oooooomgMgOoEEEE01Oooooo00?o0000ooooooooool02oooool00omgMgOo
c<c<o`000005ooooo`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo00Sooooo
00?oEEEEoiRHV?ooool00oooool00ooMgMgo410@onk^kP02ooooo`05o`000?nj^[[ooooooiRHV?l@
41004Oooool00oo^k^ko410@omgMg@0Gooooo`03o`000?oooooooooo00_ooooo00?ok^k^odA4A?l0
00001Oooool00ol0003oooooooooo`1gooooo`00T_ooool00ol0003oooooooooo`08ooooo`03okZj
^_m4A4Cooooo00Cooooo00WoMgMgofIVI_oooooooooooiRHV?l@413o0000ob4Q8Oo<c<`04Oooool0
0omVIVKoMgMgooooo`0Eooooo`03oeEEEOmVIVKo000000kooooo00?oMgMgo`000?ooool01?ooool4
o`0007Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .35892 L
.06244 .4054 L
.08255 .44165 L
.09396 .45642 L
.09905 .4616 L
.10458 .46626 L
.11004 .46986 L
.11243 .47113 L
.11508 .47232 L
.1174 .47319 L
.11989 .47393 L
.12127 .47425 L
.12253 .4745 L
.12372 .47469 L
.125 .47485 L
.12624 .47495 L
.12736 .47501 L
.12849 .47503 L
.12955 .47501 L
.13079 .47495 L
.13194 .47485 L
.13319 .4747 L
.13452 .4745 L
.13675 .47404 L
.13884 .4735 L
.14357 .47182 L
.14858 .46942 L
.15402 .4661 L
.16392 .45834 L
.18248 .43849 L
.22326 .37753 L
.26253 .30785 L
.30028 .24068 L
.34048 .17577 L
.37917 .12341 L
.39882 .10119 L
.42031 .08041 L
.44107 .06382 L
.45994 .05166 L
.47955 .04185 L
.49045 .0376 L
.5005 .0344 L
.50981 .03205 L
.51968 .03017 L
.5248 .02943 L
.52958 .02889 L
.53484 .02846 L
.53778 .02829 L
.53917 .02822 L
Mistroke
.54048 .02817 L
.54168 .02814 L
.54299 .02811 L
.54417 .02809 L
.54526 .02808 L
.54644 .02807 L
.54774 .02808 L
.54839 .02808 L
.54909 .02809 L
.55035 .02812 L
.55153 .02815 L
.55281 .02819 L
.55514 .02829 L
.55741 .02841 L
.5595 .02855 L
.56429 .02895 L
.56956 .02954 L
.58024 .03116 L
.59036 .03321 L
.59962 .03552 L
.62049 .04209 L
.66017 .05934 L
.69833 .08087 L
.73894 .10798 L
.77804 .13721 L
.81959 .17076 L
.85963 .20482 L
.89814 .2387 L
.93912 .27545 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .35671 L
.06244 .40297 L
.08255 .44006 L
.09396 .45554 L
.09905 .46107 L
.10458 .46609 L
.11004 .47005 L
.11508 .47283 L
.11989 .47472 L
.12232 .47539 L
.12369 .47569 L
.125 .47591 L
.12615 .47607 L
.12741 .4762 L
.12855 .47627 L
.12962 .4763 L
.13088 .47629 L
.13202 .47624 L
.13334 .47614 L
.13459 .47599 L
.13568 .47582 L
.13684 .47561 L
.1389 .47514 L
.14357 .47362 L
.14853 .47136 L
.15305 .46874 L
.16321 .46103 L
.18154 .44152 L
.22139 .38133 L
.25972 .31234 L
.3005 .23924 L
.33977 .17655 L
.37752 .12671 L
.41772 .08579 L
.45641 .05773 L
.47645 .04722 L
.48665 .04287 L
.49755 .03893 L
.50789 .03586 L
.51729 .03361 L
.52674 .03187 L
.53566 .03069 L
.54029 .03025 L
.54295 .03005 L
.54538 .02991 L
.54794 .02979 L
.54935 .02974 L
.5507 .0297 L
.55193 .02967 L
Mistroke
.55308 .02965 L
.55433 .02964 L
.55504 .02964 L
.55567 .02964 L
.55683 .02965 L
.55805 .02966 L
.5591 .02968 L
.56024 .02971 L
.5628 .02979 L
.56518 .0299 L
.5695 .03018 L
.57412 .03058 L
.57943 .03118 L
.58432 .03187 L
.5954 .03386 L
.60517 .03613 L
.61554 .03905 L
.65334 .05395 L
.6936 .07645 L
.73233 .10336 L
.77353 .136 L
.8132 .16965 L
.85136 .2027 L
.89198 .23772 L
.93107 .27102 L
.97262 .30604 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo09Oooooo3?l0
0008ool009Wooooo000Qooooo`03o`000?oooooooooo09Cooooo0_l00004ool0017ooooo2?oo002A
ooooo`008Oooool00ol0003oooooooooo`2Aooooo`;o00000ooo000Kooooo`;o000000?oo`00oooo
ooooool0S_ooool0027ooooo00?o0000ooooooooool0S_ooool2o`0000?oo`008Oooool3o`0008go
oooo000Qooooo`03o`000?oooooooooo08_ooooo0_l00003ool002Oooooo0ol0002:ooooo`008Ooo
ool00ol0003oooooooooo`29ooooo`;o000000?oooooool00?ooool0;?ooool3o`0008Oooooo000Q
ooooo`?o0000Qoooool2o`000003oooooooo003oo`00037ooooo0_oo0025ooooo`008Oooool00ol0
003oooooooooo`25ooooo`;o0000>?ooool3ool008;ooooo000Qooooo`03o`000?oooooooooo08Co
oooo00?o0000ooooooooool0>_ooool00ol0003oo`00ool00020ooooo`008Oooool00ol0003ooooo
ooooo`22ooooo`;o0000@?ooool2ool007kooooo000Qooooo`03o`000?oooooooooo087ooooo00?o
0000ooooooooool0@_ooool2ool007cooooo000Hooooo`Co000000?o410@ooooooooool00_ooool0
0ol0003oooooooooo`1oooooo`03o`000?oo003oo`0004Kooooo00?oo`00ooooooooool0NOooool0
01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1nooooo`03o`000?oo003ooooo
04Sooooo0_oo001iooooo`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`0007co
oooo0_l000000ooo003oooooooooo`1:ooooo`03ool00?l0003ooooo07Kooooo000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0Noooool00ol0003oo`00ool0001?ooooo`03o`00
0?oooooooooo07Cooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0N_oo
ool00ol0003oo`00ooooo`1Aooooo`;o0000M?ooool001[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1hooooo`;o000000?oo`00ooooooooool0Doooool2o`0007;ooooo000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Moooool00ol0003oooooool0001Hoooo
o`03o`000?oooooooooo06oooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0M_ooool00ol0003oooooool0001Jooooo`;o0000Koooool0027ooooo00?o0000ooooooooool0
MOooool00ol0003oooooool0001Looooo`;oo`00K_ooool0027ooooo00?o0000ooooooooool0M?oo
ool00ol0003oooooool0001Oooooo`;oo`00K?ooool0027ooooo0ol0001cooooo`03o`000?oooooo
o`0006;ooooo00?oo`00ooooooooool0JOooool0027ooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`1Tooooo`;oo`00JOooool0027ooooo00?o0000ooooooooool0L_ooool00ol0003o
ooooooooo`1Uooooo`03o`000?oo003ooooo06Oooooo000Qooooo`03o`000?oooooooooo077ooooo
00?o0000ooooooooool0J?ooool00ooo003oooooooooo`1Uooooo`008Oooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo06[ooooo00?oo`00o`000?ooool0I?ooool0027ooooo00?o0000
ooooooooool0Koooool00ol0003oooooooooo`1/ooooo`03ool00?l0003ooooo06?ooooo000Qoooo
o`03o`000?oooooooooo06kooooo00?o0000ooooooooool0K_ooool00ooo003o0000ooooo`1Roooo
o`008Oooool3o`0006gooooo00?o0000ooooooooool0L?ooool00ooo003o0000o`00001Qooooo`00
8Oooool00ol0003oooooooooo`1/ooooo`03o`000?oo003ooooo07Cooooo00?o0000ooooooooool0
G_ooool0027ooooo00?o0000ooooooooool0K?ooool00ooo003oooooooooo`1eooooo`03o`000?oo
oooooooo05gooooo000Qooooo`03o`000?oooooooooo06_ooooo00?o0000ool00?ooool0Moooool2
o`0005gooooo000Qooooo`03o`000?oooooooooo06[ooooo00?o0000ool00?ooool0N_ooool00ol0
003oooooooooo`1Jooooo`008Oooool00ol0003oooooooooo`1Zooooo`03ool00?oooooooooo07_o
oooo00?o0000ooooooooool0FOooool0027ooooo00?o0000ooooooooool0JOooool00ooo003ooooo
ooooo`1mooooo`;o0000FOooool0027ooooo0ol0001Xooooo`03o`000?oo003ooooo07kooooo0_oo
00000ol0003oooooooooo`1Fooooo`008Oooool00ol0003oooooooooo`1Wooooo`03o`000?oo003o
oooo087ooooo00?oo`00o`000?ooool0E_ooool0027ooooo00?o0000ooooooooool0Ioooool00ooo
003oooooooooo`22ooooo`03ool00?l0003o000005Gooooo000Qooooo`03o`000?oooooooooo06Ko
oooo00?o0000ool00?ooool0Q?ooool00ooo003oooooo`00001Dooooo`008Oooool00ol0003ooooo
ooooo`1Uooooo`03o`000?oo003ooooo08Kooooo0_oo00000ol0003oooooooooo`1Aooooo`008Ooo
ool00ol0003oooooooooo`1Uooooo`03ool00?oooooooooo08Sooooo00?oo`00o`000?ooool0DOoo
ool0027ooooo00?o0000ooooooooool0I?ooool00ooo003oooooooooo`2:ooooo`03ool00?l0003o
0000053ooooo000Qooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0S?ooool00ooo
003oooooo`00001?ooooo`008Oooool3o`0006;ooooo00?o0000ooooooooool0S_ooool00ooo003o
ooooo`00001>ooooo`008Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo08oooooo
00Coo`00ooooool0003o0000C?ooool0027ooooo00?o0000ooooooooool0HOooool00ol0003ooooo
ooooo`2Aooooo`04ool00?ooooooooooo`0004_ooooo000Qooooo`03o`000?oooooooooo063ooooo
00?o0000ooooooooool0U_ooool00ol0003oooooooooo`18ooooo`008Oooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo09Oooooo00?o0000ooooooooool0Aoooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo
00?o0000ooooooooool0Goooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo04Kooooo
0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
0oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool0
AOooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0
0_ooool3o`0005gooooo00?oo`00o`000?ooool0WOooool00ol0003oooooooooo`14ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooo
ooooo`1Mooooo`03ool00?oooooooooo09kooooo00?o0000ooooooooool0@oooool000Oooooo00Go
0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003o
ooooooooo`1Looooo`03ool00?l0003ooooo09kooooo0_oo00000ol0003oooooooooo`12ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Looooo`03ool00?oooooooooo0:3ooooo00?oo`00o`000?ooool0@_ooool000Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0Foooool00ooo003oooooooooo`2Rooooo`;oo`00@_ooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`1Jooooo`03ool00?l0003ooooo0:Go
oooo00?oo`00o`000?ooool0?oooool0027ooooo00?o0000ooooooooool0F_ooool00ooo003ooooo
ooooo`2Vooooo`03ool00?l0003ooooo03kooooo000Qooooo`03o`000?oooooooooo05Wooooo00?o
o`00o`000?ooool0Z?ooool00ooo003o0000ooooo`0mooooo`008Oooool3o`0005Wooooo00?oo`00
ooooooooool0ZOooool00ooo003o0000ooooo`0looooo`008Oooool00ol0003oooooooooo`1Hoooo
o`03ool00?oooooooooo0:_ooooo00?oo`00o`000?ooool0>oooool0027ooooo00?o0000oooooooo
ool0F?ooool00ooo003oooooooooo`2/ooooo`03ool00?l0003o000003[ooooo000Qooooo`03o`00
0?oooooooooo05Oooooo00?oo`00ooooooooool0[_ooool00ooo003oooooo`00000iooooo`008Ooo
ool00ol0003oooooooooo`1Fooooo`03ool00?l0003ooooo0;3ooooo00?oo`00ooooool00000>?oo
ool0027ooooo00?o0000ooooooooool0E_ooool00ooo003oooooooooo`2cooooo`03o`000?oooooo
oooo03Gooooo000Qooooo`03o`000?oooooooooo05Gooooo00?oo`00ooooooooool0]Oooool00ol0
003oooooooooo`0dooooo`008Oooool3o`0005Gooooo00?o0000ooooooooool0]_ooool2o`0003Co
oooo000Qooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0^Oooool00ol0003ooooo
ooooo`0aooooo`008Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool0<?ooool0027ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`2l
ooooo`03o`000?oooooooooo02oooooo000Qooooo`03o`000?oooooooooo05?ooooo00?o0000oooo
ooooool0^oooool2ool00003o`000?oooooooooo02kooooo000Qooooo`03o`000?oooooooooo05;o
oooo00?o0000ooooooooool0__ooool00ooo003o0000ooooo`0^ooooo`008Oooool00ol0003ooooo
ooooo`1Aooooo`03o`000?oooooooooo0<3ooooo00?oo`00o`000?ooool0;Oooool0027ooooo00?o
0000ooooooooool0DOooool00ol0003oooooooooo`31ooooo`;oo`00;Oooool0027ooooo0ol0001@
ooooo`03ool00?oooooooooo0<Cooooo00?oo`00ooooooooool0:_ooool0027ooooo00?o0000oooo
ooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
o`00oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo03_ooooo1?l000000ol@413ooooooooo
o`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM037ooooo00?oo`00ooooooooool0
2Oooool5o`0001_ooooo000Qooooo`03o`000?oooooooooo03gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1_ooool01?oo003oooooogMgMolb<S8oooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0<Oooool00ooo003o
ooooooooo`08ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0027ooooo00?o0000oooooooo
ool0?Oooool01Ol@413ooooooooooooooooo410@00gooooo00Coo`00oooooooooooo0000?oooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<Oooool0
0ooo003oooooooooo`08ooooo`03oiRHV?lQ8B7ok^k^01cooooo000Qooooo`03o`000?oooooooooo
03gooooo00Go0000ooooooooooooooooo`00000<ooooo`05ool00?ooooooooooogMgMolb<S80?ooo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0<ooo
ool00ooo003o0000ooooo`08ooooo`03oiRHV?lQ8B7ok^k^01_ooooo000Qooooo`03o`000?oooooo
oooo03gooooo00Go0000ooooooooooooooooo`00000;ooooo`06ool00?l0003o8B4Qo`000?lb<S;o
c<c<?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c00eooooo`03ool00?l0003ooooo00Sooooo00?oMgMgofIVI_ooool06_ooool0027o
oooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oo`00o`00
0?ooool0@_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0>?ooool00ooo003o0000ooooo`08ooooo`03o`000?oooooooooo01Wooooo000Qooooo`?o
0000?Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?oo`00ooooool00000@oooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@41006oooool0027ooooo00?o0000oooo
ooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo00?oo`00ooooool000000ol0000n
ooooo`03oeEEEOmVIVKo000003oooooo00?oEEEEofIVI_l000003Oooool4o`0003[ooooo00Wo0000
oooooooooooooooooiRHV?l@413o0000ob4Q8Oo<c<`06oooool0027ooooo00?o0000ooooooooool0
Boooool00ooo003oooooooooo`3Cooooo`;o00008Oooool0027ooooo00?o0000ooooooooool0Booo
ool00ooo003oooooooooo`3Eooooo`03o`000?oooooooooo01kooooo000Qooooo`03o`000?oooooo
oooo04[ooooo00?oo`00ooooooooool0eoooool00ol0003oooooooooo`0Mooooo`008Oooool00ol0
003oooooooooo`19ooooo`03ool00?oooooooooo0=Wooooo00?o0000ooooooooool04_ooool2o`00
00;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`19ooooo`03ool00?oooooooooo0=[o
oooo00?oo`00ooooooooool04Oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooo
oe;o000000?oo`00o`000?l00000g?l000000ooo003o0000o`000005o`0000cooooo00CogMgMo`00
0?l@413oc<c<1Oooool0027ooooo00?o0000ool00?ooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ool0
0?ooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`;o00003_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool01?lQ8B7oMgMgogMgMolb<S85
ooooo`008Oooool2o`000003ool00?oooooooooo04Gooooo00?o0000ooooooooool0l?ooool2o`00
00;ooooo0_l00004ooooo`008Oooool2o`000003ool00?oooooooooo04Cooooo00?o0000oooooooo
ool0noooool0027ooooo00?o0000oooooooo0000A_ooool00ol0003oooooooooo`3kooooo`008Ooo
ool01?l0003oooooo`000?oo0014ooooo`03o`000?oooooooooo0?cooooo000Qooooo`04o`000?oo
oooo0000ool004?ooooo00?o0000ooooooooool0oOooool0027ooooo0ol000000ooo003ooooooooo
o`11ooooo`03o`000?oooooooooo0?gooooo000Qooooo`05o`000?ooooooooooo`000?oo0000@Ooo
ool00ooo003oooooooooo`3nooooo`008Oooool01Ol0003oooooooooooooooooo`00047ooooo00?o
o`00ooooooooool0o_ooool0027ooooo00Go0000ooooooooooooooooool00010ooooo`03ool00?oo
oooooooo0?oooooo000Qooooo`06o`000?ooooooooooooooool0003oo`00?oooool00ooo003ooooo
ooooo`3oooooo`008Oooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo03cooooo00?o
o`00ooooooooool0ooooool1ooooo`008Oooool00ol0003oooooooooo`02ooooo`03ool00?oooooo
oooo03_ooooo00?oo`00o`000?ooool0ooooool2ooooo`008Oooool3o`0000;ooooo00?o0000ool0
0?ooool0>oooool00ooo003oooooooooo`3oooooo`;ooooo000Qooooo`03o`000?oooooooooo00?o
oooo00?oo`00ooooooooool0>Oooool00ooo003o0000ooooo`3oooooo`?ooooo000Qooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0>Oooool00ooo003oooooooooo`3oooooo`?ooooo
000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=oooool00ooo003ooooooooo
o`3oooooo`Cooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=oooool0
0ooo003oooooooooo`3oooooo`Cooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0=Oooool00ooo003oooooooooo`3oooooo`Gooooo000Qooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0=?ooool00ooo003o0000ooooo`3oooooo`Kooooo000Qooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0=?ooool00ooo003oooooooooo`3oooooo`Kooooo
000Qooooo`?o00001_ooool00ol0003oooooooooo`0booooo`03ool00?l0003ooooo0?oooooo1ooo
ool0027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo0?oooooo1oooool0027ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo0?oooooo2?ooool0027ooooo00?o0000ooooooooool01oooool00ol0003o
o`00ooooo`0`ooooo`03o`000?oooooooooo0?oooooo2?ooool0027ooooo00?o0000ooooooooool0
2?ooool00ooo003oooooooooo`0^ooooo`03o`000?oooooooooo0?oooooo2Oooool0027ooooo00?o
0000ooooooooool02?ooool00ooo003oooooooooo`0]ooooo`03o`000?oooooooooo0?oooooo2_oo
ool0027ooooo00?o0000ooooooooool02?ooool00ol0003oo`00ooooo`0]ooooo`03o`000?oooooo
oooo0?oooooo2_ooool0027ooooo0ol00009ooooo`03ool00?oooooooooo02_ooooo00?o0000oooo
ooooool0ooooool;ooooo`008Oooool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo02[o
oooo00?o0000ooooooooool0ooooool<ooooo`008Oooool00ol0003oooooooooo`0:ooooo`03ool0
0?oooooooooo02Sooooo00?oo`00ooooooooool0ooooool=ooooo`008Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oo003ooooo02Sooooo00?oo`00ooooooooool0ooooool=ooooo`008Oooool0
0ol0003oooooooooo`0;ooooo`03ool00?oooooooooo02Kooooo00?oo`00ooooooooool0ooooool>
ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo02Cooooo00?o
o`00ooooooooool0ooooool?ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool03?ooool00ooo003ooooooooo
o`0Tooooo`03ool00?oooooooooo0?oooooo3oooool000Oooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00;ooooo0ol0000=ooooo`03ool00?oooooooooo02;ooooo00?o
o`00ooooooooool0ooooool@ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oo003ooooo027ooooo00?o
0000ool00?ooool0oooooolAooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0
8?ooool00ooo003oooooooooo`3ooooooa7ooooo0007ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool0
7_ooool00ooo003oooooooooo`3ooooooa;ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
7Oooool00ol0003oo`00ooooo`3ooooooa?ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`0000Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oo003ooooo0?oooooo5?ooool0027ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oo003ooooo0?oooooo5Oooool0027ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oo003ooooo0?oooooo5_ooool0027ooooo0ol0000Boooo
o`03o`000?oooooooooo01Kooooo00?o0000ool00?ooool0oooooolGooooo`008Oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0oooooolHooooo`00
8Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo017ooooo0_l0003ooooooa_ooooo
000Qooooo`03o`000?oooooooooo01Gooooo0_oo000@ooooo`03o`000?oooooooooo0?oooooo6ooo
ool0027ooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`0;ooooo`;o0000oooooolN
ooooo`008Oooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo00[ooooo00?o0000oooo
ooooool0oooooolNooooo`008Oooool00ol0003oooooooooo`0Hooooo`;oo`0000?o0000oooooooo
ool01Oooool2o`000003ool00?oooooooooo0?oooooo7_ooool0027ooooo0ol0000Jooooo`Coo`00
0_l00004ool00?oooooo8Oooool0027ooooo00?o0000ooooooooool07Oooool4ool00?oooooo9?oo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003ooooo
ooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool0
01[ooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00Z?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mg
MgOooooo0:?ooooo0027ooooo`?o00004oooool00olQ8B7ogMgMooooo`07ooooo`03omgMgOl@413o
k^k^01Sooooo00?ok^k^oa0@4?oMgMd0Xoooool007kooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb
<S;ok^k^00?ooooo00?o0000ooooooooool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo
00?oV9RHoeEEEOooool01oooool01?mEEEGoV9RHooooooooool5o`0000Wooooo00?oEEEEojVYZOoo
ool00_ooool00onj^[[oA4A4ooooo`02ooooo`03ohN7QomVIVKooooo01?ooooo1?l000000ol@413o
ooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM07[ooooo001nooooo`07
oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP03ooooo`03o`000?oooooooooo00_ooooo00Go410@
okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oMgMgooooo00Kooooo00Wo0000oooooooooooooooo
oiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P?ooooo00?o
k^k^o`000?ooool02oooool6o`0000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool0NOooool007kooooo00Oo0000oooooooMgMgo<S8booooooo^k^ko410@00?ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`;oMgMg1oooool00olb<S;ooooo
ooooo`02ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co410@omgMgOoooooo00001Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0N?ooool007kooooo
00CoEEEEojVYZOoooooo00000_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000oooo
ooooool01Oooool00oo^k^ko410@onk^kP06ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q
8Oo^k^h02oooool01?n7QhOoIVIVooooool00005ooooo`03o`000?oooooooooo00[ooooo1_l00004
ooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0NOooool007kooooo00?ogMgMob4Q
8Oo^k^h00oooool00ol0003oooooooooo`02o`0000gooooo00?o0000ooooooooool01_ooool00omE
EEGoV9RHooooo`05ooooo`03o`000?o^k^kooooo00Cooooo00?oMgMgofIVI_ooool02_ooool01?oM
gMgo410@ooooool00004ooooo`03onk^k_l0003ooooo01Gooooo00?o0000ooooooooool02oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<07[ooooo001oooooo`03oiRHV?mgMgOooooo00;ooooo00?o0000
ooooooooool03Oooool00ol@413o0000o`000003o`0000Gooooo00?ogMgMoa0@4?ooool01Oooool0
0omEEEGoMgMgooooo`05ooooo`03o`000?oooooooooo00Sooooo1ol00002ooooo`03ogMgMomEEEGo
oooo01Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1looooo`00U_ooool00ol0
003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00WogMgMoa0@4?o^k^koooooo`000?nj
^[[ooooooiRHV?l@41004_ooool00oo^k^ko410@omgMg@0Fooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0O?ooool009Kooooo00?o0000ooooooooool01oooool00onj^[[oA4A4oooo
o`05ooooo`08ogMgMomVIVKooooooiRHV?l@413o0000ob4Q8Oo<c<`Booooo`03ofIVI_mgMgOooooo
01Cooooo00?oEEEEofIVI_l000003Oooool4o`0007_ooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.55) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .33801 L
.06244 .36625 L
.08426 .39201 L
.0949 .40185 L
.10458 .40899 L
.10911 .41171 L
.11403 .41421 L
.11828 .41597 L
.12297 .41749 L
.12553 .41813 L
.12793 .41861 L
.13047 .41899 L
.13189 .41915 L
.13319 .41926 L
.13439 .41933 L
.13551 .41937 L
.13673 .41939 L
.13803 .41937 L
.13928 .41932 L
.14045 .41925 L
.1415 .41916 L
.14264 .41905 L
.14501 .41872 L
.14755 .41825 L
.15214 .4171 L
.1576 .41523 L
.16257 .41307 L
.17339 .40696 L
.18364 .39951 L
.22197 .36041 L
.26275 .30668 L
.30202 .25136 L
.33977 .20064 L
.37997 .15341 L
.41866 .11673 L
.43831 .10168 L
.4598 .08802 L
.48033 .07767 L
.49942 .07035 L
.50995 .06725 L
.51988 .0649 L
.5288 .06327 L
.53379 .06255 L
.53847 .062 L
.54303 .06158 L
.54793 .06124 L
.55072 .06111 L
.5521 .06106 L
.55337 .06102 L
Mistroke
.55452 .06099 L
.55575 .06096 L
.55645 .06096 L
.55711 .06095 L
.55834 .06094 L
.55957 .06094 L
.56026 .06095 L
.56091 .06095 L
.56222 .06097 L
.56295 .06098 L
.56362 .061 L
.5661 .06107 L
.56846 .06117 L
.57118 .06132 L
.5737 .06149 L
.57939 .06198 L
.58904 .06315 L
.59809 .06462 L
.61871 .06928 L
.63893 .07546 L
.65744 .08241 L
.69712 .10093 L
.73528 .12273 L
.77589 .14938 L
.81499 .17768 L
.85654 .20988 L
.89658 .24235 L
.93509 .2744 L
.97607 .30891 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .33623 L
.06244 .36302 L
.08255 .38544 L
.09396 .39536 L
.10458 .40257 L
.10961 .40528 L
.11508 .4077 L
.12023 .40948 L
.12269 .41016 L
.125 .4107 L
.12724 .41113 L
.12929 .41144 L
.13156 .4117 L
.13282 .41181 L
.13401 .41188 L
.13516 .41193 L
.13638 .41195 L
.13754 .41195 L
.13858 .41193 L
.13982 .41188 L
.14051 .41184 L
.14115 .41179 L
.14357 .41156 L
.14483 .4114 L
.14603 .41123 L
.14827 .41083 L
.15331 .40964 L
.15766 .40828 L
.1624 .40646 L
.17313 .40109 L
.18306 .39467 L
.20172 .37928 L
.22233 .35813 L
.26253 .3086 L
.30122 .25684 L
.34236 .20403 L
.38198 .15978 L
.42009 .12569 L
.44134 .11066 L
.46065 .09949 L
.48074 .09033 L
.4997 .08389 L
.50942 .08139 L
.51971 .0793 L
.5285 .07796 L
.53349 .07738 L
.53816 .07695 L
.54314 .0766 L
.54596 .07646 L
Mistroke
.5473 .07641 L
.54857 .07636 L
.54978 .07633 L
.55108 .0763 L
.55227 .07628 L
.55335 .07627 L
.55454 .07626 L
.55583 .07626 L
.55649 .07626 L
.55719 .07627 L
.55845 .07628 L
.55969 .0763 L
.56084 .07633 L
.56343 .07641 L
.56572 .0765 L
.56815 .07663 L
.57235 .07691 L
.57699 .0773 L
.58711 .07846 L
.59637 .07987 L
.61724 .08422 L
.6362 .08946 L
.65692 .09645 L
.69753 .11352 L
.73663 .13358 L
.77818 .1582 L
.81821 .18468 L
.85673 .21241 L
.8977 .24405 L
.93716 .27626 L
.9751 .3081 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`2Loooooa;o0000U_ooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooo
oooo09Oooooo1Ol0000Booooo`Ko0000T?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`2Dooooo`?o00007Oooool3o`0008gooooo000?ooooo`Ko00001Oooool00ol0003o
ooooooooo`04ooooo`?o0000TOooool3o`0002?ooooo1?l00029ooooo`006_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo08kooooo0ol0000Zooooo`Co0000QOooool001[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`2;ooooo`?o00003?ooool?ool001Kooooo0_l0
0023ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Wooooo0_l00009
ooooo`Koo`006Oooool3ool000_ooooo0_l00021ooooo`006_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo08Oooooo0_l00009ooooo`;oo`008_ooool4ool000Wooooo0_l0001ooooo
o`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo08Gooooo0_l0000:ooooo`03
ool00?oooooooooo02Kooooo0ooo0008ooooo`?o0000O?ooool0027ooooo00?o0000ooooooooool0
Q?ooool00ol0003oooooooooo`0fooooo`;oo`002Oooool3o`0007Wooooo000Qooooo`03o`000?oo
oooooooo08;ooooo0_l0000kooooo`?oo`002Oooool2o`0007Oooooo000Qooooo`?o0000POooool0
0ol0003oooooooooo`0nooooo`03ool00?oooooooooo00Sooooo0ol0001dooooo`008Oooool00ol0
003oooooooooo`20ooooo`03o`000?oooooooooo00;ooooo0ooo0018ooooo`;o0000L_ooool0027o
oooo00?o0000ooooooooool0O_ooool2o`0000?ooooo0_oo001=ooooo`;o0000L?ooool0027ooooo
00?o0000ooooooooool0OOooool01?l0003oooooooooooooool2ool0057ooooo00?o0000oooooooo
ool0KOooool0027ooooo00?o0000ooooooooool0Noooool2o`0000;ooooo0_oo001;ooooo`?oo`00
1_ooool2o`0006gooooo000Qooooo`03o`000?oooooooooo07[ooooo00Go0000oooooooooooooooo
ool0001@ooooo`?oo`001Oooool2o`0006_ooooo000Qooooo`03o`000?oooooooooo07Wooooo00?o
0000ooooooooool00_oo001Dooooo`;oo`001Oooool00ol0003oooooooooo`1Xooooo`008Oooool3
o`0007Sooooo00Co0000ooooooooooooo`00F?ooool00ooo003oooooooooo`03ooooo`;o0000J?oo
ool0027ooooo00?o0000ooooooooool0Moooool01?l0003ooooooooooooo001Jooooo`;oo`001Ooo
ool2o`0006Kooooo000Qooooo`03o`000?oooooooooo07Kooooo00Co0000ooooooooooooo`00GOoo
ool2ool000Gooooo00?o0000ooooooooool0Hoooool0027ooooo00?o0000ooooooooool0MOooool0
0ol0003oooooooooo`1Qooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool0H_ooool0
027ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`1Sooooo`03ool00?oooooooooo
00?ooooo0_l0001Rooooo`008Oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo06co
oooo00?o0000ooooooooool0Goooool0027ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo05kooooo000Qooooo`?o0000LOooool00ol0003ooooooooo
o`1`ooooo`;o0000G_ooool0027ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1c
ooooo`03o`000?oooooooooo05_ooooo000Qooooo`03o`000?oooooooooo06oooooo00?o0000oooo
oooo0000LOooool2ool000;ooooo00?o0000ooooooooool0F_ooool0027ooooo00?o0000oooooooo
ool0K_ooool00ol0003oooooool0001dooooo`;oo`0000?oooooo`000?l00000F_ooool0027ooooo
00?o0000ooooooooool0KOooool00ol0003oooooool0001gooooo`;oo`0000?oooooo`000?ooool0
F?ooool0027ooooo00?o0000ooooooooool0KOooool00ol0003oo`00ooooo`1iooooo`;oo`000_l0
001Gooooo`008Oooool00ol0003oooooooooo`1/ooooo`03o`000?oo003ooooo07cooooo00?oo`00
ooooool00000E_ooool0027ooooo00?o0000ooooooooool0Joooool00ol0003oo`00ooooo`1noooo
o`;oo`000_l0001Dooooo`008Oooool3o`0006[ooooo00?o0000ool00?ooool0POooool2ool00003
o`000?oooooooooo057ooooo000Qooooo`03o`000?oooooooooo06Wooooo00?o0000ool00?ooool0
Q?ooool00ooo003o0000o`00001Aooooo`008Oooool00ol0003oooooooooo`1Xooooo`03o`000?oo
003ooooo08Kooooo00?oo`00ooooool00000D?ooool0027ooooo00?o0000ooooooooool0Ioooool0
0ol0003oo`00ooooo`2:ooooo`;o0000C_ooool0027ooooo00?o0000ooooooooool0I_ooool00ol0
003oo`00ooooo`2=ooooo`03o`000?oooooooooo04_ooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooo
oooo06Kooooo00?oo`00ooooooooool0S_ooool00ol0003oooooooooo`1:ooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000
ooooooooool0IOooool00ol0003oooooooooo`2@ooooo`;o0000B_ooool000Go00000_ooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`0006Cooooo00?o0000
ooooooooool0Toooool00ol0003oooooooooo`17ooooo`001oooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooo
oooo09Gooooo00?o0000ooooooooool0A_ooool000Oooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo09Gooooo0_oo00000ol0003oooooooooo`15ooooo`001oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Qooooo`03o`000?oo
oooooooo09Sooooo00?oo`00o`000?l00000AOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`2Jooooo`;oo`0000?o0000ooooooooool0@_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo09cooooo00?o
o`00o`000?ooool0@_ooool0027ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`2N
ooooo`03ool00?l0003o0000047ooooo000Qooooo`03o`000?oooooooooo05kooooo00?o0000ool0
0?ooool0X?ooool2ool00003o`000?oooooooooo03kooooo000Qooooo`?o0000GOooool00ol0003o
ooooool0002Sooooo`03ool00?l0003ooooo03kooooo000Qooooo`03o`000?oooooooooo05cooooo
00?o0000oooooooo0000YOooool00ooo003o0000ooooo`0mooooo`008Oooool00ol0003ooooooooo
o`1Looooo`03o`000?oo003ooooo0:Kooooo00?oo`00o`000?ooool0??ooool0027ooooo00?o0000
ooooooooool0Foooool00ol0003oo`00ooooo`2Xooooo`03ool00?l0003o000003_ooooo000Qoooo
o`03o`000?oooooooooo05[ooooo00?o0000oooooooo0000[?ooool00ol0003oooooooooo`0hoooo
o`008Oooool00ol0003oooooooooo`1Iooooo`03o`000?ooooooo`000:kooooo00?o0000oooooooo
ool0=oooool0027ooooo00?o0000ooooooooool0F?ooool00ol0003oooooool0002`ooooo`03o`00
0?oooooooooo03Kooooo000Qooooo`?o0000F?ooool00ol0003oo`00ooooo`2aooooo`03o`000?oo
oooooooo03Gooooo000Qooooo`03o`000?oooooooooo05Oooooo00?o0000oooooooo0000/oooool0
0ol0003oooooooooo`0dooooo`008Oooool00ol0003oooooooooo`1Fooooo`03o`000?ooooooo`00
0;Gooooo0_l0000dooooo`008Oooool00ol0003oooooooooo`1Eooooo`03o`000?ooooooo`000;Oo
oooo0_oo000cooooo`008Oooool00ol0003oooooooooo`1Dooooo`03o`000?ooooooo`000;[ooooo
00?oo`00ooooooooool0<?ooool0027ooooo00?o0000ooooooooool0E?ooool00ol0003ooooooooo
o`2kooooo`03ool00?oooooooooo02oooooo000Qooooo`03o`000?oooooooooo05?ooooo00?o0000
ooooooooool0_Oooool2ool002oooooo000Qooooo`03o`000?oooooooooo05;ooooo00?o0000oooo
ooooool0_oooool00ol0003oo`00ooooo`0]ooooo`008Oooool3o`0005;ooooo00?o0000oooooooo
ool0`Oooool00ooo003oooooooooo`0[ooooo`008Oooool00ol0003oooooooooo`0mooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o0000omgMg@0moooo
o`Co000000?o410@ooooooooool0>oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd0<?ooool2ool000_ooooo1Ol0000Kooooo`008Oooool00ol0
003oooooooooo`0mooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ogMgMolb<S80?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo033ooooo00?o0000ool00?ooool02Oooool01OnHV9So8B4Qonk^k_oo
ooooA4A401_ooooo000Qooooo`03o`000?oooooooooo03gooooo00Go410@oooooooooooooooooa0@
400>ooooo`03o`000?oooooo000003oooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo033ooooo00?o0000ool00?ooool02Oooool00onHV9So8B4Qonk^
kP0Looooo`008Oooool00ol0003oooooooooo`0mooooo`05o`000?ooooooooooooooool000003Ooo
ool01?l0003oooooogMgMolb<S8oooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
3_ooool00omgMgOo<S8booooo`0booooo`03o`000?oo003ooooo00Wooooo00?oV9RHob4Q8Oo^k^h0
6oooool0027ooooo00?o0000ooooooooool0?Oooool01Ol0003ooooooooooooooooo000000cooooo
00Go0000ool00?l0003o<S8bolc<c00oooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<03Gooooo00?o0000ooooooooool02?ooool00omg
MgOoIVIVooooo`0Jooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oo`00ooooo`11ooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool06Oooool0027ooooo0ol0000mooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0
003oo`00ooooo`12ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0iooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qoooo
o`03o`000?oooooooooo03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`03o`000?oo003o
000000?o0000?_ooool00omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000j
ooooo`09o`000?oooooooooooooooonHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qooooo`03o`00
0?oooooooooo04cooooo00?oo`00ooooooooool0d_ooool00ol0003oooooooooo`0Pooooo`008Ooo
ool00ol0003oooooooooo`1;ooooo`03ool00?oooooooooo0=Cooooo00?o0000ooooooooool07ooo
ool0027ooooo00?o0000ooooooooool0B_ooool00ol0003oo`00ooooo`3Fooooo`03ool00?l0003o
oooo01kooooo000Qooooo`03o`000?oooooooooo04[ooooo00?oo`00ooooooooool0eoooool00ooo
003o0000ooooo`0Cooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo04Wo
oooo00?oo`00ooooooooool0fOooool00ooo003o0000ooooo`0Booooo`06onk^k_lQ8B7oQhN7okZj
^_l0003ogMgM1?ooool001[ooooo1ol000000ooo003o0000o`000018o`000003ool00?l0003o0000
0=_o00000_oo0007o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?oo`00oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Cok^k^ob4Q
8Ol@413ok^k^1Oooool0027ooooo00?o0000ool00?ooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03ool00?l0003ooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo017ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000oooo
oooo0000A_ooool00ooo003oooooooooo`3aooooo`;o00000_ooool2o`0000Cooooo000Qooooo`04
o`000?oooooo0000ool004Cooooo00?o0000ooooooooool0o?ooool0027ooooo00Co0000oooooooo
ooooo`00@oooool00ol0003oooooooooo`3mooooo`008Oooool01Ol0003oooooooooooooooooo`00
04;ooooo00?o0000ooooooooool0oOooool0027ooooo00Ko0000ooooooooooooooooo`000?oo0010
ooooo`03o`000?oooooooooo0?kooooo000Qooooo`?o00000_ooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo0?oooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`3oooooo`7ooooo000Qooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0>_ooool00ol0003oooooooooo`3oooooo`;ooooo000Qooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`3oooooo`?ooooo000Q
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=oooool00ooo003oooooooooo`3o
ooooo`?ooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=_ooool00ooo
003oooooooooo`3oooooo`Cooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0=?ooool00ooo003oooooooooo`3oooooo`Gooooo000Qooooo`?o00001oooool00ol0003oo`00
ooooo`0booooo`03ool00?oooooooooo0?oooooo1_ooool0027ooooo00?o0000ooooooooool01ooo
ool00ol0003oo`00ooooo`0aooooo`03ool00?oooooooooo0?oooooo1oooool0027ooooo00?o0000
ooooooooool02?ooool00ol0003oo`00ooooo`0_ooooo`03ool00?l0003ooooo0?oooooo2?ooool0
027ooooo00?o0000ooooooooool02Oooool00ol0003oo`00ooooo`0]ooooo`03ool00?l0003ooooo
0?oooooo2Oooool0027ooooo00?o0000ooooooooool02Oooool00ol0003oooooool0000/ooooo`03
ool00?l0003ooooo0?oooooo2_ooool0027ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ool0000Zooooo`03ool00?l0003ooooo0?oooooo2oooool0027ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooool0000Xooooo`03ool00?l0003ooooo0?oooooo3?ooool0027ooooo00?o0000
ooooooooool03?ooool00ol0003oooooool0000Vooooo`03ool00?l0003ooooo0?oooooo3Oooool0
027ooooo0ol0000=ooooo`03o`000?ooooooo`0002Cooooo00?oo`00o`000?ooool0ooooool>oooo
o`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?ooooooo`0002?ooooo00?o0000oooooooo
ool0ooooool>ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03o`000?ooooooo`00027ooooo
00?o0000ooooooooool0ooooool?ooooo`008Oooool00ol0003oooooooooo`0@ooooo`;o000000?o
o`00ooooooooool07Oooool00ol0003oooooooooo`3ooooooa3ooooo000Qooooo`03o`000?oooooo
oooo01;ooooo00?o0000ool00?ooool07?ooool00ol0003oooooooooo`3ooooooa7ooooo000Qoooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`3ooooo
oa;ooooo000Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool00ooo003o
ooooooooo`02o`000?oooooo5Oooool0027ooooo0ol0000Eooooo`03o`000?oooooooooo01;ooooo
00Coo`00oooooooooooo0000oooooolGooooo`008Oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00kooooo0ooo00000ooooooo0000o`00003ooooooaSooooo000Qooooo`03o`000?oo
oooooooo01Oooooo0ol00002ooooo`_oo`000oooool00ol0003oooooooooo`3ooooooaSooooo000Q
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02oooool2o`000?oooooo6oooool0
027ooooo00?o0000ooooooooool06oooool3o`0000Kooooo1?l0003ooooooagooooo0007ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04
ooooo`03o`000?oooooooooo01kooooo1_l0003oooooob7ooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02
ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o
410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3o`000?oo
ooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo
000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIV
I_l000001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool0
0omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:Oooooo0023ooooo`?o00005?ooool00olQ
8B7ogMgMooooo`06ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Yoooool007_o
oooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool02oooool0
1OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?oV9RHoeEEEOooool01_ooool00omEEEGoV9RHoooo
o`02ooooo`Go00002Oooool00omEEEGoZJVYooooo`02ooooo`06okZj^_m4A4Cooooooooooon7QhOo
IVIV5Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd00oooool01Om4A4Co0000o`000?lb<S;ogMgM07Gooooo001kooooo`07oa0@4?oMgMgoMgMg
ob4Q8OooooooQhN7ofIVIP02ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_o^k^koMgMg
oa0@4004ooooo`03o`000?oMgMgooooo00Gooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Q
onk^k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X2ooooo`03onk^k_l0003o
oooo00_ooooo1_l00005ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00Gooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00Oo0000oooooooMgMgo<S8booooooo^
k^ko410@00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`;oMgMg1_oo
ool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co410@omgMgOoooooo0000
1?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1cooooo`00Noooool01?mEEEGoZJVYooooool00002ooooo`04o`00
0?ooooooooooo`0000gooooo00?o0000ooooooooool01_ooool00oo^k^ko410@onk^kP05ooooo`03
oc8b<_oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7QhOoIVIVooooool00004oooo
o`03o`000?oooooooooo00[ooooo1_l00005ooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b
<_ooool01Oooool00omgMgOo<S8booooo`1dooooo`00Noooool00ooMgMgo8B4Qonk^kP03ooooo`04
o`000?oooooo0000o`0000gooooo00?o0000ooooooooool01oooool00omEEEGoV9RHooooo`04oooo
o`03o`000?o^k^kooooo00Gooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgo410@ooooool00003
ooooo`03onk^k_l0003ooooo01Kooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c01eooooo`00O?ooool00onHV9SoMgMgoooo
o`02ooooo`03o`000?oooooooooo00cooooo00?o410@o`000?l000000ol00006ooooo`03omgMgOl@
413ooooo00Cooooo00?oEEEEogMgMoooool01_ooool00ol0003oooooooooo`08ooooo`Oo000000?o
ooooogMgMomEEED05oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Moooool009;ooooo00?o0000ooooooooool02?ooool00omEEEGoV9RHooooo`03
ooooo`03omgMgOl@413ok^k^00;ooooo00Go0000okZj^_ooooooV9RHoa0@400Aooooo`03onk^k_l@
413ogMgM01Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo07Oooooo002Booooo`03o`000?oooooooooo00Sooooo00?o^[ZjodA4A?ooool01?ooool0
2OmgMgOoIVIVooooooooooooV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`03ofIVI_mgMgOooooo01Go
oooo00?oEEEEofIVI_l000003Oooool4o`0000Cooooo1?l0001fooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .2992 L
.06244 .2907 L
.06747 .28902 L
.07286 .28747 L
.07751 .28635 L
.08255 .28536 L
.08564 .28488 L
.08848 .28452 L
.0912 .28424 L
.09259 .28412 L
.09409 .28402 L
.09543 .28394 L
.09666 .28389 L
.0979 .28385 L
.09908 .28382 L
.09974 .28381 L
.10044 .28381 L
.10171 .2838 L
.10248 .28381 L
.10321 .28382 L
.10387 .28384 L
.10458 .28385 L
.10582 .2839 L
.10695 .28395 L
.1095 .28409 L
.11185 .28427 L
.11409 .28448 L
.11908 .28507 L
.12452 .28588 L
.14558 .29021 L
.16497 .29472 L
.17526 .29687 L
.18067 .29785 L
.18637 .29876 L
.19141 .29943 L
.19693 .30001 L
.19936 .30021 L
.20195 .30038 L
.2044 .30051 L
.20662 .3006 L
.2078 .30063 L
.20906 .30065 L
.21013 .30067 L
.21131 .30068 L
.21258 .30067 L
.21329 .30067 L
.21394 .30066 L
.2152 .30063 L
.2164 .3006 L
Mistroke
.21869 .30051 L
.22082 .3004 L
.22315 .30025 L
.22563 .30004 L
.23101 .29946 L
.23594 .29875 L
.24708 .2966 L
.2569 .29406 L
.26727 .29078 L
.30529 .27423 L
.34577 .25127 L
.38473 .22714 L
.42614 .20245 L
.46604 .18192 L
.50442 .16653 L
.52423 .16048 L
.53436 .15791 L
.54525 .15554 L
.55544 .15369 L
.56476 .15232 L
.57368 .15128 L
.58306 .15049 L
.58807 .15019 L
.59263 .14999 L
.59515 .14992 L
.59648 .14988 L
.59788 .14985 L
.59911 .14983 L
.59976 .14983 L
.60046 .14982 L
.60169 .14981 L
.60284 .14981 L
.60406 .14981 L
.6052 .14981 L
.60645 .14982 L
.60708 .14983 L
.60777 .14984 L
.61018 .14989 L
.61245 .14995 L
.61667 .1501 L
.62122 .15034 L
.62617 .15067 L
.63077 .15105 L
.64123 .15217 L
.65143 .15358 L
.66233 .15544 L
.68365 .16008 L
.70379 .16562 L
.74222 .17899 L
.78311 .19671 L
Mistroke
.82248 .21655 L
.86034 .23763 L
.90064 .26165 L
.93944 .28575 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .29825 L
.06244 .28751 L
.07286 .28306 L
.08255 .27987 L
.08813 .27848 L
.0932 .2775 L
.096 .27707 L
.09905 .27669 L
.10192 .27641 L
.10329 .27631 L
.10458 .27623 L
.10574 .27617 L
.10701 .27612 L
.10817 .27609 L
.10924 .27607 L
.11051 .27606 L
.11166 .27606 L
.1123 .27606 L
.11299 .27608 L
.11425 .2761 L
.11534 .27614 L
.11654 .27619 L
.11897 .27633 L
.12121 .27649 L
.12331 .27668 L
.12851 .27728 L
.13326 .27796 L
.14393 .27993 L
.18378 .28948 L
.202 .29329 L
.20699 .29413 L
.21237 .29491 L
.21702 .29548 L
.22211 .29597 L
.22454 .29616 L
.22713 .29632 L
.22857 .2964 L
.22987 .29646 L
.2312 .29651 L
.23242 .29654 L
.23356 .29657 L
.23476 .29659 L
.23596 .2966 L
.23665 .2966 L
.23729 .2966 L
.23844 .2966 L
.2395 .29658 L
.24072 .29656 L
.24188 .29653 L
Mistroke
.24321 .29649 L
.24441 .29644 L
.2471 .29629 L
.24959 .29612 L
.25193 .29593 L
.2572 .29536 L
.26289 .29456 L
.27242 .29279 L
.28287 .29022 L
.30394 .28325 L
.34442 .26456 L
.38338 .24308 L
.42479 .2205 L
.46469 .20197 L
.50307 .18868 L
.52289 .18372 L
.53301 .18169 L
.54391 .17985 L
.55409 .17846 L
.56342 .17746 L
.57233 .17672 L
.57682 .17643 L
.58171 .17618 L
.58426 .17607 L
.58701 .17597 L
.58944 .1759 L
.59201 .17584 L
.59433 .1758 L
.59565 .17579 L
.59688 .17578 L
.59801 .17577 L
.59904 .17576 L
.60023 .17576 L
.60136 .17576 L
.60256 .17577 L
.60324 .17577 L
.60389 .17578 L
.60518 .17579 L
.60657 .17581 L
.60909 .17585 L
.6114 .1759 L
.61672 .17607 L
.62232 .17631 L
.63185 .17687 L
.64204 .17767 L
.6604 .17964 L
.68172 .18274 L
.70186 .18646 L
.7403 .19576 L
.78119 .20901 L
Mistroke
.82056 .22509 L
.85841 .24328 L
.89872 .2648 L
.93751 .28663 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0:Gooooo7?l00023ooooo`008Oooool00ol0003oooooooooo`2Oooooo`Ko0000
7?ooool7o`0007cooooo000Qooooo`03o`000?oooooooooo09cooooo0ol0000Yooooo`?o0000NOoo
ool0027ooooo00?o0000ooooooooool0V?ooool4o`0002oooooo0ol0001fooooo`008Oooool00ol0
003oooooooooo`2Eooooo`?o0000=_ooool3o`0007?ooooo000Qooooo`?o0000T_ooool3o`0003co
oooo1?l0001_ooooo`008Oooool00ol0003oooooooooo`2?ooooo`?o0000@oooool3o`0006cooooo
000Qooooo`03o`000?oooooooooo08gooooo0_l00019ooooo`?o0000JOooool0027ooooo00?o0000
ooooooooool0Roooool2o`0001Sooooo1_oo000:ooooo`goo`006Oooool3o`0006Kooooo000Qoooo
o`03o`000?oooooooooo08Sooooo0ol0000Cooooo`Ooo`007Oooool3ool001Wooooo0_l0001Toooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`26ooooo`;o00004oooool3ool004;ooooo0ol0001Q
ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00?ooooo00?o0000ooooooooool0Q?ooool2o`0004Wooooo1Ooo000?ooooo`;o0000Goooool0
00Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3
o`0008;ooooo0_l0001@ooooo`Coo`003Oooool2o`0005gooooo0007ooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo083ooooo0_l0000=
ooooo`;oo`00Aoooool4ool000_ooooo0ol0001Jooooo`001oooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo07kooooo0_l0
000<ooooo`?oo`00COooool3ool000_ooooo0_l0001Hooooo`001oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1looooo`;o00002ooo
ool3ool0063ooooo0_l0001Fooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`1jooooo`;o00002_ooool3ool006Gooooo0_l0
001Dooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oo
oooooooo07Wooooo00?o0000ooooooooool02?ooool2ool006[ooooo0ol0001Aooooo`008Oooool0
0ol0003oooooooooo`1gooooo`;o00002Oooool2ool006Gooooo1?oo0006ooooo`;o0000Coooool0
027ooooo00?o0000ooooooooool0MOooool2o`0000[ooooo00?oo`00ooooooooool0JOooool3ool0
00Gooooo0_l0001=ooooo`008Oooool3o`0007Cooooo00?o0000ooooooooool0NOooool00ooo003o
ooooooooo`04ooooo`;o0000Boooool0027ooooo00?o0000ooooooooool0L_ooool2o`0008Gooooo
0_l00019ooooo`008Oooool00ol0003oooooooooo`1`ooooo`;o0000ROooool00ol0003ooooooooo
o`16ooooo`008Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Gooooo0_oo0023
ooooo`;o0000A_ooool0027ooooo00?o0000ooooooooool0KOooool2o`0000Kooooo0_oo0027oooo
o`;o0000A?ooool0027ooooo00?o0000ooooooooool0Joooool2o`0000Oooooo00?oo`00oooooooo
ool0Poooool2ool000Cooooo00?o0000ooooooooool0@Oooool0027ooooo00?o0000ooooooooool0
J_ooool00ol0003oooooooooo`05ooooo`;oo`00R?ooool2ool000?ooooo0_l00011ooooo`008Ooo
ool3o`0006Sooooo0_l00006ooooo`;oo`00S?ooool2ool000?ooooo0_l0000oooooo`008Oooool0
0ol0003oooooooooo`1Vooooo`;o00001oooool00ooo003oooooooooo`2>ooooo`;oo`000oooool0
0ol0003oooooooooo`0looooo`008Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo
00Gooooo0_oo002Cooooo`;oo`000_ooool2o`0003cooooo000Qooooo`03o`000?oooooooooo06?o
oooo0_l00006ooooo`;oo`00Uoooool2ool000;ooooo00?o0000ooooooooool0>Oooool0027ooooo
00?o0000ooooooooool0HOooool2o`0000Oooooo00?oo`00ooooooooool0VOooool2ool00003oooo
ool0003o000003Wooooo000Qooooo`03o`000?oooooooooo05oooooo0_l0002Wooooo`04ool00?oo
ooooooooo`0003Sooooo000Qooooo`03o`000?oooooooooo05gooooo0_l0002]ooooo`;o0000=_oo
ool0027ooooo00?o0000ooooooooool0Foooool2o`000;7ooooo00?o0000ooooooooool0<oooool0
027ooooo0ol0001Jooooo`03o`000?oooooooooo0;;ooooo0_l0000cooooo`008Oooool00ol0003o
ooooooooo`0mooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`;o00001Oooool2ool002oooooo1?l000000ol@413oooooooooo`0k
ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@0Zooooo`;o00004Oooool5o`0001_ooooo000Qooooo`03o`000?oooooooooo03gooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`02ooooo`;o00001Ooo
ool2ool003?ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0Yooooo`;oo`0000?o0000ooooooooool03_ooool01OnHV9So8B4Qonk^
k_ooooooA4A401_ooooo000Qooooo`03o`000?oooooooooo03gooooo00Go410@oooooooooooooooo
oa0@400@ooooo`04o`000?oooooo0000o`0000Cooooo0ooo000eooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Zooooo`;oo`0000?o0000oooooooo
ool03Oooool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003oooooooooo`0mooooo`05o`00
0?ooooooooooooooool000003oooool00omgMgOo0000o`000004ooooo`;oo`00>?ooool00ol0003o
ooooooooo`0oooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0;Oooool2ool00003
o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0
3oooool5ool000[ooooo2?oo000Gooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?l0003oc<c<00?ooooo0_oo000jooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<033ooooo0_oo000>ooooo`03ogMgMomVIVKo
oooo01[ooooo000Qooooo`03o`000?oooooooooo00cooooo0ooo0006ooooo`;o00003oooool3ool0
01Cooooo00Go410@oooooooooooooooooa0@400<ooooo`;o00001?ooool2ool003cooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Cooooo0_oo000=
ooooo`03o`000?oooooooooo01Wooooo000Qooooo`?o00002_ooool2ool000;ooooo2?l000000ooo
oooo0000o`000008o`0000Sooooo0ooo000Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool3
o`0000?ooooo0_oo000nooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0fooooo`;oo`001oooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Q
ooooo`03o`000?oooooooooo00Sooooo0_oo0004o`0001?ooooo1Ol00006ooooo`;oo`003oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l00002ooooo`Co0000?_ooool00omEEEGoIVIVo`00
000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000gooooo`03ool00?l0003ooooo00Cooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00Kooooo`008Oooool00ol0003oooooooooo`06ooooo`;oo`000_l0
000Looooo`?o00007oooool2o`000=Cooooo00?oo`00o`000?ooool08oooool0027ooooo00?o0000
ooooooooool01Oooool00ooo003o0000o`00000Qooooo`?o00003?oooolAool00=Kooooo00?oo`00
o`000?l000008_ooool0027ooooo00?o0000ooooooooool00_ooool3o`0002Oooooo1ol0000:oooo
o`Go0000h?ooool2o`00023ooooo000Qooooo`03o`000?oooooooooo00;o0000<Oooool:o`000>Oo
oooo00?o0000ooooooooool04oooool2o`0000;ooooo0_l00004ooooo`008Oooool3o`000?oooooo
9_ooool2o`0001?ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooooooo`0003[o
00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool01?o^k^ko8B4Qoa0@4?o^k^h5oooo
o`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool04Oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003oooooooooo`3ooooooc_o
oooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03
o`000?oooooooooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0
003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`00
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
01Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooooooo
o`04ooooo`?o0000oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooo
odGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`00
6?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo002Xooooo`03ogMgMomVIVKooooo01Oooooo00?oIVIVogMgMoooool0Xoooool008Oooooo
0ol0000Cooooo`03ob4Q8OoMgMgooooo00Oooooo00?ogMgMoa0@4?o^k^h06?ooool00oo^k^ko410@
omgMg@2Sooooo`00O_ooool01on7QhOo0000oeEEEOmVIVKo0000oc8b<_o^k^h00oooool00ol0003o
ooooooooo`0;ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool00onHV9SoEEEEooooo`07oooo
o`04oeEEEOnHV9Soooooooooo`Go00002Oooool00omEEEGoZJVYooooo`02ooooo`03okZj^_m4A4Co
oooo00;ooooo00?oQhN7ofIVI_ooool04oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0Noooool007kooooo00Oo410@omgMgOmgMgOo8B4Qoooo
oon7QhOoIVIV00?ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?o
oooo00?o0000omgMgOooool01_ooool02Ol0003oooooooooooooooooV9RHob4Q8Oo^k^koooooodA4
A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj0oooool00oo^k^ko0000ooooo`0;ooooo`Ko
00001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q
07_ooooo001nooooo`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@4003ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01Oooool2ogMgM`Oooooo00?o<S8booooooooool00_ooool0
0onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`0000Gooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool00000Noooool007kooooo00Co
EEEEojVYZOoooooo00000_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000oooooooo
ool01Oooool00oo^k^ko410@onk^kP06ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^
k^h02oooool01?n7QhOoIVIVooooool00005ooooo`03o`000?oooooooooo00[ooooo1_l00004oooo
o`03o`000?oooooooooo00[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@1kooooo`00O_ooool00ooM
gMgo8B4Qonk^kP03ooooo`03o`000?oooooooooo00;o00003Oooool00ol0003oooooooooo`06oooo
o`03oeEEEOnHV9Sooooo00Gooooo00?o0000onk^k_ooool01?ooool00omgMgOoIVIVooooo`0:oooo
o`04omgMgOl@413oooooo`0000Cooooo00?ok^k^o`000?ooool05Oooool00ol0003oooooooooo`0:
ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0Noooool007oooooo00?oV9RHogMgMoooool00_ooool0
0ol0003oooooooooo`0=ooooo`03oa0@4?l0003o000000?o00001Oooool00ooMgMgo410@ooooo`05
ooooo`03oeEEEOmgMgOooooo00Gooooo00?o0000ooooooooool02?ooool7o`0000;ooooo00?oMgMg
oeEEEOooool05Oooool00ol0003oooooooooo`0:ooooo`03oeEEEOn7QhOooooo07gooooo002Foooo
o`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool02OoMgMgo410@onk^k_oooooo
0000okZj^_ooooooV9RHoa0@400Booooo`03onk^k_l@413ogMgM01Kooooo00?o0000ooooooooool0
2_ooool00ooMgMgo410@oiRHV01mooooo`00U_ooool00ol0003oooooooooo`07ooooo`03okZj^_m4
A4Cooooo00Gooooo00SoMgMgofIVI_ooooooV9RHoa0@4?l0003o8B4Qolc<c1;ooooo00?oIVIVogMg
Moooool05?ooool00omEEEGoIVIVo`00000=ooooo`04olc<c?m4A4Co0000oa0@47_ooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.65) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .2729 L
.06244 .23786 L
.08426 .20581 L
.0949 .19333 L
.10458 .18398 L
.11403 .17675 L
.12297 .17168 L
.12787 .16962 L
.1324 .16817 L
.13476 .16758 L
.13737 .16707 L
.13868 .16686 L
.14009 .16668 L
.14142 .16654 L
.14264 .16645 L
.14392 .16638 L
.14514 .16635 L
.14622 .16635 L
.1474 .16637 L
.14869 .16642 L
.14934 .16646 L
.15005 .16651 L
.15132 .16662 L
.15248 .16676 L
.15476 .16709 L
.15721 .16755 L
.16162 .16864 L
.16672 .17032 L
.17226 .1726 L
.18234 .1779 L
.20212 .19176 L
.22313 .2098 L
.26088 .24447 L
.28185 .2622 L
.30108 .27638 L
.32112 .28865 L
.33977 .29763 L
.35869 .30437 L
.3687 .30702 L
.37939 .30919 L
.38963 .31067 L
.39541 .31125 L
.39816 .31147 L
.40074 .31164 L
.40317 .31178 L
.4054 .31187 L
.40787 .31195 L
.40923 .31198 L
.41053 .31201 L
Mistroke
.41177 .31202 L
.41247 .31203 L
.4131 .31203 L
.41433 .31203 L
.41548 .31202 L
.41614 .31202 L
.41684 .31201 L
.41808 .31199 L
.41942 .31196 L
.42089 .31192 L
.42341 .31184 L
.42615 .31171 L
.43112 .31142 L
.43596 .31104 L
.44044 .31062 L
.46137 .30786 L
.48007 .3045 L
.50068 .30011 L
.54094 .29065 L
.57968 .28184 L
.59937 .27788 L
.62087 .27411 L
.64167 .27113 L
.66055 .26903 L
.67066 .26815 L
.6802 .26749 L
.69026 .26696 L
.69594 .26674 L
.69867 .26665 L
.70116 .26659 L
.70341 .26654 L
.70585 .26649 L
.70719 .26647 L
.70843 .26646 L
.7097 .26644 L
.71088 .26643 L
.71189 .26643 L
.71297 .26642 L
.71418 .26642 L
.71528 .26642 L
.71637 .26642 L
.71756 .26642 L
.7188 .26643 L
.71996 .26644 L
.72125 .26645 L
.72265 .26647 L
.72519 .26651 L
.72994 .26661 L
.73549 .26678 L
.74062 .26698 L
Mistroke
.75029 .26748 L
.75936 .26808 L
.77999 .26993 L
.80025 .27235 L
.81878 .27503 L
.85851 .28207 L
.89672 .29013 L
.93739 .29959 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .27083 L
.06244 .23352 L
.08255 .20253 L
.09396 .18883 L
.10458 .17875 L
.10961 .17489 L
.11508 .17135 L
.11989 .16879 L
.125 .16664 L
.12959 .16519 L
.13221 .16456 L
.13466 .1641 L
.13581 .16393 L
.1369 .16378 L
.13789 .16368 L
.13895 .16358 L
.1401 .16351 L
.14116 .16346 L
.14243 .16343 L
.14357 .16344 L
.14477 .16346 L
.1459 .16352 L
.14713 .1636 L
.14845 .16372 L
.15114 .16406 L
.1536 .16448 L
.15833 .16558 L
.16282 .16697 L
.17279 .17113 L
.18364 .17718 L
.20341 .19147 L
.22442 .20986 L
.26217 .24623 L
.30238 .28264 L
.34106 .31012 L
.3611 .32056 L
.3713 .32483 L
.3822 .32862 L
.39255 .3315 L
.40194 .33352 L
.40648 .3343 L
.41139 .33501 L
.41569 .33551 L
.42031 .33594 L
.42287 .33612 L
.4252 .33626 L
.42755 .33637 L
.42978 .33644 L
.43103 .33647 L
Mistroke
.43171 .33649 L
.43236 .3365 L
.43362 .33651 L
.43476 .33652 L
.43542 .33652 L
.43612 .33652 L
.43737 .33651 L
.43806 .33651 L
.43871 .3365 L
.44019 .33647 L
.4415 .33644 L
.44292 .33639 L
.44551 .33628 L
.45035 .336 L
.456 .33555 L
.46123 .33502 L
.47993 .33232 L
.50055 .32819 L
.5408 .31808 L
.57954 .3079 L
.59923 .30319 L
.62074 .2987 L
.64154 .29516 L
.66041 .2927 L
.67053 .29169 L
.68006 .29093 L
.69013 .29032 L
.6958 .29007 L
.70102 .28989 L
.70571 .28977 L
.70834 .28973 L
.71074 .28969 L
.71183 .28968 L
.71298 .28967 L
.71424 .28966 L
.71541 .28966 L
.71649 .28965 L
.71751 .28965 L
.71862 .28965 L
.71983 .28965 L
.72112 .28966 L
.72233 .28967 L
.72365 .28968 L
.72507 .28969 L
.72796 .28973 L
.7306 .28978 L
.73568 .2899 L
.74048 .29005 L
.75019 .29043 L
.76047 .29095 L
Mistroke
.77891 .29214 L
.81677 .29516 L
.85708 .29863 L
.89587 .3019 L
.93711 .30548 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool07_ooool3ool00?oooooo9?ooool0027ooooo0ol0000Looooo`;o
o`0000?oooooo`000?l000001ol0003ooooooagooooo000Qooooo`03o`000?oooooooooo01Wooooo
0ooo0003o`0000Wooooo0ol00003ool00?oooooo5oooool0027ooooo00?o0000ooooooooool06?oo
ool01?oo003oooooooooool0000@ooooo`;o000000?oo`00ooooooooool0oooooolDooooo`008Ooo
ool00ol0003oooooooooo`0Hooooo`03ool00?l0003o000001Cooooo0_oo003ooooooaCooooo000Q
ooooo`03o`000?oooooooooo01Kooooo0_oo00000ol0003oooooooooo`0Fooooo`03ool00?oooooo
oooo0?oooooo4Oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool05Oooool00ooo003oooooo`00
000Jooooo`03ool00?oooooooooo0?oooooo4?ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01Cooooo00?o
o`00ooooool000007?ooool00ooo003oooooooooo`3oooooo`oooooo0005o`0000;ooooo00Go410@
oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0000Cooooo`03ool00?oo
oooo000001kooooo00?oo`00ooooooooool0ooooool>ooooo`001oooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo01kooooo0_oo003oooooo`kooooo0007ooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Qooooo`03ool00?oooooooooo0?oooooo2oooool000Oooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Sooooo`03ool00?l0003ooooo0?oooooo2_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo0?oooooo2?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool0ooooool7ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0ooooool6ooooo`008Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0ooooool5ooooo`008Oooool3o`00
00kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`3oooooo`Cooooo000Qooooo`03
o`000?oooooooooo00gooooo00?oo`00o`000?ooool0;oooool00ol0003oooooooooo`3oooooo`?o
oooo000Qooooo`03o`000?oooooooooo00gooooo00?oo`00ooooooooool0<?ooool00ooo003ooooo
ooooo`3oooooo`;ooooo000Qooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0<_oo
ool00ooo003oooooooooo`3oooooo`7ooooo000Qooooo`03o`000?oooooooooo00_ooooo00?oo`00
ooooooooool0=?ooool00ooo003oooooooooo`3oooooo`008Oooool00ol0003oooooooooo`0:oooo
o`03ool00?l0003ooooo03Kooooo00?oo`00ooooooooool0o_ooool0027ooooo00?o0000oooooooo
ool02Oooool00ooo003o0000ooooo`0hooooo`03ool00?oooooooooo0?gooooo000Qooooo`?o0000
2Oooool00ooo003oooooooooo`0iooooo`03ool00?oooooooooo0?cooooo000Qooooo`03o`000?oo
oooooooo00Sooooo00?oo`00o`000?ooool0>oooool00ooo003oooooooooo`3kooooo`008Oooool0
0ol0003oooooooooo`08ooooo`03ool00?oooooooooo03cooooo00?oo`00o`000?ooool0n_ooool0
027ooooo00?o0000ooooooooool01oooool00ooo003o0000ooooo`0nooooo`03ool00?l0003ooooo
0?Wooooo000Qooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool0?oooool00ooo003o
0000ooooo`3hooooo`008Oooool00ol0003oooooooooo`06ooooo`03ool00?l0003ooooo047ooooo
00?oo`00o`000?ooool0moooool0027ooooo00?o0000ooooooooool01_ooool00ooo003ooooooooo
o`12ooooo`03ool00?l0003ooooo0?Kooooo000Qooooo`03o`000?oooooooooo00Gooooo00?oo`00
ooooooooool0AOooool00ol0003oooooooooo`3dooooo`008Oooool3o`0000Gooooo00?o0000oooo
ooooool0A_ooool2o`000?Cooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0=_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo03;ooooo7?l000000olb<S;ogMgMooooo`0l
ooooo`Go00006oooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0foooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo0_l0000oooooo`03o`000?oooooo
oooo02cooooo2?l0000;ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`_o0000=_ooool0
1OnHV9So8B4Qonk^k_ooooooA4A401_ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0=oooool01Ol@413ooooooooooooooooo410@013ooooo0_l0000nooooo`03o`000?oo
oooooooo027ooooo2ol0000Cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Ooo
ool6o`00037ooooo00?oV9RHob4Q8Oo^k^h07?ooool0027ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0gooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8boooo
o`02o`0003cooooo00?o0000ooooooooool07_ooool3o`0001kooooo00?o0000ooooooooool03_oo
ool00omgMgOo<S8booooo`0<ooooo`Ko0000;?ooool00onHV9So8B4Qonk^kP0Kooooo`008Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Sooooo00Go0000ooooooooooooooooo`00
000<ooooo`06o`000?lQ8B7o0000oc8b<_o<c<coo`000_ooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo01Wooooo1Ol0000Qooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c00Cooooo`Ko00009oooool00omgMgOoIVIVooooo`0Jooooo`008Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo03Sooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo00?ooooo0_oo00000ooooooo0000o`00000iooooo`03o`000?oooooooooo
01Cooooo1Ol0000Vooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06oooool6o`00
02;ooooo00?o0000ooooooooool06Oooool0027ooooo0ol000000ooooooo0000ooooo`0jooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`05ooooo`04ool00?oooooooooo
o`0003Sooooo00?o0000ooooooooool04?ooool4o`0002_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Qooooo`Ko00006?ooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Q
ooooo`05o`000?ooooooooooooooool00000>oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l00005ooooo`;oo`0000?oooooo`000?l00000=?ooool00omEEEGoIVIVo`00000>ooooo`Co0000
:Oooool5ool00003ofIVI_l0003ooooo00Oooooo0ooo0002ooooo`Co00009_ooool5o`0001?ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c00Kooooo`008Oooool01?l0003ooooooooooooo001Hooooo`03
ool00?oooooooooo00;o0000?oooool4o`0002;ooooo2ooo000Booooo`coo`009Oooool5o`0002ko
oooo000Qooooo`04o`000?oooooo0000ool005Wooooo0_oo0002ooooo`;o0000>?ooool5o`0005Wo
oooo1ooo000Iooooo`Co0000:_ooool0027ooooo00?o0000oooooooo0000G?ooool01?oo003ooooo
ooooooooool3o`00037ooooo1?l0000Nooooo`?oo`00A?ooool9ool001Cooooo1?l0000Vooooo`00
8Oooool00ol0003oo`00ooooo`1Mooooo`;oo`001?ooool3o`0002Wooooo1Ol0000Oooooo`?oo`00
F_ooool7ool000Oooooo1?l0000Hooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oo
003ooooo05oooooo00?oo`00ooooooooool01?ooool3o`00023ooooo1_l0000Oooooo`Goo`00I?oo
ool8ool000?ooooo1?l0000Dooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool001[ooooo
1ol000000ooo003o0000o`00001Po`000003ool00?l0003o000004Oo00001?oo001ao`0000;oo`00
3_l0000<ooooo`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01ooooolEo`0000kooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`05ooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo
00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000ooooooooool0W?ooool3ool009_ooooo
0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool0V?ooool4ool00:Sooooo000Q
ooooo`03o`000?oooooooooo06[ooooo0ooo000Wooooo`Coo`00[?ooool0027ooooo00?o0000oooo
ooooool0KOooool3ool0027ooooo0ooo002`ooooo`008Oooool00ol0003oooooooooo`1`ooooo`?o
o`007?ooool2ool00;?ooooo000Qooooo`?o0000Loooool5ool00<cooooo000Qooooo`03o`000?oo
oooooooo07Sooooo0_oo0003ooooo`Soo`00_oooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3
o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo
0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
0oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodGooooo
0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Co
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oo
ooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGo
oooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
AOooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00Y?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:Oooooo
0023ooooo`?o00005?ooool00olQ8B7ogMgMooooo`06ooooo`03omgMgOl@413ok^k^01Sooooo00?o
k^k^oa0@4?oMgMd0Yoooool007_ooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00;ooooo
00?o0000ooooooooool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?oV9RHoeEEEOoo
ool01_ooool00omEEEGoV9RHooooo`02ooooo`Go00002Oooool00omEEEGoZJVYooooo`02ooooo`06
okZj^_m4A4Cooooooooooon7QhOoIVIV5Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01?ooool01Om4A4Co0000o`000?lb<S;ogMgM07Gooooo
001kooooo`07oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP02ooooo`03o`000?oooooooooo00_o
oooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oMgMgooooo00Gooooo00?o0000oooo
ooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@
4?nj^[X2ooooo`03onk^k_l0003ooooo00_ooooo1_l00005ooooo`03o`000?oooooooooo00Cooooo
0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401oooool00omgMgOo<S8booooo`1dooooo`00
Noooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@41000_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Kooooo0_mgMgL6ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q
8Oo^k^h03?ooool01?l@413ogMgMooooool00004ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool02_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0Looo
ool007_ooooo00CoEEEEojVYZOoooooo00000_ooool01?l0003oooooooooool0000=ooooo`03o`00
0?oooooooooo00Kooooo00?ok^k^oa0@4?o^k^h01Oooool00olb<S;oooooooooo`04ooooo`03oiRH
V?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001?ooool00ol0003oooooooooo`0:ooooo`Ko
00001Oooool00ol0003oooooooooo`0:ooooo`05o`000?nHV9SooooooiRHV?lQ8B401oooool00omg
MgOo<S8booooo`1dooooo`00Noooool00ooMgMgo8B4Qonk^kP03ooooo`04o`000?oooooo0000o`00
00gooooo00?o0000ooooooooool01oooool00omEEEGoV9RHooooo`04ooooo`03o`000?o^k^kooooo
00Gooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgo410@ooooool00003ooooo`03onk^k_l0003o
oooo01Kooooo00?o0000ooooooooool02_ooool01Ol0003oEEEEo`000?l@413oc<c<00Cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c01eooooo`00O?ooool00onHV9SoMgMgooooo`02ooooo`03o`000?oo
oooooooo00cooooo00?o410@o`000?l000000ol00006ooooo`03omgMgOl@413ooooo00Cooooo00?o
EEEEogMgMoooool01_ooool00ol0003oooooooooo`08ooooo`Oo000000?oooooogMgMomEEED05ooo
ool00ol0003oooooooooo`0:ooooo`03oeEEEOn7QhOooooo00Kooooo00?o0000ooooooooool0Mooo
ool009;ooooo00?o0000ooooooooool02?ooool00omEEEGoV9RHooooo`03ooooo`03omgMgOl@413o
k^k^00;ooooo00Go0000okZj^_ooooooV9RHoa0@400Aooooo`03onk^k_l@413ogMgM01Oooooo00?o
0000ooooooooool02_ooool00ooMgMgo410@oiRHV006ooooo`03o`000?oooooooooo07Oooooo002B
ooooo`03o`000?oooooooooo00Sooooo00?o^[ZjodA4A?ooool01?ooool02OmgMgOoIVIVoooooooo
ooooV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`03ofIVI_mgMgOooooo01Gooooo00?oEEEEofIVI_l0
00003Oooool01?o<c<coA4A4o`000?l@4104ooooo`Co0000M_ooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .22809 L
.08255 .19129 L
.10458 .15782 L
.11448 .14552 L
.12507 .13442 L
.13499 .12602 L
.14415 .12002 L
.14911 .11749 L
.15437 .11536 L
.15964 .11379 L
.16265 .11315 L
.16399 .11292 L
.16546 .11271 L
.1668 .11256 L
.16805 .11246 L
.16925 .11238 L
.17052 .11233 L
.17178 .11232 L
.17296 .11234 L
.17401 .11237 L
.17516 .11244 L
.17642 .11254 L
.1778 .11269 L
.1806 .1131 L
.18318 .11362 L
.1856 .11422 L
.1906 .11582 L
.19605 .11808 L
.20595 .12357 L
.21559 .13051 L
.22451 .13824 L
.26377 .18409 L
.30152 .23854 L
.34173 .29654 L
.38041 .34459 L
.40006 .36475 L
.42155 .38326 L
.44231 .39766 L
.46118 .40792 L
.48079 .41591 L
.49156 .41924 L
.50174 .42173 L
.51146 .42356 L
.51678 .42434 L
.52175 .42494 L
.52634 .42539 L
.53054 .4257 L
.53277 .42584 L
.5352 .42596 L
Mistroke
.53777 .42606 L
.53895 .42609 L
.5402 .42612 L
.54154 .42615 L
.54277 .42617 L
.54409 .42618 L
.54484 .42618 L
.54553 .42618 L
.5468 .42618 L
.54796 .42617 L
.5486 .42616 L
.54929 .42615 L
.55055 .42613 L
.55291 .42606 L
.55542 .42598 L
.55992 .42576 L
.56507 .42542 L
.5699 .42501 L
.5809 .42381 L
.60112 .42068 L
.61964 .41695 L
.65932 .40694 L
.69748 .39568 L
.73809 .38286 L
.77719 .37025 L
.81874 .35694 L
.85877 .34438 L
.89729 .33258 L
.93826 .32028 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .22922 L
.08255 .19343 L
.10458 .16071 L
.11448 .14865 L
.12507 .13779 L
.13499 .12961 L
.14415 .12385 L
.14911 .12146 L
.15437 .11948 L
.15691 .11873 L
.15964 .11808 L
.16121 .11777 L
.16265 .11754 L
.16401 .11735 L
.16546 .1172 L
.16615 .11714 L
.1668 .1171 L
.16802 .11703 L
.16916 .117 L
.17039 .117 L
.17104 .11701 L
.17176 .11703 L
.1725 .11707 L
.1732 .11711 L
.17445 .11721 L
.17578 .11735 L
.17842 .11774 L
.18092 .11823 L
.1856 .11948 L
.19019 .12111 L
.19525 .12337 L
.20551 .12936 L
.22393 .14447 L
.24327 .16549 L
.26413 .19264 L
.30527 .25379 L
.34489 .31332 L
.383 .36365 L
.40425 .38708 L
.42356 .40508 L
.44388 .42056 L
.46261 .43177 L
.48179 .44037 L
.4919 .44381 L
.50259 .44671 L
.51203 .44865 L
.51723 .4495 L
.52216 .45017 L
.52674 .45066 L
Mistroke
.53173 .45108 L
.53393 .45122 L
.53627 .45135 L
.53828 .45144 L
.54048 .45151 L
.54183 .45155 L
.54309 .45157 L
.54379 .45158 L
.54443 .45159 L
.54516 .4516 L
.54585 .4516 L
.54708 .4516 L
.54822 .4516 L
.54947 .45159 L
.5501 .45158 L
.55079 .45157 L
.55224 .45154 L
.55356 .45151 L
.55654 .45141 L
.55917 .45129 L
.56193 .45114 L
.57158 .45038 L
.57704 .44981 L
.58211 .4492 L
.60261 .44596 L
.62121 .44212 L
.66124 .43159 L
.69976 .4192 L
.74073 .40425 L
.78019 .38869 L
.81813 .37332 L
.85852 .35706 L
.8974 .34155 L
.93873 .32458 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool09oooool9o`000?oooooo5Oooool0027ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`07ooooo`?o0000oooooolBooooo`008Oooool3o`0002;ooooo1?l00009ooooo`;o
o`000_ooool3o`000?oooooo3oooool0027ooooo00?o0000ooooooooool08Oooool01?l0003ooooo
oooooooo000<ooooo`Coo`0000?oooooo`000?ooool0ooooool=ooooo`008Oooool00ol0003ooooo
ooooo`0Pooooo`04o`000?ooooooo`00ool0017ooooo00?oo`00ooooool00000ooooool=ooooo`00
8Oooool00ol0003oooooooooo`0Oooooo`03o`000?oo003oo`0001Cooooo0_oo00000ol0003ooooo
ooooo`3oooooo`[ooooo000Qooooo`03o`000?oooooooooo01kooooo00?o0000ool00?ooool05ooo
ool00ooo003o0000o`00003oooooo`[ooooo000Qooooo`03o`000?oooooooooo01gooooo00?o0000
ool00?ooool06Oooool00ooo003oooooo`00003oooooo`Wooooo000Qooooo`03o`000?oooooooooo
01cooooo00?o0000ool00?ooool06oooool00ooo003oooooo`00003oooooo`Sooooo000Qooooo`?o
00006oooool00ol0003oo`00ooooo`0Mooooo`03ool00?l0003ooooo0?oooooo1oooool0027ooooo
00?o0000ooooooooool06_ooool00ol0003oo`00ooooo`0Oooooo`03ool00?l0003ooooo0?oooooo
1_ooool0027ooooo00?o0000ooooooooool06_ooool00ooo003oooooooooo`0Qooooo`03o`000?oo
oooooooo0?oooooo1?ooool0027ooooo00?o0000ooooooooool06Oooool00ooo003oooooooooo`0S
ooooo`03o`000?oooooooooo0?oooooo0oooool0027ooooo00?o0000ooooooooool06?ooool00ooo
003oooooooooo`0Uooooo`03o`000?oooooooooo0?oooooo0_ooool0027ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0?oooooo0Oooool0027ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0?oooooo
000Qooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`3oooooo`008Oooool3o`0001Gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`3n
ooooo`008Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02_ooooo00?oo`00o`00
0?ooool0o_ooool0027ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0/ooooo`03
ool00?oooooo00000?kooooo000Qooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
;_ooool00ooo003oooooo`00003mooooo`008Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo02oooooo00?oo`00ooooool00000o?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0
4_ooool00ooo003oooooooooo`0aooooo`03ool00?oooooo00000?_ooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooo
ooooo`0Booooo`03ool00?oooooooooo037ooooo00?oo`00ooooool00000noooool000Go00000_oo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`00017ooooo
00?oo`00ooooooooool0<oooool00ooo003oooooo`00003jooooo`001oooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0@ooooo`03ool0
0?oooooooooo03Gooooo00?oo`00ooooool00000nOooool000Oooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0@ooooo`03
ool00?oooooooooo03Gooooo00?oo`00ooooool00000nOooool000Oooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03oooool00ooo003o
ooooooooo`0gooooo`03ool00?oooooo00000?Sooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?oo`00oooooooo
ool0>Oooool00ooo003oooooo`00003gooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00005ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0>Oooool01?oo003o
ooooooooool0003fooooo`008Oooool00ol0003oooooooooo`0=ooooo`03ool00?oooooooooo03_o
oooo00?oo`00ooooool00000m_ooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oo`00
ooooo`0mooooo`03ool00?oooooo00000?Gooooo000Qooooo`?o00003?ooool00ooo003ooooooooo
o`10ooooo`03o`000?oooooooooo0?;ooooo000Qooooo`03o`000?oooooooooo00_ooooo00?oo`00
ooooooooool0@Oooool00ol0003oooooooooo`3booooo`008Oooool00ol0003oooooooooo`0;oooo
o`03ool00?oooooooooo04;ooooo00?o0000ooooooooool0lOooool0027ooooo00?o0000oooooooo
ool02_ooool00ooo003oooooooooo`14ooooo`03o`000?oooooooooo0?3ooooo000Qooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`3_ooooo`008Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0kooo
ool0027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo0>kooooo000Qooooo`?o00002?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo
0>gooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0BOooool00ooo003o
0000ooooo`3^ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Wooooo
00?oo`00ooooool00000k_ooool0027ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1;ooooo`03ool00?oooooo00000>gooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0Boooool01?oo003oooooooooool0003/ooooo`008Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo04gooooo00?oo`00ooooool00000k?ooool0027ooooo00?o0000oooo
ooooool01Oooool00ooo003oooooooooo`1=ooooo`04ool00?ooooooooooo`000>_ooooo000Qoooo
o`03o`000?oooooooooo00Cooooo00?o0000ool00?ooool0Coooool01?oo003oooooooooool0003Z
ooooo`008Oooool3o`0000Cooooo00?oo`00ooooooooool0D?ooool00ooo003oooooo`00003Zoooo
o`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oo003ooooo03Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00Coo`00
oooooooooooo0000=Oooool4o`000003oa0@4?oooooooooo03_ooooo1?l000000ol@413ooooooooo
o`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03gooooo1Ol0000Kooooo`008Ooo
ool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo03Oooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`04ool00?ooooooooooo`0003Ko
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`0looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0027ooooo00?o0000oooooooo
ool00oooool00ooo003oooooooooo`0gooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`04ooooo`04ool00?ooooooooooo`0003Gooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03cooooo00?oV9RHob4Q8Oo^k^h07?ooool0
027ooooo00?o0000ooooooooool00_ooool00ol0003oo`00ooooo`0hooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`05ooooo`04ool00?ooooooooooo`0003Gooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03kooooo00?o
V9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0h
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Oooooo
00Coo`00oooooooooooo0000=?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c010ooooo`03ogMgMomVIVKooooo01[ooooo000Qooooo`06
o`000?ooooooooooooooool0003oo`00>_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool02_ooool01?oo003oooooooooool0000cooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Wooooo
000Qooooo`?o000000?oooooool00?ooool0>_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0oooooo`05o`000?nj^[[ooooooiRHV?l@
41006oooool0027ooooo00Go0000oooooooooooo0000ool0000kooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000gooooo00?o0000ooooooooool0;_ooool00omEEEGoIVIVo`00000ooooo
o`03oeEEEOmVIVKo000000gooooo1?l0000nooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`06oooool0
027ooooo00Co0000ooooooooooooo`00Goooool00ol0003oooooooooo`3Qooooo`008Oooool01?l0
003oooooo`000?oo001Pooooo`03o`000?oooooooooo0>3ooooo000Qooooo`04o`000?oooooo0000
ool0063ooooo00?o0000ooooooooool0h?ooool0027ooooo0_l000000ooo003oooooooooo`1Poooo
o`03o`000?oooooooooo0=Gooooo0_l00002ooooo`;o00001?ooool0027ooooo0_l0001Tooooo`03
o`000?oooooooooo0=Cooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooooooo`00
037o00000_oo0007o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01oooool01Ooo003ooooooooooooooooo000000kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo0ooo00000ooooooo0000ooooo`0B
ooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00Coo`00
oooooooooooo00003_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool01Oooool00ol0003oo`00ool00004ooooo`03o`000?oooooooooo017ooooo00Co
8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000ooooooooool0H_ooool01Ooo003ooooooooo
oooooooo00000;Kooooo0_l00002ool001Wooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o
0000ooooooooool0Hoooool01Ooo003ooooooooooooooooo00000;7ooooo0ol00003ool002Gooooo
000Qooooo`03o`000?oooooooooo06Cooooo00Goo`00ooooooooooooooooo`00002]ooooo`?o0000
0_ooool00ooo003oooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`1Uooooo`05ool00?oo
ooooooooooooool00000ZOooool3o`0002kooooo000Qooooo`03o`000?oooooooooo06Gooooo00Go
o`00ooooooooooooooooo`00002Vooooo`?o0000<Oooool0027ooooo0ol0001Vooooo`05ool00?oo
ooooooooooooool00000XOooool4o`0003Cooooo000Qooooo`03o`000?oooooooooo06Oooooo00Go
o`00ooooooooooooooooo`00002Looooo`Co00001?ooool2ool003;ooooo000Qooooo`03o`000?oo
oooooooo06Sooooo00Goo`00ooooooooooooooooo`00002Gooooo`Co00001oooool00ooo003ooooo
ooooo`0booooo`008Oooool00ol0003oooooooooo`1Xooooo`03ool00?oooooooooo00;ooooo00?o
0000ooooooooool0TOooool3o`0000Wooooo0_oo000eooooo`008Oooool00ol0003oooooooooo`1Y
ooooo`05ool00?ooooooooooooooool00000T?ooool3o`0000Wooooo0ooo000gooooo`008Oooool0
0ol0003oooooooooo`1Zooooo`05ool00?ooooooooooooooool00000S?ooool3o`0000Wooooo0ooo
000jooooo`008Oooool00ol0003oooooooooo`1[ooooo`05ool00?ooooooooooooooool00000R?oo
ool3o`0000Wooooo0ooo000mooooo`008Oooool3o`00073ooooo00?o0000ooooooooool0POooool4
o`0000[ooooo0_oo0010ooooo`008Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo
07gooooo0ol0001@ooooo`008Oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07Wo
oooo0ol0001Cooooo`008Oooool00ol0003oooooooooo`1cooooo`;o0000M_ooool3o`0005Kooooo
000Qooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0Koooool4o`0000cooooo0_oo
001;ooooo`008Oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo06_ooooo0ol0000=
ooooo`?oo`00COooool0027ooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`1Woooo
o`?o00003_ooool2ool0053ooooo000Qooooo`03o`000?oooooooooo07;ooooo00?oo`00oooooooo
ool00oooool00ol0003oooooooooo`1Sooooo`?o00003_ooool3ool005;ooooo000Qooooo`?o0000
L_ooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo05oooooo0ol0000?ooooo`;oo`00
EOooool0027ooooo00?o0000ooooooooool0Loooool00ooo003oooooooooo`04ooooo`;o0000G?oo
ool3o`00013ooooo0_oo001Gooooo`008Oooool00ol0003oooooooooo`1dooooo`;oo`001_ooool0
0ol0003oooooooooo`1Fooooo`?o00004_ooool00ooo003oooooooooo`1Gooooo`008Oooool00ol0
003oooooooooo`1fooooo`03ool00?oooooooooo00Cooooo0_l0001Cooooo`?o0000Koooool0027o
oooo00?o0000ooooooooool0Moooool00ooo003oooooooooo`05ooooo`03o`000?oooooooooo04go
oooo0ol0001booooo`008Oooool00ol0003oooooooooo`1hooooo`03ool00?oooooooooo00Gooooo
0_l0001:ooooo`?o0000MOooool0027ooooo00?o0000ooooooooool0NOooool00ooo003ooooooooo
o`06ooooo`;o0000AOooool3o`0001;ooooo0_oo001Tooooo`008Oooool3o`0007[ooooo00?oo`00
ooooooooool01oooool2o`00043ooooo0ol0000Cooooo`;oo`00I_ooool0027ooooo00?o0000oooo
ooooool0Noooool00ooo003oooooooooo`08ooooo`;o0000>_ooool4o`0001?ooooo0ooo001Xoooo
o`008Oooool00ol0003oooooooooo`1looooo`03ool00?oooooooooo00Wooooo0_l0000cooooo`Go
00005Oooool2ool006_ooooo000Qooooo`03o`000?oooooooooo07gooooo00?oo`00ooooooooool0
2_ooool2o`0002gooooo1?l0000Hooooo`;oo`00KOooool0027ooooo00?o0000ooooooooool0S?oo
ool3o`0002Kooooo1?l0000Iooooo`?oo`00Koooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0
Soooool3o`0001gooooo1_l0000Looooo`03ool00?oooooooooo073ooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooo
ooooo`2Booooo`Oo00004Oooool5o`0009Gooooo0007ooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol0003oooooooooo`02ooooo`?o0000VOoooolAo`0009[ooooo0007ooooo`05o`000?oo
ooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0<Gooooo
0_oo001mooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o
<S8bolc<c004ooooo`03o`000?oooooooooo08Kooooo0ooo000iooooo`?oo`00Ooooool000Oooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0ROooool3ool003;ooooo1?oo0022ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2<ooooo`?oo`00:oooool4ool008Ko
oooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000oooooooo
ool0Soooool4ool002Cooooo0ooo002:ooooo`008Oooool00ol0003oooooooooo`2Cooooo`;oo`00
[oooool0027ooooo00?o0000ooooooooool0UOooool00ooo003oooooooooo`0?ooooo`Ooo`00U_oo
ool0027ooooo0ol0002Mooooo`[oo`00WOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co
000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3
o`000?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooo
odGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?o
EEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
Z?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:?ooooo0027ooooo`?o00004ooo
ool00olQ8B7ogMgMooooo`07ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Xooo
ool007kooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool0
2oooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00?oV9RHoeEEEOooool01oooool01?mEEEGo
V9RHooooooooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool00onj^[[oA4A4ooooo`02oooo
o`03ohN7QomVIVKooooo01?ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0
003ok^k^ooooo`1kooooo`00O_ooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00oooool0
0ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0003ogMgMoooo
o`06ooooo`09o`000?oooooooooooooooonHV9So8B4Qonk^k_ooooooA4A400[ooooo00KoEEEEoiRH
V?oooooooooooa0@4?nj^[X3ooooo`03onk^k_l0003ooooo00_ooooo1_l00004ooooo`03o`000?oo
oooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo07_ooooo001nooooo`07o`000?oooooo
gMgMoc8b<_ooooook^k^oa0@4003ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1Oooool2ogMgM`Oooooo00?o<S8booooooooool00_ooool00onHV9So8B4Qonk^kP0<ooooo`04oa0@
4?oMgMgoooooo`0000Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0<ooooo`03
ojVYZOmEEEGooooo07_ooooo001nooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03o`000?oooooooooo00Gooooo00?ok^k^oa0@4?o^k^h01_ooool00olb
<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001Oooool0
0ol0003oooooooooo`0:ooooo`Ko00001?ooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooo
oooo07[ooooo001nooooo`03omgMgOlQ8B7ok^k^00?ooooo00?o0000ooooooooool00_l0000=oooo
o`03o`000?oooooooooo00Kooooo00?oEEEEoiRHV?ooool01Oooool00ol0003ok^k^ooooo`04oooo
o`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo00001?ooool00oo^k^ko0000ooooo`0E
ooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool0N_ooool007oooooo00?oV9RHogMg
Moooool00_ooool00ol0003oooooooooo`0=ooooo`03oa0@4?l0003o000000?o00001Oooool00ooM
gMgo410@ooooo`05ooooo`03oeEEEOmgMgOooooo00Gooooo00?o0000ooooooooool02?ooool7o`00
00;ooooo00?oMgMgoeEEEOooool05Oooool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo
07[ooooo002Fooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool02OoMgMgo
410@onk^k_oooooo0000okZj^_ooooooV9RHoa0@400Booooo`03onk^k_l@413ogMgM01Kooooo00?o
0000ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b07_ooooo002Fooooo`03o`000?oo
oooooooo00Oooooo00?o^[ZjodA4A?ooool01Oooool02?mgMgOoIVIVoooooonHV9So410@o`000?lQ
8B7oc<c<4_ooool00omVIVKoMgMgooooo`0Dooooo`03oeEEEOmVIVKo000000cooooo1Ol0001koooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .25154 L
.10458 .19627 L
.12507 .17427 L
.14415 .15756 L
.16254 .14545 L
.17284 .14055 L
.18221 .13731 L
.18704 .13611 L
.18969 .1356 L
.19216 .1352 L
.19427 .13493 L
.19654 .13471 L
.19783 .13462 L
.19905 .13455 L
.20015 .13451 L
.20135 .13448 L
.20203 .13448 L
.20276 .13448 L
.20345 .13449 L
.20409 .1345 L
.2053 .13454 L
.20657 .13461 L
.20794 .13471 L
.20922 .13482 L
.21213 .13517 L
.21466 .13557 L
.21696 .13602 L
.22214 .1373 L
.22694 .13883 L
.23205 .14082 L
.24122 .1453 L
.26198 .15973 L
.28145 .1783 L
.29973 .1997 L
.33842 .25468 L
.37956 .32064 L
.41919 .38294 L
.45729 .43548 L
.47854 .46022 L
.49785 .47952 L
.51817 .49647 L
.5369 .50904 L
.55608 .51896 L
.56619 .52302 L
.57688 .52648 L
.58632 .52882 L
.59152 .52985 L
.59646 .53064 L
.60103 .53123 L
Mistroke
.60345 .53148 L
.60603 .53171 L
.60841 .53188 L
.61056 .532 L
.6116 .53205 L
.61273 .53209 L
.61378 .53212 L
.61477 .53215 L
.61602 .53217 L
.61715 .53218 L
.61837 .53219 L
.61906 .53219 L
.6197 .53218 L
.62076 .53217 L
.62193 .53215 L
.62315 .53211 L
.6243 .53208 L
.62693 .53196 L
.62933 .53181 L
.63475 .53136 L
.63966 .5308 L
.64502 .53003 L
.65582 .52799 L
.67547 .52274 L
.69644 .51513 L
.73799 .49483 L
.77802 .47002 L
.81654 .44253 L
.85751 .41047 L
.89697 .37769 L
.93491 .34508 L
.9753 .3098 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .25939 L
.10458 .20641 L
.12507 .18486 L
.14415 .16869 L
.1536 .1623 L
.16254 .15733 L
.16748 .15505 L
.17284 .15295 L
.17735 .15149 L
.18221 .15025 L
.18475 .14973 L
.18708 .14934 L
.18945 .14902 L
.19165 .1488 L
.19288 .14871 L
.1942 .14863 L
.19495 .1486 L
.19566 .14857 L
.19629 .14856 L
.19698 .14855 L
.19826 .14855 L
.19891 .14856 L
.19962 .14857 L
.20087 .14862 L
.20205 .14869 L
.20335 .14878 L
.20477 .14891 L
.20735 .14923 L
.20987 .14962 L
.21219 .15007 L
.21747 .15137 L
.22307 .15318 L
.23244 .15718 L
.24255 .16282 L
.26083 .17632 L
.28087 .19559 L
.30197 .22019 L
.34007 .27298 L
.38063 .33542 L
.41968 .39537 L
.46118 .45293 L
.50116 .49799 L
.51948 .51445 L
.53963 .52926 L
.5595 .54042 L
.57037 .54508 L
.58054 .54852 L
.58552 .54989 L
.59095 .55114 L
Mistroke
.59574 .55205 L
.60083 .55281 L
.60343 .55312 L
.60588 .55336 L
.60826 .55355 L
.61045 .55369 L
.61254 .55378 L
.61359 .55382 L
.61474 .55385 L
.61589 .55387 L
.61713 .55388 L
.6183 .55387 L
.61937 .55386 L
.62055 .55384 L
.62166 .55381 L
.62288 .55377 L
.62419 .55371 L
.62686 .55355 L
.62931 .55336 L
.63378 .5529 L
.63849 .55226 L
.64842 .55043 L
.65927 .54769 L
.67892 .54092 L
.69988 .5314 L
.74143 .5068 L
.78146 .47775 L
.81998 .44657 L
.86095 .41136 L
.90041 .37647 L
.93835 .34268 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo033ooooo2ol0003oooooo`[o
oooo000Qooooo`03o`000?oooooooooo02kooooo0_l0000;ooooo`?o0000ooooool7ooooo`008Ooo
ool3o`0002_ooooo0ol0000@ooooo`?o0000ooooool4ooooo`008Oooool00ol0003oooooooooo`0X
ooooo`?o00005_ooool2o`000?oooooo0_ooool0027ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`07ooooo`Goo`003Oooool00ol0003oooooooooo`3nooooo`008Oooool00ol0003o
ooooooooo`0Uooooo`;o00001_ooool4ool001?ooooo0_l0003nooooo`008Oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo00?ooooo0ooo000Iooooo`03o`000?oooooooooo0?_ooooo
000Qooooo`03o`000?oooooooooo02;ooooo0_l00004ooooo`;oo`005Oooool2ool000Kooooo00?o
0000ooooooooool0n_ooool0027ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02
ooooo`;oo`006Oooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo0?Wooooo000Qoooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool07oooool2ool000Gooooo00?o0000oooo
ooooool0n?ooool0027ooooo0ol0000Oooooo`03o`000?oooooooooo02;ooooo00?oo`00oooooooo
ool00oooool00ol0003oooooooooo`3gooooo`008Oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo02Cooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`3fooooo`008Ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?oo`00ooooooooool00ooo
ool00ol0003oooooooooo`3eooooo`008Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02Oooooo0_oo0004ooooo`03o`000?oooooooooo0?Cooooo000Qooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0:_ooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo
0??ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo01_ooooo00Co0000ooooooooooooo`00:ooo
ool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo0?;ooooo0007ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooooooo
o`0Jooooo`04o`000?ooooooooooool002gooooo00?oo`00ooooooooool00_ooool00ol0003ooooo
ooooo`3aooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooo
ooooo`02ooooo`?o00006Oooool01?l0003ooooooooooooo000_ooooo`03ool00?oooooooooo00;o
oooo00?o0000ooooooooool0l?ooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool06?ooool01?l0003ooooooooooooo000foooo
o`03o`000?oooooooooo0>oooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05oooool01?l0003ooooooooooooo
000hooooo`03o`000?oooooooooo0>kooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo0000>_oo
ool00ol0003oooooooooo`3]ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Fooooo`03o`000?ooooooo`0003_ooooo00?o
0000ooooooooool0kOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?ooooooo`0003gooooo00?o0000ooooooooool0k?oo
ool0027ooooo00?o0000ooooooooool05?ooool01?l0003ooooooooooooo000nooooo`03o`000?oo
oooooooo0>_ooooo000Qooooo`03o`000?oooooooooo01?ooooo00Co0000ooooooooooooo`00?ooo
ool00ol0003oooooooooo`3[ooooo`008Oooool3o`0001;ooooo00Co0000ooooooooooooo`00?Ooo
ool01Ooo003ooooooooooooooooo00000>cooooo000Qooooo`03o`000?oooooooooo01;ooooo00?o
0000oooooooo0000?_ooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo0>Wooooo000Q
ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo0000@?ooool00ooo003oooooooooo`02
ooooo`03o`000?oooooooooo0>Sooooo000Qooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0@Oooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo0>Sooooo000Qooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0@oooool00ooo003oooooooooo`02ooooo`03
o`000?oooooooooo0>Oooooo000Qooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
AOooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo0>Kooooo000Qooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0A_ooool01Ooo003ooooooooooooooooo00000>Sooooo
000Qooooo`?o00003Oooool00ol0003oooooooooo`17ooooo`03ool00?oooooooooo00;ooooo00?o
0000ooooooooool0iOooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`19
ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool0i?ooool0027ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`1;ooooo`03ool00?oooooooooo00;ooooo00?o0000oooo
ooooool0hoooool0027ooooo00?o0000ooooooooool02_ooool00ol0003oooooool0001<ooooo`03
ool00?oooooooooo00;ooooo00?o0000ooooooooool0hoooool0027ooooo00?o0000ooooooooool0
2Oooool01?l0003ooooooooooooo001=ooooo`03ool00?oooooooooo00;ooooo00?o0000oooooooo
ool0h_ooool0027ooooo00?o0000ooooooooool02Oooool00ol0003oooooool0001?ooooo`03ool0
0?oooooooooo00;ooooo00?o0000ooooooooool0hOooool0027ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooool0001Aooooo`05ool00?ooooooooooooooool00000hoooool0027ooooo00?o
0000ooooooooool01oooool00ol0003oooooool0001Gooooo`03o`000?oooooooooo0>3ooooo000Q
ooooo`?o00001oooool00ol0003oooooool0001Gooooo`03o`000?oooooooooo0>3ooooo000Qoooo
o`03o`000?oooooooooo00Kooooo00?o0000oooooooo0000=?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool00ol0003ooooooooo
o`0[ooooo`Co000000?o410@ooooooooool0>oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool5o`0001_ooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?o0000oooooooo0000=Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00oooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`00
0?ooooooo`0003Gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0??ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?ooooooo`0003Kooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo013ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0?_ooool00onHV9So8B4Qonk^kP0Kooooo`00
8Oooool00ol0003oooooooooo`03ooooo`03o`000?ooooooo`0003Oooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`04Oooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<043ooooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool00oooool00ol0
003oooooool0000gooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06Oooool0027ooooo0ol00002oooo
o`03o`000?ooooooo`0003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooo
oooo017ooooo00Coo`00oooooooooooo0000;?ooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0?oooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo
000Qooooo`07o`000?ooooooooooooooool0003oooooool0000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`00013ooooo00Goo`00ooooooooooooooooo`00000Yooooo`03oeEEEOmVIVKo
000003oooooo00?oEEEEofIVI_l000003Oooool4o`0003kooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00Kooooo`008Oooool01Ol0003ooooooooooooooooo0000067ooooo00Goo`00oooooooooooooooo
o`00003Looooo`008Oooool01?l0003oooooooooool0001Sooooo`04ool00?ooooooooooo`000=co
oooo000Qooooo`03o`000?oooooo000006Cooooo00Goo`00ooooooooooooooooo`00003Kooooo`00
8Oooool00ol0003oooooo`00001Uooooo`04ool00?ooooooooooo`000=7ooooo0_l00002ooooo`;o
00001?ooool0027ooooo0_l0001Wooooo`04ool00?ooooooooooo`000=3ooooo00Kok^k^ob4Q8On7
QhOo^[Zjo`000?oMgMd4ooooo`006_oooomao`000003ool00?l0003o00000;go000000?oo`00o`00
0?l000001Ol0000<ooooo`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000oooooooo00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo003o0000
01?ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool01?l0
003ooooooooooooo0002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00Co0000ool00?oooooo00004ooo
ool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003oooooooooo`1Yooooo`03ool00?oo
oooo00000;Oooooo00?o0000ool00?ooool05?ooool2o`0000;ooooo0_l00004ooooo`008Oooool0
0ol0003oooooooooo`1Yooooo`04ool00?ooooooooooo`000;Gooooo00?o0000ool00?ooool07ooo
ool0027ooooo00?o0000ooooooooool0J_ooool00ooo003oooooo`00002dooooo`03o`000?oooooo
oooo023ooooo000Qooooo`03o`000?oooooooooo06_ooooo00?oo`00ooooool00000/_ooool00ol0
003oooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo0:ko
oooo00?o0000ooooooooool08_ooool0027ooooo0ol0001^ooooo`03o`000?oooooooooo0:gooooo
00?o0000ooooooooool08oooool0027ooooo00?o0000ooooooooool0Koooool00ol0003ooooooooo
o`2[ooooo`03o`000?oooooooooo02Cooooo000Qooooo`03o`000?oooooooooo073ooooo00?o0000
ooooooooool0ZOooool00ol0003oooooooooo`0Uooooo`008Oooool00ol0003oooooooooo`1`oooo
o`03o`000?oooooooooo0:Oooooo0_oo000Xooooo`008Oooool00ol0003oooooooooo`1aooooo`03
o`000?oooooooooo0:Gooooo00?oo`00o`000?ooool0:?ooool0027ooooo00?o0000ooooooooool0
L_ooool00ol0003oooooooooo`2Sooooo`03ool00?oooooooooo02Wooooo000Qooooo`03o`000?oo
oooooooo07?ooooo00?o0000ooooooooool0XOooool00ooo003oooooooooo`0Zooooo`008Oooool3
o`00077ooooo00?oo`00ooooool00000X_ooool00ooo003oooooooooo`0[ooooo`008Oooool00ol0
003oooooooooo`1aooooo`04ool00?ooooooooooo`0009oooooo0_oo000^ooooo`008Oooool00ol0
003oooooooooo`1booooo`04ool00?ooooooooooo`0009gooooo00?oo`00o`000?ooool0;_ooool0
027ooooo00?o0000ooooooooool0Loooool00ooo003oooooo`00002Looooo`03ool00?oooooooooo
02oooooo000Qooooo`03o`000?oooooooooo07?ooooo00Coo`00oooooooooooo0000V_ooool00ooo
003oooooooooo`0`ooooo`008Oooool00ol0003oooooooooo`1dooooo`04ool00?ooooooooooo`00
09Sooooo00?oo`00ooooooooool0<Oooool0027ooooo00?o0000ooooooooool0MOooool00ooo003o
ooooo`00002Gooooo`03ool00?oooooooooo03;ooooo000Qooooo`03o`000?oooooooooo07Gooooo
00Coo`00oooooooooooo0000U?ooool2o`0003Gooooo000Qooooo`?o0000M_ooool01?oo003ooooo
ooooool0002Booooo`03o`000?oooooooooo03Gooooo000Qooooo`03o`000?oooooooooo07Oooooo
00?oo`00ooooool00000TOooool00ol0003oooooooooo`0fooooo`008Oooool00ol0003ooooooooo
o`1gooooo`04ool00?ooooooooooo`0008oooooo00?o0000ooooooooool0=oooool0027ooooo00?o
0000ooooooooool0N?ooool01?oo003oooooooooool0002=ooooo`03o`000?oooooooooo03Sooooo
000Qooooo`03o`000?oooooooooo07Wooooo00?oo`00ooooool00000Roooool2o`0003_ooooo000Q
ooooo`03o`000?oooooooooo07Wooooo00Coo`00oooooooooooo0000ROooool00ol0003ooooooooo
o`0kooooo`008Oooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo08Gooooo00?o0000
ool00?oo0000??ooool0027ooooo0ol0001nooooo`03o`000?oooooooooo08?ooooo00?o0000ool0
0?ooool0?Oooool0027ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`22ooooo`03
o`000?oo003ooooo03kooooo000Qooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0
Ooooool00ol0003oo`00ool00010ooooo`008Oooool00ol0003oooooooooo`20ooooo`03o`000?oo
oooooooo07gooooo00?o0000ool00?ooool0@Oooool0027ooooo00?o0000ooooooooool0P?ooool0
0ol0003oooooooooo`1looooo`03o`000?oo003ooooo04;ooooo0007ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oo
oooooooo087ooooo00?o0000ooooooooool0NOooool2o`000003ool00?oooooooooo04;ooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo07Oooooo00?o0000oooooooo0000AOoo
ool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0
0020ooooo`04ool00?ooooooooooo`0007Oooooo00?o0000oooooooo0000A_ooool000Oooooo00Go
0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0
P?ooool01?oo003oooooooooool0001fooooo`03o`000?ooooooo`0004Oooooo0007ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooo
ooooool0POooool01?oo003oooooooooool0001cooooo`;o000000?oooooool00?ooool0Aoooool0
00Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0P_ooool01?oo003oooooooooool0001aooooo`03o`000?oooooooooo04[ooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo08?ooooo00?oo`00ooooool00000L?ooool00ol0003oooooooooo`1;ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo08?ooooo00Co
o`00oooooooooooo0000KOooool2o`0004kooooo000Qooooo`03o`000?oooooooooo08Cooooo00Co
o`00oooooooooooo0000Joooool00ol0003oooooooooo`1>ooooo`008Oooool00ol0003ooooooooo
o`25ooooo`04ool00?ooooooooooo`0006Wooooo00?o0000ooooooooool0Coooool0027ooooo0ol0
0026ooooo`03ool00?oooooo000006Oooooo0_l0001Booooo`008Oooool00ol0003oooooooooo`26
ooooo`04ool00?ooooooooooo`0006Gooooo00?o0000ooooooooool00_oo001@ooooo`008Oooool0
0ol0003oooooooooo`27ooooo`04ool00?ooooooooooo`0006?ooooo00Co0000ooooooooooooo`00
D_ooool0027ooooo00?o0000ooooooooool0R?ooool01?oo003oooooooooool0001Pooooo`;o0000
0_ooool00ooo003oooooooooo`1Aooooo`008Oooool00ol0003oooooooooo`29ooooo`04ool00?oo
ooooooooo`0005kooooo00?o0000ooooooooool00_oo001Dooooo`008Oooool00ol0003ooooooooo
o`2=ooooo`03o`000?oooooooooo05[ooooo00Co0000ooooooooooooo`00E_ooool0027ooooo00?o
0000ooooooooool0S_ooool00ol0003oooooooooo`1Gooooo`;o00000_ooool00ooo003ooooooooo
o`1Eooooo`008Oooool3o`0008oooooo00?o0000ooooooooool0E?ooool2o`0000?ooooo00?oo`00
ooooooooool0E_ooool0027ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`1Aoooo
o`;o00000oooool2ool005Wooooo000Qooooo`03o`000?oooooooooo097ooooo0_l0001?ooooo`;o
00001?ooool00ooo003oooooooooo`1Iooooo`008Oooool00ol0003oooooooooo`2Cooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`1Jooooo`008Ooo
ool00ol0003oooooooooo`2Dooooo`;o0000BOooool2o`0006?ooooo000Qooooo`03o`000?oooooo
oooo097ooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`14ooooo`;o0000IOooool0
027ooooo00?o0000ooooooooool0TOooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo
047ooooo0_l0001Wooooo`008Oooool00ol0003oooooooooo`2Booooo`03ool00?oooooooooo00?o
oooo0_l0000oooooo`;o0000JOooool0027ooooo0ol0002Cooooo`03ool00?oooooooooo00Cooooo
00?o0000ooooooooool0>_ooool2o`0006_ooooo000Qooooo`03o`000?oooooooooo09Cooooo00?o
o`00ooooooooool01?ooool2o`0003Sooooo0_l0001]ooooo`008Oooool00ol0003oooooooooo`2E
ooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`05
ooooo`?oo`00IOooool0027ooooo00?o0000ooooooooool0U_ooool00ooo003oooooooooo`05oooo
o`;o0000<_ooool2o`0000Oooooo00?oo`00ooooooooool0I_ooool0027ooooo00?o0000oooooooo
ool0Uoooool00ooo003oooooooooo`06ooooo`;o0000;_ooool2o`0000Oooooo0_oo001Yooooo`00
8Oooool00ol0003oooooooooo`2Hooooo`;oo`002?ooool2o`0002[ooooo0_l00007ooooo`;oo`00
Joooool0027ooooo00?o0000ooooooooool0V_ooool00ooo003oooooooooo`07ooooo`?o00009?oo
ool3o`0000Sooooo00?oo`00ooooooooool0Joooool0027ooooo0ol0002Kooooo`03ool00?oooooo
oooo00Wooooo0ol0000Nooooo`?o00002Oooool2ool006kooooo000Qooooo`03o`000?oooooooooo
09cooooo00?oo`00ooooooooool02oooool3o`0001Sooooo0ol0000:ooooo`;oo`00L?ooool0027o
oooo00?o0000ooooooooool0[Oooool3o`0000oooooo1_l0000<ooooo`03ool00?oooooooooo073o
oooo000Qooooo`03o`000?oooooooooo0;3ooooo3ol0000Aooooo`03ool00?oooooooooo077ooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo1?l000000ol@413oooooooooo`02
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`2Vooooo`;oo`00W?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`2Xooooo`?oo`006_ooool2ool007gooooo000Jooooo`03o`000?oooooooooo00Cooooo
0ol0002[ooooo`;oo`005Oooool3ool007oooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0[Oooool2ool000kooooo1Ooo0022ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0;Oooooo1_oo0027ooooo`006_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool00omgMgOoIVIVooooo`0Goooo
o`03ofIVI_mgMgOooooo0:Oooooo0023ooooo`?o00005?ooool00olQ8B7ogMgMooooo`06ooooo`03
omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Yoooool007_ooooo00OoQhN7o`000?mEEEGo
IVIVo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool02oooool01OnHV9So0000o`000?m4A4Co
^[Zj00?ooooo00?oV9RHoeEEEOooool01_ooool00omEEEGoV9RHooooo`02ooooo`Go00002Oooool0
0omEEEGoZJVYooooo`02ooooo`06okZj^_m4A4Cooooooooooon7QhOoIVIV5Oooool4o`000003oa0@
4?oooooooooo00;ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@1eooooo`00Noooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00_ooool00ol0
003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ogMgMooooo`05
ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00:ooooo`06oeEEEOnH
V9Soooooooooool@413o^[Zj0_ooool00oo^k^ko0000ooooo`0;ooooo`Ko00001Oooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo07Co
oooo001kooooo`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@4002ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01_ooool2ogMgM`Kooooo00?o<S8booooooooool00oooool00onH
V9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`0000Cooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0Loooool0
07_ooooo00CoEEEEojVYZOoooooo00000_ooool01?l0003oooooooooool0000=ooooo`03o`000?oo
oooooooo00Kooooo00?ok^k^oa0@4?o^k^h01Oooool00olb<S;oooooooooo`04ooooo`03oiRHV?lQ
8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001?ooool00ol0003oooooooooo`0:ooooo`Ko0000
1Oooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool0
M?ooool007_ooooo00?ogMgMob4Q8Oo^k^h00oooool01?l0003oooooo`000?l0000=ooooo`03o`00
0?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool00ol0003ok^k^ooooo`05ooooo`03ogMg
MomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo00000oooool00oo^k^ko0000ooooo`0Fooooo`03
o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
07Gooooo001looooo`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool03?ooool00ol@413o
0000o`000003o`0000Kooooo00?ogMgMoa0@4?ooool01?ooool00omEEEGoMgMgooooo`06ooooo`03
o`000?oooooooooo00Sooooo1ol000000oooooooMgMgoeEEE@0Gooooo`03o`000?oooooooooo00go
oooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`1gooooo`00T_ooool00ol0003ooooo
ooooo`08ooooo`03oeEEEOnHV9Sooooo00?ooooo00?ogMgMoa0@4?o^k^h00_ooool01Ol0003o^[Zj
oooooonHV9So410@017ooooo00?ok^k^oa0@4?oMgMd05oooool00ol0003oooooooooo`0:ooooo`05
oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`1gooooo`00T_ooool00ol0003o
ooooooooo`08ooooo`03okZj^_m4A4Cooooo00Cooooo00WoMgMgofIVI_oooooooooooiRHV?l@413o
0000ob4Q8Oo<c<`04Oooool00omVIVKoMgMgooooo`0Eooooo`03oeEEEOmVIVKo000000cooooo1Ol0
0004ooooo`Co0000M_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28891 L
.10458 .26589 L
.14415 .24424 L
.18221 .22597 L
.20178 .21869 L
.21274 .21551 L
.21758 .21435 L
.22272 .21328 L
.22745 .21246 L
.23267 .21174 L
.23496 .21149 L
.23742 .21127 L
.23974 .2111 L
.24186 .21099 L
.24314 .21093 L
.24384 .21091 L
.24451 .21089 L
.24579 .21087 L
.24696 .21086 L
.24763 .21085 L
.24835 .21086 L
.24963 .21087 L
.25034 .21089 L
.25101 .21091 L
.25252 .21096 L
.25383 .21102 L
.25508 .2111 L
.25741 .21127 L
.25992 .21151 L
.26265 .21183 L
.26749 .21257 L
.27205 .21346 L
.28242 .21619 L
.29253 .21984 L
.30343 .22487 L
.32347 .23711 L
.34457 .25411 L
.38268 .29454 L
.42324 .34795 L
.46228 .40387 L
.50378 .46112 L
.54376 .5082 L
.58223 .54229 L
.6021 .55497 L
.61225 .5601 L
.62315 .5646 L
.63338 .56787 L
.64272 .57007 L
.64722 .57085 L
Mistroke
.64959 .5712 L
.65212 .57152 L
.65455 .57177 L
.65674 .57196 L
.65896 .5721 L
.66104 .5722 L
.6622 .57224 L
.66345 .57228 L
.66463 .57229 L
.66571 .5723 L
.66697 .57229 L
.66768 .57229 L
.66834 .57227 L
.66954 .57224 L
.67082 .5722 L
.67205 .57214 L
.67336 .57207 L
.67574 .5719 L
.67856 .57164 L
.68115 .57135 L
.69016 .56992 L
.69469 .56897 L
.69964 .56775 L
.71929 .56114 L
.74025 .55114 L
.7818 .52332 L
.82184 .48811 L
.86035 .44824 L
.90132 .40124 L
.94078 .35321 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .29399 L
.10458 .28043 L
.14415 .26499 L
.18221 .249 L
.20342 .24122 L
.21345 .23817 L
.22272 .23583 L
.23233 .23397 L
.23739 .23324 L
.23998 .23294 L
.24276 .23267 L
.24519 .23249 L
.24742 .23236 L
.24849 .23231 L
.24965 .23227 L
.25075 .23224 L
.25178 .23222 L
.25308 .23222 L
.2543 .23222 L
.2554 .23223 L
.25659 .23226 L
.25788 .23231 L
.25925 .23237 L
.26171 .23252 L
.26426 .23274 L
.26667 .23299 L
.27119 .23362 L
.27605 .23451 L
.28135 .23573 L
.29087 .23861 L
.29968 .24206 L
.31835 .25192 L
.33895 .26672 L
.37915 .30621 L
.41784 .3541 L
.45898 .40995 L
.4986 .46246 L
.53671 .50676 L
.55796 .52742 L
.57727 .5432 L
.59736 .55635 L
.61632 .5656 L
.62604 .56914 L
.63633 .572 L
.64512 .57373 L
.65011 .57442 L
.65237 .57466 L
.65478 .57488 L
.65614 .57498 L
Mistroke
.65737 .57506 L
.65862 .57512 L
.65976 .57517 L
.66111 .57522 L
.66181 .57523 L
.66256 .57525 L
.66381 .57526 L
.66453 .57526 L
.66519 .57526 L
.66647 .57525 L
.66769 .57522 L
.66878 .57519 L
.66996 .57514 L
.67262 .575 L
.67507 .57482 L
.67935 .57439 L
.68406 .57375 L
.69361 .57194 L
.70373 .56929 L
.71299 .56623 L
.73386 .5572 L
.75282 .54659 L
.77354 .5326 L
.81415 .49869 L
.85325 .45911 L
.8948 .41138 L
.93483 .36191 L
.97335 .31271 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`0koooo
oa3o0000nOooool0027ooooo0ol0000gooooo`Co00004?ooool5o`000?Cooooo000Qooooo`03o`00
0?oooooooooo03Cooooo0ol0000Iooooo`03o`000?oooooooooo0?7ooooo000Qooooo`03o`000?oo
oooooooo037ooooo0ol0000Mooooo`?o0000l?ooool0027ooooo00?o0000ooooooooool0;_ooool3
o`0002?ooooo0ol0003]ooooo`008Oooool00ol0003oooooooooo`0/ooooo`;o0000:Oooool00ol0
003oooooooooo`3Zooooo`008Oooool00ol0003oooooooooo`0Zooooo`;o00005oooool6ool000oo
oooo0_l0003Zooooo`008Oooool00ol0003oooooooooo`0Xooooo`;o00005oooool2ool000Gooooo
2Ooo0009ooooo`03o`000?oooooooooo0>Oooooo000Qooooo`?o00009_ooool2o`0002Wooooo00?o
o`00ooooooooool01oooool2o`000>Oooooo000Qooooo`03o`000?oooooooooo02Cooooo0_l0000>
ooooo`?oo`009_ooool00ol0003oooooooooo`3Tooooo`008Oooool00ol0003oooooooooo`0Roooo
o`;o00003_ooool2ool002[ooooo0_l0003Tooooo`008Oooool00ol0003oooooooooo`0Pooooo`;o
00003_ooool2ool002kooooo00?o0000ooooooooool0hOooool0027ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0<ooooo`;oo`00<Oooool00ol0003oooooooooo`3Pooooo`008Ooo
ool00ol0003oooooooooo`0Mooooo`;o00003?ooool3ool002cooooo0_oo0006ooooo`03o`000?oo
oooooooo0=oooooo000Qooooo`03o`000?oooooooooo01_ooooo0_l0000<ooooo`;oo`00<Oooool0
0ooo003oooooooooo`03ooooo`03o`000?oooooooooo0=oooooo000Qooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`0booooo`;oo`001?ooool00ol0
003oooooooooo`3Nooooo`008Oooool3o`0001Sooooo0_l00015ooooo`03ool00?oooooooooo00;o
oooo00?o0000ooooooooool0gOooool0027ooooo00?o0000ooooooooool05_ooool2o`0002Gooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00gooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`0Xooooo`Co000000?o410@oooo
ooooool0>oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd0?Oooool5o`0001_ooooo000Qooooo`03o`000?oooooooooo01Cooooo0_l0000Woooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03Oooool0
0ooo003oooooooooo`02ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0looooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@06oooool0027ooooo00?o0000ooooooooool04_ooool2o`0000Sooooo0ooo000N
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0=ooooo`03ool00?oo
oooooooo00;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0??ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool0
0ol0003oooooooooo`0@ooooo`;o00001oooool3ool0027ooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo00oooooo00?oo`00ooooooooool00_ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool03_ooool00omgMgOo<S8boooo
o`0nooooo`03oiRHV?lQ8B7ok^k^01_ooooo000Qooooo`03o`000?oooooooooo00kooooo0_l00006
ooooo`?oo`009?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00Aooooo`05ool00?ooooooooooooooool00000:Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c010ooooo`03ogMgMomVIVKooooo
01[ooooo000Qooooo`03o`000?oooooooooo00cooooo0_l00005ooooo`?oo`009oooool01Ol@413o
oooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool01Ooo003ooooooooooooooooo
000002Sooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool06Oooool0027ooooo0ol0000:ooooo`;o00001?ooool3ool0
02[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo01Gooooo00Goo`00
ooooooooooooooooo`00000Wooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0oooooo`05o`000?nj^[[ooooooiRHV?l@41006oooool0027ooooo00?o
0000ooooooooool02?ooool2o`0000Gooooo00?oo`00ooooooooool0:oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo1?l0000Iooooo`03o`000?oooooooooo02;ooooo00?oEEEEofIVI_l00000
?oooool00omEEEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_o
oooo000Qooooo`03o`000?oooooooooo00Kooooo0_l0001Tooooo`03o`000?oooooooooo0=Gooooo
000Qooooo`03o`000?oooooooooo00Cooooo0_l0001Wooooo`03o`000?oooooooooo0=Cooooo000Q
ooooo`03o`000?oooooooooo00;ooooo0_l00002ool006Oooooo00?o0000ooooooooool0e?ooool0
027ooooo00Co0000oooooooooooo00000ooo001Zooooo`03o`000?oooooooooo0<Wooooo0_l00002
ooooo`;o00001?ooool0027ooooo00Co0000ool00?oo003oo`00K_ooool00ol0003oooooooooo`38
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool001[ooooo1ol000000ooo003o0000o`00
003oo`0002So000000?oo`00o`000?l000001Ol0000<ooooo`04omgMgOl0003o410@olc<c0Gooooo
000Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ooo003oooooo`00
0003ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03ool00?oooooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`04ool00?ooooooooooo`0000;ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?oo`00o`000?ooool04_ooool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003ooooo
ooooo`1_ooooo`04ool00?ooooooooooo`000;;ooooo00?o0000ool00?ooool04_ooool2o`0000;o
oooo0_l00004ooooo`008Oooool00ol0003oooooooooo`1`ooooo`04ool00?ooooooooooo`000;3o
oooo00?o0000ool00?ooool07Oooool0027ooooo00?o0000ooooooooool0LOooool01?oo003ooooo
ooooool0002^ooooo`03o`000?oo003ooooo01kooooo000Qooooo`03o`000?oooooooooo07;ooooo
00?oo`00ooooool00000[_ooool00ooo003oooooooooo`0Nooooo`008Oooool00ol0003ooooooooo
o`1cooooo`03ool00?oooooo00000:cooooo00?oo`00ooooooooool07oooool0027ooooo0ol0001c
ooooo`04ool00?ooooooooooo`000:[ooooo00?oo`00ooooooooool08?ooool0027ooooo00?o0000
ooooooooool0M?ooool01?oo003oooooooooool0002Xooooo`03o`000?oooooooooo027ooooo000Q
ooooo`03o`000?oooooooooo07Gooooo00?oo`00ooooool00000Z?ooool00ol0003oooooooooo`0Q
ooooo`008Oooool00ol0003oooooooooo`1fooooo`03ool00?oooooo00000:Kooooo00?o0000oooo
ooooool08_ooool0027ooooo00?o0000ooooooooool0Moooool00ooo003oooooo`00002Tooooo`03
o`000?oooooooooo02?ooooo000Qooooo`03o`000?oooooooooo07Sooooo00?oo`00ooooool00000
X_ooool00ol0003oooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`1jooooo`03o`000?oo
oooooooo09oooooo00?o0000ooooooooool09Oooool0027ooooo0ol0001kooooo`03o`000?oooooo
oooo09kooooo00?o0000ooooooooool09Oooool0027ooooo00?o0000ooooooooool0O?ooool00ol0
003oooooooooo`2Kooooo`03ool00?l0003ooooo02Oooooo000Qooooo`03o`000?oooooooooo07co
oooo00?o0000ooooooooool0Voooool00ooo003oooooooooo`0Wooooo`008Oooool00ol0003ooooo
ooooo`1mooooo`03o`000?oooooooooo09Wooooo00?o0000ool00?ooool0:?ooool0027ooooo00?o
0000ooooooooool0O_ooool00ol0003oooooooooo`2Gooooo`03o`000?oo003ooooo02Wooooo000Q
ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0UOooool00ol0003oo`00ooooo`0Z
ooooo`008Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo09Cooooo00?o0000ool0
0?ooool0:oooool0027ooooo00?o0000ooooooooool0O_ooool00ooo003oooooo`00002Dooooo`03
o`000?oo003ooooo02cooooo000Qooooo`?o0000O_ooool01?oo003oooooooooool0002Cooooo`03
ool00?oooooooooo02cooooo000Qooooo`03o`000?oooooooooo07oooooo00?oo`00ooooool00000
T_ooool00ol0003oo`00ooooo`0]ooooo`008Oooool00ol0003oooooooooo`20ooooo`03ool00?oo
oooo0000093ooooo00?o0000ool00?ooool0;_ooool0027ooooo00?o0000ooooooooool0P?ooool0
1?oo003oooooooooool0002>ooooo`03o`000?oo003ooooo02oooooo000Qooooo`03o`000?oooooo
oooo087ooooo00Coo`00oooooooooooo0000S?ooool00ol0003oo`00ooooo`0`ooooo`008Oooool0
0ol0003oooooooooo`22ooooo`03ool00?oooooo000008_ooooo00?o0000ool00?ooool0<Oooool0
027ooooo00?o0000ooooooooool0Poooool00ooo003oooooo`000029ooooo`03o`000?oooooooooo
03;ooooo000Qooooo`?o0000Poooool01?oo003oooooooooool00028ooooo`03o`000?oooooooooo
03;ooooo000Qooooo`03o`000?oooooooooo08Cooooo00?oo`00ooooool00000Qoooool00ol0003o
ooooooooo`0cooooo`008Oooool00ol0003oooooooooo`25ooooo`03ool00?oooooo000008Gooooo
00?o0000ooooooooool0=?ooool0027ooooo00?o0000ooooooooool0QOooool01?oo003ooooooooo
ool00023ooooo`03o`000?oooooooooo03Gooooo000Qooooo`03o`000?oooooooooo08Kooooo00Co
o`00oooooooooooo0000POooool00ol0003oooooooooo`0fooooo`001oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003o
ooooooooo`27ooooo`03ool00?oooooo0000087ooooo00?o0000ooooooooool0=_ooool000Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03
o`000?oooooooooo08[ooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`0gooooo`00
1oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`0008_o
oooo00?o0000ooooooooool0Noooool00ooo003oooooooooo`0hooooo`001oooool01Ol0003ooooo
oooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2;ooooo`03
o`000?oooooooooo07[ooooo00?o0000ool00?ooool0>Oooool000Oooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`2<oooo
o`03o`000?oooooooooo07Sooooo00?o0000ool00?ooool0>_ooool000Oooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0SOooool00ol0
003oooooooooo`1gooooo`03ool00?oooooooooo03[ooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08kooooo00?o0000oooo
ooooool0MOooool00ooo003oooooooooo`0kooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l00005ooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool0M?ooool00ooo
003oooooooooo`0looooo`008Oooool00ol0003oooooooooo`2>ooooo`03ool00?l0003ooooo07?o
oooo00?oo`00ooooooooool0?Oooool0027ooooo00?o0000ooooooooool0S_ooool00ooo003ooooo
o`00001booooo`03ool00?oooooooooo03kooooo000Qooooo`?o0000Soooool00ooo003o0000oooo
o`1`ooooo`03ool00?oooooooooo03oooooo000Qooooo`03o`000?oooooooooo093ooooo00?oo`00
o`000?ooool0K_ooool00ooo003oooooooooo`10ooooo`008Oooool00ol0003oooooooooo`2Aoooo
o`03ool00?l0003ooooo06cooooo00?oo`00ooooooooool0@Oooool0027ooooo00?o0000oooooooo
ool0T_ooool00ooo003o0000ooooo`1Zooooo`03ool00?oooooooooo04;ooooo000Qooooo`03o`00
0?oooooooooo09;ooooo00?oo`00o`000?ooool0JOooool00ol0003oooooooooo`13ooooo`008Ooo
ool00ol0003oooooooooo`2Cooooo`03ool00?l0003ooooo06Oooooo00?o0000ooooooooool0A?oo
ool0027ooooo00?o0000ooooooooool0U?ooool00ooo003o0000ooooo`1Uooooo`03o`000?oooooo
oooo04Gooooo000Qooooo`?o0000UOooool00ooo003o0000ooooo`1Sooooo`03o`000?oooooooooo
04Kooooo000Qooooo`03o`000?oooooooooo09Kooooo00?oo`00o`000?ooool0HOooool00ol0003o
ooooooooo`17ooooo`008Oooool00ol0003oooooooooo`2Gooooo`03ool00?l0003ooooo05oooooo
00?o0000ooooooooool0B?ooool0027ooooo00?o0000ooooooooool0V?ooool00ooo003o0000oooo
o`1Mooooo`03o`000?oooooooooo04Wooooo000Qooooo`03o`000?oooooooooo09[ooooo00?o0000
ooooooooool0FOooool00ol0003oo`00ooooo`1;ooooo`008Oooool00ol0003oooooooooo`2Joooo
o`03o`000?oooooooooo05Sooooo00?o0000oooooooo0000C?ooool0027ooooo00?o0000oooooooo
ool0Voooool00ol0003oooooooooo`1Fooooo`03o`000?ooooooo`0004gooooo000Qooooo`03o`00
0?oooooooooo09cooooo00?o0000ooooooooool0E?ooool00ol0003oooooool0001>ooooo`008Ooo
ool3o`0009gooooo00?o0000ooooooooool0D_ooool00ol0003oo`00ool0001?ooooo`008Oooool0
0ol0003oooooooooo`2Nooooo`03o`000?oooooooooo04oooooo0_l000000ooo003oooooooooo`1?
ooooo`008Oooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo04gooooo00?o0000oooo
oooo0000D_ooool0027ooooo00?o0000ooooooooool0X?ooool2o`0004cooooo00?o0000oooooooo
0000Doooool0027ooooo00?o0000ooooooooool0Woooool01?oo003oooooooooool0001:ooooo`03
o`000?ooooooo`0005Cooooo000Qooooo`03o`000?oooooooooo0:3ooooo00Coo`00oooooooooooo
0000B?ooool00ol0003oooooool0001Eooooo`008Oooool00ol0003oooooooooo`2Qooooo`04ool0
0?ooooooooooo`0004Kooooo00?o0000oooooooo0000E_ooool0027ooooo0ol0002Rooooo`04ool0
0?ooooooooooo`0004?ooooo0_l000000oooooooo`00ooooo`1Fooooo`008Oooool00ol0003ooooo
ooooo`2Sooooo`03ool00?oooooooooo00;o0000@?ooool00ol0003oooooooooo`1Iooooo`008Ooo
ool00ol0003oooooooooo`2Tooooo`;oo`000_ooool00ol0003oooooooooo`0kooooo`;o0000G?oo
ool0027ooooo00?o0000ooooooooool0Y_ooool01?oo003oooooooooool0000kooooo`03o`000?oo
oooooooo05cooooo000Qooooo`03o`000?oooooooooo0:Oooooo0_oo00000ooooooo0000ooooo`0g
ooooo`;o0000Goooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo
0:Wooooo00?oo`00ooooool00000=_ooool00ol0003oooooooooo`1Oooooo`006_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0:[ooooo00Coo`00ooooool0003o0000<oooool00ol0
003oooooool0001Pooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:_o
oooo00Coo`00oooooooooooo0000<?ooool2o`000003oooooooo003ooooo063ooooo000Jooooo`03
o`000?oooooooooo00Cooooo0ol0002_ooooo`;o0000;Oooool01?l0003oooooool00?oo001Roooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;7ooooo00?o0000oooooooo
ool0:?ooool2o`0000;oo`00I?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2booooo`;o00009_ooool2o`0000;oo`00I_ooool001[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`2dooooo`03o`000?oooooooooo027ooooo0_l00002ool006Sooooo000H
ooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0]?ooool2ool000;o00007Oooool2
o`0000?oo`00J_ooool0027ooooo00?o0000ooooooooool0]_ooool2ool000Co00005_ooool3o`00
00;oo`00KOooool0027ooooo00?o0000ooooooooool0^?ooool01?oo003oooooooooooooool3o`00
017ooooo0_l0001booooo`008Oooool3o`000;Wooooo1_oo0005o`0000Cooooo2?l0001dooooo`00
8Oooool00ol0003oooooooooo`2oooooo`goo`00N?ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Sooooo
00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2Sooooo`00Qoooool3o`0001?ooooo00?o
8B4QomgMgOooool01oooool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@413ogMgM0:?ooooo001n
ooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP03ooooo`03o`000?oooooooooo00_ooooo
00GoV9RHo`000?l0003oA4A4okZj^P02ooooo`03oiRHV?mEEEGooooo00Oooooo00CoEEEEoiRHV?oo
oooooooo1Ol00009ooooo`03oeEEEOnYZJWooooo00;ooooo00?o^[ZjodA4A?ooool00_ooool00on7
QhOoIVIVooooo`0Cooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c01kooooo`00O_ooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00ooo
ool00ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0003ogMgM
ooooo`06ooooo`09o`000?oooooooooooooooonHV9So8B4Qonk^k_ooooooA4A400[ooooo00KoEEEE
oiRHV?oooooooooooa0@4?nj^[X3ooooo`03onk^k_l0003ooooo00_ooooo1_l00004ooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40Noooool007kooooo
00Oo0000oooooooMgMgo<S8booooooo^k^ko410@00?ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`05ooooo`;oMgMg1oooool00olb<S;oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^
00cooooo00Co410@omgMgOoooooo00001Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00[ooooo00Go0000ooooooooooooooooo`00001kooooo`00O_ooool01?mEEEGoZJVYooooool0
0002ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`05ooooo`03onk^
k_l@413ok^k^00Kooooo00?o<S8booooooooool00oooool00onHV9So8B4Qonk^kP0;ooooo`04ohN7
QomVIVKoooooo`0000Gooooo00?o0000ooooooooool02_ooool6o`0000Cooooo00?o0000oooooooo
ool02_ooool01Olb<S;oV9RHoooooonHV9So<S8b07_ooooo001nooooo`03omgMgOlQ8B7ok^k^00?o
oooo00?o0000ooooooooool00_l0000=ooooo`03o`000?oooooooooo00Kooooo00?oEEEEoiRHV?oo
ool01Oooool00ol0003ok^k^ooooo`04ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oo
oooo00001?ooool00oo^k^ko0000ooooo`0Eooooo`03o`000?oooooooooo00[ooooo00Goc<c<o`00
0?l0003o0000olc<c01kooooo`00Ooooool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo
00gooooo00?o410@o`000?l000000ol00005ooooo`03omgMgOl@413ooooo00Gooooo00?oEEEEogMg
Moooool01Oooool00ol0003oooooooooo`08ooooo`Oo00000_ooool00omgMgOoEEEEooooo`0Eoooo
o`03o`000?oooooooooo00[ooooo00Go410@okZj^_oooooo^[Zjoa0@401kooooo`00U_ooool00ol0
003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00WogMgMoa0@4?o^k^koooooo`000?nj
^[[ooooooiRHV?l@41004_ooool00oo^k^ko410@omgMg@0Fooooo`03o`000?oooooooooo00[ooooo
00Go0000okZj^_oooooo^[Zjo`00001kooooo`00U_ooool00ol0003oooooooooo`07ooooo`03okZj
^_m4A4Cooooo00Gooooo00SoMgMgofIVI_ooooooV9RHoa0@4?l0003o8B4Qolc<c1;ooooo00?oIVIV
ogMgMoooool05?ooool00omEEEGoIVIVo`00000<ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0Nooo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.85) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .31688 L
.06244 .32452 L
.08426 .33148 L
.0949 .33416 L
.10458 .33613 L
.11403 .33761 L
.11837 .33814 L
.12297 .3386 L
.1253 .33879 L
.12787 .33897 L
.13024 .33911 L
.1324 .33921 L
.13494 .3393 L
.13635 .33933 L
.137 .33935 L
.13768 .33936 L
.13891 .33937 L
.14005 .33938 L
.14075 .33939 L
.14141 .33938 L
.14264 .33938 L
.1438 .33937 L
.14504 .33935 L
.14622 .33932 L
.14729 .33929 L
.14991 .3392 L
.1524 .33908 L
.15734 .33877 L
.16271 .33831 L
.17231 .33721 L
.18119 .33588 L
.19985 .33229 L
.22045 .32739 L
.26066 .31691 L
.27913 .31259 L
.2896 .31051 L
.29934 .30887 L
.30903 .30759 L
.31446 .30704 L
.31938 .30665 L
.32191 .30649 L
.32459 .30635 L
.32599 .30629 L
.32753 .30624 L
.32893 .3062 L
.33024 .30618 L
.33087 .30617 L
.33156 .30616 L
.33282 .30615 L
Mistroke
.33404 .30615 L
.33518 .30615 L
.33587 .30616 L
.33653 .30617 L
.33775 .30619 L
.33906 .30622 L
.34048 .30626 L
.34287 .30636 L
.34542 .3065 L
.35001 .30684 L
.35548 .30739 L
.36046 .30805 L
.37129 .30995 L
.38154 .31238 L
.40149 .31891 L
.41992 .32704 L
.45924 .3507 L
.49704 .38001 L
.5373 .41497 L
.57604 .4481 L
.59572 .46336 L
.61723 .47806 L
.63803 .48982 L
.65691 .49809 L
.66702 .50151 L
.67655 .50406 L
.68145 .50511 L
.68662 .50603 L
.68932 .50643 L
.69229 .50681 L
.69501 .50709 L
.69752 .50731 L
.70002 .50748 L
.70132 .50755 L
.70275 .50761 L
.70399 .50765 L
.70515 .50768 L
.70638 .5077 L
.70707 .50771 L
.70771 .50771 L
.70883 .5077 L
.70987 .50769 L
.71101 .50767 L
.71223 .50764 L
.71352 .50759 L
.71473 .50753 L
.717 .5074 L
.71954 .5072 L
.72222 .50694 L
.72703 .50635 L
Mistroke
.73221 .50552 L
.73791 .50438 L
.74806 .50179 L
.75733 .49879 L
.77822 .48993 L
.79722 .47949 L
.81795 .46573 L
.85861 .43258 L
.89776 .39464 L
.93936 .35014 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .33179 L
.08255 .3421 L
.0932 .34679 L
.10458 .35113 L
.11531 .3545 L
.12507 .35695 L
.12977 .35791 L
.13488 .35879 L
.13935 .35943 L
.14415 .35997 L
.1467 .3602 L
.14903 .36038 L
.15139 .36052 L
.15359 .36062 L
.15482 .36067 L
.15614 .3607 L
.15689 .36072 L
.1576 .36073 L
.15823 .36074 L
.15892 .36075 L
.16021 .36075 L
.16085 .36075 L
.16156 .36075 L
.16282 .36074 L
.16399 .36071 L
.16529 .36068 L
.16672 .36064 L
.1693 .36052 L
.17181 .36038 L
.17414 .36021 L
.17941 .35974 L
.18502 .35908 L
.19439 .35767 L
.20449 .35574 L
.22277 .35143 L
.26391 .33984 L
.28444 .33432 L
.30353 .33005 L
.31301 .32836 L
.32196 .3271 L
.32691 .32654 L
.33227 .32607 L
.33464 .3259 L
.33715 .32575 L
.3393 .32565 L
.34164 .32556 L
.34295 .32553 L
.34417 .3255 L
.34533 .32548 L
Mistroke
.34657 .32547 L
.34779 .32547 L
.34894 .32547 L
.34997 .32548 L
.35108 .3255 L
.3523 .32553 L
.35365 .32556 L
.35636 .32567 L
.35887 .3258 L
.36122 .32596 L
.36584 .32635 L
.37006 .32681 L
.37953 .32821 L
.38947 .33021 L
.39865 .33256 L
.41943 .33959 L
.43813 .34784 L
.45874 .35884 L
.499 .3848 L
.53774 .41294 L
.57893 .4427 L
.61861 .46777 L
.63861 .47809 L
.65677 .48575 L
.67642 .49196 L
.6816 .49321 L
.68721 .49438 L
.69247 .49529 L
.69738 .49598 L
.70196 .49648 L
.70431 .49668 L
.70687 .49686 L
.70832 .49694 L
.70967 .497 L
.71093 .49705 L
.7116 .49707 L
.71232 .49709 L
.71357 .49712 L
.71473 .49713 L
.71538 .49714 L
.71607 .49714 L
.7173 .49713 L
.71861 .49711 L
.71981 .49709 L
.7212 .49704 L
.7225 .49699 L
.72483 .49687 L
.72735 .4967 L
.73307 .49614 L
.73835 .49543 L
Mistroke
.74803 .49362 L
.75709 .49135 L
.77772 .48409 L
.79799 .47423 L
.81652 .46299 L
.85624 .43249 L
.89446 .39664 L
.93512 .35412 L
.97427 .31115 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`1Looooo`Go0000fOooool0
1_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooooooo0000>_l0000<ooooo`04omgMgOl0
003o410@olc<c0Gooooo000Qooooo`04o`000?oo003oo`00o`0000_ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool01?l0003oooooooooooooool6o`0000Gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`02ooooo`Ko00001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`04onk^k_lQ8B7o410@onk^
kPGooooo000Qooooo`03o`000?oooooooooo00;oo`0000?o0000ooooooooool01oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`Co00002oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00So
oooo0ol000000ooooooo0000ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool2o`0001?ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000oooooooo
ool00_ooool2ool000;o0000?oooool4o`0002[ooooo0_l0002_ooooo`03ool00?l0003ooooo01?o
oooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool01?ooool00ooo003ooooo
o`000002o`0003Sooooo1?l0000`ooooo`;o0000[Oooool00ooo003oooooooooo`0Mooooo`008Ooo
ool00ol0003oooooooooo`05ooooo`;oo`000_ooool3o`00037ooooo1?l0000Qooooo`;oo`004ooo
ool2o`000:[ooooo00?oo`00ooooooooool07_ooool0027ooooo00?o0000ooooooooool01oooool2
ool000?ooooo0ol0000Zooooo`Co00006_ooool3ool000[ooooo2_oo000;ooooo`;o0000Yoooool0
0ooo003oooooooooo`0Oooooo`008Oooool00ol0003oooooooooo`09ooooo`;oo`001?ooool4o`00
02?ooooo0ol0000Iooooo`Goo`005oooool00ooo003oooooooooo`0:ooooo`;o0000Y?ooool00ooo
003oooooooooo`0Pooooo`008Oooool3o`0000_ooooo00?oo`00ooooooooool01Oooool4o`0001_o
oooo1?l0000Hooooo`Coo`00:oooool00ol0003oooooooooo`2Pooooo`03ool00?oooooooooo027o
oooo000Qooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool02?ooool5o`0000oooooo
1ol0000Iooooo`?oo`00<?ooool2o`0009oooooo00?oo`00ooooooooool08_ooool0027ooooo00?o
0000ooooooooool07?ooool?o`0001kooooo0_oo000]ooooo`Coo`001?ooool2o`0009cooooo00?o
o`00ooooooooool08oooool0027ooooo00?o0000ooooooooool0O?ooool3ool000?ooooo00?o0000
ooooooooool0V?ooool00ooo003oooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`1ooooo
o`;oo`000_ooool2o`0009Oooooo00?oo`00ooooooooool09Oooool0027ooooo00?o0000oooooooo
ool05_ooool00ooo003oooooooooo`0Uooooo`;oo`00@Oooool01?oo003oooooooooooooool2o`00
09Cooooo00?oo`00ooooooooool09_ooool0027ooooo00?o0000ooooooooool05oooool3ool001oo
oooo1Ooo0014ooooo`;oo`000oooool00ol0003oooooooooo`2@ooooo`03ool00?l0003ooooo02Oo
oooo000Qooooo`?o00006_ooool4ool001Oooooo1?oo001;ooooo`05ool00?ooooooooooooooool0
0000T?ooool00ooo003o0000ooooo`0Xooooo`008Oooool00ol0003oooooooooo`0Nooooo`Soo`00
2_ooool5ool0053ooooo00Goo`00ooooooooooooooooo`00002?ooooo`03o`000?oooooooooo02So
oooo000Qooooo`03o`000?oooooooooo08Kooooo00Goo`00ooooooooooooooooo`00002=ooooo`03
o`000?oooooooooo02Wooooo000Qooooo`03o`000?oooooooooo08_ooooo0_l0002:ooooo`03o`00
0?oooooooooo02[ooooo000Qooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0Q_oo
ool00ol0003oooooooooo`0[ooooo`008Oooool00ol0003oooooooooo`2>ooooo`03o`000?oooooo
oooo08Cooooo00?o0000ooooooooool0;?ooool0027ooooo00?o0000ooooooooool0Soooool00ol0
003oooooooooo`22ooooo`03o`000?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo093o
oooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0^ooooo`008Oooool3o`0008oooooo
0ooo00000ol0003oooooooooo`1mooooo`03ool00?oooooooooo02oooooo000Qooooo`03o`000?oo
oooooooo09;ooooo0_oo001mooooo`03ool00?oooooooooo033ooooo000Qooooo`03o`000?oooooo
oooo09Cooooo00?oo`00ooooooooool0NOooool00ooo003oooooooooo`0aooooo`008Oooool00ol0
003oooooooooo`2Eooooo`03ool00?l0003ooooo07Oooooo00?oo`00ooooooooool0<_ooool0027o
oooo00?o0000ooooooooool0U_ooool00ooo003o0000ooooo`1eooooo`03ool00?oooooooooo03?o
oooo000Qooooo`03o`000?oooooooooo09Oooooo0_oo001dooooo`03ool00?oooooooooo03Cooooo
000Qooooo`03o`000?oooooooooo09Wooooo00?oo`00ooooooooool0L?ooool00ooo003ooooooooo
o`0eooooo`008Oooool3o`0009[ooooo00?oo`00o`000?ooool0K_ooool00ooo003oooooooooo`0f
ooooo`008Oooool00ol0003oooooooooo`2Kooooo`03ool00?l0003ooooo06cooooo00?oo`00oooo
ooooool0=oooool0027ooooo00?o0000ooooooooool0W?ooool00ooo003o0000ooooo`1Zooooo`03
ool00?oooooooooo03Sooooo000Qooooo`03o`000?oooooooooo09kooooo0_l0001Xooooo`03ool0
0?oooooooooo03Wooooo000Qooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool0I?oo
ool00ooo003oooooooooo`0jooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`2Qooooo`03o`00
0?oooooooooo06;ooooo00?o0000ooooooooool0>oooool000Oooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0:;ooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0looooo`001oooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`000:?ooooo00?o0000ooooooooool0
G_ooool00ol0003oooooooooo`0mooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2Tooooo`03o`000?oo003oo`0005cooooo
00?o0000ooooooooool0?_ooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`2Uooooo`03o`000?ooooooo`0005Wo
oooo0_l00011ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`2Vooooo`04o`000?ooooooo`00ool005Kooooo00?o0000oooo
ooooool0@Oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0Yoooool01?l0003ooooooooooooo001Cooooo`;oo`00A?ooool0
00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`2X
ooooo`03o`000?oooooooooo00;oo`00D?ooool00ooo003o0000ooooo`14ooooo`008Oooool00ol0
003oooooooooo`2Yooooo`05o`000?oooooooooooooooooo0000COooool2ool004Oooooo000Qoooo
o`03o`000?oooooooooo0:[ooooo0_l00002ooooo`;oo`00B_ooool00ooo003o0000ooooo`17oooo
o`008Oooool3o`000:cooooo00Go0000ooooooooooooooooool00018ooooo`03ool00?l0003ooooo
04Sooooo000Qooooo`03o`000?oooooooooo0:gooooo00Go0000ooooooooooooooooool00015oooo
o`;oo`0000?o0000ooooooooool0B?ooool0027ooooo00?o0000ooooooooool0[_ooool01Ol0003o
ooooooooooooooooo`0004?ooooo00?oo`00o`000?ooool0Boooool0027ooooo00?o0000oooooooo
ool0[oooool00ol0003oooooooooo`12ooooo`;oo`0000?o0000ooooooooool0Boooool0027ooooo
00?o0000ooooooooool0/?ooool2o`00047ooooo00?oo`00o`000?l00000C_ooool0027ooooo00?o
0000ooooooooool0/_ooool2o`0003kooooo00?oo`00o`000?ooool0Coooool0027ooooo00?o0000
ooooooooool0]?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo04oooooo000Qoooo
o`?o0000]Oooool2o`0000Cooooo0_oo000dooooo`03o`000?oooooooooo053ooooo000Qooooo`03
o`000?oooooooooo0;Oooooo0_l00004ooooo`;oo`00<Oooool00ol0003oooooooooo`1Aooooo`00
8Oooool00ol0003oooooooooo`2iooooo`03o`000?oooooooooo00?ooooo0_oo000]ooooo`;o0000
E?ooool0027ooooo00?o0000ooooooooool0^_ooool2o`0000Gooooo0_oo000Tooooo`;oo`000ooo
ool2o`0005Kooooo000Qooooo`03o`000?oooooooooo0;cooooo00?o0000ooooooooool01?ooool4
ool001gooooo0ooo0003ooooo`;o0000F?ooool0027ooooo00?o0000ooooooooool0_Oooool3o`00
00Oooooo0ooo000Gooooo`?oo`001?ooool2o`0005[ooooo000Qooooo`03o`000?oooooooooo0<3o
oooo0ol00007ooooo`03ool00?oooooooooo01;ooooo0_oo0004ooooo`?o0000G?ooool0027ooooo
00?o0000ooooooooool0`oooool3o`0000oooooo2_oo0004ooooo`;o0000Goooool0027ooooo0ol0
0036ooooo`?o00006?ooool2o`00067ooooo000Qooooo`03o`000?oooooooooo0<Wooooo0_l0000A
ooooo`Go0000Hoooool0027ooooo00?o0000ooooooooool0booooolAo`0006Sooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo1?l000000ol@413oooooooooo`02oooo
o`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo002Tooooo`03ogMgMomVIVKooooo01Oo
oooo00?oIVIVogMgMoooool0Yoooool008?ooooo0ol0000Dooooo`03ob4Q8OoMgMgooooo00Kooooo
00?ogMgMoa0@4?o^k^h06?ooool00oo^k^ko410@omgMg@2Wooooo`00Noooool01on7QhOo0000oeEE
EOmVIVKo0000oc8b<_o^k^h00_ooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o0000odA4
A?nj^[X00oooool00onHV9SoEEEEooooo`06ooooo`03oeEEEOnHV9Sooooo00;ooooo1Ol00009oooo
o`03oeEEEOnYZJWooooo00;ooooo00Ko^[ZjodA4A?ooooooooooohN7QomVIVHEooooo`Co000000?o
410@ooooooooool00_ooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c004ooooo`05odA4
A?l0003o0000oc8b<_oMgMd0MOooool007_ooooo00Oo410@omgMgOmgMgOo8B4Qoooooon7QhOoIVIV
00;ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000
omgMgOooool01Oooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@02_oo
ool01_mEEEGoV9RHoooooooooooo410@okZj^P;ooooo00?ok^k^o`000?ooool02oooool6o`0000Go
oooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@07oooo
o`03ogMgMolb<S;ooooo07Cooooo001kooooo`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@4002
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool2ogMgM`Kooooo00?o<S8b
ooooooooool00oooool00onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`0000Cooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`1cooooo`00Noooool01?mEEEGoZJVYooooool00002ooooo`04o`00
0?ooooooooooo`0000gooooo00?o0000ooooooooool01_ooool00oo^k^ko410@onk^kP05ooooo`03
oc8b<_oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7QhOoIVIVooooool00004oooo
o`03o`000?oooooooooo00[ooooo1_l00005ooooo`03o`000?oooooooooo00[ooooo00Go<S8boiRH
V?ooooooV9RHoc8b<P07ooooo`03ogMgMolb<S;ooooo07Cooooo001kooooo`03omgMgOlQ8B7ok^k^
00?ooooo00Co0000ooooool0003o00003Oooool00ol0003oooooooooo`07ooooo`03oeEEEOnHV9So
oooo00Cooooo00?o0000onk^k_ooool01Oooool00omgMgOoIVIVooooo`0:ooooo`04omgMgOl@413o
ooooo`0000?ooooo00?ok^k^o`000?ooool05_ooool00ol0003oooooooooo`0:ooooo`05olc<c?l0
003o0000o`000?o<c<`01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<07Gooooo001looooo`03oiRH
V?mgMgOooooo00;ooooo00?o0000ooooooooool03?ooool00ol@413o0000o`000003o`0000Kooooo
00?ogMgMoa0@4?ooool01?ooool00omEEEGoMgMgooooo`06ooooo`03o`000?oooooooooo00Sooooo
1ol000000oooooooMgMgoeEEE@0Gooooo`03o`000?oooooooooo00[ooooo00Go410@okZj^_oooooo
^[Zjoa0@4004ooooo`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo00Sooooo
00?oEEEEoiRHV?ooool00oooool00ooMgMgo410@onk^kP02ooooo`05o`000?nj^[[ooooooiRHV?l@
41004Oooool00oo^k^ko410@omgMg@0Gooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_oo
oooo^[Zjo`000004ooooo`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo00So
oooo00?o^[ZjodA4A?ooool01?ooool02OmgMgOoIVIVooooooooooooV9RHoa0@4?l0003o8B4Qolc<
c00Aooooo`03ofIVI_mgMgOooooo01Gooooo00?oEEEEofIVI_l000003?ooool01OnYZJWo410@o`00
0?l@413oZJVY00Cooooo1?l0001fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .35043 L
.10458 .38922 L
.12507 .40438 L
.14415 .41594 L
.16254 .42461 L
.17277 .42837 L
.18221 .43117 L
.19242 .43349 L
.19781 .43441 L
.20351 .43517 L
.2059 .43542 L
.20846 .43565 L
.21068 .43581 L
.2131 .43595 L
.21456 .43602 L
.21592 .43607 L
.21722 .4361 L
.21795 .43612 L
.21861 .43613 L
.21986 .43614 L
.22056 .43614 L
.22121 .43614 L
.2224 .43614 L
.22365 .43612 L
.22487 .43609 L
.2262 .43605 L
.22861 .43595 L
.23096 .43582 L
.23313 .43567 L
.23806 .43522 L
.24329 .43458 L
.25201 .43318 L
.26163 .43115 L
.28097 .42568 L
.30183 .41796 L
.34297 .39872 L
.38259 .3778 L
.4207 .35825 L
.46126 .34046 L
.48 .33382 L
.50031 .32795 L
.51141 .32538 L
.52165 .3234 L
.53144 .32189 L
.53686 .3212 L
.5418 .32068 L
.54632 .32027 L
.55124 .31992 L
.55394 .31976 L
Mistroke
.55644 .31964 L
.55899 .31954 L
.56138 .31947 L
.56362 .31941 L
.56488 .31939 L
.56603 .31938 L
.56701 .31937 L
.56808 .31936 L
.5692 .31936 L
.57025 .31936 L
.57148 .31937 L
.57264 .31938 L
.57368 .3194 L
.57481 .31942 L
.57735 .31948 L
.57969 .31955 L
.58434 .31974 L
.58934 .32003 L
.59839 .32073 L
.60916 .32184 L
.61901 .32311 L
.65869 .32983 L
.69685 .33714 L
.71814 .34079 L
.73746 .34351 L
.74712 .3446 L
.75758 .34555 L
.76239 .34589 L
.76746 .3462 L
.77213 .34642 L
.77656 .34659 L
.77893 .34665 L
.78018 .34668 L
.78151 .34671 L
.78262 .34672 L
.78385 .34674 L
.78497 .34675 L
.78602 .34676 L
.78726 .34677 L
.78857 .34677 L
.78968 .34676 L
.7909 .34676 L
.79222 .34675 L
.79363 .34673 L
.79496 .34671 L
.79617 .34668 L
.80069 .34656 L
.80324 .34647 L
.80559 .34637 L
.8145 .34585 L
Mistroke
.81916 .3455 L
.82418 .34506 L
.83324 .34409 L
.85387 .34114 L
.87502 .33712 L
.89511 .33251 L
.93333 .32209 L
.97399 .3097 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .35913 L
.10458 .40096 L
.12507 .4172 L
.14415 .42998 L
.16371 .44064 L
.18221 .44835 L
.192 .45147 L
.19716 .45283 L
.20263 .45407 L
.20722 .45494 L
.21228 .45573 L
.21689 .45627 L
.2212 .45665 L
.22377 .45681 L
.225 .45686 L
.22616 .45691 L
.22682 .45693 L
.22754 .45695 L
.22879 .45697 L
.22949 .45698 L
.23024 .45699 L
.23088 .45699 L
.23158 .45699 L
.23287 .45698 L
.23404 .45695 L
.23469 .45694 L
.2354 .45692 L
.23668 .45687 L
.23916 .45674 L
.24145 .45659 L
.24572 .4562 L
.25043 .45562 L
.25997 .45396 L
.27007 .45155 L
.27932 .44875 L
.30018 .44057 L
.3398 .41917 L
.37791 .3942 L
.41847 .36697 L
.45751 .34377 L
.47743 .33399 L
.49901 .3253 L
.50912 .32196 L
.51981 .31895 L
.52984 .3166 L
.53899 .31485 L
.54843 .31344 L
.55328 .31285 L
.55857 .31233 L
Mistroke
.56344 .31195 L
.56796 .31167 L
.57228 .31148 L
.5747 .3114 L
.57688 .31135 L
.57809 .31133 L
.57921 .31131 L
.58045 .3113 L
.58177 .31129 L
.58244 .31129 L
.58316 .31129 L
.58447 .31129 L
.58575 .3113 L
.58693 .31131 L
.58803 .31132 L
.58906 .31134 L
.59141 .31139 L
.5937 .31146 L
.59617 .31155 L
.60147 .31179 L
.60704 .31213 L
.617 .3129 L
.63678 .31497 L
.65516 .3173 L
.69426 .32256 L
.71421 .32495 L
.73581 .32705 L
.74594 .32783 L
.75665 .32849 L
.7658 .32893 L
.77061 .32911 L
.77584 .32927 L
.77856 .32933 L
.78107 .32939 L
.78343 .32943 L
.78603 .32946 L
.78835 .32949 L
.78942 .3295 L
.79054 .3295 L
.79174 .32951 L
.79284 .32952 L
.79403 .32952 L
.79533 .32952 L
.796 .32952 L
.79674 .32952 L
.79743 .32951 L
.79807 .32951 L
.79928 .32951 L
.80056 .3295 L
.80322 .32947 L
Mistroke
.80615 .32943 L
.81136 .32934 L
.81623 .32922 L
.82663 .32886 L
.8365 .32839 L
.85503 .32719 L
.87485 .32544 L
.89324 .32333 L
.93239 .31724 L
.97399 .30938 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`3ooooooc_ooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0003o00000?oo00009Ol0
0004ool000Oo00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool00ooo003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_oo0002ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool01Oooool4ool000Co00004oooool01?o^k^ko8B4Qoa0@
4?o^k^h5ooooo`008Oooool00ol0003oo`00ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo1?oo
00000ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo2Ooo000=ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`;oo`001?l0
0003ooooo`03o`000?oooooooooo017ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o
0000oooooooo0000Uoooool6ool002Cooooo1Ooo001Eooooo`Co00006oooool2o`0000;ooooo0_l0
0004ooooo`008Oooool01?l0003ooooooooooooo002Cooooo`?oo`001?oooolLo`0000oooooo0_oo
0019ooooo`Coo`000oooool3o`0002Wooooo000Qooooo`05o`000?oooooooooooooooooo0000T?oo
ool2ool000Oo00007?ooool4o`0001Oooooo2?oo000/ooooo`_oo`001?ooool3o`0002cooooo000Q
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0S?ooool00ooo003o0000o`00000W
ooooo`Oo00006?ooool9ool0027ooooo0_oo000<ooooo`?o0000;oooool0027ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`28ooooo`?o0000<Oooool6o`0002Gooooo3Ooo000Eoooo
o`?o0000<_ooool0027ooooo0ol00004ooooo`03o`000?oooooooooo08Cooooo0ol0000jooooo`Ko
0000??ooool5o`0003Gooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
P?ooool3o`0004?ooooo1_l0000`ooooo`Ko0000>_ooool0027ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1looooo`03o`000?oo003oo`0004cooooo1_l0000Tooooo`Ko0000@?oo
ool0027ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1iooooo`03o`000?oo003o
o`0005Cooooo2?l0000Gooooo`Go0000A_ooool0027ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1fooooo`03o`000?oo003oo`0005kooooo5ol0001;ooooo`008Oooool00ol0003o
ooooooooo`09ooooo`;o0000Loooool3o`000003ool00?oooooooooo0<3ooooo000Qooooo`03o`00
0?oooooooooo00Oooooo00Goo`00ooooooooooooooooo`00001`ooooo`;o000000?oooooool00?oo
0000`oooool0027ooooo0ol00008ooooo`05ool00?ooooooooooooooool00000KOooool2o`000003
oooooooo003oo`000<Gooooo000Qooooo`03o`000?oooooooooo00Wooooo00Goo`00oooooooooooo
ooooo`00001Zooooo`;o00000_ooool00ooo003oooooooooo`35ooooo`008Oooool00ol0003ooooo
ooooo`0:ooooo`05ool00?ooooooooooooooool00000Ioooool2o`0000;ooooo0_oo0038ooooo`00
8Oooool00ol0003oooooooooo`0;ooooo`05ool00?ooooooooooooooool00000I?ooool2o`0000?o
oooo00?oo`00ooooooooool0b?ooool0027ooooo00?o0000ooooooooool03?ooool01?oo003ooooo
ooooooooool2o`00063ooooo0_l0003@ooooo`008Oooool00ol0003oooooooooo`0=ooooo`03ool0
0?oooooooooo00;ooooo00?o0000ooooooooool0Foooool2o`000=;ooooo000Qooooo`03o`000?oo
oooooooo00kooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`1Hooooo`;o0000e?oo
ool0027ooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`02ooooo`03o`000?oooooo
oooo05Gooooo0_l0003Fooooo`008Oooool3o`00013ooooo00?oo`00ooooooooool00_ooool00ol0
003oooooooooo`1Booooo`;o0000f?ooool0027ooooo00?o0000ooooooooool04Oooool00ooo003o
ooooooooo`02ooooo`03o`000?oooooooooo04oooooo0_l00005ooooo`;oo`00doooool0027ooooo
00?o0000ooooooooool04_ooool00ooo003oooooooooo`02ooooo`;o0000COooool2o`0000Kooooo
00?oo`00ooooooooool0doooool0027ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`18ooooo`;o00001oooool00ooo003oooooooooo`3Dooooo`008Oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo04Gooooo0_l00007ooooo`;oo`00eoooool0027ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`12ooooo`;o00002?ooool00ooo003oooooooooo`3Goooo
o`008Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03oooooo0_l00008ooooo`;o
o`00f_ooool0027ooooo0ol0000Mooooo`;o0000?Oooool2o`0000Wooooo00?oo`00ooooooooool0
f_ooool0027ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0gooooo`?o00002Ooo
ool2ool00=gooooo000Qooooo`03o`000?oooooooooo01[ooooo0_oo0004ooooo`;o0000=Oooool2
o`0000_ooooo00?oo`00ooooooooool0gOooool0027ooooo00?o0000ooooooooool07?ooool00ooo
003oooooooooo`03ooooo`03o`000?oooooooooo033ooooo0_l0000<ooooo`03ool00?oooooooooo
0=kooooo000Qooooo`03o`000?oooooooooo01gooooo0_oo0004ooooo`?o0000;Oooool2o`000>oo
oooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@04ooooo`03o`000?oooooooooo01oooooo00?oo`00ooooooooool01?ooool3o`00
02Sooooo0_l0003aooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool08?ooool2ool000Oooooo0_l0000Toooo
o`;o0000loooool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo
00;ooooo0ol0000Rooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool07Oooool4o`00
0?Gooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03oooo
o`03o`000?oooooooooo02?ooooo0_oo0007ooooo`Ko00005Oooool4o`0000kooooo0_oo003Yoooo
o`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004
ooooo`03o`000?oooooooooo02Gooooo00?oo`00ooooooooool02_ooool2o`00013ooooo0ol0000@
ooooo`;oo`00joooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool09_ooool00ooo003oooooooooo`0;oooooa3o00004Oooool2
ool00>gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo02Oooooo00?oo`00ooooooooool0:Oooool2ool00>oooooo0007oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0D?ooool3
ool00?7ooooo000Qooooo`03o`000?oooooooooo04kooooo0_oo003dooooo`008Oooool00ol0003o
ooooooooo`1<ooooo`;oo`00m_ooool0027ooooo0ol0000aooooo`Coo`00ooooool@ooooo`008Ooo
ool00ol0003oooooooooo`0eooooo`Ooo`001Oooool00ooo003oooooooooo`3oooooo`7ooooo000Q
ooooo`03o`000?oooooooooo03cooooo1Ooo003oooooo`Cooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000H
ooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool0
1?ooool3o`000?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5
ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001So
oooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3
o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00Z?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:?ooooo0027ooooo`?o
00004oooool00olQ8B7ogMgMooooo`07ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oM
gMd0Xoooool007kooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00?ooooo00?o0000oooo
ooooool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00?oV9RHoeEEEOooool01oooool0
1?mEEEGoV9RHooooooooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool00onj^[[oA4A4oooo
o`02ooooo`03ohN7QomVIVKooooo01?ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?oo
ool01?l@413o0000odA4A?o<c<alooooo`00O_ooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomV
IVH00oooool00ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0
003ogMgMooooo`06ooooo`09o`000?oooooooooooooooonHV9So8B4Qonk^k_ooooooA4A400[ooooo
00KoEEEEoiRHV?oooooooooooa0@4?nj^[X3ooooo`03onk^k_l0003ooooo00_ooooo1_l00004oooo
o`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oiRHV?l@413ogMgM07_ooooo001nooooo`07
o`000?oooooogMgMoc8b<_ooooook^k^oa0@4003ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01Oooool2ogMgM`Oooooo00?o<S8booooooooool00_ooool00onHV9So8B4Qonk^kP0<
ooooo`04oa0@4?oMgMgoooooo`0000Gooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0=ooooo`03ohN7QomEEEGooooo07[ooooo001nooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Go
0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00Gooooo00?ok^k^oa0@4?o^k^h0
1_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo
00001Oooool00ol0003oooooooooo`0:ooooo`Ko00001?ooool00ol0003oooooooooo`0:ooooo`05
olc<c?lQ8B7o0000oeEEEOl00000Noooool007kooooo00?ogMgMob4Q8Oo^k^h00oooool00ol0003o
ooooooooo`02o`0000gooooo00?o0000ooooooooool01_ooool00omEEEGoV9RHooooo`05ooooo`03
o`000?o^k^kooooo00Cooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgo410@ooooool00004oooo
o`03onk^k_l0003ooooo01Gooooo00?o0000ooooooooool02_ooool01OlQ8B7oQhN7oooooonHV9So
000007_ooooo001oooooo`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool03Oooool00ol@
413o0000o`000003o`0000Gooooo00?ogMgMoa0@4?ooool01Oooool00omEEEGoMgMgooooo`05oooo
o`03o`000?oooooooooo00Sooooo1ol00002ooooo`03ogMgMomEEEGooooo01Gooooo00?o0000oooo
ooooool02_ooool01Ol0003ooooooooooooooooo000007_ooooo002Fooooo`03o`000?oooooooooo
00Oooooo00?oEEEEoiRHV?ooool01?ooool02OoMgMgo410@onk^k_oooooo0000okZj^_ooooooV9RH
oa0@400Booooo`03onk^k_l@413ogMgM01Kooooo00?o0000ooooooooool02_ooool01OlQ8B7oV9RH
oooooomgMgOoEEEE07_ooooo002Fooooo`03o`000?oooooooooo00Oooooo00?o^[ZjodA4A?ooool0
1Oooool02?mgMgOoIVIVoooooonHV9So410@o`000?lQ8B7oc<c<4_ooool00omVIVKoMgMgooooo`0D
ooooo`03oeEEEOmVIVKo000000cooooo00Goc<c<oa0@4?l0003o<S8bonk^kP1kooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.95) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36468 L
.10458 .42001 L
.14415 .46289 L
.16408 .48026 L
.18221 .49329 L
.20178 .50419 L
.21254 .50873 L
.22272 .51204 L
.23241 .51431 L
.2373 .51513 L
.24012 .5155 L
.24269 .51577 L
.24504 .51596 L
.24728 .5161 L
.2485 .51616 L
.24964 .5162 L
.25088 .51623 L
.25158 .51624 L
.25221 .51624 L
.25336 .51624 L
.25442 .51623 L
.25558 .51621 L
.2568 .51617 L
.25787 .51613 L
.25887 .51608 L
.26113 .51593 L
.26373 .5157 L
.26614 .51543 L
.27158 .51464 L
.27638 .51372 L
.28148 .51252 L
.2903 .50991 L
.30004 .50626 L
.31939 .49668 L
.34024 .48313 L
.38138 .44783 L
.42101 .4055 L
.45912 .36022 L
.49968 .31074 L
.53872 .26525 L
.58022 .22251 L
.60102 .20419 L
.6202 .18951 L
.64007 .17674 L
.65867 .16721 L
.67743 .16007 L
.68738 .15731 L
.69293 .15608 L
.69807 .15514 L
Mistroke
.70298 .15441 L
.7082 .15384 L
.71119 .1536 L
.71265 .1535 L
.714 .15343 L
.7152 .15337 L
.71652 .15332 L
.71785 .15329 L
.71857 .15327 L
.71924 .15326 L
.7205 .15325 L
.7212 .15325 L
.72186 .15325 L
.72305 .15326 L
.72433 .15328 L
.72546 .15331 L
.72653 .15335 L
.72895 .15346 L
.73157 .15363 L
.73396 .15382 L
.73935 .15439 L
.7441 .15506 L
.74918 .15594 L
.75831 .15795 L
.77902 .16441 L
.80041 .17365 L
.82057 .18449 L
.85909 .20996 L
.90006 .24213 L
.93952 .27616 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36516 L
.10458 .42504 L
.14415 .47198 L
.16408 .49075 L
.18221 .50461 L
.20178 .51599 L
.21254 .52062 L
.21738 .52233 L
.22272 .52394 L
.22739 .52512 L
.23241 .52614 L
.23518 .5266 L
.23772 .52695 L
.2403 .52725 L
.24269 .52746 L
.24488 .52761 L
.2461 .52767 L
.24721 .52771 L
.24843 .52775 L
.24975 .52777 L
.251 .52777 L
.25214 .52776 L
.25322 .52774 L
.25423 .52771 L
.25533 .52767 L
.25651 .52761 L
.25893 .52744 L
.26113 .52725 L
.26594 .52665 L
.27104 .52578 L
.28022 .52362 L
.29008 .52043 L
.30098 .51591 L
.32032 .50542 L
.34118 .4908 L
.38232 .45325 L
.42194 .40863 L
.46005 .36095 L
.50061 .30864 L
.53966 .26031 L
.58116 .21482 L
.60196 .19533 L
.62114 .17974 L
.64101 .16621 L
.6596 .15612 L
.67837 .14855 L
.68832 .14562 L
.69386 .14431 L
.69901 .1433 L
Mistroke
.70432 .14247 L
.70914 .1419 L
.71189 .14165 L
.71449 .14147 L
.71582 .14139 L
.71722 .14133 L
.71796 .1413 L
.71877 .14127 L
.71944 .14126 L
.72018 .14124 L
.72088 .14123 L
.72153 .14122 L
.72281 .14121 L
.72397 .14122 L
.72521 .14124 L
.72653 .14126 L
.72776 .1413 L
.72912 .14136 L
.73058 .14143 L
.73305 .14159 L
.73565 .14181 L
.74028 .14231 L
.7453 .14302 L
.74985 .14381 L
.76006 .1461 L
.77844 .15191 L
.79767 .16017 L
.81848 .17141 L
.85945 .19959 L
.8989 .23291 L
.93684 .2692 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000=7ooooo3_oo001Uooooo`008Oooool0
0ol0003oooooooooo`3Oooooo`?oo`00H_ooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`36ooooo`;oo`00O?ooool0027ooooo00?o0000ooooooooool0
aOooool00ooo003oooooooooo`07oooooa7o00002oooool2ool005Oooooo000Qooooo`03o`000?oo
oooooooo0<?ooooo0_oo0006ooooo`Co00004Oooool6o`0000Oooooo0_oo001Eooooo`008Oooool0
0ol0003oooooooooo`31ooooo`;oo`001Oooool3o`0001_ooooo0ol00006ooooo`;oo`00Doooool0
027ooooo00?o0000ooooooooool0_oooool2ool000Cooooo0ol0000Qooooo`;o00001_ooool3ool0
053ooooo000Qooooo`?o0000_Oooool2ool000Cooooo0_l0000Vooooo`?o00001_ooool2ool004ko
oooo000Qooooo`03o`000?oooooooooo0;cooooo00?oo`00ooooooooool00_ooool2o`0002_ooooo
0_l00006ooooo`03ool00?oooooooooo04_ooooo000Qooooo`03o`000?oooooooooo0;_ooooo00Co
o`00oooooooooooooooo0_l0000_ooooo`;o00001Oooool00ooo003oooooooooo`1:ooooo`008Ooo
ool00ol0003oooooooooo`2jooooo`03ool00?oooooooooo00;o0000<oooool2o`0000Cooooo00?o
o`00ooooooooool0BOooool0027ooooo00?o0000ooooooooool0_?ooool00ol0003oooooooooo`0e
ooooo`;o00000oooool00ooo003oooooooooo`18ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003ooooooooo
o`2jooooo`;o0000>_ooool2o`0004cooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2iooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool0BOooool000Go00000_ooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o0000ooooooooool00_ooool3o`000;Oooooo0_l00010ooooo`;o0000BOoo
ool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o
0000ooooooooool0]_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo04Kooooo0007
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo
00?o0000ooooooooool0]Oooool00ol0003oooooooooo`14ooooo`;o0000A_ooool000Oooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
/?ooool2ool000;ooooo00?o0000ooooooooool0Aoooool01?l0003oooooooooooooool2ool0043o
oooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo0:oooooo00Goo`00ooooooooooooooooo`00001;ooooo`;o00000oooool00ooo
003oooooooooo`0mooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005oooo
o`03o`000?oooooooooo0:kooooo00?oo`00ooooooooool00_l0001>ooooo`05o`000?oooooooooo
oooooooo0000?_ooool0027ooooo00?o0000ooooooooool0[Oooool01?oo003oooooooooool0001A
ooooo`;o00000_ooool00ooo003oooooooooo`0kooooo`008Oooool00ol0003oooooooooo`2/oooo
o`04ool00?oooooo0000o`0005Cooooo00Co0000ooooooooooooo`00??ooool0027ooooo0ol0002[
ooooo`03ool00?oooooo000005Oooooo00?o0000ooooooooool00_oo000jooooo`008Oooool00ol0
003oooooooooo`2[ooooo`03ool00?l0003ooooo05Sooooo0_l00002ooooo`03ool00?oooooooooo
03Oooooo000Qooooo`03o`000?oooooooooo0:[ooooo00?oo`00o`000?ooool0Foooool01?l0003o
oooooooooooo000hooooo`008Oooool00ol0003oooooooooo`2Yooooo`03ool00?oooooo000005go
oooo00Co0000ooooooooooooo`00=oooool0027ooooo00?o0000ooooooooool0Z?ooool00ooo003o
ooooo`00001Oooooo`04o`000?ooooooooooool003Kooooo000Qooooo`03o`000?oooooooooo0:Oo
oooo00?oo`00ooooool00000HOooool2o`000003oooooooo003ooooo03Cooooo000Qooooo`03o`00
0?oooooooooo0:Kooooo00?oo`00ooooool00000I?ooool00ol0003oooooooooo`0dooooo`008Ooo
ool3o`000:Oooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0cooooo`008Oooool0
0ol0003oooooooooo`2Vooooo`03o`000?oooooooooo06Kooooo0_l0000cooooo`008Oooool00ol0
003oooooooooo`2Uooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0<?ooool0027o
oooo00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo02oo
oooo000Qooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0^ooooo`008Oooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo06oooooo00?o
0000oooooooo0000;Oooool0027ooooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`1a
ooooo`03o`000?oo003ooooo02cooooo000Qooooo`03o`000?oooooooooo09kooooo0_oo00000ol0
003oooooooooo`1cooooo`03o`000?oo003ooooo02_ooooo000Qooooo`?o0000W_ooool00ooo003o
0000ooooo`1fooooo`03o`000?oo003ooooo02[ooooo000Qooooo`03o`000?oooooooooo03gooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
03gooooo1?l000000ol@413oooooooooo`06ooooo`03ool00?l0003ooooo03;ooooo1?l000000ol@
413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM037ooooo00?o0000
ool00?ooool02Oooool5o`0001_ooooo000Qooooo`03o`000?oooooooooo03gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0nooooo`03o`000?oooooo
oooo00Oooooo00?oo`00ooooool00000=Oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`0aooooo`03o`000?oo003oo`0000Sooooo00GoV9RHob4Q8Oo^k^koooooodA4
A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?ooooooooooooooool@41004?oo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooool00000=_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo00002?oo
ool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003oooooooooo`0mooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`0nooooo`03o`000?oooooooooo00Kooooo00?o
o`00o`000?ooool0=_ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03?ooooo0_l0
00000ooo003oooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^01_ooooo000Qooooo`03o`000?oooooo
oooo03gooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
?oooool00ol0003oooooooooo`05ooooo`03ool00?l0003ooooo03Oooooo00?o0000ooooooooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<03Kooooo00?o0000ool00?ooool01oooool00omgMgOo
IVIVooooo`0Jooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Cooooo00?oo`00o`000?oo
ool0>?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Wooooo00?o0000ool00?oo
ool01oooool00ol0003oooooooooo`0Iooooo`008Oooool3o`0003gooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool00oooool00ooo003o
0000ooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>_ooool00ol0003o
o`00ooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@41006oooool0027ooooo00?o0000oooooooo
ool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000nooooo`03oeEEEOmVIVKo0000
00Gooooo00?oo`00ooooooooool0=oooool00omEEEGoIVIVo`00000=ooooo`Co0000>_ooool02Ol0
003oo`00ooooooooooooV9RHoa0@4?l0003o8B4Qolc<c00Kooooo`008Oooool00ol0003ooooooooo
o`2Gooooo`03ool00?l0003ooooo08Oooooo0_l0000Qooooo`008Oooool00ol0003oooooooooo`2F
ooooo`03ool00?l0003ooooo08[ooooo00?o0000ooooooooool07_ooool0027ooooo00?o0000oooo
ooooool0UOooool00ooo003o0000ooooo`2<ooooo`03o`000?oooooooooo01gooooo000Qooooo`03
o`000?oooooooooo09Gooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`0Booooo`;o
00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool0
Soooool00ol0003oooooooooo`0Aooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool001[o
ooooool0000jo`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?o0000ool00?oo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Cok^k^ob4Q8Ol@
413ok^k^1Oooool0027ooooo00?o0000ool00?ooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo017ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000oooooooo
0000TOooool00ol0003oooooooooo`2Vooooo`;o00000_ooool2o`0000Cooooo000Qooooo`04o`00
0?oooooo0000ool008oooooo00?o0000ooooooooool0/Oooool0027ooooo00Co0000oooooooooooo
o`00SOooool00ooo003o0000ooooo`2cooooo`008Oooool01Ol0003oooooooooooooooooo`0008co
oooo00?oo`00ooooooooool0/oooool0027ooooo00Ko0000ooooooooooooooooo`000?oo002:oooo
o`03ool00?oooooooooo0;Cooooo000Qooooo`?o00000_ooool00ol0003oo`00ooooo`27ooooo`03
ool00?oooooooooo0;Gooooo000Qooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0
QOooool00ol0003oo`00ooooo`2fooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
003ooooo08Gooooo00?oo`00ooooooooool0]_ooool0027ooooo00?o0000ooooooooool01?ooool0
0ol0003oo`00ooooo`23ooooo`03ool00?oooooooooo0;Oooooo000Qooooo`03o`000?oooooooooo
00Gooooo00?oo`00ooooooooool0POooool00ol0003oo`00ooooo`2hooooo`008Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oo003ooooo083ooooo00?o0000ool00?ooool0^Oooool0027ooooo
00?o0000ooooooooool01_ooool00ol0003oo`00ooooo`1nooooo`03o`000?oo003ooooo0;[ooooo
000Qooooo`?o00001oooool00ol0003oooooooooo`1looooo`03o`000?ooooooo`000;_ooooo000Q
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Noooool00ol0003oooooool0002l
ooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07[ooooo00?o0000ool0
0?ooool0_?ooool0027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1hooooo`03
o`000?oo003ooooo0;gooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
Moooool00ol0003oooooooooo`2nooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo07Gooooo00?o0000ooooooooool0_oooool0027ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`1cooooo`03o`000?oooooooooo0<3ooooo000Qooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`31ooooo`008Oooool3o`0000go
oooo00?oo`00ooooooooool0Koooool00ol0003oooooooooo`32ooooo`008Oooool00ol0003ooooo
ooooo`0=ooooo`03ool00?l0003ooooo06oooooo00?o0000ooooooooool0`_ooool0027ooooo00?o
0000ooooooooool03_ooool00ooo003oooooooooo`1]ooooo`03o`000?oooooooooo0<?ooooo000Q
ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool0Joooool00ol0003oo`00ooooo`34
ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03ool00?l0003ooooo06[ooooo00?o0000oooo
oooo0000aOooool0027ooooo00?o0000ooooooooool04?ooool00ooo003o0000ooooo`1Xooooo`03
o`000?ooooooo`000<Kooooo000Qooooo`03o`000?oooooooooo017ooooo00?oo`00o`000?ooool0
I_ooool00ol0003oooooool00037ooooo`008Oooool3o`0001;ooooo00?oo`00ooooooooool0I?oo
ool00ol0003oooooool00038ooooo`008Oooool00ol0003oooooooooo`0Booooo`03ool00?l0003o
oooo06Cooooo00?o0000ool00?ooool0b?ooool0027ooooo00?o0000ooooooooool04oooool00ooo
003o0000ooooo`1Rooooo`03o`000?ooooooo`000<Wooooo000Qooooo`03o`000?oooooooooo01Co
oooo00?oo`00o`000?ooool0H?ooool00ol0003oooooool0003:ooooo`008Oooool00ol0003ooooo
ooooo`0Dooooo`03ool00?oooooo000005oooooo00?o0000oooooooo0000boooool000Oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Co
oooo00?o0000ooooooooool05Oooool00ooo003oooooo`00001Mooooo`03o`000?ooooooo`000<co
oooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`0Fooooo`03ool00?l0003ooooo05_ooooo00?o0000oooooooo
0000cOooool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;o
oooo0ol0000Hooooo`03o`000?oooooooooo05Sooooo00?o0000oooooooo0000c_ooool000Oooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`1Gooooo`03o`000?oo003ooooo0<kooooo0007ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo0<oooooo0007ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`3@ooooo`001oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo057ooooo00?o0000ooooooooool0dOooool000Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
04oooooo00?o0000ooooooooool0d_ooool0027ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo0=?ooooo000Qooooo`03o`000?oooooooooo01gooooo
00?oo`00ooooool00000C?ooool2o`000=Kooooo000Qooooo`?o00007Oooool01?oo003ooooooooo
ool0001:ooooo`03o`000?oooooooooo0=Kooooo000Qooooo`03o`000?oooooooooo01kooooo00Co
o`00oooooooooooo0000B?ooool00ol0003oooooool0003Gooooo`008Oooool00ol0003ooooooooo
o`0Oooooo`04ool00?ooooooooooo`0004Kooooo00?o0000oooooooo0000f?ooool0027ooooo00?o
0000ooooooooool08?ooool01?oo003oooooooooool00014ooooo`03o`000?ooooooo`000=Wooooo
000Qooooo`03o`000?oooooooooo027ooooo00Coo`00oooooooooooo0000@Oooool2o`000003oooo
oooo003ooooo0=Wooooo000Qooooo`03o`000?oooooooooo02;ooooo00Coo`00oooooooooooo0000
?oooool01?l0003ooooooooooooo003Kooooo`008Oooool00ol0003oooooooooo`0Sooooo`04ool0
0?ooooooooooo`0003gooooo00Co0000ooooooooooooo`00g?ooool0027ooooo0ol0000Sooooo`05
ool00?ooooooooooooooool00000>oooool01?l0003ooooooooooooo003Mooooo`008Oooool00ol0
003oooooooooo`0Tooooo`05ool00?ooooooooooooooool00000>Oooool01?l0003ooooooooooooo
003Nooooo`008Oooool00ol0003oooooooooo`0Uooooo`04ool00?ooooooooooooooo`;o0000=_oo
ool01?l0003ooooooooooooo003Oooooo`008Oooool00ol0003oooooooooo`0Vooooo`03ool00?oo
oooooooo00;ooooo00?o0000ooooooooool0<Oooool2o`0000;ooooo00?oo`00ooooooooool0g_oo
ool0027ooooo00?o0000ooooooooool09oooool00ooo003oooooooooo`02ooooo`;o0000<?ooool0
1Ol0003oooooooooooooooooo`000>7ooooo000Qooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0:oooool2o`0000?ooooo00?oo`00ooooooooool0h?ooool0027ooooo00?o0000oooo
ooooool0;oooool2o`0002[ooooo00?o0000ooooooooool0i_ooool0027ooooo00?o0000oooooooo
ool0<Oooool2o`0002Kooooo0_l0003Yooooo`008Oooool3o`0003?ooooo0_l0000Rooooo`;o0000
joooool0027ooooo00?o0000ooooooooool0=Oooool2o`0001kooooo0_l0003]ooooo`008Oooool0
0ol0003oooooooooo`0`ooooo`;oo`001Oooool00ol0003oooooooooo`0Iooooo`;o0000koooool0
027ooooo00?o0000ooooooooool0<_ooool2ool000Cooooo0ol0000Eooooo`?o00001?ooool2ool0
0>_ooooo000Qooooo`03o`000?oooooooooo03Cooooo00?oo`00ooooooooool01?ooool5o`0000co
oooo1?l00005ooooo`;oo`00kOooool0027ooooo00?o0000ooooooooool0=Oooool3ool000Sooooo
3?l00007ooooo`;oo`00koooool0027ooooo00?o0000ooooooooool0>?ooool2ool001Gooooo1?oo
003aooooo`008Oooool3o`0003[ooooo0ooo000?ooooo`?oo`00mOooool0027ooooo00?o0000oooo
ooooool0?Oooool2ool000[ooooo0ooo003hooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5
ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`00
0?oooooooooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooo
odGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00:Cooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2Woooo
o`00Poooool3o`0001Cooooo00?o8B4QomgMgOooool01_ooool00ooMgMgo410@onk^kP0Hooooo`03
onk^k_l@413ogMgM0:Oooooo001kooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP02oooo
o`03o`000?oooooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03oiRHV?mEEEGo
oooo00Kooooo00?oEEEEoiRHV?ooool00_ooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool0
1_nj^[[oA4A4ooooooooooooQhN7ofIVIQGooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q
1?ooool01?l@413o0000odA4A?o<c<`5ooooo`05odA4A?l0003o0000oc8b<_oMgMd0MOooool007_o
oooo00Oo410@omgMgOmgMgOo8B4Qoooooon7QhOoIVIV00;ooooo00?o0000ooooooooool02oooool0
1Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000omgMgOooool01Oooool00ol0003ooooooooo
o`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooooooooooo410@okZj
^P;ooooo00?ok^k^o`000?ooool02oooool6o`0000Gooooo00?o0000ooooooooool01?ooool2ob4Q
8@Kooooo00?oV9RHoa0@4?oMgMd01oooool00omgMgOo<S8booooo`1dooooo`00Noooool01ol0003o
ooooomgMgOlb<S;oooooonk^k_l@41000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Kooooo0_mgMgL6ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h03?ooool0
1?l@413ogMgMooooool00004ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03Ooo
ool00on7QhOoEEEEooooo`07ooooo`03o`000?oooooooooo07?ooooo001kooooo`04oeEEEOnYZJWo
ooooo`0000;ooooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`06ooooo`03onk^
k_l@413ok^k^00Gooooo00?o<S8booooooooool01?ooool00onHV9So8B4Qonk^kP0;ooooo`04ohN7
QomVIVKoooooo`0000Cooooo00?o0000ooooooooool02_ooool6o`0000Gooooo00?o0000oooooooo
ool02_ooool01Oo<c<co8B4Qo`000?mEEEGo000000Oooooo00?oMgMgoc8b<_ooool0M?ooool007_o
oooo00?ogMgMob4Q8Oo^k^h00oooool01?l0003oooooo`000?l0000=ooooo`03o`000?oooooooooo
00Oooooo00?oEEEEoiRHV?ooool01?ooool00ol0003ok^k^ooooo`05ooooo`03ogMgMomVIVKooooo
00[ooooo00CogMgMoa0@4?oooooo00000oooool00oo^k^ko0000ooooo`0Fooooo`03o`000?oooooo
oooo00[ooooo00Go8B4QohN7QoooooooV9RHo`000004ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
MOooool007cooooo00?oV9RHogMgMoooool00_ooool00ol0003oooooooooo`0<ooooo`03oa0@4?l0
003o000000?o00001_ooool00ooMgMgo410@ooooo`04ooooo`03oeEEEOmgMgOooooo00Kooooo00?o
0000ooooooooool02?ooool7o`000003oooooomgMgOoEEEE01Oooooo00?o0000ooooooooool02_oo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0Moooool009;ooooo00?o
0000ooooooooool02?ooool00omEEEGoV9RHooooo`03ooooo`03omgMgOl@413ok^k^00;ooooo00Go
0000okZj^_ooooooV9RHoa0@400Aooooo`03onk^k_l@413ogMgM01Oooooo00?o0000ooooooooool0
2_ooool01OlQ8B7oV9RHoooooomgMgOoEEEE00Cooooo00?o0000ooooooooool0Moooool009;ooooo
00?o0000ooooooooool02?ooool00onj^[[oA4A4ooooo`04ooooo`09ogMgMomVIVKooooooooooonH
V9So410@o`000?lQ8B7oc<c<017ooooo00?oIVIVogMgMoooool05Oooool00omEEEGoIVIVo`00000<
ooooo`05olc<c?l@413o0000oc8b<_o^k^h01?ooool4o`0007Kooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -43.625 0 ]
[.5 .63053 43.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -104.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
146.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36897 L
.10458 .42975 L
.14415 .47855 L
.18221 .51463 L
.20178 .52826 L
.21267 .53427 L
.22272 .53879 L
.23293 .54236 L
.23832 .54382 L
.24402 .54504 L
.24641 .54546 L
.24897 .54584 L
.25119 .54611 L
.25361 .54635 L
.25507 .54647 L
.25643 .54655 L
.25773 .54662 L
.2584 .54665 L
.25912 .54667 L
.25983 .54669 L
.26048 .5467 L
.26176 .54672 L
.26293 .54671 L
.26416 .54669 L
.26538 .54666 L
.26607 .54663 L
.26671 .5466 L
.26912 .54646 L
.27131 .54627 L
.27364 .54602 L
.27847 .54532 L
.2838 .54427 L
.29326 .54169 L
.30213 .53843 L
.32232 .52812 L
.34082 .51523 L
.38045 .47762 L
.41855 .43067 L
.45912 .3724 L
.49816 .31194 L
.53966 .24751 L
.57964 .18973 L
.61811 .14196 L
.63759 .1217 L
.65902 .10299 L
.67938 .089 L
.69843 .07949 L
.70884 .0758 L
.71396 .07438 L
Mistroke
.71872 .0733 L
.72301 .07253 L
.72758 .07192 L
.7302 .07166 L
.73148 .07156 L
.73266 .07149 L
.73371 .07143 L
.73487 .07138 L
.73603 .07135 L
.73725 .07132 L
.73856 .07132 L
.73977 .07133 L
.7404 .07134 L
.7411 .07136 L
.74183 .07138 L
.74251 .07141 L
.7449 .07154 L
.74625 .07164 L
.74748 .07175 L
.75203 .07228 L
.7568 .07308 L
.76198 .0742 L
.7668 .07549 L
.77773 .0793 L
.78828 .08411 L
.79823 .08965 L
.81683 .10255 L
.85534 .13894 L
.89632 .1896 L
.93577 .24654 L
.97371 .30514 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36699 L
.10458 .42815 L
.14415 .47767 L
.18221 .51376 L
.20178 .52707 L
.21274 .53286 L
.22272 .53707 L
.22755 .53875 L
.23267 .54027 L
.2371 .54136 L
.24186 .54231 L
.24453 .54275 L
.24697 .54308 L
.24945 .54335 L
.25175 .54356 L
.25315 .54365 L
.25442 .54372 L
.25583 .54378 L
.25661 .5438 L
.25734 .54382 L
.25798 .54383 L
.25867 .54383 L
.25989 .54383 L
.2612 .54381 L
.26195 .5438 L
.26265 .54377 L
.26391 .54372 L
.26525 .54365 L
.26765 .54347 L
.27024 .54322 L
.2731 .54286 L
.2782 .54203 L
.283 .541 L
.29193 .53851 L
.30156 .53496 L
.3216 .5248 L
.3427 .51023 L
.3808 .47473 L
.42136 .42581 L
.46041 .37054 L
.50191 .30663 L
.54189 .2442 L
.58036 .1876 L
.62127 .13576 L
.64163 .11457 L
.66068 .09807 L
.67894 .08558 L
.68912 .08011 L
.69856 .07603 L
Mistroke
.7087 .07273 L
.71404 .07144 L
.71678 .0709 L
.71974 .07042 L
.72257 .07004 L
.72517 .06977 L
.72766 .06959 L
.72892 .06952 L
.72962 .06949 L
.73029 .06946 L
.73154 .06943 L
.73268 .06942 L
.7339 .06942 L
.73459 .06943 L
.73523 .06944 L
.7363 .06947 L
.73747 .06952 L
.73869 .06958 L
.73984 .06966 L
.74228 .06987 L
.74455 .07013 L
.7497 .07091 L
.75471 .07195 L
.76006 .07336 L
.76977 .07668 L
.77858 .08053 L
.7978 .0916 L
.81862 .10742 L
.85959 .14855 L
.89904 .19783 L
.93698 .25109 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000=Gooooo3_oo001Qooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=Cooooo1Ol00009ooooo`05o`00
0?oo003oo`00ool00?l00000GOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3?ooooo`;oo`0000?oooooo`000?l000004oooool2o`0005_ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0c?ooool3ool000?o00005oooool3o`0005Sooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0boooool01?oo003oooooo`000?l0
000Mooooo`;o0000E_ooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`39
ooooo`;oo`000_l0000Qooooo`03o`000?oooooooooo05?ooooo000Qooooo`03o`000?oooooooooo
0<Oooooo0_oo0002o`0002?ooooo0ooo001Cooooo`008Oooool00ol0003oooooooooo`35ooooo`;o
o`0000?oooooo`000?ooool09oooool00ooo003oooooooooo`1@ooooo`008Oooool3o`000<Cooooo
00Coo`00ooooool0003o0000:_ooool2ool0053ooooo000Qooooo`03o`000?oooooooooo0<Cooooo
00?oo`00o`000?ooool0;Oooool00ooo003oooooooooo`1=ooooo`008Oooool00ol0003ooooooooo
o`33ooooo`03ool00?l0003ooooo02oooooo00?oo`00o`000?ooool0C?ooool0027ooooo00?o0000
ooooooooool0`_ooool00ol0003oooooooooo`0aooooo`03ool00?l0003ooooo04_ooooo000Qoooo
o`03o`000?oooooooooo0<7ooooo00?o0000ooooooooool0<_ooool00ooo003oooooo`00001;oooo
o`008Oooool00ol0003oooooooooo`30ooooo`03o`000?oooooooooo03Cooooo00?oo`00ooooool0
0000B_ooool0027ooooo00?o0000ooooooooool0_oooool00ol0003oooooooooo`0fooooo`03ool0
0?oooooo000004Wooooo000Qooooo`?o0000__ooool00ol0003oooooooooo`0hooooo`03ool00?oo
oooo000004Sooooo000Qooooo`03o`000?oooooooooo0;gooooo00?o0000ooooooooool0>_ooool0
0ooo003oooooo`000017ooooo`008Oooool00ol0003oooooooooo`2kooooo`03ool00?l0003ooooo
03oooooo00?o0000ooooooooool0A?ooool0027ooooo00?o0000ooooooooool0^_ooool00ooo003o
0000ooooo`11ooooo`03o`000?oooooooooo04?ooooo000Qooooo`03o`000?oooooooooo0;Wooooo
00?oo`00o`000?ooool0@oooool00ol0003oooooooooo`12ooooo`008Oooool00ol0003ooooooooo
o`2hooooo`03ool00?l0003ooooo04Gooooo00?o0000ooooooooool0@Oooool0027ooooo00?o0000
ooooooooool0^?ooool00ooo003oooooooooo`16ooooo`03o`000?oooooooooo043ooooo000Qoooo
o`?o0000]oooool00ooo003oooooooooo`17ooooo`03o`000?oooooooooo043ooooo000Qooooo`03
o`000?oooooooooo0;Kooooo00?oo`00o`000?ooool0BOooool00ol0003oooooooooo`0oooooo`00
8Oooool00ol0003oooooooooo`2eooooo`03ool00?l0003ooooo04[ooooo00?oo`00o`000?ooool0
?oooool0027ooooo00?o0000ooooooooool0]?ooool00ooo003o0000ooooo`1;ooooo`03ool00?oo
oooo000003oooooo000Qooooo`03o`000?oooooooooo0;Cooooo00?oo`00ooooooooool0C?ooool0
0ooo003oooooo`00000nooooo`008Oooool00ol0003oooooooooo`2cooooo`03ool00?oooooooooo
04kooooo00?oo`00o`000?ooool0?Oooool0027ooooo00?o0000ooooooooool0/_ooool00ooo003o
0000ooooo`1@ooooo`03ool00?l0003ooooo03cooooo000Qooooo`03o`000?oooooooooo0;7ooooo
00?oo`00o`000?ooool0D_ooool00ooo003o0000ooooo`0kooooo`008Oooool3o`000;7ooooo00?o
0000ooooooooool0Doooool00ooo003o0000ooooo`0jooooo`008Oooool00ol0003oooooooooo`2`
ooooo`03o`000?oooooooooo05Cooooo00?oo`00ooooool00000>_ooool0027ooooo00?o0000oooo
ooooool0[oooool00ol0003oooooooooo`1Fooooo`03ool00?oooooo000003Wooooo000Qooooo`03
o`000?oooooooooo0:oooooo00?o0000ooooooooool0Eoooool00ooo003o0000ooooo`0hooooo`00
8Oooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo05Wooooo00?oo`00o`000?ooool0
=oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0[Oooool00ol0003oooooooooo`1Kooooo`03
ool00?l0003ooooo03Kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo05go
oooo00?oo`00o`000?ooool0=Oooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00_ooool3o`000:_ooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`0cooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`2Zooooo`03ool00?l0003ooooo067ooooo00?o0000oooooooo
ool0<oooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01?ooool00ol0003oooooooooo`2Zooooo`03ool00?oooooooooo06;ooooo00?o0000oooo
ooooool0<_ooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0ZOooool00ooo003oooooooooo`1Tooooo`03o`000?oooooooooo
037ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0:Sooooo00?oo`00ooooooooool0IOooool00ol0003oooooooooo`0aoooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo
0:Sooooo00?oo`00ooooooooool0I_ooool00ol0003oooooooooo`0`ooooo`008Oooool00ol0003o
ooooooooo`2Wooooo`03ool00?oooooooooo06Sooooo00?o0000ooooooooool0;oooool0027ooooo
00?o0000ooooooooool0Y_ooool00ooo003oooooooooo`1Yooooo`03o`000?oooooooooo02oooooo
000Qooooo`?o0000YOooool00ooo003o0000ooooo`1Zooooo`03ool00?l0003ooooo02oooooo000Q
ooooo`03o`000?oooooooooo0:Gooooo00?oo`00ooooooooool0J_ooool00ooo003oooooo`00000_
ooooo`008Oooool00ol0003oooooooooo`2Tooooo`03ool00?oooooooooo06cooooo00?oo`00o`00
0?ooool0;_ooool0027ooooo00?o0000ooooooooool0Xoooool00ooo003oooooooooo`1^ooooo`03
ool00?l0003ooooo02gooooo000Qooooo`03o`000?oooooooooo0:?ooooo00?oo`00ooooooooool0
Koooool00ooo003o0000ooooo`0/ooooo`008Oooool00ol0003oooooooooo`2Rooooo`03ool00?oo
oooooooo077ooooo00?oo`00ooooooooool0:oooool0027ooooo00?o0000ooooooooool0XOooool0
0ooo003oooooooooo`1cooooo`03ool00?oooooooooo02[ooooo000Qooooo`?o0000XOooool00ol0
003oooooooooo`1cooooo`03ool00?l0003ooooo02[ooooo000Qooooo`03o`000?oooooooooo0:3o
oooo00?o0000ooooooooool0MOooool00ooo003oooooooooo`0Yooooo`008Oooool00ol0003ooooo
ooooo`2Oooooo`03o`000?oooooooooo07Oooooo00?oo`00ooooooooool0:?ooool0027ooooo00?o
0000ooooooooool0W_ooool00ol0003oooooooooo`1iooooo`03ool00?oooooooooo02Oooooo000Q
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0NOooool00ol0003oo`00ooooo`0W
ooooo`008Oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo07_ooooo00?oo`00oooo
ooooool09_ooool0027ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`1looooo`03
ool00?l0003ooooo02Kooooo000Qooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool0
OOooool00ol0003oooooooooo`0Uooooo`008Oooool3o`0009_ooooo00?oo`00ooooooooool0Oooo
ool00ol0003oooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`0mooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0mooooo`Co0000
00?o410@ooooooooool01?ooool00ooo003oooooooooo`0dooooo`Co000000?o410@ooooooooool0
0_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0gooooo`03o`000?oooooooooo00?o
oooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`05ooooo`03
ool00?oooooooooo03Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool0=_ooool00ol0003oooooooooo`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0027o
oooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo03Sooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00?ooooo00?oV9RHob4Q
8Oo^k^h07?ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo
03Sooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0hooooo`03o`000?oooooooooo
00?ooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`000?oooooo
oooo00?ooooo00?oo`00ooooooooool0>Oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`0>Oooool00ol0003oooooooooo`04ooooo`03ogMgMomVIVKooooo01[ooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo047ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0iooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01Wooooo000Qooooo`?o0000?Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
0000ooooooooool0@Oooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo03[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0mooooo`07ool00?oooooo0000okZj^_oooooo
V9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l000000oooool00ooo003oooooooooo`0iooooo`03
oeEEEOmVIVKo000000gooooo1?l0000looooo`07ool00?ooooooV9RHoa0@4?l0003o8B4Qolc<c00K
ooooo`008Oooool00ol0003oooooooooo`2Fooooo`03ool00?oooooooooo08[ooooo00?oo`00oooo
ooooool07_ooool0027ooooo00?o0000ooooooooool0UOooool00ooo003oooooooooo`2<ooooo`03
ool00?oooooooooo01gooooo000Qooooo`03o`000?oooooooooo09Gooooo00?oo`00ooooooooool0
S?ooool00ol0003oo`00ooooo`0Mooooo`008Oooool00ol0003oooooooooo`2Dooooo`03ool00?oo
oooooooo08kooooo00?oo`00ooooooooool04_ooool2o`0000;ooooo0_l00004ooooo`008Oooool0
0ol0003oooooooooo`2Cooooo`03ool00?oooooooooo093ooooo00?oo`00ooooooooool04Oooool0
1_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooooooo0000<_l000000ooo003o0000o`00
0005o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^
1Oooool0027ooooo0_l0000=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Ooo
ool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003oooooo`00002Aooooo`03o`000?oo
oooooooo0:Kooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooool00000T?ooool0
0ol0003oooooooooo`2aooooo`008Oooool01?l0003ooooooooooooo002?ooooo`03o`000?oooooo
oooo0;7ooooo000Qooooo`04o`000?ooooooooooool008kooooo00?o0000ooooooooool0/_ooool0
027ooooo00Go0000ooooooooooooooooool0002<ooooo`03o`000?oooooooooo0;?ooooo000Qoooo
o`?o00000_ooool00ooo003oooooooooo`28ooooo`03ool00?l0003ooooo0;Cooooo000Qooooo`03
o`000?oooooooooo00;ooooo00?oo`00ooooooooool0R?ooool00ooo003oooooooooo`2dooooo`00
8Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo08Kooooo00?oo`00ooooooooool0
]Oooool0027ooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`24ooooo`03o`000?oo
003ooooo0;Kooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ool00?ooool0Q?ooool0
0ooo003oooooooooo`2fooooo`008Oooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo
08;ooooo00?oo`00ooooooooool0]oooool0027ooooo00?o0000ooooooooool01_ooool00ooo003o
ooooooooo`20ooooo`03o`000?oo003ooooo0;Sooooo000Qooooo`?o00001_ooool00ol0003oo`00
ooooo`20ooooo`03ool00?oooooooooo0;Sooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o
o`00ooooooooool0O_ooool00ol0003oo`00ooooo`2iooooo`008Oooool00ol0003oooooooooo`07
ooooo`03o`000?oo003ooooo07gooooo00?o0000ool00?ooool0^_ooool0027ooooo00?o0000oooo
ooooool02?ooool00ol0003oo`00ooooo`1looooo`03ool00?oooooooooo0;[ooooo000Qooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0N_ooool00ol0003oo`00ooooo`2kooooo`00
8Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo07Wooooo00?o0000ool00?ooool0
_?ooool0027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1hooooo`03ool00?oo
oooooooo0;cooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0M_ooool0
0ol0003oooooooooo`2mooooo`008Oooool3o`0000cooooo00?o0000ooooooooool0M?ooool00ol0
003oooooooooo`2nooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07Co
oooo00?o0000ooooooooool0__ooool0027ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo0;oooooo000Qooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`30ooooo`008Oooool00ol0003oooooooooo`0?
ooooo`03ool00?oooooooooo06oooooo00?o0000ooooooooool0`?ooool0027ooooo00?o0000oooo
ooooool03oooool00ooo003oooooooooo`1^ooooo`03o`000?oooooooooo0<7ooooo000Qooooo`03
o`000?oooooooooo013ooooo00?oo`00ooooooooool0K?ooool00ol0003oooooooooo`32ooooo`00
8Oooool3o`00017ooooo00?oo`00ooooooooool0J_ooool00ooo003o0000ooooo`33ooooo`008Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oo003ooooo06[ooooo00?oo`00ooooooooool0`ooo
ool0027ooooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`1Xooooo`03ool00?oooooo
oooo0<Cooooo000Qooooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool0Ioooool00ooo
003oooooooooo`34ooooo`008Oooool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo06Go
oooo00?oo`00ooooooooool0aOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool05?ooool00ooo
003oooooooooo`1Tooooo`03ool00?oooooooooo0<Kooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Eoooo
o`03ool00?oooooooooo06?ooooo00?oo`00ooooooooool0a_ooool000Oooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0000Fooooo`03ool00?oooooooooo
067ooooo00?oo`00ooooooooool0aoooool000Oooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`1Ooooo
o`03o`000?oo003ooooo0<Sooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`1O
ooooo`03ool00?oooooooooo0<Sooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo00?oo`00ooooooooool0GOooool0
0ooo003oooooooooo`39ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05_ooooo00?oo`00
ooooooooool0b_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05Wooooo00?oo`00ooooooooool0boooool0
027ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Gooooo`03ool00?oooooooooo
0<cooooo000Qooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Eoooool00ol0003o
ooooooooo`3<ooooo`008Oooool3o`0001cooooo00?o0000ooooooooool0EOooool00ol0003ooooo
ooooo`3=ooooo`008Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05?ooooo00?o
0000ooooooooool0c_ooool0027ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1A
ooooo`03o`000?oooooooooo0<oooooo000Qooooo`03o`000?oooooooooo01oooooo00?oo`00oooo
ooooool0Coooool00ol0003oooooooooo`3@ooooo`008Oooool00ol0003oooooooooo`0Oooooo`03
ool00?oooooooooo04oooooo00?o0000ooooooooool0d?ooool0027ooooo00?o0000ooooooooool0
8?ooool00ooo003oooooooooo`1=ooooo`03o`000?oooooooooo0=7ooooo000Qooooo`03o`000?oo
oooooooo027ooooo00?oo`00ooooooooool0B_ooool00ooo003o0000ooooo`3Cooooo`008Oooool3
o`0002;ooooo00?oo`00ooooooooool0Aoooool2ool00003o`000?oooooooooo0=?ooooo000Qoooo
o`03o`000?oooooooooo02?ooooo00?oo`00ooooooooool0AOooool00ooo003o0000o`00003Foooo
o`008Oooool00ol0003oooooooooo`0Tooooo`03ool00?oooooooooo04?ooooo00?oo`00o`000?oo
ool0eoooool0027ooooo00?o0000ooooooooool09Oooool00ooo003oooooooooo`11ooooo`03ool0
0?l0003ooooo0=Sooooo000Qooooo`03o`000?oooooooooo02Kooooo00?oo`00ooooooooool0?ooo
ool00ooo003o0000ooooo`3Iooooo`008Oooool00ol0003oooooooooo`0Wooooo`03ool00?oooooo
oooo03gooooo00?oo`00o`000?ooool0f_ooool0027ooooo00?o0000ooooooooool0:?ooool00ooo
003oooooooooo`0kooooo`03ool00?l0003ooooo0=_ooooo000Qooooo`03o`000?oooooooooo02Wo
oooo00?oo`00ooooooooool0>Oooool00ooo003o0000ooooo`3Looooo`008Oooool3o`0002[ooooo
00?oo`00ooooooooool0=oooool00ooo003o0000ooooo`3Mooooo`008Oooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo03Gooooo00?oo`00o`000?ooool0g_ooool0027ooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0cooooo`03ool00?l0003ooooo0=oooooo000Qoooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`3Ooooo
o`008Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0h?ooool0027ooooo00?o0000ooooooooool0;oooool2o`0002kooooo0_l0003Sooooo`008Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0hooo
ool0027ooooo0ol0000booooo`?oo`00:?ooool00ol0003oooooooooo`3Tooooo`008Oooool00ol0
003oooooooooo`0dooooo`03o`000?oo003oo`0002;ooooo0_oo00000ooooooo0000ooooo`3Voooo
o`008Oooool00ol0003oooooooooo`0eooooo`;o000000?oo`00ooooooooool07Oooool2ool00003
ooooool0003o00000>Sooooo000Qooooo`03o`000?oooooooooo03Oooooo00?o0000ool00?oo0000
6oooool2ool000?o0000j_ooool0027ooooo00?o0000ooooooooool0>?ooool2o`0000;oo`005ooo
ool2ool000;o0000kOooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo00Co0000ool00?oo003oo`004Oooool3ool000;o0000koooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0oooooo`;oo`002_ooool5ool00003ooooool0003o
00000?7ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@?ooool7o`00
00?ooooo1ol0003cooooo`006_ooool00ol0003oooooooooo`04ooooo`?o0000A_ooool4o`000?[o
oooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo0000
00Kooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:cooooo00?oMgMg
ofIVI_ooool05oooool00omVIVKoMgMgooooo`2Oooooo`00Roooool3o`0001?ooooo00?o8B4QomgM
gOooool01oooool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@413ogMgM09oooooo0022ooooo`07
ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP03ooooo`03o`000?oooooooooo00_ooooo00GoV9RH
o`000?l0003oA4A4okZj^P02ooooo`03oiRHV?mEEEGooooo00Oooooo00CoEEEEoiRHV?oooooooooo
1Ol00009ooooo`03oeEEEOnYZJWooooo00;ooooo00?o^[ZjodA4A?ooool00_ooool00on7QhOoIVIV
ooooo`0Booooo`Go00001Oooool2ob4Q8H3ooooo0022ooooo`07oa0@4?oMgMgoMgMgob4Q8Ooooooo
QhN7ofIVIP03ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_o^k^koMgMgoa0@4003oooo
o`03o`000?oMgMgooooo00Kooooo00Wo0000oooooooooooooooooiRHV?lQ8B7ok^k^oooooom4A4@0
2_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P?ooooo00?ok^k^o`000?ooool02oooool6o`00
0006oooooonHV9So8B4Qonk^k_ooooooA4A41Oooool2ob4Q8H3ooooo0022ooooo`07o`000?oooooo
gMgMoc8b<_ooooook^k^oa0@4003ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1Oooool2ogMgM`Oooooo00?o<S8booooooooool00_ooool00onHV9So8B4Qonk^kP0<ooooo`04oa0@
4?oMgMgoooooo`0000Gooooo00?o0000ooooooooool04_ooool00onHV9So8B4Qonk^kP28ooooo`00
P_ooool01?mEEEGoZJVYooooool00002ooooo`05o`000?ooooooooooooooool000003Oooool00ol0
003oooooooooo`05ooooo`03onk^k_l@413ok^k^00Kooooo00?o<S8booooooooool00oooool00onH
V9So8B4Qonk^kP0;ooooo`04ohN7QomVIVKoooooo`0000Gooooo00?o0000ooooooooool02_ooool6
o`0000?ooooo00?oV9RHob4Q8Oo^k^h0Qoooool008;ooooo00?ogMgMob4Q8Oo^k^h00oooool00ol0
003oooooooooo`02o`0000gooooo00?o0000ooooooooool01_ooool00omEEEGoV9RHooooo`05oooo
o`03o`000?o^k^kooooo00Cooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgo410@ooooool00004
ooooo`03onk^k_l0003ooooo01Gooooo00?oMgMgofIVI_ooool0Q_ooool008?ooooo00?oV9RHogMg
Moooool00_ooool00ol0003oooooooooo`0=ooooo`03oa0@4?l0003o000000?o00001Oooool00ooM
gMgo410@ooooo`05ooooo`03oeEEEOmgMgOooooo00Gooooo00?o0000ooooooooool02?ooool7o`00
00;ooooo00?oMgMgoeEEEOooool05_ooool00ol0003oooooooooo`25ooooo`00V_ooool00ol0003o
ooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00WogMgMoa0@4?o^k^koooooo`000?nj^[[o
oooooiRHV?l@41004_ooool00oo^k^ko410@omgMg@0Cooooo`05o`000?nj^[[ooooooiRHV?l@4100
Qoooool009[ooooo00?o0000ooooooooool01oooool00onj^[[oA4A4ooooo`05ooooo`08ogMgMomV
IVKooooooiRHV?l@413o0000ob4Q8Oo<c<`Booooo`03ofIVI_mgMgOooooo01?ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c027ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}]
}, Closed]],

Cell["\<\
Fig. 6.12 (animation). WKB (solid) and Galerkin (dashed) solutions \
for oscillations of an inhomogeneous string.\
\>", "Caption",
  CellTags->"Fig. 6.12"],

Cell[TextData[{
  "The solutions start out being very close, but over time, they diverge \
noticeably. This divergence is due to a simple error in the WKB method: the \
WKB frequencies are only approximately correct. Recall that the Fourier \
coefficients in the WKB solution have the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_n\)(t) = A\_n\ cos\ \[Omega]\_n\ t\)]],
  ". If there is an error \[Delta]\[Omega] in the WKB approximation to a mode \
frequency, a phase shift ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\[Omega]\ t\)]],
  " builds up over time, leading to error in the solution. "
}], "Text"],

Cell["\<\
\tAlso, there is a (small) error in the WKB eigenfunctions. While \
this error does not grow with time, it can still cause small errors in the \
solution. For both the eigenmodes and the frequencies, we expect the errors \
to be largest for the low-order WKB modes, and not so important for \
high-order modes, where WKB theory should work well.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Eigenmode Correction Using the Shooting Method", "Section",
  CellTags->{"i:40", "c:40"}],

Cell[TextData[{
  "\tIn order to improve the WKB solution, we require more accurate \
eigenfrequencies and eigenfunctions.  These can be obtained using the \
shooting method. Recall that in Chapter ",
  ButtonBox["1",
    ButtonData:>{"Chapter1.nb", "c:31"},
    ButtonStyle->"Hyperlink"],
  " the shooting method was introduced as a numerical technique to solve \
boundary-value problems. Here, we adapt the method to solve the eigenvalue \
problem ",
  ButtonBox["(6.3.14)",
    ButtonData:>"(6.3.14)",
    ButtonStyle->"Hyperlink"],
  ".  Since the error in the WKB method is important only for the low-order \
modes, we need use this method only for the first few modes. "
}], "Text"],

Cell[TextData[{
  "\tIn the shooting method we first define a numerical solution to Eq. ",
  ButtonBox["(6.3.14)",
    ButtonData:>"(6.3.14)",
    ButtonStyle->"Hyperlink"],
  ", with the frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " (or equivalently the eigenvalue ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_n\)]],
  ") a free parameter. For homogeneous Dirichlet boundary conditions, the \
initial-value of \[Psi] is set to zero, but the initial-value of ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\[Psi]/\[DifferentialD]x\)]],
  " is arbitrary, corresponding to the arbitrary value of the normal-mode \
amplitude. Here we set ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\[Psi]/\[DifferentialD]x = 1\)]],
  " initially (for von Neumann  conditions, we would set ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[DifferentialD]\[Psi]/\[DifferentialD]x\)\( | \
\_\(x = 0\)\)\) = 0\)]],
  "  and choose ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](0)\)]],
  " arbitrarily):"
}], "Text"],

Cell[BoxData[
    \(Sol[\[Omega]_] := \(NDSolve[{1/\[Rho][x] 
                D[T[x] D[\[Psi]shooting[x], x], 
                  x] \[Equal] \(-\[Omega]\^2\)\ \[Psi]shooting[
                  x], \[Psi]shooting[0] \[Equal] 
              0, \(\[Psi]shooting'\)[0] \[Equal] 1}, \[Psi]shooting, {x, 0, 
            L}]\)[\([1]\)]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.171"],

Cell[TextData[{
  "We then define \[Psi]end as the value of the solution at the ",
  "end point",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\[Psi]end[\[Omega]_] := \ \[Psi]shooting[L] /. Sol[\[Omega]]\)], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 6.172"],

Cell[TextData[{
  "The shooting-method frequency is then determined by finding the value of \
\[Omega] that makes ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[Psi]end",
            FontFamily->"Courier",
            FontWeight->"Bold"], "=", "0"}], TraditionalForm]]],
  ". We use ",
  StyleBox["FindRoot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox[" ",
    FontWeight->"Bold"],
  "to solve this equation, using the WKB eigenfrequency as the initial guess \
:"
}], "Text"],

Cell[BoxData[{
    \(\(\[Omega]WKB[n_]\  = \ n\ Pi/\[Tau][L];\)\), "\n", 
    \(\[Omega]shooting[
        n_]\  := \ \[Omega] /. \(FindRoot[\[Psi]end[\[Omega]] \[Equal] 
              0, {\[Omega], \[Omega]WKB[n], 
              1.1  \[Omega]WKB[n]}]\)[\([1]\)]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.173"],

Cell["\<\
Below, we compare the shooting-method frequencies and the WKB \
frequencies\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[
      Join[{{"\<n\>", \*"\"\<\!\(\[Omega]\_WKB\)\>\"", \
\*"\"\<\!\(\[Omega]\_shooting\)\>\"", \*"\"\<\!\(\[Omega]\_shooting\)-\!\(\
\[Omega]\_WKB\)\>\""}}, 
        Table[{n, \((\[Omega]WKB[n] // N)\), \[Omega]shooting[
              n], \[Omega]shooting[n] - \[Omega]WKB[n]}, {n, 1, 
            10}]]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.174"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"n\"\>", "\<\"\\!\\(\[Omega]\\_WKB\\)\"\>", \
"\<\"\\!\\(\[Omega]\\_shooting\\)\"\>", "\<\"\\!\\(\[Omega]\\_shooting\\)-\\!\
\\(\[Omega]\\_WKB\\)\"\>"},
          {"1", "2.8596008673801268`", "2.9029844906660083`", 
            "0.04338362328588152`"},
          {"2", "5.7192017347602535`", "5.741023072777916`", 
            "0.02182133801766284`"},
          {"3", "8.578802602140382`", "8.593362121086955`", 
            "0.014559518946573036`"},
          {"4", "11.438403469520507`", "11.449336088458773`", 
            "0.010932618938266359`"},
          {"5", "14.298004336900634`", "14.306740528407259`", 
            "0.008736191506624635`"},
          {"6", "17.157605204280763`", "17.164911015402836`", 
            "0.00730581112207318`"},
          {"7", "20.01720607166089`", "20.023446354803912`", 
            "0.006240283143021941`"},
          {"8", "22.876806939041014`", "22.88233658049111`", 
            "0.0055296414500958235`"},
          {"9", "25.73640780642114`", "25.741311611445788`", 
            "0.004903805024646601`"},
          {"10", "28.59600867380127`", "28.600426025434658`", 
            "0.004417351633389188`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["\<\
As expected, the high-order mode frequencies are accurately \
determined by the WKB method.  Therefore, in the solution we only use the \
shooting method for the first six mode frequencies. \
\>", "Text"],

Cell["\<\
\tThe shooting method also provides us with the eigenmodes. They \
are defined using our shooting solution for the frequency:\
\>", "Text"],

Cell[BoxData[
    \(\[Psi]s[n_, x_]\  := \ \[Psi]shooting[x] /. 
        Sol[\[Omega]shooting[n]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.175"],

Cell[TextData[{
  "In Cell ",
  ButtonBox["6.176",
    ButtonData:>"Cell 6.176",
    ButtonStyle->"Hyperlink"],
  ", we compare these shooting method eigenmodes with the WKB modes. Both \
solutions must be properly normalized in order to perform the comparison. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(norms[n_]\  := \ \((f\  = \[Psi]s[n, x]; \ 
          Sqrt[NIntegrate[\[Rho][x]\ f^2, {x, 0, L}]])\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(normWKB[n_]\  := \ \((f\  = \[Psi]WKB[n, x]; \ 
          Sqrt[NIntegrate[\[Rho][x] f^2, {x, 0, L}]])\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Table[
        Plot[Evaluate[{\[Psi]s[n, x]/norms[n], \[Psi]WKB[n, x]/
                normWKB[n]}], {x, 0, L}, 
          PlotLabel \[Rule] "\<WKB and shooting eigenmodes, n=\>" <> 
              ToString[n]], {n, 1, 5}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.176"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.326471 [
[.2619 .00222 -9 -9 ]
[.2619 .00222 9 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .09633 -24 -4.5 ]
[.01131 .09633 0 4.5 ]
[.01131 .17795 -18 -4.5 ]
[.01131 .17795 0 4.5 ]
[.01131 .25957 -24 -4.5 ]
[.01131 .25957 0 4.5 ]
[.01131 .34119 -6 -4.5 ]
[.01131 .34119 0 4.5 ]
[.01131 .4228 -24 -4.5 ]
[.01131 .4228 0 4.5 ]
[.01131 .50442 -18 -4.5 ]
[.01131 .50442 0 4.5 ]
[.01131 .58604 -24 -4.5 ]
[.01131 .58604 0 4.5 ]
[.5 .63053 -101 0 ]
[.5 .63053 101 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(0.5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(1.5)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .09633 m
.03006 .09633 L
s
[(0.25)] .01131 .09633 1 0 Mshowa
.02381 .17795 m
.03006 .17795 L
s
[(0.5)] .01131 .17795 1 0 Mshowa
.02381 .25957 m
.03006 .25957 L
s
[(0.75)] .01131 .25957 1 0 Mshowa
.02381 .34119 m
.03006 .34119 L
s
[(1)] .01131 .34119 1 0 Mshowa
.02381 .4228 m
.03006 .4228 L
s
[(1.25)] .01131 .4228 1 0 Mshowa
.02381 .50442 m
.03006 .50442 L
s
[(1.5)] .01131 .50442 1 0 Mshowa
.02381 .58604 m
.03006 .58604 L
s
[(1.75)] .01131 .58604 1 0 Mshowa
.125 Mabswid
.02381 .03104 m
.02756 .03104 L
s
.02381 .04736 m
.02756 .04736 L
s
.02381 .06369 m
.02756 .06369 L
s
.02381 .08001 m
.02756 .08001 L
s
.02381 .11266 m
.02756 .11266 L
s
.02381 .12898 m
.02756 .12898 L
s
.02381 .1453 m
.02756 .1453 L
s
.02381 .16163 m
.02756 .16163 L
s
.02381 .19427 m
.02756 .19427 L
s
.02381 .2106 m
.02756 .2106 L
s
.02381 .22692 m
.02756 .22692 L
s
.02381 .24324 m
.02756 .24324 L
s
.02381 .27589 m
.02756 .27589 L
s
.02381 .29222 m
.02756 .29222 L
s
.02381 .30854 m
.02756 .30854 L
s
.02381 .32486 m
.02756 .32486 L
s
.02381 .35751 m
.02756 .35751 L
s
.02381 .37383 m
.02756 .37383 L
s
.02381 .39016 m
.02756 .39016 L
s
.02381 .40648 m
.02756 .40648 L
s
.02381 .43913 m
.02756 .43913 L
s
.02381 .45545 m
.02756 .45545 L
s
.02381 .47177 m
.02756 .47177 L
s
.02381 .4881 m
.02756 .4881 L
s
.02381 .52074 m
.02756 .52074 L
s
.02381 .53707 m
.02756 .53707 L
s
.02381 .55339 m
.02756 .55339 L
s
.02381 .56972 m
.02756 .56972 L
s
.02381 .60236 m
.02756 .60236 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -162 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(WKB) show
87.000 13.000 moveto
(and) show
111.000 13.000 moveto
(shooting) show
165.000 13.000 moveto
(eigenmodes) show
231.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
243.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
249.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
255.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
261.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .11604 L
.10458 .22108 L
.14415 .31085 L
.18221 .38691 L
.22272 .45552 L
.26171 .50897 L
.28158 .53143 L
.30316 .55221 L
.32216 .56745 L
.34309 .58099 L
.36292 .59078 L
.37378 .59491 L
.38395 .59802 L
.38891 .59927 L
.39433 .60044 L
.39911 .6013 L
.4042 .60205 L
.40924 .60262 L
.41381 .60299 L
.41601 .60312 L
.41717 .60317 L
.4184 .60322 L
.41947 .60326 L
.42065 .60329 L
.42172 .6033 L
.42272 .60331 L
.42398 .60332 L
.42462 .60332 L
.42532 .60331 L
.42656 .6033 L
.42773 .60327 L
.4291 .60323 L
.43035 .60318 L
.43317 .60304 L
.43548 .60289 L
.438 .60268 L
.44308 .60215 L
.44772 .60152 L
.45269 .6007 L
.46163 .59885 L
.47187 .59615 L
.48298 .59255 L
.50313 .58428 L
.54405 .56104 L
.58345 .53131 L
.62134 .49677 L
.66168 .45444 L
.7005 .40911 L
.74178 .35679 L
Mistroke
.78154 .30311 L
.81979 .2491 L
.86048 .18966 L
.89966 .13109 L
.9413 .06796 L
.97619 .01472 L
Mfstroke
.02381 .01472 m
.06244 .11604 L
.10458 .22108 L
.14415 .31085 L
.18221 .38691 L
.22272 .45552 L
.26171 .50897 L
.28158 .53143 L
.30316 .55221 L
.32216 .56745 L
.34309 .58099 L
.36292 .59078 L
.37378 .59491 L
.38395 .59802 L
.38891 .59927 L
.39433 .60044 L
.39911 .6013 L
.4042 .60205 L
.40924 .60262 L
.41381 .60299 L
.41601 .60312 L
.41717 .60317 L
.4184 .60322 L
.41947 .60326 L
.42065 .60328 L
.42172 .6033 L
.42272 .60331 L
.42398 .60332 L
.42462 .60332 L
.42532 .60331 L
.42656 .6033 L
.42773 .60327 L
.4291 .60323 L
.43035 .60318 L
.43317 .60304 L
.43548 .60289 L
.438 .60268 L
.44308 .60215 L
.44772 .60151 L
.45269 .6007 L
.46163 .59885 L
.47187 .59615 L
.48298 .59255 L
.50313 .58428 L
.54405 .56104 L
.58345 .53131 L
.62134 .49677 L
.66168 .45444 L
.7005 .40911 L
.74178 .35679 L
Mistroke
.78154 .30311 L
.81979 .2491 L
.86048 .18966 L
.89966 .13109 L
.9413 .06796 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.482681,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo03_ooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03cooooo1Ol0
000Booooo`00Joooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0kooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@04_ooool006_ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03_ooooo00?oV9RHob4Q8Oo^k^h0
4oooool006_ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo03kooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03gooooo
00?oV9RHob4Q8Oo^k^h04_ooool006_ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03ogMgMomVIVKooooo017ooooo001[ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo
013ooooo001[ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0noooo
o`05o`000?nj^[[ooooooiRHV?l@41004_ooool006_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co0000?_ooool00omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000m
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04_ooool00?ooooooJOooool002cooooo00?o0000oooo
ooooool0ooooooljooooo`00;?ooool00ol0003oooooooooo`3ooooooc[ooooo000/ooooo`03o`00
0?oooooooooo0?oooooo>_ooool002cooooo00?o0000ooooooooool0ooooooljooooo`009Ooooooo
o`0003Wo00002oooool002cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo017ooooo000/ooooo`;o0000B?ooool00ol0003oooooooooo`17ooooo`03
o`000?oooooooooo04Oooooo00?o0000ooooooooool0A_ooool2o`0001?ooooo000/ooooo`;o0000
oooooolUooooo`03o`000?oooooooooo01?ooooo000/ooooo`;o0000oooooolUooooo`03o`000?oo
oooooooo01?ooooo000/ooooo`?o0000oooooolSooooo`03o`000?oooooooooo01Cooooo000/oooo
o`03o`000?oooooo00000?oooooo8_ooool00ol0003oooooooooo`0Eooooo`00;?ooool00ol0003o
ooooo`00003oooooob;ooooo00?o0000ooooooooool05Oooool002cooooo00Co0000oooooooooooo
0000oooooolPooooo`03o`000?oooooooooo01Kooooo000/ooooo`04o`000?ooooooooooo`000?oo
oooo7oooool00ol0003oooooooooo`0Gooooo`00;?ooool3o`000003ooooool0003ooooo0?oooooo
7Oooool00ol0003oooooooooo`0Gooooo`00;?ooool01Ol0003ooooooooooooooooo00000?oooooo
7Oooool00ol0003oooooooooo`0Hooooo`00;?ooool01Ol0003ooooooooooooooooo00000?oooooo
7Oooool00ol0003oooooooooo`0Hooooo`00;?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00ol0003oooooooooo`0Iooooo`00;?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo0?oooooo6?ooool00ol0003oooooooooo`0Jooooo`00;?ooool3o`00
00;ooooo00?o0000ooooooooool0oooooolHooooo`03o`000?oooooooooo01[ooooo000/ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolFooooo`03o`000?oooooooooo01_o
oooo000/ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolEooooo`03o`00
0?oooooooooo01cooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oolDooooo`03o`000?oooooooooo01cooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0oooooolCooooo`03o`000?oooooooooo01gooooo000/ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooolBooooo`03o`000?oooooooooo01kooooo000/ooooo`?o
00001Oooool00ol0003oooooooooo`3ooooooa7ooooo00?o0000ooooooooool07_ooool002cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooa3ooooo00?o0000ooooooooool0
7oooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0ooooool?ooooo`03o`000?oooooooooo023ooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`kooooo00?o0000oooo
ooooool08?ooool000Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^
00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo3Oooool00ol0003oooooooooo`0Qooooo`002Oooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00001oooool00ol0
003oooooooooo`3oooooo`_ooooo00?o0000ooooooooool08_ooool000Wooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0ooooool:ooooo`03o`000?oooooo
oooo02?ooooo0009ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooo`[ooooo00?o0000ooooooooool08oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0ooooool8ooooo`03o`000?oooooooooo02Cooooo0009
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo
1?l00006ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0ooooool7ooooo`03o`00
0?oooooooooo02Gooooo000/ooooo`?o00002?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o
0000ooooooooool09Oooool002cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3o
ooooo`Gooooo00?o0000ooooooooool09_ooool002cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`3oooooo`Cooooo00?o0000ooooooooool09oooool002cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`3oooooo`?ooooo00?o0000ooooooooool09oooool002cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`3oooooo`;ooooo00?o0000ooooooooool0
:?ooool002cooooo0ol0000:ooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0003ooooooooo
o`0Yooooo`00;?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0?oooooo00?o0000
ooooooooool0:Oooool002cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3noooo
o`03o`000?oooooooooo02[ooooo000/ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0o?ooool00ol0003oooooooooo`0[ooooo`00;?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo0?cooooo00?o0000ooooooooool0:oooool002cooooo0ol0000<ooooo`03o`000?oo
oooooooo0?_ooooo00?o0000ooooooooool0;?ooool002cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`3jooooo`03o`000?oooooooooo02cooooo000/ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0nOooool00ol0003oooooooooo`0]ooooo`00;?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo0?Oooooo00?o0000ooooooooool0;_ooool002cooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`3gooooo`03o`000?oooooooooo02kooooo
000/ooooo`?o00003_ooool00ol0003oooooooooo`3fooooo`03o`000?oooooooooo02oooooo000/
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`0`
ooooo`004Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0?Cooooo00?o
0000ooooooooool0<?ooool0017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0l_oo
ool00ol0003oooooooooo`0aooooo`004Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0?7ooooo00?o
0000ooooooooool0<_ooool0017ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0000Aooooo`03o`000?oooooooooo0?3ooooo00?o0000ooooooooool0<_oo
ool0017ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0>oooooo00?o0000ooooooooool0
<oooool0017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`3_ooooo`03o`000?oooooooooo03?ooooo
000Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`0dooooo`004Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0k?ooool00ol0003oooooooooo`0eooooo`00;?ooool3o`0001?ooooo00?o
0000ooooooooool0joooool00ol0003oooooooooo`0eooooo`00;?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo0>[ooooo00?o0000ooooooooool0=_ooool002cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`3Yooooo`03o`000?oooooooooo03Oooooo000/ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0j?ooool00ol0003oooooooooo`0gooooo`00
;?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0>Oooooo00?o0000ooooooooool0
>?ooool002cooooo0ol0000Eooooo`03o`000?oooooooooo0>Gooooo00?o0000ooooooooool0>Ooo
ool002cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`3Uooooo`03o`000?oooooo
oooo03Wooooo000/ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0i?ooool00ol0
003oooooooooo`0jooooo`00;?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0>;o
oooo00?o0000ooooooooool0>oooool002cooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`3Rooooo`03o`000?oooooooooo03_ooooo000/ooooo`?o00005oooool00ol0003ooooooooo
o`3Pooooo`03o`000?oooooooooo03cooooo000/ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0goooool00ol0003oooooooooo`0mooooo`00;?ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo0=kooooo00?o0000ooooooooool0?Oooool002cooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`3Mooooo`03o`000?oooooooooo03kooooo000/ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0foooool00ol0003oooooooooo`0oooooo`00;?oo
ool3o`0001Wooooo00?o0000ooooooooool0foooool00ol0003oooooooooo`0oooooo`00;?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0=[ooooo00?o0000ooooooooool0@?ooool0
02cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`3Hooooo`03o`000?oooooooooo
047ooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^
k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`3Hooooo`03o`000?oooooooooo047ooooo0009ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0e_ooool00ol0003oooooooooo`12
ooooo`002Oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool0
0ol0003oooooooooo`03ooooo`?o00006oooool00ol0003oooooooooo`3Eooooo`03o`000?oooooo
oooo04?ooooo0009ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`3D
ooooo`03o`000?oooooooooo04?ooooo0009ooooo`05o`000?ooooooooooooooool000003_ooool0
0omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo0=?ooooo00?o0000ooooooooool0A?ooool000Wooooo00Go410@
oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0=7ooooo00?o0000ooooooooool0AOoo
ool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S80
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
d?ooool00ol0003oooooooooo`16ooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
1Ol00004ooooo`Co00001_ooool3o`0001kooooo00?o0000ooooooooool0coooool00ol0003ooooo
ooooo`16ooooo`00;?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0<kooooo00?o
0000ooooooooool0Aoooool002cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`3<
ooooo`03o`000?oooooooooo04Sooooo000/ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0c?ooool00ol0003oooooooooo`18ooooo`00;?ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo0<[ooooo00?o0000ooooooooool0BOooool002cooooo0ol0000Pooooo`03o`00
0?oooooooooo0<Wooooo00?o0000ooooooooool0B_ooool002cooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`38ooooo`03o`000?oooooooooo04_ooooo000/ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool0aoooool00ol0003oooooooooo`1;ooooo`00;?ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo0<Kooooo00?o0000ooooooooool0C?ooool002co
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`34ooooo`03o`000?oooooooooo04go
oooo000/ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0a?ooool00ol0003ooooo
ooooo`1=ooooo`00;?ooool3o`0002?ooooo00?o0000ooooooooool0`_ooool00ol0003ooooooooo
o`1>ooooo`00;?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0<7ooooo00?o0000
ooooooooool0Coooool002cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2ooooo
o`03o`000?oooooooooo053ooooo000/ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0__ooool00ol0003oooooooooo`1Aooooo`00;?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo0;gooooo00?o0000ooooooooool0DOooool002cooooo0ol0000Uooooo`03o`000?oo
oooooooo0;cooooo00?o0000ooooooooool0D_ooool002cooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo05?ooooo000Rooooo`Co000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0;Wooooo00?o0000oooo
ooooool0E?ooool002Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo0;Oooooo00?o0000ooooooooool0EOooool002Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0;Kooooo00?o0000ooooooooool0
E_ooool002Cooooo00?o0000ooooooooool01Oooool3o`0002Sooooo00?o0000ooooooooool0]Ooo
ool00ol0003oooooooooo`1Fooooo`009?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0]?ooool00ol0003oooooooooo`1Gooooo`009?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`1Hooooo`009?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`1Iooooo`008_ooool00omEEEGoIVIV
o`000007ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0[oooool00ol0003ooooo
ooooo`1Jooooo`00;?ooool3o`0002[ooooo00?o0000ooooooooool0[oooool00ol0003ooooooooo
o`1Jooooo`00;?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo0:gooooo00?o0000
ooooooooool0Foooool002cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`2/oooo
o`03o`000?oooooooooo05cooooo000/ooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool0Zoooool00ol0003oooooooooo`1Looooo`00;?ooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo0:[ooooo00?o0000ooooooooool0GOooool002cooooo0ol0000]ooooo`03o`000?oo
oooooooo0:Sooooo00?o0000ooooooooool0G_ooool002cooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`2Wooooo`03o`000?oooooooooo05oooooo000/ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`1Oooooo`00;?ooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0H?ooool002cooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo067ooooo
000/ooooo`?o0000;oooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo067ooooo000/
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`1R
ooooo`00;?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo0:3ooooo00?o0000oooo
ooooool0Hoooool002cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2Nooooo`03
o`000?oooooooooo06Cooooo000/ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
WOooool00ol0003oooooooooo`1Tooooo`00;?ooool3o`0003;ooooo00?o0000ooooooooool0W?oo
ool00ol0003oooooooooo`1Uooooo`00;?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo09[ooooo00?o0000ooooooooool0I_ooool000[ooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`1Vooooo`003?ooool00ol0
003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo09Sooooo00?o0000
ooooooooool0Ioooool000cooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2Goooo
o`03o`000?oooooooooo06Sooooo000<ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^
k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000=Oooool00ol0003oooooooooo`2Eooooo`03
o`000?oooooooooo06Wooooo000<ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`2Cooooo`03o`000?oooooooooo06[ooooo000<ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool0T_ooool00ol0003oooooooooo`1[ooooo`003?ooool00ol0003ooooooooo
o`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`1/ooooo`002_oo
ool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo06gooooo
000/ooooo`?o0000>?ooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo06kooooo000/
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1_
ooooo`00;?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo08[ooooo00?o0000oooo
ooooool0L?ooool002cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`28ooooo`03
o`000?oooooooooo077ooooo000/ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
Qoooool00ol0003oooooooooo`1booooo`00;?ooool3o`0003_ooooo00?o0000ooooooooool0QOoo
ool00ol0003oooooooooo`1cooooo`00;?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo08Gooooo00?o0000ooooooooool0Loooool002cooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`23ooooo`03o`000?oooooooooo07Cooooo000/ooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool0POooool00ol0003oooooooooo`1eooooo`00;?ooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0M_ooool002cooooo0ol0
000nooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0Moooool002cooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo07Sooooo000/oooo
o`03o`000?oooooooooo043ooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`1ioooo
o`00;?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo07Wooooo00?o0000oooooooo
ool0N_ooool002cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1gooooo`03o`00
0?oooooooooo07_ooooo000/ooooo`?o0000@_ooool00ol0003oooooooooo`1eooooo`03o`000?oo
oooooooo07cooooo000/ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0M?ooool0
0ol0003oooooooooo`1mooooo`00;?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool0O_ooool001;ooooo1?l000000ol@413oooooooooo`02ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0A?ooool00ol0
003oooooooooo`1_ooooo`;o0000POooool001Cooooo00?o0000ooooooooool01?ooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool0POooool001Cooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`03ooooo`?o0000AOooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo08;ooooo
000Dooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0Poooool001Cooooo00?o0000
ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Aooo
ool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo08Cooooo000Dooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`17ooooo`03o`000?oooooo
oooo06Oooooo00?o0000ooooooooool0QOooool001Cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0IOooool00ol0
003oooooooooo`26ooooo`004_ooool00omEEEGoIVIVo`00000=ooooo`Co00001_ooool3o`0004Wo
oooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`27ooooo`00;?ooool00ol0003ooooo
ooooo`1:ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0R?ooool002cooooo00?o
0000ooooooooool0Boooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo08Wooooo000/
ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`2:
ooooo`00;?ooool00ol0003oooooooooo`1=ooooo`;o0000Foooool2o`0008gooooo000/ooooo`?o
0000Coooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo08gooooo000/ooooo`03o`00
0?oooooooooo053ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`2>ooooo`00;?oo
ool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo05;ooooo0_l0002Aooooo`00;?ooool0
0ol0003oooooooooo`1Booooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0TOooool0
02cooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
09;ooooo000/ooooo`03o`000?oooooooooo05Cooooo0_l0001<ooooo`;o0000UOooool002cooooo
0ol0001Fooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0UOooool002cooooo00?o
0000ooooooooool0Eoooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo09Kooooo000/
ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0@oooool2o`0009Wooooo000/oooo
o`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0@?ooool2o`0009_ooooo000/ooooo`03
o`000?oooooooooo05[ooooo0_l0000nooooo`;o0000WOooool002cooooo0ol0001Looooo`;o0000
>_ooool2o`0009oooooo000/ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`2Oooooo`002_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo05oooooo0_l0000dooooo`;o0000X_ooool000cooooo00?o0000ooooooooool01?ooool2
ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo067ooooo0_l0000`ooooo`;o0000Y?ooool000cooooo00?o0000ooooooooool03?ooool00onY
ZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Hoooool2o`00
02cooooo0_l0002Vooooo`003?ooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Ko
oooo00?oMgMgoc8b<_ooool01?ooool3o`0006Gooooo0_l0000Xooooo`;o0000Z?ooool000cooooo
00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`1Wooooo`?o00008oooool2o`000:[ooooo000<ooooo`03o`00
0?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo06[ooooo0ol0000Nooooo`;o0000[?ooool000cooooo00?o0000ooooooooool02_oo
ool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1]ooooo`;o00006?ooool4o`000:kooooo000:ooooo`03oeEEEOmVIVKo000000cooooo1Ol0
0004ooooo`Co00001_ooool00ol0003oooooooooo`1_ooooo`Co00003_ooool6o`000;;ooooo000/
ooooo`?o0000Loooool>o`000;Sooooo000/ooooo`03o`000?oooooooooo0?oooooo>_ooool002co
oooo00?o0000ooooooooool0ooooooljooooo`00;?ooool00ol0003oooooooooo`3ooooooc[ooooo
000/ooooo`03o`000?oooooooooo0?oooooo>_ooool002cooooo00?o0000ooooooooool0oooooolj
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00^oooool0
1OlQ8B7o0000o`000?m4A4CogMgM01Kooooo00Go8B4Qo`000?l0003oA4A4omgMg@2=ooooo`00__oo
ool00omgMgOo<S8booooo`0Hooooo`03ogMgMolb<S;ooooo03gooooo00?o0000okZj^_ooool0C?oo
ool00;oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0looooo`;o<S8bCOooool0
04Kooooo00OoQhN7ob4Q8OooooooooooodA4A?mgMgOooooo00?o00000_ooool00onYZJWo0000oooo
o`05o`000003oc8b<_o^k^kooooo00Oooooo00KoV9RHo`000?l0003oMgMgoa0@4?l00002ooooo`04
oa0@4?l0003o0000ooooo`;o000000Co410@ooooooo^k^koEEEE0_l000000onHV9So0000oa0@4007
ooooo`06oa0@4?lb<S;o0000o`000?l@413oZJVY0_ooool01?l@413o0000o`000?ooool2o`000004
oa0@4?ooooook^k^oeEEE@;o000000KoEEEEonk^k_ooooooooooonk^k_mEEED2o`000003oeEEEOo^
k^kooooo00;ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`Go00000_ooool01?l@413o0000
o`000?ooool2o`000008oa0@4?ooooook^k^oeEEEOl0003o410@olc<c?l00005ooooo`06onk^k_mE
EEGo0000o`000?m4A4Co^[Zj0oooool5o`0000;ooooo00Kok^k^oeEEEOl0003o410@olc<c?l00002
ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0_ooool01?l@413o0000o`000?ooool2o`000003
oa0@4?l0003o000000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE00;o000000KoEEEE
onk^k_ooooooooooonk^k_mEEED2o`000006oiRHV?l0003o410@ooooooo^k^koEEEE0_l000001_m4
A4Co^[Zjoooooooooooo410@oc8b<P;o000000?o410@ojVYZOooool01Oooool00on7QhOo0000okZj
^P0;ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool01oooool4o`000003oa0@
4?oooooooooo02[ooooo0016ooooo`06ofIVI_l0003ok^k^ooooool0003oMgMg0_ooool01_l0003o
oooooooooooooooo410@okZj^P;ooooo00Ko0000ooooooooooook^k^ohN7Qolb<S88ooooo`05o`00
0?o<c<cok^k^ohN7Qol000001?ooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMg
Moooooook^k^oeEEEOl00008ooooo`06o`000?nYZJWooooooooooonj^[[o00000oooool01Ol0003o
oooooooooooooooo000000;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED2ooooo`06oeEEEOmg
MgOooooooooooomgMgOoEEEE0oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Gooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMoooooook^k^oeEE
EOl00005ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@1Oooool00ol0003oooooooooo`02oooo
o`06oeEEEOmgMgOoooooonk^k_mEEEGo00000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooomEEEGoMgMg0_ooool02_mgMgOoEEEEooooooooooooEEEEogMgMoooooook^k^oeEEEOl00002
ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool01_l0003oZJVYoooooooooooo^[Zjo`00
00Kooooo00?oc<c<o`000?l@41003?ooool01_l0003ooooooooooooooooo0000ooooo`Ko00001Ooo
ool00ol0003oooooooooo`0/ooooo`00A_ooool2oc8b<P04oiRHV?nYZJWo410@oc8b<P;ooooo00Go
0000ooooooooooooV9RHodA4A003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1_ooool01Ol@413oQhN7ooooooo^k^ko000000Cooooo00Go0000ooooooooooooooooo`000002oooo
o`06o`000?ooooooooooooooooo^k^ko00002Oooool01Onj^[[oQhN7ofIVI_mVIVKo410@00?ooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00001?ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Ko0000ooooooooooooooooonk^k_l00005ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01_l0003oooooooooooooooook^k^
o`0000;ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooo`000004ooooo`04o`000?ooooooooooo`0000?o
oooo00Gok^k^o`000?ooooooooooo`000008ooooo`05okZj^_n7QhOoIVIVofIVI_l@41005Oooool0
1Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool0;?ooool004Kooooo00Ko410@
ojVYZOmEEEGoEEEEojVYZOl@4102ooooo`05o`000?mEEEGo^[Zjoa0@4?oMgMd00oooool01_l0003o
ooooooooooo^k^koQhN7oc8b<PSooooo00?o^[Zjoa0@4?l000000_l00004ooooo`05o`000?oooooo
ooooooooool000000_ooool01_l0003oooooooooooooooook^k^o`0000Sooooo00Ko<S8bob4Q8Omg
MgOoMgMgohN7Qoo^k^h3ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000009ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?oooooooooo
ooooooo^k^ko00001Oooool6o`0000Gooooo00?o0000ooooooooool00_ooool01_l0003ooooooooo
ooooooook^k^o`0000;ooooo1_l00003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooo000000Cooooo00Co0000oooooooooooo00000ooo
ool01?o^k^ko0000ooooooooool6o`0000;ooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^hEoooo
o`06o`000?ooooooooooooooool0003ooooo1_l00005ooooo`03o`000?oooooooooo02cooooo0016
ooooo`06o`000?oooooo8B4Qoa0@4?oooooo00000_ooool01?l0003oV9RHo`000?nj^[X4ooooo`Co
000000?oEEEEonk^k_ooool02_ooool00oo<c<co0000ooooo`03ooooo`05o`000?n7QhOoooooojVY
ZOl000000_ooool01_mVIVKoMgMgooooooo^k^koEEEEo`0000Sooooo00Ko0000okZj^_ooooook^k^
ogMgMol00003ooooo`05o`000?mgMgOoooooojVYZOl000000_ooool01_mEEEGoMgMgoooooooooooo
MgMgoeEEE@;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED3ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00oooool01Ol0003oQhN7oooooonYZJWo000000;ooooo00KoEEEEogMg
Moooooook^k^oeEEEOl00005ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b1Oooool00ol0003o
ooooooooo`02ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00000_ooool01_mEEEGoQhN7onk^k_oo
ooooQhN7oc8b<P?ooooo00Go0000ohN7QoooooooZJVYo`000002ooooo`0:o`000?o<c<coc<c<o`00
0?nYZJWogMgMob4Q8OooooooEEEEogMgM`;ooooo00[oMgMgoeEEEOooooooooooofIVI_mgMgOooooo
onk^k_mEEEGo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00Ko0000okZj^_oo
ooook^k^ogMgMol0000Eooooo`05o`000?n7QhOoooooojVYZOl000003?ooool00ol0003ooooooooo
o`0/ooooo`00AOooool00oo<c<co8B4Qooooo`02oeEEE@08oooooolb<S;o^[Zjooooool0003ooooo
ojVYZOmVIVH4ooooo`05o`000?oooooooooookZj^_l@41002_ooool01?lb<S;o0000o`000?nHV9P3
ooooo`03oa0@4?l0003oMgMg00;o000000WoV9RHooooooooooook^k^oeEEEOl0003o410@olc<c?l0
00002?ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000?ooooo00Go0000ogMgMol0003o0000oiRH
V002ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^0_ooool02?o^k^koEEEEo`000?l0003oEEEE
onk^k_oooooo410@1Ol00004ooooo`03oa0@4?l0003o000000Cooooo00?o410@o`000?mgMgL00_l0
00002_nHV9Soooooooooooo^k^koEEEEo`000?lQ8B7oZJVYo`000?l@4104ooooo`06onk^k_mEEEGo
0000o`000?m4A4Cok^k^0oooool00ol@413o0000o`000004ooooo`0:onk^k_mEEEGo0000ob4Q8OnY
ZJWo0000oa0@4?ooooook^k^oeEEE@;o000000OoA4A4onk^k_oooooooooooa0@4?l0003oMgMg00;o
000000goV9RHooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^k^koEEEE00;o
000000[oEEEEonk^k_ooooooooooonk^k_mEEEGo0000oa0@4?o<c<co00000_ooool01_o^k^koEEEE
o`000?l0003oA4A4onk^kP;ooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l0000Dooooo`03oa0@4?l0
003oMgMg00;o000000?oV9RHooooooooool02_ooool00ol0003oooooooooo`0/ooooo`00AOooool0
0onYZJWo<S8booooo`03ooooo`04odA4A?nHV9Soooooo`0000;ooooo00?oZJVYoeEEEOo^k^h00_oo
ool01Ol0003ooooooooooonj^[[o000001kooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0/ooooo`00AOooool3o`0000;ooooo1_l000001Ooooooo0000o`000?l0003ooooo00Co0000
00?o410@ojVYZOooool07Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool0<_ooool00omEEEGoIVIVo`00000^ooooo`00N?ooool2o`00013ooooo00?o
410@o`000?ooool08?ooool00ol@413oooooooooo`0Pooooo`03oa0@4?oooooooooo02kooooo0_l0
001Uooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.303363, -0.149245, \
0.00845269, 0.0123291}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.349182 0.163562 [
[.2619 .33668 -9 -9 ]
[.2619 .33668 9 0 ]
[.5 .33668 -3 -9 ]
[.5 .33668 3 0 ]
[.7381 .33668 -9 -9 ]
[.7381 .33668 9 0 ]
[.97619 .33668 -3 -9 ]
[.97619 .33668 3 0 ]
[.01131 .02206 -12 -4.5 ]
[.01131 .02206 0 4.5 ]
[.01131 .10384 -24 -4.5 ]
[.01131 .10384 0 4.5 ]
[.01131 .18562 -12 -4.5 ]
[.01131 .18562 0 4.5 ]
[.01131 .2674 -24 -4.5 ]
[.01131 .2674 0 4.5 ]
[.01131 .43096 -18 -4.5 ]
[.01131 .43096 0 4.5 ]
[.01131 .51274 -6 -4.5 ]
[.01131 .51274 0 4.5 ]
[.01131 .59452 -18 -4.5 ]
[.01131 .59452 0 4.5 ]
[.5 .63053 -101 0 ]
[.5 .63053 101 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .34918 m
.2619 .35543 L
s
[(0.5)] .2619 .33668 0 1 Mshowa
.5 .34918 m
.5 .35543 L
s
[(1)] .5 .33668 0 1 Mshowa
.7381 .34918 m
.7381 .35543 L
s
[(1.5)] .7381 .33668 0 1 Mshowa
.97619 .34918 m
.97619 .35543 L
s
[(2)] .97619 .33668 0 1 Mshowa
.125 Mabswid
.07143 .34918 m
.07143 .35293 L
s
.11905 .34918 m
.11905 .35293 L
s
.16667 .34918 m
.16667 .35293 L
s
.21429 .34918 m
.21429 .35293 L
s
.30952 .34918 m
.30952 .35293 L
s
.35714 .34918 m
.35714 .35293 L
s
.40476 .34918 m
.40476 .35293 L
s
.45238 .34918 m
.45238 .35293 L
s
.54762 .34918 m
.54762 .35293 L
s
.59524 .34918 m
.59524 .35293 L
s
.64286 .34918 m
.64286 .35293 L
s
.69048 .34918 m
.69048 .35293 L
s
.78571 .34918 m
.78571 .35293 L
s
.83333 .34918 m
.83333 .35293 L
s
.88095 .34918 m
.88095 .35293 L
s
.92857 .34918 m
.92857 .35293 L
s
.25 Mabswid
0 .34918 m
1 .34918 L
s
.02381 .02206 m
.03006 .02206 L
s
[(-2)] .01131 .02206 1 0 Mshowa
.02381 .10384 m
.03006 .10384 L
s
[(-1.5)] .01131 .10384 1 0 Mshowa
.02381 .18562 m
.03006 .18562 L
s
[(-1)] .01131 .18562 1 0 Mshowa
.02381 .2674 m
.03006 .2674 L
s
[(-0.5)] .01131 .2674 1 0 Mshowa
.02381 .43096 m
.03006 .43096 L
s
[(0.5)] .01131 .43096 1 0 Mshowa
.02381 .51274 m
.03006 .51274 L
s
[(1)] .01131 .51274 1 0 Mshowa
.02381 .59452 m
.03006 .59452 L
s
[(1.5)] .01131 .59452 1 0 Mshowa
.125 Mabswid
.02381 .03841 m
.02756 .03841 L
s
.02381 .05477 m
.02756 .05477 L
s
.02381 .07113 m
.02756 .07113 L
s
.02381 .08748 m
.02756 .08748 L
s
.02381 .1202 m
.02756 .1202 L
s
.02381 .13655 m
.02756 .13655 L
s
.02381 .15291 m
.02756 .15291 L
s
.02381 .16926 m
.02756 .16926 L
s
.02381 .20198 m
.02756 .20198 L
s
.02381 .21833 m
.02756 .21833 L
s
.02381 .23469 m
.02756 .23469 L
s
.02381 .25104 m
.02756 .25104 L
s
.02381 .28376 m
.02756 .28376 L
s
.02381 .30011 m
.02756 .30011 L
s
.02381 .31647 m
.02756 .31647 L
s
.02381 .33283 m
.02756 .33283 L
s
.02381 .36554 m
.02756 .36554 L
s
.02381 .38189 m
.02756 .38189 L
s
.02381 .39825 m
.02756 .39825 L
s
.02381 .41461 m
.02756 .41461 L
s
.02381 .44732 m
.02756 .44732 L
s
.02381 .46367 m
.02756 .46367 L
s
.02381 .48003 m
.02756 .48003 L
s
.02381 .49639 m
.02756 .49639 L
s
.02381 .5291 m
.02756 .5291 L
s
.02381 .54546 m
.02756 .54546 L
s
.02381 .56181 m
.02756 .56181 L
s
.02381 .57817 m
.02756 .57817 L
s
.02381 .0057 m
.02756 .0057 L
s
.02381 .61088 m
.02756 .61088 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -162 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(WKB) show
87.000 13.000 moveto
(and) show
111.000 13.000 moveto
(shooting) show
165.000 13.000 moveto
(eigenmodes) show
231.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
243.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
249.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
255.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
261.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .34918 m
.06244 .4482 L
.08255 .49357 L
.10458 .53555 L
.12507 .56605 L
.13422 .57681 L
.14415 .58642 L
.14961 .59077 L
.15465 .59421 L
.15937 .59693 L
.16457 .59936 L
.16922 .60105 L
.17359 .6022 L
.17599 .60266 L
.17819 .60298 L
.17941 .60311 L
.18005 .60316 L
.18073 .60321 L
.18198 .60328 L
.18314 .60331 L
.18439 .60332 L
.18509 .60331 L
.18575 .60329 L
.18644 .60326 L
.18708 .60322 L
.1885 .60311 L
.18971 .60298 L
.19103 .60281 L
.19343 .6024 L
.19623 .60178 L
.19921 .60095 L
.20456 .59903 L
.21414 .59423 L
.22473 .587 L
.24407 .56892 L
.26493 .54319 L
.30607 .47768 L
.34569 .40266 L
.3838 .32625 L
.42436 .24667 L
.46341 .17673 L
.50491 .11368 L
.52571 .0874 L
.54489 .06661 L
.56476 .0487 L
.58335 .03536 L
.60212 .02527 L
.61207 .0213 L
.61762 .01949 L
.62276 .01808 L
Mistroke
.62807 .01688 L
.63289 .01602 L
.63824 .01532 L
.64117 .01505 L
.64249 .01496 L
.64393 .01487 L
.6452 .01481 L
.64638 .01477 L
.64763 .01474 L
.64833 .01472 L
.64897 .01472 L
.65011 .01472 L
.65135 .01473 L
.65252 .01475 L
.6536 .01478 L
.65484 .01483 L
.656 .01489 L
.65866 .01507 L
.66125 .01531 L
.66403 .01563 L
.66901 .01637 L
.67363 .01726 L
.68411 .01994 L
.69433 .02345 L
.70523 .02813 L
.72661 .04 L
.74678 .05427 L
.78529 .08896 L
.82627 .13493 L
.86572 .18608 L
.90366 .23984 L
.94405 .30014 L
.97619 .34918 L
Mfstroke
.02381 .34918 m
.06244 .4482 L
.08255 .49357 L
.10458 .53555 L
.12507 .56605 L
.13422 .57681 L
.14415 .58642 L
.14961 .59077 L
.15465 .59421 L
.15937 .59693 L
.16457 .59937 L
.16922 .60105 L
.17359 .6022 L
.17599 .60266 L
.17819 .60298 L
.17941 .60311 L
.18005 .60316 L
.18073 .60321 L
.18198 .60328 L
.18314 .60331 L
.18439 .60332 L
.18509 .60331 L
.18575 .60329 L
.18644 .60326 L
.18708 .60322 L
.1885 .60311 L
.18971 .60298 L
.19103 .60281 L
.19343 .6024 L
.19623 .60178 L
.19921 .60095 L
.20456 .59903 L
.21414 .59423 L
.22473 .587 L
.24407 .56892 L
.26493 .54319 L
.30607 .47768 L
.34569 .40266 L
.3838 .32625 L
.42436 .24667 L
.46341 .17673 L
.50491 .11368 L
.52571 .0874 L
.54489 .06661 L
.56476 .0487 L
.58335 .03536 L
.60212 .02527 L
.61207 .0213 L
.61762 .01949 L
.62276 .01808 L
Mistroke
.62807 .01688 L
.63289 .01602 L
.63824 .01532 L
.64117 .01505 L
.64249 .01496 L
.64393 .01487 L
.6452 .01481 L
.64638 .01477 L
.64763 .01474 L
.64833 .01472 L
.64897 .01472 L
.65011 .01472 L
.65135 .01473 L
.65252 .01475 L
.6536 .01478 L
.65484 .01483 L
.656 .01489 L
.65866 .01507 L
.66125 .01531 L
.66403 .01563 L
.66901 .01637 L
.67363 .01726 L
.68411 .01994 L
.69433 .02345 L
.70523 .02813 L
.72661 .04 L
.74678 .05427 L
.78529 .08896 L
.82627 .13493 L
.86572 .18608 L
.90366 .23984 L
.94405 .30014 L
.97619 .34918 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.482681,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o9?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo0ol0003ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`006Oooool5o`0000Kooooo00?o0000ooooooooool0a?ooool>
o`0006oooooo000Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`31
ooooo`?o00003_ooool3o`0006cooooo000Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP07oooo
o`?o0000_Oooool4o`0001Cooooo0ol0001Yooooo`006oooool00onHV9So8B4Qonk^kP06ooooo`03
o`000?oooooooooo0;[ooooo0ol0000Kooooo`Co0000IOooool001cooooo00?oMgMgofIVI_ooool0
1Oooool00ol0003oooooooooo`2hooooo`;o00008_ooool2o`0006?ooooo000Mooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0]oooool00ol0003oooooooooo`0Tooooo`;o0000HOoo
ool001Wooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0;Gooooo0_l0
000Yooooo`03o`000?oooooooooo05kooooo000Iooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_oo
ool00ol0003oooooooooo`2cooooo`;o0000;?ooool2o`0005kooooo000Tooooo`?o0000/_ooool0
0ol0003oooooooooo`0^ooooo`;o0000G?ooool002Cooooo00?o0000ooooooooool0/?ooool2o`00
03?ooooo00?o0000ooooooooool0FOooool002Cooooo00?o0000ooooooooool0[oooool00ol0003o
ooooooooo`0dooooo`;o0000FOooool002Cooooo00?o0000ooooooooool0[_ooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo05Kooooo000Tooooo`03o`000?oooooooooo0:gooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`1Eooooo`009?ooool3o`000:cooooo00?o0000
ooooooooool0>oooool2o`0005Gooooo000Tooooo`03o`000?oooooooooo0:_ooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`1Booooo`009?ooool00ol0003oooooooooo`2Zooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool0DOooool002Cooooo00?o0000ooooooooool0
ZOooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo053ooooo000Tooooo`03o`000?oo
oooooooo0:Sooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1?ooooo`009?ooool3
o`000:Sooooo00?o0000ooooooooool0AOooool2o`0004oooooo000Tooooo`03o`000?oooooooooo
0:Oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1<ooooo`009?ooool00ol0003o
ooooooooo`2Vooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0Boooool002Cooooo
00?o0000ooooooooool0YOooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo04[ooooo
000Tooooo`03o`000?oooooooooo0:Cooooo00?o0000ooooooooool0C_ooool00ol0003ooooooooo
o`19ooooo`009?ooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo053ooooo00?o0000
ooooooooool0B?ooool002Cooooo0ol0002Rooooo`03o`000?oooooooooo05;ooooo00?o0000oooo
ooooool0Aoooool002Cooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`1Booooo`03
o`000?oooooooooo04Oooooo000Tooooo`03o`000?oooooooooo0:7ooooo00?o0000ooooooooool0
E?ooool00ol0003oooooooooo`16ooooo`002_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2Pooooo`03o`00
0?oooooooooo05Kooooo00?o0000ooooooooool0AOooool000cooooo00?o0000ooooooooool01?oo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2Oooooo`03o`000?oo
oooooooo05Sooooo00?o0000ooooooooool0A?ooool00003ooooool0003o000000Co00001Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo0ol0002Nooooo`03o`000?oooooo
oooo05[ooooo00?o0000ooooooooool0@oooool000cooooo00?o0000ooooooooool03_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool0G?ooool00ol0
003oooooooooo`12ooooo`003?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo05kooooo00?o0000oooo
ooooool0@Oooool000cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo09_ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`10ooooo`00
3?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
Voooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo043ooooo000:ooooo`03oeEEEOmV
IVKo000000gooooo1?l00006ooooo`?o0000V_ooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo03oooooo000Tooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool0I?ooool0
0ol0003oooooooooo`0nooooo`009?ooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool0?Oooool002Cooooo00?o0000ooooooooool0V?ooool00ol0003o
ooooooooo`1Wooooo`03o`000?oooooooooo03cooooo000Tooooo`03o`000?oooooooooo09Oooooo
00?o0000ooooooooool0JOooool00ol0003oooooooooo`0kooooo`009?ooool00ol0003ooooooooo
o`2Gooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0>_ooool002Cooooo0ol0002F
ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0>_ooool002Cooooo00?o0000oooo
ooooool0UOooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo03Wooooo000Tooooo`03
o`000?oooooooooo09Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0hooooo`00
9?ooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0
=oooool002Cooooo00?o0000ooooooooool0Toooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo03Oooooo000Tooooo`?o0000Toooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo03Kooooo000Tooooo`03o`000?oooooooooo09;ooooo00?o0000ooooooooool0M?ooool00ol0
003oooooooooo`0eooooo`009?ooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo07Ko
oooo00?o0000ooooooooool0=?ooool002Cooooo00?o0000ooooooooool0TOooool00ol0003ooooo
ooooo`1gooooo`03o`000?oooooooooo03?ooooo000Tooooo`03o`000?oooooooooo093ooooo00?o
0000ooooooooool0N?ooool00ol0003oooooooooo`0cooooo`009?ooool00ol0003oooooooooo`2?
ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0<_ooool002Cooooo0ol0002?oooo
o`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0<Oooool002Cooooo00?o0000oooooooo
ool0S_ooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo033ooooo000Jooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo07kooooo
00?o0000ooooooooool0<?ooool001cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2=ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0;oooool0017ooooo1_l00005
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`21
ooooo`03o`000?oooooooooo02kooooo000Looooo`03o`000?oooooooooo00Gooooo0ol0002<oooo
o`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0;Oooool001cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo08?ooooo00?o0000oooooooo
ool0;Oooool001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2:ooooo`03o`00
0?oooooooooo08Gooooo00?o0000ooooooooool0;?ooool001cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0:ooo
ool001[ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`29ooooo`03o`000?oooooo
oooo08Oooooo00?o0000ooooooooool0:oooool002Cooooo0ol00029ooooo`03o`000?oooooooooo
08Sooooo00?o0000ooooooooool0:_ooool002Cooooo00?o0000ooooooooool0R?ooool00ol0003o
ooooooooo`2:ooooo`03o`000?oooooooooo02Wooooo000Tooooo`03o`000?oooooooooo08Sooooo
00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0Yooooo`009?ooool00ol0003ooooooooo
o`27ooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0:?ooool002Cooooo00?o0000
ooooooooool0Q_ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo02Oooooo000Toooo
o`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`0Woooo
o`009?ooool3o`0008Gooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0Vooooo`00
9?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool0
9Oooool002Cooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`2Booooo`03o`000?oo
oooooooo02Gooooo000Tooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool0Toooool0
0ol0003oooooooooo`0Tooooo`009?ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo
09Gooooo00?o0000ooooooooool08oooool002Cooooo0ol00023ooooo`03o`000?oooooooooo09Go
oooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool0P_ooool00ol0003ooooo
ooooo`2Gooooo`03o`000?oooooooooo02;ooooo000Tooooo`03o`000?oooooooooo087ooooo00?o
0000ooooooooool0VOooool00ol0003oooooooooo`0Qooooo`009?ooool00ol0003oooooooooo`21
ooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool08Oooool002Cooooo00?o0000oooo
ooooool0P?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo023ooooo000Tooooo`?o
0000P?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo01oooooo000Tooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`0Oooooo`009?oo
ool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool07_oo
ool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`2Pooooo`03o`00
0?oooooooooo01gooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo0:3ooooo
00?o0000ooooooooool07Oooool00003ooooool0003o000000Co00000_ooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1mooooo`03o`00
0?oooooooooo0:;ooooo00?o0000ooooooooool07?ooool000Wooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0001mooooo`03o`000?oooooooooo0:?ooooo
00?o0000ooooooooool06oooool000Wooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo0:Go
oooo00?o0000ooooooooool06_ooool000Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`2Uooooo`03
o`000?oooooooooo01[ooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0Yoooool00ol0003o
ooooooooo`0Iooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03
o`000?oooooooooo07_ooooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`0Hooooo`00
9?ooool3o`0007[ooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`0Hooooo`009?oo
ool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo0:[ooooo00?o0000ooooooooool05ooo
ool002Cooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`2/ooooo`03o`000?oooooo
oooo01Kooooo000Tooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0[?ooool00ol0
003oooooooooo`0Fooooo`009?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo0:ko
oooo00?o0000ooooooooool05Oooool002Cooooo0ol0001hooooo`03o`000?oooooooooo0:oooooo
00?o0000ooooooooool05?ooool002Cooooo00?o0000ooooooooool0Moooool00ol0003ooooooooo
o`2`ooooo`03o`000?oooooooooo01Cooooo000Tooooo`03o`000?oooooooooo07Oooooo00?o0000
ooooooooool0/Oooool00ol0003oooooooooo`0Cooooo`009?ooool00ol0003oooooooooo`10oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@0Pooooo`03o`000?oooooooooo01kooooo1?l000000ol@413oooooooooo`0oooooo`Co000000?o
410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0jooooo`03o`00
0?oooooooooo00?ooooo1Ol0000:ooooo`009?ooool00ol0003oooooooooo`10ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool07oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0>Oooool00ol0003oooooooooo`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@02_ooool002Cooooo00?o0000ooooooooool0@?ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04?o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00?o
oooo00?oV9RHob4Q8Oo^k^h02oooool002Cooooo0ol00010ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`0Nooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool0@oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03_ooooo00?o0000oooooooo
ool00oooool00onHV9So8B4Qonk^kP0:ooooo`009?ooool00ol0003oooooooooo`10ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01kooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00looooo`03o`000?oooooooooo00Cooooo00?oMgMgofIVI_ooool02Oooool0
02Cooooo00?o0000ooooooooool0@?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02?ooool002Cooooo00?o0000ooooooooool0@?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`10ooooo`07o`000?oooooo
0000okZj^_ooooooV9RHoa0@400:ooooo`009?ooool00ol0003oooooooooo`10ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0001kooooo00?o0000ooooooooool08Oooool00omEEEGoIVIV
o`000013ooooo`03oeEEEOmVIVKo000000gooooo1?l00010ooooo`06o`000?nHV9So410@o`000?lQ
8B7oc<c<2_ooool002Cooooo0ol0001booooo`03o`000?oooooooooo0;cooooo00?o0000oooooooo
ool03Oooool002Cooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`2mooooo`03o`00
0?oooooooooo00cooooo000Tooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0_ooo
ool00ol0003oooooooooo`0;ooooo`009?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo0;oooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0L?ooool00ol0
003oooooooooo`31ooooo`03o`000?oooooooooo00[ooooo000Moooooooo0000BOl00003ooooo`00
9?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`09ooooo`009?ooool2o`0000kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo000Tooooo`;o0000Koooool0
0ol0003oooooooooo`3@ooooo`009?ooool2o`0006oooooo00?o0000ooooooooool0d?ooool002Co
oooo00?o0000ooooool00000KOooool00ol0003oooooooooo`3Aooooo`009?ooool3o`0006gooooo
00?o0000ooooooooool0dOooool002Cooooo00Co0000oooooooooooo0000K?ooool00ol0003ooooo
ooooo`3Aooooo`009?ooool01?l0003oooooooooool0001[ooooo`03o`000?oooooooooo0=;ooooo
000Tooooo`04o`000?ooooooooooo`0006_ooooo00?o0000ooooooooool0d_ooool002Cooooo00Go
0000ooooooooooooooooo`00001Yooooo`03o`000?oooooooooo0=?ooooo000Tooooo`?o000000?o
ooooo`000?ooool0J?ooool00ol0003oooooooooo`3Cooooo`009?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0e?ooool002Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo0=Cooooo000Tooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`3Eooooo`00
9?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0
eOooool002Cooooo0ol00003ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0e_oo
ool002Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooo
oooo0=Kooooo000Tooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`3Gooooo`009?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0eoooool002Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1Nooooo`03o`000?oooooooooo0=Sooooo000Tooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0G_ooool00ol0003oooooooooo`3Hooooo`009?ooool3o`0000Gooooo00?o0000
ooooooooool0GOooool00ol0003oooooooooo`3Iooooo`009?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo05cooooo00?o0000ooooooooool0fOooool002Cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo0=[ooooo0009ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`3Koooo
o`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo
0=_ooooo0009ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03oooo
o`?o00001oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo0=cooooo0009ooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`3Looooo`002Oooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`3Mooooo`002Oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0gOooool000Wooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`1Dooooo`03o`000?oooooooooo0=kooooo0009ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo0=kooooo000Tooooo`?o00002_ooool00ol0003oooooooooo`1Boooo
o`03o`000?oooooooooo0=oooooo000Tooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0D_ooool00ol0003oooooooooo`3Oooooo`009?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo053ooooo00?o0000ooooooooool0h?ooool002Cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo0>3ooooo000Tooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`3Qooooo`009?ooool3o`00
00cooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`3Rooooo`009?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0h_ooool002Cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo0>?ooooo
000Tooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`3Sooooo`009?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Wooooo00?o0000
ooooooooool0i?ooool002Cooooo0ol0000>ooooo`03o`000?oooooooooo04Wooooo00?o0000oooo
ooooool0i?ooool002Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`17ooooo`03
o`000?oooooooooo0>Gooooo000Tooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
A_ooool00ol0003oooooooooo`3Vooooo`009?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool0i_ooool002Cooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`14ooooo`03o`000?oooooooooo0>Oooooo000Tooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`3Xooooo`009?ooool3o`00017o
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`3Xooooo`009?ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0jOooool001[ooooo1?l0
00000ol@413oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`3Yooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`3Zooooo`007?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0?Oooool00ol0
003oooooooooo`3[ooooo`007?ooool00ol0003oooooooooo`05ooooo`?o00005?ooool00ol0003o
ooooooooo`0looooo`03o`000?oooooooooo0>_ooooo000Looooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo0>cooooo
000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo0>gooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo0>gooooo000Joooo
o`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo0>kooooo000Tooooo`?o00005oooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo0>oooooo000Tooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`3_ooooo`009?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool0l?ooool002Cooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo0?3ooooo000Tooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`3aooooo`009?ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0l_ooool002Cooooo
0ol0000Jooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0l_ooool002Cooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo0??ooooo000T
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`3d
ooooo`009?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0mOooool002Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo0?Kooooo000Tooooo`?o00007Oooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo0?Oooooo000Tooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`3hooooo`009?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0nOooool002Cooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo0?[ooooo000Tooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`3kooooo`009?ooool3o`00027ooooo
0_l0000Oooooo`03o`000?oooooooooo0?cooooo000Tooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`3mooooo`009?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0o_ooool000[ooooo1?l000000ol@
413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0?oooooo000<oooo
o`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo0Oooool000co
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`3oooooo`;ooooo000<ooooo`03o`00
0?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`0002Sooooo0ol0000?ooooo`?o0000
ooooool5ooooo`003?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`0[ooooo`;o00002oooool2o`000?oooooo2?ooool000cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02gooooo1?l0
0003ooooo`Co0000ooooool:ooooo`003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0<?ooool4o`000?oooooo3_ooool000[ooooo00?oEEEEofIV
I_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool3o`000?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo002jooooo`05ob4Q8Ol0003o0000odA4A?oMgMd05oooool01OlQ8B7o0000o`00
0?m4A4CogMgM08gooooo002mooooo`03ogMgMolb<S;ooooo01Wooooo00?oMgMgoc8b<_ooool0??oo
ool00ol0003o^[Zjooooo`1=ooooo`00__ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo03_ooooo0_lb<S9>ooooo`00AOooool01on7QhOo8B4QooooooooooooA4A4ogMgMoooool00ol0
0002ooooo`03ojVYZOl0003ooooo00Go000000?o<S8bonk^k_ooool01oooool01_nHV9So0000o`00
0?mgMgOo410@o`0000;ooooo00Co410@o`000?l0003ooooo0_l000001?l@413oooooonk^k_mEEED2
o`000003oiRHV?l0003o410@00Oooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT2ooooo`04oa0@
4?l0003o0000ooooo`;o000000Co410@ooooooo^k^koEEEE0_l000001_mEEEGok^k^oooooooooooo
k^k^oeEEE@;o000000?oEEEEonk^k_ooool00_ooool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo
1Ol00002ooooo`04oa0@4?l0003o0000ooooo`;o000000So410@ooooooo^k^koEEEEo`000?l@413o
c<c<o`0000Kooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X3ooooo`Go00000_ooool01_o^k^ko
EEEEo`000?l@413oc<c<o`0000;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X2ooooo`04oa0@
4?l0003o0000ooooo`;o000000?o410@o`000?l000000_ooool01ol0003oooooooooool0003o410@
onk^k_mEEED00_l000001_mEEEGok^k^ooooooooooook^k^oeEEE@;o000000KoV9RHo`000?l@413o
ooooonk^k_mEEED2o`000006odA4A?nj^[[oooooooooool@413o<S8b0_l000000ol@413oZJVYoooo
o`04ooooo`03ohN7Qol0003o^[Zj00_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooo
ooooo`06ooooo`Go0000;_ooool004Gooooo00KoIVIVo`000?o^k^koooooo`000?mgMgL2ooooo`06
o`000?ooooooooooooooool@413o^[Zj0_ooool01_l0003oooooooooooo^k^koQhN7oc8b<PSooooo
00Go0000olc<c?o^k^koQhN7o`000004ooooo`05o`000?ooooooooooooooool000000_ooool01_mE
EEGoMgMgooooooo^k^koEEEEo`0000Sooooo00Ko0000ojVYZOoooooooooookZj^_l00003ooooo`05
o`000?ooooooooooooooool000000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@;ooooo00Ko
EEEEogMgMoooooooooooogMgMomEEED3ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001Oooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01_mEEEGoMgMgooooooo^
k^koEEEEo`0000Kooooo00KoEEEEogMgMoooooook^k^ogMgMol@4105ooooo`03o`000?oooooooooo
00;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo
410@0oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003ooooooeEEEOmgMgL2ooooo`0:ogMgMomEEEGooooooooooomEEEGoMgMgooooooo^k^koEEEE
o`0000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06o`000?nYZJWooooooooooonj
^[[o00001Oooool00oo<c<co0000oa0@400<ooooo`05o`000?ooooooooooooooool000000_ooool6
o`000006oooooonHV9So8B4Qonk^k_ooooooA4A4;_ooool004Gooooo0_lb<S801?nHV9SoZJVYoa0@
4?lb<S82ooooo`05o`000?oooooooooooiRHV?m4A4@00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Kooooo00Go410@ohN7Qoooooook^k^o`000004ooooo`05o`000?oooooooooo
ooooool000000_ooool01_l0003oooooooooooooooook^k^o`0000Wooooo00Go^[ZjohN7QomVIVKo
IVIVoa0@4003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?ooooooooooooooooo^
k^ko00001_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooo
ooooooooooooonk^k_l00002ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000001?ooool01?l0003o
ooooooooool00003ooooo`05onk^k_l0003oooooooooool000002?ooool01Onj^[[oQhN7ofIVI_mV
IVKo410@01Cooooo00Go0000ooooooooooooooooo`00000:ooooo`03oiRHV?lQ8B7ok^k^02oooooo
0015ooooo`06oa0@4?nYZJWoEEEEoeEEEOnYZJWo410@0_ooool01Ol0003oEEEEokZj^_l@413ogMgM
00?ooooo00Ko0000ooooooooooook^k^ohN7Qolb<S88ooooo`03okZj^_l@413o000000;o00001?oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000ooooooooooooooooonk^k_l00008oooo
o`06oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^0oooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`05o`000?oooooooooooooo
ool000002Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool0
1_l0003oooooooooooooooook^k^o`0000Kooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo
00Ko0000ooooooooooooooooonk^k_l00002ooooo`Ko00000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000004ooooo`04o`000?oo
ooooooooo`0000?ooooo00Cok^k^o`000?oooooooooo1_l00002ooooo`06oc8b<_lQ8B7oMgMgogMg
Mon7QhOok^k^5?ooool01Ol0003ooooooooooooooooo000000;ooooo1_l00003ooooo`03oiRHV?lQ
8B7ok^k^02kooooo0015ooooo`06o`000?oooooo8B4Qoa0@4?oooooo00000_ooool01?l0003oV9RH
o`000?nj^[X4ooooo`Co000000?oEEEEonk^k_ooool02_ooool00oo<c<co0000ooooo`03ooooo`05
o`000?n7QhOoooooojVYZOl000000_ooool01_mVIVKoMgMgooooooo^k^koEEEEo`0000Sooooo00Ko
0000okZj^_ooooook^k^ogMgMol00003ooooo`05o`000?mgMgOoooooojVYZOl000000_ooool01_mE
EEGoMgMgooooooooooooMgMgoeEEE@;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED3ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool01Ol0003oQhN7oooooonYZJWo0000
00;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00006ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo
<S8b1Oooool00ol0003oooooooooo`02ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00000_ooool0
1_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00Go0000ohN7QoooooooZJVYo`000002ooooo`0:
o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8OooooooEEEEogMgM`;ooooo00[oMgMgoeEEEOoooooo
ooooofIVI_mgMgOoooooonk^k_mEEEGo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;o
oooo00Ko0000okZj^_ooooook^k^ogMgMol0000Dooooo`05o`000?n7QhOoooooojVYZOl000003?oo
ool00omgMgOoIVIVooooo`0]ooooo`00A?ooool00oo<c<co8B4Qooooo`02oeEEE@08oooooolb<S;o
^[Zjooooool0003oooooojVYZOmVIVH4ooooo`05o`000?oooooooooookZj^_l@41002_ooool01?lb
<S;o0000o`000?nHV9P3ooooo`03oa0@4?l0003oMgMg00;o000000WoV9RHooooooooooook^k^oeEE
EOl0003o410@olc<c?l000002?ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000?ooooo00Go0000
ogMgMol0003o0000oiRHV002ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^0_ooool02?o^k^ko
EEEEo`000?l0003oEEEEonk^k_oooooo410@1Ol00004ooooo`03oa0@4?l0003o000000Cooooo00?o
410@o`000?mgMgL00_l000002_nHV9Soooooooooooo^k^koEEEEo`000?lQ8B7oZJVYo`000?l@4105
ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0oooool00ol@413o0000o`000004ooooo`0:onk^
k_mEEEGo0000ob4Q8OnYZJWo0000oa0@4?ooooook^k^oeEEE@;o000000OoA4A4onk^k_oooooooooo
oa0@4?l0003oMgMg00;o000000goV9RHooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVY
ooooooo^k^koEEEE00;o000000[oEEEEonk^k_ooooooooooonk^k_mEEEGo0000oa0@4?o<c<co0000
0_ooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l0
000Cooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool02oooool00ol0003ooooooooo
o`0/ooooo`00A?ooool00onYZJWo<S8booooo`03ooooo`04odA4A?nHV9Soooooo`0000;ooooo00?o
ZJVYoeEEEOo^k^h00_ooool01Ol0003ooooooooooonj^[[o000001kooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0
<?ooool01Ol0003o^[ZjoooooonHV9So410@02kooooo0014ooooo`?o00000_ooool6o`000005oooo
ool0003o0000o`000?ooool01?l000000ol@413oZJVYooooo`0Mooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0`ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0;_ooool007Oooooo0_l0000@ooooo`03oa0@4?l0003ooooo023ooooo00?o410@oooooooo
ool08Oooool00ol@413oooooooooo`0^ooooo`;o0000IOooool00?ooooooJOooool00?ooooooJOoo
ool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.23606, -2.13488, \
0.00802016, 0.0233497}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.282148 0.150351 [
[.2619 .26965 -9 -9 ]
[.2619 .26965 9 0 ]
[.5 .26965 -3 -9 ]
[.5 .26965 3 0 ]
[.7381 .26965 -9 -9 ]
[.7381 .26965 9 0 ]
[.97619 .26965 -3 -9 ]
[.97619 .26965 3 0 ]
[.01131 .1318 -12 -4.5 ]
[.01131 .1318 0 4.5 ]
[.01131 .4325 -6 -4.5 ]
[.01131 .4325 0 4.5 ]
[.01131 .58285 -6 -4.5 ]
[.01131 .58285 0 4.5 ]
[.5 .63053 -101 0 ]
[.5 .63053 101 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .28215 m
.2619 .2884 L
s
[(0.5)] .2619 .26965 0 1 Mshowa
.5 .28215 m
.5 .2884 L
s
[(1)] .5 .26965 0 1 Mshowa
.7381 .28215 m
.7381 .2884 L
s
[(1.5)] .7381 .26965 0 1 Mshowa
.97619 .28215 m
.97619 .2884 L
s
[(2)] .97619 .26965 0 1 Mshowa
.125 Mabswid
.07143 .28215 m
.07143 .2859 L
s
.11905 .28215 m
.11905 .2859 L
s
.16667 .28215 m
.16667 .2859 L
s
.21429 .28215 m
.21429 .2859 L
s
.30952 .28215 m
.30952 .2859 L
s
.35714 .28215 m
.35714 .2859 L
s
.40476 .28215 m
.40476 .2859 L
s
.45238 .28215 m
.45238 .2859 L
s
.54762 .28215 m
.54762 .2859 L
s
.59524 .28215 m
.59524 .2859 L
s
.64286 .28215 m
.64286 .2859 L
s
.69048 .28215 m
.69048 .2859 L
s
.78571 .28215 m
.78571 .2859 L
s
.83333 .28215 m
.83333 .2859 L
s
.88095 .28215 m
.88095 .2859 L
s
.92857 .28215 m
.92857 .2859 L
s
.25 Mabswid
0 .28215 m
1 .28215 L
s
.02381 .1318 m
.03006 .1318 L
s
[(-1)] .01131 .1318 1 0 Mshowa
.02381 .4325 m
.03006 .4325 L
s
[(1)] .01131 .4325 1 0 Mshowa
.02381 .58285 m
.03006 .58285 L
s
[(2)] .01131 .58285 1 0 Mshowa
.125 Mabswid
.02381 .16187 m
.02756 .16187 L
s
.02381 .19194 m
.02756 .19194 L
s
.02381 .22201 m
.02756 .22201 L
s
.02381 .25208 m
.02756 .25208 L
s
.02381 .31222 m
.02756 .31222 L
s
.02381 .34229 m
.02756 .34229 L
s
.02381 .37236 m
.02756 .37236 L
s
.02381 .40243 m
.02756 .40243 L
s
.02381 .46257 m
.02756 .46257 L
s
.02381 .49264 m
.02756 .49264 L
s
.02381 .52271 m
.02756 .52271 L
s
.02381 .55278 m
.02756 .55278 L
s
.02381 .10173 m
.02756 .10173 L
s
.02381 .07166 m
.02756 .07166 L
s
.02381 .04159 m
.02756 .04159 L
s
.02381 .01152 m
.02756 .01152 L
s
.02381 .61292 m
.02756 .61292 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -162 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(WKB) show
87.000 13.000 moveto
(and) show
111.000 13.000 moveto
(shooting) show
165.000 13.000 moveto
(eigenmodes) show
231.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
243.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
249.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
255.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
261.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .28215 m
.04262 .34962 L
.06244 .41301 L
.08255 .46283 L
.08806 .47334 L
.09396 .48296 L
.09948 .49041 L
.10458 .49593 L
.10954 .50002 L
.11204 .50161 L
.1148 .50299 L
.11621 .50355 L
.11755 .50399 L
.1191 .50438 L
.11979 .50451 L
.12052 .50463 L
.12122 .50472 L
.12185 .50478 L
.12309 .50483 L
.12378 .50483 L
.12453 .5048 L
.12523 .50475 L
.12589 .50468 L
.12705 .5045 L
.1283 .50424 L
.13055 .50357 L
.13323 .50246 L
.13568 .50115 L
.14099 .49734 L
.14603 .49256 L
.15568 .48036 L
.16593 .46336 L
.18435 .42395 L
.22211 .31943 L
.26231 .19888 L
.301 .10019 L
.32104 .06197 L
.33124 .04662 L
.34214 .03348 L
.34746 .02831 L
.35248 .0242 L
.35737 .0209 L
.36188 .01849 L
.36616 .01675 L
.36832 .01607 L
.37069 .01549 L
.37191 .01525 L
.37307 .01507 L
.37371 .01498 L
.37441 .0149 L
Mistroke
.37563 .0148 L
.37679 .01474 L
.37802 .01472 L
.37919 .01473 L
.38024 .01479 L
.38145 .01488 L
.38258 .01501 L
.38381 .01519 L
.38513 .01544 L
.38784 .01608 L
.39029 .01685 L
.39504 .0188 L
.39953 .0212 L
.40952 .02845 L
.42036 .03917 L
.44018 .06575 L
.4612 .1025 L
.499 .18495 L
.53926 .28499 L
.578 .38123 L
.61919 .47225 L
.63975 .51047 L
.65886 .54066 L
.67851 .56581 L
.69702 .58375 L
.70687 .59094 L
.71205 .59407 L
.71752 .59688 L
.72214 .59885 L
.72721 .6006 L
.73181 .60181 L
.7339 .60224 L
.73612 .60262 L
.73735 .6028 L
.73872 .60296 L
.73997 .60309 L
.74112 .60318 L
.74176 .60322 L
.74247 .60325 L
.74317 .60328 L
.74392 .6033 L
.74458 .60331 L
.74529 .60332 L
.74656 .6033 L
.74783 .60326 L
.74855 .60323 L
.74922 .60319 L
.75044 .6031 L
.75174 .60297 L
.75398 .60269 L
Mistroke
.75645 .60229 L
.76107 .60128 L
.76603 .5998 L
.775 .59616 L
.78511 .59056 L
.79615 .58272 L
.81624 .56406 L
.85691 .51094 L
.89606 .44438 L
.93766 .3627 L
.97619 .28215 L
Mfstroke
.02381 .28215 m
.04262 .34962 L
.06244 .41301 L
.08255 .46283 L
.08806 .47334 L
.09396 .48296 L
.09948 .49041 L
.10458 .49593 L
.10954 .50002 L
.11204 .50161 L
.1148 .50299 L
.11621 .50355 L
.11755 .50399 L
.1191 .50438 L
.11979 .50451 L
.12052 .50463 L
.12122 .50472 L
.12185 .50478 L
.12309 .50483 L
.12378 .50483 L
.12453 .5048 L
.12523 .50475 L
.12589 .50468 L
.12705 .5045 L
.1283 .50424 L
.13055 .50357 L
.13323 .50246 L
.13568 .50115 L
.14099 .49734 L
.14603 .49256 L
.15568 .48036 L
.16593 .46336 L
.18435 .42395 L
.22211 .31943 L
.26231 .19888 L
.301 .10019 L
.32104 .06197 L
.33124 .04662 L
.34214 .03348 L
.34746 .02831 L
.35248 .0242 L
.35737 .0209 L
.36188 .01849 L
.36616 .01675 L
.36832 .01607 L
.37069 .01549 L
.37191 .01525 L
.37307 .01507 L
.37371 .01498 L
.37441 .0149 L
Mistroke
.37563 .0148 L
.37679 .01474 L
.37802 .01472 L
.37919 .01473 L
.38024 .01479 L
.38145 .01488 L
.38258 .01501 L
.38381 .01519 L
.38513 .01544 L
.38784 .01608 L
.39029 .01685 L
.39504 .0188 L
.39953 .0212 L
.40952 .02845 L
.42036 .03917 L
.44018 .06574 L
.4612 .1025 L
.499 .18495 L
.53926 .28499 L
.578 .38123 L
.61919 .47225 L
.63975 .51047 L
.65886 .54066 L
.67851 .56581 L
.69702 .58375 L
.70687 .59094 L
.71205 .59407 L
.71752 .59688 L
.72214 .59885 L
.72721 .6006 L
.73181 .60181 L
.7339 .60224 L
.73612 .60262 L
.73735 .6028 L
.73872 .60296 L
.73997 .60309 L
.74112 .60318 L
.74176 .60322 L
.74247 .60325 L
.74317 .60328 L
.74392 .6033 L
.74458 .60332 L
.74529 .60332 L
.74656 .60331 L
.74783 .60326 L
.74855 .60323 L
.74922 .60319 L
.75044 .6031 L
.75174 .60297 L
.75398 .60269 L
Mistroke
.75645 .60229 L
.76107 .60128 L
.76603 .5998 L
.775 .59616 L
.78511 .59056 L
.79615 .58272 L
.81624 .56406 L
.85691 .51094 L
.89606 .44438 L
.93766 .3627 L
.97619 .28215 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.482681,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o7Oooool0
0ol0003oooooooooo`3oooooodWooooo000Mooooo`03o`000?oooooooooo0?ooooooBOooool001go
oooo00?o0000ooooooooool0oooooom9ooooo`007Oooool00ol0003oooooooooo`3oooooodWooooo
000Mooooo`;o0000oooooom:ooooo`007Oooool00ol0003oooooooooo`1^ooooo`Oo0000doooool0
01gooooo00?o0000ooooooooool0Joooool3o`0000Oooooo0ol0003@ooooo`007Oooool00ol0003o
ooooooooo`1Yooooo`;o00003Oooool2o`000<kooooo000Mooooo`03o`000?oooooooooo06Sooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`3;ooooo`007Oooool00ol0003ooooooooo
o`1Wooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0b_ooool001gooooo00?o0000
ooooooooool0I_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0<Wooooo000Moooo
o`03o`000?oooooooooo06Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`38oooo
o`007Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0aoooool001gooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo0<Kooooo000Mooooo`;o0000Hoooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo0<Kooooo000Mooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`35ooooo`007Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0a?ooool001gooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo0<Cooooo000Mooooo`03o`000?oooooooooo05oooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`33ooooo`007Oooool00ol0003ooooooooo
o`1Oooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0`_ooool001gooooo00?o0000
ooooooooool0G_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo0<;ooooo000Moooo
o`03o`000?oooooooooo05kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`31oooo
o`007Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0`?ooool001gooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo0<3ooooo000Mooooo`;o0000GOooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo0;oooooo000Mooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`2oooooo`007Oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0__ooool001gooooo00?o0000ooooooooool0Foooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo0;gooooo000Mooooo`03o`000?oooooooooo05_ooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2mooooo`007Oooool00ol0003ooooooooo
o`1Jooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0_?ooool001gooooo00?o0000
ooooooooool0F_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo0;cooooo000Moooo
o`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`2koooo
o`007Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool0^_ooool001gooooo0_l0001Iooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
^_ooool001gooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo0;Wooooo000Mooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`2iooooo`007Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0^?ooool001gooooo00?o0000ooooooooool0Eoooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo0;Sooooo000Mooooo`03o`000?oooooooooo05Kooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2gooooo`007Oooool00ol0003ooooooooo
o`1Fooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0]oooool001gooooo00?o0000
ooooooooool0EOooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo0;Oooooo000Coooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0]_ooool001Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1Eooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0]_ooool000[ooooo
1_l00005ooooo`03o`000?oooooooooo00Gooooo0ol0001Dooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool0]Oooool001Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Dooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0]Oooool001Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0]?ooool001Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Coooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0]?ooool001Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool0/oooool001?ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`1Booooo`03o`00
0?oooooooooo03gooooo00?o0000ooooooooool0/oooool001gooooo00?o0000ooooooooool0D_oo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo0;?ooooo000Mooooo`03o`000?oooooo
oooo057ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`2booooo`007Oooool00ol0
003oooooooooo`1Aooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0/_ooool001go
oooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo0;7o
oooo000Mooooo`;o0000DOooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo0;7ooooo
000Mooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0@_ooool00ol0003ooooooooo
o`2`ooooo`007Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool0/?ooool001gooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`14oooo
o`03o`000?oooooooooo0:oooooo000Mooooo`03o`000?oooooooooo04kooooo00?o0000oooooooo
ool0AOooool00ol0003oooooooooo`2_ooooo`007Oooool00ol0003oooooooooo`1>ooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool0[oooool001gooooo00?o0000ooooooooool0C_oo
ool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo0:kooooo000Mooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`2^ooooo`007Oooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0[Oooool001go
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo0:go
oooo000Mooooo`;o0000COooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo0:cooooo
000Mooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`2/ooooo`007Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo04cooooo00?o0000
ooooooooool0Zoooool001gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`1<oooo
o`03o`000?oooooooooo0:_ooooo000Mooooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool0C?ooool00ol0003oooooooooo`2[ooooo`007Oooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo04kooooo00?o0000ooooooooool0Z_ooool001gooooo00?o0000ooooooooool0B_oo
ool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo0:[ooooo000Mooooo`03o`000?oooooo
oooo04[ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`2Yooooo`007Oooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0ZOooool001go
oooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo0:So
oooo000Mooooo`;o0000B_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo0:Sooooo
000Mooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`2Xooooo`007Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo05?ooooo00?o0000
ooooooooool0Yoooool001gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1Coooo
o`03o`000?oooooooooo0:Oooooo000Mooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool0EOooool00ol0003oooooooooo`2Vooooo`007Oooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo05Gooooo00?o0000ooooooooool0Y_ooool001gooooo00?o0000ooooooooool0@?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool00_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd0@Oooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000oooooooo
ool0>_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd0@?ooool5o`00017ooooo000Mooooo`03o`000?oooooooooo043ooooo00OoMgMgoiRHV?oo
ooooV9RHogMgMooooooo000000?ooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo04;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Cooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo03oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Aooooo`007Oooool0
0ol0003oooooooooo`10ooooo`07oa0@4?ooooooooooooooool@413oooooo`00000>ooooo`03o`00
0?oooooooooo047ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0?oooool00onHV9So8B4Qonk^kP0Booooo`007Ooo
ool00ol0003oooooooooo`10ooooo`07o`000?ooooooooooooooool0003oooooo`00000=ooooo`03
ogMgMolb<S;ooooo04;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0@Oooool00onHV9So8B4Qonk^kP0Aooooo`00
7Oooool2o`00047ooooo00Co0000oooooooooooooooo0_l0000;ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`0@oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<04?ooooo00?oMgMgofIVI_ooool04?ooool0
01gooooo00?o0000ooooooooool0@?ooool01_l@413ooooooooooooooooo410@o`0000_ooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00oooooo000M
ooooo`03o`000?oooooooooo043ooooo00KoMgMgoiRHV?ooooooV9RHogMgMol0000;ooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0@_ooool01Ol0003o^[ZjoooooonHV9So410@017o
oooo000Mooooo`03o`000?oooooooooo043ooooo00Gok^k^oc8b<_l0003o<S8bo`00000<ooooo`Co
0000@_ooool00omEEEGoIVIVo`000009ooooo`03o`000?oooooooooo03Oooooo00?oEEEEofIVI_l0
00003Oooool4o`00047ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`007Oooool00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0X_ooool001gooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo0:7ooooo
000Mooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0G_ooool00ol0003ooooooooo
o`2Qooooo`007Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo05kooooo00?o0000
ooooooooool0XOooool001gooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`1Ooooo
o`03o`000?oooooooooo0:3ooooo000Eoooooooo0000BOl0000;ooooo`007Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0003ooooo
o`00000?ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0@ooooo`007Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02_ooool00ol0003oooooo`00000?ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool2o`0001;ooooo000Mooooo`;o0000@_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo04[ooooo0_l0000Booooo`007Oooool2o`0004;ooooo00?o0000oooo
ooooool0Hoooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo01;ooooo000Mooooo`;o
0000@_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo08Wooooo00?o0000oooooooo
ool04_ooool001gooooo0_l00011ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0
Qoooool00ol0003oooooooooo`0Cooooo`007Oooool00ol0003oooooo`000010ooooo`03o`000?oo
oooooooo06Gooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0Cooooo`007Oooool0
0ol0003oooooo`000010ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0Q_ooool0
0ol0003oooooooooo`0Dooooo`007Oooool00ol0003oooooo`00000oooooo`03o`000?oooooooooo
06Oooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Dooooo`007Oooool3o`0003oo
oooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo01Go
oooo000Mooooo`04o`000?ooooooooooo`0003kooooo00?o0000ooooooooool0J?ooool00ol0003o
ooooooooo`23ooooo`03o`000?oooooooooo01Gooooo000Mooooo`04o`000?ooooooooooo`0003go
oooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo01Ko
oooo000Mooooo`04o`000?ooooooooooo`0003gooooo00?o0000ooooooooool0JOooool00ol0003o
ooooooooo`22ooooo`03o`000?oooooooooo01Kooooo000Mooooo`05o`000?ooooooooooooooool0
0000??ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo083ooooo00?o0000oooooooo
ool05oooool001gooooo00Go0000ooooooooooooooooo`00000kooooo`03o`000?oooooooooo06_o
oooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0Gooooo`007Oooool01Ol0003ooooo
oooooooooooo000003_ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`20ooooo`03
o`000?oooooooooo01Oooooo000Mooooo`05o`000?ooooooooooooooool00000>oooool00ol0003o
ooooooooo`1/ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool06?ooool001gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Hooooo`007Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0K_ooool00ol0003ooooooooo
o`1looooo`03o`000?oooooooooo01Wooooo000Mooooo`;o00000oooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`0I
ooooo`007Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0Koooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo01[ooooo000Mooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1`ooooo`03
o`000?oooooooooo07[ooooo00?o0000ooooooooool06_ooool001gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0
NOooool00ol0003oooooooooo`0Kooooo`007Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1iooooo`03o`000?oo
oooooooo01_ooooo000Mooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool07?ooool0
01gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
07?ooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`0Looooo`007Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0M?ooool00ol0003o
ooooooooo`1eooooo`03o`000?oooooooooo01gooooo000Mooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo07Gooooo
00?o0000ooooooooool07Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0M?ooool00ol0003ooooooooo
o`0Nooooo`007Oooool2o`0000Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1f
ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool07_ooool001gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo07Oooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`0Oooooo`007Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo01oooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0
8?ooool001gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo07Wooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Pooooo`007Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0N_ooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Mooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool08Oooool001gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0K?ooool00ol0003o
ooooooooo`0Rooooo`007Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool0O?ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo02;ooooo
000Mooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`1nooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool08oooool001gooooo0_l00009
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`1Z
ooooo`03o`000?oooooooooo02?ooooo000Mooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo06Sooooo00?o0000oooo
ooooool09?ooool001gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo083ooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Uooooo`00
7Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
P?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02Gooooo000Mooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`22ooooo`03o`000?oo
oooooooo06Gooooo00?o0000ooooooooool09_ooool001gooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`0Vooooo`007Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo
02Oooooo000Cooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo02Oooooo000Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0
HOooool00ol0003oooooooooo`0Xooooo`005Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo067ooooo00?o0000ooooooooool0:?ooool001Gooooo00?o0000ooooooooool01Oooool3
o`0000cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooo
oooo05oooooo00?o0000ooooooooool0:Oooool001Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0R?ooool00ol0
003oooooooooo`1Oooooo`03o`000?oooooooooo02Wooooo000Eooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo08Wo
oooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0Zooooo`005Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`2:ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0:_ooool001?ooooo00?o
EEEEofIVI_l000001oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool0Roooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo02_ooooo000M
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`2;
ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0:oooool001gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo08gooooo00?o0000oooo
ooooool0FOooool00ol0003oooooooooo`0/ooooo`007Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`1Hooooo`03
o`000?oooooooooo02gooooo000Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0
;Oooool001gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo08oooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0^ooooo`007Oooool2
o`00017ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`2@ooooo`03o`000?oooooo
oooo05Kooooo00?o0000ooooooooool0;_ooool001gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool0E?ooool00ol0
003oooooooooo`0_ooooo`007Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0T_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo033o
oooo000Mooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`2Dooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0<?ooool001gooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo09Cooooo00?o
0000ooooooooool0DOooool00ol0003oooooooooo`0aooooo`007Oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`1?
ooooo`03o`000?oooooooooo03;ooooo000Mooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`2Fooooo`03o`000?oooooooooo04oooooo00?o0000oooo
ooooool0<_ooool001gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo09Sooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0cooooo`00
7Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
VOooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo03?ooooo000Mooooo`;o00005ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`0dooooo`007Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo03Gooooo000Mooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01oooool2o`00
0:3ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0eooooo`007Oooool00ol0003o
ooooooooo`0Iooooo`;o00001_ooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo04So
oooo00?o0000ooooooooool0=_ooool001gooooo00?o0000ooooooooool06oooool7o`000:?ooooo
00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0fooooo`007Oooool00ol0003ooooooooo
o`35ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0=oooool001gooooo00?o0000
ooooooooool0a_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo03Sooooo000Moooo
o`03o`000?oooooooooo0<Kooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0hoooo
o`007Oooool00ol0003oooooooooo`37ooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool0>Oooool001gooooo00?o0000ooooooooool0b?ooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo03[ooooo000Mooooo`;o0000bOooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo03_ooooo000Mooooo`03o`000?oooooooooo0<Wooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0kooooo`007Oooool00ol0003oooooooooo`3:ooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool0??ooool001gooooo00?o0000ooooooooool0boooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo03gooooo000Mooooo`03o`000?oooooooooo0<_ooooo
00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0mooooo`007Oooool00ol0003ooooooooo
o`3<ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0?_ooool001gooooo00?o0000
ooooooooool0cOooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03oooooo000Moooo
o`03o`000?oooooooooo0<gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`10oooo
o`007Oooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0@?ooool001gooooo00?o0000ooooooooool0coooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo047ooooo000Mooooo`;o0000dOooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo04;ooooo000Mooooo`03o`000?oooooooooo0=3ooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`12ooooo`007Oooool00ol0003oooooooooo`3Aooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0@oooool001gooooo00?o0000ooooooooool0d_ooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo04Cooooo000Mooooo`03o`000?oooooooooo0=?ooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`15ooooo`007Oooool00ol0003ooooooooo
o`3Dooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0A_ooool001gooooo00?o0000
ooooooooool0eOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04Oooooo000Boooo
o`Go00001_ooool00ol0003oooooooooo`3Fooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0B?ooool001;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo
0=Oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`19ooooo`004oooool00onHV9So
8B4Qonk^kP07ooooo`03o`000?oooooooooo0=Sooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`1:ooooo`005?ooool00onHV9So8B4Qonk^kP06ooooo`?o0000fOooool00ol0003ooooo
ooooo`0Mooooo`;o0000COooool001Gooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3Jooooo`03o`000?oooooooooo01[ooooo0_l0001?ooooo`005_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0=_ooooo00?o0000ooooooooool05oooool2o`00057ooooo000Boooo
o`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3Looooo`;o00005_ooool0
0ol0003oooooooooo`1Aooooo`004_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000
ooooooooool0g_ooool3o`00017ooooo0_l0001Dooooo`007Oooool00ol0003oooooooooo`3Qoooo
o`;o00003?ooool3o`0005Kooooo000Mooooo`03o`000?oooooooooo0>?ooooo1Ol00003ooooo`Co
0000FOooool001gooooo00?o0000ooooooooool0ioooool5o`0005cooooo000Mooooo`03o`000?oo
oooooooo0?ooooooBOooool001gooooo00?o0000ooooooooool0oooooom9ooooo`007Oooool2o`00
0?ooooooB_ooool001gooooo00?o0000ooooooooool0oooooom9ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00/oooool01OlQ8B7o0000
o`000?m4A4CogMgM01Kooooo00Go8B4Qo`000?l0003oA4A4omgMg@2Eooooo`00]_ooool00omgMgOo
<S8booooo`0Hooooo`03ogMgMolb<S;ooooo03gooooo00?o0000okZj^_ooool0E?ooool00;Oooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0looooo`;o<S8bEOooool003kooooo00Oo
QhN7ob4Q8OooooooooooodA4A?mgMgOooooo00?o00000_ooool00onYZJWo0000ooooo`05o`000003
oc8b<_o^k^kooooo00Oooooo00KoV9RHo`000?l0003oMgMgoa0@4?l00002ooooo`04oa0@4?l0003o
0000ooooo`;o000000Co410@ooooooo^k^koEEEE0_l000000onHV9So0000oa0@4007ooooo`06oa0@
4?lb<S;o0000o`000?l@413oZJVY0_ooool01?l@413o0000o`000?ooool2o`000004oa0@4?oooooo
k^k^oeEEE@;o000000KoEEEEonk^k_ooooooooooonk^k_mEEED2o`000003oeEEEOo^k^kooooo00;o
oooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`Go00000_ooool01?l@413o0000o`000?ooool2
o`000008oa0@4?ooooook^k^oeEEEOl0003o410@olc<c?l00005ooooo`06onk^k_mEEEGo0000o`00
0?m4A4Co^[Zj0oooool5o`0000;ooooo00Kok^k^oeEEEOl0003o410@olc<c?l00002ooooo`06onk^
k_mEEEGo0000o`000?m4A4Co^[Zj0_ooool01?l@413o0000o`000?ooool2o`000003oa0@4?l0003o
000000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE00;o000000KoEEEEonk^k_oooooo
ooooonk^k_mEEED2o`000006oiRHV?l0003o410@ooooooo^k^koEEEE0_l000001_m4A4Co^[Zjoooo
oooooooo410@oc8b<P;o000000?o410@ojVYZOooool01Oooool00on7QhOo0000okZj^P0;ooooo`04
oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool01_ooool01OnHV9So410@o`000?lb<S;o
c<c<03Gooooo000nooooo`06ofIVI_l0003ok^k^ooooool0003oMgMg0_ooool01_l0003ooooooooo
oooooooo410@okZj^P;ooooo00Ko0000ooooooooooook^k^ohN7Qolb<S88ooooo`05o`000?o<c<co
k^k^ohN7Qol000001?ooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMooooooo
k^k^oeEEEOl00008ooooo`06o`000?nYZJWooooooooooonj^[[o00000oooool01Ol0003ooooooooo
oooooooo000000;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED2ooooo`06oeEEEOmgMgOooooo
oooooomgMgOoEEEE0oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Gooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00005
ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@1Oooool00ol0003oooooooooo`02ooooo`06oeEE
EOmgMgOoooooonk^k_mEEEGo00000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooomE
EEGoMgMg0_ooool02_mgMgOoEEEEooooooooooooEEEEogMgMoooooook^k^oeEEEOl00002ooooo`06
oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool01_l0003oZJVYoooooooooooo^[Zjo`0000Kooooo
00?oc<c<o`000?l@41003?ooool01_l0003ooooooooooooooooo0000ooooo`Ko00000_ooool01Ol@
413o^[ZjoooooomgMgOo<S8b03Gooooo000nooooo`;o<S8b00CoV9RHojVYZOl@413o<S8b0_ooool0
1Ol0003ooooooooooonHV9SoA4A400?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`06ooooo`05oa0@4?n7QhOoooooonk^k_l000001?ooool01Ol0003ooooooooooooooooo000000;o
oooo00Ko0000ooooooooooooooooonk^k_l00009ooooo`05okZj^_n7QhOoIVIVofIVI_l@41000ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00004ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool000000_ooool01_l0003oooooooooooooooook^k^o`0000Gooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooooooooo^
k^ko00000_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooo000000Cooooo00Co0000oooooooooooo0000
0oooool01Oo^k^ko0000oooooooooooo000000Sooooo00Go^[ZjohN7QomVIVKoIVIVoa0@400Eoooo
o`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`0cooooo`00?_ooool01_l@
413oZJVYoeEEEOmEEEGoZJVYoa0@40;ooooo00Go0000oeEEEOnj^[[o410@omgMg@03ooooo`06o`00
0?ooooooooooonk^k_n7QhOo<S8b2?ooool00onj^[[o410@o`000002o`0000Cooooo00Go0000oooo
ooooooooooooo`000002ooooo`06o`000?ooooooooooooooooo^k^ko00002?ooool01_lb<S;o8B4Q
ogMgMomgMgOoQhN7onk^kP?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Wooooo
00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooo
ooooooooonk^k_l00005ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`06o`000?oooooo
ooooooooooo^k^ko00000_ooool6o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooool000001?ooool01?l0003oooooooooool00003
ooooo`04onk^k_l0003oooooooooo`Ko00000_ooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kQGo
oooo00Ko0000ooooooooooooooooo`000?ooool6o`0000Gooooo00?oZJVYoa0@4?ooool0=?ooool0
03kooooo00Ko0000oooooolQ8B7o410@ooooool00002ooooo`04o`000?nHV9So0000okZj^PCooooo
1?l000000omEEEGok^k^ooooo`0:ooooo`03olc<c?l0003ooooo00?ooooo00Go0000ohN7Qooooooo
ZJVYo`000002ooooo`06ofIVI_mgMgOoooooonk^k_mEEEGo00002?ooool01_l0003o^[Zjooooooo^
k^koMgMgo`0000?ooooo00Go0000ogMgMoooooooZJVYo`000002ooooo`06oeEEEOmgMgOooooooooo
oomgMgOoEEEE0_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`03ooooo`05o`000?n7QhOoooooojVYZOl000000_ooool01_mEEEGo
MgMgooooooo^k^koEEEEo`0000Gooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S85ooooo`03o`00
0?oooooooooo00;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00002ooooo`06oeEEEOn7QhOok^k^
oooooon7QhOo<S8b0oooool01Ol0003oQhN7oooooonYZJWo000000;ooooo00[o0000olc<c?o<c<co
0000ojVYZOoMgMgo8B4QoooooomEEEGoMgMg0_ooool02_mgMgOoEEEEooooooooooooIVIVogMgMooo
ooook^k^oeEEEOl00002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0_ooool01_l0003o^[Zj
ooooooo^k^koMgMgo`0001Gooooo00Go0000ohN7QoooooooZJVYo`00000;ooooo`03oa0@4?l0003o
^[Zj03Gooooo000mooooo`03olc<c?lQ8B7ooooo00;oEEEE00Sooooooc8b<_nj^[[oooooo`000?oo
ooooZJVYofIVIPCooooo00Go0000oooooooooooo^[Zjoa0@400:ooooo`04oc8b<_l0003o0000oiRH
V0?ooooo00?o410@o`000?mgMgL00_l000002OnHV9Soooooooooooo^k^koEEEEo`000?l@413oc<c<
o`000008ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000oooool01Ol0003oMgMgo`000?l0003o
V9RH00;ooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h2ooooo`08onk^k_mEEEGo0000o`000?mE
EEGok^k^ooooool@4105o`0000Cooooo00?o410@o`000?l000001?ooool00ol@413o0000ogMgM`02
o`00000:oiRHV?ooooooooooonk^k_mEEEGo0000ob4Q8OnYZJWo0000oa0@40Cooooo00Kok^k^oeEE
EOl0003o0000odA4A?o^k^h3ooooo`03oa0@4?l0003o000000Cooooo00[ok^k^oeEEEOl0003o8B4Q
ojVYZOl0003o410@ooooooo^k^koEEEE0_l000001om4A4Cok^k^oooooooooooo410@o`000?mgMgL0
0_l000003OnHV9Sooooooa0@4?l0003o8B4Qo`000?mgMgOo410@o`000?nYZJWoooooonk^k_mEEED0
0_l000002_mEEEGok^k^ooooooooooook^k^oeEEEOl0003o410@olc<c?l00002ooooo`06onk^k_mE
EEGo0000o`000?m4A4Cok^k^0_ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0001Cooooo00?o410@
o`000?mgMgL00_l000000onHV9Soooooooooo`0:ooooo`03okZj^_lQ8B7ooooo03Cooooo000moooo
o`03ojVYZOlb<S;ooooo00?ooooo00CoA4A4oiRHV?oooooo00000_ooool00onYZJWoEEEEonk^kP02
ooooo`05o`000?oooooooooookZj^_l000007_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0aooooo`05oa0@4?nH
V9SooooookZj^_l00000=Oooool003gooooo0ol00002ooooo`Ko000000Goooooo`000?l0003o0000
ooooo`04o`000003oa0@4?nYZJWooooo01gooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo037ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0eooooo`00
L?ooool2o`00013ooooo00?o410@o`000?ooool08?ooool00ol@413oooooooooo`0Pooooo`03oa0@
4?oooooooooo02kooooo0_l0001]ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.187939, -1.87662, \
0.00802016, 0.0254013}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.329193 0.143993 [
[.2619 .31669 -9 -9 ]
[.2619 .31669 9 0 ]
[.5 .31669 -3 -9 ]
[.5 .31669 3 0 ]
[.7381 .31669 -9 -9 ]
[.7381 .31669 9 0 ]
[.97619 .31669 -3 -9 ]
[.97619 .31669 3 0 ]
[.01131 .04121 -12 -4.5 ]
[.01131 .04121 0 4.5 ]
[.01131 .1852 -12 -4.5 ]
[.01131 .1852 0 4.5 ]
[.01131 .47319 -6 -4.5 ]
[.01131 .47319 0 4.5 ]
[.01131 .61718 -6 -4.5 ]
[.01131 .61718 0 4.5 ]
[.5 .63053 -101 0 ]
[.5 .63053 101 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .32919 m
.2619 .33544 L
s
[(0.5)] .2619 .31669 0 1 Mshowa
.5 .32919 m
.5 .33544 L
s
[(1)] .5 .31669 0 1 Mshowa
.7381 .32919 m
.7381 .33544 L
s
[(1.5)] .7381 .31669 0 1 Mshowa
.97619 .32919 m
.97619 .33544 L
s
[(2)] .97619 .31669 0 1 Mshowa
.125 Mabswid
.07143 .32919 m
.07143 .33294 L
s
.11905 .32919 m
.11905 .33294 L
s
.16667 .32919 m
.16667 .33294 L
s
.21429 .32919 m
.21429 .33294 L
s
.30952 .32919 m
.30952 .33294 L
s
.35714 .32919 m
.35714 .33294 L
s
.40476 .32919 m
.40476 .33294 L
s
.45238 .32919 m
.45238 .33294 L
s
.54762 .32919 m
.54762 .33294 L
s
.59524 .32919 m
.59524 .33294 L
s
.64286 .32919 m
.64286 .33294 L
s
.69048 .32919 m
.69048 .33294 L
s
.78571 .32919 m
.78571 .33294 L
s
.83333 .32919 m
.83333 .33294 L
s
.88095 .32919 m
.88095 .33294 L
s
.92857 .32919 m
.92857 .33294 L
s
.25 Mabswid
0 .32919 m
1 .32919 L
s
.02381 .04121 m
.03006 .04121 L
s
[(-2)] .01131 .04121 1 0 Mshowa
.02381 .1852 m
.03006 .1852 L
s
[(-1)] .01131 .1852 1 0 Mshowa
.02381 .47319 m
.03006 .47319 L
s
[(1)] .01131 .47319 1 0 Mshowa
.02381 .61718 m
.03006 .61718 L
s
[(2)] .01131 .61718 1 0 Mshowa
.125 Mabswid
.02381 .07 m
.02756 .07 L
s
.02381 .0988 m
.02756 .0988 L
s
.02381 .1276 m
.02756 .1276 L
s
.02381 .1564 m
.02756 .1564 L
s
.02381 .214 m
.02756 .214 L
s
.02381 .2428 m
.02756 .2428 L
s
.02381 .2716 m
.02756 .2716 L
s
.02381 .30039 m
.02756 .30039 L
s
.02381 .35799 m
.02756 .35799 L
s
.02381 .38679 m
.02756 .38679 L
s
.02381 .41559 m
.02756 .41559 L
s
.02381 .44439 m
.02756 .44439 L
s
.02381 .50198 m
.02756 .50198 L
s
.02381 .53078 m
.02756 .53078 L
s
.02381 .55958 m
.02756 .55958 L
s
.02381 .58838 m
.02756 .58838 L
s
.02381 .01241 m
.02756 .01241 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -162 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(WKB) show
87.000 13.000 moveto
(and) show
111.000 13.000 moveto
(shooting) show
165.000 13.000 moveto
(eigenmodes) show
231.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
243.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
249.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
255.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
261.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .32919 m
.04262 .41412 L
.0522 .45218 L
.06244 .48646 L
.0679 .50147 L
.07286 .51297 L
.0779 .52246 L
.08255 .5292 L
.08519 .53213 L
.08798 .53455 L
.08943 .53551 L
.09079 .53624 L
.09228 .53685 L
.09311 .5371 L
.09388 .53728 L
.09453 .53739 L
.09524 .53746 L
.0965 .53747 L
.09727 .53741 L
.098 .5373 L
.09866 .53716 L
.09936 .53697 L
.10068 .53649 L
.10208 .53582 L
.10458 .53418 L
.10713 .53196 L
.10954 .52935 L
.11406 .52316 L
.12422 .50347 L
.133 .48072 L
.14255 .45092 L
.18333 .29269 L
.20359 .21549 L
.2226 .15559 L
.23145 .13355 L
.24077 .11499 L
.24565 .10727 L
.25098 .10046 L
.25584 .09576 L
.25803 .09411 L
.26035 .09268 L
.2616 .09204 L
.26298 .09146 L
.26424 .09102 L
.2654 .09071 L
.26605 .09056 L
.26676 .09044 L
.26751 .09034 L
.26823 .09028 L
.26889 .09025 L
Mistroke
.2696 .09024 L
.27087 .09031 L
.27216 .09048 L
.27289 .09062 L
.27356 .09078 L
.27477 .09113 L
.27609 .09161 L
.27838 .09268 L
.28081 .09415 L
.28545 .09791 L
.29043 .10326 L
.2994 .11622 L
.3096 .13576 L
.32068 .16212 L
.34081 .22085 L
.38164 .36186 L
.40194 .4311 L
.42096 .48933 L
.43939 .53632 L
.45876 .57327 L
.46843 .58639 L
.4739 .59218 L
.47899 .59648 L
.48368 .59952 L
.48795 .60151 L
.49031 .6023 L
.49164 .60265 L
.49287 .6029 L
.49394 .60307 L
.49512 .60321 L
.49635 .6033 L
.4975 .60332 L
.49876 .60328 L
.4994 .60324 L
.5001 .60318 L
.50134 .60302 L
.5025 .60281 L
.50512 .60215 L
.50659 .60166 L
.50794 .60114 L
.51276 .59871 L
.51783 .59519 L
.52669 .58679 L
.53638 .57443 L
.55597 .5403 L
.57691 .49235 L
.61837 .37452 L
.65832 .25212 L
.69676 .14609 L
.71622 .10175 L
Mistroke
.73765 .06251 L
.74744 .04826 L
.75798 .03568 L
.76792 .02648 L
.77702 .02037 L
.78179 .01805 L
.78441 .01704 L
.78687 .01625 L
.78918 .01566 L
.79039 .01541 L
.79167 .01519 L
.79275 .01503 L
.79393 .0149 L
.79501 .01481 L
.79602 .01475 L
.7973 .01472 L
.79803 .01472 L
.7987 .01473 L
.79994 .01478 L
.80125 .01488 L
.80242 .01501 L
.80352 .01517 L
.80602 .01563 L
.80872 .01632 L
.81118 .01711 L
.81674 .01946 L
.82149 .02209 L
.82656 .02551 L
.83568 .03323 L
.85639 .05784 L
.87775 .09252 L
.89791 .1326 L
.93639 .22382 L
.97619 .32919 L
Mfstroke
.02381 .32919 m
.04262 .41412 L
.0522 .45218 L
.06244 .48646 L
.0679 .50147 L
.07286 .51297 L
.0779 .52246 L
.08255 .5292 L
.08519 .53213 L
.08798 .53455 L
.08943 .53551 L
.09079 .53625 L
.09228 .53685 L
.09311 .5371 L
.09388 .53728 L
.09453 .53739 L
.09524 .53746 L
.0965 .53747 L
.09727 .53741 L
.098 .5373 L
.09866 .53716 L
.09936 .53697 L
.10068 .53649 L
.10208 .53582 L
.10458 .53418 L
.10713 .53196 L
.10954 .52935 L
.11406 .52316 L
.12422 .50348 L
.133 .48072 L
.14255 .45092 L
.18333 .29269 L
.20359 .21549 L
.2226 .15559 L
.23145 .13355 L
.24077 .11499 L
.24565 .10727 L
.25098 .10046 L
.25584 .09576 L
.25803 .09411 L
.26035 .09268 L
.2616 .09204 L
.26298 .09146 L
.26424 .09102 L
.2654 .09071 L
.26605 .09056 L
.26676 .09044 L
.26751 .09034 L
.26823 .09028 L
.26889 .09025 L
Mistroke
.2696 .09024 L
.27087 .09031 L
.27216 .09048 L
.27289 .09062 L
.27356 .09078 L
.27477 .09113 L
.27609 .09161 L
.27838 .09268 L
.28081 .09415 L
.28545 .09791 L
.29043 .10326 L
.2994 .11622 L
.3096 .13576 L
.32068 .16212 L
.34081 .22085 L
.38164 .36186 L
.40194 .4311 L
.42096 .48933 L
.43939 .53632 L
.45876 .57327 L
.46843 .58639 L
.4739 .59218 L
.47899 .59648 L
.48368 .59952 L
.48795 .60152 L
.49031 .6023 L
.49164 .60265 L
.49287 .6029 L
.49394 .60307 L
.49512 .60321 L
.49635 .6033 L
.4975 .60332 L
.49876 .60328 L
.4994 .60324 L
.5001 .60318 L
.50134 .60302 L
.5025 .60281 L
.50512 .60215 L
.50659 .60166 L
.50794 .60114 L
.51276 .59871 L
.51783 .59519 L
.52669 .58679 L
.53638 .57443 L
.55597 .5403 L
.57691 .49235 L
.61837 .37452 L
.65832 .25212 L
.69676 .14609 L
.71622 .10175 L
Mistroke
.73765 .06251 L
.74744 .04826 L
.75798 .03569 L
.76792 .02648 L
.77702 .02038 L
.78179 .01806 L
.78441 .01704 L
.78687 .01625 L
.78918 .01567 L
.79039 .01541 L
.79167 .01519 L
.79275 .01503 L
.79393 .0149 L
.79501 .01481 L
.79602 .01475 L
.7973 .01472 L
.79803 .01472 L
.7987 .01473 L
.79994 .01478 L
.80125 .01489 L
.80242 .01501 L
.80352 .01517 L
.80602 .01563 L
.80872 .01632 L
.81118 .01711 L
.81674 .01946 L
.82149 .02209 L
.82656 .02551 L
.83568 .03323 L
.85639 .05784 L
.87775 .09252 L
.89791 .1326 L
.93639 .22382 L
.97619 .32919 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.482681,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o7Oooool0
0ol0003oooooooooo`3oooooodWooooo000Mooooo`03o`000?oooooooooo0?ooooooBOooool001go
oooo00?o0000ooooooooool0oooooom9ooooo`007Oooool00ol0003oooooooooo`3oooooodWooooo
000Mooooo`;o0000oooooom:ooooo`007Oooool00ol0003oooooooooo`3gooooo`So0000BOooool0
01gooooo00?o0000ooooooooool0m?ooool3o`0000Sooooo0ol00016ooooo`007Oooool00ol0003o
ooooooooo`3booooo`;o00003_ooool2o`0004Cooooo000Mooooo`03o`000?oooooooooo0?7ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`11ooooo`007Oooool00ol0003ooooooooo
o`3`ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0@?ooool001gooooo00?o0000
ooooooooool0koooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03oooooo000Boooo
o`Go00001_ooool00ol0003oooooooooo`3^ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0?_ooool001;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo
0>gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0nooooo`002_ooool6o`0000?o
oooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0?Oooool001Cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000>cooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0looooo`005Oooool00omgMgOoIVIVoooo
o`05ooooo`03o`000?oooooooooo0>_ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0kooooo`005_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0>[ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0kooooo`004_ooool01Ol0003o^[ZjoooooonHV9So
410@00Kooooo00?o0000ooooooooool0j_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo03[ooooo000Booooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3Y
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0>Oooool001gooooo00?o0000oooo
ooooool0j?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Sooooo000Mooooo`03
o`000?oooooooooo0>Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0hooooo`00
7Oooool00ol0003oooooooooo`3Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
=oooool001gooooo00?o0000ooooooooool0i_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo03Kooooo000Mooooo`;o0000i_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo03Kooooo000Mooooo`03o`000?oooooooooo0>Gooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0eooooo`007Oooool00ol0003oooooooooo`3Tooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool0=?ooool001gooooo00?o0000ooooooooool0hoooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo03Cooooo000Mooooo`03o`000?oooooooooo0>?ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0cooooo`007Oooool00ol0003oooooooooo`3R
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<oooool001gooooo00?o0000oooo
ooooool0h_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo03;ooooo000Mooooo`03
o`000?oooooooooo04[ooooo1ol0002@ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0<Oooool001gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0aooooo`007Ooo
ool2o`0004Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2;ooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool0<?ooool001gooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0`ooooo`007Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
02oooooo000Mooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`27ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0;oooool001gooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Kooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0^ooooo`007Oooool00ol0003ooooooooo
o`14ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0QOooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo02kooooo000Mooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool0;Oooool001gooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0]oooo
o`007Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0POooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02cooooo000Mooooo`03o`00
0?oooooooooo04?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`21ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool0;?ooool001gooooo0_l00013ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo02_ooooo000Mooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`1oooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0:oooool0
01gooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
07oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Zooooo`007Oooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0OOooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo02[ooooo000Mooooo`03o`000?oooooooooo043ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool0:Oooool001gooooo00?o0000ooooooooool0@?ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`0Yooooo`007Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0Noooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo02Wooooo000Moooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1joooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool0:?ooool001gooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo07Wooooo00?o0000oooooooo
ool0@_ooool00ol0003oooooooooo`0Xooooo`007Oooool2o`0003oooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
9oooool001gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo07Sooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Wooooo`007Oooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0M_ooool0
0ol0003oooooooooo`15ooooo`03o`000?oooooooooo02Kooooo000Mooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool09_ooool001gooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0AOooool00ol0003o
ooooooooo`0Vooooo`007Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool0M?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo02Gooooo
000Mooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`1dooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool09Oooool001?ooooo1?l00000
0ol@413oooooooooo`03ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool09?ooool0
01Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo
02Cooooo000:ooooo`Ko00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo04Wo
oooo00?o0000ooooooooool09?ooool001Gooooo00?o0000ooooooooool01Oooool3o`0003_ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo04_ooooo
00?o0000ooooooooool08oooool001Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0L?ooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo02?ooooo000Eooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06oooooo00?o0000
ooooooooool0C?ooool00ol0003oooooooooo`0Rooooo`005Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^oooo
o`03o`000?oooooooooo04gooooo00?o0000ooooooooool08_ooool001?ooooo00?oEEEEofIVI_l0
00001oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0K_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo02;ooooo000Mooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1/ooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool08Oooool001gooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0Cooo
ool00ol0003oooooooooo`0Qooooo`007Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooo
oooo023ooooo000Mooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`1Zooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool08?ooool001go
oooo0_l0000iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0J_ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01oooooo000Mooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo05;ooooo
00?o0000ooooooooool07oooool001gooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0Doooool00ol0003ooooooooo
o`0Oooooo`007Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool0J?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo01kooooo000Moooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Xoooo
o`03o`000?oooooooooo05Cooooo00?o0000ooooooooool07_ooool001gooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo06Kooooo00?o0000oooooooo
ool0E_ooool00ol0003oooooooooo`0Mooooo`007Oooool00ol0003oooooooooo`0gooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`1Fooooo`03o`00
0?oooooooooo01gooooo000Mooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool07Ooo
ool001gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Looooo`007Oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`1Hooooo`03o`000?oooooooooo01cooooo000Mooooo`;o0000=oooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0F_ooool00ol0003o
ooooooooo`0Kooooo`007Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool0Hoooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo01_ooooo
000Mooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`1Rooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool06oooool001gooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool0G?ooool00ol0003oooooooooo`0Jooooo`007Oooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Loooo
o`03o`000?oooooooooo01[ooooo000Mooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo05gooooo00?o0000oooooooo
ool06Oooool001gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo05oooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Iooooo`007Ooo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0Gooo
ool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooo
oooo05oooooo00?o0000ooooooooool06?ooool001gooooo0_l0000dooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
01Sooooo000Mooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`1Mooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool05oooool001gooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo05gooooo
00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Gooooo`007Oooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0G?ooool00ol0003ooooooooo
o`1Rooooo`03o`000?oooooooooo01Oooooo000Mooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo06?ooooo00?o0000
ooooooooool05_ooool001gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Foooo
o`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Gooooo00?o0000
ooooooooool0:Oooool4o`000003oa0@4?oooooooooo02[ooooo00?o0000ooooooooool04_ooool4
o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?_oo
ool00ol0003oooooo`000004o`00017ooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool03?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo01Gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?Ooo
ool01ol0003ooooooiRHV?lQ8B7ok^k^oooooom4A4@04Oooool001gooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0<ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0??ooool01_l0003o
oooooooooonHV9So8B4Qonk^kQ;ooooo000Mooooo`;o0000<_ooool00ol0003oooooooooo`0<oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00kooooo00?oMgMgoc8b<_ooool0?_ooool01_l0003ooooooooooonHV9So8B4Qonk^kQ7ooooo
000Mooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`06o`000?oooooooooooooooomgMgOoIVIV4Ooo
ool001gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0@_ooool01Ol0003ooooooooooooooooo0000017ooooo000Mooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool03Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04;ooooo
00Go0000okZj^_ooooooV9RHoa0@400Aooooo`007Oooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo00gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00006?ooool00ol0003o
ooooooooo`0Wooooo`03oeEEEOmVIVKo000002cooooo00?o0000ooooooooool05?ooool00omEEEGo
IVIVo`00000=ooooo`Co0000@Oooool01Ol0003o410@o`000?lQ8B7oc<c<017ooooo000Mooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`1Fooooo`03
o`000?oooooooooo06[ooooo00?o0000ooooooooool04_ooool001gooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0
Joooool00ol0003oooooooooo`0Booooo`007Oooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`1/ooooo`03o`000?oo
oooooooo017ooooo000Mooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0??ooool0
0ol0003oooooooooo`1Dooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool04Oooool0
01gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
05;ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Aooooo`005Oooooooo`0004Wo
00002oooool001gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`04o`00
0?ooooooooooo`0000oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool04?ooool001gooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
Boooool00ol0003oooooooooo`0@ooooo`007Oooool2o`0002kooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo08;ooooo000Mooooo`;o0000;_ooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0P_ooool0
01gooooo0_l0000^ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0Coooool00ol0
003oooooooooo`23ooooo`007Oooool2o`0002kooooo00?o0000ooooooooool0@?ooool00ol0003o
ooooooooo`1?ooooo`03o`000?oooooooooo08?ooooo000Mooooo`;o0000;Oooool00ol0003ooooo
ooooo`12ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0Poooool001gooooo00?o
0000ooooool00000;?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo04gooooo00?o
0000ooooooooool0Q?ooool001gooooo0ol0000/ooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool0COooool00ol0003oooooooooo`24ooooo`007Oooool00ol0003oooooo`00000/oooo
o`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`24oooo
o`007Oooool00ol0003oooooo`00000[ooooo`03o`000?oooooooooo04Cooooo00?o0000oooooooo
ool0Boooool00ol0003oooooooooo`25ooooo`007Oooool00ol0003oooooo`00000[ooooo`03o`00
0?oooooooooo04Cooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`25ooooo`007Ooo
ool01?l0003oooooooooool0000Zooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
Boooool00ol0003oooooooooo`25ooooo`007Oooool01?l0003oooooooooool0000Zooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`26ooooo`007Ooo
ool01?l0003oooooooooool0000Yooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`26ooooo`007Oooool01?l0003oooooooooool0000Yooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`26ooooo`007Ooo
ool01Ol0003ooooooooooooooooo000002Sooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
ooooo`17ooooo`03o`000?oooooooooo08Oooooo000Mooooo`05o`000?ooooooooooooooool00000
:?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
Qoooool001gooooo0_l00002ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo08Oooooo000Mooooo`05o`000?oooooo
ooooooooool000009oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04Gooooo00?o
0000ooooooooool0R?ooool001gooooo00Go0000ooooooooooooooooo`00000Wooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`28ooooo`007Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`15ooooo`03o`000?oooooooooo08Sooooo000Mooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool0ROooool001gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0@oooool00ol0003o
ooooooooo`29ooooo`007Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0Boooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo08Wooooo
000Mooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`1<ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0R_ooool001gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04gooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`2:ooooo`007Oooool2o`0000Cooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo047ooooo00?o0000oooo
ooooool0R_ooool001gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo04kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`2;ooooo`00
7Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo08_ooooo000Mooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1?ooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool0Roooool001gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`2<ooooo`007Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
08cooooo000Mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1@ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0S?ooool001gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo057ooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`2=ooooo`007Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo08gooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0SOooool001gooooo0_l00006ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0D_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo08kooooo000Mooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Dooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0S_ooool001gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`2>ooooo`007Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo08oooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`1Fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Soooool0
01gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
05Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`2?ooooo`004oooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo05Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2@ooooo`00
5Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
T?ooool001Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo093ooooo000Eooooo`03o`000?oooooooooo00Gooooo0ol00008ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo097ooooo000Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`2Aooooo`005Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool0TOooool001Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0F_ooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo09;ooooo000Cooooo`03oeEEEOmVIVKo000000Oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05cooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`2Booooo`007Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo09;ooooo000Mooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool0Toooool001gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo05kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Cooooo`00
7Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
G_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo09Cooooo000Mooooo`;o00003?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`2Dooooo`007Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo09Gooooo000Mooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0UOooool001go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo067o
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2Eooooo`007Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Hoooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo09Kooooo000Mooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0U_ooool001gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`2G
ooooo`007Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0I_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo09Oooooo000Mooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Vooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0V?ooool001gooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`2Hooooo`007Oooool2o`0001;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0V?oo
ool001gooooo00?o0000ooooooooool04_ooool01?l0003oooooooooooooool2o`0006cooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`2Iooooo`007Oooool00ol0003oooooooooo`0C
ooooo`Co0000K_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo09Wooooo000Moooo
o`03o`000?oooooooooo08Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`2Joooo
o`007Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0V_ooool001gooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo09_ooooo000Mooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`2Kooooo`007Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0W?ooool001gooooo00?o0000ooooooooool0R?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo09cooooo000Mooooo`;o0000ROooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo09gooooo000Mooooo`03o`000?oooooooooo08Wooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`2Nooooo`007Oooool00ol0003ooooooooo
o`29ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0W_ooool001gooooo00?o0000
ooooooooool0R_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo09oooooo000Moooo
o`03o`000?oooooooooo08[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2Ooooo
o`007Oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0X?ooool001gooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo0:7ooooo000Mooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`2Rooooo`007Oooool00ol0003oooooooooo`2=ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0Xoooool001gooooo00?o0000ooooooooool0S_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo0:Cooooo000Mooooo`;o0000T?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo0:Gooooo000Mooooo`03o`000?oooooooooo093ooooo
0_l0000=ooooo`03o`000?oooooooooo0:Kooooo000Mooooo`03o`000?oooooooooo09;ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`2Wooooo`007Oooool00ol0003oooooooooo`2C
ooooo`;o00001oooool2o`000:[ooooo000Mooooo`03o`000?oooooooooo09Gooooo0_l00002oooo
o`?o0000[?ooool001gooooo00?o0000ooooooooool0Uoooool3o`000:kooooo000Mooooo`03o`00
0?oooooooooo0?ooooooBOooool001;ooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooBOoo
ool001;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?ooooooBOoo
ool001?ooooo00?oV9RHob4Q8Oo^k^h01oooool3o`000?ooooooBOooool001Cooooo00?oV9RHob4Q
8Oo^k^h0oooooomBooooo`005Oooool00omgMgOoIVIVooooo`3ooooooe7ooooo000Fooooo`03o`00
0?oooooooooo0?ooooooD?ooool001;ooooo00Go0000okZj^_ooooooV9RHoa0@403ooooooe;ooooo
000Booooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0oooooomBooooo`00/oooool01OlQ8B7o0000o`00
0?m4A4CogMgM01Kooooo00Go8B4Qo`000?l0003oA4A4omgMg@2Eooooo`00]_ooool00omgMgOo<S8b
ooooo`0Hooooo`03ogMgMolb<S;ooooo03gooooo00?o0000okZj^_ooool0E?ooool00;Oooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0looooo`;o<S8bEOooool003kooooo00OoQhN7
ob4Q8OooooooooooodA4A?mgMgOooooo00?o00000_ooool00onYZJWo0000ooooo`05o`000003oc8b
<_o^k^kooooo00Oooooo00KoV9RHo`000?l0003oMgMgoa0@4?l00002ooooo`04oa0@4?l0003o0000
ooooo`;o000000Co410@ooooooo^k^koEEEE0_l000000onHV9So0000oa0@4007ooooo`06oa0@4?lb
<S;o0000o`000?l@413oZJVY0_ooool01?l@413o0000o`000?ooool2o`000004oa0@4?ooooook^k^
oeEEE@;o000000KoEEEEonk^k_ooooooooooonk^k_mEEED2o`000003oeEEEOo^k^kooooo00;ooooo
00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`Go00000_ooool01?l@413o0000o`000?ooool2o`00
0008oa0@4?ooooook^k^oeEEEOl0003o410@olc<c?l00005ooooo`06onk^k_mEEEGo0000o`000?m4
A4Co^[Zj0oooool5o`0000;ooooo00Kok^k^oeEEEOl0003o410@olc<c?l00002ooooo`06onk^k_mE
EEGo0000o`000?m4A4Co^[Zj0_ooool01?l@413o0000o`000?ooool2o`000003oa0@4?l0003o0000
00;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE00;o000000KoEEEEonk^k_oooooooooo
onk^k_mEEED2o`000006oiRHV?l0003o410@ooooooo^k^koEEEE0_l000001_m4A4Co^[Zjoooooooo
oooo410@oc8b<P;o000000?o410@ojVYZOooool01Oooool00on7QhOo0000okZj^P0;ooooo`04oa0@
4?l0003o0000ooooo`;o000000?o410@ooooooooool02?ooool2o`000003oa0@4?oooooooooo03?o
oooo000nooooo`06ofIVI_l0003ok^k^ooooool0003oMgMg0_ooool01_l0003ooooooooooooooooo
410@okZj^P;ooooo00Ko0000ooooooooooook^k^ohN7Qolb<S88ooooo`05o`000?o<c<cok^k^ohN7
Qol000001?ooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMoooooook^k^oeEE
EOl00008ooooo`06o`000?nYZJWooooooooooonj^[[o00000oooool01Ol0003ooooooooooooooooo
000000;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED2ooooo`06oeEEEOmgMgOooooooooooomg
MgOoEEEE0oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Gooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00005ooooo`06
oeEEEOmgMgOoooooonk^k_mgMgOo410@1Oooool00ol0003oooooooooo`02ooooo`06oeEEEOmgMgOo
ooooonk^k_mEEEGo00000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooomEEEGoMgMg
0_ooool02_mgMgOoEEEEooooooooooooEEEEogMgMoooooook^k^oeEEEOl00002ooooo`06oeEEEOmg
MgOoooooonk^k_mgMgOo410@0_ooool01_l0003oZJVYoooooooooooo^[Zjo`0000Kooooo00?oc<c<
o`000?l@41003?ooool01_l0003ooooooooooooooooo0000ooooo`Ko00001Oooool00ol0003ooooo
ooooo`0dooooo`00?_ooool2oc8b<P04oiRHV?nYZJWo410@oc8b<P;ooooo00Go0000oooooooooooo
V9RHodA4A003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol@413o
QhN7ooooooo^k^ko000000Cooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?oooooo
ooooooooooo^k^ko00002Oooool01Onj^[[oQhN7ofIVI_mVIVKo410@00?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool0
1Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Ko0000ooooooooooooooooonk^k_l00005ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool00_ooool01_l0003oooooooooooooooook^k^o`0000;ooooo00?o
0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo00Gok^k^o`00
0?ooooooooooo`000008ooooo`05okZj^_n7QhOoIVIVofIVI_l@41005Oooool01Ol0003ooooooooo
oooooooo000000Wooooo1Ol0000eooooo`00?_ooool01_l@413oZJVYoeEEEOmEEEGoZJVYoa0@40;o
oooo00Go0000oeEEEOnj^[[o410@omgMg@03ooooo`06o`000?ooooooooooonk^k_n7QhOo<S8b2?oo
ool00onj^[[o410@o`000002o`0000Cooooo00Go0000ooooooooooooooooo`000002ooooo`06o`00
0?ooooooooooooooooo^k^ko00002?ooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP?ooooo00Go
0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00001?ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo000000;ooooo00Ko0000ooooooooooooooooonk^k_l00005ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooooooooo^k^ko00000_ooool6o`00
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooool000001?ooool01?l0003oooooooooool00003ooooo`04onk^k_l0003oooooooooo`Ko
00000_ooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kQGooooo00Ko0000ooooooooooooooooo`00
0?ooool6o`0000;ooooo00CoA4A4omgMgOoooooo0000=_ooool003kooooo00Ko0000oooooolQ8B7o
410@ooooool00002ooooo`04o`000?nHV9So0000okZj^PCooooo1?l000000omEEEGok^k^ooooo`0:
ooooo`03olc<c?l0003ooooo00?ooooo00Go0000ohN7QoooooooZJVYo`000002ooooo`06ofIVI_mg
MgOoooooonk^k_mEEEGo00002?ooool01_l0003o^[Zjooooooo^k^koMgMgo`0000?ooooo00Go0000
ogMgMoooooooZJVYo`000002ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0_ooool01_mEEEGo
MgMgooooooooooooMgMgoeEEE@?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03
ooooo`05o`000?n7QhOoooooojVYZOl000000_ooool01_mEEEGoMgMgooooooo^k^koEEEEo`0000Go
oooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S85ooooo`03o`000?oooooooooo00;ooooo00KoEEEE
ogMgMoooooook^k^oeEEEOl00002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0oooool01Ol0
003oQhN7oooooonYZJWo000000;ooooo00[o0000olc<c?o<c<co0000ojVYZOoMgMgo8B4QoooooomE
EEGoMgMg0_ooool02_mgMgOoEEEEooooooooooooIVIVogMgMoooooook^k^oeEEEOl00002ooooo`06
oeEEEOn7QhOok^k^oooooon7QhOo<S8b0_ooool01_l0003o^[Zjooooooo^k^koMgMgo`0001Gooooo
00Go0000ohN7QoooooooZJVYo`000009ooooo`04omgMgOmEEEGoooooo`0003Kooooo000mooooo`03
olc<c?lQ8B7ooooo00;oEEEE00Sooooooc8b<_nj^[[oooooo`000?ooooooZJVYofIVIPCooooo00Go
0000oooooooooooo^[Zjoa0@400:ooooo`04oc8b<_l0003o0000oiRHV0?ooooo00?o410@o`000?mg
MgL00_l000002OnHV9Soooooooooooo^k^koEEEEo`000?l@413oc<c<o`000008ooooo`06ojVYZOlQ
8B7o0000o`000?lb<S;o00000oooool01Ol0003oMgMgo`000?l0003oV9RH00;ooooo00Kok^k^oeEE
EOl0003o0000oeEEEOo^k^h2ooooo`08onk^k_mEEEGo0000o`000?mEEEGok^k^ooooool@4105o`00
00Cooooo00?o410@o`000?l000001?ooool00ol@413o0000ogMgM`02o`00000:oiRHV?oooooooooo
onk^k_mEEEGo0000ob4Q8OnYZJWo0000oa0@40Cooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h3
ooooo`03oa0@4?l0003o000000Cooooo00[ok^k^oeEEEOl0003o8B4QojVYZOl0003o410@ooooooo^
k^koEEEE0_l000001om4A4Cok^k^oooooooooooo410@o`000?mgMgL00_l000003OnHV9Sooooooa0@
4?l0003o8B4Qo`000?mgMgOo410@o`000?nYZJWoooooonk^k_mEEED00_l000002_mEEEGok^k^oooo
ooooooook^k^oeEEEOl0003o410@olc<c?l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^
0_ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0001Cooooo00?o410@o`000?mgMgL00_l000000onH
V9Soooooooooo`08ooooo`03ogMgMoo<c<co000003Kooooo000mooooo`03ojVYZOlb<S;ooooo00?o
oooo00CoA4A4oiRHV?oooooo00000_ooool00onYZJWoEEEEonk^kP02ooooo`05o`000?oooooooooo
okZj^_l000007_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0G?ooool00ol0003oooooooooo`0booooo`03onk^k_m4A4Co000003Kooooo000moooo
o`?o00000_ooool6o`000005ooooool0003o0000o`000?ooool01?l000000ol@413oZJVYooooo`0M
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0c
ooooo`03ogMgMol0003ooooo03Gooooo001`ooooo`;o00004?ooool00ol@413o0000ooooo`0Poooo
o`03oa0@4?oooooooooo023ooooo00?o410@ooooooooool0;_ooool2o`0006gooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.187939, -2.2862, \
0.00802016, 0.0265229}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.292863 0.140261 [
[.2619 .28036 -9 -9 ]
[.2619 .28036 9 0 ]
[.5 .28036 -3 -9 ]
[.5 .28036 3 0 ]
[.7381 .28036 -9 -9 ]
[.7381 .28036 9 0 ]
[.97619 .28036 -3 -9 ]
[.97619 .28036 3 0 ]
[.01131 .01234 -12 -4.5 ]
[.01131 .01234 0 4.5 ]
[.01131 .1526 -12 -4.5 ]
[.01131 .1526 0 4.5 ]
[.01131 .43312 -6 -4.5 ]
[.01131 .43312 0 4.5 ]
[.01131 .57339 -6 -4.5 ]
[.01131 .57339 0 4.5 ]
[.5 .63053 -101 0 ]
[.5 .63053 101 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .29286 m
.2619 .29911 L
s
[(0.5)] .2619 .28036 0 1 Mshowa
.5 .29286 m
.5 .29911 L
s
[(1)] .5 .28036 0 1 Mshowa
.7381 .29286 m
.7381 .29911 L
s
[(1.5)] .7381 .28036 0 1 Mshowa
.97619 .29286 m
.97619 .29911 L
s
[(2)] .97619 .28036 0 1 Mshowa
.125 Mabswid
.07143 .29286 m
.07143 .29661 L
s
.11905 .29286 m
.11905 .29661 L
s
.16667 .29286 m
.16667 .29661 L
s
.21429 .29286 m
.21429 .29661 L
s
.30952 .29286 m
.30952 .29661 L
s
.35714 .29286 m
.35714 .29661 L
s
.40476 .29286 m
.40476 .29661 L
s
.45238 .29286 m
.45238 .29661 L
s
.54762 .29286 m
.54762 .29661 L
s
.59524 .29286 m
.59524 .29661 L
s
.64286 .29286 m
.64286 .29661 L
s
.69048 .29286 m
.69048 .29661 L
s
.78571 .29286 m
.78571 .29661 L
s
.83333 .29286 m
.83333 .29661 L
s
.88095 .29286 m
.88095 .29661 L
s
.92857 .29286 m
.92857 .29661 L
s
.25 Mabswid
0 .29286 m
1 .29286 L
s
.02381 .01234 m
.03006 .01234 L
s
[(-2)] .01131 .01234 1 0 Mshowa
.02381 .1526 m
.03006 .1526 L
s
[(-1)] .01131 .1526 1 0 Mshowa
.02381 .43312 m
.03006 .43312 L
s
[(1)] .01131 .43312 1 0 Mshowa
.02381 .57339 m
.03006 .57339 L
s
[(2)] .01131 .57339 1 0 Mshowa
.125 Mabswid
.02381 .04039 m
.02756 .04039 L
s
.02381 .06845 m
.02756 .06845 L
s
.02381 .0965 m
.02756 .0965 L
s
.02381 .12455 m
.02756 .12455 L
s
.02381 .18065 m
.02756 .18065 L
s
.02381 .20871 m
.02756 .20871 L
s
.02381 .23676 m
.02756 .23676 L
s
.02381 .26481 m
.02756 .26481 L
s
.02381 .32092 m
.02756 .32092 L
s
.02381 .34897 m
.02756 .34897 L
s
.02381 .37702 m
.02756 .37702 L
s
.02381 .40507 m
.02756 .40507 L
s
.02381 .46118 m
.02756 .46118 L
s
.02381 .48923 m
.02756 .48923 L
s
.02381 .51728 m
.02756 .51728 L
s
.02381 .54533 m
.02756 .54533 L
s
.02381 .60144 m
.02756 .60144 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -162 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(WKB) show
87.000 13.000 moveto
(and) show
111.000 13.000 moveto
(shooting) show
165.000 13.000 moveto
(eigenmodes) show
231.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
243.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
249.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
255.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
261.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .29286 m
.03279 .34326 L
.04262 .39435 L
.053 .43941 L
.05753 .45531 L
.06244 .46958 L
.06526 .47629 L
.06786 .4815 L
.07051 .4858 L
.07298 .48892 L
.07434 .49025 L
.07559 .49124 L
.07697 .49206 L
.07773 .4924 L
.07846 .49264 L
.07915 .49281 L
.0799 .4929 L
.0806 .49292 L
.08123 .49287 L
.08198 .49274 L
.08279 .49251 L
.08355 .49221 L
.08426 .49186 L
.08543 .49111 L
.08669 .4901 L
.08897 .48771 L
.09167 .48396 L
.09414 .47969 L
.0995 .46778 L
.10458 .45337 L
.12449 .37383 L
.14291 .28225 L
.16316 .18437 L
.17308 .1439 L
.18218 .11347 L
.19103 .09105 L
.19548 .0827 L
.20034 .07588 L
.20291 .07327 L
.20525 .0715 L
.20654 .07077 L
.20722 .07045 L
.20794 .07017 L
.20857 .06997 L
.20927 .0698 L
.21049 .06961 L
.21172 .06958 L
.21284 .06969 L
.21413 .06998 L
.21536 .07042 L
Mistroke
.2165 .07095 L
.21755 .07157 L
.21993 .07337 L
.22258 .07604 L
.22502 .0791 L
.23052 .08806 L
.24049 .11109 L
.24955 .13873 L
.25911 .17355 L
.29713 .34061 L
.31832 .42901 L
.33761 .49177 L
.3472 .51435 L
.35262 .52425 L
.35763 .53149 L
.362 .53629 L
.36449 .53838 L
.36682 .53991 L
.36801 .54054 L
.36927 .54109 L
.37034 .54146 L
.37151 .54176 L
.37278 .54198 L
.37349 .54205 L
.37413 .54208 L
.37539 .54205 L
.37657 .54191 L
.37773 .54167 L
.37897 .54131 L
.38014 .54087 L
.38121 .54037 L
.38383 .53881 L
.38632 .53687 L
.39125 .53173 L
.39662 .52423 L
.40621 .50621 L
.41509 .48466 L
.45432 .34906 L
.49204 .19752 L
.51299 .12353 L
.52217 .09588 L
.53221 .06972 L
.54131 .05011 L
.55103 .03375 L
.55641 .02683 L
.5613 .02188 L
.56366 .01995 L
.56622 .0182 L
.56865 .01687 L
.57087 .01593 L
Mistroke
.57199 .01555 L
.57322 .01522 L
.57451 .01496 L
.57575 .0148 L
.57689 .01472 L
.57812 .01472 L
.57927 .01478 L
.58032 .01491 L
.58097 .01501 L
.58166 .01515 L
.58289 .01546 L
.58422 .01588 L
.58567 .01645 L
.58828 .01775 L
.59072 .01928 L
.59603 .02367 L
.60087 .02891 L
.61175 .04479 L
.62168 .0639 L
.63085 .08515 L
.65162 .14385 L
.6909 .2801 L
.72867 .41471 L
.74966 .48029 L
.7689 .53027 L
.78776 .56764 L
.79724 .5816 L
.80257 .58796 L
.80761 .59296 L
.81254 .59692 L
.81514 .59862 L
.81789 .60014 L
.82021 .60119 L
.82275 .6021 L
.82387 .60242 L
.82507 .6027 L
.82611 .60291 L
.82723 .60309 L
.82796 .60317 L
.82863 .60324 L
.82992 .60331 L
.83065 .60332 L
.83143 .60331 L
.83217 .60328 L
.83285 .60323 L
.83409 .6031 L
.83479 .60299 L
.83545 .60288 L
.83685 .60259 L
.83818 .60224 L
Mistroke
.84071 .60139 L
.84302 .60041 L
.84819 .59748 L
.8528 .59404 L
.85788 .58936 L
.86815 .57713 L
.88659 .54652 L
.90599 .50374 L
.92686 .44796 L
.96808 .31946 L
.97619 .29286 L
Mfstroke
.02381 .29286 m
.03279 .34326 L
.04262 .39435 L
.053 .43941 L
.05753 .45531 L
.06244 .46958 L
.06526 .47629 L
.06786 .4815 L
.07051 .4858 L
.07298 .48892 L
.07434 .49025 L
.07559 .49124 L
.07697 .49206 L
.07773 .4924 L
.07846 .49264 L
.07915 .49281 L
.0799 .4929 L
.0806 .49292 L
.08123 .49287 L
.08198 .49274 L
.08279 .49251 L
.08355 .49221 L
.08426 .49186 L
.08543 .49111 L
.08669 .4901 L
.08897 .48771 L
.09167 .48396 L
.09414 .47969 L
.0995 .46778 L
.10458 .45337 L
.12449 .37383 L
.14291 .28225 L
.16316 .18437 L
.17308 .1439 L
.18218 .11347 L
.19103 .09105 L
.19548 .0827 L
.20034 .07588 L
.20291 .07327 L
.20525 .0715 L
.20654 .07077 L
.20722 .07045 L
.20794 .07017 L
.20857 .06997 L
.20927 .0698 L
.21049 .06961 L
.21172 .06958 L
.21284 .06969 L
.21413 .06998 L
.21536 .07042 L
Mistroke
.2165 .07095 L
.21755 .07157 L
.21993 .07337 L
.22258 .07604 L
.22502 .0791 L
.23052 .08806 L
.24049 .11109 L
.24955 .13873 L
.25911 .17355 L
.29713 .34061 L
.31832 .42901 L
.33761 .49177 L
.3472 .51435 L
.35262 .52425 L
.35763 .53149 L
.362 .53628 L
.36449 .53837 L
.36682 .53991 L
.36801 .54054 L
.36927 .54108 L
.37034 .54146 L
.37151 .54176 L
.37278 .54198 L
.37349 .54205 L
.37413 .54208 L
.37539 .54204 L
.37657 .54191 L
.37773 .54167 L
.37897 .54131 L
.38014 .54086 L
.38121 .54037 L
.38383 .53881 L
.38632 .53687 L
.39125 .53173 L
.39662 .52423 L
.40621 .50621 L
.41509 .48466 L
.45432 .34906 L
.49204 .19752 L
.51299 .12353 L
.52217 .09588 L
.53221 .06972 L
.54131 .05011 L
.55103 .03375 L
.55641 .02683 L
.5613 .02188 L
.56366 .01995 L
.56622 .0182 L
.56865 .01687 L
.57087 .01593 L
Mistroke
.57199 .01555 L
.57322 .01522 L
.57451 .01496 L
.57575 .0148 L
.57689 .01472 L
.57812 .01472 L
.57927 .01478 L
.58032 .01491 L
.58097 .01501 L
.58166 .01515 L
.58289 .01546 L
.58422 .01588 L
.58567 .01645 L
.58828 .01775 L
.59072 .01928 L
.59603 .02367 L
.60087 .02891 L
.61175 .04479 L
.62168 .0639 L
.63085 .08515 L
.65162 .14385 L
.6909 .28009 L
.72867 .41471 L
.74966 .48029 L
.7689 .53027 L
.78776 .56764 L
.79724 .5816 L
.80257 .58796 L
.80761 .59297 L
.81254 .59692 L
.81514 .59862 L
.81789 .60014 L
.82021 .60119 L
.82275 .6021 L
.82387 .60242 L
.82507 .60271 L
.82611 .60291 L
.82723 .60309 L
.82796 .60317 L
.82863 .60324 L
.82992 .60331 L
.83065 .60332 L
.83143 .60331 L
.83217 .60328 L
.83285 .60323 L
.83409 .6031 L
.83479 .603 L
.83545 .60288 L
.83685 .60259 L
.83818 .60224 L
Mistroke
.84071 .60139 L
.84302 .60041 L
.84819 .59748 L
.8528 .59404 L
.85788 .58936 L
.86815 .57713 L
.88659 .54652 L
.90599 .50374 L
.92686 .44796 L
.96808 .31946 L
.97619 .29286 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.482681,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Cooooo`Go0000
1_ooool00ol0003oooooooooo`3oooooodSooooo000Cooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1_ooool00ol0003oooooooooo`3oooooodSooooo000;ooooo`Ko00000oooool00onHV9So8B4Qonk^
kP07ooooo`03o`000?oooooooooo0?ooooooB?ooool001Gooooo00?oV9RHob4Q8Oo^k^h01_ooool3
o`000?ooooooB?ooool001Kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`2^oooo
o`Ko0000Toooool001Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2/ooooo`;o
00001_ooool3o`00093ooooo000Cooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003o
ooooooooo`2[ooooo`;o00002_ooool00ol0003oooooooooo`2=ooooo`004oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo08gooooo000Nooooo`03o`000?oooooooooo0:[ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`2<ooooo`007_ooool00ol0003oooooooooo`2Yooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0S?ooool001kooooo00?o0000ooooooooool0Z?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo08_ooooo000Nooooo`03o`000?oooooooooo
0:Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2:ooooo`007_ooool2o`000:So
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`29ooooo`007_ooool00ol0003ooooo
ooooo`2Vooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0R?ooool001kooooo00?o
0000ooooooooool0Y_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo08Sooooo000N
ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`27
ooooo`007_ooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0Qoooool001kooooo00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo08Kooooo000Nooooo`03o`000?oooooooooo0:Cooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`26ooooo`007_ooool00ol0003oooooooooo`2Sooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0QOooool001kooooo00?o0000ooooooooool0Xoooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo08Gooooo000Nooooo`;o0000>_ooool3o`00
06Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`24ooooo`007_ooool00ol0003o
ooooooooo`0hooooo`;o000000?oooooo`000?l00000IOooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo08Cooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l00005ooooo`;o0000
H_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo08?ooooo000Nooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0Poooool001kooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`23ooooo`007_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
08;ooooo000Nooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1Mooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0P_ooool001kooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05gooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`21ooooo`007_ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Foooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo087ooooo000Nooooo`;o0000<oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`21
ooooo`007_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0Foooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo083ooooo000Nooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Iooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0P?ooool001kooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`20ooooo`007_ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo07oooooo000Nooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1Gooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Ooooool0
01kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
05Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1nooooo`007_ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0E_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo07kooooo000Nooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0O_ooool001kooooo0_l0000`ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0EOooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07gooooo000N
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0OOooool001kooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05Cooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`1mooooo`007_ooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo07cooooo000Nooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
O?ooool001kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1looooo`007_ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0DOooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo07_ooooo000Dooooo`Co000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0DOooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo07_ooooo000Fooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo053ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1kooooo`00
2oooool6o`0000Gooooo00?o0000ooooooooool01Oooool3o`0002gooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
N_ooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo07[ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`1jooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool0NOooool001Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo07Wooooo000Dooooo`03oeEEEOmVIVKo000000Oooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1iooooo`007_ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0C?ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo07Wooooo000Nooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool0N?ooool001kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1hoooo
o`007_ooool2o`0002cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1;ooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool0N?ooool001kooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`1gooooo`007_ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo07Oooooo000Nooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`19ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0Moooool0
01kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1gooooo`007_ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo07Kooooo000Nooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool0M_ooool001kooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`1fooooo`007_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0Aoooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo07Gooooo000Noooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0MOooool001kooooo0_l0000Zooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo07Gooooo000Nooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
M?ooool001kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`1dooooo`007_ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0A?ooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo07Cooooo000Nooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool0M?ooool001kooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`1cooooo`007_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0@oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo07?ooooo
000Nooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`12ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0Loooool001kooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool0?Oooool00ol0003oooooooooo`1booooo`007_ooool2o`0002Sooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool0L_ooool001kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`1booooo`00
7_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
@?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo07;ooooo000Nooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool0LOooool001kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`1aooooo`007_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01_l0003oA4A4o`000?l0
003o<S8bomgMgCcooooo00?o0000ooooooooool00_ooool4o`000003oa0@4?oooooooooo03Kooooo
00?o0000ooooooooool01Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd0?oooool5o`0001?ooooo000Nooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool05_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`06
o`000?oooooooooooooooomgMgOo<S8b>oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`0nooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@04oooool001kooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Gooooo`05oa0@4?ooooooooooooooool@41003?oo
ool01Ol0003ooooooooooooooooo000003_ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0nooooo`03oiRHV?lQ8B7ok^k^01Cooooo000Nooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool05oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000oooooooooooo
MgMgoc8b<P0kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0@?ooool00onHV9So
8B4Qonk^kP0Cooooo`007_ooool2o`0002Kooooo00?o0000ooooooooool05oooool01Ol0003ooooo
oooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00kooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c012ooooo`03ogMgMomVIVKooooo01;ooooo000Noooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool05oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo04Gooooo00?o0000ooooooooool04Oooool001kooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Gooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool2o`0003gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`11ooooo`05o`000?nj^[[ooooooiRHV?l@41004ooo
ool001kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Hooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`0003_ooooo00?o0000ooooooooool01?ooool00omEEEGoIVIVo`00
000looooo`03o`000?oooooooooo00?ooooo00?oEEEEofIVI_l000003Oooool4o`00043ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00Cooooo`007_ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`14ooooo`03o`000?oo
oooooooo06kooooo000Nooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0K_ooool0
01kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`1^ooooo`007_ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooooooo`15ooooo`03o`000?oooooooooo06kooooo000Nooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool0KOooool001Koooooool00017o`0000cooooo000Nooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03Oooool2o`0000gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;ooooo000Nooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Booooo`007_ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool04oooool001kooooo
0_l0000Sooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool04oooool001kooooo0_l0
000Sooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`19ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool04oooool001kooooo0_l0000S
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool04oooool001kooooo0_l0000Soooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1:oooo
o`03o`000?oooooooooo05Cooooo00?o0000ooooooooool05?ooool001kooooo0_l0000Sooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo05Cooooo00?o0000ooooooooool05?ooool001kooooo0ol0000Qooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1;ooooo`03o`00
0?oooooooooo05Cooooo00?o0000ooooooooool05?ooool001kooooo00?o0000ooooool000008Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0C?oo
ool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo01Gooooo000Nooooo`03o`000?oooooo
0000027ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo04cooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Eooooo`007_ooool00ol0
003oooooo`00000Qooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool05Oooool001ko
oooo00?o0000ooooool000008Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01Ko
oooo000Nooooo`04o`000?ooooooooooo`0001oooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0D?ooool00ol0003o
ooooooooo`0Fooooo`007_ooool01?l0003oooooooooool0000Oooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo053o
oooo00?o0000ooooooooool05_ooool001kooooo00Co0000oooooooooooo00007oooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`1?ooooo`03o`000?oooooooooo01Oooooo000Nooooo`04o`000?ooooooooooo`0001oo
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo053o
oooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Gooooo`007_ooool2o`000003oooo
ool0003ooooo01kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo053ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Gooooo`007_oo
ool01?l0003oooooooooool0000Nooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
6?ooool001kooooo00Go0000ooooooooooooooooo`00000Mooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo04cooooo
00?o0000ooooooooool06?ooool001kooooo00Go0000ooooooooooooooooo`00000Mooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Booooo`03o`00
0?oooooooooo04cooooo00?o0000ooooooooool06?ooool001kooooo00Go0000oooooooooooooooo
o`00000Mooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`1Booooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool06Oooool001kooooo00Go
0000ooooooooooooooooo`00000Mooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
6Oooool001kooooo00Go0000ooooooooooooooooo`00000Looooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo04[ooooo
00?o0000ooooooooool06Oooool001kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`1Dooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool06_ooool001kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo04Wooooo00?o0000
ooooooooool06_ooool001kooooo0_l00003ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo05Kooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`0Jooooo`007_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo05Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Kooooo`00
7_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`0Kooooo`007_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo05Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Kooooo`007_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0AOooool0
0ol0003oooooooooo`0Looooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
05Sooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Looooo`007_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0AOooool00ol0003o
ooooooooo`0Looooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo05Wooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Mooooo`007_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`0Mooooo`007_ooool2o`0000Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`13
ooooo`03o`000?oooooooooo01gooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0F_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01kooooo000Nooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`11ooooo`03
o`000?oooooooooo01kooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
G?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01kooooo000Nooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo01oooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0GOooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo01oooooo000Nooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
01oooooo000Dooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo05kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Pooooo`00
5_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo023ooooo000Fooooo`03o`000?oo
oooooooo00Gooooo0ol00006ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0@Ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0Pooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo027ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Oooool001Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo06;o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Qooooo`005_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`13ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0H_ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo02;ooooo000Dooooo`03oeEEEOmVIVKo000000Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool08_ooool001kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool08_ooool001kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04Gooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool08oooool001kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Tooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool08oooool001kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
8oooool001kooooo0_l0000:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Aooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0Tooooo`007_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo06Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Tooooo`007_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0Tooooo`007_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo06So
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Uooooo`007_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0BOooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0Uooooo`007_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0B_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo06Wooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`0Uooooo`007_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0V
ooooo`007_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0C?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo06[ooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`0Vooooo`007_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo06_ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Vooooo`00
7_ooool2o`0000kooooo0_l00002ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
9oooool001kooooo00?o0000ooooooooool03_ooool3o`0005;ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool09ooo
ool001kooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Wooooo`007_ooool00ol0
003oooooooooo`1Tooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo02Sooooo000Nooooo`03o`000?oooooooooo06Co
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0:?ooool001kooooo00?o0000ooooooooool0IOooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0Xooooo`007_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02Wooooo000N
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:Oooool001kooooo00?o0000oooo
ooooool0I_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07;ooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`0Zooooo`007_ooool2o`0006Oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool0:_ooool001kooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo07Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0[ooooo`007_oo
ool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0MOoo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02_ooooo000Nooooo`03o`000?oooooo
oooo06Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0;?ooool001kooooo00?o0000ooooooooool0JOooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0/ooooo`007_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02go
oooo000Nooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1jooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0;Oooool001kooooo00?o
0000ooooooooool0K?ooool2o`0000?ooooo0_l0001mooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0;_ooool001kooooo00?o0000ooooooooool0K_ooool3o`00083ooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0^ooooo`007_ooool2o`000?;ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0_ooooo`007_ooool00ol0003oooooooooo`3booooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0;oooool001kooooo00?o0000ooooooooool0
l_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo033ooooo000Nooooo`03o`000?oo
oooooooo0??ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0aooooo`007_ooool0
0ol0003oooooooooo`3cooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0<Oooool0
01kooooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
03;ooooo000Cooooo`Go00001_ooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0<_ooool001?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo0?Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0cooooo`00
5?ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?Gooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0dooooo`005Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000m_oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03Cooooo000Fooooo`03ogMgMomVIVKo
oooo00Gooooo00?o0000ooooooooool0moooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo03Gooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0moooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo03Gooooo000Cooooo`05o`000?nj^[[ooooooiRH
V?l@41001_ooool00ol0003oooooooooo`3hooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0=_ooool001?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
0?Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0gooooo`007_ooool00ol0003o
ooooooooo`3jooooo`;o00004?ooool00ol0003oooooooooo`0hooooo`007_ooool00ol0003ooooo
ooooo`3looooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0>Oooool001kooooo00?o
0000ooooooooool0o?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03[ooooo000N
ooooo`03o`000?oooooooooo0?gooooo0_l00009ooooo`;o0000?Oooool001kooooo0_l0003ooooo
o`7ooooo0ol00003ooooo`?o0000?oooool001kooooo00?o0000ooooooooool0ooooool3ooooo`Co
0000@Oooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00/oooool01OlQ8B7o0000o`000?m4A4CogMgM01Kooooo00Go8B4Qo`00
0?l0003oA4A4omgMg@2Eooooo`00]_ooool00omgMgOo<S8booooo`0Hooooo`03ogMgMolb<S;ooooo
03gooooo00?o0000okZj^_ooool0E?ooool00;Oooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0looooo`;o<S8bEOooool003kooooo00OoQhN7ob4Q8OooooooooooodA4A?mgMgOooooo
00?o00000_ooool00onYZJWo0000ooooo`05o`000003oc8b<_o^k^kooooo00Oooooo00KoV9RHo`00
0?l0003oMgMgoa0@4?l00002ooooo`04oa0@4?l0003o0000ooooo`;o000000Co410@ooooooo^k^ko
EEEE0_l000000onHV9So0000oa0@4007ooooo`06oa0@4?lb<S;o0000o`000?l@413oZJVY0_ooool0
1?l@413o0000o`000?ooool2o`000004oa0@4?ooooook^k^oeEEE@;o000000KoEEEEonk^k_oooooo
ooooonk^k_mEEED2o`000003oeEEEOo^k^kooooo00;ooooo00GoV9RHo`000?l0003oA4A4okZj^P03
ooooo`Go00000_ooool01?l@413o0000o`000?ooool2o`000008oa0@4?ooooook^k^oeEEEOl0003o
410@olc<c?l00005ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0oooool5o`0000;ooooo00Ko
k^k^oeEEEOl0003o410@olc<c?l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0_ooool0
1?l@413o0000o`000?ooool2o`000003oa0@4?l0003o000000;ooooo00Oo0000oooooooooooo0000
oa0@4?o^k^koEEEE00;o000000KoEEEEonk^k_ooooooooooonk^k_mEEED2o`000006oiRHV?l0003o
410@ooooooo^k^koEEEE0_l000001_m4A4Co^[Zjoooooooooooo410@oc8b<P;o000000?o410@ojVY
ZOooool01Oooool00on7QhOo0000okZj^P0;ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@
ooooooooool01oooool01Om4A4Co0000o`000?lb<S;ogMgM03Cooooo000nooooo`06ofIVI_l0003o
k^k^ooooool0003oMgMg0_ooool01_l0003ooooooooooooooooo410@okZj^P;ooooo00Ko0000oooo
ooooooook^k^ohN7Qolb<S88ooooo`05o`000?o<c<cok^k^ohN7Qol000001?ooool01Ol0003ooooo
oooooooooooo000000;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00008ooooo`06o`000?nYZJWo
oooooooooonj^[[o00000oooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMooo
ooooooooogMgMomEEED2ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0oooool01Ol@413o^[Zj
onk^k_mgMgOo410@00Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00005ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo
410@1Oooool00ol0003oooooooooo`02ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00000_ooool0
1_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooomEEEGoMgMg0_ooool02_mgMgOoEEEEoooooooo
ooooEEEEogMgMoooooook^k^oeEEEOl00002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_oo
ool01_l0003oZJVYoooooooooooo^[Zjo`0000Kooooo00?oc<c<o`000?l@41003?ooool01_l0003o
oooooooooooooooo0000ooooo`Ko00001_ooool00omgMgOo<S8booooo`0cooooo`00?_ooool2oc8b
<P04oiRHV?nYZJWo410@oc8b<P;ooooo00Go0000ooooooooooooV9RHodA4A003ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol@413oQhN7ooooooo^k^ko000000Cooooo
00Go0000ooooooooooooooooo`000002ooooo`06o`000?ooooooooooooooooo^k^ko00002Oooool0
1Onj^[[oQhN7ofIVI_mVIVKo410@00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo0000
00Wooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000
ooooooooooooooooonk^k_l00005ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
0_ooool01_l0003oooooooooooooooook^k^o`0000;ooooo00?o0000ooooooooool01_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`00
0004ooooo`04o`000?ooooooooooo`0000?ooooo00Gok^k^o`000?ooooooooooo`000008ooooo`05
okZj^_n7QhOoIVIVofIVI_l@41005Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool0<_ooool003kooooo00Ko410@ojVYZOmEEEGoEEEEojVYZOl@4102ooooo`05o`000?mE
EEGo^[Zjoa0@4?oMgMd00oooool01_l0003oooooooooooo^k^koQhN7oc8b<PSooooo00?o^[Zjoa0@
4?l000000_l00004ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003ooooooooooooo
ooook^k^o`0000Sooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h3ooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00Go
0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`06o`000?ooooooooooooooooo^k^ko00001Oooool6o`0000Gooooo00?o0000
ooooooooool00_ooool01_l0003oooooooooooooooook^k^o`0000;ooooo1_l00003ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo0000
00Cooooo00Co0000oooooooooooo00000oooool01?o^k^ko0000ooooooooool6o`0000;ooooo00Ko
<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^hEooooo`06o`000?ooooooooooooooool0003ooooo1_l00006
ooooo`03ogMgMolb<S;ooooo03?ooooo000nooooo`06o`000?oooooo8B4Qoa0@4?oooooo00000_oo
ool01?l0003oV9RHo`000?nj^[X4ooooo`Co000000?oEEEEonk^k_ooool02_ooool00oo<c<co0000
ooooo`03ooooo`05o`000?n7QhOoooooojVYZOl000000_ooool01_mVIVKoMgMgooooooo^k^koEEEE
o`0000Sooooo00Ko0000okZj^_ooooook^k^ogMgMol00003ooooo`05o`000?mgMgOoooooojVYZOl0
00000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@;ooooo00KoEEEEogMgMoooooooooooogMg
MomEEED3ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool01Ol0003oQhN7
oooooonYZJWo000000;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00005ooooo`06oeEEEOn7QhOo
k^k^oooooon7QhOo<S8b1Oooool00ol0003oooooooooo`02ooooo`06oeEEEOmgMgOoooooonk^k_mE
EEGo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00Go0000ohN7QoooooooZJVY
o`000002ooooo`0:o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8OooooooEEEEogMgM`;ooooo00[o
MgMgoeEEEOooooooooooofIVI_mgMgOoooooonk^k_mEEEGo00000_ooool01_mEEEGoQhN7onk^k_oo
ooooQhN7oc8b<P;ooooo00Ko0000okZj^_ooooook^k^ogMgMol0000Eooooo`05o`000?n7QhOooooo
ojVYZOl000002_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<03Cooooo000mooooo`03olc<c?lQ8B7o
oooo00;oEEEE00Sooooooc8b<_nj^[[oooooo`000?ooooooZJVYofIVIPCooooo00Go0000oooooooo
oooo^[Zjoa0@400:ooooo`04oc8b<_l0003o0000oiRHV0?ooooo00?o410@o`000?mgMgL00_l00000
2OnHV9Soooooooooooo^k^koEEEEo`000?l@413oc<c<o`000008ooooo`06ojVYZOlQ8B7o0000o`00
0?lb<S;o00000oooool01Ol0003oMgMgo`000?l0003oV9RH00;ooooo00Kok^k^oeEEEOl0003o0000
oeEEEOo^k^h2ooooo`08onk^k_mEEEGo0000o`000?mEEEGok^k^ooooool@4105o`0000Cooooo00?o
410@o`000?l000001?ooool00ol@413o0000ogMgM`02o`00000:oiRHV?ooooooooooonk^k_mEEEGo
0000ob4Q8OnYZJWo0000oa0@40Cooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h3ooooo`03oa0@
4?l0003o000000Cooooo00[ok^k^oeEEEOl0003o8B4QojVYZOl0003o410@ooooooo^k^koEEEE0_l0
00001om4A4Cok^k^oooooooooooo410@o`000?mgMgL00_l000003OnHV9Sooooooa0@4?l0003o8B4Q
o`000?mgMgOo410@o`000?nYZJWoooooonk^k_mEEED00_l000002_mEEEGok^k^ooooooooooook^k^
oeEEEOl0003o410@olc<c?l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_nY
ZJWo8B4Qo`000?l0003o<S8bo`0001Cooooo00?o410@o`000?mgMgL00_l000000onHV9Sooooooooo
o`08ooooo`03o`000?oooooooooo03Kooooo000mooooo`03ojVYZOlb<S;ooooo00?ooooo00CoA4A4
oiRHV?oooooo00000_ooool00onYZJWoEEEEonk^kP02ooooo`05o`000?oooooooooookZj^_l00000
7_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
G?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo03Kooooo000mooooo`?o00000_oo
ool6o`000005ooooool0003o0000o`000?ooool01?l000000ol@413oZJVYooooo`0Mooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0booooo`Co0000
=Oooool0073ooooo0_l0000@ooooo`03oa0@4?l0003ooooo023ooooo00?o410@ooooooooool08?oo
ool00ol@413oooooooooo`0^ooooo`;o0000KOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.197418, -2.12353, \
0.00808352, 0.0274438}}]
}, Open  ]]
}, Open  ]],

Cell["\<\
Surprisingly, there is no discernible difference between the WKB \
and shooting method eigenmodes, even for the lowest-order mode.  Therefore, \
we do not bother using the shooting eigenmodes in the solution shown below; \
the WKB eigenfunctions suffice.  However, we will use the shooting \
eigenfrequencies for the lowest six modes:\
\>", "Text"],

Cell[BoxData[{
    \(\(\[Omega][n_]\  := \ 
        n\ Pi/\[Tau][L]\  /; n \[GreaterEqual] 6;\)\), "\n", 
    \(\(\(\[Omega][n_]\  := \ \[Omega]shooting[n]\  /; \ n < 6;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi][n_, x_]\  := \ \[Psi]WKB[n, x]\ ;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(y0[x_]\  = \ Sin[Pi\ x];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Clear[A];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(A[n_]\  := \ \(A[n]\  = \ 
          NIntegrate[\[Rho][x]\ \[Psi][n, x]\ y0[x], {x, 0, L}]/
            NIntegrate[\[Rho][x]\ \[Psi][n, x]^2, {x, 0, 
                L}]\);\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(y[x_, t_]\  = \ 
        Sum[A[n]\ Cos[\[Omega][n]\ t]\ \[Psi][n, x], {n, 1, 
            10}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.177"],

Cell[TextData[{
  "In Fig. ",
  ButtonBox["6.13",
    ButtonData:>"Fig. 6.13",
    ButtonStyle->"Hyperlink"],
  ", we compare the Galerkin method solution (dashed) with the WKB/shooting \
method solution (solid):"
}], "Text"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -40.625 0 ]
[.5 .63053 40.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -101.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
140.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36897 L
.10458 .42975 L
.14415 .47855 L
.18221 .51463 L
.20178 .52826 L
.21267 .53427 L
.22272 .53879 L
.23293 .54236 L
.23832 .54382 L
.24402 .54504 L
.24641 .54546 L
.24897 .54584 L
.25119 .54611 L
.25361 .54635 L
.25507 .54647 L
.25643 .54655 L
.25773 .54662 L
.2584 .54665 L
.25912 .54667 L
.25983 .54669 L
.26048 .5467 L
.26176 .54672 L
.26293 .54671 L
.26416 .54669 L
.26538 .54666 L
.26607 .54663 L
.26671 .5466 L
.26912 .54646 L
.27131 .54627 L
.27364 .54602 L
.27847 .54532 L
.2838 .54427 L
.29326 .54169 L
.30213 .53843 L
.32232 .52812 L
.34082 .51523 L
.38045 .47762 L
.41855 .43067 L
.45912 .3724 L
.49816 .31194 L
.53966 .24751 L
.57964 .18973 L
.61811 .14196 L
.63759 .1217 L
.65902 .10299 L
.67938 .089 L
.69843 .07949 L
.70884 .0758 L
.71396 .07438 L
Mistroke
.71872 .0733 L
.72301 .07253 L
.72758 .07192 L
.7302 .07166 L
.73148 .07156 L
.73266 .07149 L
.73371 .07143 L
.73487 .07138 L
.73603 .07135 L
.73725 .07132 L
.73856 .07132 L
.73977 .07133 L
.7404 .07134 L
.7411 .07136 L
.74183 .07138 L
.74251 .07141 L
.7449 .07154 L
.74625 .07164 L
.74748 .07175 L
.75203 .07228 L
.7568 .07308 L
.76198 .0742 L
.7668 .07549 L
.77773 .0793 L
.78828 .08411 L
.79823 .08965 L
.81683 .10255 L
.85534 .13894 L
.89632 .1896 L
.93577 .24654 L
.97371 .30514 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36895 L
.10458 .42977 L
.14415 .47853 L
.18221 .51461 L
.20178 .52826 L
.21267 .53429 L
.22272 .53882 L
.23293 .54239 L
.23832 .54385 L
.24402 .54507 L
.24641 .54548 L
.24897 .54586 L
.25119 .54613 L
.25361 .54637 L
.25507 .54648 L
.25643 .54657 L
.25773 .54663 L
.2584 .54666 L
.25912 .54668 L
.25983 .5467 L
.26048 .54671 L
.26176 .54672 L
.26293 .54672 L
.26416 .5467 L
.26538 .54666 L
.26607 .54663 L
.26671 .5466 L
.26912 .54645 L
.27131 .54627 L
.27364 .54601 L
.27847 .54531 L
.2838 .54425 L
.29326 .54166 L
.30213 .5384 L
.32232 .52809 L
.34082 .51523 L
.38045 .47766 L
.41855 .43068 L
.45912 .37236 L
.49816 .3119 L
.53966 .24753 L
.57964 .18979 L
.61811 .14198 L
.63759 .12168 L
.65902 .10293 L
.67938 .08892 L
.69843 .0794 L
.70884 .07573 L
.71396 .07432 L
Mistroke
.71872 .07325 L
.72301 .07249 L
.72758 .07188 L
.7302 .07163 L
.73148 .07154 L
.73266 .07146 L
.73371 .07141 L
.73487 .07137 L
.73603 .07133 L
.73725 .07131 L
.73856 .07131 L
.73977 .07133 L
.7404 .07134 L
.7411 .07136 L
.74251 .07141 L
.74375 .07148 L
.74508 .07156 L
.74748 .07177 L
.74985 .07203 L
.75235 .07236 L
.7568 .07312 L
.76198 .07426 L
.7668 .07556 L
.77773 .07939 L
.78828 .08422 L
.79823 .08977 L
.81683 .10266 L
.85534 .13895 L
.89632 .18947 L
.93577 .24638 L
.97371 .30513 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000=Wooooo2Ooo001Rooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=Cooooo00?o0000ool00?oo0000
0_oo0009ooooo`?oo`000_l0001Mooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0=;ooooo0_l0000Cooooo`;o0000Foooool001[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3?ooooo`?o00005oooool3o`0005Sooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0cOooool2o`0001gooooo0_l0001Fooooo`006?ooool00omEEEGo
IVIVo`000006ooooo`03o`000?oooooooooo0<_ooooo00?oo`00o`000?ooool08?ooool00ooo003o
ooooooooo`1Cooooo`008Oooool00ol0003oooooooooo`39ooooo`;oo`009?ooool2ool005?ooooo
000Qooooo`03o`000?oooooooooo0<Sooooo00?oo`00ooooooooool09_ooool00ooo003ooooooooo
o`1@ooooo`008Oooool3o`000<Kooooo0_oo000Zooooo`;oo`00D?ooool0027ooooo00?o0000oooo
ooooool0aOooool00ooo003oooooooooo`0/ooooo`03ool00?oooooooooo04gooooo000Qooooo`03
o`000?oooooooooo0<?ooooo0_oo000`ooooo`03ool00?l0003ooooo04cooooo000Qooooo`03o`00
0?oooooooooo0<;ooooo00?oo`00ooooooooool0<Oooool00ooo003o0000ooooo`1;ooooo`008Ooo
ool00ol0003oooooooooo`31ooooo`03ool00?oooooooooo03?ooooo00?oo`00o`000?ooool0B_oo
ool0027ooooo00?o0000ooooooooool0`?ooool00ooo003oooooooooo`0eooooo`03ool00?l0003o
oooo04Wooooo000Qooooo`03o`000?oooooooooo0;oooooo00?oo`00ooooooooool0=oooool00ooo
003o0000ooooo`18ooooo`008Oooool3o`000;kooooo00?oo`00ooooooooool0>Oooool00ooo003o
0000ooooo`17ooooo`008Oooool00ol0003oooooooooo`2mooooo`03o`000?oooooooooo03cooooo
00?o0000ooooooooool0AOooool0027ooooo00?o0000ooooooooool0_?ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo04Cooooo000Qooooo`03o`000?oooooooooo0;_ooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`13ooooo`008Oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0@_ooool0027ooooo00?o0000oooooooo
ool0^Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo047ooooo000Qooooo`03o`00
0?oooooooooo0;Sooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`10ooooo`008Ooo
ool3o`000;Oooooo00?oo`00ooooooooool0Aoooool00ol0003oooooooooo`10ooooo`008Oooool0
0ol0003oooooooooo`2gooooo`03ool00?oooooooooo04Sooooo00?oo`00ooooooooool0?oooool0
027ooooo00?o0000ooooooooool0]_ooool00ooo003oooooooooo`19ooooo`03ool00?l0003ooooo
03oooooo000Qooooo`03o`000?oooooooooo0;Gooooo00?oo`00ooooooooool0Boooool00ooo003o
0000ooooo`0nooooo`008Oooool00ol0003oooooooooo`2dooooo`03ool00?oooooooooo04gooooo
00?oo`00o`000?ooool0?Oooool0027ooooo00?o0000ooooooooool0/oooool00ol0003oo`00oooo
o`1?ooooo`03ool00?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo0;?ooooo00?oo`00
ooooooooool0D?ooool00ooo003oooooooooo`0kooooo`008Oooool00ol0003oooooooooo`2boooo
o`03ool00?oooooooooo05;ooooo00?oo`00ooooooooool0>_ooool0027ooooo0ol0002aooooo`03
ool00?oooooooooo05?ooooo00?oo`00o`000?ooool0>_ooool0027ooooo00?o0000ooooooooool0
/?ooool00ooo003oooooooooo`1Eooooo`03ool00?l0003ooooo03Wooooo000Qooooo`03o`000?oo
oooooooo0:oooooo00?o0000ool00?ooool0Eoooool00ooo003o0000ooooo`0hooooo`008Oooool0
0ol0003oooooooooo`2_ooooo`03ool00?oooooooooo05Sooooo00?oo`00ooooooooool0=oooool0
027ooooo00?o0000ooooooooool0[_ooool00ooo003oooooooooo`1Jooooo`03ool00?oooooooooo
03Kooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0:gooooo00?oo`00ooooooooool0G?ooool0
0ooo003oooooooooo`0eooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`1N
ooooo`03o`000?oooooooooo03Cooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00;ooooo0ol0002[ooooo`03o`000?oooooooooo063ooooo00?o0000
ooooooooool0<oooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00?ooooo00?o0000ooooooooool0Zoooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo03?ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo03;ooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool0I?ooool00ol0003ooooooooo
o`0aooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0<Ooo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003ooooooooo
o`2Xooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0<?ooool0027ooooo00?o0000
ooooooooool0Yoooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo02oooooo000Qoooo
o`03o`000?oooooooooo0:Kooooo00?o0000ool00?ooool0JOooool00ooo003oooooooooo`0_oooo
o`008Oooool3o`000:Kooooo00?o0000ool00?ooool0JOooool00ooo003o0000ooooo`0_ooooo`00
8Oooool00ol0003oooooooooo`2Uooooo`03o`000?oo003ooooo06_ooooo00?oo`00o`000?ooool0
;_ooool0027ooooo00?o0000ooooooooool0Y?ooool00ol0003oo`00ooooo`1]ooooo`03ool00?oo
oooooooo02gooooo000Qooooo`03o`000?oooooooooo0:?ooooo00?o0000ool00?ooool0Koooool0
0ooo003oooooooooo`0/ooooo`008Oooool00ol0003oooooooooo`2Sooooo`03ool00?oooooooooo
06oooooo00?oo`00o`000?ooool0;?ooool0027ooooo00?o0000ooooooooool0X_ooool00ooo003o
ooooooooo`1aooooo`03ool00?oooooooooo02_ooooo000Qooooo`03o`000?oooooooooo0:7ooooo
00?o0000ool00?ooool0Loooool00ooo003oooooooooo`0Zooooo`008Oooool3o`000:7ooooo00?o
o`00ooooooooool0Loooool00ooo003o0000ooooo`0Zooooo`008Oooool00ol0003oooooooooo`2P
ooooo`03ool00?oooooooooo07Gooooo00?oo`00ooooooooool0:Oooool0027ooooo00?o0000oooo
ooooool0Woooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo02Sooooo000Qooooo`03
o`000?oooooooooo09kooooo00?oo`00ooooooooool0NOooool00ooo003oooooooooo`0Wooooo`00
8Oooool00ol0003oooooooooo`2Nooooo`03ool00?oooooooooo07Wooooo00?oo`00ooooooooool0
9oooool0027ooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`1kooooo`03ool00?oo
oooooooo02Kooooo000Qooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool0OOooool0
0ol0003oooooooooo`0Uooooo`008Oooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
07gooooo00?o0000ooooooooool09Oooool0027ooooo0ol0002Kooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool09?ooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`00
0003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0=?ooool4o`000003oa0@4?oooooooooo
00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0=oooool00ol0003oooooooooo`03
ooooo`Go00006oooool0027ooooo00?o0000ooooooooool0?Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo03Kooooo00?o0000ooooooooool00oooool01OnHV9So8B4Qonk^k_ooooooA4A401_ooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ
8B7ok^k^01cooooo000Qooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo03kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0>?ooool00ol0003ooooooooo
o`03ooooo`03oiRHV?lQ8B7ok^k^01_ooooo000Qooooo`03o`000?oooooooooo03gooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0?oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<03Wooooo00?o0000ooooooooool01?ooool00omgMgOoIVIVooooo`0Jooooo`00
8Oooool00ol0003oooooooooo`0mooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0>Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo03cooooo00?oo`00ooooooooool01?ooool00ol0003o
ooooooooo`0Iooooo`008Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool00_ooool00ol0003oo`00ooooo`0jooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0??ooool02?oo003o0000ooooool0003o^[Zj
oooooonHV9So410@6oooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000nooooo`03oeEEEOmVIVKo000000?ooooo00?o0000ool00?ooool0>Ooo
ool00omEEEGoIVIVo`00000=ooooo`Co0000??ooool01ooo003ooooooiRHV?l@413o0000ob4Q8Oo<
c<`06oooool0027ooooo00?o0000ooooooooool0U_ooool00ooo003oooooooooo`2:ooooo`03ool0
0?oooooooooo01kooooo000Qooooo`03o`000?oooooooooo09Gooooo00?o0000ool00?ooool0S?oo
ool00ooo003oooooooooo`0Mooooo`008Oooool00ol0003oooooooooo`2Eooooo`03ool00?oooooo
oooo08cooooo00?oo`00ooooooooool07Oooool0027ooooo00?o0000ooooooooool0U?ooool00ooo
003oooooooooo`2>ooooo`03ool00?oooooooooo01;ooooo0_l00002ooooo`;o00001?ooool0027o
oooo00?o0000ooooooooool0Toooool00ol0003oo`00ooooo`2@ooooo`03ool00?oooooooooo017o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0003o0000
09?o000000?oo`00o`000?l00000TOl000000ooo003o0000o`000005o`0000cooooo00CogMgMo`00
0?l@413oc<c<1Oooool0027ooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ool0
0?ooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Co8B4QogMg
MomgMgOo<S8b1Oooool0027ooooo00?o0000oooooooo0000TOooool00ooo003oooooooooo`2Voooo
o`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?ooooooo`00093ooooo00?oo`00oooooooo
ool0/Oooool0027ooooo00Co0000ooooooooooooo`00S_ooool00ooo003o0000ooooo`2booooo`00
8Oooool01Ol0003oooooooooool0003oo`0008gooooo00?o0000ooooooooool0/_ooool0027ooooo
00Ko0000ooooooooooooooooo`000?oo002;ooooo`03o`000?oooooooooo0;?ooooo000Qooooo`?o
00000_ooool00ooo003oooooooooo`29ooooo`03o`000?oooooooooo0;?ooooo000Qooooo`03o`00
0?oooooooooo00;ooooo00?o0000ool00?ooool0R?ooool00ol0003oooooooooo`2dooooo`008Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oo003ooooo08Kooooo00?o0000ooooooooool0]Ooo
ool0027ooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`24ooooo`03o`000?oooooo
oooo0;Kooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ool00?ooool0Q?ooool00ol0
003oooooooooo`2fooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo003ooooo08;o
oooo00?o0000ooooooooool0]oooool0027ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`20ooooo`03ool00?oooooooooo0;Sooooo000Qooooo`?o00001_ooool00ol0003ooooooooo
o`20ooooo`03ool00?oooooooooo0;Sooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0O_ooool00ooo003oooooooooo`2iooooo`008Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo07gooooo00?oo`00ooooooooool0^_ooool0027ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`1looooo`03ool00?oooooooooo0;[ooooo000Qooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0N_ooool00ooo003oooooooooo`2kooooo`008Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo07Wooooo00?oo`00ooooooooool0_?oo
ool0027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1hooooo`03ool00?oooooo
oooo0;cooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0M_ooool00ooo
003oooooooooo`2mooooo`008Oooool3o`0000cooooo00?oo`00ooooooooool0M?ooool00ol0003o
o`00ooooo`2nooooo`008Oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo07Cooooo
00?oo`00ooooooooool0__ooool0027ooooo00?o0000ooooooooool03Oooool00ooo003ooooooooo
o`1booooo`03ool00?oooooooooo0;oooooo000Qooooo`03o`000?oooooooooo00kooooo00?oo`00
ooooooooool0L?ooool00ol0003oo`00ooooo`30ooooo`008Oooool00ol0003oooooooooo`0?oooo
o`03ool00?oooooooooo06oooooo00?oo`00ooooooooool0`?ooool0027ooooo00?o0000oooooooo
ool03oooool00ooo003oooooooooo`1^ooooo`03o`000?oooooooooo0<7ooooo000Qooooo`03o`00
0?oooooooooo013ooooo00?oo`00ooooooooool0K?ooool00ol0003oooooooooo`32ooooo`008Ooo
ool3o`00017ooooo00?oo`00ooooooooool0Joooool00ol0003oooooooooo`32ooooo`008Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oo003ooooo06[ooooo00?o0000ooooooooool0`oooool0
027ooooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`1Xooooo`03o`000?oooooooooo
0<Cooooo000Qooooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool0Ioooool00ol0003o
ooooooooo`34ooooo`008Oooool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo06Gooooo
00?o0000ooooooooool0aOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool05?ooool00ol0003o
o`00ooooo`1Tooooo`03o`000?oooooooooo0<Kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo06;ooooo00?oo`00o`000?ooool0aoooool000Oooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0000Fooooo`03o`000?oooooooooo067o
oooo00?oo`00ooooooooool0aoooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Oooooo`03
ool00?oooooooooo0<Sooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Ooooo
o`03ool00?oooooooooo0<Sooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0GOooool00ooo
003oooooooooo`39ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05_ooooo00?oo`00oooo
ooooool0b_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo05Wooooo00?oo`00ooooooooool0boooool0027o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Gooooo`03ool00?oooooooooo0<co
oooo000Qooooo`03o`000?oooooooooo01_ooooo00?oo`00ooooooooool0Eoooool00ooo003ooooo
ooooo`3<ooooo`008Oooool3o`0001_ooooo00?oo`00o`000?ooool0E_ooool00ooo003ooooooooo
o`3=ooooo`008Oooool00ol0003oooooooooo`0Looooo`03ool00?l0003ooooo05Cooooo00?oo`00
ooooooooool0c_ooool0027ooooo00?o0000ooooooooool07Oooool00ooo003o0000ooooo`1Boooo
o`03ool00?oooooooooo0<oooooo000Qooooo`03o`000?oooooooooo01kooooo00?oo`00o`000?oo
ool0D?ooool00ooo003oooooooooo`3@ooooo`008Oooool00ol0003oooooooooo`0Oooooo`03ool0
0?oooooooooo04oooooo00?o0000ooooooooool0d?ooool0027ooooo00?o0000ooooooooool08?oo
ool00ooo003oooooooooo`1=ooooo`03o`000?oooooooooo0=7ooooo000Qooooo`03o`000?oooooo
oooo027ooooo00?oo`00ooooooooool0Boooool00ol0003oooooooooo`3Booooo`008Oooool3o`00
02;ooooo00?oo`00ooooooooool0BOooool00ol0003oooooooooo`3Cooooo`008Oooool00ol0003o
ooooooooo`0Sooooo`03ool00?oooooooooo04Kooooo0_l0003Fooooo`008Oooool00ol0003ooooo
ooooo`0Tooooo`03ool00?oooooooooo04Cooooo00?o0000ooooooooool0e_ooool0027ooooo00?o
0000ooooooooool09Oooool00ooo003oooooooooo`12ooooo`03o`000?oooooooooo0=Oooooo000Q
ooooo`03o`000?oooooooooo02Kooooo00?oo`00ooooooooool0@?ooool00ooo003oooooooooo`3H
ooooo`008Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03kooooo00?oo`00oooo
ooooool0fOooool0027ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0looooo`03
ool00?oooooooooo0=[ooooo000Qooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
>_ooool00ooo003oooooooooo`3Kooooo`008Oooool3o`0002[ooooo00?o0000ooooooooool0>?oo
ool00ooo003oooooooooo`3Looooo`008Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo03Kooooo00?oo`00ooooooooool0gOooool0027ooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0dooooo`03ool00?oooooooooo0=kooooo000Qooooo`03o`000?oooooooooo02go
oooo00?o0000ool00?ooool0<_ooool00ooo003oooooooooo`3Oooooo`008Oooool00ol0003ooooo
ooooo`0^ooooo`03ool00?oooooooooo033ooooo00?oo`00ooooooooool0h?ooool0027ooooo00?o
0000ooooooooool0;oooool2ool002kooooo00?o0000ool00?ooool0h_ooool0027ooooo00?o0000
ooooooooool0<Oooool00ooo003oooooooooo`0Zooooo`03o`000?oo003ooooo0>?ooooo000Qoooo
o`?o0000<_ooool2ool002Wooooo00?o0000ool00?ooool0i?ooool0027ooooo00?o0000oooooooo
ool0=?ooool00ooo003oooooooooo`0Uooooo`03o`000?oooooooooo0>Gooooo000Qooooo`03o`00
0?oooooooooo03Gooooo0_oo000Sooooo`;o0000j?ooool0027ooooo00?o0000ooooooooool0=ooo
ool00ooo003oooooooooo`0Mooooo`?o0000j_ooool0027ooooo00?o0000ooooooooool0>?ooool3
ool001[ooooo0_l0003]ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000oooo
ooooool0>oooool01?oo003o0000o`000?l0000Dooooo`;oo`00koooool001[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo0_oo003aoooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo043ooooo1ol00003ooooo`Oo
o`00loooool001[ooooo00?o0000ooooooooool01?ooool3o`0004Gooooo1Ooo003jooooo`006_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002_ooooo`03ogMgMomVIVKooooo
01Oooooo00?oIVIVogMgMoooool0W?ooool008kooooo0ol0000Dooooo`03ob4Q8OoMgMgooooo00Ko
oooo00?ogMgMoa0@4?o^k^h06?ooool00oo^k^ko410@omgMg@2Looooo`00Q_ooool01on7QhOo0000
oeEEEOmVIVKo0000oc8b<_o^k^h00_ooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o0000
odA4A?nj^[X00oooool00onHV9SoEEEEooooo`06ooooo`03oeEEEOnHV9Sooooo00;ooooo1Ol00009
ooooo`03oeEEEOnYZJWooooo00;ooooo00Ko^[ZjodA4A?ooooooooooohN7QomVIVHDooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0Poooool008Kooooo00Oo410@omgMgOmgMgOo8B4Qoooooon7QhOoIVIV
00;ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000
omgMgOooool01Oooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@02_oo
ool01_mEEEGoV9RHoooooooooooo410@okZj^P;ooooo00?ok^k^o`000?ooool02oooool6o`0000;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`23ooooo`00Q_ooool01ol0003oooooomgMgOlb<S;ooooo
onk^k_l@41000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo0_mgMgL6
ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool0
0004ooooo`03o`000?oooooooooo01;ooooo00Go410@oooooooooooooooooa0@4023ooooo`00Q_oo
ool01?mEEEGoZJVYooooool00002ooooo`04o`000?ooooooooooo`0000gooooo00?o0000oooooooo
ool01_ooool00oo^k^ko410@onk^kP05ooooo`03oc8b<_oooooooooo00Cooooo00?oV9RHob4Q8Oo^
k^h02oooool01?n7QhOoIVIVooooool00004ooooo`03o`000?oooooooooo00[ooooo1_l00002oooo
o`05o`000?ooooooooooooooool00000Poooool008Kooooo00?ogMgMob4Q8Oo^k^h00oooool01?l0
003oooooo`000?l0000=ooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool0
0ol0003ok^k^ooooo`05ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo00000ooo
ool00oo^k^ko0000ooooo`0Cooooo`05o`000?ooooooooooooooool00000Poooool008Oooooo00?o
V9RHogMgMoooool00_ooool00ol0003oooooooooo`0<ooooo`03oa0@4?l0003o000000?o00001_oo
ool00ooMgMgo410@ooooo`04ooooo`03oeEEEOmgMgOooooo00Kooooo00?o0000ooooooooool02?oo
ool7o`000003oooooomgMgOoEEEE01Cooooo00Go410@oooooooooooooooooa0@4023ooooo`00WOoo
ool00ol0003oooooooooo`08ooooo`03oeEEEOnHV9Sooooo00?ooooo00?ogMgMoa0@4?o^k^h00_oo
ool01Ol0003o^[ZjoooooonHV9So410@017ooooo00?ok^k^oa0@4?oMgMd05?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg08?ooooo002Mooooo`03o`000?oooooooooo00Sooooo00?o^[ZjodA4A?ooool0
1?ooool02OmgMgOoIVIVooooooooooooV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`03ofIVI_mgMgOo
oooo01Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP23ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36459 L
.10458 .41983 L
.14415 .46264 L
.16408 .47998 L
.18221 .49298 L
.20178 .50387 L
.21254 .5084 L
.22272 .51171 L
.23241 .51398 L
.2373 .51479 L
.24012 .51516 L
.24269 .51543 L
.24504 .51562 L
.24728 .51576 L
.2485 .51581 L
.24964 .51585 L
.25088 .51588 L
.25158 .51589 L
.25221 .5159 L
.25336 .5159 L
.25442 .51589 L
.25558 .51587 L
.2568 .51583 L
.25787 .51578 L
.25887 .51573 L
.26113 .51559 L
.26373 .51536 L
.26614 .51509 L
.27158 .5143 L
.27638 .51338 L
.28148 .51218 L
.2903 .50957 L
.30004 .50593 L
.31939 .49637 L
.34024 .48284 L
.38138 .44759 L
.42101 .40533 L
.45912 .36013 L
.49968 .31074 L
.53872 .26533 L
.58022 .22268 L
.60102 .2044 L
.6202 .18974 L
.64007 .177 L
.65867 .16749 L
.67743 .16036 L
.68738 .15761 L
.69293 .15638 L
.69807 .15544 L
Mistroke
.70298 .15473 L
.7082 .15415 L
.71119 .15391 L
.71265 .15382 L
.714 .15374 L
.7152 .15369 L
.71652 .15364 L
.71785 .1536 L
.71857 .15359 L
.71924 .15358 L
.7205 .15356 L
.7212 .15356 L
.72186 .15356 L
.72305 .15358 L
.72433 .1536 L
.72546 .15363 L
.72653 .15366 L
.72895 .15378 L
.73157 .15394 L
.73396 .15413 L
.73935 .15471 L
.7441 .15538 L
.74918 .15626 L
.75831 .15826 L
.77902 .16471 L
.80041 .17393 L
.82057 .18476 L
.85909 .21017 L
.90006 .24227 L
.93952 .27623 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36461 L
.10458 .41979 L
.14415 .46266 L
.16408 .48001 L
.18221 .49301 L
.20178 .50387 L
.21254 .50838 L
.22272 .51169 L
.23241 .51395 L
.2373 .51476 L
.24012 .51513 L
.24269 .5154 L
.24504 .5156 L
.24728 .51574 L
.2485 .51579 L
.24964 .51583 L
.25088 .51586 L
.25158 .51587 L
.25221 .51588 L
.25336 .51588 L
.25442 .51587 L
.25558 .51585 L
.2568 .51582 L
.25787 .51577 L
.25887 .51572 L
.26113 .51558 L
.26373 .51535 L
.26614 .51509 L
.27158 .5143 L
.27638 .51339 L
.28148 .5122 L
.2903 .5096 L
.30004 .50595 L
.31939 .49639 L
.34024 .48284 L
.38138 .44755 L
.42101 .40533 L
.45912 .36018 L
.49968 .31078 L
.53872 .2653 L
.58022 .2226 L
.60102 .20434 L
.6202 .18972 L
.64007 .17703 L
.65867 .16756 L
.67743 .16045 L
.68738 .1577 L
.69293 .15647 L
.69807 .15553 L
Mistroke
.70298 .15481 L
.7082 .15423 L
.71119 .15398 L
.71265 .15388 L
.714 .15381 L
.7152 .15375 L
.71652 .1537 L
.71785 .15366 L
.71857 .15364 L
.71924 .15363 L
.7205 .15361 L
.7212 .15361 L
.72186 .15361 L
.72305 .15362 L
.72433 .15364 L
.72546 .15367 L
.72653 .1537 L
.72895 .15381 L
.73157 .15396 L
.73396 .15415 L
.73935 .15471 L
.7441 .15537 L
.74918 .15623 L
.75831 .15821 L
.76917 .16124 L
.77902 .16461 L
.81906 .18378 L
.85758 .20909 L
.89855 .24115 L
.938 .27497 L
.97594 .30879 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0coooool2ool000So0000
1ooo001Tooooo`008Oooool00ol0003oooooooooo`3;ooooo`Coo`004Oooool6ool005kooooo000Q
ooooo`03o`000?oooooooooo0<Sooooo0ooo000Kooooo`;oo`0000?o0000ooooooooool0FOooool0
027ooooo00?o0000ooooooooool0aOooool2o`000003ool00?oooooooooo01kooooo00?oo`00o`00
0?l00000FOooool0027ooooo0ol00033ooooo`;o00009_ooool3o`0005Kooooo000Qooooo`03o`00
0?oooooooooo0<7ooooo0_l0000[ooooo`;o0000E?ooool0027ooooo00?o0000ooooooooool0_ooo
ool2o`0002oooooo0_l0001Booooo`008Oooool00ol0003oooooooooo`2mooooo`;oo`00<oooool2
ool0053ooooo000Qooooo`03o`000?oooooooooo0;cooooo00?oo`00ooooooooool0=?ooool00ol0
003oo`00ool0001>ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`2jooooo`;oo`00>Oooool0
0ol0003oo`00ool0001<ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0^Oooool00ooo003oooooooooo`0j
ooooo`;o000000?oo`00ooooooooool0BOooool000Go00000_ooool01Ol@413ooooooooooooooooo
410@013ooooo00?o0000ooooooooool00_ooool3o`000;Oooooo0_oo000oooooo`03o`000?oo003o
oooo04Wooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo0;Kooooo00?oo`00ooooooooool0@Oooool2ool004Sooooo0007oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o
0000ooooooooool0]Oooool00ooo003oooooooooo`13ooooo`03o`000?oo003ooooo04Kooooo0007
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0;Cooooo00?oo`00ooooooooool0A_ooool00ooo003o0000ooooo`14ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`2cooooo`03ool00?oooooooooo04Sooooo00?oo`00o`000?ooool0@oooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`2aooooo`;oo`00C?oo
ool00ooo003o0000o`000012ooooo`008Oooool00ol0003oooooooooo`2`ooooo`03o`000?oooooo
oooo04oooooo0_l00010ooooo`008Oooool00ol0003oooooooooo`2^ooooo`;o0000E?ooool00ol0
003oooooooooo`0mooooo`008Oooool3o`000:gooooo00?o0000ooooooooool0EOooool00ol0003o
ooooooooo`0looooo`008Oooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo05Oooooo
00?o0000ooooooooool0>oooool0027ooooo00?o0000ooooooooool0Zoooool00ol0003ooooooooo
o`1Iooooo`03o`000?oooooooooo03[ooooo000Qooooo`03o`000?oooooooooo0:_ooooo00?o0000
ooooooooool0F_ooool2ool003[ooooo000Qooooo`03o`000?oooooooooo0:[ooooo00?o0000oooo
ooooool0GOooool00ooo003oooooooooo`0gooooo`008Oooool00ol0003oooooooooo`2Yooooo`03
ool00?oooooooooo05oooooo0_oo000gooooo`008Oooool00ol0003oooooooooo`2Xooooo`03ool0
0?oooooooooo067ooooo00?o0000ool00?ooool0=Oooool0027ooooo0ol0002Wooooo`03ool00?oo
oooooooo06?ooooo00?o0000ool00?ooool0=?ooool0027ooooo00?o0000ooooooooool0Y_ooool0
0ooo003oooooooooo`1Uooooo`03o`000?oo003ooooo03?ooooo000Qooooo`03o`000?oooooooooo
0:Gooooo00?oo`00ooooooooool0Ioooool00ol0003oo`00ooooo`0booooo`008Oooool00ol0003o
ooooooooo`2Tooooo`03ool00?oooooooooo06[ooooo00?oo`00ooooooooool0<?ooool0027ooooo
00?o0000ooooooooool0Xoooool00ooo003oooooooooo`1/ooooo`03ool00?oooooooooo02oooooo
000Qooooo`03o`000?oooooooooo0:;ooooo00?oo`00ooooooooool0K_ooool00ooo003ooooooooo
o`0^ooooo`008Oooool00ol0003oooooooooo`2Qooooo`03ool00?oooooooooo073ooooo00?oo`00
ooooooooool0;Oooool0027ooooo00?o0000ooooooooool0X?ooool00ooo003oooooooooo`1boooo
o`;o0000;Oooool0027ooooo0ol0002Oooooo`03ool00?oooooooooo07Gooooo00?o0000oooooooo
ool0:_ooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
00Oooooo00?oo`00ooooooooool0<Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd0<Oooool00ol0003oooooooooo`09ooooo`Go00006oooool0
027ooooo00?o0000ooooooooool0?Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo03kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo037ooooo00?o0000
ooooooooool02?ooool01OnHV9So8B4Qonk^k_ooooooA4A401_ooooo000Qooooo`03o`000?oooooo
oooo03gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`08ooooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo00kooooo00?oMgMgoc8b<_ooool0<oooool2o`0000Wooooo00?oV9RHob4Q8Oo^k^h06ooo
ool0027ooooo00?o0000ooooooooool0?Oooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0=Oooool2ool000Wo
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0iooooo`03
ool00?oooooooooo00Oooooo00?o0000ooooooooool06Oooool0027ooooo0ol0000mooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03[o
oooo00?oo`00ooooooooool00_ooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`03
o`000?oooooooooo03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000?_ooool00omE
EEGoIVIVo`000005ooooo`03o`000?oooooooooo03Oooooo00?oEEEEofIVI_l000003Oooool4o`00
03[ooooo00Woo`00oooooooooooooooooiRHV?l@413o0000ob4Q8Oo<c<`06oooool0027ooooo00?o
0000ooooooooool0Uoooool00ooo003o0000ooooo`27ooooo`;oo`008Oooool0027ooooo00?o0000
ooooooooool0Uoooool00ooo003oooooooooo`29ooooo`03ool00?oooooooooo01kooooo000Qoooo
o`03o`000?oooooooooo09Kooooo00?oo`00ooooooooool0Roooool00ooo003oooooooooo`0Moooo
o`008Oooool00ol0003oooooooooo`2Eooooo`03ool00?oooooooooo08gooooo00?oo`00oooooooo
ool04_ooool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`2Dooooo`03ool0
0?oooooooooo08oooooo00?oo`00ooooooooool04Oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgM
g@Cooooo000Joooooigo000000?oo`00o`000?l00000TOl000000ooo003o0000o`000005o`0000co
oooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ooo003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027o
oooo0_l0000=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool01?lQ8B7o
MgMgogMgMolb<S85ooooo`008Oooool00ol0003oooooo`00002Aooooo`03ool00?oooooooooo0:Ko
oooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooool00000T?ooool00ooo003ooooo
ooooo`2aooooo`008Oooool01?l0003oooooooooool0002>ooooo`03ool00?oooooooooo0;;ooooo
000Qooooo`05o`000?ooooooooooooooool00000S?ooool00ooo003oooooooooo`2cooooo`008Ooo
ool01Ol0003ooooooooooooooooo000008_ooooo00?oo`00ooooooooool0]?ooool0027ooooo0ol0
0002ooooo`03ool00?oooooooooo08Oooooo00?o0000ooooooooool0]Oooool0027ooooo00?o0000
ooooooooool00_ooool00ooo003o0000ooooo`26ooooo`03o`000?oooooooooo0;Kooooo000Qoooo
o`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0QOooool00ol0003oooooooooo`2foooo
o`008Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo08?ooooo00?o0000oooooooo
ool0]oooool0027ooooo00?o0000ooooooooool01?ooool00ooo003o0000ooooo`22ooooo`03o`00
0?oooooooooo0;Sooooo000Qooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool0P?oo
ool00ol0003oooooooooo`2iooooo`008Oooool00ol0003oooooooooo`06ooooo`03ool00?oooooo
oooo07kooooo00?o0000ooooooooool0^_ooool0027ooooo0ol00007ooooo`03ool00?oooooooooo
07cooooo00?o0000ooooooooool0^oooool0027ooooo00?o0000ooooooooool01oooool00ooo003o
ooooooooo`1kooooo`;oo`00_Oooool0027ooooo00?o0000ooooooooool02?ooool00ooo003ooooo
ooooo`1jooooo`03ool00?oooooooooo0;cooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o
o`00ooooooooool0N?ooool00ooo003oooooooooo`2mooooo`008Oooool00ol0003oooooooooo`09
ooooo`03o`000?oo003ooooo07Oooooo00?oo`00ooooooooool0__ooool0027ooooo00?o0000oooo
ooooool02_ooool00ol0003oo`00ooooo`1eooooo`03ool00?oooooooooo0;oooooo000Qooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0Loooool00ol0003oo`00ooooo`30ooooo`00
8Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo077ooooo00?o0000ool00?ooool0
`Oooool0027ooooo0ol0000=ooooo`03o`000?oooooooooo06oooooo00?o0000ool00?ooool0`_oo
ool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1^ooooo`03ool00?oooooo
oooo0<;ooooo000Qooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0KOooool00ol0
003oo`00ooooo`33ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06_o
oooo00?o0000ool00?ooool0a?ooool0027ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`1Yooooo`03o`000?oo003ooooo0<Gooooo000Qooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0Ioooool00ol0003oo`00ooooo`36ooooo`008Oooool00ol0003oooooooooo`0B
ooooo`03ool00?oooooooooo06Gooooo00?o0000ooooooooool0aoooool0027ooooo0ol0000Boooo
o`03ool00?oooooooooo06Cooooo00?o0000ooooooooool0b?ooool0027ooooo00?o0000oooooooo
ool04oooool00ooo003oooooooooo`1Sooooo`03o`000?oooooooooo0<Sooooo000Qooooo`03o`00
0?oooooooooo01Cooooo00?oo`00ooooooooool0HOooool00ol0003oooooooooo`39ooooo`008Ooo
ool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo05oooooo00?o0000ooooooooool0b_oo
ool0027ooooo00?o0000ooooooooool05_ooool00ooo003oooooooooo`1Mooooo`03o`000?oooooo
oooo0<_ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0Fooo
ool00ol0003oooooooooo`3<ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool05oooool00ooo003ooooooooo
o`1Jooooo`03ool00?oooooooooo0<gooooo0007ooooo`05oa0@4?ooooooooooooooool@41004?oo
ool00ol0003oooooooooo`02ooooo`?o00006?ooool00ooo003oooooooooo`1Hooooo`03o`000?oo
003ooooo0<kooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8boooo
o`03ooooo`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool0Eoooool00ooo003ooooooooo
o`3>ooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo01[ooooo00?oo`00ooooooooool0EOooool00ooo003ooooo
ooooo`3?ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Kooooo`03ool00?oooooooooo05?ooooo00?oo`00ooooooooool0
d?ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool07?ooool00ooo003oooooooooo`1Aooooo`03ool00?oooooooooo0=7ooooo
0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`1?ooooo`03ool00?oooooooooo0=;ooooo000Qooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool0COooool00ooo003oooooooooo`3Cooooo`008Oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo04[ooooo0_oo003Fooooo`008Oooool3o`00
023ooooo00?o0000ooooooooool0B?ooool00ooo003oooooooooo`3Fooooo`008Oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo04Kooooo00?oo`00ooooooooool0eoooool0027ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`14ooooo`03ool00?oooooooooo0=Sooooo
000Qooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0@_ooool00ol0003ooooooooo
o`3Iooooo`008Oooool00ol0003oooooooooo`0Tooooo`03ool00?oooooooooo03oooooo0_l0003L
ooooo`008Oooool00ol0003oooooooooo`0Uooooo`03ool00?oooooooooo03gooooo00?o0000oooo
ooooool0g?ooool0027ooooo00?o0000ooooooooool09_ooool00ooo003oooooooooo`0kooooo`03
o`000?oooooooooo0=gooooo000Qooooo`?o00009oooool00ooo003oooooooooo`0iooooo`03o`00
0?oooooooooo0=kooooo000Qooooo`03o`000?oooooooooo02Sooooo00?oo`00ooooooooool0=ooo
ool00ol0003oooooooooo`3Oooooo`008Oooool00ol0003oooooooooo`0Yooooo`;oo`00=_ooool0
0ooo003oooooooooo`3Pooooo`008Oooool00ol0003oooooooooo`0[ooooo`03ool00?oooooooooo
037ooooo0_oo003Sooooo`008Oooool00ol0003oooooooooo`0/ooooo`;oo`00<?ooool00ooo003o
ooooooooo`3Sooooo`008Oooool00ol0003oooooooooo`0^ooooo`03ool00?oooooooooo02_ooooo
0_oo003Vooooo`008Oooool00ol0003oooooooooo`0_ooooo`;oo`00:_ooool00ooo003ooooooooo
o`3Vooooo`008Oooool00ol0003oooooooooo`0aooooo`;o00009_ooool2ool00>Wooooo000Qoooo
o`?o0000<oooool2o`0002;ooooo0_oo003[ooooo`008Oooool00ol0003oooooooooo`0eooooo`;o
00007_ooool2ool00>gooooo000Qooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
6Oooool00ol0003oo`00ooooo`3^ooooo`008Oooool00ol0003oooooooooo`0hooooo`;o00000_oo
000Dooooo`?o0000lOooool0027ooooo00?o0000ooooooooool0>oooool00ol0003oo`00ool00002
ool000[ooooo1_l0003dooooo`008Oooool00ol0003oooooooooo`10ooooo`[oo`00n_ooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
6?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5ooooo`006_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
AOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000H
ooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00:Cooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2Wooooo`00Poooool3
o`0001Cooooo00?o8B4QomgMgOooool01_ooool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@413o
gMgM0:Oooooo001kooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP02ooooo`03o`000?oo
oooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03oiRHV?mEEEGooooo00Kooooo
00?oEEEEoiRHV?ooool00_ooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool01_nj^[[oA4A4
ooooooooooooQhN7ofIVIQCooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@1eooooo`00Nooo
ool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00_ooool00ol0003oooooooooo`0;ooooo`05
oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ogMgMooooo`05ooooo`03o`000?oooooooooo
00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj
0_ooool00oo^k^ko0000ooooo`0;ooooo`Ko00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`1doooo
o`00Noooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@41000_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Kooooo0_mgMgL6ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RH
ob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool00004ooooo`03o`000?oooooooooo01;ooooo00Go
410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003o
ooooooooo`1cooooo`00Noooool01?mEEEGoZJVYooooool00002ooooo`04o`000?ooooooooooo`00
00gooooo00?o0000ooooooooool01_ooool00oo^k^ko410@onk^kP05ooooo`03oc8b<_oooooooooo
00Cooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7QhOoIVIVooooool00004ooooo`03o`000?oooooo
oooo00[ooooo1_l00002ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooo
oooooooo000000Oooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00?ogMgMob4Q8Oo^k^h00ooo
ool01?l0003oooooo`000?l0000=ooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool0
1?ooool00ol0003ok^k^ooooo`05ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo
00000oooool00oo^k^ko0000ooooo`0Cooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003ooooooooooooooooo000000Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c01eooooo`00O?ooool0
0onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo00cooooo00?o410@o`000?l000000ol00006
ooooo`03omgMgOl@413ooooo00Cooooo00?oEEEEogMgMoooool01_ooool00ol0003oooooooooo`08
ooooo`Oo000000?oooooogMgMomEEED05?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
410@oooooooooooooooooa0@4004ooooo`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oo
oooooooo00Sooooo00?oEEEEoiRHV?ooool00oooool00ooMgMgo410@onk^kP02ooooo`05o`000?nj
^[[ooooooiRHV?l@41004Oooool00oo^k^ko410@omgMg@0Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool0Moooool009;o
oooo00?o0000ooooooooool02?ooool00onj^[[oA4A4ooooo`04ooooo`09ogMgMomVIVKooooooooo
oonHV9So410@o`000?lQ8B7oc<c<017ooooo00?oIVIVogMgMoooool05?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co0000M_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .35011 L
.10458 .38858 L
.12507 .40359 L
.14415 .41504 L
.16254 .42362 L
.17277 .42734 L
.18221 .4301 L
.19242 .43238 L
.19781 .43329 L
.20351 .43404 L
.2059 .43428 L
.20846 .4345 L
.21068 .43466 L
.2131 .4348 L
.21456 .43486 L
.21592 .43491 L
.21722 .43494 L
.21795 .43495 L
.21861 .43496 L
.21986 .43497 L
.22056 .43497 L
.22121 .43497 L
.2224 .43496 L
.22365 .43494 L
.22487 .43491 L
.2262 .43487 L
.22861 .43477 L
.23096 .43463 L
.23313 .43448 L
.23806 .43403 L
.24329 .43339 L
.25201 .43199 L
.26163 .42996 L
.28097 .42451 L
.30183 .41683 L
.34297 .39773 L
.38259 .37701 L
.4207 .35769 L
.46126 .34017 L
.48 .33366 L
.50031 .32793 L
.51141 .32543 L
.52165 .32352 L
.53144 .32207 L
.53686 .32142 L
.5418 .32092 L
.54632 .32054 L
.55124 .32022 L
.55394 .32008 L
Mistroke
.55644 .31997 L
.55883 .31989 L
.56016 .31985 L
.56138 .31982 L
.56251 .3198 L
.56376 .31978 L
.56501 .31977 L
.56633 .31976 L
.5675 .31976 L
.56874 .31976 L
.56992 .31977 L
.57099 .31978 L
.5721 .31979 L
.57313 .31981 L
.57546 .31986 L
.57751 .31992 L
.57969 .32 L
.5846 .32024 L
.58909 .32051 L
.5992 .32135 L
.60812 .32231 L
.61749 .32352 L
.65566 .33 L
.69627 .33785 L
.71504 .34112 L
.73537 .34407 L
.7465 .34535 L
.75675 .34629 L
.76655 .34694 L
.77149 .34718 L
.77409 .34728 L
.77692 .34737 L
.77963 .34744 L
.78083 .34746 L
.78215 .34748 L
.78339 .3475 L
.78455 .34751 L
.78578 .34752 L
.78647 .34752 L
.7871 .34752 L
.78822 .34752 L
.78927 .34752 L
.79041 .34751 L
.79163 .3475 L
.79292 .34748 L
.79413 .34746 L
.7964 .34741 L
.79893 .34735 L
.80162 .34725 L
.80643 .34704 L
Mistroke
.81161 .34674 L
.81731 .34633 L
.82745 .34538 L
.83673 .34428 L
.85762 .34104 L
.89734 .33233 L
.93556 .32164 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .35001 L
.10458 .38865 L
.12507 .40366 L
.14415 .41508 L
.16254 .42363 L
.17277 .42733 L
.18221 .43009 L
.19242 .43236 L
.19781 .43327 L
.20351 .43401 L
.2059 .43426 L
.20846 .43448 L
.21068 .43464 L
.2131 .43478 L
.21456 .43484 L
.21592 .43488 L
.21722 .43492 L
.21795 .43493 L
.21861 .43494 L
.21986 .43495 L
.22056 .43495 L
.22121 .43495 L
.2224 .43494 L
.22365 .43492 L
.22487 .43489 L
.2262 .43485 L
.22861 .43475 L
.23096 .43461 L
.23313 .43446 L
.23806 .434 L
.24329 .43336 L
.25201 .43195 L
.26163 .42993 L
.28097 .42447 L
.30183 .41681 L
.34297 .39779 L
.38259 .3771 L
.4207 .35768 L
.46126 .34006 L
.48 .33354 L
.50031 .32784 L
.51141 .32537 L
.52165 .3235 L
.53144 .32208 L
.53686 .32145 L
.5418 .32097 L
.54632 .32061 L
.55124 .3203 L
.55394 .32017 L
Mistroke
.55644 .32007 L
.55883 .31999 L
.56016 .31996 L
.56138 .31993 L
.56251 .31991 L
.56376 .3199 L
.56501 .31989 L
.56633 .31988 L
.5675 .31988 L
.56874 .31989 L
.56992 .3199 L
.57099 .31991 L
.5721 .31992 L
.57313 .31994 L
.57546 .32 L
.57751 .32006 L
.57969 .32014 L
.5846 .32038 L
.58909 .32065 L
.5992 .32148 L
.60812 .32243 L
.61749 .32361 L
.65566 .32995 L
.69627 .3377 L
.71504 .34098 L
.73537 .34398 L
.7465 .3453 L
.75675 .34628 L
.76655 .34698 L
.77149 .34724 L
.77409 .34735 L
.77692 .34745 L
.77963 .34752 L
.78083 .34755 L
.78215 .34758 L
.7833 .3476 L
.78455 .34761 L
.78587 .34762 L
.7871 .34763 L
.78823 .34763 L
.78947 .34763 L
.79075 .34763 L
.79195 .34762 L
.79308 .34761 L
.7941 .34759 L
.7964 .34755 L
.79908 .34748 L
.80156 .3474 L
.80715 .34715 L
.81208 .34686 L
Mistroke
.81731 .34648 L
.82673 .3456 L
.83686 .34439 L
.85516 .34154 L
.89641 .33244 L
.93614 .3213 L
.97435 .30959 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`3ooooooc_ooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0003o00000?oo0000:?l0
00000ooo003o0000o`000005o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?o
0000ool00?ooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`?o00000_oo00000ol0003ooooooooo
o`0Aooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`;o000000?oo`00ooooooooool02_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`04ooooo`?o00001Oooool00ol0003oooooooooo`0Aooooo`04ob4Q8Omg
MgOoMgMgoc8b<PGooooo000Qooooo`04o`000?oooooo0000ool00?oooooo7?ooool3o`0001_ooooo
0_l00002ooooo`;o00001?ooool0027ooooo00Go0000oooooooooooo0000ool0002Iooooo`Oo0000
3ooo0003o`0006Gooooo0_oo00000ol0003oooooooooo`0Vooooo`008Oooool01_l0003ooooooooo
oooooooo0000ool0097ooooo1?oo0003o`0001Wooooo1ol0001Kooooo`?oo`00:oooool0027ooooo
00?o0000ooooooooool00_ooool00ol0003oo`00ooooo`2<ooooo`?oo`009oooool5ool00003o`00
0?oooooooooo053ooooo0ooo000^ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
003ooooo08Sooooo0ooo000_ooooo`Soo`00B?ooool3ool0037ooooo000Qooooo`?o00001?ooool0
0ol0003oo`00ooooo`23ooooo`Coo`00>Oooool01?l0003oo`00ool00?oo0002o`0003kooooo1Ooo
000dooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo003ooooo083ooooo0_oo0000
0ol0003oooooooooo`10ooooo`Ko0000<_ooool6o`0003Wooooo000Qooooo`03o`000?oooooooooo
00Kooooo00?o0000ool00?ooool0O?ooool3o`0004_ooooo0_l00005ool002Gooooo1_l0000ooooo
o`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oo003ooooo07Wooooo0_l0001Eooooo`Go
o`006oooool8ool004;ooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
M_ooool2o`0005cooooo1ooo000:o`0000[oo`00B_ooool0027ooooo00?o0000ooooooooool02Ooo
ool2o`0007?ooooo0ol00033ooooo`008Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo06kooooo00?o0000ool00?oo0000aOooool0027ooooo0ol0000<ooooo`03o`000?oooooooooo
06_ooooo0ooo0037ooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06So
oooo0_oo003:ooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06Gooooo
0_oo003<ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo067ooooo0ooo
003>ooooo`008Oooool00ol0003oooooooooo`0@ooooo`;oo`00Goooool2ool00003o`000?oooooo
oooo0<kooooo000Qooooo`03o`000?oooooooooo01;ooooo00?oo`00ooooooooool0Foooool00ooo
003o0000ooooo`3Aooooo`008Oooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo05So
oooo0_l0003Dooooo`008Oooool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo05Gooooo
0_l0003Fooooo`008Oooool3o`0001Gooooo00?oo`00ooooooooool0D_ooool2o`000=Sooooo000Q
ooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool0Coooool2o`000=[ooooo000Qoooo
o`03o`000?oooooooooo01Oooooo0_oo001<ooooo`;oo`0000?o0000ooooooooool0f_ooool0027o
oooo00?o0000ooooooooool06Oooool00ooo003oooooooooo`17ooooo`;oo`0000?o0000oooooooo
ool0g?ooool0027ooooo00?o0000ooooooooool06_ooool00ooo003oooooooooo`15ooooo`03ool0
0?l0003ooooo0=oooooo000Qooooo`03o`000?oooooooooo01_ooooo00?oo`00ooooooooool0@_oo
ool2ool00>;ooooo000Qooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0?oooool2
ool00>Cooooo000Qooooo`?o00007Oooool2o`0003cooooo0ooo003Vooooo`008Oooool00ol0003o
ooooooooo`0Oooooo`;o0000>?ooool2ool00003o`000?oooooooooo0>Kooooo000Qooooo`03o`00
0?oooooooooo027ooooo0_l0000dooooo`03o`000?oo003ooooo0>[ooooo000Qooooo`03o`000?oo
oooooooo02?ooooo0_l0000`ooooo`;o0000kOooool0027ooooo00?o0000ooooooooool09Oooool2
ool002cooooo0_l0003_ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Wooooo`;oo`009ooo
ool3o`000?7ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Yooooo`?oo`008Oooool2ool00003o`000?oo
oooooooo0?;ooooo0007ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`02ooooo`?o0000;?ooool3ool001_ooooo0ooo003gooooo`001oooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0_ooooo`?oo`005Ooo
ool3ool00?[ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Cooooo00?o0000ooooooooool0<_ooool3ool000;o00002Oooool7ool00?gooooo
0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo03Oooooo2?l000000ooo003oooooooooo`3oooooo`?ooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo
AOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo
000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOoo
ool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00Z?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:?ooooo0027
ooooo`?o00004oooool00olQ8B7ogMgMooooo`07ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^
oa0@4?oMgMd0Xoooool007kooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00?ooooo00?o
0000ooooooooool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00?oV9RHoeEEEOooool0
1oooool01?mEEEGoV9RHooooooooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool00onj^[[o
A4A4ooooo`02ooooo`03ohN7QomVIVKooooo01;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo07Sooooo001nooooo`07oa0@4?oMgMgoMgMgob4Q
8OooooooQhN7ofIVIP03ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_o^k^koMgMgoa0@
4003ooooo`03o`000?oMgMgooooo00Kooooo00Wo0000oooooooooooooooooiRHV?lQ8B7ok^k^oooo
oom4A4@02_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P?ooooo00?ok^k^o`000?ooool02ooo
ool6o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool0N_ooool007kooooo00Oo0000oooooooMgMgo<S8booooooo^k^ko410@00?ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`05ooooo`;oMgMg1oooool00olb<S;oooooooooo`02oooo
o`03oiRHV?lQ8B7ok^k^00cooooo00Co410@omgMgOoooooo00001Oooool00ol0003oooooooooo`0A
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`1jooooo`00O_ooool0
1?mEEEGoZJVYooooool00002ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003ooooo
ooooo`05ooooo`03onk^k_l@413ok^k^00Kooooo00?o<S8booooooooool00oooool00onHV9So8B4Q
onk^kP0;ooooo`04ohN7QomVIVKoooooo`0000Gooooo00?o0000ooooooooool02_ooool6o`000003
ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1jooooo`00
O_ooool00ooMgMgo8B4Qonk^kP03ooooo`03o`000?oooooooooo00;o00003Oooool00ol0003ooooo
ooooo`06ooooo`03oeEEEOnHV9Sooooo00Gooooo00?o0000onk^k_ooool01?ooool00omgMgOoIVIV
ooooo`0:ooooo`04omgMgOl@413oooooo`0000Cooooo00?ok^k^o`000?ooool04_ooool01Ol0003o
oooooooooooooooo000000kooooo00?o0000ooooooooool0N_ooool007oooooo00?oV9RHogMgMooo
ool00_ooool00ol0003oooooooooo`0=ooooo`03oa0@4?l0003o000000?o00001Oooool00ooMgMgo
410@ooooo`05ooooo`03oeEEEOmgMgOooooo00Gooooo00?o0000ooooooooool02?ooool7o`0000;o
oooo00?oMgMgoeEEEOooool04_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000oooo
ooooool0N_ooool009Kooooo00?o0000ooooooooool01oooool00omEEEGoV9RHooooo`04ooooo`09
omgMgOl@413ok^k^ooooool0003o^[ZjoooooonHV9So410@01;ooooo00?ok^k^oa0@4?oMgMd04ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool0N_ooool009Kooooo00?o
0000ooooooooool01oooool00onj^[[oA4A4ooooo`05ooooo`08ogMgMomVIVKooooooiRHV?l@413o
0000ob4Q8Oo<c<`Booooo`03ofIVI_mgMgOooooo01?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`03oeEEEOmVIVKo000007cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .31657 L
.06244 .3239 L
.08426 .33054 L
.0949 .33306 L
.10458 .33491 L
.10911 .33562 L
.11403 .33627 L
.11828 .33674 L
.12297 .33716 L
.12793 .33748 L
.13065 .3376 L
.13195 .33765 L
.13319 .33769 L
.13433 .33771 L
.13557 .33774 L
.1367 .33775 L
.13774 .33776 L
.13898 .33776 L
.14011 .33776 L
.14141 .33775 L
.14264 .33773 L
.1438 .33771 L
.14504 .33768 L
.14729 .3376 L
.14996 .33748 L
.1524 .33735 L
.1577 .33697 L
.16271 .3365 L
.17156 .33543 L
.18119 .33394 L
.20096 .33001 L
.22197 .32491 L
.25972 .31505 L
.28069 .31023 L
.28988 .30846 L
.29992 .30684 L
.30464 .3062 L
.30969 .30562 L
.31404 .30521 L
.31877 .30485 L
.32155 .30469 L
.32412 .30457 L
.32657 .30448 L
.3278 .30445 L
.3285 .30444 L
.32916 .30443 L
.33039 .30441 L
.33152 .3044 L
.33273 .3044 L
Mistroke
.33404 .30441 L
.33519 .30442 L
.33641 .30445 L
.33757 .30447 L
.33861 .30451 L
.34094 .3046 L
.3435 .30473 L
.34866 .3051 L
.35344 .30558 L
.35789 .30614 L
.36796 .30783 L
.37873 .31029 L
.40001 .31718 L
.42014 .32618 L
.45852 .34959 L
.49936 .38172 L
.53868 .41626 L
.57648 .44877 L
.59749 .46508 L
.61673 .47826 L
.63682 .48978 L
.65547 .49818 L
.66542 .50166 L
.67444 .50421 L
.68446 .50634 L
.68996 .50719 L
.69264 .50752 L
.69515 .50779 L
.69758 .508 L
.6998 .50815 L
.70226 .50828 L
.70361 .50833 L
.7049 .50836 L
.70614 .50838 L
.70746 .50839 L
.70859 .50839 L
.70983 .50838 L
.71053 .50837 L
.71116 .50835 L
.7126 .50831 L
.71387 .50826 L
.7152 .50819 L
.71741 .50806 L
.71977 .50787 L
.72402 .50743 L
.72907 .50673 L
.73367 .50593 L
.74363 .50368 L
.75283 .50099 L
.77362 .49276 L
Mistroke
.79236 .48297 L
.81299 .46979 L
.8533 .43776 L
.89209 .40074 L
.93333 .35694 L
.97306 .31254 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .31681 L
.06244 .32413 L
.08255 .33017 L
.09409 .33289 L
.10458 .33484 L
.1094 .33556 L
.11464 .33623 L
.11917 .3367 L
.12415 .3371 L
.12688 .33727 L
.12944 .3374 L
.13213 .3375 L
.13365 .33755 L
.13504 .33758 L
.13632 .3376 L
.1375 .33761 L
.1388 .33761 L
.13953 .33761 L
.14019 .33761 L
.1414 .3376 L
.14271 .33758 L
.14395 .33756 L
.14509 .33753 L
.14755 .33745 L
.14979 .33736 L
.15482 .33706 L
.15949 .3367 L
.16391 .33627 L
.17381 .33504 L
.18458 .33331 L
.22536 .32412 L
.26462 .31399 L
.28432 .30961 L
.30238 .30655 L
.3118 .30542 L
.31654 .30499 L
.32172 .30464 L
.32446 .3045 L
.32695 .30441 L
.32832 .30437 L
.32905 .30435 L
.32982 .30434 L
.33049 .30433 L
.33123 .30432 L
.33253 .30431 L
.33383 .30431 L
.33503 .30432 L
.33569 .30433 L
.33641 .30434 L
Mistroke
.33772 .30437 L
.33894 .3044 L
.34024 .30444 L
.34258 .30454 L
.34519 .30469 L
.34795 .30489 L
.35289 .30535 L
.3582 .30601 L
.36403 .30691 L
.37447 .30904 L
.38421 .31163 L
.4046 .31892 L
.42317 .32774 L
.46307 .35306 L
.50145 .38369 L
.54229 .41941 L
.58161 .45266 L
.61941 .47973 L
.63879 .49069 L
.64877 .49541 L
.65966 .49979 L
.66938 .50298 L
.67974 .50562 L
.68548 .50673 L
.69069 .50753 L
.6932 .50784 L
.69592 .50812 L
.6983 .50831 L
.70086 .50848 L
.70217 .50854 L
.70342 .50859 L
.70454 .50863 L
.70576 .50865 L
.70692 .50867 L
.70814 .50867 L
.70919 .50867 L
.71035 .50865 L
.711 .50864 L
.71169 .50862 L
.71293 .50858 L
.71426 .50852 L
.71572 .50844 L
.71834 .50826 L
.72077 .50805 L
.7261 .50742 L
.73095 .50667 L
.74183 .50434 L
.75179 .50145 L
.76099 .49817 L
.78178 .48867 L
Mistroke
.82115 .46366 L
.859 .43252 L
.89931 .39352 L
.9381 .35181 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`1Eooooo`03o`000?oo003o
o`0000Soo`001Ol00003ool00003o`000?oooooooooo0<oooooo00Kok^k^ob4Q8On7QhOo^[Zjo`00
0?oMgMd4ooooo`006_oooomKo`0000Goo`004_l00006ool00<7o00003?ooool01?oMgMgo0000oa0@
4?o<c<`5ooooo`008Oooool01?l0003oooooo`000?l0000;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01?l00008ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1?ooool2o`0000?oo`000oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool2o`0001?ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo
00Co0000oooooooooooooooo0_l00009ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo1_l0000<ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool2o`0000?oo`0000?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0_l0000Cooooo`04
ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03o`000?oooooooooo00?ooooo0ooo000kooooo`?o
00000ooo000[ooooo`;o000000?oo`00ooooooooool0[_ooool00ol0003oooooooooo`0Booooo`;o
00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo00Kooooo0ooo000dooooo`;o0000
1Ooo000aooooo`;o0000[Oooool00ol0003oooooooooo`0Mooooo`008Oooool00ol0003ooooooooo
o`09ooooo`?oo`00;_ooool5ool003Sooooo0_l0002Zooooo`03o`000?oooooooooo01kooooo000Q
ooooo`03o`000?oooooooooo00cooooo0ooo000Xooooo`?oo`00?oooool2o`000:Oooooo00?o0000
ooooooooool07oooool0027ooooo00?o0000ooooooooool03oooool3ool00003o`000?oooooooooo
01gooooo1Ol00014ooooo`;o0000Y?ooool00ooo003oooooooooo`0Pooooo`008Oooool3o`0001;o
oooo00?oo`00o`000?l000000ol0000Fooooo`Co0000Boooool2ool00:7ooooo00?o0000ool00?oo
ool08Oooool0027ooooo00?o0000ooooooooool06?ooool5o`00013oo`0000?o0000ooooooooool0
C_ooool00ol0003oo`00ool0002Nooooo`03o`000?oo003ooooo02;ooooo000Qooooo`03o`000?oo
oooooooo083ooooo00?o0000ool00?ooool0Voooool00ol0003oo`00ooooo`0Sooooo`008Oooool0
0ol0003oooooooooo`22ooooo`;oo`00VOooool00ol0003oo`00ooooo`0Tooooo`008Oooool00ol0
003oooooooooo`23ooooo`03o`000?oo003oo`0009Kooooo00?o0000ool00?ooool09Oooool0027o
oooo00?o0000ooooooooool0QOooool00ol0003oo`00ooooo`2Cooooo`03o`000?oo003ooooo02Ko
oooo000Qooooo`03o`000?oooooooooo08Oooooo00?oo`00ooooooooool0T?ooool00ol0003oo`00
ooooo`0Wooooo`008Oooool3o`0008Sooooo00?oo`00ooooooooool0S_ooool00ol0003oo`00oooo
o`0Xooooo`008Oooool00ol0003oooooooooo`29ooooo`03ool00?l0003ooooo08gooooo00?oo`00
ooooooooool0:?ooool0027ooooo00?o0000ooooooooool0R_ooool00ooo003o0000ooooo`2;oooo
o`03ool00?oooooooooo02Wooooo000Qooooo`03o`000?oooooooooo08cooooo00?o0000oooooooo
ool0R?ooool00ooo003oooooooooo`0Zooooo`008Oooool00ol0003oooooooooo`2=ooooo`03o`00
0?oooooooooo08Kooooo00?o0000ooooooooool0:oooool0027ooooo00?o0000ooooooooool0S_oo
ool2o`0008Gooooo00?o0000ooooooooool0;?ooool0027ooooo00?o0000ooooooooool0T?ooool0
0ol0003oooooooooo`21ooooo`03o`000?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo
097ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0^ooooo`008Oooool3o`0009;o
oooo0_l0001oooooo`03o`000?oooooooooo02kooooo000Qooooo`03o`000?oooooooooo09?ooooo
0_oo001mooooo`03o`000?oooooooooo02oooooo000Qooooo`03o`000?oooooooooo09Gooooo00?o
o`00ooooooooool0NOooool00ol0003oooooooooo`0`ooooo`008Oooool00ol0003oooooooooo`2F
ooooo`03ool00?oooooooooo07Kooooo00?oo`00o`000?ooool0<_ooool0027ooooo00?o0000oooo
ooooool0Uoooool00ooo003oooooooooo`1dooooo`;oo`00=?ooool0027ooooo00?o0000oooooooo
ool0V?ooool00ooo003oooooooooo`1booooo`03ool00?l0003ooooo03Cooooo000Qooooo`03o`00
0?oooooooooo09Wooooo0_oo001aooooo`03ool00?l0003ooooo03Gooooo000Qooooo`?o0000V_oo
ool00ol0003oo`00ooooo`1^ooooo`03ool00?oooooooooo03Kooooo000Qooooo`03o`000?oooooo
oooo09_ooooo00?o0000ool00?ooool0K?ooool00ooo003oooooooooo`0gooooo`008Oooool00ol0
003oooooooooo`2Looooo`03o`000?oo003ooooo06[ooooo00?oo`00ooooooooool0>?ooool0027o
oooo00?o0000ooooooooool0WOooool00ol0003oo`00ooooo`1Xooooo`03ool00?oooooooooo03Wo
oooo000Qooooo`03o`000?oooooooooo09kooooo00?o0000ool00?ooool0I_ooool00ooo003ooooo
ooooo`0jooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo06?o
oooo00?oo`00ooooooooool0>oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0:7ooooo00?o0000oooooooo
ool0HOooool00ooo003oooooooooo`0looooo`001oooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00_ooool3o`000:;ooooo00?o0000ooooooooool0Goooool00ooo003o
ooooooooo`0mooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo05gooooo00?o0000oooooooo
ool0?_ooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01?ooool00ol0003oooooooooo`2Tooooo`;o0000G?ooool00ol0003oooooooooo`0ooooo
o`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`2Vooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0@?ooool000Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0Yoooool2ool005Kooooo0_l00013ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l00005ooooo`03o`000?oooooooooo0:Sooooo00?o0000ool00?ooool0Doooool00ol0
003oooooooooo`13ooooo`008Oooool00ol0003oooooooooo`2Yooooo`03o`000?oo003ooooo057o
oooo00?o0000ooooooooool0A?ooool0027ooooo00?o0000ooooooooool0Z_ooool00ol0003oo`00
ooooo`1>ooooo`;oo`00Aoooool0027ooooo0ol0002/ooooo`;oo`00C?ooool00ooo003o0000oooo
o`17ooooo`008Oooool00ol0003oooooooooo`2]ooooo`03o`000?oo003ooooo04Wooooo00?oo`00
o`000?ooool0B?ooool0027ooooo00?o0000ooooooooool0[oooool00ooo003oooooooooo`16oooo
o`03ool00?oooooooooo04Wooooo000Qooooo`03o`000?oooooooooo0;3ooooo00?oo`00oooooooo
ool0A?ooool00ooo003oooooooooo`1:ooooo`008Oooool00ol0003oooooooooo`2aooooo`03ool0
0?l0003ooooo047ooooo0_oo001=ooooo`008Oooool00ol0003oooooooooo`2booooo`03ool00?l0
003ooooo03kooooo0_oo00000ol0003oooooooooo`1<ooooo`008Oooool00ol0003oooooooooo`2c
ooooo`03ool00?l0003o000003cooooo00?oo`00o`000?l00000Coooool0027ooooo0ol0002foooo
o`03o`000?oooooooooo03Oooooo0_oo00000ol0003oooooooooo`1?ooooo`008Oooool00ol0003o
ooooooooo`2gooooo`;o0000=_ooool00ooo003o0000ooooo`1Booooo`008Oooool00ol0003ooooo
ooooo`2iooooo`03o`000?oooooooooo03;ooooo0_l0001Dooooo`008Oooool00ol0003ooooooooo
o`2jooooo`;o0000<?ooool2o`0005Kooooo000Qooooo`03o`000?oooooooooo0;cooooo00?o0000
ooooooooool0:oooool2o`0005Sooooo000Qooooo`03o`000?oooooooooo0;gooooo0_oo00000ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo05Sooooo000Qooooo`03o`000?oooooooooo0;oo
oooo0_oo0002o`0002?ooooo0ol0001Kooooo`008Oooool00ol0003oooooooooo`31ooooo`?oo`00
00?o0000ooooooooool07?ooool3ool005kooooo000Qooooo`?o0000a?ooool3ool001Wooooo0ooo
001Qooooo`008Oooool00ol0003oooooooooo`36ooooo`04o`000?oo003oo`00ool000;o00004?oo
ool4ool006Cooooo000Qooooo`03o`000?oooooooooo0<[ooooo0_oo0005o`0000Kooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`1Uooooo`008Oooool00ol0003oooooooooo`3@oooo
o`Ko00000_oo001/ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3
o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000
ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGo
oooo000Jooooo`03o`000?oooooooooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00:Cooooo00?oMgMgofIVI_ooool05oooool00omV
IVKoMgMgooooo`2Wooooo`00Poooool3o`0001Cooooo00?o8B4QomgMgOooool01_ooool00ooMgMgo
410@onk^kP0Hooooo`03onk^k_l@413ogMgM0:Oooooo001kooooo`07ohN7Qol0003oEEEEofIVI_l0
003o<S8bonk^kP02ooooo`03o`000?oooooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P03
ooooo`03oiRHV?mEEEGooooo00Kooooo00?oEEEEoiRHV?ooool00_ooool5o`0000Wooooo00?oEEEE
ojVYZOooool00_ooool01_nj^[[oA4A4ooooooooooooQhN7ofIVIQCooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`1dooooo`00Noooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00_ooool0
0ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ogMgMoooo
o`05ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00:ooooo`06oeEE
EOnHV9Soooooooooool@413o^[Zj0_ooool00oo^k^ko0000ooooo`0;ooooo`Ko00000_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMg
oc8b<_ooool0M?ooool007_ooooo00Oo0000oooooooMgMgo<S8booooooo^k^ko410@00;ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`;oMgMg1_ooool00olb<S;ooooooooo
o`03ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co410@omgMgOoooooo00001?ooool00ol0003ooooo
ooooo`0Booooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo07?ooooo001kooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Co0000oooooooo
oooo00003Oooool00ol0003oooooooooo`06ooooo`03onk^k_l@413ok^k^00Gooooo00?o<S8boooo
ooooool01?ooool00onHV9So8B4Qonk^kP0;ooooo`04ohN7QomVIVKoooooo`0000Cooooo00?o0000
ooooooooool02_ooool6o`0000;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oo
oooooooo00Kooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00?ogMgMob4Q8Oo^k^h00oooool0
1?l0003oooooo`000?l0000=ooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?oo
ool00ol0003ok^k^ooooo`05ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo0000
0oooool00oo^k^ko0000ooooo`0Cooooo`05o`000?ooooooooooooooool000003_ooool00ol0003o
ooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0MOooool007cooooo00?oV9RHogMgMooo
ool00_ooool00ol0003oooooooooo`0<ooooo`03oa0@4?l0003o000000?o00001_ooool00ooMgMgo
410@ooooo`04ooooo`03oeEEEOmgMgOooooo00Kooooo00?o0000ooooooooool02?ooool7o`000003
oooooomgMgOoEEEE01Cooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0Moooool009;ooooo00?o0000ooooooooool02?ooool00omEEEGo
V9RHooooo`03ooooo`03omgMgOl@413ok^k^00;ooooo00Go0000okZj^_ooooooV9RHoa0@400Aoooo
o`03onk^k_l@413ogMgM01Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0Moooool009;ooooo00?o0000ooooooooool02?ooool00onj
^[[oA4A4ooooo`04ooooo`09ogMgMomVIVKooooooooooonHV9So410@o`000?lQ8B7oc<c<017ooooo
00?oIVIVogMgMoooool05?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l0
00001Oooool4o`0007Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .2881 L
.10458 .26431 L
.14415 .24213 L
.18221 .22354 L
.20178 .21618 L
.21274 .21298 L
.21758 .21181 L
.22272 .21074 L
.22745 .20991 L
.23267 .2092 L
.23496 .20895 L
.23742 .20873 L
.23974 .20857 L
.24186 .20845 L
.24314 .2084 L
.24384 .20838 L
.24451 .20836 L
.24579 .20834 L
.24696 .20833 L
.24763 .20833 L
.24835 .20834 L
.24963 .20836 L
.25034 .20837 L
.25101 .20839 L
.25252 .20845 L
.25383 .20852 L
.25508 .20859 L
.25741 .20877 L
.25992 .20902 L
.26265 .20935 L
.26749 .21011 L
.27205 .21101 L
.28242 .2138 L
.29253 .2175 L
.30343 .22259 L
.32347 .23496 L
.34457 .25212 L
.38268 .29283 L
.42324 .34653 L
.46228 .4027 L
.50378 .46016 L
.54376 .50738 L
.58223 .54158 L
.6021 .5543 L
.61225 .55945 L
.62315 .56397 L
.63338 .56726 L
.64272 .56946 L
.64722 .57026 L
Mistroke
.65212 .57093 L
.65436 .57117 L
.65674 .57137 L
.659 .57152 L
.66104 .57163 L
.66224 .57167 L
.66337 .5717 L
.6646 .57172 L
.66593 .57173 L
.66659 .57173 L
.66731 .57172 L
.66863 .5717 L
.6699 .57167 L
.67109 .57162 L
.67322 .57152 L
.67557 .57136 L
.68032 .5709 L
.6855 .57019 L
.69107 .5692 L
.70115 .56681 L
.71075 .56384 L
.72123 .55983 L
.74235 .5495 L
.78296 .52199 L
.82206 .48754 L
.86361 .44439 L
.90364 .39831 L
.94216 .35141 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .28797 L
.10458 .26394 L
.14415 .24225 L
.18221 .22399 L
.20178 .2166 L
.21267 .21334 L
.22272 .21098 L
.22768 .21007 L
.23293 .20929 L
.23548 .20899 L
.23821 .20873 L
.23978 .2086 L
.24121 .2085 L
.24257 .20842 L
.24402 .20836 L
.24471 .20833 L
.24536 .20831 L
.24658 .20828 L
.24772 .20827 L
.24896 .20826 L
.24961 .20827 L
.25032 .20827 L
.25107 .20829 L
.25177 .2083 L
.25301 .20834 L
.25435 .2084 L
.25698 .20856 L
.25948 .20876 L
.26416 .2093 L
.26875 .21003 L
.27382 .21107 L
.28407 .21392 L
.29357 .21749 L
.30249 .22166 L
.32267 .23405 L
.34118 .24891 L
.3808 .2908 L
.41891 .34077 L
.45947 .39873 L
.49852 .45311 L
.54002 .50332 L
.56082 .52403 L
.58 .53999 L
.59868 .55246 L
.60822 .55763 L
.61846 .56226 L
.62869 .56595 L
.63804 .5685 L
.64253 .56946 L
Mistroke
.64743 .5703 L
.65206 .57091 L
.65415 .57112 L
.65635 .57131 L
.65762 .57139 L
.65901 .57147 L
.66028 .57153 L
.66144 .57158 L
.6621 .5716 L
.66282 .57161 L
.66358 .57163 L
.66429 .57164 L
.66496 .57164 L
.66567 .57164 L
.66695 .57163 L
.66812 .57161 L
.66939 .57157 L
.67059 .57153 L
.67169 .57148 L
.67424 .57132 L
.67691 .5711 L
.68153 .57058 L
.68581 .56996 L
.69553 .56802 L
.70608 .56512 L
.71603 .56167 L
.73463 .55341 L
.77315 .52954 L
.81412 .49542 L
.85358 .45557 L
.89151 .41247 L
.93191 .36376 L
.97078 .31582 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0?Oooool>ool00?Wooooo000Qooooo`03o`000?oooooooooo
03Oooooo1?l00002ool000gooooo00Coo`00o`000?l0003o0000m_ooool0027ooooo0ol0000doooo
o`?o00005oooool3o`000??ooooo000Qooooo`03o`000?oooooooooo03;ooooo0_l0000Mooooo`?o
0000l?ooool0027ooooo00?o0000ooooooooool0<?ooool2ool002;ooooo00?o0000ool00?oo0000
kOooool0027ooooo00?o0000ooooooooool0;_ooool2ool002Oooooo00?oo`00ooooooooool0j_oo
ool0027ooooo00?o0000ooooooooool0:oooool00ol0003oo`00ool0000Zooooo`;oo`00j_ooool0
027ooooo00?o0000ooooooooool0:Oooool00ol0003oo`00ool0000^ooooo`03ool00?oooooooooo
0>Oooooo000Qooooo`03o`000?oooooooooo02Oooooo00?o0000ool00?oo0000<Oooool00ooo003o
0000ooooo`3Vooooo`008Oooool3o`0002Cooooo0_l00002ool003Cooooo00?oo`00o`000?ooool0
iOooool0027ooooo00?o0000ooooooooool08_ooool2o`0000;oo`00=oooool00ooo003o0000oooo
o`3Tooooo`008Oooool00ol0003oooooooooo`0Pooooo`;o00000_oo000jooooo`03ool00?l0003o
oooo0>?ooooo000Qooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?Oooool00ooo
003o0000ooooo`3Rooooo`008Oooool00ol0003oooooooooo`0Mooooo`;o0000@Oooool2ool00>;o
oooo000Qooooo`03o`000?oooooooooo01_ooooo0_l00015ooooo`03o`000?oooooooooo0=oooooo
000Qooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0AOooool00ol0003ooooooooo
o`3Oooooo`008Oooool00ol0003oooooooooo`0Hooooo`;oo`00BOooool00ol0003oooooooooo`3N
ooooo`008Oooool3o`0001Kooooo0_oo001<ooooo`03o`000?oooooooooo0=gooooo000Qooooo`03
o`000?oooooooooo01Cooooo0_oo000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Booooo`03o`000?oooooooooo02Sooooo1?l00000
0ol@413oooooooooo`0kooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@0mooooo`Go00006oooool0027ooooo00?o0000ooooooooool04oooool0
0ooo003oooooooooo`0Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool04_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0??ooool01OnHV9So8B4Qonk^
k_ooooooA4A401_ooooo000Qooooo`03o`000?oooooooooo017ooooo0_oo000Zooooo`05oa0@4?oo
ooooooooooooool@41004?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03cooooo
00?oV9RHob4Q8Oo^k^h07?ooool0027ooooo00?o0000ooooooooool03oooool2ool002cooooo00Go
0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Cooooo00?o0000ool00?ooool0
9oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0
?_ooool00onHV9So8B4Qonk^kP0Kooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
003ooooo02gooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`05_ooool00ooo003oooooooooo`0Vooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043ooooo00?oMgMgofIVI_ooool06_ooool0027o
oooo00?o0000ooooooooool03?ooool2ool002oooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool09Oooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Ioooo
o`008Oooool3o`0000[ooooo00?o0000ool00?ooool0<?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool06_ooool00ooo003oooooooooo`0Tooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0oooooo`05o`000?nj^[[ooooo
oiRHV?l@41006oooool0027ooooo00?o0000ooooooooool02?ooool2o`0003?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00006_ooool00ooo003oooooooooo`0Qooooo`03oeEEEOmVIVKo
000003oooooo00?oEEEEofIVI_l000003Oooool4o`0003kooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00Kooooo`008Oooool00ol0003oooooooooo`06ooooo`;o0000IOooool00ooo003oooooooooo`3D
ooooo`008Oooool00ol0003oooooooooo`04ooooo`;o0000Ioooool00ooo003oooooooooo`3Doooo
o`008Oooool00ol0003oooooooooo`02ooooo`;o0000J_ooool00ooo003oooooooooo`3Cooooo`00
8Oooool01?l0003oooooooooool00002ool006cooooo00?oo`00ooooooooool0b?ooool2o`0000;o
oooo0_l00004ooooo`008Oooool01?l0003oo`00ool00?oo001_ooooo`03ool00?oooooooooo0<Oo
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0003o0000
077o000000?oo`00o`000?l00000/ol000000ooo003o0000o`000005o`0000cooooo00CogMgMo`00
0?l@413oc<c<1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09oooo
o`04o`000?oo003oooooo`0000kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03ool00?l0003ooooo01;ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oo003o000000kooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03ool00?l0003o000001?ooooo00Co8B4Q
ogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`2_
ooooo`03ool00?oooooooooo01;ooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000oooo
ooooool0M?ooool00ol0003oooooooooo`2]ooooo`03ool00?oooooooooo01gooooo000Qooooo`03
o`000?oooooooooo07Cooooo00?o0000ooooooooool0[?ooool00ooo003oooooooooo`0Nooooo`00
8Oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo0:[ooooo00?oo`00o`000?ooool0
7oooool0027ooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`2Yooooo`03ool00?oo
oooooooo01oooooo000Qooooo`?o0000Moooool00ol0003oooooooooo`2Wooooo`03ool00?oooooo
oooo023ooooo000Qooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0Y_ooool00ooo
003oooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo0:Go
oooo00?oo`00ooooooooool08Oooool0027ooooo00?o0000ooooooooool0NOooool00ooo003ooooo
ooooo`2Sooooo`03ool00?oooooooooo02;ooooo000Qooooo`03o`000?oooooooooo07Wooooo00?o
o`00o`000?ooool0X_ooool00ooo003oooooooooo`0Sooooo`008Oooool00ol0003oooooooooo`1j
ooooo`03ool00?oooooooooo0:3ooooo00?oo`00ooooooooool09?ooool0027ooooo00?o0000oooo
ooooool0Noooool00ooo003oooooooooo`2Nooooo`03o`000?oooooooooo02Gooooo000Qooooo`?o
0000Noooool00ooo003o0000ooooo`2Nooooo`03o`000?oooooooooo02Gooooo000Qooooo`03o`00
0?oooooooooo07cooooo00?oo`00ooooooooool0W?ooool00ol0003oooooooooo`0Vooooo`008Ooo
ool00ol0003oooooooooo`1mooooo`03ool00?oooooooooo09[ooooo00?o0000ooooooooool09ooo
ool0027ooooo00?o0000ooooooooool0O_ooool00ooo003oooooooooo`2Hooooo`03o`000?oooooo
oooo02Sooooo000Qooooo`03o`000?oooooooooo07kooooo00?oo`00ooooooooool0Uoooool00ol0
003oooooooooo`0Yooooo`008Oooool00ol0003oooooooooo`1oooooo`03ool00?oooooooooo09Go
oooo00?o0000ooooooooool0:_ooool0027ooooo00?o0000ooooooooool0P?ooool00ooo003ooooo
ooooo`2Cooooo`03ool00?oooooooooo02_ooooo000Qooooo`03o`000?oooooooooo083ooooo00?o
o`00ooooooooool0Toooool00ooo003oooooooooo`0[ooooo`008Oooool3o`00087ooooo00?oo`00
ooooooooool0TOooool00ooo003oooooooooo`0/ooooo`008Oooool00ol0003oooooooooo`22oooo
o`03ool00?oooooooooo08oooooo00?oo`00ooooooooool0;Oooool0027ooooo00?o0000oooooooo
ool0P_ooool00ol0003oooooooooo`2>ooooo`03ool00?oooooooooo02kooooo000Qooooo`03o`00
0?oooooooooo08?ooooo00?o0000ooooooooool0S?ooool00ooo003oooooooooo`0_ooooo`008Ooo
ool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo08[ooooo00?oo`00ooooooooool0<?oo
ool0027ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`29ooooo`03o`000?oo003o
oooo037ooooo000Qooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0R?ooool00ooo
003oooooooooo`0aooooo`008Oooool3o`0008Kooooo00?o0000ooooooooool0Q_ooool00ooo003o
ooooooooo`0booooo`008Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo08Gooooo
00?oo`00ooooooooool0<oooool0027ooooo00?o0000ooooooooool0Qoooool00ol0003ooooooooo
o`23ooooo`03ool00?oooooooooo03Cooooo000Qooooo`03o`000?oooooooooo08Sooooo00?o0000
ool00?ooool0POooool00ooo003oooooooooo`0eooooo`008Oooool00ol0003oooooooooo`29oooo
o`03ool00?oooooooooo083ooooo00?o0000ooooooooool0=Oooool000Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000
ooooooooool0ROooool00ol0003oo`00ooooo`1oooooo`03o`000?oooooooooo03Kooooo0007oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool0
0ol0003oooooooooo`2:ooooo`03o`000?oo003ooooo07gooooo00?o0000ooooooooool0=oooool0
00Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0002;
ooooo`03o`000?oo003ooooo07_ooooo00?o0000ooooooooool0>?ooool000Oooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0Roooool0
0ol0003oo`00ooooo`1jooooo`03o`000?oooooooooo03Wooooo0007ooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0S?oo
ool00ol0003oo`00ooooo`1iooooo`03o`000?oooooooooo03Wooooo0007ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08gooooo00?o
0000ool00?ooool0Moooool00ol0003oooooooooo`0jooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2>ooooo`03o`000?oo
003ooooo07Cooooo00?oo`00o`000?ooool0??ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001Oooool00ol0003oooooooooo`2>ooooo`03o`000?oo003ooooo07?ooooo00?o
o`00o`000?ooool0?Oooool0027ooooo00?o0000ooooooooool0Soooool00ol0003oo`00ooooo`1a
ooooo`03ool00?l0003ooooo03kooooo000Qooooo`03o`000?oooooooooo093ooooo00?o0000ool0
0?ooool0Koooool00ooo003o0000ooooo`0oooooo`008Oooool3o`00093ooooo00?o0000oooooooo
0000K_ooool00ooo003o0000ooooo`10ooooo`008Oooool00ol0003oooooooooo`2Aooooo`03o`00
0?oooooooooo06cooooo00?oo`00o`000?ooool0@Oooool0027ooooo00?o0000ooooooooool0T_oo
ool00ol0003oooooooooo`1[ooooo`03ool00?oooooooooo047ooooo000Qooooo`03o`000?oooooo
oooo09?ooooo00?o0000ooooooooool0JOooool00ooo003oooooooooo`12ooooo`008Oooool00ol0
003oooooooooo`2Cooooo`03o`000?oooooooooo06Sooooo00?oo`00ooooooooool0@oooool0027o
oooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`1Vooooo`03ool00?oooooooooo04Co
oooo000Qooooo`03o`000?oooooooooo09Gooooo00?o0000ooooooooool0I?ooool00ooo003ooooo
ooooo`15ooooo`008Oooool3o`0009Kooooo00?o0000ooooooooool0H_ooool00ooo003ooooooooo
o`16ooooo`008Oooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo063ooooo00?oo`00
ooooooooool0Aoooool0027ooooo00?o0000ooooooooool0V?ooool00ol0003oo`00ooooo`1Noooo
o`03o`000?oooooooooo04Sooooo000Qooooo`03o`000?oooooooooo09Wooooo00?oo`00oooooooo
ool0G?ooool00ol0003oooooooooo`19ooooo`008Oooool00ol0003oooooooooo`2Jooooo`03ool0
0?oooooooooo05Wooooo0_l0001<ooooo`008Oooool00ol0003oooooooooo`2Kooooo`03ool00?oo
oooooooo05Oooooo00?o0000ooooooooool0C?ooool0027ooooo00?o0000ooooooooool0W?ooool0
0ooo003oooooooooo`1Eooooo`03o`000?oooooooooo04gooooo000Qooooo`03o`000?oooooooooo
09gooooo00?oo`00ooooooooool0Doooool00ol0003oooooooooo`1>ooooo`008Oooool3o`0009ko
oooo00?oo`00ooooooooool0D?ooool2ool0057ooooo000Qooooo`03o`000?oooooooooo09oooooo
00?oo`00ooooooooool0C_ooool00ooo003o0000ooooo`1Aooooo`008Oooool00ol0003ooooooooo
o`2Oooooo`03ool00?l0003o000004gooooo00?oo`00ooooooooool0D_ooool0027ooooo00?o0000
ooooooooool0X?ooool00ooo003oooooo`00001;ooooo`03ool00?oooooooooo05?ooooo000Qoooo
o`03o`000?oooooooooo0:7ooooo00?oo`00ooooool00000B?ooool2ool005Kooooo000Qooooo`03
o`000?oooooooooo0:;ooooo00?oo`00ooooool00000A_ooool00ooo003o0000ooooo`1Fooooo`00
8Oooool00ol0003oooooooooo`2Sooooo`03ool00?oooooo000004Cooooo00?oo`00o`000?ooool0
Eoooool0027ooooo0ol0002Vooooo`03o`000?oooooooooo043ooooo00?oo`00o`000?ooool0F?oo
ool0027ooooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`0nooooo`03ool00?oooooo
oooo05Wooooo000Qooooo`03o`000?oooooooooo0:Sooooo00?o0000ooooooooool0>oooool00ol0
003oo`00ooooo`1Kooooo`008Oooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo03Wo
oooo00?o0000ool00?ooool0G?ooool0027ooooo00?o0000ooooooooool0Z_ooool00ol0003ooooo
ooooo`0fooooo`;o0000Goooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oo
oooooooo0:_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1Oooooo`006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:_ooooo0_oo00000ol0003oooooooooo`0`
ooooo`;o0000H_ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2]oooo
o`;oo`00<?ooool00ol0003oooooooooo`1Rooooo`006_ooool00ol0003oooooooooo`04ooooo`?o
0000[oooool2ool002cooooo0_l0001Uooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0;7ooooo0_oo000Xooooo`03o`000?oo003oo`0006Kooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0/_ooool00ol0003oo`00ooooo`0Uooooo`;oo`00J?oo
ool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2dooooo`?oo`008?ooool3
ool006[ooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0]Oooool2o`00
00;oo`006oooool3ool00003o`000?oooooooooo06[ooooo000Qooooo`03o`000?oooooooooo0;So
oooo00Co0000ool00?l0003o00005Oooool3ool000;o0000K_ooool0027ooooo00?o0000oooooooo
ool0_?ooool3o`0000oooooo0ooo0002o`00077ooooo000Qooooo`?o0000_oooool5ool000co0000
M?ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z?oo
ool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:?ooooo0027ooooo`?o00004oooool0
0olQ8B7ogMgMooooo`07ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Xoooool0
07kooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool02ooo
ool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00?oV9RHoeEEEOooool01oooool01?mEEEGoV9RH
ooooooooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool00onj^[[oA4A4ooooo`02ooooo`03
ohN7QomVIVKooooo01;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00
07_ooooo001nooooo`07oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP03ooooo`03o`000?oooooo
oooo00_ooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oMgMgooooo00Kooooo00Wo
0000oooooooooooooooooiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooooooooooo
410@okZj^P?ooooo00?ok^k^o`000?ooool02oooool6o`000006oooooomgMgOoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A01kooooo`00O_ooool01ol0003o
ooooomgMgOlb<S;oooooonk^k_l@41000oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Gooooo0_mgMgL7ooooo`03oc8b<_oooooooooo00;ooooo00?oV9RHob4Q8Oo^k^h03?ooool0
1?l@413ogMgMooooool00005ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^07cooooo001nooooo`04oeEEEOnYZJWoooooo`0000;ooooo
00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00Gooooo00?ok^k^oa0@4?o^
k^h01_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oo
oooo00001Oooool00ol0003oooooooooo`0:ooooo`Ko000000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^07_ooooo001nooooo`03omgMgOlQ8B7ok^k^00?o
oooo00?o0000ooooooooool00_l0000=ooooo`03o`000?oooooooooo00Kooooo00?oEEEEoiRHV?oo
ool01Oooool00ol0003ok^k^ooooo`04ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oo
oooo00001?ooool00oo^k^ko0000ooooo`0Booooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`1jooooo`00Ooooool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo
00gooooo00?o410@o`000?l000000ol00005ooooo`03omgMgOl@413ooooo00Gooooo00?oEEEEogMg
Moooool01Oooool00ol0003oooooooooo`08ooooo`Oo00000_ooool00omgMgOoEEEEooooo`0Boooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`1iooooo`00U_ooool00ol0
003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00WogMgMoa0@4?o^k^koooooo`000?nj
^[[ooooooiRHV?l@41004_ooool00oo^k^ko410@omgMg@0Cooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@07_ooooo002Fooooo`03o`000?oooooooooo00Oo
oooo00?o^[ZjodA4A?ooool01Oooool02?mgMgOoIVIVoooooonHV9So410@o`000?lQ8B7oc<c<4_oo
ool00omVIVKoMgMgooooo`0Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<07_ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .25082 L
.10458 .1949 L
.12507 .17265 L
.14415 .15576 L
.16254 .14352 L
.17284 .13856 L
.18221 .13528 L
.18704 .13407 L
.18969 .13354 L
.19216 .13313 L
.19427 .13286 L
.19654 .13263 L
.19783 .13254 L
.19905 .13247 L
.20015 .13242 L
.20135 .13239 L
.20203 .13239 L
.20276 .13239 L
.20345 .13239 L
.20409 .13241 L
.2053 .13244 L
.20657 .13251 L
.20794 .1326 L
.20922 .13272 L
.21213 .13306 L
.21466 .13346 L
.21696 .1339 L
.22214 .13518 L
.22694 .13671 L
.23205 .13869 L
.24122 .14318 L
.26198 .15761 L
.28145 .1762 L
.29973 .19761 L
.33842 .2526 L
.37956 .31852 L
.41919 .38074 L
.45729 .43315 L
.47854 .45782 L
.49785 .47706 L
.51817 .49394 L
.5369 .50646 L
.55608 .51634 L
.56619 .52038 L
.57688 .52382 L
.58632 .52616 L
.59152 .52718 L
.59646 .52797 L
.60103 .52855 L
Mistroke
.60345 .52881 L
.60603 .52903 L
.60841 .5292 L
.61056 .52932 L
.6116 .52937 L
.61273 .52942 L
.61378 .52945 L
.61477 .52948 L
.61602 .5295 L
.61715 .52951 L
.61837 .52952 L
.61906 .52952 L
.6197 .52951 L
.62076 .5295 L
.62193 .52948 L
.62315 .52945 L
.6243 .52941 L
.62693 .52929 L
.62933 .52915 L
.63475 .5287 L
.63966 .52815 L
.64502 .52739 L
.65582 .52537 L
.67547 .52018 L
.69644 .51265 L
.73799 .49256 L
.77802 .46803 L
.81654 .44086 L
.85751 .40918 L
.89697 .37682 L
.93491 .34462 L
.9753 .30979 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .24997 L
.10458 .19598 L
.12507 .17365 L
.14415 .15624 L
.16254 .14335 L
.17284 .13805 L
.18221 .13451 L
.18704 .13319 L
.18969 .13261 L
.19216 .13217 L
.19445 .13184 L
.19654 .1316 L
.19773 .1315 L
.19886 .13142 L
.20005 .13136 L
.20135 .13132 L
.20203 .13131 L
.20276 .13131 L
.20345 .13131 L
.20409 .13132 L
.2053 .13136 L
.20657 .13142 L
.20794 .13151 L
.20922 .13163 L
.21213 .13198 L
.21466 .13239 L
.21696 .13285 L
.22214 .13418 L
.22694 .13578 L
.23205 .13786 L
.24122 .14257 L
.26198 .15762 L
.28145 .17678 L
.29973 .19856 L
.33842 .25355 L
.37956 .31854 L
.41919 .37995 L
.45729 .4323 L
.47854 .45722 L
.49785 .47679 L
.51817 .49402 L
.5369 .50683 L
.55608 .5169 L
.56619 .521 L
.57688 .52446 L
.58632 .52679 L
.59152 .5278 L
.59646 .52857 L
.60103 .52913 L
Mistroke
.60345 .52937 L
.60603 .52958 L
.60841 .52973 L
.61056 .52984 L
.6116 .52988 L
.61273 .52991 L
.61379 .52994 L
.61477 .52996 L
.61604 .52997 L
.61724 .52997 L
.61831 .52997 L
.61948 .52995 L
.62076 .52993 L
.62211 .52989 L
.62453 .52979 L
.62676 .52967 L
.62886 .52953 L
.63363 .52911 L
.63883 .52849 L
.64359 .5278 L
.65431 .52578 L
.67327 .52075 L
.69399 .51336 L
.7346 .49404 L
.7737 .47061 L
.81525 .44178 L
.85528 .41112 L
.8938 .3797 L
.93477 .34493 L
.97422 .31073 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`0booooo`Co00001Ooo003oooooo`[ooooo000Qooooo`03o`000?oooooooooo02ko
oooo1?l00007ooooo`;o00000ooo003oooooo`Oooooo000Qooooo`03o`000?oooooooooo02_ooooo
0_oo00000ol0003oooooooooo`0=ooooo`04o`000?oo003oo`00ool00?oooooo1?ooool0027ooooo
0ol0000Zooooo`03ool00?oooooooooo01?ooooo00?o0000ool00?ooool0ooooool2ooooo`008Ooo
ool00ol0003oooooooooo`0Xooooo`;oo`005oooool00ol0003oo`00ooooo`3oooooo`7ooooo000Q
ooooo`03o`000?oooooooooo02Oooooo00?oo`00ooooooooool06Oooool00ooo003o0000ooooo`3n
ooooo`008Oooool00ol0003oooooooooo`0Uooooo`;oo`007Oooool00ooo003o0000ooooo`3moooo
o`008Oooool00ol0003oooooooooo`0Tooooo`03ool00?oooooooooo01oooooo0_l0003looooo`00
8Oooool00ol0003oooooooooo`0Rooooo`;oo`009?ooool00ol0003oooooooooo`3iooooo`008Ooo
ool00ol0003oooooooooo`0Qooooo`03ool00?oooooooooo02Gooooo00?o0000ooooooooool0n?oo
ool0027ooooo00?o0000ooooooooool08?ooool00ooo003oooooooooo`0Wooooo`03o`000?oooooo
oooo0?Oooooo000Qooooo`?o00007oooool00ooo003oooooooooo`0Yooooo`03o`000?oooooooooo
0?Kooooo000Qooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`3eooooo`008Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02gooooo
00?oo`00ooooooooool0m?ooool0027ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0^ooooo`03ool00?oooooooooo0??ooooo000Qooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0;oooool00ooo003oooooooooo`3cooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo037ooooo00?oo`00ooooooooool0l_ooool000Oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0<oooool00ooo003oooooooooo`3aooooo`001Ol00002
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o00006Ooo
ool00ol0003oooooooooo`0eooooo`03ool00?oooooooooo0?3ooooo0007ooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01Oooooo00?o
o`00o`000?ooool0>?ooool00ooo003oooooooooo`3_ooooo`001oooool01Ol0003ooooooooooooo
oooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo01Oooooo
00?oo`00ooooooooool0>Oooool00ooo003oooooooooo`3^ooooo`001oooool01Ol@413ooooooooo
oooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Gooooo`03ool0
0?oooooooooo03[ooooo00?oo`00ooooooooool0kOooool000Oooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool00ooo003ooooo
ooooo`0kooooo`03ool00?oooooooooo0>gooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`0000Gooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`0mooooo`03ool0
0?oooooooooo0>cooooo000Qooooo`03o`000?oooooooooo01Cooooo00?oo`00ooooooooool0?_oo
ool00ooo003o0000ooooo`3/ooooo`008Oooool00ol0003oooooooooo`0Cooooo`03ool00?oooooo
oooo043ooooo00?oo`00ooooooooool0joooool0027ooooo0ol0000Booooo`03ool00?oooooooooo
04;ooooo00?o0000ooooooooool0j_ooool0027ooooo00?o0000ooooooooool04_ooool00ooo003o
ooooooooo`13ooooo`03o`000?oooooooooo0>Wooooo000Qooooo`03o`000?oooooooooo017ooooo
00?oo`00ooooooooool0AOooool00ol0003oooooooooo`3Xooooo`008Oooool00ol0003ooooooooo
o`0@ooooo`03ool00?oooooooooo04Kooooo00?o0000ooooooooool0j?ooool0027ooooo00?o0000
ooooooooool03oooool00ooo003oooooooooo`18ooooo`03o`000?oooooooooo0>Oooooo000Qoooo
o`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0B_ooool00ol0003oooooooooo`3Voooo
o`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04[ooooo00?o0000oooooooo
ool0i_ooool0027ooooo0ol0000=ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0
iOooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1>ooooo`03ool00?oo
oooooooo0>Cooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Coooool0
0ooo003o0000ooooo`3Tooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
057ooooo00?oo`00ooooooooool0hoooool0027ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1Cooooo`03ool00?oooooooooo0>;ooooo000Qooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0E?ooool00ooo003oooooooooo`3Qooooo`008Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05Gooooo00?oo`00ooooooooool0hOooool0027ooooo00?o0000
ooooooooool01oooool00ooo003oooooooooo`1Gooooo`03ool00?oooooooooo0>3ooooo000Qoooo
o`?o00001oooool00ooo003oooooooooo`1Gooooo`03ool00?l0003ooooo0>3ooooo000Qooooo`03
o`000?oooooooooo00Kooooo00?oo`00ooooooooool0=?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool00ooo003oooooooooo`0[
ooooo`Co000000?o410@ooooooooool0>oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool5o`0001_ooooo000Qooooo`03o`000?oooooo
oooo00Gooooo00?oo`00ooooooooool0=Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00oooooo00?oo`00ooooooooool0;?ooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`05ooooo`03ool00?oo
oooooooo03Gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00kooooo
00?oo`00ooooooooool0;?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0??ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003ooooooooo
o`04ooooo`03ool00?oooooooooo03Kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo013ooooo00?oo`00ooooooooool0:oooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo00kooooo00?oMgMgoc8b<_ooool0?_ooool00onHV9So8B4Qonk^kP0Kooooo`008Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oo003ooooo03Oooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`04Oooool00ooo003o0000ooooo`0[ooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
043ooooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool00oooool00ooo003o
ooooooooo`0gooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Doooo
o`03ool00?oooooooooo02[ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06Oooool0027ooooo0ol00002ooooo`03
ool00?oooooooooo03Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0?oooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qoooo
o`06o`000?ooooooooooooooool0003oo`00>_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000Dooooo`03o`000?oooooooooo02Oooooo00?oEEEEofIVI_l00000?oooool00omEEEGoIVIV
o`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qooooo`05o`00
0?oooooooooooooooooo0000IOooool00ol0003oooooooooo`3Jooooo`008Oooool01Ol0003ooooo
ooooool0003oo`0006Kooooo00?o0000ooooooooool0fOooool0027ooooo00Co0000ooooool0003o
o`00Ioooool00ol0003oooooooooo`3Iooooo`008Oooool00ol0003oooooool0001Yooooo`03o`00
0?oooooooooo0<kooooo0_l00002ooooo`;o00001?ooool0027ooooo0_l0001Zooooo`03o`000?oo
oooooooo0<kooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooooooo`0003;o0000
00?oo`00o`000?l000001Ol0000<ooooo`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`06ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oo003o000001?ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00Co0000ool00?oooooo
00004oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003oooooooooo`1/ooooo`03
ool00?oooooooooo0;Cooooo00?o0000ool00?ooool05?ooool2o`0000;ooooo0_l00004ooooo`00
8Oooool00ol0003oooooooooo`1/ooooo`03ool00?oooooooooo0;?ooooo00?o0000ooooooooool0
7oooool0027ooooo00?o0000ooooooooool0KOooool00ooo003oooooooooo`2aooooo`03o`000?oo
oooooooo023ooooo000Qooooo`03o`000?oooooooooo06kooooo00?oo`00ooooooooool0[_ooool2
o`0002?ooooo000Qooooo`03o`000?oooooooooo06kooooo00?oo`00ooooooooool0[Oooool00ol0
003oooooooooo`0Sooooo`008Oooool3o`0006oooooo00?oo`00ooooooooool0Zoooool00ol0003o
ooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`1`ooooo`03ool00?oooooooooo0:Wooooo
00?o0000ooooooooool09Oooool0027ooooo00?o0000ooooooooool0L?ooool00ooo003ooooooooo
o`2Xooooo`03o`000?oo003ooooo02Kooooo000Qooooo`03o`000?oooooooooo077ooooo00?oo`00
ooooooooool0YOooool2o`000003ool00?oooooooooo02Kooooo000Qooooo`03o`000?oooooooooo
077ooooo00?oo`00o`000?ooool0Y?ooool00ol0003oo`00ool0000Yooooo`008Oooool00ol0003o
ooooooooo`1booooo`03ool00?oooooooooo0:;ooooo00?o0000ool00?ooool0:_ooool0027ooooo
00?o0000ooooooooool0Loooool00ooo003oooooooooo`2Pooooo`03o`000?oo003ooooo02_ooooo
000Qooooo`?o0000Loooool00ol0003oooooooooo`2Oooooo`03o`000?oo003ooooo02cooooo000Q
ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0WOooool2ool002kooooo000Qoooo
o`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0Voooool00ooo003oooooooooo`0^oooo
o`008Oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo09[ooooo00?oo`00oooooooo
ool0;oooool0027ooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`2Hooooo`03ool0
0?oooooooooo033ooooo000Qooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0U_oo
ool00ooo003oooooooooo`0aooooo`008Oooool00ol0003oooooooooo`1gooooo`03o`000?oooooo
oooo09Gooooo00?o0000ooooooooool0<_ooool0027ooooo00?o0000ooooooooool0N?ooool00ol0
003oooooooooo`2Booooo`;o0000=Oooool0027ooooo0ol0001iooooo`03ool00?oooooooooo093o
oooo00?o0000ooooooooool0=Oooool0027ooooo00?o0000ooooooooool0NOooool00ooo003ooooo
ooooo`2?ooooo`03o`000?oooooooooo03Kooooo000Qooooo`03o`000?oooooooooo07[ooooo00?o
o`00ooooooooool0SOooool00ol0003oooooooooo`0gooooo`008Oooool00ol0003oooooooooo`1k
ooooo`03ool00?oooooooooo08_ooooo00?o0000ooooooooool0>?ooool0027ooooo00?o0000oooo
ooooool0O?ooool00ooo003oooooooooo`27ooooo`;oo`0000?o0000ooooooooool0>Oooool0027o
oooo00?o0000ooooooooool0O?ooool00ooo003oooooooooo`26ooooo`03ool00?l0003ooooo03co
oooo000Qooooo`03o`000?oooooooooo07gooooo00?oo`00ooooooooool0Q?ooool00ooo003o0000
ooooo`0mooooo`008Oooool3o`0007kooooo00?oo`00ooooooooool0P_ooool00ooo003o0000oooo
o`0nooooo`008Oooool00ol0003oooooooooo`1oooooo`03ool00?oooooooooo083ooooo00?oo`00
o`000?ooool0?oooool0027ooooo00?o0000ooooooooool0Ooooool00ol0003oo`00ooooo`1noooo
o`;oo`0000?o0000ooooooooool0?oooool0027ooooo00?o0000ooooooooool0P?ooool00ooo003o
ooooooooo`1looooo`03ool00?l0003ooooo04;ooooo000Qooooo`03o`000?oooooooooo087ooooo
00?oo`00ooooooooool0N_ooool00ooo003o0000ooooo`13ooooo`001oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003o
ooooooooo`22ooooo`03ool00?oooooooooo07Sooooo00?oo`00o`000?ooool0A?ooool000Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03
o`000?oooooooooo08;ooooo00?o0000ool00?ooool0Moooool00ooo003oooooooooo`15ooooo`00
1oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`0008?o
oooo00?o0000ooooooooool0MOooool00ooo003oooooooooo`16ooooo`001oooool01Ol0003ooooo
oooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`24ooooo`03
o`000?oooooooooo07?ooooo00?o0000ooooooooool0Aoooool000Oooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`25oooo
o`03o`000?oooooooooo073ooooo0_l0001:ooooo`001oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo
06oooooo00?o0000ooooooooool0B_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo04_ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
00Gooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`1Zooooo`;o0000C_ooool0027o
oooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`1Vooooo`;oo`0000?o0000oooooooo
ool0C_ooool0027ooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`1Uooooo`03ool0
0?l0003o0000057ooooo000Qooooo`?o0000ROooool00ol0003oo`00ooooo`1Sooooo`03ool00?l0
003ooooo05;ooooo000Qooooo`03o`000?oooooooooo08[ooooo00?oo`00ooooooooool0HOooool0
0ooo003o0000ooooo`1Cooooo`008Oooool00ol0003oooooooooo`2;ooooo`03ool00?oooooooooo
05kooooo0_oo001Fooooo`008Oooool00ol0003oooooooooo`2<ooooo`03ool00?oooooooooo05co
oooo00?oo`00o`000?ooool0E_ooool0027ooooo00?o0000ooooooooool0SOooool00ooo003ooooo
ooooo`1Jooooo`03ool00?oooooooooo05Oooooo000Qooooo`03o`000?oooooooooo08kooooo00?o
o`00ooooooooool0Eoooool00ol0003oo`00ooooo`1Iooooo`008Oooool00ol0003oooooooooo`2?
ooooo`03ool00?oooooooooo05Gooooo0_oo001Kooooo`008Oooool3o`00093ooooo00?oo`00oooo
ooooool0D_ooool2ool005gooooo000Qooooo`03o`000?oooooooooo097ooooo0_oo001@ooooo`;o
0000Goooool0027ooooo00?o0000ooooooooool0Toooool2ool004gooooo00?o0000ooooooooool0
Goooool0027ooooo00?o0000ooooooooool0U?ooool00ol0003oo`00ooooo`19ooooo`;o0000H_oo
ool0027ooooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`15ooooo`;o0000I?ooool0
027ooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo
06Cooooo000Qooooo`03o`000?oooooooooo09Sooooo0_l00010ooooo`?oo`00Ioooool0027ooooo
00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0kooooo`;oo`0000?o0000ooooooooool0
Ioooool0027ooooo0ol0002Kooooo`;o0000>Oooool2ool00003o`000?oooooooooo06Wooooo000Q
ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool0=?ooool2ool00003o`000?oooooo
oooo06_ooooo000Qooooo`03o`000?oooooooooo09gooooo0ooo000booooo`;oo`00L?ooool0027o
oooo00?o0000ooooooooool0X?ooool2ool002kooooo0_oo001booooo`008Oooool00ol0003ooooo
ooooo`2Rooooo`;oo`00:_ooool2ool007Cooooo000Qooooo`03o`000?oooooooooo0:Cooooo0_oo
00000ol0003oooooooooo`0Rooooo`?o0000M_ooool0027ooooo00?o0000ooooooooool0Y_ooool0
1?oo003o0000o`000?l0000Nooooo`?o0000NOooool0027ooooo0ol0002Wooooo`?oo`000ol0000H
ooooo`?o0000O?ooool0027ooooo00?o0000ooooooooool0Z_ooool3ool000?o00004Oooool4ool0
07oooooo000Qooooo`03o`000?oooooooooo0;3ooooo1?l0000=ool008?ooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool4
o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo
0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool0
01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`03
oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0:Cooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2Wooooo`00Poooool3o`0001Co
oooo00?o8B4QomgMgOooool01_ooool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@413ogMgM0:Oo
oooo001kooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo
00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03oiRHV?mEEEGooooo00Kooooo00?oEEEE
oiRHV?ooool00_ooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool01_nj^[[oA4A4oooooooo
ooooQhN7ofIVIQCooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@1eooooo`00Noooool01ol@413ogMgMogMgMolQ8B7ooooo
ohN7QomVIVH00_ooool00ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?oo
ool00ol0003ogMgMooooo`05ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj0_ooool00oo^k^ko0000ooooo`0;oooo
o`Ko00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`1dooooo`00Noooool01ol0003oooooomgMgOlb
<S;oooooonk^k_l@41000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
0_mgMgL6ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgM
ooooool00004ooooo`03o`000?oooooooooo01;ooooo00Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0Loooool007_ooooo00CoEEEEojVYZOoo
oooo00000_ooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00Kooooo00?ok^k^
oa0@4?o^k^h01Oooool00olb<S;oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7
ofIVI_oooooo00001?ooool00ol0003oooooooooo`0:ooooo`Ko00000_ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`1dooooo`00Nooo
ool00ooMgMgo8B4Qonk^kP03ooooo`04o`000?oooooo0000o`0000gooooo00?o0000ooooooooool0
1oooool00omEEEGoV9RHooooo`04ooooo`03o`000?o^k^kooooo00Gooooo00?oMgMgofIVI_ooool0
2_ooool01?oMgMgo410@ooooool00003ooooo`03onk^k_l0003ooooo01?ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c01e
ooooo`00O?ooool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo00cooooo00?o410@o`00
0?l000000ol00006ooooo`03omgMgOl@413ooooo00Cooooo00?oEEEEogMgMoooool01_ooool00ol0
003oooooooooo`08ooooo`Oo000000?oooooogMgMomEEED05?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1gooooo`00T_ooool00ol0
003oooooooooo`08ooooo`03oeEEEOnHV9Sooooo00?ooooo00?ogMgMoa0@4?o^k^h00_ooool01Ol0
003o^[ZjoooooonHV9So410@017ooooo00?ok^k^oa0@4?oMgMd05?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo07Oooooo
002Booooo`03o`000?oooooooooo00Sooooo00?o^[ZjodA4A?ooool01?ooool02OmgMgOoIVIVoooo
ooooooooV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`03ofIVI_mgMgOooooo01Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0007Kooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .22786 L
.08255 .19097 L
.10458 .15741 L
.11448 .14507 L
.12507 .13393 L
.13499 .1255 L
.14415 .11947 L
.14911 .11692 L
.15437 .11477 L
.15964 .11318 L
.16265 .11253 L
.16399 .1123 L
.16546 .11209 L
.1668 .11193 L
.16805 .11182 L
.16925 .11174 L
.17052 .11169 L
.17178 .11167 L
.17296 .11168 L
.17401 .11171 L
.17516 .11177 L
.17642 .11187 L
.1778 .11201 L
.1806 .11241 L
.18318 .11292 L
.1856 .11351 L
.1906 .11508 L
.19605 .11732 L
.20595 .12276 L
.21559 .12964 L
.22451 .13731 L
.26377 .18284 L
.30152 .23687 L
.34173 .29432 L
.38041 .34181 L
.40006 .36169 L
.42155 .37989 L
.44231 .39401 L
.46118 .40403 L
.48079 .4118 L
.49156 .41502 L
.50174 .41742 L
.51146 .41916 L
.51678 .4199 L
.52175 .42047 L
.52634 .42088 L
.53054 .42117 L
.53277 .42129 L
.5352 .42139 L
Mistroke
.53653 .42144 L
.53777 .42148 L
.53893 .42151 L
.5402 .42153 L
.5415 .42155 L
.5422 .42156 L
.54286 .42156 L
.54404 .42156 L
.5453 .42156 L
.54601 .42156 L
.54678 .42155 L
.5475 .42154 L
.54818 .42153 L
.54945 .42151 L
.5508 .42147 L
.55325 .4214 L
.55554 .4213 L
.56077 .42102 L
.56545 .42069 L
.56973 .42031 L
.57939 .41926 L
.59835 .41642 L
.61906 .41234 L
.65968 .40226 L
.69877 .39098 L
.74032 .37826 L
.78036 .36587 L
.81888 .35411 L
.85985 .34193 L
.8993 .33055 L
.93724 .31986 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .23002 L
.08255 .19216 L
.10458 .15723 L
.11448 .14436 L
.12507 .13279 L
.13499 .12411 L
.14415 .11799 L
.14911 .11545 L
.15437 .11334 L
.15691 .11254 L
.15964 .11183 L
.16121 .1115 L
.16265 .11124 L
.16401 .11104 L
.16546 .11086 L
.16615 .11079 L
.1668 .11074 L
.16802 .11066 L
.16916 .11062 L
.17039 .1106 L
.17104 .11061 L
.17176 .11062 L
.1725 .11065 L
.1732 .11068 L
.17445 .11077 L
.17578 .1109 L
.17842 .11126 L
.18092 .11173 L
.1856 .11294 L
.19019 .11454 L
.19525 .11677 L
.20551 .12266 L
.22393 .13749 L
.24327 .15796 L
.26413 .18417 L
.30527 .24235 L
.34489 .298 L
.383 .34426 L
.40425 .36551 L
.42356 .38166 L
.44388 .39538 L
.46261 .40517 L
.48179 .41253 L
.4919 .41541 L
.50259 .41777 L
.51203 .41931 L
.51732 .41996 L
.52216 .42043 L
.52666 .42077 L
Mistroke
.52903 .42091 L
.53156 .42103 L
.53399 .42112 L
.53619 .42118 L
.53725 .4212 L
.5384 .42122 L
.53948 .42123 L
.54048 .42123 L
.54175 .42123 L
.54295 .42123 L
.54402 .42122 L
.54519 .42121 L
.54647 .42118 L
.54782 .42115 L
.55024 .42108 L
.55457 .4209 L
.55934 .42063 L
.56448 .42025 L
.57001 .41975 L
.58002 .41861 L
.6001 .41558 L
.62121 .4115 L
.65937 .40245 L
.69998 .39117 L
.73908 .37926 L
.78063 .36603 L
.82067 .35332 L
.85918 .34162 L
.90015 .32988 L
.93961 .31886 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool09_ooool00ooo003o0000o`000008o`000?oooooo5?ooool0027ooooo00?o0000oooo
ooooool09?ooool2ool00003o`000?oooooooooo00Sooooo1?oo003ooooooa3ooooo000Qooooo`?o
00008_ooool2ool000oooooo0_l000000ooo003oooooooooo`3oooooo`gooooo000Qooooo`03o`00
0?oooooooooo027ooooo00?oo`00ooooooooool04_ooool2ool00?oooooo3Oooool0027ooooo00?o
0000ooooooooool07oooool2ool001Oooooo00?oo`00ooooooooool0ooooool:ooooo`008Oooool0
0ol0003oooooooooo`0Nooooo`03ool00?l0003ooooo01Sooooo00?oo`00ooooooooool0ooooool9
ooooo`008Oooool00ol0003oooooooooo`0Mooooo`03ool00?l0003ooooo01[ooooo00?oo`00oooo
ooooool0ooooool8ooooo`008Oooool00ol0003oooooooooo`0Mooooo`03ool00?oooooooooo01_o
oooo00?oo`00ooooooooool0ooooool7ooooo`008Oooool00ol0003oooooooooo`0Looooo`03ool0
0?oooooooooo01gooooo00?oo`00ooooooooool0ooooool6ooooo`008Oooool3o`0001_ooooo00?o
o`00ooooooooool07_ooool00ooo003oooooooooo`3oooooo`Kooooo000Qooooo`03o`000?oooooo
oooo01[ooooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`3oooooo`Gooooo000Qoooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`3ooooo
o`Cooooo000Qooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`3oooooo`?ooooo000Qooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`3oooooo`;ooooo000Qooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`3oooooo`7ooooo000Qooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`3oooooo`008Oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0ooooool0027o
oooo0ol0000Eooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0o_ooool0027ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0/ooooo`03o`000?oo003ooooo0?gooooo
000Qooooo`03o`000?oooooooooo01Cooooo00?oo`00ooooooooool0;_ooool00ooo003ooooooooo
o`3looooo`008Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo003ooooo033ooooo00?oo`00
ooooooooool0noooool0027ooooo00?o0000ooooooooool04oooool00ooo003oooooooooo`0aoooo
o`03ool00?oooooooooo0?[ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo01;ooooo00?oo`00
ooooooooool0<oooool00ooo003oooooooooo`3iooooo`001oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool04_ooool0
0ooo003oooooooooo`0cooooo`03ool00?oooooooooo0?Wooooo0005o`0000;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0000Aooooo`03ool00?oooooo
oooo03Gooooo00?oo`00ooooooooool0n?ooool000Oooooo00Go0000ooooooooooooooooo`00000?
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`0g
ooooo`03ool00?oooooooooo0?Oooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool04?ooool00ooo003ooooooooo
o`0gooooo`03o`000?oo003ooooo0?Oooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool0>Ooo
ool00ooo003oooooooooo`3fooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo003ooooo03_ooooo00?o
o`00ooooooooool0mOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo03cooooo00?oo`00ooooooooool0m?oo
ool0027ooooo00?o0000ooooooooool03Oooool00ooo003oooooooooo`0mooooo`03o`000?oo003o
oooo0?Cooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000ool00?ooool0?oooool00ol0
003oooooooooo`3cooooo`008Oooool3o`0000cooooo00?oo`00ooooooooool0@?ooool00ol0003o
ooooooooo`3booooo`008Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo047ooooo
00?o0000ooooooooool0l_ooool0027ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`12ooooo`03o`000?oooooooooo0?7ooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0A?ooool00ol0003oooooooooo`3`ooooo`008Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0koooool0027ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo0>oooooo000Qooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`3^ooooo`008Ooo
ool3o`0000Sooooo00?o0000ooooooooool0BOooool00ooo003oooooooooo`3]ooooo`008Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo04[ooooo00?oo`00ooooooooool0kOooool0
027ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1;ooooo`03ool00?oooooooooo
0>cooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000ool00?ooool0C?ooool00ooo003o
0000ooooo`3/ooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oo003ooooo04gooooo
00?oo`00o`000?ooool0joooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oo`00oooo
o`1?ooooo`03ool00?oooooooooo0>[ooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000
ool00?ooool0D?ooool00ooo003oooooooooo`3Yooooo`008Oooool00ol0003oooooooooo`04oooo
o`03o`000?oo003ooooo057ooooo00?oo`00o`000?ooool0jOooool0027ooooo0ol00004ooooo`03
o`000?oo003ooooo05;ooooo00?oo`00ooooooooool0j?ooool0027ooooo00?o0000ooooooooool0
0oooool00ol0003oo`00ooooo`0gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@07ooooo`03ool00?oooooooooo03?ooooo1?l000000ol@
413oooooooooo`0kooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0mooooo`Go00006oooool0027ooooo00?o0000ooooooooool00oooool00ol0
003oo`00ooooo`0gooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01_ooool00ooo003o0000ooooo`0eooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0??ooool01OnHV9So8B4Qonk^k_oo
ooooA4A401_ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0=oooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool01_ooool00ooo003o0000oooo
o`0dooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Qooooo`03o`000?oooooooooo00;ooooo00?o0000
ool00?ooool0>?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool02?oo
ool00ooo003oooooooooo`0cooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool03_oo
ool00omgMgOo<S8booooo`0nooooo`03oiRHV?lQ8B7ok^k^01_ooooo000Qooooo`03o`000?oooooo
oooo00;ooooo00?oo`00ooooooooool0>?ooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00:ooooo`03ool00?oooooooooo03;ooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0@?ooool00omgMgOo
IVIVooooo`0Jooooo`008Oooool01_l0003ooooooooooooooooo0000ool003[ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool0
0ol0003oooooooooo`0Iooooo`008Oooool3o`000003oooooooo003ooooo03[ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0?oooool0
1Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`05o`000?ooooooooooo`000?oo0000>ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000=ooooo`03o`000?oooooooooo02kooooo
00?oEEEEofIVI_l00000?oooool00omEEEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@
o`000?lQ8B7oc<c<01_ooooo000Qooooo`04o`000?ooooooooooool005oooooo00?o0000oooooooo
ool0hOooool0027ooooo00?o0000ooooool00000HOooool00ol0003oooooooooo`3Pooooo`008Ooo
ool00ol0003oooooo`00001Qooooo`03o`000?oooooooooo0>3ooooo000Qooooo`;o0000Hoooool0
0ol0003oooooooooo`3Eooooo`;o00000_ooool2o`0000Cooooo000Qooooo`;o0000I?ooool00ol0
003oooooooooo`3Dooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool001[oooooK_l00000
0ooo003o0000o`00002oo`0000;oo`001ol0000<ooooo`04omgMgOl0003o410@olc<c0Gooooo000Q
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00[ooooo00?oo`00o`000?ooool03Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool3ool00003ooooool0003o
oooo01;ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oo003oo`0000Cooooo00?o0000ooooooooool04Oooool0
1?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003oooooooooo`1Vooooo`03ool00?oooooo
oooo0;Cooooo0ol0000Jooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo
06Oooooo00?oo`00ooooooooool0[oooool4o`0002Oooooo000Qooooo`03o`000?oooooooooo06So
oooo00?oo`00ooooooooool0ZOooool3ool000;o0000:oooool0027ooooo00?o0000ooooooooool0
JOooool00ooo003oooooooooo`2Uooooo`?oo`0000?o0000ooooooooool0;Oooool0027ooooo00?o
0000ooooooooool0JOooool00ol0003oo`00ooooo`2Qooooo`Coo`00<oooool0027ooooo0ol0001Z
ooooo`03o`000?oo003ooooo09cooooo1?oo000gooooo`008Oooool00ol0003oooooooooo`1[oooo
o`03o`000?oo003ooooo09Wooooo0_oo00000ol0003oooooooooo`0hooooo`008Oooool00ol0003o
ooooooooo`1/ooooo`03o`000?oo003ooooo09Gooooo0ol0000mooooo`008Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oo003ooooo093ooooo1?l00010ooooo`008Oooool00ol0003ooooooooo
o`1^ooooo`03ool00?oooooooooo08[ooooo0ooo0002o`0004Cooooo000Qooooo`03o`000?oooooo
oooo06oooooo00?o0000ooooooooool0Q_ooool3ool00003o`000?oooooooooo04Kooooo000Qoooo
o`03o`000?oooooooooo073ooooo00?o0000ooooooooool0P_ooool3ool004cooooo000Qooooo`?o
0000LOooool00ol0003oooooooooo`1nooooo`?oo`00Coooool0027ooooo00?o0000ooooooooool0
L_ooool00ol0003oooooooooo`1jooooo`?oo`00D_ooool0027ooooo00?o0000ooooooooool0Looo
ool2o`0007Oooooo0_l000000ooo003oooooooooo`1Cooooo`008Oooool00ol0003oooooooooo`1e
ooooo`03o`000?oooooooooo073ooooo1?l0001Hooooo`008Oooool00ol0003oooooooooo`1foooo
o`03ool00?l0003ooooo06cooooo0ol0001Looooo`008Oooool00ol0003oooooooooo`1gooooo`03
ool00?l0003ooooo06Sooooo0_oo00000ol0003oooooooooo`1Mooooo`008Oooool00ol0003ooooo
ooooo`1hooooo`03ool00?l0003ooooo06Cooooo0ooo001Rooooo`008Oooool00ol0003ooooooooo
o`1iooooo`03ool00?l0003o000005oooooo00Co0000ool00?oo003oo`00IOooool0027ooooo0ol0
001jooooo`;oo`0000?o0000ooooooooool0FOooool01?l0003oo`00ool00?oo001Xooooo`008Ooo
ool00ol0003oooooooooo`1looooo`;oo`00Eoooool01?l0003oo`00ool00?oo001[ooooo`008Ooo
ool00ol0003oooooooooo`1nooooo`03ool00?oooooooooo057ooooo0_l00002ool006kooooo000Q
ooooo`03o`000?oooooooooo07oooooo0_oo001=ooooo`Co0000L_ooool0027ooooo00?o0000oooo
ooooool0P?ooool00ol0003oo`00ooooo`17ooooo`Co0000M_ooool0027ooooo00?o0000oooooooo
ool0P_ooool00ooo003o0000ooooo`11ooooo`?o00000_oo001iooooo`008Oooool00ol0003ooooo
ooooo`24ooooo`;o0000??ooool4o`0000?oo`00Noooool0027ooooo0ol00026ooooo`?o0000=_oo
ool3o`0000Coo`00O_ooool0027ooooo00?o0000ooooooooool0ROooool3o`00033ooooo00?o0000
ool00?oo00000ooo0022ooooo`008Oooool00ol0003oooooooooo`2<ooooo`?o0000:_ooool2o`00
00;oo`00Qoooool0027ooooo00?o0000ooooooooool0S?ooool3ool000?o00008_ooool5o`0008_o
oooo000Qooooo`03o`000?oooooooooo08oooooo1ooo000Hooooo`?oo`000ol0002@ooooo`001ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01?ooool00ol0003oooooooooo`2Fooooo`Goo`001Ol0000>ool009Kooooo0007ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003o
ooooooooo`02ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooo
ooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0
003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hoooo
o`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?oo
ool3o`000?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo
00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`00
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00Z?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:?ooooo0027ooooo`?o0000
4oooool00olQ8B7ogMgMooooo`07ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0
Xoooool007kooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00?ooooo00?o0000oooooooo
ool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00?oV9RHoeEEEOooool01oooool01?mE
EEGoV9RHooooooooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool00onj^[[oA4A4ooooo`02
ooooo`03ohN7QomVIVKooooo01;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool01OnHV9So410@o`000?lb<S;oc<c<07_ooooo001nooooo`07oa0@4?oMgMgoMgMgob4Q8Ooooooo
QhN7ofIVIP03ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_o^k^koMgMgoa0@4003oooo
o`03o`000?oMgMgooooo00Kooooo00Wo0000oooooooooooooooooiRHV?lQ8B7ok^k^oooooom4A4@0
2_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P?ooooo00?ok^k^o`000?ooool02oooool6o`00
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMg
oc8b<P1kooooo`00O_ooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@41000oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo0_mgMgL7ooooo`03oc8b<_oooooooooo00;o
oooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool00005ooooo`03o`000?oooooooooo
017ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo07Wooooo001noooo
o`04oeEEEOnYZJWoooooo`0000;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oo
oooooooo00Gooooo00?ok^k^oa0@4?o^k^h01_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ
8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001Oooool00ol0003oooooooooo`0:ooooo`Ko0000
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ojVYZOl@413ooooo07[ooooo
001nooooo`03omgMgOlQ8B7ok^k^00?ooooo00?o0000ooooooooool00_l0000=ooooo`03o`000?oo
oooooooo00Kooooo00?oEEEEoiRHV?ooool01Oooool00ol0003ok^k^ooooo`04ooooo`03ogMgMomV
IVKooooo00[ooooo00CogMgMoa0@4?oooooo00001?ooool00oo^k^ko0000ooooo`0Booooo`05o`00
0?ooooooooooooooool000003Oooool00ol@413o0000okZj^P1kooooo`00Ooooool00onHV9SoMgMg
ooooo`02ooooo`03o`000?oooooooooo00gooooo00?o410@o`000?l000000ol00005ooooo`03omgM
gOl@413ooooo00Gooooo00?oEEEEogMgMoooool01Oooool00ol0003oooooooooo`08ooooo`Oo0000
0_ooool00omgMgOoEEEEooooo`0Booooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o
8B4Qooooo`1jooooo`00U_ooool00ol0003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo
00WogMgMoa0@4?o^k^koooooo`000?nj^[[ooooooiRHV?l@41004_ooool00oo^k^ko410@omgMg@0C
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RHoooooonj^[[o000007_ooooo
002Fooooo`03o`000?oooooooooo00Oooooo00?o^[ZjodA4A?ooool01Oooool02?mgMgOoIVIVoooo
oonHV9So410@o`000?lQ8B7oc<c<4_ooool00omVIVKoMgMgooooo`0Cooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY07_ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .2732 L
.06244 .23845 L
.08426 .20667 L
.0949 .1943 L
.10458 .18502 L
.11403 .17786 L
.12297 .17283 L
.12787 .17078 L
.1324 .16934 L
.13476 .16876 L
.13737 .16825 L
.13868 .16804 L
.14009 .16786 L
.14142 .16773 L
.14264 .16763 L
.14392 .16756 L
.14514 .16753 L
.14622 .16752 L
.1474 .16754 L
.14869 .16759 L
.14934 .16763 L
.15005 .16768 L
.15132 .16779 L
.15248 .16792 L
.15476 .16824 L
.15721 .16869 L
.16162 .16977 L
.16672 .17142 L
.17226 .17367 L
.18234 .17888 L
.20212 .1925 L
.22313 .21021 L
.26088 .24409 L
.28185 .26129 L
.30108 .27498 L
.32112 .28671 L
.33977 .29519 L
.35869 .30144 L
.3687 .30384 L
.37426 .30491 L
.37939 .30575 L
.38427 .3064 L
.38963 .30698 L
.39503 .3074 L
.39798 .30758 L
.40074 .3077 L
.40198 .30774 L
.40334 .30778 L
.40463 .30781 L
Mistroke
.40581 .30783 L
.40699 .30784 L
.40806 .30785 L
.40929 .30785 L
.41045 .30785 L
.41173 .30784 L
.41237 .30783 L
.41307 .30782 L
.41547 .30776 L
.41682 .30772 L
.41827 .30767 L
.42089 .30755 L
.42619 .30723 L
.43109 .30685 L
.44217 .30567 L
.45194 .30432 L
.4623 .30261 L
.50011 .29467 L
.54036 .28491 L
.5791 .276 L
.59879 .27205 L
.62029 .26834 L
.64109 .26545 L
.65997 .26348 L
.67008 .26268 L
.67962 .2621 L
.68486 .26186 L
.68968 .26167 L
.69498 .26152 L
.69765 .26147 L
.69917 .26144 L
.70058 .26142 L
.70177 .2614 L
.70309 .26139 L
.70441 .26138 L
.70513 .26138 L
.70581 .26137 L
.70706 .26137 L
.7082 .26137 L
.70945 .26137 L
.71077 .26138 L
.71188 .26138 L
.71307 .26139 L
.71521 .26142 L
.71775 .26146 L
.72007 .2615 L
.72522 .26164 L
.73082 .26185 L
.74097 .26235 L
.75042 .26299 L
Mistroke
.76083 .26386 L
.78186 .26615 L
.82217 .27232 L
.86096 .28008 L
.9022 .28975 L
.94193 .29993 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .273 L
.06244 .23719 L
.08255 .20715 L
.09409 .19365 L
.10458 .18392 L
.1094 .18027 L
.11464 .1769 L
.11917 .17448 L
.12415 .17231 L
.12944 .17059 L
.13233 .16989 L
.13504 .16938 L
.13633 .16919 L
.13757 .16904 L
.13869 .16893 L
.13988 .16884 L
.14117 .16877 L
.14237 .16873 L
.1431 .16872 L
.1438 .16872 L
.14509 .16874 L
.14625 .16879 L
.1475 .16886 L
.14867 .16896 L
.14974 .16907 L
.15237 .16942 L
.15485 .16986 L
.15979 .17102 L
.16517 .17271 L
.17476 .17672 L
.18364 .18144 L
.22291 .21027 L
.26066 .24263 L
.30086 .27345 L
.31934 .28479 L
.33955 .2947 L
.35959 .30185 L
.37052 .30464 L
.38069 .30656 L
.38574 .30728 L
.39121 .3079 L
.39372 .30813 L
.39638 .30833 L
.39868 .30847 L
.40114 .3086 L
.40237 .30865 L
.40353 .30869 L
.40467 .30872 L
.40572 .30874 L
Mistroke
.40671 .30876 L
.40776 .30877 L
.40893 .30878 L
.41 .30878 L
.41125 .30878 L
.41241 .30877 L
.41367 .30875 L
.41501 .30872 L
.41726 .30865 L
.41973 .30855 L
.42499 .30825 L
.42996 .30786 L
.43928 .30687 L
.44931 .30547 L
.46021 .30362 L
.50104 .29455 L
.54036 .2846 L
.57816 .27574 L
.59918 .27154 L
.61842 .26826 L
.6385 .26549 L
.65716 .26354 L
.66633 .26281 L
.67612 .26218 L
.68171 .2619 L
.68698 .26169 L
.69171 .26154 L
.69418 .26148 L
.69684 .26142 L
.6994 .26138 L
.70174 .26135 L
.70287 .26134 L
.70409 .26133 L
.70525 .26133 L
.70633 .26133 L
.70756 .26132 L
.70873 .26133 L
.71 .26133 L
.71072 .26133 L
.71138 .26134 L
.71263 .26135 L
.71399 .26136 L
.71675 .2614 L
.71951 .26145 L
.72202 .26151 L
.72765 .26168 L
.73287 .26189 L
.73781 .26213 L
.74751 .26272 L
.7578 .26353 L
Mistroke
.77624 .26541 L
.79579 .26802 L
.8141 .27099 L
.85289 .27875 L
.89413 .28848 L
.93386 .2983 L
.97207 .30791 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`00027ooooo1_l0003ooooooako
oooo000Qooooo`03o`000?oooooooooo01gooooo0ol0000:ool000;o0000oooooolIooooo`008Ooo
ool00ol0003oooooooooo`0Kooooo`;o00003Oooool3ool00003o`000?oooooooooo0?oooooo5Ooo
ool0027ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0@ooooo`;oo`00oooooolF
ooooo`008Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01?ooooo00?oo`00o`00
0?ooool0oooooolCooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0oooooolAooooo`001oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool05Oooool2
ool00003o`000?oooooooooo01Sooooo0_l0003ooooooa7ooooo0005o`0000;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0000Dooooo`03ool00?oooooo
000001gooooo00?o0000ooooooooool0ooooool>ooooo`001oooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Cooooo`03ool00?oooooo
000001oooooo0_l0003oooooo`kooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool04oooool00ooo003o0000oooo
o`0Qooooo`03o`000?oooooooooo0?oooooo2oooool000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ooo003ooooooooo
o`0Sooooo`03o`000?oooooooooo0?oooooo2_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool00ooo003ooooooooo
o`0Tooooo`;oo`00ooooool;ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
0005ooooo`03o`000?oooooooooo013ooooo00?o0000ool00?ooool09oooool00ooo003ooooooooo
o`3oooooo`Sooooo000Qooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0:?ooool0
0ooo003oooooooooo`3oooooo`Oooooo000Qooooo`03o`000?oooooooooo00oooooo00?o0000ool0
0?ooool0:_ooool2ool00?oooooo1oooool0027ooooo0ol0000>ooooo`03o`000?oo003ooooo02go
oooo00?oo`00ooooooooool0ooooool4ooooo`008Oooool00ol0003oooooooooo`0>ooooo`03ool0
0?oooooooooo02kooooo00?oo`00ooooooooool0ooooool3ooooo`008Oooool00ol0003ooooooooo
o`0=ooooo`03ool00?oooooooooo033ooooo00?oo`00ooooooooool0ooooool2ooooo`008Oooool0
0ol0003oooooooooo`0<ooooo`03ool00?oooooooooo03;ooooo00?oo`00ooooooooool0ooooool1
ooooo`008Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Cooooo00?oo`00oooo
ooooool0ooooool0027ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0eooooo`03
ool00?oooooooooo0?kooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
=oooool00ooo003oooooooooo`3mooooo`008Oooool3o`0000Wooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`3looooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool0noooool0027ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0looooo`;o0000noooool0027ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo0?Sooooo000Qooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0@?ooool2o`000?Sooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o
o`00ooooooooool0@_ooool2ool00?Kooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000
ool00?ooool0A?ooool00ol0003oo`00ooooo`3dooooo`008Oooool00ol0003oooooooooo`05oooo
o`03o`000?oo003ooooo04Kooooo00?o0000ool00?ooool0Ooooool2ool000Co0000K_ooool0027o
oooo0ol00005ooooo`03ool00?oooooooooo04Sooooo0_oo001_ooooo`03o`000?oo003oo`0000co
o`0000?o0000ooooooooool00oooool6o`0000_oo`0000?o0000ooooooooool0F_ooool0027ooooo
00?o0000ooooooooool01?ooool00ol0003oo`00ooooo`0fooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o0000ool0000mooooo`Co000000?o410@oooo
ooooool09?ooool6o`00017ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Goo`000_l0000fooooo`Go00006oooool0027ooooo00?o0000oooo
ooooool01?ooool00ooo003oooooooooo`0fooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgo`000?oo0000?_ooool00ol0003oooooooooo`0Oooooo`Coo`000ol0000I
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo1_oo0003
o`0002oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`03
ooooo`03ool00?oooooooooo03Oooooo00Go410@oooooooooooooooooa0@400@ooooo`;o00000_oo
000looooo`03o`000?oooooooooo01Wooooo1_oo00000ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool03?ooool6o`0002[ooooo00?oV9RHob4Q8Oo^k^h07?oo
ool0027ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0gooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`02o`0000;oo`00>_ooool00ol0003ooooooooo
o`0Dooooo`Goo`009_ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo01?ooooo00Co
0000ool00?oo003oo`000_l0000Uooooo`03oiRHV?lQ8B7ok^k^01_ooooo000Qooooo`03o`000?oo
oooooooo00;ooooo00?oo`00ooooooooool0>?ooool01Ol0003ooooooooooooooooo000000cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c003ooooo`;o000000?oo`00ooooooooool0=oooool00ol0003o
ooooooooo`0@ooooo`?o000000?oo`00ooooooooool0:Oooool00ol0003oooooooooo`0;ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06?ooool5ool000;o00008Oooool00omgMgOoIVIVooooo`0Joooo
o`008Oooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo03Sooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ool00?ooool0=oooool00ol0
003oooooooooo`0<ooooo`Co0000;oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01oooooo1Ooo0002o`0001gooooo00?o0000ooooooooool06Oooool0027ooooo0ol000000ooooooo
o`00ooooo`0jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`09oooo
o`;o0000=_ooool00ol0003oooooooooo`06ooooo`?oo`000ol0000cooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool09?ooool3ool000?o00005Oooool01Ol0003o^[ZjoooooonHV9So
410@01_ooooo000Qooooo`05o`000?oooooooooooooooooo0000>oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000:ooooo`;o0000<_ooool00omEEEGoIVIVo`000004ooooo`Coo`000_l0
000eooooo`03oeEEEOmVIVKo000000gooooo1?l0000Yooooo`Co00004Oooool01OnHV9So410@o`00
0?lQ8B7oc<c<01_ooooo000Qooooo`04o`000?ooooooooooool005gooooo0_l0000dooooo`?oo`00
00?o0000ooooooooool0NOooool3o`0002kooooo000Qooooo`04o`000?oooooo0000ool005oooooo
0ol0000/ooooo`03o`000?oo003oo`0000;oo`00P_ooool3ool002_ooooo000Qooooo`03o`000?oo
ooooo`0006?ooooo0ooo000Sooooo`Go00000_oo0029ooooo`Coo`009oooool0027ooooo0_l0001W
ooooo`?oo`007?ooool4o`0009?ooooo00?o0000ool00?oo00000_oo000Iooooo`;o00000_ooool2
o`0000Cooooo000Qooooo`;o0000J_ooool4ool00003o`000?oooooooooo00oooooo0_l00003ool0
0003o`000?oooooooooo09Wooooo00Go0000ool00?oo003oo`00o`00000Eooooo`06onk^k_lQ8B7o
QhN7okZj^_l0003ogMgM1?ooool001[oooooMol00006ool000;o00003?oo002So`0000;oo`002Ol0
000<ooooo`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`04onk^k_lQ8B7o410@onk^kPGooooo
000Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Aooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@013ooooo00?o
0000ooooooooool00_ooool3o`000?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`00
0?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodGooooo
0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
6?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5ooooo`006_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
AOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000H
ooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00:Cooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2Wooooo`00Poooool3
o`0001Cooooo00?o8B4QomgMgOooool01_ooool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@413o
gMgM0:Oooooo001kooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP02ooooo`03o`000?oo
oooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03oiRHV?mEEEGooooo00Kooooo
00?oEEEEoiRHV?ooool00_ooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool01_nj^[[oA4A4
ooooooooooooQhN7ofIVIQCooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool0
1OnHV9So410@o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@1eooooo`00Nooo
ool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00_ooool00ol0003oooooooooo`0;ooooo`05
oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ogMgMooooo`05ooooo`03o`000?oooooooooo
00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj
0_ooool00oo^k^ko0000ooooo`0;ooooo`Ko00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801oooool00omgMgOo<S8booooo`1doooo
o`00Noooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@41000_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Kooooo0_mgMgL6ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RH
ob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool00004ooooo`03o`000?oooooooooo01;ooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
Loooool007_ooooo00CoEEEEojVYZOoooooo00000_ooool01?l0003oooooooooool0000=ooooo`03
o`000?oooooooooo00Kooooo00?ok^k^oa0@4?o^k^h01Oooool00olb<S;oooooooooo`04ooooo`03
oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001?ooool00ol0003oooooooooo`0:oooo
o`Ko00000_ooool01Ol0003ooooooooooooooooo000000kooooo00?oZJVYoa0@4?ooool01_ooool0
0omgMgOo<S8booooo`1dooooo`00Noooool00ooMgMgo8B4Qonk^kP03ooooo`04o`000?oooooo0000
o`0000gooooo00?o0000ooooooooool01oooool00omEEEGoV9RHooooo`04ooooo`03o`000?o^k^ko
oooo00Gooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgo410@ooooool00003ooooo`03onk^k_l0
003ooooo01?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oa0@4?l0003o^[Zj00Cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c01eooooo`00O?ooool00onHV9SoMgMgooooo`02ooooo`03o`00
0?oooooooooo00cooooo00?o410@o`000?l000000ol00006ooooo`03omgMgOl@413ooooo00Cooooo
00?oEEEEogMgMoooool01_ooool00ol0003oooooooooo`08ooooo`Oo000000?oooooogMgMomEEED0
5?ooool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q8Oooool00oooool00ol0003o
ooooooooo`1gooooo`00T_ooool00ol0003oooooooooo`08ooooo`03oeEEEOnHV9Sooooo00?ooooo
00?ogMgMoa0@4?o^k^h00_ooool01Ol0003o^[ZjoooooonHV9So410@017ooooo00?ok^k^oa0@4?oM
gMd05?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000004
ooooo`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo00Sooooo00?o^[ZjodA4
A?ooool01?ooool02OmgMgOoIVIVooooooooooooV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`03ofIV
I_mgMgOooooo01Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT01?ooool4o`0007Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .29983 L
.06244 .29195 L
.06747 .29041 L
.07286 .289 L
.07751 .288 L
.08255 .28713 L
.08564 .28671 L
.08848 .2864 L
.0912 .28618 L
.09258 .28609 L
.09409 .28601 L
.09545 .28596 L
.0967 .28593 L
.09739 .28591 L
.09814 .2859 L
.09885 .2859 L
.0995 .2859 L
.10079 .28591 L
.10196 .28592 L
.10261 .28594 L
.10331 .28596 L
.10458 .28601 L
.10695 .28613 L
.1095 .28631 L
.11409 .28674 L
.11954 .28744 L
.12452 .28822 L
.14558 .29256 L
.16628 .29721 L
.17538 .29898 L
.18022 .29979 L
.18543 .30055 L
.19043 .30115 L
.19501 .30158 L
.19729 .30174 L
.1994 .30187 L
.2016 .30198 L
.20277 .30202 L
.20401 .30205 L
.20466 .30207 L
.20534 .30208 L
.20657 .3021 L
.20788 .30211 L
.20863 .3021 L
.20933 .3021 L
.2106 .30208 L
.21176 .30206 L
.21309 .30202 L
.21436 .30197 L
Mistroke
.21669 .30186 L
.21886 .30171 L
.22376 .30128 L
.22885 .30066 L
.23435 .29979 L
.24432 .29771 L
.25402 .29508 L
.26294 .29217 L
.30248 .27437 L
.3405 .25202 L
.38098 .22596 L
.41994 .20162 L
.46135 .17909 L
.48209 .16966 L
.50125 .1622 L
.52106 .15581 L
.53963 .15109 L
.55834 .14759 L
.56826 .14624 L
.5738 .14563 L
.57895 .14517 L
.58398 .14481 L
.58855 .14456 L
.59116 .14445 L
.59362 .14437 L
.59622 .14431 L
.59768 .14428 L
.59839 .14427 L
.59903 .14426 L
.60025 .14425 L
.60156 .14425 L
.60277 .14425 L
.60392 .14425 L
.60457 .14426 L
.60526 .14427 L
.60649 .14428 L
.60782 .14431 L
.60929 .14434 L
.61198 .14442 L
.61489 .14453 L
.62014 .14481 L
.62509 .14516 L
.6297 .14555 L
.64016 .14671 L
.65035 .14817 L
.66125 .15009 L
.68257 .15488 L
.70272 .16059 L
.74115 .17437 L
.78204 .19263 L
Mistroke
.82141 .21306 L
.85926 .23477 L
.89957 .25951 L
.93836 .28434 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .29823 L
.0522 .2938 L
.06244 .29011 L
.0679 .28861 L
.07286 .28752 L
.07784 .28668 L
.08008 .28639 L
.08255 .28613 L
.08522 .28591 L
.08668 .28582 L
.08805 .28575 L
.08932 .2857 L
.09049 .28567 L
.09113 .28566 L
.09184 .28565 L
.09312 .28564 L
.09389 .28565 L
.09462 .28565 L
.09528 .28566 L
.09599 .28568 L
.09759 .28573 L
.09906 .28579 L
.10174 .28595 L
.10458 .28617 L
.10954 .28669 L
.11406 .28728 L
.12422 .28897 L
.14255 .29279 L
.16325 .29721 L
.17235 .29889 L
.1824 .30041 L
.18701 .30096 L
.19198 .30144 L
.19427 .30162 L
.19668 .30177 L
.19893 .30189 L
.20098 .30197 L
.2022 .30201 L
.20334 .30204 L
.20455 .30206 L
.20587 .30207 L
.20702 .30208 L
.20823 .30207 L
.20927 .30206 L
.21041 .30204 L
.2111 .30202 L
.21175 .30201 L
.21298 .30197 L
.21574 .30184 L
Mistroke
.21813 .30169 L
.22073 .30149 L
.22606 .30094 L
.23107 .30026 L
.24044 .29856 L
.25053 .29611 L
.26142 .29276 L
.2814 .28486 L
.30248 .27442 L
.3405 .25179 L
.38098 .2255 L
.41994 .20123 L
.46135 .17905 L
.48209 .16982 L
.50125 .16253 L
.52106 .15629 L
.53963 .15164 L
.55834 .14814 L
.56826 .14677 L
.5738 .14615 L
.57895 .14566 L
.58398 .14527 L
.58855 .14499 L
.59362 .14476 L
.59641 .14468 L
.59766 .14464 L
.59903 .14462 L
.60036 .14459 L
.6016 .14458 L
.60291 .14457 L
.60364 .14457 L
.60431 .14456 L
.6055 .14456 L
.6068 .14457 L
.60803 .14458 L
.60917 .1446 L
.61047 .14462 L
.6117 .14465 L
.61449 .14473 L
.61721 .14483 L
.62014 .14496 L
.62509 .14526 L
.6297 .14561 L
.64016 .14665 L
.65035 .14802 L
.66125 .14984 L
.68257 .15449 L
.70272 .16015 L
.74115 .17409 L
.78204 .19269 L
Mistroke
.82141 .21328 L
.85926 .23476 L
.89957 .25907 L
.93836 .28399 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0Z?ooool2o`0000_oo`002Ol00026ooooo`008Oooool00ol0003oooooooooo`2Qoooo
o`Co00001Ooo000Dooooo`03o`000?oo003oo`0000?oo`00P?ooool0027ooooo00?o0000oooooooo
ool0WOooool4o`0002?ooooo1Ooo001kooooo`008Oooool00ol0003oooooooooo`2Jooooo`03ool0
0?l0003o000002cooooo1Ooo001fooooo`008Oooool00ol0003oooooooooo`2Gooooo`?oo`00=?oo
ool00ooo003o0000o`00001cooooo`008Oooool00ol0003oooooooooo`2Dooooo`?oo`00>_ooool3
o`00073ooooo000Qooooo`03o`000?oooooooooo097ooooo0ooo0010ooooo`?o0000KOooool0027o
oooo0ol0002>ooooo`?oo`00A_ooool3o`0006[ooooo000Qooooo`03o`000?oooooooooo08_ooooo
0ooo001;ooooo`?oo`0000?o0000ooooooooool0IOooool0027ooooo00?o0000ooooooooool0ROoo
ool2o`00057ooooo0ooo001Uooooo`008Oooool00ol0003oooooooooo`27ooooo`;o0000E_ooool2
ool006?ooooo000Qooooo`03o`000?oooooooooo08Gooooo0_l0001Jooooo`;oo`00HOooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Cooooo00?o0000ooooooooool0Poooool2o`0005kooooo0_oo00000ol0003oooooooooo`1L
ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00?ooooo00?o0000ooooooooool0P?ooool2ool00003o`000?oooooooooo063ooooo0_oo0000
0ol0003oooooooooo`1Jooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`02ooooo`?o0000Ooooool00ooo003o0000ooooo`1Uooooo`03ool00?l0003o
000005[ooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo07gooooo0_oo001[ooooo`;oo`00F?ooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`1kooooo`;oo`0000?o0000ooooooooool0K?ooool00ooo003o0000ooooo`1Eooooo`001oooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1jooooo`03ool00?l0003ooooo077ooooo0_l0001Dooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1hooooo`;oo`00M_oo
ool2o`0005;ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o
0000ooooooooool0M_ooool2ool007[ooooo0_l0001@ooooo`008Oooool00ol0003oooooooooo`1e
ooooo`03ool00?oooooooooo07cooooo0_l0001>ooooo`008Oooool00ol0003oooooooooo`1coooo
o`03o`000?oo003ooooo07oooooo0ooo001<ooooo`008Oooool3o`00077ooooo0_l00025ooooo`;o
o`00B_ooool0027ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`27ooooo`03ool0
0?oooooooooo04Oooooo000Qooooo`03o`000?oooooooooo06kooooo0_l0002;ooooo`;oo`00Aooo
ool0027ooooo00?o0000ooooooooool0K?ooool2o`0008oooooo0_oo0015ooooo`008Oooool00ol0
003oooooooooo`1[ooooo`03o`000?oooooooooo097ooooo00?oo`00ooooooooool0@_ooool0027o
oooo00?o0000ooooooooool0JOooool00ol0003oo`00ool0002Dooooo`;oo`00@_ooool0027ooooo
00?o0000ooooooooool0J?ooool2ool009Sooooo00?oo`00o`000?ooool0?oooool0027ooooo0ol0
001Vooooo`;oo`00Voooool00ooo003o0000ooooo`0nooooo`008Oooool00ol0003oooooooooo`1U
ooooo`03ool00?oooooooooo09gooooo0_l0000mooooo`008Oooool00ol0003oooooooooo`1Soooo
o`;oo`00X_ooool2o`0003_ooooo000Qooooo`03o`000?oooooooooo067ooooo0_oo00000ol0003o
ooooooooo`2Sooooo`03o`000?oooooooooo03Sooooo000Qooooo`03o`000?oooooooooo05oooooo
0_oo00000ol0003oooooooooo`2Vooooo`;o0000>?ooool0027ooooo00?o0000ooooooooool0G_oo
ool00ooo003o0000o`00002[ooooo`;oo`00=_ooool0027ooooo00?o0000ooooooooool0GOooool0
0ooo003o0000ooooo`2^ooooo`03ool00?oooooooooo03?ooooo000Qooooo`03o`000?oooooooooo
05cooooo00?o0000ooooooooool0/?ooool2ool003?ooooo000Qooooo`?o0000F_ooool2o`000;Go
oooo00?oo`00ooooooooool0<?ooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool2o`00
03Kooooo1?l000000ol@413oooooooooo`0kooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0[ooooo`;oo`004?ooool5o`0001_ooooo000Qoooo
o`03o`000?oooooooooo03gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0/ooooo`03ool00?oooooo
oooo00gooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0m
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02o`0003_ooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02cooooo00?o
o`00o`000?ooool03Oooool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003oooooooooo`0m
ooooo`05o`000?ooooooooooooooool000003oooool01?mgMgOo<S8bool00?oo000mooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0^ooooo`;oo`00
3_ooool00onHV9So8B4Qonk^kP0Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05o`000?oo
ooooooooooooool000003?ooool00ol0003o8B4Qo`000002ool003oooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0<Oooool00ooo003o
0000ooooo`0<ooooo`03ogMgMomVIVKooooo01[ooooo000Qooooo`03o`000?oooooooooo03gooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo003oo`00047ooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Cooooo00?oo`00o`000?oo
ool03?ooool00ol0003oooooooooo`0Iooooo`008Oooool3o`0000kooooo3?oo00000ol0003ooooo
ooooo`0Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool00ol0003oo`00ool00013ooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0fooooo`;o
00001oooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`03o`000?oooooooooo00co
oooo0_l000000ooo003o0000o`000009ooooo`Coo`000ol0000Looooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01oooool01Ol0003oo`00ool00?oo003ooooo00Co0000?_ooool00omEEEGoIVIVo`00000o
ooooo`03oeEEEOmVIVKo000000gooooo1?l0000gooooo`;o00001Oooool01OnHV9So410@o`000?lQ
8B7oc<c<01_ooooo000Qooooo`03o`000?oooooooooo00Sooooo1?l0000Eooooo`Go00008Oooool3
ool00=Gooooo00?o0000ooooooooool08_ooool0027ooooo00?o0000ooooooooool01Oooool3o`00
01kooooo0_l000000ooo003oooooooooo`0Iooooo`;o000000?oo`00ooooooooool0eoooool2o`00
02;ooooo000Qooooo`03o`000?oooooooooo00;ooooo0_oo00000ol0003oooooooooo`0Rooooo`Ko
o`0000?o0000ooooooooool03?ooool6o`000=kooooo0_l0000Pooooo`008Oooool00ol0003ooooo
ooooo`02ool002gooooo2Ooo00001?l0003oo`00ool00?oo0002o`000>Gooooo0_oo000Eooooo`;o
00000_ooool2o`0000Cooooo000Qooooo`03o`000?oo003oo`000?oooooo9_ooool2ool001?ooooo
00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0003o00000?oo
0000:?l000000ooo003o0000o`000005o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017o
oooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027o
oooo00?o0000ooooooooool0oooooolkooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom5ooooo`00
1oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413o
oooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00001Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0
003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
AOooool001[ooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00Z?ooool00omgMgOoIVIVooooo`0Gooooo`03
ofIVI_mgMgOooooo0:?ooooo0027ooooo`?o00004oooool00olQ8B7ogMgMooooo`07ooooo`03omgM
gOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Xoooool007kooooo00OoQhN7o`000?mEEEGoIVIV
o`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool02oooool01OnHV9So0000o`000?m4A4Co^[Zj
00;ooooo00?oV9RHoeEEEOooool01oooool01?mEEEGoV9RHooooooooool5o`0000Wooooo00?oEEEE
ojVYZOooool00_ooool00onj^[[oA4A4ooooo`02ooooo`03ohN7QomVIVKooooo01;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo07Wooooo001n
ooooo`07oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP03ooooo`03o`000?oooooooooo00_ooooo
00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oMgMgooooo00Kooooo00Wo0000oooooooo
oooooooooiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P?o
oooo00?ok^k^o`000?ooool02oooool6o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Oooooo00?o0000ooooooooool0N_ooool007kooooo00Oo0000oooooooMgMgo<S8booooooo^
k^ko410@00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`;oMgMg1ooo
ool00olb<S;oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co410@omgMgOoooooo0000
1Oooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0007_o
oooo001nooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Go0000ooooooooooooooooo`00000=oooo
o`03o`000?oooooooooo00Gooooo00?ok^k^oa0@4?o^k^h01_ooool00olb<S;oooooooooo`03oooo
o`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001Oooool00ol0003oooooooooo`0:
ooooo`Ko000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgo
ooooo`0007cooooo001nooooo`03omgMgOlQ8B7ok^k^00?ooooo00?o0000ooooooooool00_l0000=
ooooo`03o`000?oooooooooo00Kooooo00?oEEEEoiRHV?ooool01Oooool00ol0003ok^k^ooooo`04
ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo00001?ooool00oo^k^ko0000oooo
o`0Booooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0001looooo`00
Ooooool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo00gooooo00?o410@o`000?l00000
0ol00005ooooo`03omgMgOl@413ooooo00Gooooo00?oEEEEogMgMoooool01Oooool00ol0003ooooo
ooooo`08ooooo`Oo00000_ooool00omgMgOoEEEEooooo`0Booooo`05oa0@4?ooooooooooooooool@
41003?ooool00omgMgOoc<c<o`00001looooo`00U_ooool00ol0003oooooooooo`07ooooo`03oeEE
EOnHV9Sooooo00Cooooo00WogMgMoa0@4?o^k^koooooo`000?nj^[[ooooooiRHV?l@41004_ooool0
0oo^k^ko410@omgMg@0Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00
001looooo`00U_ooool00ol0003oooooooooo`07ooooo`03okZj^_m4A4Cooooo00Gooooo00SoMgMg
ofIVI_ooooooV9RHoa0@4?l0003o8B4Qolc<c1;ooooo00?oIVIVogMgMoooool04oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0Noooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .33858 L
.06244 .36737 L
.08426 .3936 L
.0949 .4036 L
.10458 .41087 L
.10911 .41363 L
.11403 .41616 L
.11828 .41795 L
.12297 .41949 L
.12553 .42014 L
.12793 .42062 L
.13047 .42101 L
.13189 .42117 L
.13319 .42128 L
.13439 .42135 L
.13551 .42138 L
.13673 .4214 L
.13803 .42138 L
.13928 .42133 L
.14045 .42126 L
.1415 .42117 L
.14264 .42104 L
.14501 .42071 L
.14755 .42023 L
.15214 .41905 L
.1576 .41714 L
.16257 .41494 L
.17339 .4087 L
.18364 .40112 L
.22197 .36133 L
.26275 .30672 L
.30202 .25053 L
.33977 .19905 L
.37997 .15114 L
.41866 .11395 L
.43831 .09869 L
.4598 .08484 L
.48033 .07435 L
.49942 .06694 L
.50995 .06379 L
.51988 .06142 L
.5288 .05977 L
.53379 .05904 L
.53847 .05848 L
.54303 .05805 L
.54793 .05772 L
.55072 .05758 L
.5521 .05753 L
.55337 .05749 L
Mistroke
.55452 .05746 L
.55575 .05744 L
.55645 .05743 L
.55711 .05742 L
.55834 .05742 L
.55957 .05742 L
.56026 .05742 L
.56091 .05743 L
.56222 .05745 L
.56295 .05746 L
.56362 .05748 L
.5661 .05755 L
.56846 .05765 L
.57118 .05781 L
.5737 .05798 L
.57939 .05847 L
.58904 .05967 L
.59809 .06117 L
.61871 .0659 L
.63893 .07218 L
.65744 .07923 L
.69712 .09803 L
.73528 .12014 L
.77589 .14718 L
.81499 .17589 L
.85654 .20853 L
.89658 .24144 L
.93509 .27393 L
.97607 .30891 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .34079 L
.06244 .37024 L
.08255 .39386 L
.09396 .404 L
.09905 .40772 L
.10458 .41119 L
.11004 .41404 L
.11508 .41615 L
.11989 .41771 L
.12235 .41833 L
.125 .41888 L
.12738 .41925 L
.12956 .4195 L
.13061 .41959 L
.13175 .41966 L
.13283 .41971 L
.13384 .41974 L
.13511 .41974 L
.13631 .41972 L
.13738 .41967 L
.13855 .4196 L
.13982 .4195 L
.14117 .41936 L
.14357 .41902 L
.14612 .41856 L
.14853 .41801 L
.15305 .41672 L
.15792 .41495 L
.16321 .41259 L
.18154 .40116 L
.20132 .38382 L
.22233 .36084 L
.26008 .3116 L
.30028 .2544 L
.33897 .20095 L
.38011 .15082 L
.41973 .11204 L
.45784 .08474 L
.47745 .07455 L
.4984 .06646 L
.50864 .06351 L
.51975 .06102 L
.52484 .06012 L
.53023 .05933 L
.53528 .05874 L
.5399 .05832 L
.54222 .05815 L
.54474 .058 L
.54712 .05789 L
Mistroke
.54934 .05781 L
.55066 .05778 L
.55191 .05775 L
.55303 .05774 L
.55425 .05773 L
.55488 .05773 L
.55557 .05773 L
.5563 .05773 L
.55697 .05773 L
.55818 .05775 L
.55947 .05777 L
.5607 .0578 L
.56183 .05784 L
.5644 .05794 L
.56666 .05806 L
.56906 .0582 L
.57779 .05897 L
.58269 .05956 L
.58718 .06018 L
.5973 .06191 L
.61559 .06607 L
.63455 .07171 L
.65527 .07927 L
.69588 .09783 L
.73498 .11981 L
.77653 .14699 L
.81656 .17634 L
.85508 .20685 L
.89605 .24086 L
.9355 .27425 L
.97344 .30664 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0Voooool7ool000Wo00000_oo00000ol0003ooooo
ooooo`2Dooooo`008Oooool00ol0003oooooooooo`2Gooooo`Go00004Oooool6ool000;o0000Sooo
ool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo09Cooooo0ol0000L
ooooo`?oo`001?l0002:ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
093ooooo0_oo0002o`0002;ooooo0ooo00001?oooooo0000o`000?l00027ooooo`003oooool6o`00
00Gooooo00?o0000ooooooooool01?ooool3o`0008gooooo0ooo00000ol0003oooooooooo`0Voooo
o`;oo`000_ooool2o`0008Gooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0R_ooool3ool00003o`000?oooooooooo02oooooo0_l00023ooooo`006_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo08Sooooo0_oo00000ol0003oooooooooo`0dooooo`;o0000
POooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`26ooooo`;oo`0000?o
0000ooooooooool0>?ooool2o`0007oooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0QOooool00ooo003o0000ooooo`0mooooo`;oo`0000?o0000ooooooooool0N_ooool0
01Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`24ooooo`03ool00?oooooooooo
043ooooo0ooo00000ol0003oooooooooo`1gooooo`008Oooool00ol0003oooooooooo`22ooooo`03
o`000?oo003ooooo04Gooooo0_oo00000ol0003oooooooooo`1eooooo`008Oooool00ol0003ooooo
ooooo`21ooooo`03o`000?oooooooooo04Sooooo0ooo00000ol0003oooooooooo`1booooo`008Ooo
ool3o`00083ooooo00?o0000ooooooooool0C?ooool2ool00003o`000?oooooooooo073ooooo000Q
ooooo`03o`000?oooooooooo07kooooo0_l0001Aooooo`;oo`0000?o0000ooooooooool0K_ooool0
027ooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`1Cooooo`03ool00?l0003ooooo
06kooooo000Qooooo`03o`000?oooooooooo07_ooooo0_l0001Hooooo`;o0000KOooool0027ooooo
00?o0000ooooooooool0N_ooool00ooo003oooooooooo`1Jooooo`;o0000Joooool0027ooooo00?o
0000ooooooooool0NOooool00ooo003oooooooooo`1Mooooo`03o`000?oooooooooo06Sooooo000Q
ooooo`03o`000?oooooooooo07Sooooo00?oo`00ooooooooool0Goooool2o`0006Sooooo000Qoooo
o`?o0000Moooool00ooo003oooooooooo`1Rooooo`;o0000I_ooool0027ooooo00?o0000oooooooo
ool0M_ooool00ooo003oooooooooo`1Sooooo`;oo`0000?o0000ooooooooool0Hoooool0027ooooo
00?o0000ooooooooool0MOooool00ooo003oooooooooo`1Vooooo`03ool00?l0003ooooo06?ooooo
000Qooooo`03o`000?oooooooooo07Cooooo00?oo`00ooooooooool0J?ooool2ool00003o`000?oo
oooooooo063ooooo000Qooooo`03o`000?oooooooooo07?ooooo00?oo`00ooooooooool0Joooool0
0ooo003o0000ooooo`1Pooooo`008Oooool00ol0003oooooooooo`1booooo`03ool00?oooooooooo
06gooooo0_oo001Pooooo`008Oooool00ol0003oooooooooo`1aooooo`03ool00?oooooooooo073o
oooo00?oo`00o`000?ooool0GOooool0027ooooo0ol0001`ooooo`03ool00?oooooooooo07;ooooo
0_oo001Mooooo`008Oooool00ol0003oooooooooo`1_ooooo`03ool00?oooooooooo07Gooooo00?o
o`00ooooooooool0F_ooool0027ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1g
ooooo`;oo`00F_ooool0027ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1joooo
o`03o`000?oooooooooo05Oooooo000Qooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool0Noooool00ol0003oooooooooo`1Fooooo`008Oooool00ol0003oooooooooo`1/ooooo`03o`00
0?oooooooooo07gooooo0_l0001Fooooo`008Oooool00ol0003oooooooooo`1[ooooo`03o`000?oo
oooooooo083ooooo00?o0000ooooooooool0Doooool0027ooooo00?o0000ooooooooool0J_ooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo05;ooooo000Qooooo`?o0000JOooool00ol0
003oooooooooo`24ooooo`;o0000D_ooool0027ooooo00?o0000ooooooooool0Ioooool00ooo003o
0000ooooo`28ooooo`;oo`00D?ooool0027ooooo00?o0000ooooooooool0Ioooool00ooo003ooooo
ooooo`29ooooo`03o`000?oo003ooooo04kooooo000Qooooo`03o`000?oooooooooo06Kooooo00?o
o`00ooooooooool0Roooool00ol0003oo`00ool0001=ooooo`008Oooool00ol0003oooooooooo`1U
ooooo`03ool00?l0003ooooo08kooooo00?o0000ool00?ooool0Boooool000Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o
0000ooooooooool0IOooool00ooo003oooooooooo`2?ooooo`03o`000?oo003ooooo04[ooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`1Tooooo`03ool00?oooooooooo097ooooo00?o0000ool00?oo0000BOoo
ool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_oo
ool3o`0006?ooooo00?oo`00ooooooooool0U?ooool00ol0003oo`00ooooo`17ooooo`001oooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooooooo
o`1Rooooo`03ool00?oooooooooo09Kooooo00?o0000ool00?ooool0A_ooool000Oooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooo
ooooo`1Qooooo`03o`000?oo003ooooo09Sooooo00?o0000ool00?ooool0AOooool000Oooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
H?ooool00ol0003oo`00ooooo`2Jooooo`03o`000?oo003ooooo04Cooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo063ooooo
00?oo`00ooooooooool0W?ooool00ol0003oooooooooo`12ooooo`001oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo05oooooo00?oo`00ooooooooool0
W_ooool00ol0003oooooooooo`11ooooo`008Oooool00ol0003oooooooooo`1Nooooo`03ool00?oo
oooooooo0:3ooooo0_l00011ooooo`008Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooo
oooo0:?ooooo00?o0000ooooooooool0?_ooool0027ooooo0ol0001Mooooo`03o`000?oooooooooo
0:Cooooo00?o0000ooooooooool0?Oooool0027ooooo00?o0000ooooooooool0G?ooool00ol0003o
ooooooooo`2Vooooo`;o0000?Oooool0027ooooo00?o0000ooooooooool0Foooool00ol0003ooooo
ooooo`2Yooooo`;oo`00>oooool0027ooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`2[ooooo`03o`000?oo003ooooo03Wooooo000Qooooo`03o`000?oooooooooo05[ooooo00?o0000
ooooooooool0[?ooool00ol0003oo`00ooooo`0hooooo`008Oooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo0:kooooo00?o0000ool00?ooool0=oooool0027ooooo00?o0000oooooooo
ool0F?ooool00ol0003oooooooooo`2aooooo`03ool00?oooooooooo03Gooooo000Qooooo`?o0000
Eoooool00ooo003oooooooooo`2cooooo`03ool00?oooooooooo03Cooooo000Qooooo`03o`000?oo
oooooooo05Oooooo00?oo`00ooooooooool0]?ooool2ool003Cooooo000Qooooo`03o`000?oooooo
oooo05Kooooo00?oo`00ooooooooool0]oooool00ooo003oooooooooo`0aooooo`008Oooool00ol0
003oooooooooo`1Eooooo`03ool00?oooooooooo0;Wooooo00?oo`00ooooooooool0<?ooool0027o
oooo00?o0000ooooooooool0E?ooool00ol0003oo`00ooooo`2kooooo`03ool00?oooooooooo02oo
oooo000Qooooo`03o`000?oooooooooo05Cooooo00?oo`00ooooooooool0_?ooool00ooo003ooooo
ooooo`0^ooooo`008Oooool00ol0003oooooooooo`1Cooooo`03o`000?oo003ooooo0;kooooo0_l0
000^ooooo`008Oooool00ol0003oooooooooo`1Booooo`03o`000?oo003ooooo0<7ooooo00?o0000
ooooooooool0:oooool0027ooooo0ol0001Booooo`03ool00?oooooooooo0<;ooooo00?o0000oooo
ooooool0:_ooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000ool00?oMgMd0?Oooool4o`000003oa0@4?oooooo
oooo03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM037ooooo00?o0000ooooooooool02Oooool5o`0001_ooooo000Qooooo`03o`000?oooooo
oooo03gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oo`00oc8b
<P0oooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool0<Oooool00ol0003oooooooooo`08ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
6oooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo410@00kooooo
00?oo`00ooooool00000?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0<Oooool2o`0000Wooooo00?oV9RHob4Q8Oo^k^h07?ooool0027ooooo00?o
0000ooooooooool0?Oooool01Ol0003ooooooooooooooooo000000gooooo00Coo`00oooooomgMgOo
<S8b?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_oo
ool0=?ooool00ol0003oooooooooo`07ooooo`03oiRHV?lQ8B7ok^k^01_ooooo000Qooooo`03o`00
0?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000<ooooo`05ool00?lQ8B7o0000oc8b
<_o<c<`0?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00dooooo`;oo`0000?o0000ooooooooool01oooool00omgMgOoIVIVooooo`0J
ooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0hooooo`03ool00?l0003ooooo00Sooooo00?o0000ooooooooool06Oooool0
027ooooo0ol0000mooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool2o`0004?ooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Wooooo00?oo`00
o`000?ooool00oooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`03o`000?oooooo
oooo03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`03o`000?oooooo000000?o0000?_oo
ool00omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000iooooo`03ool00?l0
003o000000;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Kooooo`008Oooool00ol0003ooooooooo
o`1<ooooo`03o`000?oooooooooo0=7ooooo0_oo00000ol0003oooooooooo`0Oooooo`008Oooool0
0ol0003oooooooooo`1;ooooo`03o`000?oooooooooo0=Cooooo00?oo`00o`000?ooool07oooool0
027ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`3Fooooo`03ool00?l0003ooooo
01kooooo000Qooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0eoooool00ooo003o
0000ooooo`0Cooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool0fOooool00ooo003o0000ooooo`0Booooo`06onk^k_lQ8B7oQhN7okZj^_l0
003ogMgM1?ooool001[oooooD_l000000ooo003o0000o`00003Ko`0000;oo`001ol0000<ooooo`04
omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ooo003o0000ooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Aooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`;o
00003Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03ool00?l0003ooooo00gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Co8B4QogMgMomg
MgOo<S8b1Oooool0027ooooo00?o0000ooooool00000A_ooool00ooo003oooooooooo`3aooooo`;o
00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooo000004Gooooo00?oo`00ooooooooool0
o?ooool0027ooooo00Co0000oooooooooooo0000@oooool00ooo003o0000ooooo`3mooooo`008Ooo
ool01?l0003oooooooooool00013ooooo`03ool00?oooooooooo0?gooooo000Qooooo`05o`000?oo
ooooooooooooool00000@Oooool00ooo003oooooooooo`3nooooo`008Oooool3o`0000;ooooo00?o
0000ooooooooool0?Oooool00ooo003oooooooooo`3oooooo`008Oooool00ol0003oooooooooo`02
ooooo`03o`000?oo003ooooo03cooooo00?o0000ool00?ooool0ooooool1ooooo`008Oooool00ol0
003oooooooooo`03ooooo`03ool00?oooooooooo03_ooooo00?oo`00ooooooooool0ooooool1oooo
o`008Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo03[ooooo00?oo`00oooooooo
ool0ooooool2ooooo`008Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo03Sooooo
00?oo`00ooooooooool0ooooool3ooooo`008Oooool00ol0003oooooooooo`05ooooo`03ool00?oo
oooooooo03Kooooo00?o0000ooooooooool0ooooool4ooooo`008Oooool00ol0003oooooooooo`05
ooooo`03ool00?oooooooooo03Kooooo00?o0000ooooooooool0ooooool4ooooo`008Oooool3o`00
00Kooooo00?oo`00ooooooooool0=?ooool00ol0003oooooooooo`3oooooo`Gooooo000Qooooo`03
o`000?oooooooooo00Oooooo00?oo`00ooooooooool0<_ooool00ol0003oooooooooo`3oooooo`Ko
oooo000Qooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool0<Oooool00ol0003ooooo
ooooo`3oooooo`Oooooo000Qooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool0;ooo
ool00ol0003oooooooooo`3oooooo`Sooooo000Qooooo`03o`000?oooooooooo00Wooooo00?oo`00
ooooooooool0;Oooool00ol0003oooooooooo`3oooooo`Wooooo000Qooooo`03o`000?oooooooooo
00Wooooo00?o0000ool00?ooool0;?ooool00ol0003oooooooooo`3oooooo`[ooooo000Qooooo`03
o`000?oooooooooo00[ooooo00?o0000ool00?ooool0:_ooool00ol0003oo`00ooooo`3oooooo`_o
oooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000ool00?ooool0:?ooool00ol0003oo`00
ooooo`3oooooo`cooooo000Qooooo`?o00003?ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
003ooooo0?oooooo3Oooool0027ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0T
ooooo`;oo`00ooooool?ooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
02;ooooo00?oo`00ooooooooool0ooooool?ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo023ooooo00?oo`00ooooooooool0ooooool@ooooo`008Oooool00ol0003ooooo
ooooo`0@ooooo`;o00007oooool00ooo003oooooooooo`3ooooooa7ooooo000Qooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool06oooool00ooo003oooooooooo`3ooooooa;ooooo000Q
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06?ooool2ool00?oooooo5Oooool0
027ooooo0ol0000Cooooo`;oo`0000?o0000ooooooooool05Oooool00ooo003oooooooooo`3ooooo
oaGooooo000Qooooo`03o`000?oooooooooo01Gooooo0_oo000Dooooo`03o`000?oo003ooooo0?oo
oooo5oooool0027ooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`0@ooooo`03o`00
0?oooooooooo0?oooooo6?ooool0027ooooo00?o0000ooooooooool06?ooool2ool000kooooo0_l0
003ooooooa_ooooo000Qooooo`03o`000?oooooooooo01[ooooo0ooo0009ooooo`;o0000oooooolM
ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Looooo`03o`000?oo003oo`0000Coo`000ol0
003ooooooaoooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom5ooooo`001oooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooo
oooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodGooooo
0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000
1Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003ooooo
ooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool0
01[ooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00Y?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mg
MgOooooo0:Oooooo0023ooooo`?o00005?ooool00olQ8B7ogMgMooooo`06ooooo`03omgMgOl@413o
k^k^01Sooooo00?ok^k^oa0@4?oMgMd0Yoooool007_ooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb
<S;ok^k^00;ooooo00?o0000ooooooooool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo
00?oV9RHoeEEEOooool01_ooool00omEEEGoV9RHooooo`02ooooo`Go00002Oooool00omEEEGoZJVY
ooooo`02ooooo`06okZj^_m4A4Cooooooooooon7QhOoIVIV5?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool00_ooool01Om4A4Co0000o`000?lb
<S;ogMgM07Gooooo001kooooo`07oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP02ooooo`03o`00
0?oooooooooo00_ooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oMgMgooooo00Go
oooo00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400[ooooo00KoEEEEoiRH
V?oooooooooooa0@4?nj^[X2ooooo`03onk^k_l0003ooooo00_ooooo1_l00002ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01_ooool00omgMgOo<S8b
ooooo`1dooooo`00Noooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@41000_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo0_mgMgL6ooooo`03oc8b<_oooooooooo00?o
oooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool00004ooooo`03o`000?oooooooooo
01;ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00002?ooool00ol0003oooooooooo`1c
ooooo`00Noooool01?mEEEGoZJVYooooool00002ooooo`04o`000?ooooooooooo`0000gooooo00?o
0000ooooooooool01_ooool00oo^k^ko410@onk^kP05ooooo`03oc8b<_oooooooooo00Cooooo00?o
V9RHob4Q8Oo^k^h02oooool01?n7QhOoIVIVooooool00004ooooo`03o`000?oooooooooo00[ooooo
1_l00002ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00008oooo
o`03ogMgMolb<S;ooooo07Cooooo001kooooo`03omgMgOlQ8B7ok^k^00?ooooo00Co0000ooooool0
003o00003Oooool00ol0003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00?o0000onk^
k_ooool01Oooool00omgMgOoIVIVooooo`0:ooooo`04omgMgOl@413oooooo`0000?ooooo00?ok^k^
o`000?ooool04oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo0000
1Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<07Gooooo001looooo`03oiRHV?mgMgOooooo00;ooooo
00?o0000ooooooooool03?ooool00ol@413o0000o`000003o`0000Kooooo00?ogMgMoa0@4?ooool0
1?ooool00omEEEGoMgMgooooo`06ooooo`03o`000?oooooooooo00Sooooo1ol000000oooooooMgMg
oeEEE@0Dooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000005ooooo`03
o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo00Sooooo00?oEEEEoiRHV?ooool0
0oooool00ooMgMgo410@onk^kP02ooooo`05o`000?nj^[[ooooooiRHV?l@41004Oooool00oo^k^ko
410@omgMg@0Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000005oooo
o`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo00Sooooo00?o^[ZjodA4A?oo
ool01?ooool02OmgMgOoIVIVooooooooooooV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`03ofIVI_mg
MgOooooo01Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Cooooo
1?l0001fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .35892 L
.06244 .4054 L
.08255 .44165 L
.09396 .45642 L
.09905 .46161 L
.10458 .46626 L
.11004 .46986 L
.11243 .47113 L
.11508 .47233 L
.1174 .47319 L
.11989 .47393 L
.12127 .47426 L
.12253 .47451 L
.12372 .4747 L
.125 .47485 L
.12624 .47496 L
.12736 .47501 L
.12849 .47503 L
.12955 .47502 L
.13079 .47496 L
.13194 .47486 L
.13319 .47471 L
.13452 .47451 L
.13675 .47405 L
.13884 .47351 L
.14357 .47183 L
.14858 .46943 L
.15402 .46612 L
.16392 .45836 L
.18248 .43852 L
.22326 .37758 L
.26253 .30793 L
.30028 .24078 L
.34048 .1759 L
.37917 .12355 L
.39882 .10134 L
.42031 .08057 L
.44107 .06398 L
.45994 .05183 L
.47955 .04202 L
.49045 .03777 L
.5005 .03458 L
.50981 .03222 L
.51968 .03034 L
.5248 .02961 L
.52958 .02907 L
.53484 .02863 L
.53778 .02846 L
.53917 .0284 L
Mistroke
.54048 .02835 L
.54168 .02831 L
.54299 .02828 L
.54417 .02826 L
.54526 .02825 L
.54644 .02825 L
.54774 .02825 L
.54839 .02826 L
.54909 .02827 L
.55035 .02829 L
.55153 .02832 L
.55281 .02836 L
.55514 .02846 L
.55741 .02858 L
.5595 .02872 L
.56429 .02913 L
.56956 .02971 L
.58024 .03133 L
.59036 .03338 L
.59962 .03569 L
.62049 .04226 L
.66017 .0595 L
.69833 .08101 L
.73894 .1081 L
.77804 .13731 L
.81959 .17084 L
.85963 .20489 L
.89814 .23874 L
.93912 .27547 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .35778 L
.06244 .40451 L
.08255 .44142 L
.09396 .45658 L
.09905 .46193 L
.10458 .46675 L
.11004 .47048 L
.11243 .47181 L
.11508 .47306 L
.1174 .47397 L
.11989 .47475 L
.12127 .47509 L
.12253 .47536 L
.12372 .47556 L
.125 .47573 L
.12624 .47585 L
.12736 .47591 L
.12849 .47594 L
.12955 .47593 L
.13079 .47588 L
.13194 .47579 L
.13319 .47564 L
.13452 .47544 L
.13675 .47499 L
.13884 .47444 L
.14357 .47274 L
.14858 .47029 L
.15402 .46691 L
.16392 .45898 L
.18248 .43872 L
.22326 .37689 L
.26253 .30699 L
.30028 .24019 L
.34048 .17608 L
.37917 .12446 L
.42031 .08176 L
.44084 .06522 L
.45994 .05261 L
.47836 .04294 L
.49804 .03524 L
.50829 .03227 L
.51368 .03098 L
.51939 .02983 L
.52438 .029 L
.52987 .02826 L
.53228 .028 L
.53487 .02776 L
.53732 .02757 L
.53954 .02743 L
Mistroke
.54209 .0273 L
.54348 .02725 L
.5448 .02721 L
.54602 .02719 L
.54714 .02717 L
.54837 .02717 L
.54967 .02717 L
.55099 .02718 L
.55173 .02719 L
.5524 .0272 L
.5537 .02723 L
.55494 .02727 L
.55771 .02739 L
.56072 .02757 L
.56579 .028 L
.57116 .0286 L
.58082 .03009 L
.59021 .03202 L
.60033 .03459 L
.61862 .04049 L
.65981 .05896 L
.69949 .08218 L
.73765 .10814 L
.77826 .13849 L
.81736 .16963 L
.85891 .20441 L
.89894 .23932 L
.93746 .27382 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`2Sooooo`Coo`00WOooool0027ooooo00?o0000ooooooooool0Uooo
ool6ool000[o00001ooo002Fooooo`008Oooool00ol0003oooooooooo`2Cooooo`Coo`005?ooool3
o`0000?oo`00Toooool0027ooooo00?o0000ooooooooool0T?ooool3ool00003o`000?oooooooooo
01_ooooo0_oo00000ol0003oooooooooo`2>ooooo`008Oooool00ol0003oooooooooo`2>ooooo`;o
o`0000?o0000ooooooooool08Oooool3o`0008gooooo000Qooooo`03o`000?oooooooooo08_ooooo
0_l000000ooo003oooooooooo`0Wooooo`?o0000R_ooool0027ooooo00?o0000ooooooooool0ROoo
ool2o`0002oooooo0ol00027ooooo`008Oooool3o`0008Oooooo0_l0000cooooo`;oo`0000?o0000
ooooooooool0Poooool0027ooooo00?o0000ooooooooool0QOooool2o`0003Oooooo0ooo0023oooo
o`008Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo03[ooooo0ooo0020ooooo`00
8Oooool00ol0003oooooooooo`22ooooo`;oo`00@?ooool2ool007kooooo000Qooooo`03o`000?oo
oooooooo087ooooo00?oo`00ooooooooool0@_ooool00ooo003o0000ooooo`1kooooo`006?ooool4
o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0Ooooool2ool004Kooooo0_oo001k
ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07kooooo00?oo`00oooo
ooooool0B?ooool00ooo003o0000ooooo`1hooooo`003oooool6o`0000Gooooo00?o0000oooooooo
ool01?ooool3o`0007cooooo0_oo001<ooooo`03ool00?l0003o000007Oooooo000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0Noooool00ooo003oooooooooo`1?ooooo`03o`00
0?oooooooooo07Cooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0N_oo
ool00ooo003oooooooooo`1Aooooo`;o0000M?ooool001[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1iooooo`03ool00?oooooooooo05Cooooo0_l0001booooo`006_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo07Sooooo00?o0000ool00?ooool0Eoooool00ol0
003oooooooooo`1_ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo07Oo
oooo00?o0000ool00?ooool0FOooool2o`0006oooooo000Qooooo`03o`000?oooooooooo07Kooooo
00?o0000ool00?ooool0F_ooool2ool00003o`000?oooooooooo06cooooo000Qooooo`03o`000?oo
oooooooo07Gooooo00?o0000ooooooooool0GOooool00ooo003o0000o`00001/ooooo`008Oooool3
o`0007Cooooo00?o0000ooooooooool0Goooool2ool00003o`000?oooooooooo06Wooooo000Qoooo
o`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0H_ooool00ooo003o0000ooooo`1Yoooo
o`008Oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo06Cooooo0_oo00000ol0003o
ooooooooo`1Vooooo`008Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo06Oooooo
00?oo`00o`000?ooool0I_ooool0027ooooo00?o0000ooooooooool0L?ooool00ol0003ooooooooo
o`1Yooooo`;oo`0000?o0000ooooooooool0Hoooool0027ooooo00?o0000ooooooooool0Koooool0
0ol0003oo`00ooooo`1/ooooo`03ool00?l0003ooooo06?ooooo000Qooooo`03o`000?oooooooooo
06kooooo00?o0000ool00?ooool0K_ooool00ooo003o0000ooooo`1Rooooo`008Oooool3o`0006go
oooo00?o0000ool00?ooool0L?ooool00ooo003o0000o`00001Qooooo`008Oooool00ol0003ooooo
ooooo`1/ooooo`03o`000?oo003ooooo07Cooooo00?o0000ooooooooool0G_ooool0027ooooo00?o
0000ooooooooool0K?ooool00ooo003oooooooooo`1eooooo`03o`000?oooooooooo05gooooo000Q
ooooo`03o`000?oooooooooo06_ooooo00?o0000ool00?ooool0Moooool2o`0005gooooo000Qoooo
o`03o`000?oooooooooo06[ooooo00?o0000ool00?ooool0N_ooool00ol0003oooooooooo`1Joooo
o`008Oooool00ol0003oooooooooo`1Zooooo`03ool00?oooooooooo07_ooooo00?o0000oooooooo
ool0FOooool0027ooooo00?o0000ooooooooool0JOooool00ol0003oo`00ooooo`1mooooo`;oo`00
FOooool0027ooooo0ol0001Xooooo`03o`000?oo003ooooo083ooooo00?oo`00ooooooooool0E_oo
ool0027ooooo00?o0000ooooooooool0Ioooool00ol0003oo`00ooooo`22ooooo`03ool00?oooooo
oooo05Gooooo000Qooooo`03o`000?oooooooooo06Oooooo00?o0000ool00?ooool0Poooool00ooo
003o0000ooooo`1Dooooo`008Oooool00ol0003oooooooooo`1Vooooo`03o`000?oo003ooooo08Go
oooo00?oo`00o`000?ooool0Doooool0027ooooo00?o0000ooooooooool0IOooool00ol0003oo`00
ooooo`27ooooo`;oo`00Doooool0027ooooo00?o0000ooooooooool0IOooool00ol0003ooooooooo
o`29ooooo`03ool00?oooooooooo053ooooo000Qooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool0Roooool00ooo003o0000ooooo`1?ooooo`008Oooool00ol0003oooooooooo`1Soooo
o`03o`000?oooooooooo08gooooo00?oo`00o`000?ooool0C_ooool0027ooooo0ol0001Rooooo`03
o`000?oooooooooo08oooooo00?oo`00o`000?ooool0COooool0027ooooo00?o0000ooooooooool0
H_ooool00ol0003oooooooooo`2@ooooo`03ool00?l0003o000004cooooo000Qooooo`03o`000?oo
oooooooo067ooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`19ooooo`008Oooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool0B?ooool0
027ooooo00?o0000ooooooooool0Goooool00ooo003o0000ooooo`2Hooooo`03o`000?oooooooooo
04Oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo05oooooo00?oo`00ooooooooool0VOooool0
0ol0003oooooooooo`16ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0G_ooool00ooo003oooooooooo`2K
ooooo`03o`000?oooooooooo04Gooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00;ooooo0ol0001Nooooo`03ool00?oooooooooo09cooooo00?o0000
ooooooooool0A?ooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00?ooooo00?o0000ooooooooool0GOooool00ooo003oooooooooo`2Mooooo`;oo`00AOooool0
00Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?oo
ool00ol0003oooooooooo`1Looooo`03ool00?l0003ooooo0:3ooooo00?oo`00ooooooooool0@_oo
ool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0G?ooool00ooo003oooooooooo`2Qooooo`03ool00?oooooooooo047ooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo05_ooooo00?oo`00ooooooooool0Xoooool00ooo003oooooooooo`10ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo05_ooooo00?o
o`00ooooooooool0Y?ooool2ool0043ooooo000Qooooo`03o`000?oooooooooo05[ooooo00?oo`00
ooooooooool0Yoooool00ooo003oooooooooo`0mooooo`008Oooool00ol0003oooooooooo`1Joooo
o`03ool00?oooooooooo0:Sooooo00?oo`00ooooooooool0??ooool0027ooooo0ol0001Iooooo`03
ool00?oooooooooo0:[ooooo00?oo`00ooooooooool0>oooool0027ooooo00?o0000ooooooooool0
F?ooool00ooo003oooooooooo`2/ooooo`03ool00?oooooooooo03[ooooo000Qooooo`03o`000?oo
oooooooo05Sooooo00?oo`00ooooooooool0[Oooool00ooo003o0000ooooo`0iooooo`008Oooool0
0ol0003oooooooooo`1Gooooo`03ool00?oooooooooo0:oooooo00?oo`00o`000?ooool0>?ooool0
027ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo
03Kooooo000Qooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0/oooool00ol0003o
ooooooooo`0eooooo`008Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo0;Gooooo
00?o0000ooooooooool0=?ooool0027ooooo0ol0001Eooooo`03o`000?oooooooooo0;Kooooo0_l0
000dooooo`008Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo0;Wooooo00?o0000
ooooooooool0<Oooool0027ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo033ooooo000Qooooo`03o`000?oooooooooo05?ooooo00?o0000oooooooo
ool0_?ooool2ool0033ooooo000Qooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0
_Oooool00ol0003oo`00ooooo`0^ooooo`008Oooool00ol0003oooooooooo`1Aooooo`03ool00?l0
003ooooo0<3ooooo00?o0000ool00?ooool0;Oooool0027ooooo00?o0000ooooooooool0DOooool0
0ooo003oooooooooo`31ooooo`03o`000?oo003ooooo02cooooo000Qooooo`03o`000?oooooooooo
053ooooo00?oo`00o`000?ooool0`oooool00ol0003oo`00ooooo`0[ooooo`008Oooool3o`00053o
oooo00?oo`00ooooooooool0a?ooool00ol0003oo`00ooooo`0Zooooo`008Oooool00ol0003ooooo
ooooo`0mooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4ool00?l0
003o<S8bomgMg@0mooooo`Co000000?o410@ooooooooool0>oooool4o`000003oa0@4?oooooooooo
00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0<Oooool00ol0003oo`00ooooo`09
ooooo`Go00006oooool0027ooooo00?o0000ooooooooool0?Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B46ooooo`04ool00?ooooooMgMgoc8b<Soooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0aooooo`03o`000?oo
003ooooo00Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003ooooooooo
o`0mooooo`05oa0@4?ooooooooooooooool@41003?ooool01Ooo003o0000oooooooooooo000003oo
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo037o
oooo00?o0000ool00?ooool02?ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003ooooo
ooooo`0mooooo`05o`000?ooooooooooooooool000003?ooool01Ooo003ooooooooooomgMgOo<S8b
03oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo
03?ooooo00?oo`00o`000?ooool02?ooool00onHV9So8B4Qonk^kP0Kooooo`008Oooool00ol0003o
ooooooooo`0mooooo`05o`000?ooooooooooooooool000002oooool01_oo003o0000ob4Q8Ol0003o
<S8bolc<c3oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`0=Oooool00ooo003o0000ooooo`08ooooo`03ogMgMomVIVKooooo01[ooooo
000Qooooo`03o`000?oooooooooo03gooooo00Go410@oooooooooooooooooa0@400;ooooo`03ool0
0?l0003ooooo04;ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo03Sooooo00?oo`00o`000?ooool02?ooool00ol0003oooooooooo`0Iooooo`008Ooo
ool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`03ool00?oooooo000004?ooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool00_ooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`03o`00
0?oooooooooo03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`03ool00?oooooo000000?o
0000?_ooool00omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000jooooo`09
o`000?oooooooooooooooonHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qooooo`03o`000?oooooo
oooo04_ooooo00?oo`00ooooooooool0doooool2o`00027ooooo000Qooooo`03o`000?oooooooooo
04_ooooo00?oo`00ooooooooool0eOooool00ol0003oooooooooo`0Nooooo`008Oooool00ol0003o
ooooooooo`1:ooooo`03ool00?oooooooooo0=Oooooo00?o0000ooooooooool07Oooool0027ooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`3Iooooo`03o`000?oooooooooo01;ooooo
0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`3Iooooo`;oo`004oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooooooo0000
<_l000000ooo003o0000o`000005o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo
00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo0_l0000=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
0_l0000>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Aooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`;o0000B?ooool00ol0003ooooo
ooooo`3`ooooo`;o00000_ooool2o`0000Cooooo000Qooooo`;o000000?oo`00ooooooooool0A?oo
ool00ol0003oooooooooo`3kooooo`008Oooool00ol0003oooooool00016ooooo`03o`000?oooooo
oooo0?_ooooo000Qooooo`04o`000?oooooo0000ool004?ooooo00?oo`00o`000?ooool0oOooool0
027ooooo00Co0000ooooool0003oo`00@oooool00ooo003oooooooooo`3mooooo`008Oooool3o`00
0003ool00?oooooooooo043ooooo00?oo`00o`000?ooool0o_ooool0027ooooo00Go0000oooooooo
oooo0000ool00011ooooo`03ool00?oooooooooo0?kooooo000Qooooo`05o`000?oooooooooooooo
oooo0000@?ooool00ooo003o0000ooooo`3oooooo`008Oooool01Ol0003oooooooooooooooooo`00
043ooooo00?oo`00ooooooooool0ooooool0027ooooo00Ko0000ooooooooooooooooo`000?oo000n
ooooo`03ool00?l0003ooooo0?oooooo0Oooool0027ooooo00?o0000ooooooooool00_ooool00ooo
003oooooooooo`0looooo`03ool00?oooooooooo0?oooooo0Oooool0027ooooo00?o0000oooooooo
ool00_ooool00ooo003oooooooooo`0kooooo`03ool00?l0003ooooo0?oooooo0_ooool0027ooooo
0ol00002ooooo`03o`000?oo003ooooo03_ooooo00?oo`00ooooooooool0ooooool2ooooo`008Ooo
ool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo03Wooooo00?oo`00o`000?ooool0oooo
ool3ooooo`008Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo03Wooooo00?oo`00
ooooooooool0ooooool3ooooo`008Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo
03Oooooo00?oo`00ooooooooool0ooooool4ooooo`008Oooool00ol0003oooooooooo`04ooooo`03
o`000?oo003ooooo03Oooooo00?oo`00ooooooooool0ooooool4ooooo`008Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo03Gooooo00?oo`00ooooooooool0ooooool5ooooo`008Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0oooo
ool5ooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool0ooooool6ooooo`008Oooool3o`0000Kooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`3oooooo`Kooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`3oooooo`Oooooo000Qooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`3oooooo`Sooooo000Qooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`3oooooo`Sooooo000Q
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`3o
ooooo`Wooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`3oooooo`[ooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ool00?oo
ool0;?ooool00ooo003o0000ooooo`3oooooo`_ooooo000Qooooo`?o00002Oooool00ooo003ooooo
ooooo`0[ooooo`03ool00?oooooooooo0?oooooo2oooool0027ooooo00?o0000ooooooooool02Ooo
ool00ooo003oooooooooo`0Zooooo`03ool00?oooooooooo0?oooooo3?ooool0027ooooo00?o0000
ooooooooool02_ooool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo0?oooooo3Oooool0
027ooooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo
0?oooooo3Oooool0027ooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`0Vooooo`03
ool00?oooooooooo0?oooooo3_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool03?ooool00ooo
003oooooooooo`0Tooooo`03ool00?oooooooooo0?oooooo3oooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo
00cooooo00?oo`00ooooooooool09?ooool00ooo003oooooooooo`3oooooo`oooooo0007ooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o00003Oooool00ooo
003oooooooooo`0Rooooo`03ool00?oooooooooo0?oooooo4?ooool000Oooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool03Oooool00ooo
003oooooooooo`0Qooooo`03ool00?oooooooooo0?oooooo4Oooool000Oooooo00Go0000oooooooo
ooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0>
ooooo`03ool00?oooooooooo023ooooo00?oo`00ooooooooool0oooooolAooooo`001oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?
ooooo`03ool00?oooooooooo01kooooo00?oo`00ooooooooool0oooooolBooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?
ooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool0oooooolCooooo`001oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo013ooooo00?oo`00
ooooooooool06oooool00ooo003oooooooooo`3ooooooaCooooo000Qooooo`03o`000?oooooooooo
013ooooo00?oo`00ooooooooool06_ooool00ol0003oooooooooo`3ooooooaGooooo000Qooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`3ooooooaKo
oooo000Qooooo`?o00004_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0?oooooo
5oooool0027ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo0?oooooo6?ooool0027ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0A
ooooo`;o0000oooooolKooooo`008Oooool00ol0003oooooooooo`0Eooooo`;o00004?ooool00ol0
003oooooooooo`3ooooooa_ooooo000Qooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool02oooool00ol0003oo`00ooooo`3ooooooagooooo000Qooooo`03o`000?oooooooooo01Oooooo
00?o0000ool00?ooool02_ooool00ol0003oo`00ool0003ooooooakooooo000Qooooo`03o`000?oo
oooooooo01Sooooo0_oo00000ol0003oooooooooo`05ooooo`?oo`00oooooolPooooo`008Oooool3
o`0001[ooooo2?oo003oooooob?ooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00Z?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo
0:?ooooo0027ooooo`?o00004oooool00olQ8B7ogMgMooooo`07ooooo`03omgMgOl@413ok^k^01So
oooo00?ok^k^oa0@4?oMgMd0Xoooool007kooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^
00?ooooo00?o0000ooooooooool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00?oV9RH
oeEEEOooool01oooool01?mEEEGoV9RHooooooooool5o`0000Wooooo00?oEEEEojVYZOooool00_oo
ool00onj^[[oA4A4ooooo`02ooooo`03ohN7QomVIVKooooo01;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM07[ooooo001nooooo`07oa0@
4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP03ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj
^_o^k^koMgMgoa0@4003ooooo`03o`000?oMgMgooooo00Kooooo00Wo0000oooooooooooooooooiRH
V?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P?ooooo00?ok^k^
o`000?ooool02oooool6o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0NOooool007kooooo00Oo0000oooooooMgMgo<S8booooooo^k^ko410@00?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`;oMgMg1oooool00olb<S;o
ooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co410@omgMgOoooooo00001Oooool00ol0
003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`1h
ooooo`00O_ooool01?mEEEGoZJVYooooool00002ooooo`05o`000?ooooooooooooooool000003Ooo
ool00ol0003oooooooooo`05ooooo`03onk^k_l@413ok^k^00Kooooo00?o<S8booooooooool00ooo
ool00onHV9So8B4Qonk^kP0;ooooo`04ohN7QomVIVKoooooo`0000Gooooo00?o0000ooooooooool0
2_ooool6o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool03Oooool00omgMgOo<S8b
ooooo`1iooooo`00O_ooool00ooMgMgo8B4Qonk^kP03ooooo`03o`000?oooooooooo00;o00003Ooo
ool00ol0003oooooooooo`06ooooo`03oeEEEOnHV9Sooooo00Gooooo00?o0000onk^k_ooool01?oo
ool00omgMgOoIVIVooooo`0:ooooo`04omgMgOl@413oooooo`0000Cooooo00?ok^k^o`000?ooool0
4_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c01joooo
o`00Ooooool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo00gooooo00?o410@o`000?l0
00000ol00005ooooo`03omgMgOl@413ooooo00Gooooo00?oEEEEogMgMoooool01Oooool00ol0003o
ooooooooo`08ooooo`Oo00000_ooool00omgMgOoEEEEooooo`0Booooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`1looooo`00U_ooool00ol0003oooooooooo`07ooooo`03
oeEEEOnHV9Sooooo00Cooooo00WogMgMoa0@4?o^k^koooooo`000?nj^[[ooooooiRHV?l@41004_oo
ool00oo^k^ko410@omgMg@0Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`1looooo`00U_ooool00ol0003oooooooooo`07ooooo`03okZj^_m4A4Cooooo00Gooooo00So
MgMgofIVI_ooooooV9RHoa0@4?l0003o8B4Qolc<c1;ooooo00?oIVIVogMgMoooool04oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0001kooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.55) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .33731 L
.06244 .3649 L
.08426 .39009 L
.0949 .39972 L
.10458 .40672 L
.10911 .4094 L
.11403 .41184 L
.11828 .41358 L
.12297 .41507 L
.12553 .41571 L
.12793 .41619 L
.13047 .41657 L
.13189 .41672 L
.13319 .41683 L
.13439 .41691 L
.13551 .41695 L
.13673 .41697 L
.13803 .41695 L
.13928 .41691 L
.14045 .41684 L
.1415 .41676 L
.14264 .41665 L
.14501 .41633 L
.14755 .41588 L
.15214 .41477 L
.1576 .41295 L
.16257 .41085 L
.17339 .40489 L
.18364 .39763 L
.22197 .3594 L
.26275 .3068 L
.30202 .25258 L
.33977 .20282 L
.37997 .15647 L
.41866 .12045 L
.43831 .10567 L
.4598 .09224 L
.48033 .08207 L
.49942 .07487 L
.50995 .07182 L
.51988 .06951 L
.5288 .0679 L
.53379 .06719 L
.53847 .06665 L
.54303 .06623 L
.54793 .0659 L
.55072 .06576 L
.5521 .06571 L
.55337 .06567 L
Mistroke
.55452 .06564 L
.55575 .06562 L
.55645 .06561 L
.55711 .0656 L
.55834 .0656 L
.55957 .0656 L
.56026 .0656 L
.56091 .0656 L
.56222 .06562 L
.56295 .06563 L
.56362 .06565 L
.5661 .06572 L
.56846 .06581 L
.57118 .06596 L
.5737 .06612 L
.57939 .0666 L
.58904 .06774 L
.59809 .06918 L
.61871 .07374 L
.63893 .0798 L
.65744 .0866 L
.69712 .10476 L
.73528 .12613 L
.77589 .15228 L
.81499 .18006 L
.85654 .21167 L
.89658 .24354 L
.93509 .27502 L
.97607 .30891 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36391 L
.08255 .38793 L
.0932 .39807 L
.10458 .40662 L
.11009 .40988 L
.11531 .4124 L
.11999 .41421 L
.1224 .41497 L
.12507 .41568 L
.12739 .41618 L
.12988 .41661 L
.13126 .41679 L
.13252 .41692 L
.13379 .41703 L
.13499 .4171 L
.13609 .41714 L
.13726 .41715 L
.13837 .41714 L
.13937 .41712 L
.14055 .41706 L
.14183 .41697 L
.14304 .41685 L
.14415 .41672 L
.14661 .41635 L
.14885 .41592 L
.15389 .41462 L
.15855 .41301 L
.16298 .41114 L
.17287 .40581 L
.18364 .39831 L
.20341 .38054 L
.22442 .3571 L
.26217 .30757 L
.30238 .25138 L
.34106 .20025 L
.3822 .15348 L
.42183 .11792 L
.45994 .09294 L
.47955 .08349 L
.5005 .0758 L
.51074 .07292 L
.52184 .07041 L
.53233 .06861 L
.54199 .06743 L
.54667 .06703 L
.54924 .06685 L
.55169 .06671 L
.55396 .0666 L
.55515 .06655 L
Mistroke
.55643 .06651 L
.55761 .06648 L
.55867 .06645 L
.55975 .06644 L
.56076 .06642 L
.56196 .06641 L
.56327 .06641 L
.56394 .06641 L
.56465 .06642 L
.56593 .06643 L
.56721 .06645 L
.56841 .06648 L
.57068 .06654 L
.57335 .06665 L
.57582 .06678 L
.5814 .06717 L
.58604 .06759 L
.59105 .06816 L
.6001 .06945 L
.61086 .07142 L
.62072 .07364 L
.63968 .079 L
.66039 .0864 L
.701 .10526 L
.7401 .12814 L
.78165 .15637 L
.82169 .1861 L
.8602 .21601 L
.90118 .24852 L
.94063 .28029 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`2Q
ooooo`So0000Voooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Joooo
o`Ko00001Ooo0004ooooo`Ko00000_oo0003o`00093ooooo000?ooooo`Ko00001Oooool00ol0003o
ooooooooo`04ooooo`?o0000U?ooool6o`0001Oooooo1ooo002<ooooo`006_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo097ooooo0ol00002ool0027ooooo00Co0000ool00?oo003o
o`00ROooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2?ooooo`;o0000
0ooo000Vooooo`04o`000?oo003oo`00ool008Kooooo000Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0SOooool01?l0003oo`00ool00?oo000/ooooo`03o`000?oo003o000008Co
oooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Roooool3ool003;ooooo
0ol00021ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo08Sooooo0ooo
000hooooo`;o0000Ooooool0027ooooo00?o0000ooooooooool0Qoooool00ooo003o0000ooooo`0k
ooooo`;o0000OOooool0027ooooo00?o0000ooooooooool0QOooool2o`00043ooooo00?o0000ool0
0?oo0000N_ooool0027ooooo0ol00023ooooo`;o0000A?ooool00ol0003oo`00ool0001hooooo`00
8Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo04Oooooo0ooo001eooooo`008Ooo
ool00ol0003oooooooooo`20ooooo`;o0000C?ooool00ol0003oo`00ool0001cooooo`008Oooool0
0ol0003oooooooooo`1nooooo`;o0000D?ooool00ol0003oo`00ool0001aooooo`008Oooool00ol0
003oooooooooo`1mooooo`;oo`00Doooool00ol0003oo`00ool0001_ooooo`008Oooool00ol0003o
ooooooooo`1kooooo`03o`000?oo003ooooo05Kooooo00?o0000ool00?ooool0KOooool0027ooooo
00?o0000ooooooooool0N_ooool00ol0003oo`00ooooo`1Iooooo`03ool00?l0003ooooo06_ooooo
000Qooooo`?o0000NOooool2ool005gooooo0_l0001Zooooo`008Oooool00ol0003oooooooooo`1h
ooooo`03ool00?oooooooooo05oooooo0_l0001Xooooo`008Oooool00ol0003oooooooooo`1goooo
o`03ool00?oooooooooo06;ooooo0_l0001Vooooo`008Oooool00ol0003oooooooooo`1fooooo`03
ool00?oooooooooo06Gooooo00?o0000ooooooooool0Hoooool0027ooooo00?o0000ooooooooool0
MOooool00ooo003oooooooooo`1Wooooo`;o0000Hoooool0027ooooo00?o0000ooooooooool0M?oo
ool00ooo003oooooooooo`1Xooooo`;oo`0000?o0000ooooooooool0H?ooool0027ooooo00?o0000
ooooooooool0Loooool00ooo003oooooooooo`1[ooooo`03ool00?l0003o0000063ooooo000Qoooo
o`?o0000L_ooool00ooo003oooooooooo`1]ooooo`;oo`0000?o0000ooooooooool0GOooool0027o
oooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1`ooooo`;oo`0000?o0000oooooooo
ool0Foooool0027ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1cooooo`03ool0
0?l0003ooooo05_ooooo000Qooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0MOoo
ool2ool00003o`000?oooooooooo05Sooooo000Qooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool0N?ooool00ooo003o0000ooooo`1Hooooo`008Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo07[ooooo0_oo001Hooooo`008Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo07cooooo00?oo`00o`000?ooool0EOooool0027ooooo00?o0000ooooooooool0
K?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo05?ooooo000Qooooo`?o0000J_oo
ool00ooo003o0000ooooo`22ooooo`03o`000?oooooooooo05;ooooo000Qooooo`03o`000?oooooo
oooo06Wooooo00?oo`00o`000?ooool0Q?ooool2o`0005;ooooo000Qooooo`03o`000?oooooooooo
06Sooooo00?oo`00o`000?ooool0Qoooool00ol0003oooooooooo`1?ooooo`008Oooool00ol0003o
ooooooooo`1Wooooo`03ool00?l0003ooooo08Wooooo00?o0000ooooooooool0C_ooool0027ooooo
00?o0000ooooooooool0I_ooool00ooo003o0000ooooo`2;ooooo`;o0000C_ooool000Oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Co
oooo00?o0000ooooooooool0IOooool00ooo003o0000ooooo`2=ooooo`;oo`00COooool000Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03
o`000?oooooooooo06Cooooo00?oo`00o`000?ooool0T?ooool2ool004_ooooo0005o`0000;ooooo
00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0001Sooooo`03
ool00?l0003ooooo09;ooooo00?o0000ool00?ooool0BOooool000Oooooo00Go0000oooooooooooo
ooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0H_ooool00ooo003o
0000ooooo`2Eooooo`03ool00?oooooooooo04Oooooo0007ooooo`05o`000?ooooooooooooooool0
00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0HOooool00ooo
003o0000ooooo`2Gooooo`03ool00?oooooooooo04Kooooo0007ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo063ooooo00?oo`00o`00
0?ooool0VOooool00ooo003oooooooooo`15ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Pooooo`03ool00?oooooooooo
09[ooooo00?oo`00o`000?ooool0A?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00001Oooool00ol0003oooooooooo`1Pooooo`03ool00?oooooooooo09_ooooo00?oo`00o`00
0?ooool0@oooool0027ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`2Mooooo`03
ool00?l0003ooooo04;ooooo000Qooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0
Woooool00ooo003o0000o`000011ooooo`008Oooool3o`0005gooooo00?o0000ooooooooool0XOoo
ool00ooo003oooooo`000010ooooo`008Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooo
oooo0:Cooooo00?o0000ooooooooool0?Oooool0027ooooo00?o0000ooooooooool0G?ooool00ol0
003oooooooooo`2Vooooo`;o0000?Oooool0027ooooo00?o0000ooooooooool0Foooool00ol0003o
ooooooooo`2Yooooo`03o`000?oooooooooo03[ooooo000Qooooo`03o`000?oooooooooo05[ooooo
00?o0000ooooooooool0Zoooool00ol0003oooooooooo`0iooooo`008Oooool00ol0003ooooooooo
o`1Iooooo`03ool00?l0003ooooo0:gooooo00?o0000ooooooooool0>?ooool0027ooooo00?o0000
ooooooooool0FOooool00ooo003oooooooooo`2^ooooo`;oo`00>?ooool0027ooooo0ol0001Hoooo
o`03ool00?oooooooooo0;7ooooo00?oo`00ooooooooool0=Oooool0027ooooo00?o0000oooooooo
ool0Eoooool00ooo003oooooooooo`2cooooo`03ool00?oooooooooo03Cooooo000Qooooo`03o`00
0?oooooooooo05Kooooo00?oo`00o`000?ooool0]Oooool00ooo003o0000ooooo`0cooooo`008Ooo
ool00ol0003oooooooooo`1Eooooo`03ool00?l0003ooooo0;Oooooo0_oo000cooooo`008Oooool0
0ol0003oooooooooo`1Dooooo`03ool00?l0003ooooo0;[ooooo00?oo`00ooooooooool0<?ooool0
027ooooo00?o0000ooooooooool0E?ooool00ooo003oooooooooo`2kooooo`03ool00?oooooooooo
02oooooo000Qooooo`03o`000?oooooooooo05?ooooo00?oo`00o`000?ooool0_Oooool00ooo003o
ooooooooo`0^ooooo`008Oooool00ol0003oooooooooo`1Cooooo`03ool00?oooooooooo0;kooooo
00?oo`00o`000?ooool0;Oooool0027ooooo0ol0001Booooo`03ool00?oooooooooo0<3ooooo00?o
o`00o`000?ooool0;?ooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000ool00?l00000?Oooool4o`000003oa0@
4?oooooooooo03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM02oooooo00?oo`00o`000?ooool02oooool5o`0001_ooooo000Qooooo`03o`00
0?oooooooooo03gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00ooo003o
<S8booooo`0nooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01?ooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool0<?ooool00ol0003oooooooooo`09ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@06oooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo410@
00kooooo00?oo`00ooooool00000?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`09ooooo`03oiRHV?lQ8B7ok^k^
01cooooo000Qooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000=oooo
o`04o`000?ooooooMgMgoc8b<Soooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>
ooooo`03ogMgMolb<S;ooooo03;ooooo0_l0000:ooooo`03oiRHV?lQ8B7ok^k^01_ooooo000Qoooo
o`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000<ooooo`?o000000?o<S8b
olc<c?ooool0?_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00eooooo`03o`000?oooooooooo00Sooooo00?oMgMgofIVI_ooool06_oo
ool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Wooooo000Q
ooooo`?o0000?Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo0_l00013ooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0iooooo`;o00001?oo
ool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`03o`000?oooooooooo03gooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go0000?_ooool00omEEEGoIVIVo`00000oooooo`03oeEE
EOmVIVKo000000gooooo1?l0000iooooo`;oo`000oooool01OnHV9So410@o`000?lQ8B7oc<c<01_o
oooo000Qooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0d_ooool00ooo003ooooo
ooooo`0Pooooo`008Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo0=Cooooo00?o
o`00ooooooooool07oooool0027ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`3F
ooooo`;oo`007oooool0027ooooo00?o0000ooooooooool0BOooool00ooo003o0000ooooo`3Ioooo
o`03ool00?oooooooooo01;ooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000oooooooo
ool0BOooool00ooo003oooooooooo`3Jooooo`03ool00?oooooooooo017ooooo00Kok^k^ob4Q8On7
QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0003o000004So000000?oo`00o`00
0?l00000g?l000000ooo003o0000o`000005o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0
027ooooo00?o0000ool00?ooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo
00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo0_l0000=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?oo`00o`000?ooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool04Oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0
003oooooo`000016ooooo`03ool00?oooooooooo0?7ooooo0_l00002ooooo`;o00001?ooool0027o
oooo00?o0000ooooool00000AOooool00ooo003oooooooooo`3looooo`008Oooool01?l0003ooooo
ooooool00013ooooo`03ool00?oooooooooo0?gooooo000Qooooo`05o`000?ooooooooooooooool0
0000@_ooool00ooo003oooooooooo`3mooooo`008Oooool01Ol0003ooooooooooooooooo0000047o
oooo00?oo`00ooooooooool0o_ooool0027ooooo0ol00002ooooo`03o`000?oooooooooo03gooooo
00?oo`00ooooooooool0ooooool0027ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0kooooo`03ool00?oooooooooo0?oooooo0Oooool0027ooooo00?o0000ooooooooool00oooool0
0ol0003oo`00ooooo`0jooooo`03ool00?oooooooooo0?oooooo0_ooool0027ooooo00?o0000oooo
ooooool01?ooool00ooo003oooooooooo`0hooooo`03o`000?oooooooooo0?oooooo0oooool0027o
oooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`0gooooo`03o`000?oooooooooo0?oo
oooo0oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oo`00ooooo`0fooooo`03o`00
0?oooooooooo0?oooooo1?ooool0027ooooo00?o0000ooooooooool01_ooool00ol0003oo`00oooo
o`0dooooo`03o`000?oooooooooo0?oooooo1Oooool0027ooooo0ol00007ooooo`03ool00?oooooo
oooo03;ooooo00?o0000ooooooooool0ooooool6ooooo`008Oooool00ol0003oooooooooo`07oooo
o`03o`000?oo003ooooo037ooooo00?o0000ooooooooool0ooooool7ooooo`008Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oo003ooooo02oooooo00?o0000ooooooooool0ooooool8ooooo`00
8Oooool00ol0003oooooooooo`09ooooo`03o`000?oo003ooooo02gooooo00?o0000ooooooooool0
ooooool9ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?ooooooo`0002cooooo00?o
0000ool00?ooool0ooooool:ooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
o`0002[ooooo00?o0000ool00?ooool0ooooool;ooooo`008Oooool00ol0003oooooooooo`0;oooo
o`03o`000?ooooooo`0002Sooooo00?o0000ool00?ooool0ooooool<ooooo`008Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?ooooooo`0002Kooooo00?o0000ool00?ooool0ooooool=ooooo`00
8Oooool3o`0000gooooo00?o0000ooooooooool09?ooool2ool00?oooooo3oooool0027ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Rooooo`03ool00?oooooooooo0?oooooo3ooo
ool0027ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Pooooo`03ool00?oooooo
oooo0?oooooo4?ooool0027ooooo00?o0000ooooooooool04?ooool2o`0001oooooo00?oo`00oooo
ooooool0oooooolAooooo`008Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01_o
oooo00?oo`00ooooooooool0oooooolBooooo`008Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01Sooooo00?o0000ool00?ooool0oooooolDooooo`008Oooool00ol0003ooooooooo
o`0Dooooo`;o00005oooool00ol0003oo`00ooooo`3ooooooaGooooo000Qooooo`?o00005Oooool2
ool001Cooooo0_l0003ooooooaSooooo000Qooooo`03o`000?oooooooooo01Oooooo00?oo`00oooo
ooooool04?ooool00ol0003oooooooooo`3ooooooaSooooo000Qooooo`03o`000?oooooooooo01So
oooo0_oo00000ol0003oooooooooo`0;ooooo`;o0000oooooolKooooo`008Oooool00ol0003ooooo
ooooo`0Jooooo`?oo`002?ooool3o`000?oooooo7Oooool0027ooooo00?o0000ooooooooool07Ooo
ool8ool00?oooooo8?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool00_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5ooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooo
oooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oo
ooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo
000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00:Cooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2Wooooo`00Pooo
ool3o`0001Cooooo00?o8B4QomgMgOooool01_ooool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@
413ogMgM0:Oooooo001kooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP02ooooo`03o`00
0?oooooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03oiRHV?mEEEGooooo00Ko
oooo00?oEEEEoiRHV?ooool00_ooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool01_nj^[[o
A4A4ooooooooooooQhN7ofIVIQCooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00?ooooo00GoA4A4o`000?l0003o<S8bomgMg@1eooooo`00
Noooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00_ooool00ol0003oooooooooo`0;oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ogMgMooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o
^[Zj0_ooool00oo^k^ko0000ooooo`0;ooooo`Ko00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Gooooo00?oMgMgoc8b<_ooool0M?ooool007_o
oooo00Oo0000oooooooMgMgo<S8booooooo^k^ko410@00;ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`06ooooo`;oMgMg1_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7o
k^k^00cooooo00Co410@omgMgOoooooo00001?ooool00ol0003oooooooooo`0Booooo`05oa0@4?oo
ooooooooooooool@41004?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07?ooooo
001kooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Co0000oooooooooooo00003Oooool00ol0003o
ooooooooo`06ooooo`03onk^k_l@413ok^k^00Gooooo00?o<S8booooooooool01?ooool00onHV9So
8B4Qonk^kP0;ooooo`04ohN7QomVIVKoooooo`0000Cooooo00?o0000ooooooooool02_ooool6o`00
00;ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Gooooo00?oMgMg
oc8b<_ooool0M?ooool007_ooooo00?ogMgMob4Q8Oo^k^h00oooool01?l0003oooooo`000?l0000=
ooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool00ol0003ok^k^ooooo`05
ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo00000oooool00oo^k^ko0000oooo
o`0Cooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c01eooooo`00O?ooool00onHV9SoMgMgooooo`02ooooo`03
o`000?oooooooooo00cooooo00?o410@o`000?l000000ol00006ooooo`03omgMgOl@413ooooo00Co
oooo00?oEEEEogMgMoooool01_ooool00ol0003oooooooooo`08ooooo`Oo000000?oooooogMgMomE
EED05?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1gooooo`00T_ooool00ol0003oooooooooo`08ooooo`03oeEEEOnHV9Sooooo00?o
oooo00?ogMgMoa0@4?o^k^h00_ooool01Ol0003o^[ZjoooooonHV9So410@017ooooo00?ok^k^oa0@
4?oMgMd05?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1gooooo`00T_ooool00ol0003oooooooooo`08ooooo`03okZj^_m4A4Cooooo
00Cooooo00WoMgMgofIVI_oooooooooooiRHV?l@413o0000ob4Q8Oo<c<`04Oooool00omVIVKoMgMg
ooooo`0Dooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Cooooo1?l0001fooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .29825 L
.06244 .28885 L
.07286 .28521 L
.07784 .28384 L
.08255 .28277 L
.08523 .28226 L
.08813 .28179 L
.09054 .28147 L
.0932 .28117 L
.09607 .28094 L
.09764 .28084 L
.09912 .28077 L
.09982 .28075 L
.10049 .28073 L
.10175 .2807 L
.10245 .28069 L
.1031 .28069 L
.10382 .28068 L
.10458 .28069 L
.10582 .28071 L
.10653 .28073 L
.10718 .28074 L
.10851 .2808 L
.10994 .28087 L
.11251 .28103 L
.11487 .28123 L
.12058 .28188 L
.12599 .2827 L
.14616 .28691 L
.16438 .29137 L
.17475 .29375 L
.18449 .29569 L
.19401 .2972 L
.19936 .29785 L
.2019 .29811 L
.20427 .29831 L
.20683 .2985 L
.20915 .29863 L
.21174 .29875 L
.21316 .29879 L
.2138 .29881 L
.2145 .29882 L
.21581 .29884 L
.21652 .29885 L
.21719 .29885 L
.21838 .29885 L
.21967 .29884 L
.22039 .29883 L
.22117 .29881 L
Mistroke
.2226 .29877 L
.22399 .29872 L
.22527 .29866 L
.22793 .29851 L
.23037 .29834 L
.23587 .2978 L
.24072 .29717 L
.24584 .29635 L
.25472 .29454 L
.26446 .29205 L
.284 .28553 L
.30493 .27666 L
.34635 .25505 L
.38624 .2319 L
.42462 .21022 L
.46546 .19006 L
.48575 .18164 L
.50478 .17486 L
.5232 .16938 L
.54258 .16479 L
.55224 .16297 L
.5628 .16132 L
.5724 .16015 L
.58132 .15932 L
.58639 .15897 L
.58905 .15882 L
.59187 .15868 L
.59434 .15859 L
.59705 .1585 L
.59824 .15847 L
.59951 .15845 L
.60063 .15843 L
.60182 .15841 L
.60306 .1584 L
.60421 .15839 L
.60544 .15839 L
.60615 .15839 L
.60681 .1584 L
.608 .1584 L
.60909 .15841 L
.61028 .15843 L
.61154 .15845 L
.61374 .1585 L
.61578 .15856 L
.62042 .15875 L
.62546 .15903 L
.63092 .15942 L
.64085 .16036 L
.65051 .16156 L
.65943 .16291 L
Mistroke
.67817 .16648 L
.6988 .1715 L
.73911 .18432 L
.7779 .19991 L
.81914 .21935 L
.85887 .24026 L
.89709 .26184 L
.93775 .28585 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .30003 L
.06244 .29044 L
.07286 .28645 L
.08255 .28366 L
.08813 .28249 L
.0932 .28169 L
.096 .28136 L
.09748 .28121 L
.09905 .28108 L
.10042 .28099 L
.10192 .2809 L
.1033 .28085 L
.10458 .28081 L
.10583 .28078 L
.10652 .28078 L
.10715 .28077 L
.10838 .28078 L
.10954 .28079 L
.1102 .2808 L
.1109 .28082 L
.11214 .28087 L
.11349 .28093 L
.11496 .28101 L
.11742 .28118 L
.12006 .28141 L
.12483 .28195 L
.13452 .28345 L
.14335 .28518 L
.16405 .28991 L
.1832 .29416 L
.19278 .29593 L
.20178 .29725 L
.2063 .29776 L
.21117 .2982 L
.2138 .29838 L
.21657 .29853 L
.21894 .29862 L
.22028 .29866 L
.22153 .29868 L
.2228 .2987 L
.22345 .2987 L
.22415 .2987 L
.22541 .29869 L
.22658 .29868 L
.22728 .29867 L
.22795 .29865 L
.22921 .29862 L
.23057 .29857 L
.23205 .2985 L
Mistroke
.23455 .29835 L
.2372 .29815 L
.24198 .29768 L
.24701 .29702 L
.25174 .29625 L
.26057 .29441 L
.27036 .2918 L
.28069 .28842 L
.29917 .28091 L
.3372 .26089 L
.37768 .2362 L
.41664 .21291 L
.45805 .1917 L
.47879 .18303 L
.49795 .17631 L
.51776 .17065 L
.53633 .16653 L
.55503 .16349 L
.56496 .16231 L
.5705 .16177 L
.57565 .16136 L
.58068 .16102 L
.58524 .16078 L
.59032 .16058 L
.5931 .1605 L
.59435 .16047 L
.59573 .16044 L
.59696 .16042 L
.59829 .16041 L
.59903 .1604 L
.59969 .16039 L
.601 .16039 L
.6022 .16038 L
.6035 .16039 L
.60473 .16039 L
.60586 .1604 L
.60717 .16041 L
.60839 .16043 L
.61118 .16048 L
.6139 .16056 L
.61684 .16066 L
.62179 .16087 L
.62639 .16113 L
.63686 .16192 L
.64705 .16295 L
.65795 .16434 L
.67927 .16791 L
.69941 .1723 L
.73785 .18339 L
.77873 .19891 L
Mistroke
.8181 .21704 L
.85596 .23679 L
.89627 .25969 L
.93506 .28317 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`2^ooooo`_o0000Roooool0027ooooo00?o0000ooooooooool0Y?ooool:
o`000003oooooooo003oo`0000koo`001Ol00020ooooo`008Oooool00ol0003oooooooooo`2Noooo
o`;o00001Ooo000Jooooo`03ool00?oooooooooo00;ooooo1?l0001looooo`008Oooool3o`0009_o
oooo1Ooo000Xooooo`;o00000ooo00000ol0003oooooooooo`1dooooo`008Oooool00ol0003ooooo
ooooo`2Gooooo`Coo`00<_ooool3ool000?o0000LOooool0027ooooo00?o0000ooooooooool0Tooo
ool2o`0000;oo`00>Oooool3ool000?o0000K_ooool0027ooooo00?o0000ooooooooool0TOooool2
o`00043ooooo1Ooo00000ol0003oooooooooo`1Yooooo`008Oooool00ol0003oooooooooo`2?oooo
o`;o0000Aoooool2ool000;o0000J?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0R_ooool2
ool000?o0000COooool3o`0006Gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`28ooooo`;oo`000_l0001C
ooooo`?o0000H_ooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000
ooooooooool00_ooool3o`0008Kooooo0_oo00000ol0003oooooooooo`1Gooooo`;o0000H?ooool0
00Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000
ooooooooool0Q?ooool2ool005gooooo0ooo001Nooooo`001oooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo08;ooooo0_oo
001Rooooo`?oo`00Foooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0P?ooool2ool00003o`000?oooooooooo06Cooooo0_oo
001Iooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1nooooo`;oo`0000?o0000ooooooooool0J?ooool3ool005Kooooo0007
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0OOoo
ool00ooo003o0000ooooo`1]ooooo`03o`000?oo003ooooo05Cooooo000Qooooo`03o`000?oooooo
oooo07cooooo0_l0001aooooo`?o0000D_ooool0027ooooo00?o0000ooooooooool0N_ooool2o`00
07Kooooo0_l0001@ooooo`008Oooool3o`0007Sooooo0_l0001jooooo`;o0000C_ooool0027ooooo
00?o0000ooooooooool0M_ooool2o`0007kooooo0_l0001<ooooo`008Oooool00ol0003ooooooooo
o`1booooo`;oo`000_l00022ooooo`;oo`00B_ooool0027ooooo00?o0000ooooooooool0LOooool0
0ooo003o0000o`000026ooooo`;oo`00B?ooool0027ooooo00?o0000ooooooooool0Koooool2ool0
0003o`000?oooooooooo08Oooooo00?o0000ool00?oo0000A_ooool0027ooooo00?o0000oooooooo
ool0K_ooool00ooo003o0000ooooo`2<ooooo`03o`000?oo003ooooo04Cooooo000Qooooo`03o`00
0?oooooooooo06gooooo00?oo`00ooooooooool0Soooool2ool004?ooooo000Qooooo`?o0000Jooo
ool2ool009?ooooo00?o0000ool00?oo0000@Oooool0027ooooo00?o0000ooooooooool0JOooool2
ool009Oooooo00?o0000ool00?oo0000?oooool0027ooooo00?o0000ooooooooool0Ioooool2ool0
09_ooooo00?o0000ool00?ooool0?Oooool0027ooooo00?o0000ooooooooool0I_ooool00ooo003o
0000ooooo`2Mooooo`03o`000?oooooooooo03_ooooo000Qooooo`03o`000?oooooooooo06Cooooo
0_l0002Qooooo`;o0000>oooool0027ooooo00?o0000ooooooooool0Hoooool00ol0003ooooooooo
o`2Sooooo`;o0000>Oooool0027ooooo00?o0000ooooooooool0HOooool2o`000:Sooooo00?o0000
ooooooooool0=_ooool0027ooooo00?o0000ooooooooool0Goooool2o`000:_ooooo0_l0000foooo
o`008Oooool3o`0005gooooo0_l0002_ooooo`03o`000?oo003oo`0003?ooooo000Qooooo`03o`00
0?oooooooooo03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Oooooo00?o0000ool00?oo0000<oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM02Wooooo00?o0000ool00?oo00004Oooool5o`0001_ooooo000Qooooo`03o`000?oooooooooo
03gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oo003oo`0003Oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Zooooo`03o`000?oo003oo`0000oooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool01Ol0003ooooooooooooooooo000000;oo`00>Oooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:oooool00ol0003oo`00
ooooo`0>ooooo`03oiRHV?lQ8B7ok^k^01cooooo000Qooooo`03o`000?oooooooooo03gooooo00Go
0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00;o000000?oo`00ooooooooool0
>Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0
;_ooool2ool000kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Ooo
ool01Ol0003ooooooooooooooooo000000cooooo00Co0000ob4Q8Ol0003o<S8b0_l00002ool003co
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`0<?ooool00ol0003oo`00ool0000=ooooo`03ogMgMomVIVKooooo01[ooooo000Qooooo`03
o`000?oooooooooo00kooooo00?o0000ool00?oo00002?oo0009o`0001_ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`04o`000?oooooo0000o`0000;oo`00?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=?ooool00ol0003oo`00ooooo`0<
ooooo`03o`000?oooooooooo01Wooooo000Qooooo`?o00002oooool01?l0003oo`00ool00?oo000C
ooooo`Goo`005_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00Co0000ool00?oo003oo`00
@?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
=_ooool00ooo003o0000ooooo`06ooooo`05o`000?nj^[[ooooooiRHV?l@41006oooool0027ooooo
00?o0000ooooooooool02?ooool2o`0000;oo`006_ooool00ol0003oo`00ool00003ool0017ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP09ooooo`?o000000Coo`00o`000?l0003o0000?_ooool00omE
EEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000fooooo`03ool00?l0003o0000
00Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Kooooo`008Oooool00ol0003oooooooooo`06oooo
o`;o00000_oo000Oooooo`?o00000ooo000Iooooo`?o0000e?ooool00ol0003oooooooooo`0Roooo
o`008Oooool00ol0003oooooooooo`04ooooo`;o00009_ooool3o`0000Coo`003oooool6o`000=So
oooo0_l0000Rooooo`008Oooool00ol0003oooooooooo`02ooooo`;o0000;oooool:o`0000Soo`00
gOooool2o`00023ooooo000Qooooo`03o`000?oooooooooo00;o0000oooooolSooooo`03o`000?oo
oooooooo01?ooooo0_l00002ooooo`;o00001?ooool0027ooooo0ol0003oooooobKooooo0_l0000C
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool001[ooooo1ol00003ool00?oo00009ol0
0002ool000Oo00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool01?o^k^ko8B4Qoa0@
4?o^k^h5ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool04Oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003ooooooooo
o`3ooooooc_ooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo
AOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0
003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo002Xooooo`03ogMgMomVIVKooooo01Oooooo00?oIVIVogMgMoooool0Xooo
ool008Oooooo0ol0000Cooooo`03ob4Q8OoMgMgooooo00Oooooo00?ogMgMoa0@4?o^k^h06?ooool0
0oo^k^ko410@omgMg@2Sooooo`00O_ooool01on7QhOo0000oeEEEOmVIVKo0000oc8b<_o^k^h00ooo
ool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool00onHV9SoEEEE
ooooo`07ooooo`04oeEEEOnHV9Soooooooooo`Go00002Oooool00omEEEGoZJVYooooo`02ooooo`03
okZj^_m4A4Cooooo00;ooooo00?oQhN7ofIVI_ooool04_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0Noooool007kooooo00Oo410@omgM
gOmgMgOo8B4Qoooooon7QhOoIVIV00?ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^
k_mgMgOo410@00?ooooo00?o0000omgMgOooool01_ooool02Ol0003oooooooooooooooooV9RHob4Q
8Oo^k^koooooodA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj0oooool00oo^k^ko0000
ooooo`0;ooooo`Ko000000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q07_ooooo001nooooo`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@
4003ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool2ogMgM`Oooooo00?o
<S8booooooooool00_ooool00onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`0000Gooooo
00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooo
ooooooooo`00001kooooo`00O_ooool01?mEEEGoZJVYooooool00002ooooo`05o`000?oooooooooo
ooooool000003Oooool00ol0003oooooooooo`05ooooo`03onk^k_l@413ok^k^00Kooooo00?o<S8b
ooooooooool00oooool00onHV9So8B4Qonk^kP0;ooooo`04ohN7QomVIVKoooooo`0000Gooooo00?o
0000ooooooooool02_ooool6o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q07_ooooo001nooooo`03omgMgOlQ8B7ok^k^00?ooooo00?o
0000ooooooooool00_l0000=ooooo`03o`000?oooooooooo00Kooooo00?oEEEEoiRHV?ooool01Ooo
ool00ol0003ok^k^ooooo`04ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo0000
1?ooool00oo^k^ko0000ooooo`0Booooo`05o`000?ooooooooooooooool000002oooool01Ol0003o
EEEEo`000?l@413oc<c<07_ooooo001oooooo`03oiRHV?mgMgOooooo00;ooooo00?o0000oooooooo
ool03Oooool00ol@413o0000o`000003o`0000Gooooo00?ogMgMoa0@4?ooool01Oooool00omEEEGo
MgMgooooo`05ooooo`03o`000?oooooooooo00Sooooo1ol00002ooooo`03ogMgMomEEEGooooo01;o
oooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo07gooooo002Fooooo`03
o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool02OoMgMgo410@onk^k_oooooo0000
okZj^_ooooooV9RHoa0@400Booooo`03onk^k_l@413ogMgM01?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`03omgMgOl@413oV9RH07gooooo002Fooooo`03o`000?oooooooooo00Oooooo00?o
^[ZjodA4A?ooool01Oooool02?mgMgOoIVIVoooooonHV9So410@o`000?lQ8B7oc<c<4_ooool00omV
IVKoMgMgooooo`0Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@
411kooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.65) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .27238 L
.06244 .23683 L
.08426 .20431 L
.0949 .19164 L
.10458 .18215 L
.11403 .17482 L
.12297 .16968 L
.12787 .16759 L
.1324 .16613 L
.13476 .16554 L
.13737 .16502 L
.13868 .16482 L
.14009 .16463 L
.14142 .1645 L
.14264 .16441 L
.14392 .16435 L
.14514 .16432 L
.14622 .16431 L
.1474 .16434 L
.14869 .1644 L
.14934 .16444 L
.15005 .16449 L
.15248 .16475 L
.15476 .1651 L
.15721 .16558 L
.16162 .16671 L
.16719 .16862 L
.17246 .1709 L
.18234 .17627 L
.20225 .19068 L
.22067 .20694 L
.25994 .2445 L
.29769 .27667 L
.31866 .29095 L
.33789 .30144 L
.35674 .3093 L
.36622 .31239 L
.37658 .31513 L
.38686 .31723 L
.39619 .31862 L
.40136 .3192 L
.40409 .31945 L
.40697 .31967 L
.40949 .31983 L
.41226 .31998 L
.41478 .32008 L
.41714 .32015 L
.41839 .32018 L
.41908 .32019 L
Mistroke
.41973 .3202 L
.42098 .32021 L
.42212 .32021 L
.42278 .32021 L
.42348 .32021 L
.42473 .32021 L
.42543 .3202 L
.42608 .32019 L
.42755 .32017 L
.42883 .32014 L
.43005 .3201 L
.43232 .32003 L
.43743 .31978 L
.44205 .31948 L
.44631 .31913 L
.45597 .31814 L
.47467 .31549 L
.49529 .31172 L
.53554 .30294 L
.57428 .29421 L
.61547 .28605 L
.63604 .28272 L
.65515 .28016 L
.67361 .27821 L
.68387 .27736 L
.69331 .27673 L
.70358 .2762 L
.70898 .27599 L
.7147 .27582 L
.71709 .27576 L
.71966 .27571 L
.72209 .27568 L
.7243 .27565 L
.72565 .27564 L
.7269 .27563 L
.72755 .27563 L
.72827 .27562 L
.72902 .27562 L
.72972 .27562 L
.73101 .27562 L
.73219 .27562 L
.73349 .27563 L
.73414 .27563 L
.73486 .27563 L
.73739 .27566 L
.73882 .27567 L
.74013 .27569 L
.74512 .27578 L
.74965 .2759 L
.75445 .27606 L
Mistroke
.76441 .2765 L
.77539 .27714 L
.79481 .27869 L
.8157 .28088 L
.85694 .28657 L
.89667 .29337 L
.93488 .30069 L
.97555 .30889 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .27199 L
.06244 .23587 L
.08255 .20557 L
.09409 .19184 L
.10458 .18186 L
.11464 .17456 L
.11926 .17195 L
.12415 .16968 L
.12937 .16783 L
.13169 .16718 L
.13419 .16661 L
.13687 .16614 L
.13807 .16597 L
.13938 .16582 L
.14017 .16575 L
.14091 .16569 L
.14167 .16564 L
.14236 .16561 L
.14368 .16557 L
.14441 .16556 L
.14509 .16556 L
.14625 .16558 L
.1475 .16563 L
.14867 .16571 L
.14974 .16579 L
.15237 .1661 L
.15485 .1665 L
.15979 .16759 L
.16517 .16924 L
.17476 .17324 L
.18364 .17803 L
.2023 .19093 L
.22291 .2083 L
.26311 .24579 L
.3018 .27888 L
.32144 .29264 L
.34294 .30467 L
.35286 .30911 L
.36346 .31307 L
.3734 .31605 L
.38256 .3182 L
.3928 .31995 L
.3982 .32061 L
.40095 .32088 L
.40391 .32112 L
.4065 .32129 L
.40886 .32141 L
.41 .32146 L
.41124 .3215 L
Mistroke
.41241 .32154 L
.4135 .32156 L
.41417 .32157 L
.41489 .32159 L
.41616 .3216 L
.41687 .3216 L
.41763 .3216 L
.41827 .3216 L
.41898 .3216 L
.42025 .32158 L
.42096 .32157 L
.42161 .32156 L
.42406 .32149 L
.42635 .32141 L
.42888 .32128 L
.434 .32095 L
.43874 .32054 L
.44318 .32008 L
.46396 .31706 L
.48418 .31309 L
.5027 .30891 L
.54237 .29954 L
.58053 .29144 L
.60182 .28768 L
.62115 .2848 L
.6415 .2823 L
.66024 .28047 L
.67947 .27902 L
.69022 .27839 L
.70028 .27791 L
.70935 .27756 L
.71908 .27729 L
.72462 .27717 L
.72735 .27713 L
.72988 .2771 L
.73212 .27707 L
.7346 .27705 L
.73588 .27704 L
.73709 .27704 L
.73836 .27703 L
.73907 .27703 L
.73973 .27703 L
.74101 .27703 L
.74221 .27703 L
.74329 .27703 L
.74446 .27704 L
.74574 .27704 L
.74709 .27705 L
.74952 .27707 L
.75176 .27709 L
Mistroke
.75386 .27712 L
.75863 .27721 L
.76384 .27733 L
.7686 .27747 L
.77932 .2779 L
.78918 .27843 L
.79832 .27904 L
.81905 .28087 L
.83959 .28331 L
.8582 .28604 L
.89829 .29317 L
.93686 .30077 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool08Oooool6o`000?oooooo7_ooool0027ooooo0ol0000Mooooo`03
o`000?oo003oo`0000[oo`00oooooolKooooo`008Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oo003oo`0000cooooo00Coo`00o`000?l0003o0000oooooolGooooo`008Oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oo003ooooo017ooooo00?o0000ooooooooool0oooooolDooooo`008Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01?ooooo0_l0003ooooooaCooooo000Q
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`3o
oooooa7ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06?oo
ool2o`000?oooooo4Oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06_oo
ool2ool00?oooooo4?ooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o
0000ooooooooool00_ooool3o`0001Gooooo00?o0000ooooooooool07Oooool2ool00?oooooo3_oo
ool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Pooooo`03ool00?oooooooooo0?oooooo2ooo
ool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1?ooool00ol0003oooooooooo`0Booooo`03ool00?l0003ooooo02?ooooo00?oo`00ooooooooool0
ooooool:ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Booooo`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0
ooooool9ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo02Kooooo00?oo`00ooooooooool0
ooooool8ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`00
0?oooooooooo013ooooo00?oo`00ooooooooool0:?ooool00ooo003oooooooooo`3oooooo`Oooooo
000Qooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0:Oooool00ooo003ooooooooo
o`3oooooo`Kooooo000Qooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool0:oooool0
0ooo003oooooooooo`3oooooo`Gooooo000Qooooo`?o00003_ooool00ooo003oooooooooo`0]oooo
o`03ool00?oooooooooo0?oooooo1?ooool0027ooooo00?o0000ooooooooool03Oooool00ooo003o
0000ooooo`0_ooooo`03ool00?oooooooooo0?oooooo0oooool0027ooooo00?o0000ooooooooool0
3?ooool00ooo003o0000ooooo`0aooooo`03o`000?oooooooooo0?oooooo0_ooool0027ooooo00?o
0000ooooooooool03?ooool00ooo003oooooooooo`0booooo`03o`000?oooooooooo0?oooooo0Ooo
ool0027ooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`0dooooo`03o`000?oooooo
oooo0?oooooo000Qooooo`03o`000?oooooooooo00[ooooo00?oo`00o`000?ooool0=_ooool00ol0
003oooooooooo`3nooooo`008Oooool00ol0003oooooooooo`09ooooo`03ool00?l0003ooooo03So
oooo00?o0000ooooooooool0oOooool0027ooooo0ol00009ooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool0o?ooool0027ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo0?_ooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0??ooool00ooo003o0000ooooo`3jooooo`008Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo03gooooo0_oo003jooooo`008Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo043ooooo00?oo`00ooooooooool0moooool0027ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`11ooooo`03ool00?oooooooooo0?Kooooo000Qooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0@oooool00ooo003oooooooooo`3eooooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Gooooo0_oo003eooooo`008Oooool3o`00
00Gooooo00?o0000ooooooooool0Aoooool00ooo003oooooooooo`3booooo`008Oooool00ol0003o
ooooooooo`04ooooo`03ool00?oooooooooo03Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000ool00?lb<S;ogMgM03gooooo1?l000000ol@413oooooooooo`0k
ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@0mooooo`Go00006oooool0027ooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`0f
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oo`00oc8b<_ooool0?_oo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo03cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003ooooooooo
o`03ooooo`03ool00?oooooooooo03Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03ool0
0?oooooooooo03gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo03cooooo00?oV9RHob4Q8Oo^k^h07?ooool0027ooooo00?o0000ooooooooool00ooo
ool00ooo003oooooooooo`0gooooo`05o`000?ooooooooooooooool000003oooool01?mgMgOo<S8b
ool00?l0000mooooo`03o`000?oooooooooo03Gooooo4ol00009ool000Ko0000>_ooool00onHV9So
8B4Qonk^kP0Kooooo`008Oooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo03Sooooo
00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo02_ooooo1?l0000?ool00003ooooool0003ooooo
00cooooo00Co0000ob4Q8Ol0003o<S8b2Ooo0004o`0003Cooooo00?oMgMgofIVI_ooool06_ooool0
027ooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0hooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool09Oooool6o`0000?ooooo00?oo`00ooooooooool03_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00kooooo1_l00007ool002Sooooo00?o0000ooooooooool06Oooool0
027ooooo0ol000000oooooooo`00ooooo`0jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool07oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Hooooo`?o00001_oo000Nooooo`05o`000?nj^[[ooooooiRHV?l@41006ooo
ool0027ooooo00Go0000ooooooooooooooooool0000kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`0000Kooooo00?o0000ooooooooool0=Oooool00omEEEGoIVIVo`00000Looooo`Koo`00
7Oooool00omEEEGoIVIVo`00000=ooooo`Co00008?ooool3ool000?o00006?ooool01OnHV9So410@
o`000?lQ8B7oc<c<01_ooooo000Qooooo`04o`000?ooooooooooool005Sooooo0_l0001=ooooo`Oo
o`00GOooool5o`0003?ooooo000Qooooo`03o`000?ooooooo`0005_ooooo00?o0000ool00?oo0000
B?ooool5o`0006Kooooo0_l00003ool002kooooo000Qooooo`03o`000?ooooooo`0005gooooo00?o
0000ool00?oo0000@?ooool6o`0006oooooo00Co0000ool00?oo003oo`00:oooool0027ooooo00?o
0000ool00?ooool0Goooool00ol0003oo`00o`00000iooooo`Coo`0000?o0000ooooooooool0Mooo
ool7ool001[ooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ool00?ooool0HOooool3
ool00003o`000?oooooooooo02oooooo1Ooo0023ooooo`;o00001?oo00000ol0003oooooooooo`0C
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool001[ooooo1ol000000ooo003o0000o`00
001To`0000;oo`00:ol00005ool009Wo00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oo003ooooo00?o00002Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ool00?oo00000_l0000>ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooool00003ool000Co00001Oooool00ol0003oooooooooo`0<ooooo`04o`000?oo
ooooooooooooo`Oo00001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo
00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000ooooooooool0Koooool4o`0000oooooo
0ooo0002o`000;?ooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool0Looo
ool2o`0000goo`0000?o0000ooooooooool0_oooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodGooooo
0007ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000
oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0
0oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3
o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o410@oooooooo
ool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool0
01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_oo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool00omgMgOoIVIV
ooooo`0Gooooo`03ofIVI_mgMgOooooo0:Oooooo0023ooooo`?o00005?ooool00olQ8B7ogMgMoooo
o`06ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Yoooool007_ooooo00OoQhN7
o`000?mEEEGoIVIVo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool02oooool01OnHV9So0000
o`000?m4A4Co^[Zj00?ooooo00?oV9RHoeEEEOooool01_ooool00omEEEGoV9RHooooo`02ooooo`Go
00002Oooool00omEEEGoZJVYooooo`02ooooo`06okZj^_m4A4Cooooooooooon7QhOoIVIV5?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM07Gooooo001kooooo`07oa0@4?oMgMgoMgMgob4Q8Ooo
ooooQhN7ofIVIP02ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_o^k^koMgMgoa0@4004
ooooo`03o`000?oMgMgooooo00Gooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X2ooooo`03onk^k_l0003ooooo00_o
oooo1_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMg
MoooooooV9RHob4Q8@07ooooo`03ogMgMolb<S;ooooo07Cooooo001kooooo`07o`000?oooooogMgM
oc8b<_ooooook^k^oa0@4002ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_oo
ool2ogMgM`Kooooo00?o<S8booooooooool00oooool00onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oM
gMgoooooo`0000Cooooo00?o0000ooooooooool04_ooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo07?ooooo001kooooo`04
oeEEEOnYZJWoooooo`0000;ooooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`06
ooooo`03onk^k_l@413ok^k^00Gooooo00?o<S8booooooooool01?ooool00onHV9So8B4Qonk^kP0;
ooooo`04ohN7QomVIVKoooooo`0000Cooooo00?o0000ooooooooool02_ooool6o`0000;ooooo00Go
0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401oooool00omgMgOo
<S8booooo`1dooooo`00Noooool00ooMgMgo8B4Qonk^kP03ooooo`04o`000?oooooo0000o`0000go
oooo00?o0000ooooooooool01oooool00omEEEGoV9RHooooo`04ooooo`03o`000?o^k^kooooo00Go
oooo00?oMgMgofIVI_ooool02_ooool01?oMgMgo410@ooooool00003ooooo`03onk^k_l0003ooooo
01?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<07Gooooo001looooo`03oiRHV?mgMgOooooo00;ooooo00?o
0000ooooooooool03?ooool00ol@413o0000o`000003o`0000Kooooo00?ogMgMoa0@4?ooool01?oo
ool00omEEEGoMgMgooooo`06ooooo`03o`000?oooooooooo00Sooooo1ol000000oooooooMgMgoeEE
E@0Dooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`06ooooo`03o`00
0?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo00Sooooo00?oEEEEoiRHV?ooool00ooo
ool00ooMgMgo410@onk^kP02ooooo`05o`000?nj^[[ooooooiRHV?l@41004Oooool00oo^k^ko410@
omgMg@0Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV006ooooo`03
o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo00Sooooo00?o^[ZjodA4A?ooool0
1?ooool02OmgMgOoIVIVooooooooooooV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`03ofIVI_mgMgOo
oooo01Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Cooooo
1?l0001fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .22868 L
.08255 .19214 L
.10458 .15892 L
.11448 .14672 L
.12507 .13572 L
.13499 .1274 L
.14415 .12149 L
.14911 .119 L
.15437 .11691 L
.15964 .11539 L
.16265 .11477 L
.16399 .11456 L
.16546 .11436 L
.1668 .11423 L
.16805 .11413 L
.16925 .11407 L
.17052 .11403 L
.17178 .11403 L
.17296 .11406 L
.17401 .1141 L
.17516 .11418 L
.17642 .11429 L
.1778 .11446 L
.1806 .1149 L
.18318 .11544 L
.1856 .11607 L
.1906 .11772 L
.19605 .12005 L
.20595 .12566 L
.22451 .14059 L
.24428 .16194 L
.26529 .18929 L
.30304 .24489 L
.34324 .30393 L
.38193 .35286 L
.40158 .37344 L
.42307 .39239 L
.44383 .40718 L
.46269 .41776 L
.4823 .42605 L
.49308 .42953 L
.50325 .43214 L
.51298 .43407 L
.51829 .43491 L
.52327 .43555 L
.52786 .43604 L
.53205 .43638 L
.53671 .43667 L
.53928 .43679 L
Mistroke
.54172 .43687 L
.54297 .4369 L
.54363 .43691 L
.54432 .43692 L
.54559 .43694 L
.54676 .43695 L
.54789 .43695 L
.54894 .43695 L
.5501 .43694 L
.55133 .43693 L
.55265 .43691 L
.55408 .43688 L
.55669 .4368 L
.55922 .43669 L
.56157 .43657 L
.57049 .43593 L
.575 .4355 L
.57997 .43495 L
.59935 .43205 L
.62022 .42782 L
.66141 .41698 L
.70109 .40451 L
.73925 .39151 L
.77986 .37721 L
.81896 .36334 L
.86051 .34872 L
.90054 .33484 L
.93906 .32164 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .2282 L
.08255 .19146 L
.10458 .15819 L
.11448 .14607 L
.12507 .13522 L
.13499 .12711 L
.14415 .12143 L
.14911 .11909 L
.15437 .11716 L
.15709 .11639 L
.15964 .1158 L
.16245 .11531 L
.16402 .1151 L
.16546 .11496 L
.1667 .11487 L
.16802 .1148 L
.16926 .11478 L
.17039 .11478 L
.17109 .11479 L
.17173 .11481 L
.17243 .11485 L
.17317 .11489 L
.17441 .11499 L
.17578 .11513 L
.17823 .11548 L
.18086 .11598 L
.1856 .11722 L
.19088 .11909 L
.19577 .12126 L
.20684 .12769 L
.22696 .14425 L
.24562 .16432 L
.26622 .19047 L
.30643 .24823 L
.34512 .30452 L
.38626 .35718 L
.40678 .37897 L
.42588 .39611 L
.44548 .41045 L
.46399 .42098 L
.4738 .42542 L
.48444 .42938 L
.49405 .43223 L
.50303 .4343 L
.5125 .4359 L
.51752 .43652 L
.52291 .43702 L
.52561 .4372 L
.52855 .43736 L
Mistroke
.5299 .43742 L
.53133 .43746 L
.53268 .4375 L
.5339 .43752 L
.5352 .43754 L
.53639 .43755 L
.5377 .43755 L
.53836 .43755 L
.53908 .43754 L
.5403 .43753 L
.5416 .4375 L
.54283 .43747 L
.54395 .43744 L
.54625 .43735 L
.54877 .43723 L
.55389 .4369 L
.55863 .43649 L
.56307 .43603 L
.58385 .43298 L
.60407 .42887 L
.62259 .42442 L
.66227 .41361 L
.70043 .40257 L
.74104 .39062 L
.78014 .37884 L
.82169 .36563 L
.86172 .35195 L
.90024 .33794 L
.94121 .32244 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0:oooool2o`000?oooooo6?ooool0027ooooo00?o0000ooooooooool09_ooool5o`00
0004ooooool0003o0000o`0000?oo`00oooooolCooooo`008Oooool3o`0002Cooooo0_oo000;oooo
o`04o`000?oo003o0000o`000?oooooo4?ooool0027ooooo00?o0000ooooooooool08_ooool2ool0
00oooooo0_oo00000ol0003oooooooooo`3oooooo`gooooo000Qooooo`03o`000?oooooooooo027o
oooo00?oo`00ooooooooool04Oooool2ool00003o`000?oooooooooo0?oooooo2oooool0027ooooo
00?o0000ooooooooool07oooool2ool001Kooooo0_oo003oooooo`cooooo000Qooooo`03o`000?oo
oooooooo01kooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`3oooooo`Wooooo000Q
ooooo`03o`000?oooooooooo01gooooo00?oo`00ooooooooool06_ooool00ooo003oooooooooo`3o
ooooo`Sooooo000Qooooo`03o`000?oooooooooo01cooooo00?oo`00o`000?ooool07?ooool00ooo
003oooooooooo`3oooooo`Oooooo000Qooooo`?o00006oooool00ooo003o0000ooooo`0Nooooo`03
ool00?oooooooooo0?oooooo1_ooool0027ooooo00?o0000ooooooooool06_ooool00ooo003o0000
ooooo`0Pooooo`03ool00?oooooooooo0?oooooo1Oooool0027ooooo00?o0000ooooooooool06_oo
ool00ooo003oooooooooo`0Qooooo`03o`000?oooooooooo0?oooooo1?ooool0027ooooo00?o0000
ooooooooool06Oooool00ooo003oooooooooo`0Sooooo`03o`000?oooooooooo0?oooooo0oooool0
027ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
0?oooooo0_ooool0027ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo0?oooooo0Oooool0027ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo0?oooooo000Qooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`3oooooo`008Oooool3o`0001Gooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`3nooooo`008Oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo02cooooo00?oo`00ooooooooool0oOooool0027ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0]ooooo`03ool00?l0003ooooo0?gooooo000Qooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0;oooool00ooo003o0000ooooo`3looooo`008Ooo
ool00ol0003oooooooooo`0Booooo`03ool00?l0003ooooo037ooooo00?oo`00ooooooooool0nooo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Cooooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`0booooo`03ool0
0?oooooooooo0?[ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Aooooo`03ool00?l0003ooooo03Cooooo
00?oo`00ooooooooool0nOooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool00_ooool3o`00017ooooo00?oo`00ooooooooool0=Oooool00ooo003ooooo
ooooo`3hooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0
0oooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo03Kooooo00?oo`00ooooooooool0
n?ooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01?ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo03Oooooo00?oo`00oooooooo
ool0moooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool03oooool00ooo003oooooooooo`0iooooo`03ool00?oooooooooo0?Ko
oooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00kooooo00?o0000ool00?ooool0>_ooool00ooo003oooooooooo`3fooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo00ko
oooo00?oo`00ooooooooool0>oooool00ooo003oooooooooo`3eooooo`008Oooool00ol0003ooooo
ooooo`0=ooooo`03ool00?oooooooooo03gooooo00?oo`00ooooooooool0m?ooool0027ooooo00?o
0000ooooooooool03?ooool00ol0003oo`00ooooo`0oooooo`03o`000?oooooooooo0??ooooo000Q
ooooo`?o00003?ooool00ooo003oooooooooo`0oooooo`03o`000?oooooooooo0??ooooo000Qoooo
o`03o`000?oooooooooo00_ooooo00?o0000ool00?ooool0@Oooool00ol0003oooooooooo`3boooo
o`008Oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo04;ooooo00?o0000oooooooo
ool0lOooool0027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`13ooooo`03o`00
0?oooooooooo0?7ooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0AOoo
ool00ol0003oooooooooo`3`ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo04Kooooo00?o0000ooooooooool0koooool0027ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo0>kooooo000Qooooo`?o00002?ooool00ol0003o
ooooooooo`18ooooo`03ool00?oooooooooo0>kooooo000Qooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0B_ooool00ooo003oooooooooo`3]ooooo`008Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo04_ooooo00?oo`00ooooooooool0k?ooool0027ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`1<ooooo`03o`000?oo003ooooo0>cooooo000Qoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0COooool00ooo003oooooooooo`3[oooo
o`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo003ooooo04oooooo00?oo`00oooooooo
ool0j_ooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oo`00ooooo`1?ooooo`03o`00
0?oo003ooooo0>[ooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ool00?ooool0DOoo
ool00ooo003oooooooooo`3Yooooo`008Oooool3o`0000Cooooo00?o0000ool00?ooool0DOooool0
0ol0003oo`00ooooo`3Yooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oo003ooooo
03Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Kooooo00?oo`00ooooooooool0=?ooool4o`000003oa0@4?oooooooooo03_ooooo1?l0
00000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03gooooo
1Ol0000Kooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oo003ooooo03Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`06ooooo`03ool0
0?oooooooooo03Gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`0looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0027ooooo
00?o0000ooooooooool00oooool00ooo003oooooooooo`0gooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol0003oooooooooo`05ooooo`03o`000?oo003ooooo03Gooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03cooooo00?oV9RHob4Q8Oo^
k^h07?ooool0027ooooo00?o0000ooooooooool00_ooool00ol0003oo`00ooooo`0hooooo`05o`00
0?ooooooooooooooool000003oooool00omgMgOo<S8booooo`07ooooo`03ool00?oooooooooo03Co
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03ko
oooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool00_ooool00ooo003ooooo
ooooo`0hooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Wooooo00?oo`00ooooooooool0<oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c010ooooo`03ogMgMomVIVKooooo01[ooooo000Qoooo
o`06o`000?ooooooooooooooool0003oo`00>_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Wooooo
000Qooooo`?o000000?oooooool00?ooool0>_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0oooooo`05o`000?nj^[[ooooooiRHV?l@
41006oooool0027ooooo00Go0000oooooooooooo0000ool0000kooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000cooooo00?o0000ooooooooool0;oooool00omEEEGoIVIVo`00000ooooo
o`03oeEEEOmVIVKo000000gooooo1?l0000nooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`06oooool0
027ooooo00Co0000ooooooooooooo`00GOooool00ol0003oooooooooo`3Sooooo`008Oooool01?l0
003oooooo`000?oo001Nooooo`03o`000?oooooooooo0>;ooooo000Qooooo`03o`000?ooooooo`00
05oooooo00?o0000ooooooooool0h_ooool0027ooooo0_l0001Qooooo`03o`000?oooooooooo0=Oo
oooo0_l00002ooooo`;o00001?ooool0027ooooo0_l0001Rooooo`03o`000?oooooooooo0=Kooooo
00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_oooom]o`000003ool00?l0003o00000<3o
00000_oo0007o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02?ooool01?l0003oo`00ooooool0000>ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`08ooooo`05o`000?oo003oo`00ooooool000004oooool0
1?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oo003o
000000kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Gooooo00Co0000ool00?oo003oo`000oooool00ol0003oooooooooo`0Aooooo`04ob4Q8Omg
MgOoMgMgoc8b<PGooooo000Qooooo`03o`000?oooooooooo06Cooooo00?o0000ool00?ooool0]_oo
ool2o`0000;oo`006Oooool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`1U
ooooo`03o`000?oo003ooooo0;;ooooo0ol000000oooooooo`00ooooo`0Tooooo`008Oooool00ol0
003oooooooooo`1Uooooo`03o`000?oo003ooooo0:oooooo0ol0000Zooooo`008Oooool00ol0003o
ooooooooo`1Vooooo`03o`000?oo003ooooo0:_ooooo0ol0000]ooooo`008Oooool00ol0003ooooo
ooooo`1Wooooo`03o`000?oo003ooooo0:Oooooo0ol0000`ooooo`008Oooool3o`0006Sooooo00?o
0000ool00?ooool0Xoooool3o`000004oooooooo003oo`00ool002oooooo000Qooooo`03o`000?oo
oooooooo06Wooooo00?oo`00ooooooooool0Woooool3o`0000Coo`00<_ooool0027ooooo00?o0000
ooooooooool0JOooool00ol0003oo`00ooooo`2Mooooo`;o00000ooo000fooooo`008Oooool00ol0
003oooooooooo`1Zooooo`03o`000?oo003ooooo09[ooooo0_l00002ool003Wooooo000Qooooo`03
o`000?oooooooooo06_ooooo00?o0000ool00?ooool0U_ooool2o`0000?oo`00>oooool0027ooooo
00?o0000ooooooooool0K?ooool00ol0003oooooooooo`2Booooo`?o000000?oooooool00?ooool0
?Oooool0027ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`2>ooooo`?o0000@ooo
ool0027ooooo0ol0001^ooooo`03o`000?oooooooooo08[ooooo0ol00016ooooo`008Oooool00ol0
003oooooooooo`1_ooooo`03o`000?oooooooooo08Kooooo0ol00019ooooo`008Oooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo08;ooooo0ol000001?ooooooo`00ool00?oo0018oooo
o`008Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07kooooo0ol00004ool004_o
oooo000Qooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0N_ooool2o`0000Coo`00
Coooool0027ooooo00?o0000ooooooooool0Loooool2o`0007Sooooo00Co0000ool00?oo003oo`00
Doooool0027ooooo00?o0000ooooooooool0Loooool2ool00003o`000?oooooooooo07;ooooo0_l0
0002ool005Kooooo000Qooooo`03o`000?oooooooooo07Gooooo00?oo`00o`000?ooool0L?ooool2
o`0005[ooooo000Qooooo`?o0000M_ooool00ooo003o0000ooooo`1/ooooo`?o0000G?ooool0027o
oooo00?o0000ooooooooool0Moooool00ooo003o0000ooooo`1Xooooo`?o0000Goooool0027ooooo
00?o0000ooooooooool0N?ooool00ooo003o0000ooooo`1Tooooo`?oo`00H_ooool0027ooooo00?o
0000ooooooooool0NOooool00ooo003o0000o`00001Oooooo`Coo`00IOooool0027ooooo00?o0000
ooooooooool0N_ooool00ooo003oooooo`00001Jooooo`Coo`0000?o0000ooooooooool0I_ooool0
027ooooo00?o0000ooooooooool0Noooool2ool000;o0000EOooool3ool000;o0000Joooool0027o
oooo00?o0000ooooooooool0OOooool00ooo003oooooo`00001Booooo`;oo`000_l0001^ooooo`00
8Oooool3o`0007kooooo00?oo`00ooooool00000C_ooool4o`00077ooooo000Qooooo`03o`000?oo
oooooooo07oooooo00Coo`00ooooool0003o0000BOooool3o`0007Gooooo000Qooooo`03o`000?oo
oooooooo08?ooooo0_l00012ooooo`;oo`000ol0001hooooo`008Oooool00ol0003oooooooooo`25
ooooo`03o`000?oooooooooo03_ooooo1?oo0002o`0007_ooooo000Qooooo`03o`000?oooooooooo
08Kooooo0_l0000gooooo`Coo`000ol0001nooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`28
ooooo`?o0000<?ooool4ool000?o0000P_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo08Wooooo00Coo`00
ooooool0003o0000;?ooool2ool000?o0000Q_ooool000Oooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00;ooooo0ol0002:ooooo`?oo`000ol0000Vooooo`Co0000R_oo
ool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o
0000ooooooooool0SOooool3ool000?o00008?ooool3o`0008kooooo0007ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0
T?ooool6ool000;o00004Oooool6ool000Co0000TOooool000Oooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0U_ooool3ool000Ko0000
2_oo0005o`0009Kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`00
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool0
0_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_ooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z?ooool00omgMgOoIVIVoooo
o`0Gooooo`03ofIVI_mgMgOooooo0:?ooooo0027ooooo`?o00004oooool00olQ8B7ogMgMooooo`07
ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Xoooool007kooooo00OoQhN7o`00
0?mEEEGoIVIVo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool02oooool01OnHV9So0000o`00
0?m4A4Co^[Zj00;ooooo00?oV9RHoeEEEOooool01oooool01?mEEEGoV9RHooooooooool5o`0000Wo
oooo00?oEEEEojVYZOooool00_ooool00onj^[[oA4A4ooooo`02ooooo`03ohN7QomVIVKooooo01;o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`1koooo
o`00O_ooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00oooool00ol0003oooooooooo`0;
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0003ogMgMooooo`06ooooo`09o`000?oo
oooooooooooooonHV9So8B4Qonk^k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@4?nj
^[X3ooooo`03onk^k_l0003ooooo00_ooooo1_l000001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Go
oooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo07_ooooo001nooooo`07o`000?oooooogMgMoc8b<_oo
ooook^k^oa0@4003ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool2ogMg
M`Oooooo00?o<S8booooooooool00_ooool00onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgooooo
o`0000Gooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00gooooo00?o
ZJVYoeEEEOooool0Noooool007kooooo00CoEEEEojVYZOoooooo00000_ooool01Ol0003ooooooooo
oooooooo000000gooooo00?o0000ooooooooool01Oooool00oo^k^ko410@onk^kP06ooooo`03oc8b
<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7QhOoIVIVooooool00005ooooo`03
o`000?oooooooooo00[ooooo1_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00co
oooo00?o8B4Qooooooooool0N_ooool007kooooo00?ogMgMob4Q8Oo^k^h00oooool00ol0003ooooo
ooooo`02o`0000gooooo00?o0000ooooooooool01_ooool00omEEEGoV9RHooooo`05ooooo`03o`00
0?o^k^kooooo00Cooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgo410@ooooool00004ooooo`03
onk^k_l0003ooooo01;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo
07[ooooo001oooooo`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool03Oooool00ol@413o
0000o`000003o`0000Gooooo00?ogMgMoa0@4?ooool01Oooool00omEEEGoMgMgooooo`05ooooo`03
o`000?oooooooooo00Sooooo1ol00002ooooo`03ogMgMomEEEGooooo01;ooooo00Go410@oooooooo
oooooooooa0@400>ooooo`03ojVYZOmgMgOooooo07[ooooo002Fooooo`03o`000?oooooooooo00Oo
oooo00?oEEEEoiRHV?ooool01?ooool02OoMgMgo410@onk^k_oooooo0000okZj^_ooooooV9RHoa0@
400Booooo`03onk^k_l@413ogMgM01?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S80Noooool009Kooooo00?o0000ooooooooool01oooool00onj^[[oA4A4
ooooo`05ooooo`08ogMgMomVIVKooooooiRHV?l@413o0000ob4Q8Oo<c<`Booooo`03ofIVI_mgMgOo
oooo01?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go0000Noooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .25375 L
.10458 .2005 L
.12507 .17924 L
.14415 .16309 L
.16254 .15139 L
.17284 .14665 L
.18221 .14355 L
.18704 .1424 L
.18969 .14191 L
.19216 .14154 L
.19427 .14129 L
.19654 .14108 L
.19783 .141 L
.19905 .14094 L
.20015 .14091 L
.20135 .14089 L
.20203 .14089 L
.20276 .1409 L
.20345 .14091 L
.20409 .14093 L
.2053 .14098 L
.20657 .14105 L
.20794 .14115 L
.20922 .14128 L
.21213 .14164 L
.21466 .14205 L
.21696 .1425 L
.22214 .1438 L
.22694 .14533 L
.23205 .14732 L
.24122 .15181 L
.26198 .16619 L
.28145 .18471 L
.29973 .20604 L
.33842 .26095 L
.37956 .32697 L
.41919 .3895 L
.45729 .44234 L
.47854 .46728 L
.49785 .48677 L
.51817 .50389 L
.5369 .5166 L
.55608 .52665 L
.56619 .53076 L
.57688 .53425 L
.58632 .53663 L
.59152 .53766 L
.59646 .53846 L
.60103 .53905 L
Mistroke
.60345 .53931 L
.60603 .53953 L
.60841 .5397 L
.61056 .53982 L
.6116 .53987 L
.61273 .53991 L
.61378 .53995 L
.61477 .53997 L
.61602 .53999 L
.61715 .54 L
.61837 .54 L
.61906 .54 L
.6197 .54 L
.62076 .53998 L
.62193 .53996 L
.62315 .53992 L
.6243 .53988 L
.62693 .53975 L
.62933 .5396 L
.63475 .53913 L
.63966 .53854 L
.64502 .53775 L
.65582 .53565 L
.67547 .53024 L
.69644 .52239 L
.73799 .50146 L
.77802 .47584 L
.81654 .44741 L
.85751 .41421 L
.89697 .38024 L
.93491 .34643 L
.9753 .30983 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .25452 L
.10458 .20111 L
.12507 .17917 L
.14415 .16236 L
.16254 .15021 L
.17284 .14535 L
.1773 .1437 L
.18221 .14222 L
.18704 .1411 L
.18969 .14063 L
.19216 .14028 L
.19335 .14015 L
.19448 .14004 L
.1955 .13996 L
.19659 .13989 L
.19777 .13984 L
.19887 .1398 L
.20017 .13979 L
.20135 .1398 L
.20266 .13983 L
.20331 .13986 L
.20403 .13989 L
.20531 .13997 L
.2065 .14007 L
.20918 .14037 L
.21206 .14081 L
.21733 .14194 L
.22214 .14332 L
.23205 .14724 L
.24122 .1521 L
.26198 .16731 L
.28065 .18551 L
.30125 .20983 L
.34145 .26663 L
.38014 .32713 L
.42128 .39051 L
.4609 .44482 L
.49901 .48706 L
.52026 .50556 L
.53957 .51906 L
.54921 .52461 L
.55966 .52974 L
.56945 .53372 L
.57862 .53674 L
.58808 .53914 L
.5931 .54014 L
.59849 .54098 L
.60119 .54133 L
.60414 .54164 L
Mistroke
.60673 .54186 L
.60815 .54196 L
.60949 .54204 L
.61081 .54211 L
.61223 .54217 L
.61352 .54221 L
.6147 .54223 L
.61583 .54225 L
.61706 .54226 L
.61834 .54226 L
.61954 .54224 L
.6208 .54222 L
.62144 .5422 L
.62215 .54218 L
.62456 .54208 L
.62592 .542 L
.62738 .54191 L
.63002 .5417 L
.63519 .54117 L
.63993 .54053 L
.64898 .53891 L
.6585 .53669 L
.67828 .53046 L
.69666 .52291 L
.73576 .50216 L
.77731 .47473 L
.81734 .44464 L
.85586 .41344 L
.89683 .37867 L
.93629 .34424 L
.97422 .31075 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`00033ooooo2?l00003ool00?oooooo2_oo
ool0027ooooo00?o0000ooooooooool0:oooool4ool00003o`000?oooooooooo00Wooooo0ooo003o
ooooo`Oooooo000Qooooo`03o`000?oooooooooo02[ooooo00Coo`00o`000?l0003o00004?ooool3
ool00?oooooo1?ooool0027ooooo00?o0000ooooooooool0:?ooool2ool00003o`000?oooooooooo
01Cooooo0_oo003oooooo`;ooooo000Qooooo`03o`000?oooooooooo02Oooooo00?oo`00oooooooo
ool06Oooool00ooo003oooooooooo`3nooooo`008Oooool00ol0003oooooooooo`0Uooooo`;oo`00
7Oooool00ooo003o0000ooooo`3mooooo`008Oooool00ol0003oooooooooo`0Tooooo`03ool00?oo
oooooooo01kooooo00?oo`00o`000?ooool0o?ooool0027ooooo00?o0000ooooooooool08_ooool2
ool002;ooooo00?oo`00o`000?ooool0noooool0027ooooo0ol0000Qooooo`03ool00?oooooooooo
02Cooooo00?o0000ooooooooool0nOooool0027ooooo00?o0000ooooooooool08?ooool00ooo003o
ooooooooo`0Vooooo`03o`000?oooooooooo0?Sooooo000Qooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`3gooooo`008Oooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0m_ooool0027ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo0?Gooooo0007oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`3dooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0`ooooo`03ool00?oo
oooooooo0??ooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo00;ooooo0ol0000Jooooo`03o`000?oooooooooo037ooooo00?oo`00o`000?ooool0looo
ool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0cooooo`03ool00?l0003ooooo0?;ooooo0007
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo
00?o0000ooooooooool06?ooool00ol0003oo`00ooooo`0eooooo`03ool00?l0003ooooo0?7ooooo
0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ool00?ooool0=oooool00ooo003o0000ooooo`3`ooooo`001ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Gooooo`03ool00?oooooooooo03Sooooo00?oo`00o`000?ooool0koooool000Oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oo003ooooo03[ooooo00?oo`00o`000?ooool0k_ooool0027ooooo00?o0000ooooooooool05Ooo
ool00ol0003oo`00ooooo`0looooo`03ool00?oooooooooo0>gooooo000Qooooo`03o`000?oooooo
oooo01Cooooo00?o0000ool00?ooool0?Oooool00ooo003o0000ooooo`3]ooooo`008Oooool3o`00
01?ooooo00?o0000ool00?ooool0?oooool00ooo003o0000ooooo`3/ooooo`008Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oo003ooooo047ooooo00?oo`00ooooooooool0joooool0027ooooo
00?o0000ooooooooool04_ooool00ol0003oo`00ooooo`11ooooo`03ool00?l0003ooooo0>_ooooo
000Qooooo`03o`000?oooooooooo017ooooo00?o0000ool00?ooool0@oooool00ooo003o0000oooo
o`3Zooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo003ooooo04Gooooo00?oo`00
o`000?ooool0jOooool0027ooooo00?o0000ooooooooool03oooool00ol0003oo`00ooooo`17oooo
o`03o`000?oooooooooo0>Sooooo000Qooooo`03o`000?oooooooooo00kooooo00?o0000ool00?oo
ool0BOooool00ol0003oooooooooo`3Wooooo`008Oooool3o`0000kooooo00?o0000ooooooooool0
B_ooool00ol0003oooooooooo`3Vooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool0i_ooool0027ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`1=ooooo`03o`000?oooooooooo0>Gooooo000Qooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`3Tooooo`008Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0hoooool0027ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo0>?ooooo
000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0D_ooool00ooo003o0000oooo
o`3Sooooo`008Oooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo05Cooooo00?oo`00
o`000?ooool0h_ooool0027ooooo0ol00007ooooo`03o`000?oo003ooooo05Kooooo00?oo`00oooo
ooooool0hOooool0027ooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`0cooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0>
ooooo`03ool00?oooooooooo02cooooo1?l000000ol@413oooooooooo`0kooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0mooooo`Go00006ooo
ool0027ooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`0dooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03Oooool00ooo003ooooooooo
o`0^ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool0??ooool01OnHV9So8B4Qonk^k_ooooooA4A401_ooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?o0000ool00?ooool0=Oooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool03Oooool00ooo003oooooooooo`0]ooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo
000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ool00?ooool0=_ooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool03oooool00ooo003oooooooooo`0/ooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0nooooo`03oiRH
V?lQ8B7ok^k^01_ooooo000Qooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0=_oo
ool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00@ooooo`03
ool00?oooooooooo02cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`0@?ooool00omgMgOoIVIVooooo`0Jooooo`008Oooool00ol0003o
ooooooooo`03ooooo`03ool00?oooooooooo03Oooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool0:oooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Ioooo
o`008Oooool3o`0000;ooooo00?o0000ool00?ooool0>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04oooool00ooo003oooooooooo`0[ooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0oooooo`05o`000?nj^[[ooooo
oiRHV?l@41006oooool0027ooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0hoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0001?ooooo00?oo`00ooooooooool0:?ooool0
0omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000nooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`06oooool0027ooooo00Go0000ooooooooooooooooool0001Sooooo`03o`000?oo
003ooooo0=cooooo000Qooooo`05o`000?ooooooooooo`000?oo0000I?ooool00ooo003ooooooooo
o`3Kooooo`008Oooool01?l0003oooooo`000?oo001Vooooo`03ool00?oooooooooo0=[ooooo000Q
ooooo`03o`000?ooooooo`0006Oooooo00?o0000ooooooooool0d?ooool2o`0000;ooooo0_l00004
ooooo`008Oooool2o`0006Wooooo00?o0000ooooooooool0coooool01_o^k^ko8B4QohN7Qonj^[[o
0000omgMg@Cooooo000Joooooooo0000<_l000000ooo003o0000o`000005o`0000cooooo00CogMgM
o`000?l@413oc<c<1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooo
oooo000000[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00[ooooo0_oo00000ol0003oooooooooo`0Aooooo`04onk^k_lQ8B7o410@onk^kPGooooo
000Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`04ool0
0?ooooooooooo`0001?ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000oooooooo
ool0J_ooool00ol0003oooooooooo`2fooooo`03ool00?oooooooooo01Cooooo0_l00002ooooo`;o
00001?ooool0027ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`2dooooo`03o`00
0?oooooooooo01oooooo000Qooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0/ooo
ool00ol0003oooooooooo`0Pooooo`008Oooool00ol0003oooooooooo`1/ooooo`;oo`00/_ooool0
0ol0003oooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`1/ooooo`03o`000?oo003ooooo
0;3ooooo00?o0000ooooooooool08_ooool0027ooooo0ol0001]ooooo`03o`000?oo003ooooo0:ko
oooo00?o0000ooooooooool08oooool0027ooooo00?o0000ooooooooool0K_ooool00ol0003oo`00
ooooo`2/ooooo`03o`000?oooooooooo02Cooooo000Qooooo`03o`000?oooooooooo06kooooo00?o
0000ool00?ooool0Zoooool00ol0003oooooooooo`0Uooooo`008Oooool00ol0003oooooooooo`1_
ooooo`03o`000?oo003ooooo0:Oooooo0ooo000Xooooo`008Oooool00ol0003oooooooooo`1`oooo
o`03ool00?oooooooooo0:Gooooo00?oo`00o`000?l00000:Oooool0027ooooo00?o0000oooooooo
ool0L?ooool00ol0003oo`00ooooo`2Tooooo`03ool00?l0003ooooo02[ooooo000Qooooo`03o`00
0?oooooooooo077ooooo00?o0000ool00?ooool0X_ooool00ooo003o0000ooooo`0[ooooo`008Ooo
ool3o`0007;ooooo00?oo`00ooooooooool0X?ooool00ooo003o0000ooooo`0/ooooo`008Oooool0
0ol0003oooooooooo`1cooooo`03ool00?oooooooooo09kooooo00?oo`00o`000?ooool0;Oooool0
027ooooo00?o0000ooooooooool0Loooool00ooo003oooooooooo`2Mooooo`03ool00?l0003ooooo
02kooooo000Qooooo`03o`000?oooooooooo07Cooooo00?oo`00ooooooooool0Voooool00ooo003o
0000ooooo`0_ooooo`008Oooool00ol0003oooooooooo`1eooooo`03ool00?oooooooooo09Wooooo
00?oo`00o`000?ooool0<?ooool0027ooooo00?o0000ooooooooool0MOooool00ol0003ooooooooo
o`2Hooooo`03ool00?l0003ooooo037ooooo000Qooooo`03o`000?oooooooooo07Kooooo00?o0000
ooooooooool0U_ooool00ooo003o0000ooooo`0booooo`008Oooool00ol0003oooooooooo`1goooo
o`03o`000?oooooooooo09Gooooo00?o0000ooooooooool0<_ooool0027ooooo0ol0001gooooo`03
o`000?oooooooooo09?ooooo0_l0000eooooo`008Oooool00ol0003oooooooooo`1hooooo`03o`00
0?oooooooooo097ooooo00?o0000ooooooooool0=Oooool0027ooooo00?o0000ooooooooool0NOoo
ool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo03Kooooo000Qooooo`03o`000?oooooo
oooo07Wooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`0gooooo`008Oooool00ol0
003oooooooooo`1jooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0>?ooool0027o
oooo00?o0000ooooooooool0Noooool00ooo003oooooooooo`28ooooo`;oo`0000?o0000oooooooo
ool0>Oooool0027ooooo00?o0000ooooooooool0Noooool00ooo003oooooooooo`27ooooo`03ool0
0?l0003ooooo03cooooo000Qooooo`?o0000O?ooool00ooo003oooooooooo`25ooooo`03ool00?l0
003ooooo03gooooo000Qooooo`03o`000?oooooooooo07gooooo00?oo`00ooooooooool0Poooool0
0ooo003o0000ooooo`0nooooo`008Oooool00ol0003oooooooooo`1mooooo`03ool00?l0003ooooo
08;ooooo00?oo`00o`000?ooool0?oooool0027ooooo00?o0000ooooooooool0O_ooool00ooo003o
ooooooooo`1oooooo`;oo`0000?o0000ooooooooool0?oooool0027ooooo00?o0000ooooooooool0
Ooooool00ooo003oooooooooo`1mooooo`03ool00?l0003ooooo04;ooooo0007ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03
o`000?oooooooooo083ooooo00?oo`00ooooooooool0Noooool00ooo003o0000ooooo`13ooooo`00
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?o
oooo00?o0000ooooooooool0P?ooool00ooo003oooooooooo`1jooooo`03ool00?l0003ooooo04Co
oooo0007ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o
0000POooool00ooo003oooooooooo`1hooooo`03ool00?l0003ooooo04Gooooo0007ooooo`05o`00
0?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo08;o
oooo00?oo`00ooooooooool0M_ooool00ooo003o0000ooooo`16ooooo`001oooool01Ol0003ooooo
oooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo
08;ooooo00?oo`00o`000?ooool0MOooool00ol0003oooooooooo`17ooooo`001oooool01Ol@413o
oooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`23oooo
o`03ool00?oooooooooo07?ooooo00?o0000ooooooooool0B?ooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Q?ooool00ooo
003oooooooooo`1aooooo`03o`000?oooooooooo04Wooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`1_oooo
o`03o`000?oooooooooo04[ooooo000Qooooo`03o`000?oooooooooo08Gooooo00?o0000oooooooo
ool0K_ooool00ol0003oooooooooo`1;ooooo`008Oooool00ol0003oooooooooo`26ooooo`03o`00
0?oooooooooo06_ooooo0_l0001>ooooo`008Oooool3o`0008Oooooo00?o0000ooooooooool0J?oo
ool2ool0053ooooo000Qooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0I_ooool0
0ooo003o0000ooooo`1@ooooo`008Oooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo
06Cooooo0_oo001Cooooo`008Oooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo06;o
oooo00?oo`00o`000?ooool0Doooool0027ooooo00?o0000ooooooooool0R_ooool00ol0003oo`00
ooooo`1Pooooo`03ool00?oooooooooo05Cooooo000Qooooo`03o`000?oooooooooo08_ooooo00?o
0000ool00?ooool0GOooool2ool005Oooooo000Qooooo`03o`000?oooooooooo08cooooo00?o0000
ool00?ooool0Foooool00ooo003oooooooooo`1Gooooo`008Oooool3o`0008gooooo00?o0000ool0
0?ooool0F?ooool2ool005[ooooo000Qooooo`03o`000?oooooooooo08kooooo00?o0000ool00?oo
ool0E_ooool00ooo003oooooooooo`1Jooooo`008Oooool00ol0003oooooooooo`2?ooooo`03o`00
0?oo003ooooo05?ooooo00?o0000ool00?ooool0G?ooool0027ooooo00?o0000ooooooooool0T?oo
ool00ol0003oo`00ooooo`1@ooooo`;o0000Goooool0027ooooo00?o0000ooooooooool0TOooool0
0ol0003oo`00ooooo`1>ooooo`03o`000?oooooooooo05oooooo000Qooooo`03o`000?oooooooooo
09?ooooo00?oo`00ooooooooool0B_ooool2o`0006;ooooo000Qooooo`03o`000?oooooooooo09Co
oooo00?oo`00o`000?ooool0Aoooool2o`0006Cooooo000Qooooo`03o`000?oooooooooo09Gooooo
00?oo`00o`000?ooool0AOooool00ol0003oooooooooo`1Tooooo`008Oooool3o`0009Kooooo00?o
o`00o`000?ooool0@_ooool2o`000003ool00?oooooooooo06Cooooo000Qooooo`03o`000?oooooo
oooo09Sooooo0_l0000oooooo`;o00000_oo001Wooooo`008Oooool00ol0003oooooooooo`2Joooo
o`03o`000?oooooooooo03[ooooo0_l00002ool006Wooooo000Qooooo`03o`000?oooooooooo09_o
oooo0_l0000hooooo`;o00000_oo001[ooooo`008Oooool00ol0003oooooooooo`2Mooooo`03o`00
0?oooooooooo03Cooooo0ooo001]ooooo`008Oooool00ol0003oooooooooo`2Nooooo`;o0000<_oo
ool2ool0073ooooo000Qooooo`03o`000?oooooooooo09oooooo00?oo`00o`000?l00000;_ooool2
ool007;ooooo000Qooooo`?o0000X?ooool01?oo003oooooo`000?l0000Zooooo`03o`000?oo003o
oooo07?ooooo000Qooooo`03o`000?oooooooooo0:7ooooo0ooo0002o`0002Gooooo0ol0001foooo
o`008Oooool00ol0003oooooooooo`2Tooooo`?oo`008Oooool3o`0007Wooooo000Qooooo`03o`00
0?oooooooooo0:Oooooo00?oo`00o`000?l000006oooool3o`0007cooooo000Qooooo`03o`000?oo
oooooooo0:Sooooo1_oo00000ol0003oooooooooo`0@ooooo`;o00000ooo001nooooo`006?ooool4
o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0[_ooool00ooo003o0000o`00000?
o`0000?oo`00POooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2eoooo
o`_oo`00Q?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGo
oooo000Jooooo`03o`000?oooooooooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00:Cooooo00?oMgMgofIVI_ooool05oooool00omV
IVKoMgMgooooo`2Wooooo`00Poooool3o`0001Cooooo00?o8B4QomgMgOooool01_ooool00ooMgMgo
410@onk^kP0Hooooo`03onk^k_l@413ogMgM0:Oooooo001kooooo`07ohN7Qol0003oEEEEofIVI_l0
003o<S8bonk^kP02ooooo`03o`000?oooooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P03
ooooo`03oiRHV?mEEEGooooo00Kooooo00?oEEEEoiRHV?ooool00_ooool5o`0000Wooooo00?oEEEE
ojVYZOooool00_ooool01_nj^[[oA4A4ooooooooooooQhN7ofIVIQCooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd0MOooool007_ooooo00Oo410@omgMgOmgMgOo8B4Qoooooon7QhOoIVIV00;ooooo00?o0000
ooooooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000omgMgOooool01Ooo
ool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RH
oooooooooooo410@okZj^P;ooooo00?ok^k^o`000?ooool02oooool6o`0000;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;o
oooo07Cooooo001kooooo`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@4002ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01_ooool2ogMgM`Kooooo00?o<S8booooooooool00ooo
ool00onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`0000Cooooo00?o0000ooooooooool0
4_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003o
ooooooooo`1cooooo`00Noooool01?mEEEGoZJVYooooool00002ooooo`04o`000?ooooooooooo`00
00gooooo00?o0000ooooooooool01_ooool00oo^k^ko410@onk^kP05ooooo`03oc8b<_oooooooooo
00Cooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7QhOoIVIVooooool00004ooooo`03o`000?oooooo
oooo00[ooooo1_l00002ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo07Cooooo001kooooo`03omgMgOlQ8B7ok^k^00?ooooo00Co0000
ooooool0003o00003Oooool00ol0003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00?o
0000onk^k_ooool01Oooool00omgMgOoIVIVooooo`0:ooooo`04omgMgOl@413oooooo`0000?ooooo
00?ok^k^o`000?ooool04oooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<07Gooooo001looooo`03oiRHV?mgMgOooooo00;o
oooo00?o0000ooooooooool03?ooool00ol@413o0000o`000003o`0000Kooooo00?ogMgMoa0@4?oo
ool01?ooool00omEEEGoMgMgooooo`06ooooo`03o`000?oooooooooo00Sooooo1ol000000ooooooo
MgMgoeEEE@0Dooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03oooo
o`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo00Sooooo00?oEEEEoiRHV?oo
ool00oooool00ooMgMgo410@onk^kP02ooooo`05o`000?nj^[[ooooooiRHV?l@41004Oooool00oo^
k^ko410@omgMg@0Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooo
oooo<S8b00Cooooo00?o0000ooooooooool0Moooool009;ooooo00?o0000ooooooooool02?ooool0
0onj^[[oA4A4ooooo`04ooooo`09ogMgMomVIVKooooooooooonHV9So410@o`000?lQ8B7oc<c<017o
oooo00?oIVIVogMgMoooool05?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004oooo
o`Co0000M_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .29218 L
.10458 .27223 L
.14415 .25272 L
.18221 .23569 L
.20178 .22874 L
.21267 .22568 L
.22272 .22347 L
.22768 .22261 L
.23293 .22189 L
.23548 .22161 L
.23821 .22136 L
.23978 .22125 L
.24121 .22116 L
.24257 .22108 L
.24402 .22102 L
.24471 .221 L
.24536 .22098 L
.24658 .22096 L
.24772 .22094 L
.24896 .22094 L
.24961 .22094 L
.25032 .22095 L
.25107 .22096 L
.25177 .22098 L
.25301 .22101 L
.25435 .22107 L
.25698 .22122 L
.25948 .22141 L
.26416 .22192 L
.26875 .22261 L
.27382 .22358 L
.28407 .22625 L
.29357 .22958 L
.30249 .23349 L
.32267 .2451 L
.34118 .25911 L
.3808 .29907 L
.41891 .34753 L
.45947 .40439 L
.49852 .45793 L
.54002 .50729 L
.56082 .52759 L
.58 .54323 L
.59868 .55545 L
.60822 .56051 L
.61846 .56506 L
.62869 .56869 L
.63804 .57121 L
.64253 .57215 L
Mistroke
.64743 .57298 L
.65206 .57358 L
.65415 .57379 L
.65635 .57397 L
.65762 .57406 L
.65901 .57414 L
.66028 .5742 L
.66144 .57424 L
.6621 .57426 L
.66282 .57427 L
.66358 .57429 L
.66429 .57429 L
.66496 .5743 L
.66567 .5743 L
.66695 .57429 L
.66812 .57426 L
.66939 .57423 L
.67059 .57418 L
.67169 .57413 L
.67424 .57397 L
.67691 .57375 L
.68153 .57323 L
.68581 .5726 L
.69553 .57064 L
.70608 .5677 L
.71603 .56419 L
.73463 .55579 L
.77315 .53141 L
.81412 .49671 L
.85358 .4566 L
.89151 .41354 L
.93191 .36455 L
.97078 .31584 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .29243 L
.10458 .27268 L
.14415 .25276 L
.18221 .23522 L
.20178 .22811 L
.21274 .225 L
.21758 .22385 L
.22272 .22281 L
.22745 .222 L
.23267 .2213 L
.23496 .22105 L
.23742 .22083 L
.23974 .22067 L
.24186 .22055 L
.24314 .2205 L
.24384 .22048 L
.24451 .22046 L
.24579 .22044 L
.24696 .22043 L
.24763 .22043 L
.24835 .22043 L
.24963 .22045 L
.25034 .22047 L
.25101 .22048 L
.25252 .22054 L
.25383 .2206 L
.25508 .22068 L
.25741 .22085 L
.25992 .22109 L
.26265 .22141 L
.26749 .22215 L
.27205 .22304 L
.28242 .22576 L
.29253 .22939 L
.30343 .23437 L
.32347 .24644 L
.34457 .26309 L
.38268 .30223 L
.42324 .35344 L
.46228 .40714 L
.50378 .46295 L
.54376 .51004 L
.58223 .5451 L
.6021 .55839 L
.61225 .56382 L
.62315 .56859 L
.63338 .57206 L
.64272 .5744 L
.64722 .57523 L
Mistroke
.64959 .57559 L
.65212 .57593 L
.65455 .57619 L
.65674 .57638 L
.65896 .57653 L
.66004 .57659 L
.66104 .57663 L
.6622 .57667 L
.66345 .5767 L
.66461 .57672 L
.66571 .57672 L
.66698 .57671 L
.66816 .57668 L
.66945 .57664 L
.67082 .57659 L
.67336 .57644 L
.67574 .57624 L
.68115 .57562 L
.6858 .57489 L
.69005 .57406 L
.69964 .57163 L
.70947 .56838 L
.7186 .56469 L
.73931 .55407 L
.77841 .52656 L
.81996 .48883 L
.86 .44661 L
.89851 .4025 L
.93949 .35357 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo03gooooo0_l0000<ool00?Wooooo000Qooooo`03o`000?oooooo
oooo03Oooooo1_l0000>ooooo`Coo`00mOooool0027ooooo00?o0000ooooooooool0<oooool2ool0
00;o00005oooool4o`000?;ooooo000Qooooo`03o`000?oooooooooo033ooooo0ooo00000ol0003o
ooooooooo`0Looooo`;o0000l?ooool0027ooooo00?o0000ooooooooool0;_ooool2ool00003o`00
0?oooooooooo027ooooo0_l0003^ooooo`008Oooool3o`0002cooooo0_oo000Xooooo`?o0000jooo
ool0027ooooo00?o0000ooooooooool0:_ooool2ool002cooooo0_oo00000ol0003oooooooooo`3W
ooooo`008Oooool00ol0003oooooooooo`0Xooooo`03o`000?oo003ooooo02oooooo00?oo`00o`00
0?ooool0ioooool0027ooooo00?o0000ooooooooool09_ooool00ol0003oo`00ool0000booooo`;o
o`00ioooool0027ooooo00?o0000ooooooooool09?ooool2o`000003ool00?oooooooooo03Cooooo
00?oo`00ooooooooool0i?ooool0027ooooo00?o0000ooooooooool08_ooool2o`0003[ooooo0_oo
003Tooooo`008Oooool00ol0003oooooooooo`0Pooooo`;o0000?Oooool00ol0003oo`00ooooo`3R
ooooo`008Oooool00ol0003oooooooooo`0Nooooo`;o0000@?ooool00ol0003oo`00ooooo`3Qoooo
o`008Oooool3o`0001_ooooo0_oo00000ol0003oooooooooo`12ooooo`03ool00?oooooooooo0=oo
oooo000Qooooo`03o`000?oooooooooo01Wooooo0_oo00000ol0003oooooooooo`0Oooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?oooo
o`03ool00?l0003ooooo02_ooooo1?l000000ol@413oooooooooo`0kooooo`Co000000?o410@oooo
ooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0mooooo`Go00006oooool0
027ooooo00?o0000ooooooooool06?ooool00ooo003o0000ooooo`0Rooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03oooool00ooo003o0000ooooo`0/
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool0??ooool01OnHV9So8B4Qonk^k_ooooooA4A401_ooooo000Qooooo`03o`000?oooooo
oooo01Kooooo0_oo000Uooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0?ooooo`03ool00?l0003ooooo02_ooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo03cooooo00?oV9RHob4Q8Oo^k^h07?ooool0027ooooo00?o0000
ooooooooool04oooool00ol0003oo`00ool0000Wooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`0Booooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06ooo
ool0027ooooo00?o0000ooooooooool04Oooool3ool002Wooooo00Go0000ooooooooooooooooo`00
000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05?ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool03oooool2ool002cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0@oooool00ol0003oooooooooo`0Iooooo`008Oooool3o`0000cooooo0_l000000ooo003ooooo
ooooo`0/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo03oooooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003o
ooooooooo`0:ooooo`;o0000<Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000Hoooo
o`03o`000?oooooooooo02?ooooo00?oEEEEofIVI_l00000?oooool00omEEEGoIVIVo`00000=oooo
o`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qooooo`03o`000?oooooooooo
00Sooooo0_l0001Qooooo`03o`000?oooooooooo0=Kooooo000Qooooo`03o`000?oooooooooo00Go
oooo0ol0001Tooooo`03o`000?oooooooooo0=Gooooo000Qooooo`03o`000?oooooooooo00?ooooo
0_l0001Wooooo`03ool00?l0003ooooo0=Gooooo000Qooooo`05o`000?ooooooooooooooool00000
0ooo001Xooooo`03ool00?oooooooooo0<[ooooo0_l00002ooooo`;o00001?ooool0027ooooo0_l0
0003ool006_ooooo00?oo`00o`000?ooool0b_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Co
oooo000Jooooo`Oo00000_oo001_o`000003ool00?l0003o00000;Ko000000?oo`00o`000?l00000
1Ol0000<ooooo`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01oooool00ooo003o0000ooooo`02ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo003ooooo01;ooooo
00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`08ooooo`05ool00?l0003oooooooooool000003_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00[ooooo00?o0000ool00?l000004oooool01?lQ8B7oMgMgogMgMolb<S85oooo
o`008Oooool00ol0003oooooooooo`1aooooo`03ool00?oooooooooo0;7ooooo00?oo`00oooooooo
ool04_ooool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`1booooo`03ool0
0?oooooooooo0:oooooo00?oo`00ooooooooool07Oooool0027ooooo00?o0000ooooooooool0L_oo
ool00ooo003o0000ooooo`2^ooooo`03ool00?oooooooooo01kooooo000Qooooo`03o`000?oooooo
oooo07?ooooo00?oo`00o`000?ooool0[?ooool00ol0003oo`00ooooo`0Oooooo`008Oooool00ol0
003oooooooooo`1dooooo`03ool00?l0003ooooo0:_ooooo00?oo`00ooooooooool07oooool0027o
oooo0ol0001eooooo`03ool00?oooooooooo0:Wooooo00?oo`00ooooooooool08?ooool0027ooooo
00?o0000ooooooooool0M_ooool00ooo003oooooooooo`2Wooooo`03ool00?oooooooooo027ooooo
000Qooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0YOooool00ooo003ooooooooo
o`0Rooooo`008Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooooooool08_ooool0027ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`2Roooo
o`03o`000?oooooooooo02?ooooo000Qooooo`03o`000?oooooooooo07Wooooo00?o0000oooooooo
ool0XOooool00ol0003oooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`1jooooo`03o`00
0?oooooooooo09oooooo00?o0000ooooooooool09Oooool0027ooooo0ol0001kooooo`03o`000?oo
oooooooo09kooooo00?o0000ooooooooool09Oooool0027ooooo00?o0000ooooooooool0Noooool0
0ol0003oooooooooo`2Mooooo`03o`000?oooooooooo02Kooooo000Qooooo`03o`000?oooooooooo
07cooooo00?oo`00ooooooooool0Voooool00ol0003oooooooooo`0Wooooo`008Oooool00ol0003o
ooooooooo`1looooo`03ool00?l0003ooooo09[ooooo00?o0000ooooooooool0:?ooool0027ooooo
00?o0000ooooooooool0OOooool00ooo003oooooooooo`2Hooooo`03ool00?l0003ooooo02Wooooo
000Qooooo`03o`000?oooooooooo07kooooo00?oo`00ooooooooool0Uoooool00ooo003ooooooooo
o`0Yooooo`008Oooool00ol0003oooooooooo`1nooooo`03ool00?l0003ooooo09Kooooo00?oo`00
ooooooooool0:_ooool0027ooooo00?o0000ooooooooool0Ooooool00ooo003oooooooooo`2Doooo
o`03ool00?oooooooooo02_ooooo000Qooooo`?o0000P?ooool00ooo003oooooooooo`2Booooo`03
ool00?oooooooooo02cooooo000Qooooo`03o`000?oooooooooo087ooooo00?oo`00ooooooooool0
T?ooool00ooo003oooooooooo`0]ooooo`008Oooool00ol0003oooooooooo`21ooooo`03ool00?oo
oooooooo08oooooo00?oo`00ooooooooool0;_ooool0027ooooo00?o0000ooooooooool0P_ooool0
0ooo003oooooooooo`2=ooooo`03o`000?oo003ooooo02oooooo000Qooooo`03o`000?oooooooooo
08?ooooo00?oo`00ooooooooool0S?ooool00ooo003oooooooooo`0_ooooo`008Oooool00ol0003o
ooooooooo`23ooooo`03ool00?oooooooooo08_ooooo00?oo`00ooooooooool0<?ooool0027ooooo
00?o0000ooooooooool0Q?ooool00ooo003oooooooooo`29ooooo`03ool00?oooooooooo037ooooo
000Qooooo`?o0000QOooool00ooo003oooooooooo`27ooooo`03ool00?oooooooooo03;ooooo000Q
ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0Q_ooool00ooo003oooooooooo`0c
ooooo`008Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo08Cooooo00?o0000oooo
ooooool0=?ooool0027ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`22ooooo`03
o`000?oooooooooo03Gooooo000Qooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0
POooool00ol0003oooooooooo`0eooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`28ooooo`03
o`000?oooooooooo083ooooo00?o0000ooooooooool0=_ooool000Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo08Wo
oooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0gooooo`001oooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`0008[ooooo00?o0000oooooooo
ool0O?ooool00ol0003oooooooooo`0hooooo`001oooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo07[o
oooo00?o0000ooooooooool0>Oooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`2<ooooo`03ool00?oooooooooo
07Oooooo00?oo`00o`000?ooool0>oooool000Oooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0S?ooool00ooo003oooooooooo`1foooo
o`03ool00?l0003ooooo03cooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo08gooooo00?oo`00ooooooooool0M?ooool00ooo
003o0000ooooo`0mooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005oooo
o`03o`000?oooooooooo08kooooo00?oo`00ooooooooool0L_ooool00ooo003o0000ooooo`0noooo
o`008Oooool00ol0003oooooooooo`2?ooooo`03ool00?oooooooooo073ooooo00?oo`00o`000?oo
ool0?oooool0027ooooo00?o0000ooooooooool0Soooool00ol0003oo`00ooooo`1`ooooo`03ool0
0?oooooooooo03oooooo000Qooooo`?o0000T?ooool00ooo003oooooooooo`1^ooooo`03ool00?oo
oooooooo043ooooo000Qooooo`03o`000?oooooooooo097ooooo00?oo`00ooooooooool0K?ooool0
0ooo003oooooooooo`11ooooo`008Oooool00ol0003oooooooooo`2Booooo`03ool00?oooooooooo
06[ooooo00?oo`00o`000?ooool0@_ooool0027ooooo00?o0000ooooooooool0T_ooool00ol0003o
o`00ooooo`1Yooooo`03ool00?l0003ooooo04?ooooo000Qooooo`03o`000?oooooooooo09?ooooo
00?oo`00ooooooooool0Ioooool00ooo003o0000ooooo`14ooooo`008Oooool00ol0003ooooooooo
o`2Dooooo`03ool00?oooooooooo06Gooooo00?oo`00o`000?ooool0AOooool0027ooooo00?o0000
ooooooooool0UOooool00ooo003oooooooooo`1Tooooo`03o`000?oooooooooo04Gooooo000Qoooo
o`?o0000U_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo04Kooooo000Qooooo`03
o`000?oooooooooo09Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`17ooooo`00
8Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0
B?ooool0027ooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`1Looooo`03o`000?oo
oooooooo04Wooooo000Qooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool0Foooool0
0ol0003oooooooooo`1:ooooo`008Oooool00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo
05Wooooo00?o0000ooooooooool0Boooool0027ooooo00?o0000ooooooooool0Voooool00ol0003o
ooooooooo`1Eooooo`;oo`0000?o0000ooooooooool0C?ooool0027ooooo00?o0000ooooooooool0
W?ooool00ol0003oo`00ooooo`1Cooooo`03ool00?l0003o000004oooooo000Qooooo`?o0000WOoo
ool00ooo003oooooooooo`1Aooooo`03ool00?l0003ooooo053ooooo000Qooooo`03o`000?oooooo
oooo09kooooo00?oo`00ooooooooool0Coooool00ooo003o0000ooooo`1Aooooo`008Oooool00ol0
003oooooooooo`2Oooooo`03ool00?oooooooooo04gooooo00?oo`00o`000?ooool0D_ooool0027o
oooo00?o0000ooooooooool0Woooool00ol0003oo`00ool0001<ooooo`03ool00?l0003ooooo05?o
oooo000Qooooo`03o`000?oooooooooo0:3ooooo00?o0000oooooooo0000B_ooool00ooo003o0000
ooooo`1Dooooo`008Oooool00ol0003oooooooooo`2Qooooo`03o`000?ooooooo`0004Sooooo00?o
o`00ooooooooool0EOooool0027ooooo00?o0000ooooooooool0X_ooool00ol0003oooooool00016
ooooo`03ool00?oooooooooo05Kooooo000Qooooo`?o0000Xoooool00ol0003oooooool00014oooo
o`03ool00?oooooooooo05Oooooo000Qooooo`03o`000?oooooooooo0:Cooooo00?o0000oooooooo
0000@_ooool00ooo003oooooooooo`1Hooooo`008Oooool00ol0003oooooooooo`2Uooooo`;o0000
00?oo`00ooooooooool0?_ooool00ol0003oo`00ooooo`1Iooooo`008Oooool00ol0003ooooooooo
o`2Wooooo`03o`000?oo003ooooo03cooooo0_l0001Looooo`008Oooool00ol0003oooooooooo`2X
ooooo`;o0000>_ooool2o`0005kooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0
003oooooooooo`2Zooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0G_ooool001[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2[ooooo`;o0000=?ooool2o`00067o
oooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[Oooool00ol0003ooooo
ooooo`0_ooooo`;o0000Hoooool001[ooooo00?o0000ooooooooool01?ooool3o`000:kooooo0_l0
000^ooooo`03o`000?oo003oo`0006?ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0/?ooool00ol0003oooooooooo`0Yooooo`;o000000?oo`00ooooooooool0Hoooool0
01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2`ooooo`;oo`0000?o0000oooo
ooooool09Oooool2o`0000;oo`00I_ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`2booooo`;oo`009?ooool01?l0003oo`00ool00?oo001Xooooo`006?ooool00omEEEGo
IVIVo`000006ooooo`03o`000?oooooooooo0;Cooooo00?oo`00o`000?l000008?ooool2ool006_o
oooo000Qooooo`03o`000?oooooooooo0;Gooooo0ooo0002o`0001[ooooo00?o0000ool00?oo0000
KOooool0027ooooo00?o0000ooooooooool0^?ooool4ool00003o`000?oooooooooo01;ooooo0_l0
0002ool006oooooo000Qooooo`?o0000_?ooool2ool00003o`000?oooooooooo00gooooo0ol00000
0oooooooo`00ooooo`1`ooooo`008Oooool00ol0003oooooooooo`2nooooo`03ool00?l0003oo`00
00go0000M_ooool0027ooooo00?o0000ooooooooool0`Oooool7ool007cooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z?ooool00omgMgOoIVIVooooo`0Goooo
o`03ofIVI_mgMgOooooo0:?ooooo0027ooooo`?o00004oooool00olQ8B7ogMgMooooo`07ooooo`03
omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Xoooool007kooooo00OoQhN7o`000?mEEEGo
IVIVo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool02oooool01OnHV9So0000o`000?m4A4Co
^[Zj00;ooooo00?oV9RHoeEEEOooool01oooool01?mEEEGoV9RHooooooooool5o`0000Wooooo00?o
EEEEojVYZOooool00_ooool00onj^[[oA4A4ooooo`02ooooo`03ohN7QomVIVKooooo01;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<07_o
oooo001nooooo`07oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP03ooooo`03o`000?oooooooooo
00_ooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oMgMgooooo00Kooooo00Wo0000
oooooooooooooooooiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooooooooooo410@
okZj^P?ooooo00?ok^k^o`000?ooool02oooool6o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@1kooooo`00O_ooool01ol0003ooooo
omgMgOlb<S;oooooonk^k_l@41000oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Gooooo0_mgMgL7ooooo`03oc8b<_oooooooooo00;ooooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@
413ogMgMooooool00005ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@
400;ooooo`05o`000?ooooooooooooooool00000Noooool007kooooo00CoEEEEojVYZOoooooo0000
0_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool01Oooool00oo^k^ko
410@onk^kP06ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7QhOo
IVIVooooool00005ooooo`03o`000?oooooooooo00[ooooo1_l000000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P1kooooo`00O_ooool00ooM
gMgo8B4Qonk^kP03ooooo`03o`000?oooooooooo00;o00003Oooool00ol0003oooooooooo`06oooo
o`03oeEEEOnHV9Sooooo00Gooooo00?o0000onk^k_ooool01?ooool00omgMgOoIVIVooooo`0:oooo
o`04omgMgOl@413oooooo`0000Cooooo00?ok^k^o`000?ooool04_ooool01Ol0003ooooooooooooo
oooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c01kooooo`00Ooooool00onHV9SoMgMgoooo
o`02ooooo`03o`000?oooooooooo00gooooo00?o410@o`000?l000000ol00005ooooo`03omgMgOl@
413ooooo00Gooooo00?oEEEEogMgMoooool01Oooool00ol0003oooooooooo`08ooooo`Oo00000_oo
ool00omgMgOoEEEEooooo`0Booooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zj
oooooonj^[[o410@07_ooooo002Fooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool0
1?ooool02OoMgMgo410@onk^k_oooooo0000okZj^_ooooooV9RHoa0@400Booooo`03onk^k_l@413o
gMgM01?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000
Noooool009Kooooo00?o0000ooooooooool01oooool00onj^[[oA4A4ooooo`05ooooo`08ogMgMomV
IVKooooooiRHV?l@413o0000ob4Q8Oo<c<`Booooo`03ofIVI_mgMgOooooo01?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0Noooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.85) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .32801 L
.08255 .33618 L
.0932 .33977 L
.10458 .34298 L
.11531 .34536 L
.12507 .34699 L
.12977 .34758 L
.13488 .34809 L
.13722 .34828 L
.1397 .34845 L
.14183 .34856 L
.14415 .34867 L
.14546 .34871 L
.14667 .34874 L
.14783 .34877 L
.14907 .34879 L
.15028 .3488 L
.15142 .3488 L
.15245 .3488 L
.15356 .34879 L
.15479 .34877 L
.15548 .34876 L
.15613 .34875 L
.15884 .34867 L
.16118 .34857 L
.16369 .34844 L
.1686 .3481 L
.17326 .34767 L
.18199 .34664 L
.19164 .34516 L
.2019 .34324 L
.22032 .3391 L
.25807 .32923 L
.27904 .32397 L
.29827 .31992 L
.30803 .31829 L
.31712 .31709 L
.32208 .31657 L
.32659 .31619 L
.3316 .31588 L
.33436 .31576 L
.33561 .31571 L
.33696 .31567 L
.33821 .31564 L
.33935 .31563 L
.3405 .31561 L
.34159 .31561 L
.34285 .31561 L
.34402 .31561 L
Mistroke
.34531 .31563 L
.34603 .31564 L
.34668 .31566 L
.34923 .31573 L
.35066 .31579 L
.35198 .31585 L
.35697 .31617 L
.36125 .31655 L
.36595 .31708 L
.37542 .31854 L
.38566 .32068 L
.39497 .32317 L
.4159 .3306 L
.43502 .3396 L
.4558 .35161 L
.49663 .38084 L
.53595 .41317 L
.57375 .44423 L
.61401 .4729 L
.63252 .48348 L
.65275 .49269 L
.66246 .49615 L
.67283 .49914 L
.67857 .50046 L
.68377 .50146 L
.68871 .50223 L
.69142 .50258 L
.69394 .50286 L
.69643 .50308 L
.69871 .50325 L
.70124 .50339 L
.70263 .50345 L
.70395 .50349 L
.70506 .50352 L
.70624 .50354 L
.70725 .50354 L
.70836 .50354 L
.70955 .50353 L
.71084 .50351 L
.71205 .50348 L
.71316 .50344 L
.71567 .50332 L
.718 .50316 L
.7233 .50267 L
.72846 .502 L
.73397 .50107 L
.7442 .49879 L
.7553 .4955 L
.77544 .48746 L
.79529 .47706 L
Mistroke
.81633 .46361 L
.85418 .4339 L
.89449 .39616 L
.93328 .35585 L
.97453 .31085 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .32735 L
.08255 .33538 L
.0932 .33907 L
.10458 .34248 L
.11531 .34513 L
.12507 .34704 L
.12977 .34777 L
.13488 .34843 L
.1397 .34891 L
.14415 .34925 L
.14658 .34938 L
.14881 .34948 L
.15004 .34952 L
.15138 .34955 L
.15264 .34958 L
.15382 .34959 L
.155 .3496 L
.15612 .34959 L
.15712 .34959 L
.1582 .34957 L
.15939 .34955 L
.16064 .34952 L
.16288 .34944 L
.16533 .34933 L
.16796 .34917 L
.17271 .34879 L
.17836 .3482 L
.1835 .34752 L
.20259 .34403 L
.22335 .33886 L
.26413 .32697 L
.28438 .32155 L
.2943 .31928 L
.3034 .3175 L
.31207 .31611 L
.31666 .31552 L
.32156 .31499 L
.32415 .31476 L
.32651 .31458 L
.3289 .31443 L
.3311 .31431 L
.33358 .31421 L
.33489 .31418 L
.33555 .31416 L
.33627 .31415 L
.33747 .31413 L
.33859 .31412 L
.33928 .31412 L
.33993 .31412 L
Mistroke
.34115 .31413 L
.3424 .31414 L
.3431 .31416 L
.34375 .31417 L
.34491 .3142 L
.34619 .31425 L
.34841 .31435 L
.35076 .31449 L
.35605 .31492 L
.36099 .31548 L
.36988 .31686 L
.37939 .31887 L
.38959 .32166 L
.40067 .32541 L
.42081 .33406 L
.46164 .35801 L
.50096 .38679 L
.53876 .41657 L
.57902 .44698 L
.61776 .47188 L
.63744 .48207 L
.65895 .49091 L
.6689 .49412 L
.67951 .4969 L
.68467 .498 L
.68953 .49889 L
.69423 .4996 L
.69862 .50015 L
.70327 .50059 L
.70573 .50077 L
.70837 .50092 L
.7097 .50097 L
.71114 .50102 L
.7118 .50104 L
.7125 .50106 L
.71376 .50108 L
.71497 .50109 L
.7161 .50109 L
.71734 .50108 L
.71804 .50107 L
.71868 .50106 L
.71975 .50103 L
.7209 .501 L
.72297 .50091 L
.72543 .50077 L
.72767 .50061 L
.73254 .50015 L
.73714 .49957 L
.74685 .49788 L
.75713 .49541 L
Mistroke
.77558 .48923 L
.79513 .48025 L
.81343 .46966 L
.85222 .44069 L
.89347 .40168 L
.9332 .3586 L
.97141 .31462 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`3ooooooc_ooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooooooo`0003[o00003?ooool01?oMgMgo0000oa0@
4?o<c<`5ooooo`008Oooool01?l0003oooooo`000?l0000;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
0_l0000Cooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`04o`000?ooooooooooooooo`;o
o`002Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ool00?oo
00001?oo0002o`0000Koo`003_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool2o`0001?ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027o
oooo00?o0000ooooooooool00oooool2ool004oooooo1?oo0007o`0000Kooooo2Ol0002gooooo`03
o`000?oooooooooo01;ooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool0
1Oooool2ool004Oooooo1_oo00000ol0003oooooooooo`0Gooooo`;o00000ooo002aooooo`03o`00
0?oooooooooo01gooooo000Qooooo`03o`000?oooooooooo00Oooooo0_oo0013ooooo`04o`000?oo
003o0000o`00027ooooo0_l00002ool00:kooooo00?oo`00ooooooooool07_ooool0027ooooo00?o
0000ooooooooool02Oooool3ool003gooooo0ol0000Xooooo`03o`000?oo003oo`000:_ooooo00?o
0000ool00?ooool07oooool0027ooooo00?o0000ooooooooool02oooool01?l0003oo`00ool00?oo
000fooooo`Co0000;_ooool2ool00003o`000?oooooooooo0:Gooooo00?o0000ool00?ooool08?oo
ool0027ooooo0ol0000>ooooo`03o`000?oo003ooooo033ooooo0ooo00000ol0003oooooooooo`0b
ooooo`;oo`0000?o0000ooooooooool0X_ooool00ol0003oo`00ooooo`0Qooooo`008Oooool00ol0
003oooooooooo`0@ooooo`?o0000:_ooool01?l0003oo`00ool00?oo000jooooo`;oo`0000?o0000
ooooooooool0Woooool00ol0003oo`00ooooo`0Rooooo`008Oooool00ol0003oooooooooo`0Coooo
o`?o00008_ooool00ol0003oo`00ool00003ool003oooooo00?oo`00o`000?l00000W_ooool00ol0
003oo`00ooooo`0Sooooo`008Oooool00ol0003oooooooooo`0Fooooo`Co00006_ooool00ol0003o
o`00ool00002ool004Gooooo00?oo`00ooooool00000W?ooool00ol0003oo`00ooooo`0Tooooo`00
8Oooool00ol0003oooooooooo`0Jooooo`Koo`003?ooool8o`000003ool00?oooooooooo04[ooooo
0_l0002Iooooo`03o`000?oo003ooooo02Gooooo000Qooooo`03o`000?oooooooooo023ooooo2_oo
0002o`0005Oooooo00?o0000ooooooooool0UOooool00ol0003oo`00ooooo`0Vooooo`008Oooool0
0ol0003oooooooooo`24ooooo`;o0000U?ooool00ol0003oo`00ooooo`0Wooooo`008Oooool3o`00
08Kooooo00?o0000ooooooooool0T?ooool00ol0003oo`00ooooo`0Xooooo`008Oooool00ol0003o
ooooooooo`27ooooo`;o0000T?ooool00ooo003oooooooooo`0Xooooo`008Oooool00ol0003ooooo
ooooo`28ooooo`;oo`00S_ooool00ol0003oo`00ooooo`0Yooooo`008Oooool00ol0003ooooooooo
o`2:ooooo`03ool00?l0003ooooo08[ooooo00?o0000ooooooooool0:_ooool0027ooooo00?o0000
ooooooooool0Roooool00ooo003o0000ooooo`28ooooo`03o`000?oooooooooo02_ooooo000Qoooo
o`03o`000?oooooooooo08cooooo00?oo`00o`000?ooool0Q_ooool00ol0003oooooooooo`0/oooo
o`008Oooool00ol0003oooooooooo`2=ooooo`;oo`0000?o0000ooooooooool0P_ooool00ol0003o
ooooooooo`0]ooooo`008Oooool00ol0003oooooooooo`2?ooooo`03ool00?l0003ooooo087ooooo
00?o0000ooooooooool0;_ooool0027ooooo0ol0002@ooooo`03ool00?l0003o000007oooooo00?o
0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool0TOooool00ooo003oooooo`00001m
ooooo`03o`000?oooooooooo033ooooo000Qooooo`03o`000?oooooooooo09;ooooo0_oo00000ol0
003oooooooooo`1iooooo`03o`000?oo003ooooo037ooooo000Qooooo`03o`000?oooooooooo09Co
oooo00?oo`00o`000?ooool0N?ooool00ol0003oo`00ooooo`0booooo`008Oooool00ol0003ooooo
ooooo`2Fooooo`03o`000?oooooooooo07Gooooo00?o0000ool00?ooool0<oooool0027ooooo00?o
0000ooooooooool0Uoooool2o`0007?ooooo0_l000000ooo003oooooooooo`0cooooo`008Oooool0
0ol0003oooooooooo`2Iooooo`03o`000?oooooooooo06oooooo00?o0000oooooooo0000=_ooool0
027ooooo0ol0002Jooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo0000=oooool0027o
oooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`1[ooooo`03o`000?ooooooo`0003So
oooo000Qooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool0JOooool00ol0003ooooo
ool0000iooooo`008Oooool00ol0003oooooooooo`2Mooooo`03ool00?l0003ooooo06Oooooo00?o
0000oooooooo0000>_ooool0027ooooo00?o0000ooooooooool0W_ooool2ool006Kooooo00?o0000
oooooooo0000>oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0X?ooool00ooo003ooooooooo
o`1Rooooo`03o`000?ooooooo`0003cooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2Qooooo`03ool00?oo
oooooooo063ooooo00?o0000oooooooo0000?Oooool000Oooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00;ooooo0ol0002Rooooo`;oo`00Goooool00ol0003ooooooooo
o`0nooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`2Sooooo`03o`000?oo003ooooo05cooooo00?o0000ooooooooool0?ooo
ool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1?ooool00ol0003oooooooooo`2Uooooo`;oo`00FOooool2o`0004;ooooo0007ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0:Kooooo
00?o0000ool00?ooool0E_ooool00ol0003oooooooooo`12ooooo`001oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Wooooo`03o`00
0?oo003ooooo05Cooooo00?o0000ooooooooool0@oooool000Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`2Xooooo`03o`000?oo003ooooo05;ooooo
00?o0000ooooooooool0A?ooool0027ooooo00?o0000ooooooooool0ZOooool2o`00057ooooo00?o
0000ool00?oo0000AOooool0027ooooo00?o0000ooooooooool0Zoooool00ol0003oooooooooo`1<
ooooo`;o000000?oo`00ooooooooool0AOooool0027ooooo0ol0002/ooooo`;o0000Boooool00ol0
003oooooool00018ooooo`008Oooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo04Oo
oooo00?o0000oooooooo0000BOooool0027ooooo00?o0000ooooooooool0[oooool2o`0004Kooooo
00?o0000ool00?oo0000B_ooool0027ooooo00?o0000ooooooooool0/Oooool00ol0003oo`00ool0
0012ooooo`03o`000?oo003ooooo04_ooooo000Qooooo`03o`000?oooooooooo0;;ooooo00Co0000
oooooooo003oo`00?_ooool2o`000003ool00?oooooooooo04_ooooo000Qooooo`03o`000?oooooo
oooo0;?ooooo0_l000000oooooooo`00ooooo`0jooooo`;o000000?oooooool00?ooool0COooool0
027ooooo00?o0000ooooooooool0]Oooool01?l0003oooooool00?oo000hooooo`04o`000?oooooo
o`00ool004oooooo000Qooooo`?o0000]_ooool2o`000003oooooooo003oo`0003Cooooo0_l00002
ool0057ooooo000Qooooo`03o`000?oooooooooo0;Sooooo0_l000000oooooooo`00ool0000`oooo
o`;o0000EOooool0027ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`02ool002co
oooo0_l0001Gooooo`008Oooool00ol0003oooooooooo`2kooooo`;o00000_ooool00ooo003ooooo
ooooo`0Wooooo`;o0000FOooool0027ooooo00?o0000ooooooooool0_Oooool3o`000003ool00?oo
oooooooo02Cooooo0_l0001Kooooo`008Oooool00ol0003oooooooooo`30ooooo`;o00008oooool0
0ol0003oo`00ool0001Looooo`008Oooool00ol0003oooooooooo`32ooooo`?o00007_ooool3ool0
05kooooo000Qooooo`03o`000?oooooooooo0<Gooooo0ol00002ooooo`?oo`004oooool2o`000003
ool00?oooooooooo05oooooo000Qooooo`?o0000b?ooool5o`0000koo`001Ol0001Tooooo`008Ooo
ool00ol0003oooooooooo`3=ooooo`go0000J_ooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o410@
ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3o`000?oooooo
AOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l0
00001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool00omg
MgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:Oooooo0023ooooo`?o00005?ooool00olQ8B7o
gMgMooooo`06ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Yoooool007_ooooo
00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool02oooool01OnH
V9So0000o`000?m4A4Co^[Zj00?ooooo00?oV9RHoeEEEOooool01_ooool00omEEEGoV9RHooooo`02
ooooo`Go00002Oooool00omEEEGoZJVYooooo`02ooooo`06okZj^_m4A4Cooooooooooon7QhOoIVIV
5?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`01?ooool01Om4A4Co0000o`000?lb<S;ogMgM07Gooooo001kooooo`07oa0@4?oMgMgoMgMg
ob4Q8OooooooQhN7ofIVIP02ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_o^k^koMgMg
oa0@4004ooooo`03o`000?oMgMgooooo00Gooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Q
onk^k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X2ooooo`03onk^k_l0003o
oooo00_ooooo1_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
8B4QoiRHV?ooooooV9RHob4Q8@07ooooo`03ogMgMolb<S;ooooo07Cooooo001kooooo`07o`000?oo
oooogMgMoc8b<_ooooook^k^oa0@4002ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01_ooool2ogMgM`Kooooo00?o<S8booooooooool00oooool00onHV9So8B4Qonk^kP0<ooooo`04
oa0@4?oMgMgoooooo`0000Cooooo00?o0000ooooooooool04_ooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo07?ooooo001k
ooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Co0000oooooooooooo00003Oooool00ol0003ooooo
ooooo`06ooooo`03onk^k_l@413ok^k^00Gooooo00?o<S8booooooooool01?ooool00onHV9So8B4Q
onk^kP0;ooooo`04ohN7QomVIVKoooooo`0000Cooooo00?o0000ooooooooool02_ooool6o`0000;o
oooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801oooool0
0omgMgOo<S8booooo`1dooooo`00Noooool00ooMgMgo8B4Qonk^kP03ooooo`04o`000?oooooo0000
o`0000gooooo00?o0000ooooooooool01oooool00omEEEGoV9RHooooo`04ooooo`03o`000?o^k^ko
oooo00Gooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgo410@ooooool00003ooooo`03onk^k_l0
003ooooo01?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<
c<`01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<07Gooooo001looooo`03oiRHV?mgMgOooooo00;o
oooo00?o0000ooooooooool03?ooool00ol@413o0000o`000003o`0000Kooooo00?ogMgMoa0@4?oo
ool01?ooool00omEEEGoMgMgooooo`06ooooo`03o`000?oooooooooo00Sooooo1ol000000ooooooo
MgMgoeEEE@0Dooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o
410@00Cooooo00?o0000ooooooooool0Moooool009;ooooo00?o0000ooooooooool02?ooool00omE
EEGoV9RHooooo`03ooooo`03omgMgOl@413ok^k^00;ooooo00Go0000okZj^_ooooooV9RHoa0@400A
ooooo`03onk^k_l@413ogMgM01Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooookZj^_l000001?ooool00ol0003oooooooooo`1gooooo`00T_ooool00ol0003ooooooooo
o`08ooooo`03okZj^_m4A4Cooooo00Cooooo00WoMgMgofIVI_oooooooooooiRHV?l@413o0000ob4Q
8Oo<c<`04Oooool00omVIVKoMgMgooooo`0Dooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnYZJWo410@o`000?l@413oZJVY00Cooooo1?l0001fooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .35328 L
.10458 .39488 L
.12507 .41122 L
.14415 .42375 L
.16254 .43323 L
.17277 .43737 L
.18221 .44049 L
.19242 .4431 L
.19781 .44416 L
.20351 .44505 L
.20846 .44564 L
.21084 .44586 L
.2131 .44603 L
.21437 .44611 L
.21575 .44618 L
.21703 .44624 L
.21818 .44628 L
.21956 .44631 L
.22031 .44633 L
.22102 .44634 L
.22228 .44635 L
.223 .44635 L
.22365 .44635 L
.22492 .44634 L
.22611 .44631 L
.22718 .44629 L
.22835 .44625 L
.23097 .44613 L
.23339 .44598 L
.2378 .4456 L
.24248 .44507 L
.2523 .44352 L
.26314 .44115 L
.28249 .43534 L
.30334 .42709 L
.34448 .40639 L
.38411 .38365 L
.42222 .36208 L
.46278 .34202 L
.50182 .32735 L
.51207 .32441 L
.52317 .32169 L
.53276 .31971 L
.54332 .31796 L
.54827 .31729 L
.55359 .31668 L
.55819 .31623 L
.5632 .31584 L
.56612 .31565 L
Mistroke
.56884 .31551 L
.57165 .31538 L
.57419 .3153 L
.5754 .31527 L
.5767 .31524 L
.57782 .31521 L
.57906 .3152 L
.58037 .31518 L
.58109 .31518 L
.58176 .31518 L
.58296 .31518 L
.58424 .31518 L
.58546 .31519 L
.58616 .3152 L
.58681 .3152 L
.58813 .31522 L
.58954 .31525 L
.5921 .31532 L
.59444 .3154 L
.59984 .31565 L
.60552 .31601 L
.61514 .31681 L
.62565 .31795 L
.66627 .32416 L
.70536 .33108 L
.72531 .33426 L
.73581 .33572 L
.74691 .33707 L
.75684 .33807 L
.76776 .33894 L
.77254 .33924 L
.77768 .3395 L
.78252 .33969 L
.78695 .33982 L
.78923 .33986 L
.79054 .33988 L
.79174 .3399 L
.79301 .33991 L
.79367 .33992 L
.79437 .33992 L
.79555 .33993 L
.79684 .33993 L
.79805 .33993 L
.79914 .33992 L
.8004 .33991 L
.80159 .3399 L
.80371 .33987 L
.80601 .33982 L
.8085 .33976 L
.81125 .33967 L
Mistroke
.8168 .33944 L
.82194 .33916 L
.82676 .33884 L
.83715 .33796 L
.84702 .3369 L
.86555 .33436 L
.90377 .32713 L
.94443 .31736 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .35303 L
.10458 .39523 L
.12507 .41151 L
.14415 .42385 L
.16254 .43312 L
.17277 .43716 L
.18221 .44021 L
.19242 .44277 L
.19781 .44382 L
.20351 .4447 L
.20846 .44528 L
.2131 .44568 L
.21575 .44584 L
.21818 .44594 L
.21952 .44598 L
.22028 .446 L
.22099 .44601 L
.22228 .44603 L
.223 .44603 L
.22365 .44603 L
.22486 .44603 L
.22598 .44601 L
.22721 .44599 L
.22853 .44595 L
.22991 .4459 L
.23122 .44583 L
.23368 .44569 L
.2381 .44534 L
.2429 .44482 L
.24814 .44409 L
.25371 .44314 L
.26372 .44098 L
.28319 .43525 L
.30147 .42823 L
.34016 .40931 L
.3813 .38564 L
.42092 .3626 L
.45903 .34299 L
.48028 .33395 L
.49959 .32719 L
.50923 .32438 L
.51968 .32177 L
.52947 .31974 L
.53864 .3182 L
.5481 .31697 L
.55312 .31646 L
.55851 .31603 L
.56121 .31586 L
.56415 .3157 L
Mistroke
.56675 .31558 L
.56951 .31549 L
.57092 .31545 L
.57224 .31542 L
.57344 .3154 L
.57472 .31539 L
.57595 .31538 L
.57724 .31537 L
.57835 .31537 L
.57956 .31538 L
.58087 .31539 L
.58208 .31541 L
.5834 .31543 L
.58481 .31546 L
.58718 .31553 L
.58979 .31562 L
.5946 .31584 L
.5991 .31612 L
.60918 .31693 L
.62003 .31808 L
.66122 .32428 L
.7009 .3311 L
.72091 .33415 L
.73906 .33643 L
.7485 .33739 L
.75871 .33822 L
.76433 .33859 L
.7695 .33887 L
.77445 .33908 L
.77713 .33917 L
.77967 .33924 L
.78204 .3393 L
.78329 .33932 L
.78462 .33934 L
.78574 .33936 L
.78697 .33937 L
.78808 .33938 L
.78914 .33938 L
.79038 .33939 L
.79168 .33939 L
.7928 .33938 L
.79402 .33938 L
.79534 .33937 L
.79675 .33935 L
.79929 .33931 L
.80165 .33926 L
.80422 .33919 L
.80889 .33902 L
.81761 .33858 L
.82706 .33792 L
Mistroke
.83747 .33698 L
.8585 .33442 L
.87792 .33136 L
.89881 .32741 L
.94005 .31805 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`3ooooooc_ooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0003o00000?oo00009ol0
0002ool000Oo00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool00ol0003oo`00oooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Oooooo00Ko0000ool00?oo003oo`00ooooool0000Cooooo`04
onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`;o000000?oo`00ooooooooool02_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`04o`000?ooooooooooooooo`Ooo`001ol0000<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Cooooo0ol000000ooo003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00Co8B4QogMg
MomgMgOo<S8b1Oooool0027ooooo00Co0000ooooool0003oo`00W?ooool8ool000kooooo0ol00006
ool00003o`000?oooooooooo05cooooo1?l0000Kooooo`;o00000_ooool2o`0000Cooooo000Qoooo
o`05o`000?ooooooooooo`000?oo0000U_ooool5ool00003o`000?oooooooooo01cooooo1_oo0002
o`00057ooooo0ooo0003o`0002Wooooo000Qooooo`06o`000?ooooooooooooooool0003oo`00T_oo
ool2o`000003ool00?oooooooooo02Sooooo1?oo0004o`0004Oooooo1?oo00000ol0003ooooooooo
o`0/ooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oo003ooooo08gooooo0ol0000e
ooooo`Ko0000??ooool5ool00003o`000?oooooooooo033ooooo000Qooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0ROooool3o`0003kooooo1Ooo00000ol0003oooooooooo`0_oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0=Oooool0027ooooo0ol00003ooooo`03
o`000?oooooooooo08Gooooo0ooo00000ol0003oooooooooo`14ooooo`Koo`009_ooool6o`0003go
oooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0POooool3ool00003o`00
0?oooooooooo04gooooo1_oo0004o`0001;ooooo1ooo0003o`0004?ooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0O_ooool2ool000;o0000Foooool5o`0000goo`000ol0
001:ooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07_ooooo0_oo0000
0ol0003oooooooooo`2kooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
07Sooooo0_oo00000ol0003oooooooooo`2mooooo`008Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo07Kooooo00?oo`00o`000?ooool0`?ooool0027ooooo00?o0000ooooooooool0
2Oooool2o`0007Cooooo0_oo0033ooooo`008Oooool3o`0000[ooooo00?oo`00o`000?ooool0L?oo
ool00ol0003oo`00ooooo`34ooooo`008Oooool00ol0003oooooooooo`0;ooooo`03ool00?l0003o
oooo06gooooo0_l00037ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03ool00?l0003ooooo
06[ooooo0_l00039ooooo`008Oooool00ol0003oooooooooo`0=ooooo`03ool00?l0003ooooo06Oo
oooo0_l0003;ooooo`008Oooool00ol0003oooooooooo`0>ooooo`03ool00?l0003ooooo06Gooooo
00?o0000ooooooooool0boooool0027ooooo00?o0000ooooooooool03oooool00ooo003o0000oooo
o`1Rooooo`;oo`00c_ooool0027ooooo00?o0000ooooooooool04?ooool00ooo003o0000ooooo`1O
ooooo`;oo`00d?ooool0027ooooo00?o0000ooooooooool04Oooool00ooo003o0000ooooo`1Loooo
o`;oo`00d_ooool0027ooooo0ol0000Booooo`03ool00?l0003ooooo05Wooooo0_oo00000ol0003o
ooooooooo`3Aooooo`008Oooool00ol0003oooooooooo`0Cooooo`03ool00?l0003ooooo05Kooooo
0_oo00000ol0003oooooooooo`3Cooooo`008Oooool00ol0003oooooooooo`0Dooooo`03ool00?l0
003ooooo05Cooooo00?oo`00o`000?ooool0e_ooool0027ooooo00?o0000ooooooooool05Oooool0
0ooo003o0000ooooo`1Aooooo`;oo`00fOooool0027ooooo00?o0000ooooooooool05oooool2o`00
04oooooo00?oo`00o`000?ooool0fOooool0027ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`1:ooooo`03o`000?oo003ooooo0=_ooooo000Qooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`3Looooo`008Oooool3o`0001_ooooo00?o
0000ooooooooool0AOooool2o`000=oooooo000Qooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0@_ooool2o`000>7ooooo000Qooooo`03o`000?oooooooooo01gooooo0_l00010oooo
o`;o0000hoooool0027ooooo00?o0000ooooooooool07Oooool2ool00003o`000?oooooooooo03_o
oooo0_oo003Uooooo`008Oooool00ol0003oooooooooo`0Oooooo`;oo`0000?o0000ooooooooool0
=_ooool00ol0003oo`00ool0003Wooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Qooooo`;o
o`00=Oooool00ol0003oo`00ool0003Yooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool08oooool2ool0037o
oooo00?o0000ool00?oo0000joooool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03
o`000?oooooooooo00;ooooo0ol0000Uooooo`;oo`00;Oooool00ol0003oo`00ool0003]ooooo`00
1oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003o
ooooooooo`0Wooooo`;oo`00:?ooool01?l0003oo`00ool00?oo003_ooooo`001oooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooo
oooo02Wooooo0_oo00000ol0003oooooooooo`0Qooooo`03o`000?oo003oo`000?;ooooo0007oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo02_ooooo00Coo`00o`000?l0003o00007_ooool2o`000?Gooooo0007ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02oooooo0ol0
000Hooooo`?o0000moooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`0booooo`;o00004?ooool2ool000Co0000n_ooool0027ooooo00?o0000
ooooooooool0=?ooool2o`0000koo`00ooooool1ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo1?l0
00000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`?o
0000oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
AOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool00omE
EEGoIVIVo`000006ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002X
ooooo`03ogMgMomVIVKooooo01Oooooo00?oIVIVogMgMoooool0Xoooool008Oooooo0ol0000Coooo
o`03ob4Q8OoMgMgooooo00Oooooo00?ogMgMoa0@4?o^k^h06?ooool00oo^k^ko410@omgMg@2Soooo
o`00O_ooool01on7QhOo0000oeEEEOmVIVKo0000oc8b<_o^k^h00oooool00ol0003oooooooooo`0;
ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool00onHV9SoEEEEooooo`07ooooo`04oeEEEOnH
V9Soooooooooo`Go00002Oooool00omEEEGoZJVYooooo`02ooooo`03okZj^_m4A4Cooooo00;ooooo
00?oQhN7ofIVI_ooool04_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`04
oa0@4?l0003oA4A4olc<c7cooooo001nooooo`07oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP03
ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oM
gMgooooo00Kooooo00Wo0000oooooooooooooooooiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mE
EEGoV9RHoooooooooooo410@okZj^P?ooooo00?ok^k^o`000?ooool02oooool6o`000006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Kooooo00?oV9RHoa0@4?oMgMd0Noooool007kooooo
00Oo0000oooooooMgMgo<S8booooooo^k^ko410@00?ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`05ooooo`;oMgMg1oooool00olb<S;oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^
00cooooo00Co410@omgMgOoooooo00001Oooool00ol0003oooooooooo`0Aooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00on7QhOoEEEEooooo`1jooooo`00O_ooool01?mEEEGoZJVYooooool0
0002ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`05ooooo`03onk^
k_l@413ok^k^00Kooooo00?o<S8booooooooool00oooool00onHV9So8B4Qonk^kP0;ooooo`04ohN7
QomVIVKoooooo`0000Gooooo00?o0000ooooooooool02_ooool6o`000003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02Oooool01Oo<c<co8B4Qo`000?mEEEGo000007_ooooo001nooooo`03
omgMgOlQ8B7ok^k^00?ooooo00?o0000ooooooooool00_l0000=ooooo`03o`000?oooooooooo00Ko
oooo00?oEEEEoiRHV?ooool01Oooool00ol0003ok^k^ooooo`04ooooo`03ogMgMomVIVKooooo00[o
oooo00CogMgMoa0@4?oooooo00001?ooool00oo^k^ko0000ooooo`0Booooo`05o`000?oooooooooo
ooooool000002oooool01OlQ8B7oQhN7oooooonHV9So000007_ooooo001oooooo`03oiRHV?mgMgOo
oooo00;ooooo00?o0000ooooooooool03Oooool00ol@413o0000o`000003o`0000Gooooo00?ogMgM
oa0@4?ooool01Oooool00omEEEGoMgMgooooo`05ooooo`03o`000?oooooooooo00Sooooo1ol00002
ooooo`03ogMgMomEEEGooooo01;ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oo
ooooooooooooool00000Noooool009Kooooo00?o0000ooooooooool01oooool00omEEEGoV9RHoooo
o`04ooooo`09omgMgOl@413ok^k^ooooool0003o^[ZjoooooonHV9So410@01;ooooo00?ok^k^oa0@
4?oMgMd04oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go8B4QoiRHV?ooooooMgMgoeEE
E@1kooooo`00U_ooool00ol0003oooooooooo`07ooooo`03okZj^_m4A4Cooooo00Gooooo00SoMgMg
ofIVI_ooooooV9RHoa0@4?l0003o8B4Qolc<c1;ooooo00?oIVIVogMgMoooool04oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00Goc<c<oa0@4?l0003o<S8bonk^kP1kooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36621 L
.10458 .42311 L
.14415 .46724 L
.16408 .48513 L
.18221 .49855 L
.20178 .50979 L
.21254 .51447 L
.22272 .51789 L
.23241 .52023 L
.2373 .52107 L
.24012 .52145 L
.24269 .52174 L
.24504 .52194 L
.24728 .52208 L
.2485 .52214 L
.24964 .52218 L
.25088 .52221 L
.25158 .52223 L
.25221 .52223 L
.25336 .52223 L
.25442 .52222 L
.25558 .5222 L
.2568 .52216 L
.25787 .52212 L
.25887 .52207 L
.26113 .52192 L
.26373 .52168 L
.26614 .52141 L
.27158 .5206 L
.27638 .51966 L
.28148 .51843 L
.2903 .51575 L
.30004 .51199 L
.31939 .50215 L
.34024 .48821 L
.38138 .45187 L
.42101 .40826 L
.45912 .36155 L
.49968 .31045 L
.53872 .26341 L
.58022 .21916 L
.60102 .20017 L
.6202 .18493 L
.64007 .17167 L
.65867 .16177 L
.67743 .15432 L
.68738 .15144 L
.69293 .15016 L
.69807 .14917 L
Mistroke
.70298 .14841 L
.7082 .1478 L
.71119 .14755 L
.71265 .14744 L
.714 .14736 L
.7152 .1473 L
.71652 .14725 L
.71785 .14721 L
.71857 .14719 L
.71924 .14718 L
.7205 .14717 L
.7212 .14716 L
.72186 .14716 L
.72305 .14717 L
.72433 .14719 L
.72546 .14722 L
.72653 .14726 L
.72895 .14737 L
.73157 .14753 L
.73396 .14773 L
.73935 .14832 L
.7441 .149 L
.74918 .14991 L
.75831 .15197 L
.76917 .15513 L
.77902 .15864 L
.81906 .17853 L
.85758 .20474 L
.89855 .23804 L
.938 .27338 L
.97594 .30878 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36768 L
.10458 .42297 L
.14415 .46615 L
.18221 .49767 L
.20178 .50932 L
.21274 .51436 L
.22272 .51798 L
.22755 .51939 L
.23267 .52064 L
.2371 .52152 L
.24186 .52225 L
.24453 .52256 L
.24697 .52279 L
.24814 .52288 L
.24942 .52296 L
.25062 .52302 L
.25175 .52306 L
.25244 .52308 L
.25319 .5231 L
.25449 .52312 L
.25523 .52312 L
.25601 .52312 L
.25667 .52311 L
.2574 .5231 L
.25871 .52306 L
.25945 .52303 L
.26011 .523 L
.26265 .52285 L
.26493 .52265 L
.26745 .52238 L
.27256 .52164 L
.27729 .52072 L
.28173 .51967 L
.29172 .51661 L
.30249 .51227 L
.32253 .50141 L
.34363 .48635 L
.38174 .45111 L
.4223 .40527 L
.46135 .35685 L
.50284 .30502 L
.54283 .25836 L
.58129 .21926 L
.60078 .20226 L
.62221 .18604 L
.6428 .17306 L
.66161 .16356 L
.68106 .15615 L
.69178 .15314 L
Mistroke
.69712 .15193 L
.70195 .15099 L
.70657 .15025 L
.71157 .1496 L
.71431 .14932 L
.71684 .1491 L
.71941 .14892 L
.7218 .1488 L
.72386 .14872 L
.72502 .14869 L
.72607 .14867 L
.72722 .14866 L
.72848 .14865 L
.72966 .14866 L
.73075 .14867 L
.73188 .14869 L
.73293 .14872 L
.73409 .14876 L
.73534 .14881 L
.73787 .14895 L
.7402 .14912 L
.74495 .14956 L
.75003 .15021 L
.75916 .15178 L
.77002 .15436 L
.77988 .15735 L
.7991 .1649 L
.81991 .17552 L
.86088 .20305 L
.90034 .23607 L
.93828 .27159 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3?ooooo`Ko00002_oo00000ol0
003oooooooooo`1Rooooo`008Oooool00ol0003oooooooooo`3;ooooo`Co00004?ooool5ool000;o
0000G_ooool0027ooooo00?o0000ooooooooool0b?ooool3o`0000;ooooo0_oo000Eooooo`03ool0
0?oooooo000000;o0000Foooool0027ooooo00?o0000ooooooooool0aOooool3o`0000;ooooo0ooo
000Looooo`;o0000FOooool0027ooooo00?o0000ooooooooool0`oooool2o`0000;ooooo0ooo000Q
ooooo`;o0000Eoooool0027ooooo00?o0000ooooooooool0`Oooool2o`000004oooooooo003oo`00
ool002Kooooo0_l00002ool005?ooooo000Qooooo`?o0000_oooool2o`0000;ooooo00?oo`00oooo
ooooool0:Oooool2o`0000;oo`00DOooool0027ooooo00?o0000ooooooooool0_Oooool2o`0003;o
oooo00?o0000oooooooo0000D?ooool0027ooooo00?o0000ooooooooool0_?ooool00ol0003ooooo
ooooo`0cooooo`;o00000_oo001>ooooo`008Oooool00ol0003oooooooooo`2kooooo`03o`000?oo
oooooooo03Kooooo0_l00002ool004cooooo000Qooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool0>Oooool2o`000003ool00?oooooooooo04Wooooo0007ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oo
oooooooo0;Wooooo00?oo`00ooooooooool0??ooool00ol0003oo`00ool00019ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o
0000ooooooooool0]oooool2ool0043ooooo0_l000000ooo003oooooooooo`16ooooo`001Ol00002
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000]_oo
ool00ooo003oooooooooo`12ooooo`03o`000?oo003ooooo04Kooooo0007ooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0;Cooooo00?o
0000ool00?ooool0AOooool2o`0004Kooooo0007ooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0/oooool00ol0003oo`00
ooooo`18ooooo`03o`000?oooooooooo04?ooooo0007ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;7ooooo0_l000000ooo003ooooo
ooooo`19ooooo`;o0000@oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0/?ooool00ol0003oo`00ool0001>ooooo`03o`00
0?oooooooooo043ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo
00?o0000ooooooooool0[oooool00ol0003oo`00ooooo`1@ooooo`;o0000@?ooool0027ooooo00?o
0000ooooooooool0[_ooool00ol0003oo`00ooooo`1Cooooo`03o`000?oo003oo`0003gooooo000Q
ooooo`03o`000?oooooooooo0:gooooo00?o0000ool00?ooool0EOooool00ol0003oooooool0000l
ooooo`008Oooool3o`000:cooooo00?o0000ool00?ooool0Eoooool2o`000003ool00?oooooooooo
03Wooooo000Qooooo`03o`000?oooooooooo0:_ooooo00?o0000ooooooooool0F_ooool00ol0003o
o`00ooooo`0iooooo`008Oooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo05_ooooo
00?o0000ool00?ooool0>?ooool0027ooooo00?o0000ooooooooool0Z_ooool00ol0003ooooooooo
o`1Mooooo`03o`000?oo003ooooo03Oooooo000Qooooo`03o`000?oooooooooo0:Wooooo00?o0000
ooooooooool0Goooool00ol0003oo`00ooooo`0fooooo`008Oooool00ol0003oooooooooo`2Xoooo
o`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool0=?ooool0027ooooo00?o0000oooooooo
ool0Yoooool00ol0003oooooooooo`1Tooooo`03ool00?oooooooooo03?ooooo000Qooooo`?o0000
Y_ooool00ol0003oooooooooo`1Vooooo`;oo`00<oooool0027ooooo00?o0000ooooooooool0YOoo
ool00ooo003oooooooooo`1Yooooo`03ool00?oooooooooo033ooooo000Qooooo`03o`000?oooooo
oooo0:Cooooo00?oo`00ooooooooool0Joooool00ol0003oooooooooo`0_ooooo`008Oooool00ol0
003oooooooooo`2Sooooo`03ool00?oooooooooo06gooooo00?o0000ooooooooool0;_ooool0027o
oooo00?o0000ooooooooool0X_ooool00ooo003oooooooooo`1_ooooo`03o`000?oooooooooo02go
oooo000Qooooo`03o`000?oooooooooo0:7ooooo00?oo`00ooooooooool0LOooool00ol0003ooooo
ooooo`0/ooooo`008Oooool00ol0003oooooooooo`2Pooooo`03ool00?oooooooooo07?ooooo00?o
0000ooooooooool0:oooool0027ooooo00?o0000ooooooooool0Woooool00ooo003oooooooooo`1e
ooooo`03o`000?oooooooooo02[ooooo000Qooooo`?o0000W_ooool00ol0003oo`00ooooo`1goooo
o`03o`000?oooooooooo02Wooooo000Qooooo`03o`000?oooooooooo03gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03gooooo1?l00000
0ol@413oooooooooo`07ooooo`03ool00?oooooooooo037ooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03;ooooo00?oo`00ooooooooool02?oo
ool5o`0001_ooooo000Qooooo`03o`000?oooooooooo03gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0nooooo`03o`000?oooooooooo00Sooooo00?o
o`00ooooooooool0=?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`0booooo`03ool00?oooooooooo00Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Ooo
ool00ol0003oooooooooo`0mooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool0=Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo03;ooooo00?oo`00o`000?ooool01oooool00onHV9So8B4Q
onk^kP0Looooo`008Oooool00ol0003oooooooooo`0mooooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`0nooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool0
=_ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03Cooooo00?oo`00o`000?ooool0
1oooool00onHV9So8B4Qonk^kP0Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<03oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c00fooooo`03ool00?l0003ooooo00Oooooo00?oMgMgofIVI_ooool06_ooool0027o
oooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0iooooo`03ool00?l0003ooooo00Oooooo00?o0000oooo
ooooool06Oooool0027ooooo0ol0000mooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo03[ooooo00?oo`00o`000?ooool00_ooool01Ol0
003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`03o`000?oooooooooo03gooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co0000?_ooool00omEEEGoIVIVo`000005ooooo`03o`000?oooooo
oooo03Oooooo00?oEEEEofIVI_l000003Oooool4o`0003[ooooo00Woo`00o`000?oooooooooooiRH
V?l@413o0000ob4Q8Oo<c<`06oooool0027ooooo00?o0000ooooooooool0Uoooool00ol0003ooooo
ooooo`27ooooo`03ool00?l0003ooooo023ooooo000Qooooo`03o`000?oooooooooo09Kooooo00?o
0000ooooooooool0ROooool00ooo003o0000ooooo`0Oooooo`008Oooool00ol0003oooooooooo`2F
ooooo`03o`000?oooooooooo08[ooooo00?oo`00o`000?ooool07_ooool0027ooooo00?o0000oooo
ooooool0UOooool00ol0003oooooooooo`2<ooooo`03ool00?l0003ooooo01?ooooo0_l00002oooo
o`;o00001?ooool0027ooooo00?o0000ooooooooool0Toooool00ooo003o0000ooooo`2@ooooo`03
o`000?oooooooooo017ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_oooonMo`00
0003ool00?l0003o000009Wo00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool01?o^
k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool2o`0000gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?oo`00o`000?ooool03Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Aooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03o`000?oooooo0000
093ooooo00?oo`00o`000?ooool0Yoooool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003o
ooooo`00002@ooooo`03ool00?oooooooooo0;7ooooo000Qooooo`04o`000?ooooooooooo`0008ko
oooo00?oo`00ooooooooool0/_ooool0027ooooo00Go0000ooooooooooooooooool0002<ooooo`03
ool00?oooooooooo0;?ooooo000Qooooo`05o`000?oooooooooooooooooo0000Roooool00ooo003o
0000ooooo`2dooooo`008Oooool3o`0000;ooooo00?oo`00ooooooooool0R?ooool00ooo003ooooo
ooooo`2dooooo`008Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo08Kooooo00?o
o`00ooooooooool0]Oooool0027ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`25
ooooo`03ool00?oooooooooo0;Kooooo000Qooooo`03o`000?oooooooooo00Cooooo00?oo`00oooo
ooooool0Poooool00ooo003oooooooooo`2gooooo`008Oooool00ol0003oooooooooo`04ooooo`03
ool00?l0003ooooo08;ooooo00?o0000ooooooooool0^?ooool0027ooooo00?o0000ooooooooool0
1Oooool00ooo003oooooooooo`21ooooo`03o`000?oooooooooo0;Sooooo000Qooooo`03o`000?oo
oooooooo00Kooooo00?oo`00ooooooooool0Ooooool00ol0003oooooooooo`2iooooo`008Oooool3
o`0000Kooooo00?oo`00o`000?ooool0O_ooool00ol0003oooooooooo`2jooooo`008Oooool00ol0
003oooooooooo`07ooooo`03ool00?oooooooooo07cooooo00?o0000ooooooooool0^oooool0027o
oooo00?o0000ooooooooool01oooool00ooo003o0000ooooo`1kooooo`03o`000?oooooooooo0;co
oooo000Qooooo`03o`000?oooooooooo00Sooooo00?oo`00o`000?ooool0N_ooool00ol0003ooooo
ooooo`2looooo`008Oooool00ol0003oooooooooo`09ooooo`;oo`00N?ooool00ooo003o0000oooo
o`2nooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07Kooooo00?oo`00
ooooooooool0__ooool0027ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1doooo
o`03ool00?oooooooooo0;oooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0L_ooool00ooo003oooooooooo`30ooooo`008Oooool3o`0000gooooo00?o0000ooooooooool0
L?ooool00ooo003oooooooooo`31ooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo06oooooo00?oo`00ooooooooool0`_ooool0027ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`1]ooooo`03ool00?l0003ooooo0<?ooooo000Qooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0K?ooool00ooo003oooooooooo`33ooooo`008Oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo06[ooooo00?oo`00ooooooooool0a?ooool0027ooooo
00?o0000ooooooooool04?ooool00ol0003oo`00ooooo`1Yooooo`03ool00?oooooooooo0<Gooooo
000Qooooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool0Ioooool00ooo003ooooooooo
o`36ooooo`008Oooool3o`0001;ooooo00?oo`00ooooooooool0IOooool00ooo003oooooooooo`37
ooooo`008Oooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo06?ooooo00?oo`00oooo
ooooool0b?ooool0027ooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`1Rooooo`03
o`000?oooooooooo0<Sooooo000Qooooo`03o`000?oooooooooo01Cooooo00?oo`00ooooooooool0
HOooool00ol0003oooooooooo`39ooooo`008Oooool00ol0003oooooooooo`0Eooooo`03ool00?oo
oooooooo05oooooo00?o0000ooooooooool0b_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0
5_ooool00ooo003oooooooooo`1Mooooo`03o`000?oooooooooo0<_ooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooo
ooooo`0Gooooo`03ool00?oooooooooo05_ooooo00?o0000ooooooooool0c?ooool000Oooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0000Gooooo`03ool0
0?oooooooooo05[ooooo00?o0000ooooooooool0cOooool000Oooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool06?ooool00ooo003ooooo
ooooo`1Hooooo`03o`000?oooooooooo0<kooooo0007ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool06Oooool00ooo003o
ooooooooo`1Gooooo`03o`000?oooooooooo0<kooooo0007ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo00?oo`00oooooooo
ool0EOooool00ooo003oooooooooo`3?ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05?o
oooo00?oo`00ooooooooool0d?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00001Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo057ooooo00?oo`00oooooooo
ool0dOooool0027ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1?ooooo`03ool0
0?oooooooooo0=;ooooo000Qooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0C_oo
ool00ooo003oooooooooo`3Cooooo`008Oooool3o`0001kooooo00?o0000ooooooooool0Boooool0
0ol0003oo`00ooooo`3Eooooo`008Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
04Wooooo00?o0000ool00?ooool0e_ooool0027ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`17ooooo`03o`000?oo003ooooo0=Oooooo000Qooooo`03o`000?oooooooooo027ooooo
00?o0000ool00?ooool0AOooool00ol0003oo`00ooooo`3Hooooo`008Oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oo003oo`0004?ooooo00?o0000ool00?ooool0fOooool0027ooooo00?o0000
ooooooooool08oooool2o`000003ool00?oooooooooo03kooooo0_l000000ooo003oooooooooo`3I
ooooo`008Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo003ooooo03gooooo00?o0000oooo
oooo0000g?ooool0027ooooo0ol0000Vooooo`03o`000?oo003ooooo03_ooooo00?o0000oooooooo
ool0gOooool0027ooooo00?o0000ooooooooool09oooool00ol0003oo`00ool0000iooooo`03o`00
0?oooooooooo0=kooooo000Qooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo0000=ooo
ool00ol0003oooooooooo`3Oooooo`008Oooool00ol0003oooooooooo`0Yooooo`;o000000?oo`00
ooooooooool0<oooool00ol0003oooooooooo`3Pooooo`008Oooool00ol0003oooooooooo`0[oooo
o`03o`000?oo003ooooo037ooooo0_l0003Sooooo`008Oooool00ol0003oooooooooo`0/ooooo`03
o`000?oo003ooooo02oooooo00?o0000ooooooooool0hoooool0027ooooo00?o0000ooooooooool0
;Oooool00ol0003oo`00ooooo`0]ooooo`;oo`00iOooool0027ooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0[ooooo`03ool00?oooooooooo0>Gooooo000Qooooo`?o0000;oooool2
o`0002Wooooo0_oo003Xooooo`008Oooool00ol0003oooooooooo`0aooooo`;o00009Oooool2ool0
0003o`000?oooooooooo0>Oooooo000Qooooo`03o`000?oooooooooo03?ooooo0_l0000Rooooo`03
ool00?l0003ooooo0>[ooooo000Qooooo`03o`000?oooooooooo03Gooooo0_l0000Nooooo`;oo`00
kOooool0027ooooo00?o0000ooooooooool0=oooool3ool001Wooooo0_oo003_ooooo`008Oooool0
0ol0003oooooooooo`0hooooo`;o00000_oo000Dooooo`03o`000?oo003oo`000?7ooooo000Qoooo
o`03o`000?oooooooooo03_ooooo00?o0000ool00?oo00000_oo000:ooooo`Ko0000m?ooool0027o
oooo0ol00010ooooo`Ooo`000ol0003jooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o410@oooooooo
ool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool0
01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_oo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool00omgMgOoIVIV
ooooo`0Gooooo`03ofIVI_mgMgOooooo0:Oooooo0023ooooo`?o00005?ooool00olQ8B7ogMgMoooo
o`06ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Yoooool007_ooooo00OoQhN7
o`000?mEEEGoIVIVo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool02oooool01OnHV9So0000
o`000?m4A4Co^[Zj00?ooooo00?oV9RHoeEEEOooool01_ooool00omEEEGoV9RHooooo`02ooooo`Go
00002Oooool00omEEEGoZJVYooooo`02ooooo`06okZj^_m4A4Cooooooooooon7QhOoIVIV5?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`04oa0@4?l0003oA4A4olc<c0Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@1eooooo`00Noooool01ol@413ogMgMogMgMolQ8B7oooooohN7
QomVIVH00_ooool00ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool0
0ol0003ogMgMooooo`05ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4
A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj0_ooool00oo^k^ko0000ooooo`0;ooooo`Ko
00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oiRHV?l@413ogMgM
00Oooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00Oo0000oooooooMgMgo<S8booooooo^k^ko
410@00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`;oMgMg1_ooool0
0olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co410@omgMgOoooooo00001?oo
ool00ol0003oooooooooo`0Booooo`05oa0@4?ooooooooooooooool@41003_ooool00on7QhOoEEEE
ooooo`07ooooo`03o`000?oooooooooo07?ooooo001kooooo`04oeEEEOnYZJWoooooo`0000;ooooo
00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`06ooooo`03onk^k_l@413ok^k^00Go
oooo00?o<S8booooooooool01?ooool00onHV9So8B4Qonk^kP0;ooooo`04ohN7QomVIVKoooooo`00
00Cooooo00?o0000ooooooooool02_ooool6o`0000;ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05olc<c?lQ8B7o0000oeEEEOl000001oooool00omgMgOo<S8booooo`1dooooo`00Noooool0
0ooMgMgo8B4Qonk^kP03ooooo`04o`000?oooooo0000o`0000gooooo00?o0000ooooooooool01ooo
ool00omEEEGoV9RHooooo`04ooooo`03o`000?o^k^kooooo00Gooooo00?oMgMgofIVI_ooool02_oo
ool01?oMgMgo410@ooooool00003ooooo`03onk^k_l0003ooooo01?ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05ob4Q8On7QhOooooooiRHV?l000001?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<07Gooooo001looooo`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool03?ooool00ol@
413o0000o`000003o`0000Kooooo00?ogMgMoa0@4?ooool01?ooool00omEEEGoMgMgooooo`06oooo
o`03o`000?oooooooooo00Sooooo1ol000000oooooooMgMgoeEEE@0Dooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0Mooo
ool009;ooooo00?o0000ooooooooool02?ooool00omEEEGoV9RHooooo`03ooooo`03omgMgOl@413o
k^k^00;ooooo00Go0000okZj^_ooooooV9RHoa0@400Aooooo`03onk^k_l@413ogMgM01Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ob4Q8OnHV9SoooooogMgMomEEED01?ooool00ol0003o
ooooooooo`1gooooo`00T_ooool00ol0003oooooooooo`08ooooo`03okZj^_m4A4Cooooo00Cooooo
00WoMgMgofIVI_oooooooooooiRHV?l@413o0000ob4Q8Oo<c<`04Oooool00omVIVKoMgMgooooo`0D
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo<c<co410@o`000?lb<S;ok^k^00Cooooo
1?l0001fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -43.625 0 ]
[.5 .63053 43.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -104.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
146.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36882 L
.10458 .42945 L
.14415 .47813 L
.18221 .51413 L
.20178 .52772 L
.21267 .53371 L
.22272 .53823 L
.23293 .54179 L
.23832 .54324 L
.24402 .54446 L
.24641 .54487 L
.24897 .54525 L
.25119 .54552 L
.25361 .54576 L
.25507 .54587 L
.25643 .54596 L
.25773 .54603 L
.2584 .54605 L
.25912 .54608 L
.25983 .5461 L
.26048 .54611 L
.26176 .54612 L
.26293 .54612 L
.26416 .5461 L
.26538 .54606 L
.26607 .54604 L
.26671 .54601 L
.26912 .54586 L
.27131 .54567 L
.27364 .54542 L
.27847 .54472 L
.2838 .54367 L
.29326 .54109 L
.30213 .53784 L
.32232 .52753 L
.34082 .51465 L
.38045 .47709 L
.41855 .43018 L
.45912 .37198 L
.49816 .31159 L
.53966 .24723 L
.57964 .18952 L
.61811 .14181 L
.63759 .12157 L
.65902 .10289 L
.67938 .08893 L
.69843 .07943 L
.70884 .07575 L
.71396 .07434 L
Mistroke
.71872 .07327 L
.72301 .0725 L
.72758 .07188 L
.7302 .07163 L
.73148 .07153 L
.73266 .07146 L
.73371 .0714 L
.73487 .07135 L
.73603 .07132 L
.73725 .0713 L
.73856 .07129 L
.73977 .0713 L
.7404 .07132 L
.7411 .07133 L
.74183 .07136 L
.74251 .07139 L
.7449 .07152 L
.74625 .07162 L
.74748 .07173 L
.75203 .07227 L
.7568 .07306 L
.76198 .07419 L
.7668 .07548 L
.77773 .07929 L
.78828 .08411 L
.79823 .08966 L
.81683 .10256 L
.85534 .13895 L
.89632 .18962 L
.93577 .24654 L
.97371 .30514 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36745 L
.10458 .42888 L
.14415 .47887 L
.18221 .51541 L
.20178 .52887 L
.21274 .53472 L
.22272 .53897 L
.22755 .54066 L
.23267 .54218 L
.2371 .54328 L
.24186 .54424 L
.24453 .54467 L
.24697 .545 L
.24945 .54527 L
.25175 .54547 L
.25305 .54556 L
.25442 .54563 L
.25521 .54566 L
.25595 .54569 L
.25662 .54571 L
.25734 .54572 L
.25798 .54573 L
.25868 .54574 L
.25942 .54574 L
.2601 .54573 L
.26133 .54571 L
.26265 .54567 L
.26386 .54561 L
.26521 .54554 L
.26793 .54533 L
.27045 .54507 L
.27282 .54476 L
.27815 .54388 L
.28389 .54261 L
.29438 .53945 L
.30401 .53563 L
.32293 .52562 L
.34363 .51103 L
.38419 .47244 L
.42324 .42464 L
.46474 .3653 L
.50472 .30334 L
.54318 .24316 L
.5841 .18312 L
.62351 .13374 L
.66139 .09783 L
.68084 .08474 L
.69176 .07912 L
.70173 .07511 L
Mistroke
.70651 .07357 L
.7116 .07221 L
.716 .07126 L
.72076 .07048 L
.72368 .07013 L
.72496 .07 L
.72636 .06988 L
.7276 .0698 L
.72893 .06972 L
.72966 .06969 L
.73033 .06967 L
.73164 .06963 L
.7329 .06962 L
.73407 .06962 L
.73535 .06964 L
.73599 .06966 L
.7367 .06968 L
.73789 .06974 L
.73918 .06981 L
.74149 .06999 L
.7439 .07024 L
.74647 .07057 L
.75109 .07135 L
.75659 .07257 L
.76157 .07396 L
.77244 .07788 L
.78269 .08268 L
.80274 .09498 L
.8212 .10949 L
.86066 .14929 L
.8986 .19655 L
.93899 .25354 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000=Gooooo3Ooo001Rooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=Cooooo1Ol00009ooooo`?oo`00
0_l0001Mooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=;ooooo0_l0
000Cooooo`;o0000Foooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3=
ooooo`;oo`000ol0000Gooooo`?o0000F?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3:ooooo`?oo`000_l0000Mooooo`;o0000E_ooool001Sooooo00?oEEEEofIVI_l0
00001_ooool00ol0003oooooooooo`38ooooo`;oo`0000?oooooo`000?l000008Oooool00ol0003o
ooooooooo`1Cooooo`008Oooool00ol0003oooooooooo`37ooooo`04ool00?oooooo0000o`0002?o
oooo0_oo00000ol0003oooooooooo`1Aooooo`008Oooool00ol0003oooooooooo`35ooooo`;oo`00
00?oooooo`000?ooool09_ooool00ooo003o0000ooooo`1Aooooo`008Oooool3o`000<Cooooo00Co
o`00ooooool0003o0000:Oooool2ool00003o`000?oooooooooo04kooooo000Qooooo`03o`000?oo
oooooooo0<Cooooo00?oo`00o`000?ooool0;?ooool00ooo003o0000ooooo`1>ooooo`008Oooool0
0ol0003oooooooooo`33ooooo`03ool00?l0003ooooo02kooooo00?oo`00o`000?l00000COooool0
027ooooo00?o0000ooooooooool0`_ooool00ooo003oooooooooo`0`ooooo`03ool00?oooooo0000
04cooooo000Qooooo`03o`000?oooooooooo0<7ooooo00?oo`00ooooooooool0<_ooool00ooo003o
ooooo`00001;ooooo`008Oooool00ol0003oooooooooo`30ooooo`03o`000?oooooooooo03Cooooo
00?oo`00ooooool00000B_ooool0027ooooo00?o0000ooooooooool0_oooool00ol0003ooooooooo
o`0fooooo`03ool00?oooooo000004Wooooo000Qooooo`?o0000__ooool00ol0003oooooooooo`0h
ooooo`03ool00?oooooo000004Sooooo000Qooooo`03o`000?oooooooooo0;gooooo00?o0000oooo
ooooool0>_ooool00ooo003oooooo`000017ooooo`008Oooool00ol0003oooooooooo`2looooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0A?ooool0027ooooo00?o0000ooooooooool0
^oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo04?ooooo000Qooooo`03o`000?oo
oooooooo0;Wooooo00?oo`00o`000?ooool0@oooool00ol0003oooooooooo`12ooooo`008Oooool0
0ol0003oooooooooo`2iooooo`03ool00?oooooooooo04Cooooo00?o0000ooooooooool0@Oooool0
027ooooo00?o0000ooooooooool0^?ooool00ol0003oo`00ooooo`16ooooo`03o`000?oooooooooo
043ooooo000Qooooo`?o0000]oooool00ol0003oo`00ooooo`17ooooo`03o`000?oooooooooo043o
oooo000Qooooo`03o`000?oooooooooo0;Oooooo00?oo`00ooooooooool0B?ooool00ooo003ooooo
ooooo`0oooooo`008Oooool00ol0003oooooooooo`2fooooo`03ool00?oooooooooo04[ooooo00?o
o`00ooooooooool0?_ooool0027ooooo00?o0000ooooooooool0]Oooool00ooo003oooooooooo`1;
ooooo`03ool00?l0003ooooo03kooooo000Qooooo`03o`000?oooooooooo0;Cooooo00?oo`00oooo
ooooool0COooool00ooo003o0000ooooo`0mooooo`008Oooool00ol0003oooooooooo`2cooooo`03
ool00?oooooooooo04oooooo00?oo`00ooooooooool0??ooool0027ooooo00?o0000ooooooooool0
/_ooool00ooo003o0000ooooo`1Aooooo`03ool00?oooooooooo03_ooooo000Qooooo`03o`000?oo
oooooooo0;7ooooo00?oo`00o`000?ooool0D_ooool00ooo003o0000ooooo`0kooooo`008Oooool3
o`000;3ooooo00?oo`00o`000?ooool0E?ooool00ooo003o0000ooooo`0jooooo`008Oooool00ol0
003oooooooooo`2_ooooo`03ool00?l0003ooooo05Kooooo00?oo`00o`000?ooool0>Oooool0027o
oooo00?o0000ooooooooool0[oooool00ol0003oooooooooo`1Fooooo`03ool00?oooooo000003Wo
oooo000Qooooo`03o`000?oooooooooo0:oooooo00?o0000ooooooooool0Eoooool00ooo003o0000
ooooo`0hooooo`008Oooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo05Wooooo00?o
o`00o`000?ooool0=oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0[Oooool00ol0003ooooo
ooooo`1Kooooo`03ool00?l0003ooooo03Kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2/ooooo`03o`00
0?oooooooooo05kooooo00?o0000ooooooooool0=?ooool000Go00000_ooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`000:_ooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`0cooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo063ooooo
00?o0000ooooooooool0<oooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo06;o
oooo00?o0000ooooooooool0<_ooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0ZOooool00ooo003oooooooooo`1Tooooo`03
o`000?oooooooooo037ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0:Sooooo00?o0000ool00?ooool0IOooool00ol0003o
ooooooooo`0aooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03
o`000?oooooooooo0:Sooooo00?oo`00ooooooooool0I_ooool00ol0003oooooooooo`0`ooooo`00
8Oooool00ol0003oooooooooo`2Wooooo`03ool00?oooooooooo06Sooooo00?o0000ooooooooool0
;oooool0027ooooo00?o0000ooooooooool0Y_ooool00ol0003oo`00ooooo`1Yooooo`03ool00?oo
oooooooo02oooooo000Qooooo`?o0000Y_ooool00ooo003oooooooooo`1Yooooo`03ool00?l0003o
oooo02oooooo000Qooooo`03o`000?oooooooooo0:Gooooo00?oo`00ooooooooool0Joooool00ooo
003o0000ooooo`0^ooooo`008Oooool00ol0003oooooooooo`2Tooooo`03ool00?oooooooooo06go
oooo00?oo`00ooooooooool0;Oooool0027ooooo00?o0000ooooooooool0Xoooool00ol0003oo`00
ooooo`1^ooooo`03ool00?l0003ooooo02gooooo000Qooooo`03o`000?oooooooooo0:?ooooo00?o
o`00ooooooooool0Koooool00ooo003o0000ooooo`0/ooooo`008Oooool00ol0003oooooooooo`2R
ooooo`03ool00?oooooooooo077ooooo00?oo`00ooooooooool0:oooool0027ooooo00?o0000oooo
ooooool0XOooool00ol0003oo`00ooooo`1cooooo`03ool00?oooooooooo02[ooooo000Qooooo`?o
0000XOooool00ooo003oooooooooo`1cooooo`03ool00?l0003ooooo02[ooooo000Qooooo`03o`00
0?oooooooooo0:3ooooo00?oo`00ooooooooool0MOooool00ooo003oooooooooo`0Yooooo`008Ooo
ool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo07Oooooo00?oo`00ooooooooool0:?oo
ool0027ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`1hooooo`03ool00?l0003o
oooo02Sooooo000Qooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0NOooool00ooo
003oooooooooo`0Wooooo`008Oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo07_o
oooo00?oo`00ooooooooool09_ooool0027ooooo00?o0000ooooooooool0W?ooool00ol0003ooooo
ooooo`1mooooo`03o`000?oooooooooo02Gooooo000Qooooo`03o`000?oooooooooo09cooooo00?o
0000ooooooooool0OOooool00ol0003oooooooooo`0Uooooo`008Oooool3o`0009_ooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`0moooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@0mooooo`Co000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0dooooo`Co000000?o
410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0gooooo`03o`00
0?oooooooooo00?ooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003ooooo
ooooo`05ooooo`03ool00?oooooooooo03Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0=_ooool00ol0003oooooooooo`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@06oooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`04ooooo`03o`000?oo003ooooo03So
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00?o
oooo00?oV9RHob4Q8Oo^k^h07?ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol0003ooooo
oooooooooooo000000oooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`04ooooo`03
ool00?oooooooooo03Sooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0hooooo`03
o`000?oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0
?Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00ooooo
o`03o`000?oooooooooo00?ooooo00?o0000ool00?ooool0>Oooool00ol0003oooooooooo`0;oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`0>Oooool00ol0003oooooooooo`04ooooo`03ogMgMomVIVKo
oooo01[ooooo000Qooooo`03o`000?oooooooooo03gooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0i
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0??ooool00ooo003oooooooooo`04
ooooo`03o`000?oooooooooo01Wooooo000Qooooo`?o0000?Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`02ooooo`03o`000?oo003o
oooo03[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0looooo`08ool00?l0003o
ooooo`000?nj^[[ooooooiRHV?l@410Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l000000oooool00ol0003o
o`00ooooo`0iooooo`03oeEEEOmVIVKo000000gooooo1?l0000looooo`07ool00?ooooooV9RHoa0@
4?l0003o8B4Qolc<c00Kooooo`008Oooool00ol0003oooooooooo`2Fooooo`03ool00?oooooooooo
08[ooooo00?oo`00ooooooooool07_ooool0027ooooo00?o0000ooooooooool0UOooool00ol0003o
o`00ooooo`2<ooooo`03ool00?oooooooooo01gooooo000Qooooo`03o`000?oooooooooo09Gooooo
00?oo`00ooooooooool0S?ooool00ooo003oooooooooo`0Mooooo`008Oooool00ol0003ooooooooo
o`2Dooooo`03o`000?oo003ooooo08kooooo00?oo`00ooooooooool04_ooool2o`0000;ooooo0_l0
0004ooooo`008Oooool00ol0003oooooooooo`2Cooooo`03o`000?oo003ooooo093ooooo00?oo`00
ooooooooool04Oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooooigo000000?o
o`00o`000?l00000TOl000000ooo003o0000o`000005o`0000cooooo00CogMgMo`000?l@413oc<c<
1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo0_l0000=ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool04Oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Ooo
ool00ol0003oooooool0002Aooooo`03o`000?oooooooooo0:Kooooo0_l00002ooooo`;o00001?oo
ool0027ooooo00?o0000oooooooo0000T?ooool00ol0003oooooooooo`2aooooo`008Oooool01?l0
003ooooooooooooo002?ooooo`03o`000?oooooooooo0;7ooooo000Qooooo`05o`000?oooooooooo
o`000?oo0000SOooool00ol0003oooooooooo`2booooo`008Oooool01Ol0003ooooooooooooooooo
o`0008cooooo00?o0000ooooooooool0/oooool0027ooooo0ol00002ooooo`03ool00?oooooooooo
08Wooooo00?o0000ooooooooool0/oooool0027ooooo00?o0000ooooooooool00_ooool00ol0003o
o`00ooooo`28ooooo`03o`000?oooooooooo0;Cooooo000Qooooo`03o`000?oooooooooo00?ooooo
00?o0000ool00?ooool0Q_ooool00ol0003oooooooooo`2eooooo`008Oooool00ol0003ooooooooo
o`04ooooo`03ool00?oooooooooo08Cooooo00?o0000ool00?ooool0]_ooool0027ooooo00?o0000
ooooooooool01?ooool00ol0003oo`00ooooo`24ooooo`03o`000?oo003ooooo0;Kooooo000Qoooo
o`03o`000?oooooooooo00Gooooo00?o0000ool00?ooool0P_ooool00ol0003oo`00ooooo`2goooo
o`008Oooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo083ooooo00?o0000ool00?oo
ool0^?ooool0027ooooo0ol00006ooooo`03o`000?oo003ooooo083ooooo00?oo`00ooooooooool0
^?ooool0027ooooo00?o0000ooooooooool01oooool00ol0003oo`00ooooo`1nooooo`03o`000?oo
003ooooo0;Wooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0OOooool0
0ol0003oo`00ooooo`2jooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
07cooooo00?oo`00ooooooooool0^_ooool0027ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1jooooo`03o`000?oo003ooooo0;_ooooo000Qooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0NOooool00ol0003oo`00ooooo`2looooo`008Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo07Sooooo00?oo`00ooooooooool0_?ooool0027ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1fooooo`03o`000?oo003ooooo0;gooooo000Qoooo
o`?o00003?ooool00ol0003oooooooooo`1dooooo`03o`000?oo003ooooo0;kooooo000Qooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0M?ooool00ooo003oooooooooo`2nooooo`00
8Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo003ooooo07;ooooo00?o0000ooooooooool0
_oooool0027ooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`1`ooooo`03o`000?oo
oooooooo0<3ooooo000Qooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool0Koooool0
0ol0003oooooooooo`30ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo003ooooo
06kooooo00?o0000ooooooooool0`Oooool0027ooooo00?o0000ooooooooool04?ooool00ooo003o
ooooooooo`1/ooooo`03o`000?oooooooooo0<;ooooo000Qooooo`?o00004Oooool00ooo003ooooo
ooooo`1[ooooo`03o`000?oooooooooo0<;ooooo000Qooooo`03o`000?oooooooooo017ooooo00?o
0000ool00?ooool0J_ooool00ol0003oooooooooo`33ooooo`008Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oo003ooooo06Sooooo00?o0000ooooooooool0a?ooool0027ooooo00?o0000oooo
ooooool04oooool00ooo003oooooooooo`1Wooooo`03ool00?oooooooooo0<Cooooo000Qooooo`03
o`000?oooooooooo01Cooooo00?oo`00ooooooooool0IOooool00ooo003oooooooooo`35ooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo003ooooo06Cooooo00?oo`00oooo
ooooool0a_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`03ooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool0H_ooool00ooo
003o0000ooooo`37ooooo`001oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool00_ooool3o`0001Kooooo00?oo`00ooooooooool0HOooool00ooo003oooooooooo`37oooo
o`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0
003oooooooooo`0Gooooo`03ool00?oooooooooo05oooooo00?oo`00ooooooooool0b?ooool000Oo
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo05kooooo00?oo`00o`000?ooool0bOooool0
00Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`1Looooo`03ool00?l0003ooooo0<[ooooo0007oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0F_ooool00ooo003o0000ooooo`3;ooooo`001oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0FOooool00ooo003oooooooooo`3;ooooo`008Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo05Oooooo00?oo`00ooooooooool0c?ooool0027ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`1Fooooo`03ool00?l0003ooooo0<gooooo000Qooooo`?o0000
7?ooool00ol0003oooooooooo`1Dooooo`03ool00?l0003ooooo0<kooooo000Qooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`3>ooooo`008Oooool0
0ol0003oooooooooo`0Nooooo`03ool00?oooooooooo057ooooo00?o0000ooooooooool0coooool0
027ooooo00?o0000ooooooooool07_ooool00ooo003o0000ooooo`1@ooooo`03o`000?oooooooooo
0=3ooooo000Qooooo`03o`000?oooooooooo01oooooo00?oo`00ooooooooool0Coooool00ol0003o
ooooooooo`3@ooooo`008Oooool00ol0003oooooooooo`0Pooooo`03ool00?oooooooooo04gooooo
00?o0000ooooooooool0dOooool0027ooooo00?o0000ooooooooool08Oooool00ooo003ooooooooo
o`1;ooooo`03o`000?oooooooooo0=;ooooo000Qooooo`?o00008_ooool00ooo003oooooooooo`19
ooooo`03o`000?oooooooooo0=?ooooo000Qooooo`03o`000?oooooooooo02?ooooo00?oo`00o`00
0?ooool0AOooool2ool00003o`000?oooooooooo0=Cooooo000Qooooo`03o`000?oooooooooo02Co
oooo00?oo`00o`000?ooool0@oooool00ooo003o0000ooooo`3Gooooo`008Oooool00ol0003ooooo
ooooo`0Uooooo`03ool00?l0003ooooo047ooooo00?oo`00o`000?ooool0f?ooool0027ooooo00?o
0000ooooooooool09_ooool00ooo003o0000ooooo`0oooooo`03ool00?l0003ooooo0=Wooooo000Q
ooooo`03o`000?oooooooooo02Oooooo00?oo`00o`000?ooool0?Oooool00ooo003o0000ooooo`3J
ooooo`008Oooool00ol0003oooooooooo`0Xooooo`03ool00?l0003ooooo03_ooooo00?oo`00o`00
0?ooool0foooool0027ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0hooooo`03
ool00?l0003ooooo0=cooooo000Qooooo`?o0000:oooool00ol0003oooooooooo`0fooooo`03ool0
0?l0003ooooo0=gooooo000Qooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0=?oo
ool00ooo003o0000ooooo`3Nooooo`008Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo03;ooooo00?oo`00o`000?ooool0goooool0027ooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0`ooooo`03ool00?l0003ooooo0>3ooooo000Qooooo`03o`000?oooooooooo02oo
oooo0_l0000`ooooo`03ool00?oooooooooo0>3ooooo000Qooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool0:oooool2o`000>?ooooo000Qooooo`03o`000?oooooooooo033ooooo0_oo
00000ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0>?ooooo000Qooooo`?o0000<_ooool2
ool002Wooooo00?o0000ooooooooool0i?ooool0027ooooo00?o0000ooooooooool0=?ooool00ooo
003oooooooooo`0Uooooo`03o`000?oooooooooo0>Gooooo000Qooooo`03o`000?oooooooooo03Go
oooo0_oo000Sooooo`;o0000j?ooool0027ooooo00?o0000ooooooooool0=oooool00ooo003ooooo
ooooo`0Mooooo`;oo`0000?o0000ooooooooool0j?ooool0027ooooo00?o0000ooooooooool0>?oo
ool3ool001Wooooo0ooo003]ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000
ooooooooool0>oooool2ool000;o00004_ooool3ool00003o`000?oooooooooo0>gooooo000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?Oooool2ool000?o00003?ooool3ool0
00;o0000lOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`12ooooo`Oo
00001Ooo0003o`000??ooooo000Jooooo`03o`000?oooooooooo00Cooooo0ol0003oooooodGooooo
000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Ko
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:cooooo00?oMgMgofIV
I_ooool05oooool00omVIVKoMgMgooooo`2Oooooo`00Roooool3o`0001?ooooo00?o8B4QomgMgOoo
ool01oooool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@413ogMgM09oooooo0022ooooo`07ohN7
Qol0003oEEEEofIVI_l0003o<S8bonk^kP03ooooo`03o`000?oooooooooo00_ooooo00GoV9RHo`00
0?l0003oA4A4okZj^P02ooooo`03oiRHV?mEEEGooooo00Oooooo00CoEEEEoiRHV?oooooooooo1Ol0
0009ooooo`03oeEEEOnYZJWooooo00;ooooo00?o^[ZjodA4A?ooool00_ooool00on7QhOoIVIVoooo
o`0Cooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8H3ooooo0022ooooo`07oa0@4?oMgMgo
MgMgob4Q8OooooooQhN7ofIVIP03ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_o^k^ko
MgMgoa0@4003ooooo`03o`000?oMgMgooooo00Kooooo00Wo0000oooooooooooooooooiRHV?lQ8B7o
k^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P?ooooo00?ok^k^o`000?oo
ool02oooool6o`0000Cooooo00?o0000ooooooooool01?ooool2ob4Q8H3ooooo0022ooooo`07o`00
0?oooooogMgMoc8b<_ooooook^k^oa0@4003ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01Oooool2ogMgM`Oooooo00?o<S8booooooooool00_ooool00onHV9So8B4Qonk^kP0<oooo
o`04oa0@4?oMgMgoooooo`0000Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`26
ooooo`00P_ooool01?mEEEGoZJVYooooool00002ooooo`05o`000?ooooooooooooooool000003Ooo
ool00ol0003oooooooooo`05ooooo`03onk^k_l@413ok^k^00Kooooo00?o<S8booooooooool00ooo
ool00onHV9So8B4Qonk^kP0;ooooo`04ohN7QomVIVKoooooo`0000Gooooo00?o0000ooooooooool0
2_ooool6o`0000Cooooo00?o0000ooooooooool0Q_ooool008;ooooo00?ogMgMob4Q8Oo^k^h00ooo
ool00ol0003oooooooooo`02o`0000gooooo00?o0000ooooooooool01_ooool00omEEEGoV9RHoooo
o`05ooooo`03o`000?o^k^kooooo00Cooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgo410@oooo
ool00004ooooo`03onk^k_l0003ooooo01Gooooo00?o0000ooooooooool0Q_ooool008?ooooo00?o
V9RHogMgMoooool00_ooool00ol0003oooooooooo`0=ooooo`03oa0@4?l0003o000000?o00001Ooo
ool00ooMgMgo410@ooooo`05ooooo`03oeEEEOmgMgOooooo00Gooooo00?o0000ooooooooool02?oo
ool7o`0000;ooooo00?oMgMgoeEEEOooool05Oooool00ol0003oooooooooo`26ooooo`00V_ooool0
0ol0003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00WogMgMoa0@4?o^k^koooooo`00
0?nj^[[ooooooiRHV?l@41004_ooool00oo^k^ko410@omgMg@0Fooooo`03o`000?oooooooooo08Ko
oooo002Jooooo`03o`000?oooooooooo00Oooooo00?o^[ZjodA4A?ooool01Oooool02?mgMgOoIVIV
oooooonHV9So410@o`000?lQ8B7oc<c<4_ooool00omVIVKoMgMgooooo`0Dooooo`03oeEEEOmVIVKo
000008Sooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36269 L
.10458 .41601 L
.14415 .45728 L
.16408 .47398 L
.18221 .4865 L
.20178 .49698 L
.21254 .50133 L
.22272 .5045 L
.23241 .50667 L
.2373 .50745 L
.24012 .5078 L
.24269 .50805 L
.24504 .50824 L
.24728 .50836 L
.2485 .50842 L
.24964 .50845 L
.25088 .50848 L
.25158 .50849 L
.25221 .50849 L
.25336 .50849 L
.25442 .50848 L
.25558 .50845 L
.2568 .50841 L
.25787 .50837 L
.25887 .50832 L
.26113 .50817 L
.26373 .50794 L
.26614 .50768 L
.27158 .50691 L
.27638 .50601 L
.28148 .50484 L
.2903 .50231 L
.30004 .49877 L
.31939 .4895 L
.34024 .4764 L
.38138 .44232 L
.42101 .4015 L
.45912 .3579 L
.49968 .31034 L
.53872 .26667 L
.58022 .22574 L
.60102 .20821 L
.6202 .19418 L
.64007 .18201 L
.65867 .17294 L
.67743 .16616 L
.68738 .16355 L
.69293 .16239 L
.69807 .16151 L
Mistroke
.70298 .16084 L
.7082 .1603 L
.71119 .16008 L
.71265 .16 L
.714 .15993 L
.7152 .15988 L
.71652 .15984 L
.71716 .15983 L
.71785 .15981 L
.71857 .1598 L
.71924 .15979 L
.7199 .15979 L
.72059 .15979 L
.72184 .15979 L
.72253 .1598 L
.72318 .15981 L
.72389 .15982 L
.72465 .15984 L
.72595 .15988 L
.72732 .15994 L
.72977 .16007 L
.73214 .16023 L
.73434 .16042 L
.73935 .16095 L
.74441 .16166 L
.7499 .16261 L
.75984 .1648 L
.77844 .17047 L
.79836 .17863 L
.81942 .18935 L
.85735 .2132 L
.89775 .24333 L
.93662 .27522 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36178 L
.10458 .41672 L
.14415 .45819 L
.16408 .4745 L
.18221 .48653 L
.20178 .49648 L
.21254 .50059 L
.22272 .50359 L
.23241 .50565 L
.2373 .50639 L
.24012 .50672 L
.24269 .50697 L
.24504 .50715 L
.24728 .50728 L
.2485 .50733 L
.24964 .50737 L
.25088 .50739 L
.25158 .50741 L
.25221 .50741 L
.25336 .50741 L
.25442 .50741 L
.25558 .50739 L
.2568 .50735 L
.25787 .50732 L
.25887 .50727 L
.26113 .50714 L
.26373 .50694 L
.26614 .5067 L
.27158 .50599 L
.27638 .50516 L
.28148 .50407 L
.2903 .5017 L
.30004 .49835 L
.31939 .48951 L
.34024 .47686 L
.38138 .44339 L
.42101 .40266 L
.45912 .35859 L
.49968 .31013 L
.53872 .26562 L
.58022 .22428 L
.60102 .20685 L
.6202 .19306 L
.64007 .18126 L
.65867 .17261 L
.67743 .16628 L
.68738 .1639 L
.69293 .16286 L
.69807 .16209 L
Mistroke
.70298 .16151 L
.70549 .16128 L
.7082 .16107 L
.70976 .16098 L
.71119 .1609 L
.71253 .16084 L
.714 .16079 L
.71532 .16076 L
.71655 .16074 L
.71785 .16073 L
.71858 .16073 L
.71924 .16073 L
.72049 .16074 L
.72112 .16075 L
.72182 .16076 L
.72305 .16079 L
.7242 .16083 L
.72679 .16095 L
.72957 .16112 L
.73468 .16155 L
.73935 .16209 L
.74918 .16366 L
.75831 .16562 L
.77902 .17177 L
.79952 .18004 L
.81812 .18924 L
.85815 .21372 L
.89667 .24208 L
.93764 .27574 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0<oooooo00Co0000
ool00?oo003oo`003Ol0001Tooooo`008Oooool00ol0003oooooooooo`3;ooooo`Co00003_ooool6
ool000?o0000G_ooool0027ooooo0ol00038ooooo`?o00006?ooool3ool000?o0000Foooool0027o
oooo00?o0000ooooooooool0aOooool00ooo003o0000o`00000Nooooo`?oo`000_l0001Iooooo`00
8Oooool00ol0003oooooooooo`33ooooo`;oo`009?ooool3ool00003o`000?oooooooooo05Gooooo
000Qooooo`03o`000?oooooooooo0<3ooooo0ooo000Yooooo`03ool00?l0003o000005Gooooo000Q
ooooo`03o`000?oooooooooo0;gooooo0ooo00000ol0003oooooooooo`0/ooooo`;o0000Doooool0
00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Cooooo00?o0000ooooooooool0_?ooool00ooo003o0000o`00000booooo`?o0000D?oo
ool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`03ooooo`03o`000?oooooooooo0;[ooooo0_oo00000ol0003oooooooooo`0eooooo`;o0000C_oo
ool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_oo
ool3o`000;Wooooo00?oo`00o`000?l00000>_ooool2ool004cooooo0007ooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0;Sooooo00?o
o`00o`000?ooool0?Oooool00ooo003o0000ooooo`19ooooo`001oooool01Ol0003ooooooooooooo
oooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0;Oooooo
0_l00010ooooo`;oo`00BOooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0]_ooool00ol0003oooooooooo`12ooooo`03ool0
0?l0003ooooo04Kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo0;Cooooo0_l00016ooooo`;oo`0000?o0000ooooooooool0
@oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003ooooo
ooooo`2cooooo`03o`000?oooooooooo04Sooooo00?oo`00o`000?ooool0@oooool0027ooooo00?o
0000ooooooooool0/Oooool2o`0004cooooo0_oo00000ol0003oooooooooo`10ooooo`008Oooool0
0ol0003oooooooooo`2`ooooo`03o`000?oooooooooo04kooooo00?oo`00o`000?l00000@?ooool0
027ooooo0ol0002^ooooo`;oo`00D_ooool00ooo003oooooo`00000oooooo`008Oooool00ol0003o
ooooooooo`2]ooooo`03ool00?oooooooooo05?ooooo00?oo`00ooooool00000?_ooool0027ooooo
00?o0000ooooooooool0[?ooool00ooo003oooooooooo`1Gooooo`03o`000?oooooooooo03_ooooo
000Qooooo`03o`000?oooooooooo0:_ooooo00?oo`00ooooooooool0FOooool00ol0003ooooooooo
o`0jooooo`008Oooool00ol0003oooooooooo`2Zooooo`03ool00?oooooooooo05_ooooo0_l0000j
ooooo`008Oooool00ol0003oooooooooo`2Yooooo`03ool00?oooooooooo05kooooo00?o0000oooo
ooooool0=oooool0027ooooo00?o0000ooooooooool0Z?ooool00ooo003oooooooooo`1Pooooo`03
o`000?oooooooooo03Kooooo000Qooooo`?o0000Yoooool00ooo003oooooooooo`1Rooooo`;oo`00
=_ooool0027ooooo00?o0000ooooooooool0Y_ooool00ooo003oooooooooo`1Tooooo`03o`000?oo
003oo`0003Cooooo000Qooooo`03o`000?oooooooooo0:Gooooo00?oo`00ooooooooool0I_ooool2
o`000003ool00?oooooooooo037ooooo000Qooooo`03o`000?oooooooooo0:Cooooo00?oo`00oooo
ooooool0JOooool00ol0003oo`00ooooo`0aooooo`008Oooool00ol0003oooooooooo`2Sooooo`03
ool00?oooooooooo06_ooooo00?o0000ool00?ooool0<?ooool0027ooooo00?o0000ooooooooool0
X_ooool00ol0003oooooooooo`1]ooooo`03o`000?oo003ooooo02oooooo000Qooooo`03o`000?oo
oooooooo0:7ooooo00?o0000ooooooooool0Koooool00ol0003oo`00ooooo`0^ooooo`008Oooool0
0ol0003oooooooooo`2Pooooo`03o`000?oooooooooo077ooooo00?o0000ool00?ooool0;Oooool0
027ooooo0ol0002Oooooo`03o`000?oooooooooo07Cooooo00?oo`00ooooooooool0:oooool0027o
oooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo00Oooooo00?o0000
ooooooooool0<Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd0<?ooool00ooo003oooooooooo`0:ooooo`Go00006oooool0027ooooo00?o0000
ooooooooool0?Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo033ooooo00?oo`00ooooooooool02Ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A401_ooooo000Qooooo`03o`000?oooooooooo03gooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
1oooool00ooo003o0000ooooo`0eooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`09ooooo`03oiRHV?lQ8B7ok^k^01cooooo000Qooooo`03o`000?oo
oooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo03kooooo
00?o0000ooooooooool01oooool00ooo003oooooooooo`0eooooo`03o`000?oooooooooo00kooooo
00?oMgMgoc8b<_ooool0<_ooool2o`0000[ooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o
0000ooooooooool0?Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o
<S8bolc<c00oooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool0=_ooool00ol0003o
ooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0=Oooool00ol0003oooooooooo`08oooo
o`03ogMgMomVIVKooooo01[ooooo000Qooooo`03o`000?oooooooooo03gooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool01Oooool00ooo
003oooooooooo`0gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01Wooooo000Qooooo`?o0000?Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`04oooo
o`03ool00?oooooooooo03Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0ioooo
o`;o00001?ooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`03o`000?oooooooooo
03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000?_ooool00omEEEGoIVIVo`000005
ooooo`03ool00?oooooooooo03Oooooo00?oEEEEofIVI_l000003Oooool4o`0003[ooooo00Wo0000
oooooooooooooooooiRHV?l@413o0000ob4Q8Oo<c<`06oooool0027ooooo00?o0000ooooooooool0
Uoooool00ooo003o0000ooooo`27ooooo`;oo`008Oooool0027ooooo00?o0000ooooooooool0Uooo
ool00ooo003oooooooooo`28ooooo`03o`000?oo003ooooo01oooooo000Qooooo`03o`000?oooooo
oooo09Kooooo00?oo`00ooooooooool0R_ooool00ol0003oo`00ooooo`0Nooooo`008Oooool00ol0
003oooooooooo`2Eooooo`03ool00?oooooooooo08gooooo00?oo`00ooooooooool04_ooool2o`00
00;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`2Dooooo`03ool00?oooooooooo08oo
oooo00?oo`00ooooooooool04Oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooo
o`Oo000000?oo`00o`000?l00000Tol000000ooo003o0000o`00002Ao`000003ool00?l0003o0000
00Go00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool00ol0003oo`00ooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03ool00?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool01?o^k^ko8B4Qoa0@4?o^k^h5
ooooo`008Oooool2o`000003ool00?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Aooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03o`000?oooooo0000
097ooooo00?o0000ooooooooool0Y_ooool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003o
ooooo`00002@ooooo`03o`000?oooooooooo0;7ooooo000Qooooo`04o`000?ooooooooooo`0008ko
oooo00?o0000ooooooooool0/_ooool0027ooooo00Go0000ooooooooooooooooo`00002<ooooo`03
o`000?oooooooooo0;?ooooo000Qooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
R?ooool00ol0003oooooooooo`2dooooo`008Oooool3o`0000;ooooo00?o0000ooooooooool0Qooo
ool00ol0003oooooooooo`2eooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo08Gooooo00?o0000ooooooooool0]_ooool0027ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`24ooooo`03ool00?oooooooooo0;Kooooo000Qooooo`03o`000?oooooooooo00Co
oooo00?o0000ool00?ooool0Poooool00ooo003oooooooooo`2gooooo`008Oooool00ol0003ooooo
ooooo`05ooooo`03ool00?oooooooooo087ooooo00?oo`00ooooooooool0^?ooool0027ooooo00?o
0000ooooooooool01_ooool00ooo003oooooooooo`1oooooo`03ool00?oooooooooo0;Wooooo000Q
ooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool0OOooool00ooo003oooooooooo`2j
ooooo`008Oooool3o`0000Oooooo00?oo`00ooooooooool0O?ooool00ooo003oooooooooo`2koooo
o`008Oooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo07[ooooo00?oo`00oooooooo
ool0_?ooool0027ooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`1hooooo`03ool0
0?l0003ooooo0;gooooo000Qooooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool0Mooo
ool00ooo003o0000ooooo`2nooooo`008Oooool00ol0003oooooooooo`0:ooooo`03ool00?oooooo
oooo07Gooooo00?oo`00o`000?ooool0_oooool0027ooooo00?o0000ooooooooool02oooool00ooo
003oooooooooo`1cooooo`03ool00?l0003ooooo0<3ooooo000Qooooo`03o`000?oooooooooo00co
oooo00?oo`00ooooooooool0LOooool00ooo003o0000ooooo`31ooooo`008Oooool00ol0003ooooo
ooooo`0=ooooo`03ool00?oooooooooo073ooooo00?o0000ooooooooool0`Oooool0027ooooo0ol0
000>ooooo`03ool00?oooooooooo06kooooo00?o0000ooooooooool0`_ooool0027ooooo00?o0000
ooooooooool03_ooool00ol0003oo`00ooooo`1]ooooo`03o`000?oooooooooo0<?ooooo000Qoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`34oooo
o`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06Wooooo00?o0000oooooooo
ool0aOooool0027ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Wooooo`03o`00
0?oooooooooo0<Kooooo000Qooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0IOoo
ool00ol0003oooooooooo`37ooooo`008Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool0b?ooool0027ooooo0ol0000Cooooo`03o`000?oooooooooo
06?ooooo00?oo`00ooooooooool0b?ooool0027ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`1Qooooo`03ool00?oooooooooo0<Wooooo000Qooooo`03o`000?oooooooooo01Gooooo
00?oo`00ooooooooool0Goooool00ooo003oooooooooo`3:ooooo`008Oooool00ol0003ooooooooo
o`0Fooooo`03ool00?oooooooooo05gooooo00?oo`00ooooooooool0boooool0027ooooo00?o0000
ooooooooool05oooool00ooo003oooooooooo`1Kooooo`03ool00?oooooooooo0<cooooo0007oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@04ooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0F_ooool00ooo003ooooooooo
o`3=ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00?ooooo00?o0000ooooooooool06?ooool00ooo003oooooooooo`1Hooooo`03ool00?oo
oooooooo0<kooooo0007ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`02ooooo`?o00006Oooool00ooo003oooooooooo`1Fooooo`03ool00?oooooooooo0<oooooo0007
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oo
oooooooo01[ooooo00?oo`00ooooooooool0E?ooool00ooo003oooooooooo`3@ooooo`001oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`00
0?oooooooooo01_ooooo00?oo`00ooooooooool0D_ooool00ooo003oooooooooo`3Aooooo`001ooo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Looooo`03ool00?oooooooooo053ooooo00?oo`00ooooooooool0d_ooool000Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
7Oooool00ooo003oooooooooo`1>ooooo`03ool00?oooooooooo0=?ooooo0007ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool07_ooool00ooo003ooooo
ooooo`1;ooooo`;o0000e_ooool0027ooooo00?o0000ooooooooool07oooool00ooo003ooooooooo
o`19ooooo`03o`000?oooooooooo0=Kooooo000Qooooo`03o`000?oooooooooo023ooooo00?oo`00
ooooooooool0Aoooool00ol0003oooooooooo`3Gooooo`008Oooool3o`00027ooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`3Hooooo`008Oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool0fOooool0027ooooo00?o0000ooooooooool0
8oooool2o`00047ooooo0_l0003Looooo`008Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03gooooo0_oo003Mooooo`008Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo03_ooooo00?oo`00ooooooooool0gOooool0027ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0iooooo`03ool00?oooooooooo0=kooooo000Qooooo`03o`000?oooooooooo02So
oooo00?oo`00ooooooooool0=oooool00ooo003oooooooooo`3Oooooo`008Oooool3o`0002Wooooo
0_oo000fooooo`03ool00?oooooooooo0>3ooooo000Qooooo`03o`000?oooooooooo02_ooooo00?o
o`00ooooooooool0<Oooool2ool00>?ooooo000Qooooo`03o`000?oooooooooo02cooooo0_oo000`
ooooo`03ool00?oooooooooo0>?ooooo000Qooooo`03o`000?oooooooooo02kooooo00?oo`00oooo
ooooool0:oooool2ool00>Kooooo000Qooooo`03o`000?oooooooooo02oooooo0_oo000Zooooo`03
ool00?oooooooooo0>Kooooo000Qooooo`03o`000?oooooooooo037ooooo0_oo000Vooooo`;oo`00
jOooool0027ooooo00?o0000ooooooooool0<oooool2ool002;ooooo0_l0003[ooooo`008Oooool0
0ol0003oooooooooo`0eooooo`03ool00?l0003o000001gooooo0_l0003]ooooo`008Oooool3o`00
03Sooooo0ol0000Hooooo`;o0000koooool0027ooooo00?o0000ooooooooool0>oooool4o`0000ko
oooo0ooo0003o`000?7ooooo000Qooooo`03o`000?oooooooooo03oooooo00?o0000ool00?oo0000
2ooo0003o`000?Cooooo000Qooooo`03o`000?oooooooooo04;ooooo1ol0003kooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
6?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5ooooo`006_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
AOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000H
ooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00:Cooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2Wooooo`00Poooool3
o`0001Cooooo00?o8B4QomgMgOooool01_ooool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@413o
gMgM0:Oooooo001kooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP02ooooo`03o`000?oo
oooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03oiRHV?mEEEGooooo00Kooooo
00?oEEEEoiRHV?ooool00_ooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool01_nj^[[oA4A4
ooooooooooooQhN7ofIVIQGooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@1eooooo`00Noooool0
1ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00_ooool00ol0003oooooooooo`0;ooooo`05oa0@
4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ogMgMooooo`05ooooo`03o`000?oooooooooo00;o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj0_oo
ool00oo^k^ko0000ooooo`0;ooooo`Ko00001Oooool00ol0003oooooooooo`04ooooo`;o8B4Q1?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00Oo
0000oooooooMgMgo<S8booooooo^k^ko410@00;ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`06ooooo`;oMgMg1_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00co
oooo00Co410@omgMgOoooooo00001?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00[ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo07?ooooo001koooo
o`04oeEEEOnYZJWoooooo`0000;ooooo00Co0000oooooooooooo00003Oooool00ol0003ooooooooo
o`06ooooo`03onk^k_l@413ok^k^00Gooooo00?o<S8booooooooool01?ooool00onHV9So8B4Qonk^
kP0;ooooo`04ohN7QomVIVKoooooo`0000Cooooo00?o0000ooooooooool02_ooool6o`0000Gooooo
00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000Oooooo00?oMgMgoc8b<_oo
ool0M?ooool007_ooooo00?ogMgMob4Q8Oo^k^h00oooool01?l0003oooooo`000?l0000=ooooo`03
o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool00ol0003ok^k^ooooo`05ooooo`03
ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo00000oooool00oo^k^ko0000ooooo`0Foooo
o`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`0MOooool007cooooo00?oV9RHogMgMoooool00_ooool00ol0003oooooooooo`0<
ooooo`03oa0@4?l0003o000000?o00001_ooool00ooMgMgo410@ooooo`04ooooo`03oeEEEOmgMgOo
oooo00Kooooo00?o0000ooooooooool02?ooool7o`000003oooooomgMgOoEEEE01Oooooo00?o0000
ooooooooool02_ooool01Ol@413ooooooooooooooooo410@00Cooooo00?o0000ooooooooool0Mooo
ool009;ooooo00?o0000ooooooooool02?ooool00omEEEGoV9RHooooo`03ooooo`03omgMgOl@413o
k^k^00;ooooo00Go0000okZj^_ooooooV9RHoa0@400Aooooo`03onk^k_l@413ogMgM01Oooooo00?o
0000ooooooooool02_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool0
Moooool009;ooooo00?o0000ooooooooool02?ooool00onj^[[oA4A4ooooo`04ooooo`09ogMgMomV
IVKooooooooooonHV9So410@o`000?lQ8B7oc<c<017ooooo00?oIVIVogMgMoooool05Oooool00omE
EEGoIVIVo`00000<ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool4o`0007Kooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .34674 L
.10458 .38188 L
.12507 .39549 L
.14415 .40579 L
.16254 .41342 L
.17284 .41669 L
.18221 .41906 L
.18704 .42005 L
.19216 .42094 L
.19659 .42157 L
.20135 .42211 L
.20402 .42235 L
.20646 .42253 L
.20891 .42268 L
.21124 .42278 L
.21255 .42283 L
.21327 .42285 L
.21395 .42286 L
.21526 .42288 L
.21645 .4229 L
.21714 .4229 L
.21788 .4229 L
.21918 .42289 L
.21991 .42288 L
.22059 .42287 L
.22214 .42284 L
.2234 .4228 L
.22474 .42275 L
.22714 .42264 L
.22973 .42247 L
.23259 .42225 L
.2377 .42175 L
.24249 .42115 L
.25142 .41972 L
.26105 .41774 L
.28109 .41231 L
.30219 .40495 L
.34029 .38865 L
.38086 .36951 L
.4199 .35205 L
.43981 .34422 L
.4614 .33689 L
.48044 .3316 L
.49126 .32912 L
.50138 .32717 L
.51177 .32555 L
.52126 .3244 L
.52611 .32394 L
.5314 .32353 L
Mistroke
.5343 .32335 L
.53699 .32321 L
.53976 .32309 L
.5423 .323 L
.54478 .32294 L
.54602 .32292 L
.54739 .3229 L
.54811 .32289 L
.54877 .32288 L
.54952 .32288 L
.55024 .32288 L
.55151 .32288 L
.55223 .32288 L
.55289 .32288 L
.55408 .32289 L
.55519 .32291 L
.55642 .32293 L
.55773 .32296 L
.56041 .32303 L
.56286 .32312 L
.5672 .32332 L
.57194 .32361 L
.58148 .32439 L
.59178 .32552 L
.60113 .32679 L
.62209 .33029 L
.66213 .33857 L
.70065 .34658 L
.72017 .34997 L
.73052 .35147 L
.74162 .35282 L
.75228 .35382 L
.75734 .35419 L
.76202 .35447 L
.7667 .35469 L
.76917 .35478 L
.7718 .35486 L
.77407 .35491 L
.77511 .35493 L
.7762 .35495 L
.77743 .35496 L
.77855 .35497 L
.77975 .35497 L
.78107 .35497 L
.78239 .35497 L
.7836 .35496 L
.78424 .35495 L
.78494 .35495 L
.78635 .35492 L
.78892 .35487 L
Mistroke
.79133 .3548 L
.79583 .35463 L
.80066 .35437 L
.80627 .35399 L
.8116 .35354 L
.8216 .35248 L
.84142 .34953 L
.85981 .34587 L
.89896 .33553 L
.94057 .32184 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .34994 L
.10458 .3822 L
.12507 .3944 L
.14415 .40388 L
.16254 .41125 L
.18221 .41715 L
.19242 .41937 L
.19781 .42031 L
.20351 .42112 L
.2085 .42168 L
.21114 .42191 L
.21399 .42212 L
.21659 .42228 L
.21898 .42238 L
.22012 .42242 L
.22137 .42245 L
.22256 .42248 L
.22365 .42249 L
.22494 .4225 L
.22559 .4225 L
.2263 .4225 L
.22756 .42249 L
.22873 .42247 L
.22944 .42245 L
.23012 .42244 L
.23138 .4224 L
.23422 .42228 L
.2367 .42214 L
.23899 .42198 L
.24418 .4215 L
.24846 .421 L
.2532 .42032 L
.26278 .4186 L
.28213 .4137 L
.30299 .40654 L
.34413 .38818 L
.38375 .36806 L
.42186 .3497 L
.44311 .34093 L
.46242 .33426 L
.47206 .33146 L
.4825 .32886 L
.4923 .32683 L
.50147 .32529 L
.51093 .32408 L
.51595 .3236 L
.52134 .32319 L
.52404 .32303 L
.52698 .32289 L
Mistroke
.52976 .32278 L
.53109 .32275 L
.53234 .32272 L
.53356 .32269 L
.53421 .32269 L
.53489 .32268 L
.5361 .32267 L
.5372 .32266 L
.53848 .32266 L
.53967 .32267 L
.54098 .32268 L
.54172 .32269 L
.54238 .3227 L
.54468 .32275 L
.54721 .32282 L
.54985 .32293 L
.55232 .32305 L
.56151 .32367 L
.56673 .32414 L
.57151 .32464 L
.58228 .326 L
.62196 .33302 L
.66012 .34097 L
.68141 .3451 L
.70073 .3483 L
.71039 .34965 L
.72086 .35089 L
.73066 .35183 L
.73983 .3525 L
.74441 .35276 L
.74932 .35298 L
.75212 .35308 L
.75477 .35316 L
.75715 .35321 L
.75849 .35323 L
.75974 .35325 L
.76095 .35327 L
.76226 .35328 L
.76297 .35328 L
.76371 .35328 L
.76435 .35328 L
.76504 .35328 L
.76578 .35328 L
.76645 .35328 L
.76723 .35328 L
.76796 .35327 L
.76926 .35326 L
.77068 .35324 L
.77323 .3532 L
.77594 .35313 L
Mistroke
.7808 .35297 L
.78572 .35275 L
.79022 .35249 L
.80035 .35174 L
.80974 .35084 L
.81865 .3498 L
.85687 .3435 L
.87656 .33919 L
.89753 .33385 L
.93914 .32124 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`3ooooooc_ooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0003o00000?oo0000<?l0
000<ooooo`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oo003ooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02?ooool3o`000003ooooool0003ooooo01;ooooo00Cok^k^ob4Q8Ol@413ok^k^
1Oooool0027ooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`?o00001?oo
ool00ol0003oooooooooo`0Aooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`04o`000?oo
ooooooooo`000?oooooo7?ooool2ool000;o00006_ooool2o`0000;ooooo0_l00004ooooo`008Ooo
ool01Ol0003ooooooooooooooooo00000?oooooo6?ooool3ool00003o`000?oooooooooo02Gooooo
000Qooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0TOooool7ool000[o00001?oo
0004o`0006Oooooo0ooo0002o`0002Wooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0Roooool7o`0001?ooooo1Ooo0006o`0005gooooo0ooo0002o`0002cooooo000Qoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0POooool5ool000Co00007oooool5ool0
0003ooooool0003o000000?o0000EOooool3ool000;o0000;oooool0027ooooo0ol00005ooooo`03
o`000?oooooooooo07gooooo0ooo0003o`0002[ooooo0_oo0004ooooo`Go0000C_ooool2ool000?o
0000<Oooool0027ooooo00?o0000ooooooooool01Oooool00ooo003o0000ooooo`1jooooo`?oo`00
0ol0000hooooo`Co0000BOooool3o`0003Cooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o
o`00o`000?ooool0M_ooool3ool000;o0000?Oooool6ool000;o0000?oooool5o`0003Oooooo000Q
ooooo`03o`000?oooooooooo00Oooooo00?oo`00o`000?ooool0M?ooool00ooo003o0000o`000016
ooooo`?oo`001Ol0000`ooooo`Koo`000ol0000looooo`008Oooool00ol0003oooooooooo`08oooo
o`03ool00?l0003o0000077ooooo00?o0000ool00?ooool0Boooool5ool000Ko00009?ooool6ool0
0003ooooool0003o000000;o0000@?ooool0027ooooo00?o0000ooooooooool02Oooool2ool00003
o`000?oooooooooo06cooooo0_l0001Cooooo`;oo`001?ooool5o`0001[ooooo1Ooo00000ooooooo
0000o`000004o`0004Cooooo000Qooooo`03o`000?oooooooooo00_ooooo00?oo`00o`000?ooool0
J_ooool2o`00063ooooo00?o0000ool00?oo00003_oo0006ooooo`Wo0000B_ooool0027ooooo0ol0
000<ooooo`03ool00?l0003ooooo06Kooooo0ol0001/ooooo`go0000Doooool0027ooooo00?o0000
ooooooooool03Oooool2ool00003o`000?oooooooooo063ooooo0_oo00000ol0003oooooooooo`3=
ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03ool00?l0003ooooo05kooooo0_oo00000ol0
003oooooooooo`3?ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03ool00?l0003ooooo05_o
oooo00?o0000ool00?l00000doooool0027ooooo00?o0000ooooooooool04Oooool00ooo003o0000
o`00001Hooooo`03o`000?oo003oo`000=Gooooo000Qooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0Doooool00ol0003oo`00ool0003Gooooo`008Oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo053ooooo0ooo003Iooooo`008Oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo04cooooo00?o0000ool00?oo0000g?ooool0027ooooo0ol0000Gooooo`;o
0000B_ooool2o`000003ool00?oooooooooo0=cooooo000Qooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool0AOooool2o`000>7ooooo000Qooooo`03o`000?oooooooooo01[ooooo0_oo
0013ooooo`;o0000hoooool0027ooooo00?o0000ooooooooool07?ooool00ooo003oooooooooo`0m
ooooo`?o0000iOooool0027ooooo00?o0000ooooooooool07Oooool2ool003_ooooo0_l0003Xoooo
o`008Oooool00ol0003oooooooooo`0Oooooo`;oo`00=oooool2o`0000;oo`00j?ooool0027ooooo
00?o0000ooooooooool08?ooool00ol0003oo`00ool0000booooo`?o00000_oo003Zooooo`008Ooo
ool3o`0002;ooooo00?o0000ool00?oo0000;_ooool2o`000003oooooooo003oo`000>cooooo000Q
ooooo`03o`000?oooooooooo02?ooooo0_l00003ool002Wooooo0_l00003ool00>kooooo000Qoooo
o`03o`000?oooooooooo02Kooooo0_l000000ooo003oooooooooo`0Tooooo`04o`000?oo003oo`00
ool00?7ooooo000Qooooo`03o`000?oooooooooo02Wooooo0ol0000Oooooo`03o`000?oo003oo`00
00;oo`00m?ooool0027ooooo00?o0000ooooooooool0;?ooool3o`0001Oooooo1Ol0003iooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01?ooool00ol0003oooooooooo`0_ooooo`?o00001Ooo000:ooooo`Go0000o_ooool000Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03oooo
o`03o`000?oooooooooo03?ooooo1?l0000<ool00?oooooo0_ooool000Oooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0003oooooodGooooo0007ooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo
0?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooAOooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooo
oooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooo
odGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`00
6_ooool00ol0003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo002Xooooo`03ogMgMomVIVKooooo01Oooooo00?oIVIVogMg
Moooool0Xoooool008Oooooo0ol0000Cooooo`03ob4Q8OoMgMgooooo00Oooooo00?ogMgMoa0@4?o^
k^h06?ooool00oo^k^ko410@omgMg@2Sooooo`00O_ooool01on7QhOo0000oeEEEOmVIVKo0000oc8b
<_o^k^h00oooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool0
0onHV9SoEEEEooooo`07ooooo`04oeEEEOnHV9Soooooooooo`Go00002Oooool00omEEEGoZJVYoooo
o`02ooooo`03okZj^_m4A4Cooooo00;ooooo00?oQhN7ofIVI_ooool04oooool4o`000003oa0@4?oo
oooooooo00;ooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool0N?ooool007kooooo00Oo410@
omgMgOmgMgOo8B4Qoooooon7QhOoIVIV00?ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zj
onk^k_mgMgOo410@00?ooooo00?o0000omgMgOooool01_ooool02Ol0003oooooooooooooooooV9RH
ob4Q8Oo^k^koooooodA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj0oooool00oo^k^ko
0000ooooo`0;ooooo`Ko00001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1oooool00ol0003o
ooooooooo`1jooooo`00O_ooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@41000oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo0_mgMgL7ooooo`03oc8b<_oooooooooo
00;ooooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool00005ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1jooooo`00O_ooool01?mE
EEGoZJVYooooool00002ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003ooooooooo
o`05ooooo`03onk^k_l@413ok^k^00Kooooo00?o<S8booooooooool00oooool00onHV9So8B4Qonk^
kP0;ooooo`04ohN7QomVIVKoooooo`0000Gooooo00?o0000ooooooooool02_ooool6o`0000Cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`1jooooo`00O_ooool00ooMgMgo8B4Qonk^
kP03ooooo`03o`000?oooooooooo00;o00003Oooool00ol0003oooooooooo`06ooooo`03oeEEEOnH
V9Sooooo00Gooooo00?o0000onk^k_ooool01?ooool00omgMgOoIVIVooooo`0:ooooo`04omgMgOl@
413oooooo`0000Cooooo00?ok^k^o`000?ooool05Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo07[ooooo001oooooo`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool03Ooo
ool00ol@413o0000o`000003o`0000Gooooo00?ogMgMoa0@4?ooool01Oooool00omEEEGoMgMgoooo
o`05ooooo`03o`000?oooooooooo00Sooooo1ol00002ooooo`03ogMgMomEEEGooooo01Gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`1jooooo`00U_ooool00ol0003oooooooooo`07
ooooo`03oeEEEOnHV9Sooooo00Cooooo00WogMgMoa0@4?o^k^koooooo`000?nj^[[ooooooiRHV?l@
41004_ooool00oo^k^ko410@omgMg@0Fooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0N_ooool009Kooooo00?o0000ooooooooool01oooool00onj^[[oA4A4ooooo`05ooooo`08ogMg
MomVIVKooooooiRHV?l@413o0000ob4Q8Oo<c<`Booooo`03ofIVI_mgMgOooooo01Cooooo00?oEEEE
ofIVI_l000003Oooool00omEEEGoIVIVo`00001looooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .3145 L
.06244 .31971 L
.08255 .32387 L
.08806 .32475 L
.09396 .32557 L
.09948 .3262 L
.10458 .32667 L
.10954 .32702 L
.11204 .32716 L
.1148 .32728 L
.11621 .32732 L
.11755 .32736 L
.1183 .32738 L
.1191 .32739 L
.11985 .3274 L
.12052 .32741 L
.12121 .32742 L
.12187 .32743 L
.12256 .32743 L
.1233 .32743 L
.12396 .32743 L
.12465 .32742 L
.12589 .32741 L
.12714 .3274 L
.12828 .32737 L
.13085 .3273 L
.13323 .32721 L
.13549 .32711 L
.14053 .32679 L
.14603 .32633 L
.15542 .32528 L
.1658 .32374 L
.18681 .31964 L
.22701 .30942 L
.2657 .29954 L
.28574 .29559 L
.29582 .29411 L
.30149 .29345 L
.30684 .29296 L
.31177 .29262 L
.31455 .29248 L
.31587 .29242 L
.31711 .29238 L
.31824 .29235 L
.31927 .29232 L
.32042 .2923 L
.32165 .29229 L
.32283 .29228 L
.32411 .29228 L
Mistroke
.32532 .29229 L
.32645 .2923 L
.32777 .29233 L
.32919 .29237 L
.33177 .29246 L
.33429 .29259 L
.3366 .29274 L
.34185 .29319 L
.3474 .29383 L
.3569 .29535 L
.36708 .29757 L
.38542 .30316 L
.4067 .31223 L
.42684 .3233 L
.46522 .35047 L
.50605 .3859 L
.54537 .42262 L
.58317 .45612 L
.60419 .47252 L
.62343 .48552 L
.64351 .49663 L
.66217 .50447 L
.67134 .50738 L
.68113 .50979 L
.68672 .51083 L
.69199 .5116 L
.69672 .5121 L
.69939 .51231 L
.70065 .51239 L
.70184 .51246 L
.70302 .51251 L
.7043 .51255 L
.70546 .51258 L
.70653 .5126 L
.70769 .51261 L
.70897 .51261 L
.70961 .5126 L
.71031 .5126 L
.71156 .51257 L
.71267 .51254 L
.71387 .51249 L
.7163 .51236 L
.71855 .5122 L
.72065 .51202 L
.72587 .51142 L
.73063 .51069 L
.7413 .50846 L
.75127 .50561 L
.76046 .50237 L
.78125 .49291 L
Mistroke
.82062 .46766 L
.85848 .43578 L
.89878 .39569 L
.93757 .35318 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .31783 L
.08255 .32215 L
.0932 .32407 L
.10458 .32572 L
.11009 .32635 L
.11531 .32682 L
.11999 .32716 L
.12263 .3273 L
.12507 .32741 L
.12616 .32745 L
.12734 .32749 L
.12836 .32751 L
.12947 .32754 L
.13077 .32756 L
.13201 .32757 L
.13321 .32757 L
.13433 .32757 L
.13561 .32756 L
.13682 .32755 L
.13791 .32753 L
.13908 .3275 L
.14172 .32742 L
.14415 .32731 L
.14885 .32703 L
.15389 .32662 L
.16298 .32558 L
.17378 .32391 L
.18364 .32199 L
.22348 .31151 L
.26181 .30033 L
.28159 .29555 L
.29157 .29364 L
.29694 .29278 L
.3026 .29201 L
.30742 .29148 L
.30997 .29125 L
.31269 .29104 L
.3152 .29088 L
.31748 .29077 L
.31858 .29072 L
.31978 .29068 L
.32082 .29065 L
.32194 .29063 L
.32324 .29061 L
.32445 .2906 L
.32519 .2906 L
.3259 .2906 L
.32721 .29061 L
.32789 .29062 L
Mistroke
.3286 .29064 L
.32988 .29067 L
.33141 .29072 L
.33279 .29078 L
.33527 .29091 L
.33795 .2911 L
.3428 .29155 L
.34773 .29216 L
.35233 .29288 L
.36278 .29503 L
.37296 .29782 L
.38385 .30158 L
.40514 .31116 L
.42527 .32281 L
.46365 .35089 L
.50448 .38643 L
.5438 .42231 L
.58161 .45462 L
.60262 .47044 L
.62186 .48308 L
.64194 .49405 L
.6606 .50197 L
.66977 .50501 L
.67956 .5076 L
.68515 .50878 L
.69042 .50968 L
.69515 .51033 L
.69763 .5106 L
.70028 .51084 L
.70284 .51102 L
.70518 .51114 L
.70631 .51119 L
.70754 .51123 L
.70869 .51126 L
.70977 .51127 L
.711 .51128 L
.71217 .51128 L
.71344 .51127 L
.71416 .51125 L
.71482 .51124 L
.71607 .5112 L
.71744 .51114 L
.72019 .51099 L
.72295 .51078 L
.72546 .51055 L
.7311 .50984 L
.73632 .50899 L
.74125 .508 L
.75095 .50553 L
.76124 .50219 L
Mistroke
.77968 .49435 L
.79923 .48358 L
.81754 .47134 L
.85633 .43934 L
.89757 .39818 L
.9373 .35412 L
.97551 .30981 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo05?ooooo00?o0000ool00?oo00002?oo0004o`000>;ooooo000Qooooo`03
o`000?oooooooooo04cooooo1ol0000?ooooo`Go00000ooo003Jooooo`008Oooool00ol0003ooooo
ooooo`17ooooo`;o00000_oo00000ol0003oooooooooo`0Jooooo`;o00000ooo003Gooooo`008Ooo
ool00ol0003oooooooooo`13ooooo`?o00000ooo000Rooooo`;o00000ooo003:ooooo`;o00000_oo
ool2o`0000Cooooo000Qooooo`03o`000?oooooooooo03oooooo0ol00004ool002Sooooo0_l00002
ool00<Sooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_oooom8o`0000Coo`00<?l0
0002ool00;?o000000?oo`00o`000?l000001Ol0000<ooooo`04omgMgOl0003o410@olc<c0Gooooo
000Qooooo`03o`000?oooooooooo00?o00002Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool3o`0000?oo`002_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool2ool00003o`000?oo
oooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03ool00?oo
oooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ooooooooool00ooo
ool3o`0000?oo`000oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02?ooool3o`000003ooooool0003ooooo00gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooo003o0000
2oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0_l0000Cooooo`04ob4Q
8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03o`000?oooooooooo00Kooooo0ol00005ool002Cooooo
0ol00013ooooo`;o0000Zoooool00ol0003oooooooooo`0Booooo`;o00000_ooool2o`0000Cooooo
000Qooooo`03o`000?oooooooooo00Wooooo1Ol00005ool001[ooooo00Go0000ool00?oo003oo`00
o`000018ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool07Oooool0027ooooo00?o
0000ooooooooool03_ooool5o`0000Coo`003_ooool6o`0000?oo`00COooool2o`000:Kooooo00?o
0000ooooooooool07_ooool0027ooooo00?o0000ooooooooool04oooool>o`0000[oo`00D_ooool0
0ol0003oooooooooo`2Rooooo`03o`000?oooooooooo01oooooo000Qooooo`03o`000?oooooooooo
07kooooo0_l0002Qooooo`03o`000?oooooooooo023ooooo000Qooooo`?o0000Ooooool2ool00:3o
oooo00?o0000ooooooooool08?ooool0027ooooo00?o0000ooooooooool0POooool00ooo003o0000
ooooo`2Kooooo`03ool00?l0003ooooo02;ooooo000Qooooo`03o`000?oooooooooo08;ooooo0_oo
002Kooooo`03ool00?oooooooooo02;ooooo000Qooooo`03o`000?oooooooooo08Cooooo0_oo002H
ooooo`03ool00?oooooooooo02?ooooo000Qooooo`03o`000?oooooooooo08Kooooo00?oo`00oooo
ooooool0U?ooool00ooo003oooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`27ooooo`03
ool00?l0003ooooo09;ooooo00?oo`00ooooooooool09Oooool0027ooooo00?o0000ooooooooool0
R?ooool00ooo003o0000ooooo`2@ooooo`03ool00?oooooooooo02Kooooo000Qooooo`?o0000ROoo
ool00ooo003o0000ooooo`2?ooooo`03ool00?oooooooooo02Kooooo000Qooooo`03o`000?oooooo
oooo08[ooooo00?oo`00o`000?ooool0SOooool00ooo003oooooooooo`0Wooooo`008Oooool00ol0
003oooooooooo`2;ooooo`03ool00?l0003ooooo08_ooooo00?oo`00ooooooooool0:?ooool0027o
oooo00?o0000ooooooooool0SOooool2o`0008Wooooo00?oo`00ooooooooool0:Oooool0027ooooo
00?o0000ooooooooool0Soooool00ol0003oooooooooo`25ooooo`03ool00?oooooooooo02[ooooo
000Qooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0Poooool00ooo003ooooooooo
o`0[ooooo`008Oooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo087ooooo00?oo`00
ooooooooool0;?ooool0027ooooo00?o0000ooooooooool0T_ooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooooooo02gooooo000Qooooo`?o0000Toooool00ol0003oooooooooo`1mooooo`03
o`000?oooooooooo02kooooo000Qooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool0
Noooool00ol0003oooooooooo`0_ooooo`008Oooool00ol0003oooooooooo`2Cooooo`;oo`0000?o
0000ooooooooool0NOooool00ol0003oooooooooo`0`ooooo`008Oooool00ol0003oooooooooo`2E
ooooo`03ool00?l0003ooooo07Sooooo00?o0000ooooooooool0<Oooool0027ooooo00?o0000oooo
ooooool0U_ooool00ooo003o0000ooooo`1fooooo`03o`000?oooooooooo03;ooooo000Qooooo`03
o`000?oooooooooo09Oooooo00?oo`00o`000?ooool0M?ooool00ol0003oooooooooo`0cooooo`00
8Oooool00ol0003oooooooooo`2Hooooo`03ool00?l0003ooooo07;ooooo00?o0000ool00?ooool0
=?ooool0027ooooo0ol0002Iooooo`;oo`00LOooool00ol0003oo`00ooooo`0eooooo`008Oooool0
0ol0003oooooooooo`2Kooooo`03ool00?oooooooooo06gooooo00?o0000ool00?ooool0=_ooool0
027ooooo00?o0000ooooooooool0W?ooool00ooo003oooooooooo`1[ooooo`03o`000?oo003ooooo
03Oooooo000Qooooo`03o`000?oooooooooo09gooooo00?oo`00ooooooooool0JOooool00ol0003o
o`00ooooo`0hooooo`008Oooool00ol0003oooooooooo`2Nooooo`03ool00?oooooooooo06Oooooo
00?o0000ool00?ooool0>Oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0Woooool00ooo003o
ooooooooo`1Uooooo`03o`000?oo003ooooo03[ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2Pooooo`;o
0000I?ooool00ol0003oo`00ooooo`0kooooo`001oooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00_ooool3o`000:;ooooo00?o0000ooooooooool0H?ooool00ol0003o
o`00ooooo`0looooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo05kooooo00?o0000ool00?oo
ool0?Oooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01?ooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo05cooooo00?o0000ool0
0?ooool0?_ooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0YOooool00ol0003oooooooooo`1Iooooo`;o000000?oo`00oooo
ooooool0?_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0Y_ooool2o`0005Sooooo00?o0000ooooooooool0@Oooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`2Woooo
o`;oo`00E_ooool00ol0003oooooooooo`12ooooo`008Oooool00ol0003oooooooooo`2Yooooo`03
ool00?oooooooooo05;ooooo00?o0000ooooooooool0@oooool0027ooooo00?o0000ooooooooool0
Z_ooool00ooo003oooooooooo`1@ooooo`03o`000?oooooooooo04Cooooo000Qooooo`?o0000Zooo
ool00ooo003oooooooooo`1=ooooo`;o0000Aoooool0027ooooo00?o0000ooooooooool0[?ooool2
ool004cooooo00?o0000ooooooooool0Aoooool0027ooooo00?o0000ooooooooool0[_ooool00ooo
003oooooooooo`18ooooo`;oo`00BOooool0027ooooo00?o0000ooooooooool0[oooool00ooo003o
0000ooooo`16ooooo`03ool00?oooooooooo04Wooooo000Qooooo`03o`000?oooooooooo0;3ooooo
00?oo`00o`000?ooool0A?ooool00ooo003oooooooooo`1:ooooo`008Oooool00ol0003ooooooooo
o`2aooooo`03ool00?l0003ooooo047ooooo00?o0000ool00?ooool0C?ooool0027ooooo00?o0000
ooooooooool0/_ooool2ool00003o`000?oooooooooo03gooooo0_oo001>ooooo`008Oooool3o`00
0;Cooooo00?oo`00o`000?ooool0>oooool00ol0003oo`00ooooo`1?ooooo`008Oooool00ol0003o
ooooooooo`2fooooo`;o0000>Oooool00ol0003oo`00ooooo`1@ooooo`008Oooool00ol0003ooooo
ooooo`2hooooo`03o`000?oooooooooo03Cooooo0_l000000ooo003oooooooooo`1@ooooo`008Ooo
ool00ol0003oooooooooo`2iooooo`;o0000<oooool00ol0003oo`00ool0001Cooooo`008Oooool0
0ol0003oooooooooo`2kooooo`03o`000?oooooooooo02kooooo0_l000000ooo003oooooooooo`1C
ooooo`008Oooool00ol0003oooooooooo`2looooo`03o`000?oo003ooooo02cooooo00?o0000oooo
ooooool0E_ooool0027ooooo00?o0000ooooooooool0__ooool2ool002Wooooo0_l0001Iooooo`00
8Oooool00ol0003oooooooooo`2oooooo`03o`000?oo003oo`0002Cooooo0ol0001Kooooo`008Ooo
ool3o`000<;ooooo0_oo00000ol0003oooooooooo`0Mooooo`;o0000G_ooool0027ooooo00?o0000
ooooooooool0a?ooool3ool00003o`000?oooooooooo01Sooooo0ooo001Oooooo`008Oooool00ol0
003oooooooooo`37ooooo`Goo`004Oooool5ool006;ooooo000Qooooo`03o`000?oooooooooo0<_o
oooo00?o0000ool00?l000002?ooool7ool000;o0000IOooool0027ooooo00?o0000ooooooooool0
c_ooool<o`0006[ooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool4o`00
0003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo0ol0
003oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5
ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`03oeEE
EOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Co
oooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2Wooooo`00Poooool3o`0001Cooooo
00?o8B4QomgMgOooool01_ooool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@413ogMgM0:Oooooo
001kooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo00_o
oooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03oiRHV?mEEEGooooo00Kooooo00?oEEEEoiRH
V?ooool00_ooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool01_nj^[[oA4A4oooooooooooo
QhN7ofIVIQGooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`1dooooo`00Noooool01ol@413ogMgMogMg
MolQ8B7oooooohN7QomVIVH00_ooool00ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMg
Mol@41001?ooool00ol0003ogMgMooooo`05ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q
8Oo^k^koooooodA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj0_ooool00oo^k^ko0000
ooooo`0;ooooo`Ko00001Oooool00ol0003oooooooooo`04ooooo`;o8B4Q1oooool00ol0003ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo07Cooooo001kooooo`07o`000?oooooogMgMoc8b<_oooooo
k^k^oa0@4002ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool2ogMgM`Ko
oooo00?o<S8booooooooool00oooool00onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`00
00Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0Loooool007_ooooo00CoEEEEojVYZOoooooo00000_ooool01?l0
003oooooooooool0000=ooooo`03o`000?oooooooooo00Kooooo00?ok^k^oa0@4?o^k^h01Oooool0
0olb<S;oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001?oo
ool00ol0003oooooooooo`0:ooooo`Ko00001Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Kooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00?ogMgMob4Q8Oo^k^h00oooool0
1?l0003oooooo`000?l0000=ooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?oo
ool00ol0003ok^k^ooooo`05ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo0000
0oooool00oo^k^ko0000ooooo`0Fooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<07Gooooo001looooo`03oiRHV?mgMgOooooo00;ooooo
00?o0000ooooooooool03?ooool00ol@413o0000o`000003o`0000Kooooo00?ogMgMoa0@4?ooool0
1?ooool00omEEEGoMgMgooooo`06ooooo`03o`000?oooooooooo00Sooooo1ol000000oooooooMgMg
oeEEE@0Gooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1gooooo`00T_ooool00ol0003oooooooooo`08ooooo`03oeEEEOnHV9Sooooo00?ooooo00?o
gMgMoa0@4?o^k^h00_ooool01Ol0003o^[ZjoooooonHV9So410@017ooooo00?ok^k^oa0@4?oMgMd0
5oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Moooool009;ooooo00?o0000ooooooooool02?ooool00onj^[[oA4A4ooooo`04ooooo`09ogMgMomV
IVKooooooooooonHV9So410@o`000?lQ8B7oc<c<017ooooo00?oIVIVogMgMoooool05Oooool00omE
EEGoIVIVo`00000=ooooo`03oeEEEOmVIVKo000000Gooooo1?l0001fooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28407 L
.10458 .25647 L
.14415 .23164 L
.18221 .21149 L
.20178 .20371 L
.21274 .20037 L
.21758 .19916 L
.22272 .19807 L
.22745 .19724 L
.22997 .19687 L
.23267 .19653 L
.23515 .19627 L
.23742 .19608 L
.2397 .19593 L
.24081 .19588 L
.24186 .19583 L
.24317 .19579 L
.24436 .19577 L
.24563 .19575 L
.24635 .19575 L
.24702 .19575 L
.24813 .19577 L
.24934 .1958 L
.25061 .19584 L
.2518 .19589 L
.25454 .19607 L
.25703 .19628 L
.25992 .1966 L
.26265 .19698 L
.26724 .19777 L
.2723 .19887 L
.28256 .20187 L
.29206 .20557 L
.30098 .20986 L
.32116 .22248 L
.33966 .23753 L
.37929 .27995 L
.4174 .33086 L
.45796 .3902 L
.497 .44592 L
.5385 .49726 L
.5593 .51843 L
.57848 .5348 L
.59836 .54837 L
.61695 .5579 L
.62599 .56142 L
.63571 .5644 L
.64124 .56573 L
.6465 .56674 L
Mistroke
.65121 .56745 L
.65389 .56777 L
.65635 .56801 L
.65891 .5682 L
.66023 .56828 L
.66168 .56835 L
.66294 .5684 L
.66412 .56843 L
.66536 .56845 L
.66606 .56846 L
.6667 .56846 L
.6679 .56846 L
.669 .56844 L
.67022 .56841 L
.67151 .56837 L
.67263 .56832 L
.67368 .56827 L
.67606 .56811 L
.67863 .5679 L
.68134 .56761 L
.68617 .56695 L
.69137 .56604 L
.69705 .56482 L
.70735 .56197 L
.7167 .55873 L
.73766 .54927 L
.7777 .52363 L
.81621 .49104 L
.85719 .44981 L
.89664 .4055 L
.93458 .36018 L
.97497 .31052 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .28165 L
.10458 .25635 L
.14415 .23311 L
.18221 .21278 L
.20178 .20445 L
.21267 .20076 L
.22272 .19809 L
.22758 .19707 L
.23293 .19618 L
.23553 .19583 L
.23832 .19552 L
.23985 .19538 L
.24126 .19526 L
.2426 .19518 L
.24402 .1951 L
.24536 .19504 L
.24658 .19501 L
.24781 .19499 L
.24896 .19498 L
.24961 .19498 L
.25031 .19499 L
.25155 .19501 L
.25224 .19503 L
.25288 .19505 L
.25435 .19511 L
.25562 .19518 L
.25683 .19527 L
.25908 .19546 L
.26152 .19573 L
.26416 .19608 L
.26901 .19692 L
.27356 .19793 L
.28394 .20104 L
.29405 .20516 L
.30494 .21083 L
.32498 .22451 L
.34608 .24326 L
.38419 .28677 L
.42475 .34253 L
.4638 .39954 L
.5053 .45708 L
.54528 .50409 L
.58374 .53802 L
.60362 .5506 L
.61377 .55568 L
.62466 .56012 L
.63489 .56334 L
.64424 .56549 L
.64873 .56626 L
Mistroke
.65111 .56659 L
.65363 .5669 L
.65606 .56715 L
.65826 .56733 L
.66047 .56747 L
.66255 .56756 L
.66372 .5676 L
.66497 .56763 L
.66615 .56765 L
.66722 .56765 L
.66848 .56764 L
.66919 .56764 L
.66985 .56762 L
.67106 .56759 L
.67234 .56755 L
.67488 .56742 L
.67725 .56725 L
.67986 .56702 L
.68267 .56671 L
.68737 .56605 L
.69232 .56518 L
.70115 .56318 L
.71072 .56038 L
.72093 .5567 L
.73931 .54834 L
.78086 .52197 L
.8209 .48802 L
.85942 .44886 L
.90039 .4021 L
.93984 .35429 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`0mooooo`Ooo`001Ol0003kooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0gooooo`?o00000ooo000<ooooo`Co00000_oo
003eooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0dooooo`?o00000ooo000Dooooo`04o`000?oo003oo`00ool00?;ooooo
0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0
<_ooool2o`0000?oo`006_ooool00ol0003oo`00ool0003`ooooo`008Oooool00ol0003ooooooooo
o`0`ooooo`;o00008_ooool00ooo003o0000ooooo`3]ooooo`008Oooool00ol0003oooooooooo`0^
ooooo`;o00009Oooool2ool00>gooooo000Qooooo`?o0000;?ooool2o`0002Wooooo00?oo`00o`00
0?ooool0j_ooool0027ooooo00?o0000ooooooooool0:_ooool2o`0002cooooo0_oo003Zooooo`00
8Oooool00ol0003oooooooooo`0Xooooo`03o`000?oo003oo`0002oooooo00?oo`00o`000?ooool0
ioooool0027ooooo00?o0000ooooooooool09_ooool00ol0003oo`00ool0000booooo`03ool00?l0
003ooooo0>Kooooo000Qooooo`03o`000?oooooooooo02Cooooo0_l000000ooo003oooooooooo`0d
ooooo`03o`000?oooooooooo0>Cooooo000Qooooo`03o`000?oooooooooo02;ooooo0_l00002ool0
03Sooooo00?o0000ooooooooool0hoooool0027ooooo00?o0000ooooooooool08Oooool00ol0003o
o`00ool0000kooooo`03o`000?oooooooooo0>;ooooo000Qooooo`?o00007oooool00ol0003oo`00
ool0000nooooo`03o`000?oooooooooo0>7ooooo000Qooooo`03o`000?oooooooooo01kooooo00?o
0000ool00?ooool0?oooool00ol0003oooooooooo`3Qooooo`008Oooool00ol0003oooooooooo`0L
ooooo`03o`000?oo003oo`0004;ooooo00?o0000ooooooooool0h?ooool0027ooooo00?o0000oooo
ooooool06oooool00ol0003oo`00ooooo`14ooooo`03o`000?oo003ooooo0=oooooo000Qooooo`03
o`000?oooooooooo01Wooooo0_l00018ooooo`03ool00?oooooooooo0=kooooo000Qooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0BOooool00ooo003oooooooooo`3Mooooo`008Ooo
ool00ol0003oooooooooo`0Fooooo`;o0000COooool00ooo003oooooooooo`3Looooo`008Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04kooooo00?oo`00ooooooooool0foooool0
027ooooo0ol0000Booooo`;oo`0000?o0000ooooooooool0D?ooool00ooo003oooooooooo`3Joooo
o`008Oooool00ol0003oooooooooo`0@ooooo`;oo`0000?o0000ooooooooool0:?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd05Oooool0
0ooo003oooooooooo`0Uooooo`Co000000?o410@ooooooooool0>oooool4o`000003oa0@4?oooooo
oooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool5o`0001_ooooo000Q
ooooo`03o`000?oooooooooo00oooooo00?oo`00o`000?l00000:oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01Cooooo00?oo`00o`000?ooool09ooo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo03cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003ooooooooo
o`0=ooooo`;oo`0000?o0000ooooooooool0:oooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool05?ooool00ooo003o0000ooooo`0Vooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo
000Qooooo`03o`000?oooooooooo00_ooooo0_oo00000ol0003oooooooooo`0]ooooo`05o`000?oo
ooooooooooooool000003oooool00omgMgOo<S8booooo`0Fooooo`03ool00?l0003ooooo02Gooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03kooooo
00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool02_ooool00ooo003o0000o`00
000`ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01So
oooo00?oo`00o`000?ooool09?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c010ooooo`03ogMgMomVIVKooooo01[ooooo000Qooooo`03
o`000?oooooooooo00Wooooo00?oo`00o`000?ooool0<Oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool06oooool00ooo003oooooooooo`0Sooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo
01Wooooo000Qooooo`?o00002?ooool00ooo003o0000ooooo`0booooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`0Looooo`03ool00?oooooooooo02;ooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oooooo00Go0000okZj
^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oo003ooooo
03Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00007?ooool00ol0003oooooooooo`0O
ooooo`03oeEEEOmVIVKo000003oooooo00?oEEEEofIVI_l000003Oooool4o`0003kooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c00Kooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo003o
oooo06Oooooo00?o0000ooooooooool0d_ooool0027ooooo00?o0000ooooooooool00oooool2o`00
06[ooooo00?o0000ooooooooool0d_ooool0027ooooo00Co0000oooooooooooooooo0_l0001]oooo
o`03o`000?oooooooooo0=7ooooo000Qooooo`04o`000?ooooooooooo`00073ooooo00?o0000oooo
ooooool0a_ooool2o`0000;ooooo0_l00004ooooo`008Oooool3o`0007;ooooo00?o0000oooooooo
ool0aOooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooooooo0000>_l0000<oooo
o`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool2o`0000kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`;o00004oooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo0_l0000Cooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qoooo
o`03o`000?oooooooooo07Cooooo00?oo`00o`000?ooool0[_ooool00ooo003oooooooooo`0Boooo
o`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo07Gooooo00?oo`00oooooooo
ool0[?ooool00ol0003oo`00ooooo`0Mooooo`008Oooool00ol0003oooooooooo`1fooooo`03ool0
0?oooooooooo0:[ooooo00?o0000ool00?ooool07_ooool0027ooooo00?o0000ooooooooool0Mooo
ool00ooo003oooooooooo`2Xooooo`03o`000?oo003ooooo01oooooo000Qooooo`03o`000?oooooo
oooo07Sooooo00?oo`00ooooooooool0Yoooool00ooo003oooooooooo`0Oooooo`008Oooool3o`00
07Sooooo00?oo`00ooooooooool0Y_ooool00ooo003oooooooooo`0Pooooo`008Oooool00ol0003o
ooooooooo`1iooooo`03ool00?oooooooooo0:Cooooo00?oo`00ooooooooool08Oooool0027ooooo
00?o0000ooooooooool0N_ooool00ooo003oooooooooo`2Rooooo`03ool00?oooooooooo02;ooooo
000Qooooo`03o`000?oooooooooo07[ooooo00?o0000ool00?ooool0XOooool00ooo003ooooooooo
o`0Sooooo`008Oooool00ol0003oooooooooo`1kooooo`03ool00?oooooooooo09oooooo00?oo`00
o`000?ooool09?ooool0027ooooo00?o0000ooooooooool0O?ooool00ooo003oooooooooo`2Moooo
o`03ool00?l0003ooooo02Gooooo000Qooooo`03o`000?oooooooooo07cooooo00?o0000ool00?oo
ool0W?ooool00ooo003o0000ooooo`0Vooooo`008Oooool3o`0007gooooo00?o0000ooooooooool0
Voooool00ooo003oooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`1nooooo`03o`000?oo
oooooooo09Wooooo00?o0000ooooooooool09oooool0027ooooo00?o0000ooooooooool0Ooooool0
0ol0003oooooooooo`2Hooooo`03o`000?oooooooooo02Oooooo000Qooooo`03o`000?oooooooooo
07oooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`0Xooooo`008Oooool00ol0003o
ooooooooo`20ooooo`03o`000?oooooooooo09Gooooo00?o0000ooooooooool0:Oooool0027ooooo
00?o0000ooooooooool0POooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo02[ooooo
000Qooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0T_ooool00ol0003ooooooooo
o`0[ooooo`008Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo093ooooo00?o0000
ooooooooool0;?ooool0027ooooo0ol00023ooooo`03ool00?oooooooooo08kooooo00?o0000oooo
ooooool0;Oooool0027ooooo00?o0000ooooooooool0Poooool00ooo003oooooooooo`2>ooooo`03
ool00?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo08Cooooo00?oo`00ooooooooool0
S?ooool00ooo003oooooooooo`0^ooooo`008Oooool00ol0003oooooooooo`25ooooo`03ool00?oo
oooooooo08[ooooo00?oo`00ooooooooool0;oooool0027ooooo00?o0000ooooooooool0QOooool0
0ooo003oooooooooo`29ooooo`03ool00?oooooooooo033ooooo000Qooooo`03o`000?oooooooooo
08Kooooo00?oo`00ooooooooool0Qoooool00ooo003oooooooooo`0aooooo`008Oooool00ol0003o
ooooooooo`27ooooo`03ool00?oooooooooo08Gooooo00?oo`00ooooooooool0<_ooool0027ooooo
0ol00027ooooo`03ool00?oooooooooo08Cooooo00?o0000ool00?ooool0<oooool0027ooooo00?o
0000ooooooooool0R?ooool00ooo003oooooooooo`23ooooo`03ool00?oooooooooo03?ooooo000Q
ooooo`03o`000?oooooooooo08Wooooo00?oo`00ooooooooool0POooool00ooo003oooooooooo`0d
ooooo`008Oooool00ol0003oooooooooo`2:ooooo`03ool00?oooooooooo07oooooo00?oo`00oooo
ooooool0=Oooool0027ooooo00?o0000ooooooooool0R_ooool00ooo003oooooooooo`1nooooo`03
ool00?oooooooooo03Kooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo08_ooooo00?oo`00oooo
ooooool0O?ooool00ooo003oooooooooo`0gooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0S?ooool00ooo
003oooooooooo`1jooooo`03o`000?oooooooooo03Sooooo0007ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000S?ooool00ol0003oooooooooo`1ioooo
o`03o`000?oooooooooo03Wooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omg
MgOo<S8booooo`03ooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0N?ooool00ol0
003oooooooooo`0iooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool0M_ooool0
0ol0003oooooooooo`0jooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo07Cooooo00?o0000
ooooooooool0>oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`1cooooo`03o`000?oooooo
oooo03cooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000
ooooooooool0T?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03gooooo000Qoooo
o`03o`000?oooooooooo097ooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`0noooo
o`008Oooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo06kooooo0_oo0010ooooo`00
8Oooool3o`0009;ooooo00?o0000ool00?ooool0K?ooool00ol0003oo`00ooooo`10ooooo`008Ooo
ool00ol0003oooooooooo`2Cooooo`03ool00?oooooooooo06[ooooo00?o0000ool00?ooool0@Ooo
ool0027ooooo00?o0000ooooooooool0U?ooool00ooo003oooooooooo`1Xooooo`03o`000?oo003o
oooo04;ooooo000Qooooo`03o`000?oooooooooo09Cooooo00?oo`00o`000?ooool0Ioooool00ol0
003oo`00ooooo`13ooooo`008Oooool00ol0003oooooooooo`2Eooooo`03ool00?oooooooooo06Go
oooo00?o0000ool00?ooool0A?ooool0027ooooo00?o0000ooooooooool0U_ooool00ooo003ooooo
ooooo`1Sooooo`03o`000?oo003ooooo04Gooooo000Qooooo`03o`000?oooooooooo09Oooooo00?o
o`00ooooooooool0HOooool00ol0003oo`00ooooo`16ooooo`008Oooool3o`0009Sooooo00?oo`00
ooooooooool0Goooool00ol0003oo`00ooooo`17ooooo`008Oooool00ol0003oooooooooo`2Ioooo
o`03ool00?oooooooooo05gooooo00?o0000ool00?ooool0B?ooool0027ooooo00?o0000oooooooo
ool0V_ooool00ooo003oooooooooo`1Kooooo`03o`000?oo003ooooo04Wooooo000Qooooo`03o`00
0?oooooooooo09[ooooo00?o0000ool00?ooool0F_ooool00ol0003oo`00ooooo`1:ooooo`008Ooo
ool00ol0003oooooooooo`2Kooooo`03o`000?oo003ooooo05Sooooo00?o0000ooooooooool0Booo
ool0027ooooo00?o0000ooooooooool0W?ooool00ol0003oo`00ooooo`1Eooooo`;o0000C_ooool0
027ooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo
04kooooo000Qooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0DOooool00ol0003o
ooooooooo`1?ooooo`008Oooool3o`0009oooooo00?o0000ooooooooool0Coooool00ol0003ooooo
ooooo`1@ooooo`008Oooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo04gooooo00?o
0000ooooooooool0DOooool0027ooooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`1:
ooooo`03o`000?oo003ooooo05?ooooo000Qooooo`03o`000?oooooooooo0:;ooooo00?o0000oooo
ooooool0B?ooool00ol0003oo`00ooooo`1Dooooo`008Oooool00ol0003oooooooooo`2Sooooo`03
o`000?oooooooooo04Kooooo00?o0000ool00?ooool0EOooool0027ooooo00?o0000ooooooooool0
Y?ooool2ool004Gooooo00?o0000ool00?ooool0E_ooool0027ooooo00?o0000ooooooooool0YOoo
ool00ol0003oo`00ooooo`12ooooo`03o`000?oo003ooooo05Oooooo000Qooooo`?o0000Yoooool0
0ooo003oooooooooo`0nooooo`03o`000?oo003oo`0005Wooooo000Qooooo`03o`000?oooooooooo
0:Sooooo00?oo`00ooooooooool0??ooool2ool005_ooooo000Qooooo`03o`000?oooooooooo0:Wo
oooo00?oo`00ooooooooool0>Oooool00ol0003oo`00ooooo`1Looooo`008Oooool00ol0003ooooo
ooooo`2Zooooo`03ool00?oooooooooo03Kooooo00?o0000ool00?oo0000G_ooool0027ooooo00?o
0000ooooooooool0Zoooool00ooo003o0000ooooo`0dooooo`03o`000?oo003ooooo05oooooo000H
ooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`2/ooooo`;oo`00<_ooool2
o`0006;ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[_ooool00ooo
003o0000ooooo`0]ooooo`;o0000I?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`2_ooooo`03ool00?l0003ooooo02_ooooo00?o0000ooooooooool0I?ooool001[ooooo
00?o0000ooooooooool01?ooool3o`000;3ooooo00?oo`00o`000?l00000:?ooool2o`0006Oooooo
000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/oooool2o`0002Cooooo0_l0
001Yooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;Gooooo0_l0000P
ooooo`03o`000?oo003oo`0006[ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0]oooool2o`0001cooooo00?o0000ool00?oo0000K?ooool001Sooooo00?oEEEEofIVI_l0
00001_ooool00ol0003oooooooooo`2iooooo`03o`000?oo003oo`0001Kooooo00Co0000ool00?oo
003oo`00K_ooool0027ooooo00?o0000ooooooooool0_?ooool5ool000gooooo1Ooo001aooooo`00
8Oooool00ol0003oooooooooo`2nooooo`?o000000?oo`00o`000?l000001_l00004ool00003o`00
0?oooooooooo07?ooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`00
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo002Xooooo`03ogMgMomVIVKooooo01Oooooo00?oIVIV
ogMgMoooool0Xoooool008Oooooo0ol0000Cooooo`03ob4Q8OoMgMgooooo00Oooooo00?ogMgMoa0@
4?o^k^h06?ooool00oo^k^ko410@omgMg@2Sooooo`00O_ooool01on7QhOo0000oeEEEOmVIVKo0000
oc8b<_o^k^h00oooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_oo
ool00onHV9SoEEEEooooo`07ooooo`04oeEEEOnHV9Soooooooooo`Go00002Oooool00omEEEGoZJVY
ooooo`02ooooo`03okZj^_m4A4Cooooo00;ooooo00?oQhN7ofIVI_ooool04oooool4o`000003oa0@
4?oooooooooo00;ooooo0_lQ8B44ooooo`Go0000Noooool007kooooo00Oo410@omgMgOmgMgOo8B4Q
oooooon7QhOoIVIV00?ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@
00?ooooo00?o0000omgMgOooool01_ooool02Ol0003oooooooooooooooooV9RHob4Q8Oo^k^kooooo
odA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj0oooool00oo^k^ko0000ooooo`0;oooo
o`Ko00001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A407_ooooo001nooooo`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@4003ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01Oooool2ogMgM`Oooooo00?o<S8booooooooool00_oo
ool00onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`0000Gooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^07cooooo001nooooo`04oeEEEOnY
ZJWoooooo`0000;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00Go
oooo00?ok^k^oa0@4?o^k^h01_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00_o
oooo00CoQhN7ofIVI_oooooo00001Oooool00ol0003oooooooooo`0:ooooo`Ko00001?ooool00ol0
003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^07_ooooo001nooooo`03omgMgOlQ8B7ok^k^00?o
oooo00?o0000ooooooooool00_l0000=ooooo`03o`000?oooooooooo00Kooooo00?oEEEEoiRHV?oo
ool01Oooool00ol0003ok^k^ooooo`04ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oo
oooo00001?ooool00oo^k^ko0000ooooo`0Eooooo`03o`000?oooooooooo00gooooo00?oMgMgofIV
I_ooool0N_ooool007oooooo00?oV9RHogMgMoooool00_ooool00ol0003oooooooooo`0=ooooo`03
oa0@4?l0003o000000?o00001Oooool00ooMgMgo410@ooooo`05ooooo`03oeEEEOmgMgOooooo00Go
oooo00?o0000ooooooooool02?ooool7o`0000;ooooo00?oMgMgoeEEEOooool05Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo07Wooooo002Fooooo`03o`000?oooooooooo00Oooooo
00?oEEEEoiRHV?ooool01?ooool02OoMgMgo410@onk^k_oooooo0000okZj^_ooooooV9RHoa0@400B
ooooo`03onk^k_l@413ogMgM01Kooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonH
V9So410@07_ooooo002Fooooo`03o`000?oooooooooo00Oooooo00?o^[ZjodA4A?ooool01Oooool0
2?mgMgOoIVIVoooooonHV9So410@o`000?lQ8B7oc<c<4_ooool00omVIVKoMgMgooooo`0Dooooo`03
oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c01kooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .24805 L
.10458 .1896 L
.12507 .16639 L
.14415 .1488 L
.16254 .13606 L
.17284 .13087 L
.18221 .12743 L
.18704 .12614 L
.18969 .12558 L
.19216 .12514 L
.19445 .12482 L
.19654 .12459 L
.19765 .12449 L
.19886 .12441 L
.20014 .12434 L
.20135 .1243 L
.20203 .12429 L
.20276 .12428 L
.20345 .12428 L
.20409 .12429 L
.2053 .12432 L
.20657 .12438 L
.20723 .12441 L
.20794 .12446 L
.20922 .12456 L
.21213 .12489 L
.21482 .1253 L
.21737 .12579 L
.22214 .12696 L
.22673 .12839 L
.23179 .13033 L
.24205 .13538 L
.26047 .14811 L
.27981 .16624 L
.30067 .19061 L
.34181 .24964 L
.38143 .31309 L
.41954 .37239 L
.4601 .42715 L
.49915 .46818 L
.5205 .4853 L
.54065 .49803 L
.55037 .50301 L
.56066 .50748 L
.5703 .51095 L
.57911 .51352 L
.58855 .51567 L
.5934 .51653 L
.59869 .51729 L
Mistroke
.60356 .51783 L
.60593 .51804 L
.60808 .5182 L
.61016 .51832 L
.6124 .51842 L
.61364 .51846 L
.61477 .51849 L
.61586 .51852 L
.617 .51853 L
.61823 .51854 L
.61892 .51854 L
.61956 .51854 L
.62073 .51853 L
.62197 .51851 L
.62309 .51848 L
.62413 .51845 L
.6265 .51836 L
.62906 .51822 L
.6314 .51806 L
.63668 .51759 L
.64095 .51709 L
.64562 .51644 L
.65502 .51477 L
.67467 .50987 L
.69564 .50273 L
.73719 .48364 L
.77722 .46033 L
.81574 .43454 L
.85671 .40451 L
.89617 .37386 L
.93411 .34338 L
.9745 .3104 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .25198 L
.10458 .19094 L
.12507 .16576 L
.14415 .14666 L
.16254 .13303 L
.16783 .13006 L
.17284 .12765 L
.17768 .1257 L
.18221 .12421 L
.18682 .12304 L
.18927 .12256 L
.1919 .12215 L
.19322 .12199 L
.19466 .12185 L
.19601 .12174 L
.19727 .12167 L
.19852 .12162 L
.19965 .1216 L
.20095 .12161 L
.20218 .12164 L
.20325 .12168 L
.20443 .12175 L
.20565 .12185 L
.2068 .12196 L
.20884 .12221 L
.21104 .12255 L
.21605 .12363 L
.22062 .12495 L
.23054 .12891 L
.23971 .13388 L
.26047 .14942 L
.27913 .16793 L
.29973 .19252 L
.33994 .24927 L
.37862 .30891 L
.41976 .37076 L
.45939 .42348 L
.4975 .46454 L
.51875 .48266 L
.53806 .49601 L
.55814 .50675 L
.5771 .514 L
.58682 .51666 L
.59214 .51782 L
.59712 .51871 L
.60171 .51939 L
.6059 .51987 L
.61056 .52027 L
.61313 .52042 L
Mistroke
.61557 .52053 L
.61682 .52057 L
.61748 .52058 L
.61817 .5206 L
.61944 .52062 L
.62061 .52062 L
.62174 .52062 L
.62279 .52061 L
.62395 .52059 L
.62518 .52056 L
.6265 .52052 L
.62793 .52046 L
.63054 .52032 L
.63307 .52015 L
.63541 .51995 L
.64434 .51889 L
.64885 .51817 L
.65381 .51725 L
.6732 .51236 L
.69407 .505 L
.73526 .48518 L
.77494 .46103 L
.8131 .43471 L
.85371 .40468 L
.89281 .37465 L
.93436 .34205 L
.97439 .31042 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`0`ooooo`_oo`00ooooool:ooooo`008Ooo
ool00ol0003oooooooooo`0^ooooo`;oo`002ol00003ool00?oooooo1oooool0027ooooo00?o0000
ooooooooool0;_ooool2o`0000_ooooo0ol000000ooo003oooooooooo`3oooooo`Cooooo000Qoooo
o`03o`000?oooooooooo02_ooooo0ol0000@ooooo`?o0000ooooool4ooooo`008Oooool00ol0003o
ooooooooo`0Xooooo`?o00005_ooool3o`000?oooooo0Oooool0027ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0?gooooo000Qooooo`?o00009Ooo
ool00ooo003o0000ooooo`0Mooooo`03o`000?oooooooooo0?cooooo000Qooooo`03o`000?oooooo
oooo02Cooooo00?oo`00ooooooooool07oooool00ol0003oooooooooo`3kooooo`008Oooool00ol0
003oooooooooo`0Sooooo`03ool00?oooooooooo027ooooo00?oo`00ooooooooool0n_ooool0027o
oooo00?o0000ooooooooool08_ooool00ooo003oooooooooo`0Rooooo`;oo`00noooool0027ooooo
00?o0000ooooooooool08Oooool00ooo003oooooooooo`0Uooooo`03ool00?oooooooooo0?Sooooo
000Qooooo`03o`000?oooooooooo023ooooo00?oo`00ooooooooool09oooool00ooo003ooooooooo
o`3gooooo`008Oooool00ol0003oooooooooo`0Oooooo`03ool00?oooooooooo02Wooooo00?oo`00
ooooooooool0m_ooool0027ooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`0[oooo
o`03ool00?oooooooooo0?Gooooo000Qooooo`?o00007Oooool00ooo003oooooooooo`0]ooooo`03
ool00?oooooooooo0?Cooooo000Qooooo`03o`000?oooooooooo01cooooo00?oo`00o`000?ooool0
;_ooool00ooo003o0000ooooo`3dooooo`008Oooool00ol0003oooooooooo`0Kooooo`03ool00?l0
003ooooo033ooooo00?oo`00o`000?ooool0loooool0027ooooo00?o0000ooooooooool06_ooool0
0ooo003o0000ooooo`0booooo`03ool00?l0003ooooo0?;ooooo000Qooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0<oooool00ooo003o0000ooooo`3aooooo`001oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03Gooooo00?oo`00o`000?ooool0l?ooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`3^
ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02
ooooo`?o00005oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo0>gooooo0007oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`3]ooooo`001oooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`3/ooooo`001oooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0joooool000Oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo0>_ooooo0007ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool04oooool00ooo003ooooooooo
o`11ooooo`03o`000?oooooooooo0>[ooooo000Qooooo`03o`000?oooooooooo01?ooooo00?oo`00
ooooooooool0@_ooool00ol0003oooooooooo`3Yooooo`008Oooool00ol0003oooooooooo`0Boooo
o`03ool00?oooooooooo04?ooooo00?oo`00ooooooooool0jOooool0027ooooo0ol0000Aooooo`03
ool00?oooooooooo04Cooooo00?oo`00o`000?ooool0jOooool0027ooooo00?o0000ooooooooool0
4?ooool00ol0003oo`00ooooo`16ooooo`03ool00?l0003ooooo0>Sooooo000Qooooo`03o`000?oo
oooooooo013ooooo00?oo`00ooooooooool0Aoooool00ooo003o0000ooooo`3Wooooo`008Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oo003ooooo04Sooooo00?oo`00o`000?ooool0ioooool0
027ooooo00?o0000ooooooooool03_ooool00ol0003oo`00ooooo`1:ooooo`03ool00?l0003ooooo
0>Kooooo000Qooooo`03o`000?oooooooooo00gooooo00?o0000ool00?ooool0C?ooool00ooo003o
0000ooooo`3Uooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?ooooooo`0004gooooo
00?oo`00o`000?ooool0iOooool0027ooooo0ol0000<ooooo`03o`000?oo003ooooo04kooooo00?o
o`00o`000?ooool0i?ooool0027ooooo00?o0000ooooooooool02oooool00ol0003oooooool0001@
ooooo`03ool00?l0003ooooo0>?ooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
oooo0000DOooool00ooo003o0000ooooo`3Sooooo`008Oooool00ol0003oooooooooo`09ooooo`03
o`000?ooooooo`0005?ooooo00?oo`00o`000?ooool0h_ooool0027ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`1Dooooo`03ool00?l0003ooooo0>7ooooo000Qooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0E_ooool00ooo003oooooooooo`3Pooooo`008Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0goooool0
027ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo
0=kooooo000Qooooo`?o00001_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo0=ko
oooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd04Oooool00ol0
003oooooooooo`0Yooooo`Co000000?o410@ooooooooool0>oooool4o`000003oa0@4?oooooooooo
00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool5o`0001_ooooo000Qoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo013ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo03cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo03Kooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0??ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool0
0ol0003oooooooooo`04ooooo`03ool00?oooooooooo03Kooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo01;ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0?_ooool00onHV9So8B4Qonk^
kP0Kooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oo003ooooo03Oooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`04oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<043ooooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0
0_ooool00ol0003oo`00ooooo`0hooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`0Fooooo`03ool00?oooooooooo02Sooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06Oooool0027ooooo
0ol00002ooooo`03ool00?oooooooooo03Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo01Kooooo00?oo`00ooooooooool0:?ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0?oooool01Ol0003o^[ZjoooooonHV9So410@
01_ooooo000Qooooo`06o`000?ooooooooooooooool0003oo`00>_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000Fooooo`03ool00?oooooooooo02Gooooo00?oEEEEofIVI_l00000?ooo
ool00omEEEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo
000Qooooo`05o`000?ooooooooooo`000?oo0000Ioooool00ooo003oooooooooo`3Hooooo`008Ooo
ool01?l0003ooooooooooooo001Xooooo`03ool00?oooooooooo0=Sooooo000Qooooo`03o`000?oo
ooooo`0006[ooooo00?oo`00ooooooooool0eoooool0027ooooo00?o0000oooooooo0000J_ooool0
0ooo003oooooooooo`3=ooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oo003ooooo
06_ooooo00?oo`00ooooooooool0c?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000J
ooooo`Oo000000?oo`00o`000?l00000K?l000000ooo003o0000o`00002ho`000003ool00?l0003o
000000Go00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool00ol0003oo`00o`00000C
ooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`09ooooo`04o`000?oo003oooooo`0001?ooooo00Co
8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000ooooooooool0KOooool00ol0003oo`00oooo
o`2cooooo`03o`000?oo003ooooo01Cooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000
ooooooooool0K_ooool00ooo003oooooooooo`2aooooo`03o`000?oooooooooo01oooooo000Qoooo
o`03o`000?oooooooooo06oooooo00?oo`00ooooooooool0[oooool00ol0003oooooooooo`0Poooo
o`008Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo0:gooooo0_l0000Sooooo`00
8Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo0:_ooooo00?o0000ooooooooool0
8oooool0027ooooo0ol0001aooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool09?oo
ool0027ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`2Wooooo`03ool00?l0003o
oooo02Kooooo000Qooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Y_ooool00ooo
003oooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo0:?o
oooo0_oo000Yooooo`008Oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo0:;ooooo
00?oo`00ooooooooool0:Oooool0027ooooo00?o0000ooooooooool0M?ooool00ol0003ooooooooo
o`2Pooooo`03ool00?oooooooooo02[ooooo000Qooooo`03o`000?oooooooooo07Gooooo00?oo`00
ooooooooool0WOooool2ool002gooooo000Qooooo`?o0000MOooool00ooo003oooooooooo`2Loooo
o`03ool00?l0003ooooo02gooooo000Qooooo`03o`000?oooooooooo07Kooooo00?oo`00oooooooo
ool0VOooool2ool00003o`000?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo07Oooooo
00?oo`00ooooooooool0Uoooool00ooo003o0000ooooo`0`ooooo`008Oooool00ol0003ooooooooo
o`1gooooo`03ool00?oooooooooo09Kooooo00?oo`00o`000?ooool0<Oooool0027ooooo00?o0000
ooooooooool0N?ooool00ooo003oooooooooo`2Dooooo`03ool00?l0003ooooo03;ooooo000Qoooo
o`03o`000?oooooooooo07Wooooo00?oo`00ooooooooool0Toooool00ol0003oooooooooo`0boooo
o`008Oooool00ol0003oooooooooo`1iooooo`03ool00?oooooooooo097ooooo0_l0000eooooo`00
8Oooool00ol0003oooooooooo`1jooooo`03ool00?oooooooooo08oooooo00?o0000ooooooooool0
=Oooool0027ooooo0ol0001kooooo`03ool00?oooooooooo08cooooo0_l0000hooooo`008Oooool0
0ol0003oooooooooo`1looooo`03ool00?oooooooooo08[ooooo00?o0000ooooooooool0>?ooool0
027ooooo00?o0000ooooooooool0O?ooool00ooo003oooooooooo`28ooooo`;o0000>oooool0027o
oooo00?o0000ooooooooool0OOooool00ooo003oooooooooo`25ooooo`;oo`00?Oooool0027ooooo
00?o0000ooooooooool0O_ooool00ooo003oooooooooo`23ooooo`03ool00?l0003ooooo03gooooo
000Qooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0POooool00ooo003o0000oooo
o`0nooooo`008Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo07oooooo00?oo`00
ooooooooool0?oooool0027ooooo0ol00020ooooo`03o`000?oooooooooo07gooooo0_oo0012oooo
o`008Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo07_ooooo00?oo`00oooooooo
ool0@_ooool0027ooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`1hooooo`;oo`00
AOooool0027ooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`1fooooo`03ool00?l0
003ooooo04Gooooo000Qooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0MOooool0
0ooo003o0000ooooo`16ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`24ooooo`03o`000?oo
oooooooo07?ooooo00?oo`00o`000?ooool0Aoooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo08Gooooo00?o
o`00ooooooooool0LOooool00ol0003oooooooooo`18ooooo`001oooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o0000ooooooooool00_ooool3o`0008Kooooo00?oo`00ooooooooool0Kooo
ool00ol0003oooooooooo`19ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool00oooool00ol0003oooooooooo`26ooooo`03o`000?oo003ooooo06kooooo00?o
0000ooooooooool0B_ooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`27ooooo`03o`000?oo003ooooo06cooooo
00?o0000ooooooooool0Boooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0R?ooool00ol0003oo`00ooooo`1Yooooo`;o0000
C_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0ROooool00ol0003oo`00ooooo`1Wooooo`03o`000?oooooooooo04kooooo
0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0
R_ooool00ol0003oo`00ooooo`1Sooooo`;oo`0000?o0000ooooooooool0Coooool0027ooooo00?o
0000ooooooooool0Roooool00ol0003oo`00ooooo`1Qooooo`03ool00?l0003ooooo05;ooooo000Q
ooooo`03o`000?oooooooooo08cooooo00?o0000ool00?ooool0G_ooool2ool00003o`000?oooooo
oooo05;ooooo000Qooooo`?o0000SOooool00ol0003oo`00ooooo`1Looooo`03ool00?l0003ooooo
05Gooooo000Qooooo`03o`000?oooooooooo08kooooo00?o0000ool00?ooool0FOooool2ool00003
o`000?oooooooooo05Gooooo000Qooooo`03o`000?oooooooooo08oooooo00?o0000ool00?ooool0
Eoooool00ooo003o0000ooooo`1Hooooo`008Oooool00ol0003oooooooooo`2@ooooo`03o`000?oo
oooooooo05Cooooo0_oo00000ol0003oooooooooo`1Hooooo`008Oooool00ol0003oooooooooo`2A
ooooo`03o`000?oooooooooo057ooooo0_oo00000ol0003oooooooooo`1Jooooo`008Oooool00ol0
003oooooooooo`2Booooo`;o0000D?ooool00ooo003o0000ooooo`1Mooooo`008Oooool00ol0003o
ooooooooo`2Dooooo`03o`000?oooooooooo04_ooooo0_l0001Pooooo`008Oooool3o`0009Gooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`1Pooooo`008Oooool00ol0003ooooooooo
o`2Fooooo`03o`000?oooooooooo04Kooooo0_l0001Sooooo`008Oooool00ol0003oooooooooo`2G
ooooo`03o`000?oo003ooooo04?ooooo0_l0001Uooooo`008Oooool00ol0003oooooooooo`2Hoooo
o`;oo`00@Oooool2o`0006Oooooo000Qooooo`03o`000?oooooooooo09[ooooo00?oo`00o`000?oo
ool0??ooool00ol0003oo`00ool0001Xooooo`008Oooool00ol0003oooooooooo`2Kooooo`;oo`00
>_ooool00ol0003oo`00ool0001Zooooo`008Oooool00ol0003oooooooooo`2Mooooo`03ool00?l0
003ooooo03Cooooo0_l00002ool006cooooo000Qooooo`03o`000?oooooooooo09kooooo0_oo0000
0ol0003oooooooooo`0_ooooo`;o00000_oo001^ooooo`008Oooool3o`000:3ooooo0_oo000^oooo
o`;o00000_oo001`ooooo`008Oooool00ol0003oooooooooo`2Rooooo`;oo`0000?o0000oooooooo
ool09oooool2o`0000;oo`00L_ooool0027ooooo00?o0000ooooooooool0Y?ooool2ool000;o0000
8oooool00ol0003oo`00ool00002ool007Cooooo000Qooooo`03o`000?oooooooooo0:Sooooo0ol0
000Looooo`Co0000NOooool0027ooooo00?o0000ooooooooool0Zoooool3o`0001Kooooo0ol0001m
ooooo`008Oooool00ol0003oooooooooo`2^ooooo`Co00002_ooool6o`000003ool00?l0003ooooo
07oooooo000Qooooo`03o`000?oooooooooo0:oooooo4ooo0022ooooo`008Oooool3o`000?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0
oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOoo
ool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Joooo
o`03o`000?oooooooooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00:Cooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgoooo
o`2Wooooo`00Poooool3o`0001Cooooo00?o8B4QomgMgOooool01_ooool00ooMgMgo410@onk^kP0H
ooooo`03onk^k_l@413ogMgM0:Oooooo001kooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^
kP02ooooo`03o`000?oooooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03oiRH
V?mEEEGooooo00Kooooo00?oEEEEoiRHV?ooool00_ooool5o`0000Wooooo00?oEEEEojVYZOooool0
0_ooool01_nj^[[oA4A4ooooooooooooQhN7ofIVIQGooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@1eooooo`00Noooool01ol@
413ogMgMogMgMolQ8B7oooooohN7QomVIVH00_ooool00ol0003oooooooooo`0;ooooo`05oa0@4?nj
^[[ok^k^ogMgMol@41001?ooool00ol0003ogMgMooooo`05ooooo`03o`000?oooooooooo00;ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj0_ooool0
0oo^k^ko0000ooooo`0;ooooo`Ko00001Oooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00Oo0000
oooooooMgMgo<S8booooooo^k^ko410@00;ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`06ooooo`;oMgMg1_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00cooooo
00Co410@omgMgOoooooo00001?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_o
oooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`1cooooo`00Noooool01?mEEEGoZJVY
ooooool00002ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool01_ooool00oo^
k^ko410@onk^kP05ooooo`03oc8b<_oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7
QhOoIVIVooooool00004ooooo`03o`000?oooooooooo00[ooooo1_l00005ooooo`03o`000?oooooo
oooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`1dooooo`00Noooool00ooM
gMgo8B4Qonk^kP03ooooo`04o`000?oooooo0000o`0000gooooo00?o0000ooooooooool01oooool0
0omEEEGoV9RHooooo`04ooooo`03o`000?o^k^kooooo00Gooooo00?oMgMgofIVI_ooool02_ooool0
1?oMgMgo410@ooooool00003ooooo`03onk^k_l0003ooooo01Kooooo00?o0000ooooooooool03Ooo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0MOooool007cooooo00?o
V9RHogMgMoooool00_ooool00ol0003oooooooooo`0<ooooo`03oa0@4?l0003o000000?o00001_oo
ool00ooMgMgo410@ooooo`04ooooo`03oeEEEOmgMgOooooo00Kooooo00?o0000ooooooooool02?oo
ool7o`000003oooooomgMgOoEEEE01Oooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo00Sooooo00?oEEEE
oiRHV?ooool00oooool00ooMgMgo410@onk^kP02ooooo`05o`000?nj^[[ooooooiRHV?l@41004Ooo
ool00oo^k^ko410@omgMg@0Gooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RH
oa0@4004ooooo`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo00Sooooo00?o
^[ZjodA4A?ooool01?ooool02OmgMgOoIVIVooooooooooooV9RHoa0@4?l0003o8B4Qolc<c00Aoooo
o`03ofIVI_mgMgOooooo01Gooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l0001fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .22726 L
.08255 .19009 L
.10458 .15629 L
.11448 .14385 L
.12507 .13261 L
.13499 .12408 L
.14415 .11797 L
.14901 .11542 L
.15437 .11317 L
.15975 .11149 L
.1627 .11083 L
.16402 .11058 L
.16546 .11036 L
.1668 .11019 L
.16805 .11006 L
.16925 .10997 L
.17052 .1099 L
.17178 .10987 L
.17296 .10986 L
.17401 .10988 L
.17516 .10993 L
.17642 .11001 L
.1778 .11013 L
.17925 .1103 L
.1806 .1105 L
.1856 .11152 L
.1882 .11224 L
.1906 .11302 L
.19605 .11517 L
.20595 .12043 L
.21495 .12664 L
.22451 .13459 L
.26226 .17702 L
.30246 .23293 L
.34115 .28644 L
.38229 .33467 L
.40281 .35403 L
.42191 .36903 L
.44151 .38149 L
.46002 .39065 L
.46984 .39455 L
.48048 .39807 L
.49008 .40065 L
.49906 .40258 L
.50853 .40414 L
.51355 .40478 L
.51894 .40533 L
.52164 .40556 L
.52458 .40576 L
Mistroke
.52718 .40591 L
.52994 .40604 L
.53135 .40609 L
.53267 .40613 L
.53396 .40616 L
.53515 .40619 L
.53628 .4062 L
.53747 .40622 L
.53867 .40622 L
.53998 .40622 L
.54129 .40622 L
.5425 .40621 L
.54314 .4062 L
.54383 .40619 L
.54524 .40616 L
.54781 .40609 L
.55022 .40601 L
.5547 .40579 L
.55953 .40548 L
.57046 .4045 L
.58046 .40331 L
.59942 .40035 L
.62014 .3963 L
.66075 .38667 L
.69985 .37631 L
.7414 .36501 L
.78143 .35434 L
.81995 .34451 L
.86092 .3346 L
.90038 .32556 L
.93832 .31719 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .22711 L
.08255 .19021 L
.10458 .15642 L
.11448 .14394 L
.12507 .13264 L
.13499 .12407 L
.14415 .11794 L
.14911 .11535 L
.15437 .11316 L
.15964 .11154 L
.16265 .11088 L
.16399 .11064 L
.16546 .11042 L
.1668 .11026 L
.16805 .11015 L
.16925 .11006 L
.17052 .11001 L
.17178 .10998 L
.17296 .10999 L
.17401 .11002 L
.17516 .11008 L
.17642 .11017 L
.1778 .11031 L
.1806 .1107 L
.18318 .1112 L
.1856 .11178 L
.1906 .11333 L
.19605 .11553 L
.20595 .12086 L
.22451 .13503 L
.24428 .15517 L
.26529 .18083 L
.30304 .23283 L
.34324 .28824 L
.38193 .33429 L
.40158 .35351 L
.42307 .37091 L
.4436 .38396 L
.46269 .3931 L
.47322 .39697 L
.48315 .39992 L
.49207 .40203 L
.49706 .403 L
.50174 .40377 L
.50668 .40445 L
.5112 .40496 L
.51622 .40541 L
.51902 .4056 L
.52161 .40575 L
Mistroke
.52412 .40586 L
.52678 .40595 L
.5283 .40599 L
.52905 .406 L
.52973 .40601 L
.53102 .40603 L
.5317 .40603 L
.53241 .40604 L
.53363 .40604 L
.53494 .40603 L
.53617 .40602 L
.5373 .40601 L
.53862 .40598 L
.54005 .40595 L
.54266 .40587 L
.545 .40577 L
.54752 .40565 L
.55208 .40537 L
.56247 .4045 L
.57344 .40325 L
.58349 .40186 L
.62317 .39461 L
.66133 .38598 L
.70194 .37584 L
.74104 .36554 L
.78259 .35444 L
.82262 .3441 L
.86114 .33485 L
.90211 .32564 L
.94157 .31673 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo02Wooooo0_oo0005o`000?oooooo5Ooo
ool0027ooooo00?o0000ooooooooool09Oooool01?l0003oo`00ool00?oo0007ooooo`?o0000oooo
oolBooooo`008Oooool00ol0003oooooooooo`0Tooooo`;oo`003Oooool3o`000?oooooo3oooool0
027ooooo0ol0000Rooooo`;oo`004?ooool2ool000;o0000ooooool=ooooo`008Oooool00ol0003o
ooooooooo`0Qooooo`03ool00?oooooooooo01;ooooo0_oo00000ol0003oooooooooo`3oooooo`[o
oooo000Qooooo`03o`000?oooooooooo01oooooo0_oo000Gooooo`03ool00?l0003ooooo0?oooooo
2_ooool0027ooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`0Hooooo`;oo`00oooo
ool:ooooo`008Oooool00ol0003oooooooooo`0Mooooo`03ool00?oooooooooo01_ooooo00?oo`00
ooooooooool0ooooool7ooooo`008Oooool00ol0003oooooooooo`0Mooooo`03ool00?oooooooooo
01cooooo00?oo`00ooooooooool0ooooool6ooooo`008Oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01gooooo00?oo`00ooooooooool0ooooool6ooooo`008Oooool3o`0001_ooooo
00?o0000ooooooooool07oooool00ooo003oooooooooo`3oooooo`Gooooo000Qooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool08Oooool00ooo003oooooooooo`3oooooo`Cooooo000Q
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08_ooool00ooo003oooooooooo`3o
ooooo`?ooooo000Qooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool09?ooool00ooo
003oooooooooo`3oooooo`;ooooo000Qooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`3oooooo`7ooooo000Qooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`3oooooo`008Oooool00ol0003ooooooooo
o`0Fooooo`03ool00?l0003ooooo02[ooooo00?o0000ooooooooool0o_ooool0027ooooo00?o0000
ooooooooool05_ooool00ooo003oooooooooo`0[ooooo`03o`000?oooooooooo0?gooooo000Qoooo
o`?o00005Oooool00ooo003oooooooooo`0]ooooo`03o`000?oooooooooo0?cooooo000Qooooo`03
o`000?oooooooooo01Cooooo00?oo`00o`000?ooool0;oooool00ol0003oooooooooo`3kooooo`00
8Oooool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo033ooooo00?o0000ooooooooool0
n_ooool0027ooooo00?o0000ooooooooool04oooool00ooo003oooooooooo`0booooo`03ool00?oo
oooooooo0?Wooooo000Qooooo`03o`000?oooooooooo01;ooooo00?oo`00ooooooooool0<oooool0
0ol0003oo`00ooooo`3iooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Booooo`03ool00?oo
oooooooo03Cooooo00?oo`00ooooooooool0n?ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo017ooooo00?o
o`00ooooooooool0=_ooool00ooo003oooooooooo`3gooooo`001Ol00002ooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o00004?ooool00ooo003ooooooooo
o`0gooooo`03o`000?oo003ooooo0?Oooooo0007ooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0>?oo
ool00ol0003oo`00ooooo`3fooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool0
>_ooool00ooo003oooooooooo`3eooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`03ool00?l0003ooooo03_ooooo
00?o0000ool00?ooool0mOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ooo003o0000ooooo`0mooooo`03o`00
0?oo003ooooo0?Cooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0nooooo`03ool00?oooooooooo0??ooooo
000Qooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0?_ooool00ol0003oo`00oooo
o`3cooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo043ooooo00?o0000
ool00?ooool0l_ooool0027ooooo0ol0000<ooooo`03o`000?oooooooooo047ooooo00?o0000ool0
0?ooool0lOooool0027ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`12ooooo`03
o`000?oooooooooo0?7ooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
A?ooool00ol0003oooooooooo`3`ooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool0koooool0027ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`16ooooo`03o`000?oooooooooo0>oooooo000Qooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`3^ooooo`008Oooool00ol0003o
ooooooooo`08ooooo`03ool00?oooooooooo04Wooooo00?o0000ooooooooool0kOooool0027ooooo
0ol00008ooooo`03ool00?oooooooooo04Wooooo00?o0000ooooooooool0kOooool0027ooooo00?o
0000ooooooooool01oooool00ooo003oooooooooo`1;ooooo`03o`000?oooooooooo0>cooooo000Q
ooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool0C?ooool00ol0003oo`00ooooo`3[
ooooo`008Oooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo04kooooo00?oo`00oooo
ooooool0j_ooool0027ooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`1>ooooo`03
o`000?oo003ooooo0>[ooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ool00?ooool0
D?ooool00ol0003oo`00ooooo`3Yooooo`008Oooool00ol0003oooooooooo`05ooooo`03ool00?oo
oooooooo057ooooo00?oo`00ooooooooool0j?ooool0027ooooo00?o0000ooooooooool01?ooool0
0ol0003oo`00ooooo`1Cooooo`03ool00?oooooooooo0>Oooooo000Qooooo`?o00001?ooool00ooo
003oooooooooo`1Cooooo`03o`000?oo003ooooo0>Oooooo000Qooooo`03o`000?oooooooooo00?o
oooo00?o0000ool00?ooool0=oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd02?ooool00ol0003oo`00ooooo`0booooo`Co000000?o410@
ooooooooool0>oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd0?Oooool5o`0001_ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?oo`00
ooooooooool0=oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00Sooooo00?oo`00ooooooooool0<oooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Kooooo`008Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo03Oooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool0
<_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
??ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
003ooooo03Sooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Wooooo
00?o0000ool00?ooool0<_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00kooooo
00?oMgMgoc8b<_ooool0?_ooool00onHV9So8B4Qonk^kP0Kooooo`008Oooool00ol0003ooooooooo
o`02ooooo`03ool00?oooooooooo03Sooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`02oooool00ooo003oooooooooo`0aooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043ooooo00?oMgMgofIV
I_ooool06_ooool0027ooooo00Go0000ooooooooooooooooo`00000kooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo033ooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool06Oooool0027ooooo0ol000000ooooooo0000ooooo`0jooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo02oooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oooooo00Go0000
okZj^_ooooooV9RHoa0@400Kooooo`008Oooool01?l0003oooooooooool0000looooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000kooooo00?o0000ooooooooool0;Oooool00omEEEGoIVIV
o`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000nooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`06oooool0027ooooo00Co0000oooooooooooo0000H?ooool00ol0003oooooooooo`3Pooooo`00
8Oooool00ol0003oooooo`00001Rooooo`03o`000?oooooooooo0=oooooo000Qooooo`03o`000?oo
oooo000006?ooooo00?o0000ooooooooool0g_ooool0027ooooo0_l0001Uooooo`03o`000?oooooo
oooo0=?ooooo0_l00002ooooo`;o00001?ooool0027ooooo0_l0001Vooooo`03o`000?oooooooooo
0=;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooooooo`00037o00000_oo0007
o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooool0000<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`06ooooo`?o00000_oo00000ooooooo0000ooooo`0Booooo`04onk^k_lQ8B7o
410@onk^kPGooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo00003?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool4
o`0000Kooooo00?o0000ooooooooool04Oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool0
0ol0003oooooooooo`1Xooooo`03ool00?oooooooooo0:gooooo0ooo0002o`0001gooooo0_l00002
ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool0JOooool00ooo003oooooooooo`2Yoooo
o`?oo`0000?o0000ooooooooool0:Oooool0027ooooo00?o0000ooooooooool0J_ooool00ooo003o
ooooooooo`2Tooooo`04o`000?oo003oo`00ool002oooooo000Qooooo`03o`000?oooooooooo06_o
oooo00?oo`00ooooooooool0W_ooool00ol0003oo`00ool00003ool003;ooooo000Qooooo`03o`00
0?oooooooooo06cooooo00?oo`00ooooooooool0Uoooool4o`0000?oo`00=oooool0027ooooo0ol0
001]ooooo`03ool00?l0003ooooo097ooooo1Ol0000nooooo`008Oooool00ol0003oooooooooo`1^
ooooo`03ool00?l0003ooooo08_ooooo0_l00003ool004?ooooo000Qooooo`03o`000?oooooooooo
06oooooo00?oo`00o`000?ooool0Q_ooool00ol0003oo`00ool00003ool004Kooooo000Qooooo`03
o`000?oooooooooo073ooooo00?oo`00o`000?ooool0P_ooool4ool004_ooooo000Qooooo`03o`00
0?oooooooooo077ooooo00?oo`00o`000?ooool0O_ooool3ool004oooooo000Qooooo`03o`000?oo
oooooooo07;ooooo00?oo`00o`000?ooool0N_ooool00ol0003oo`00ool0001Booooo`008Oooool0
0ol0003oooooooooo`1dooooo`;o0000M_ooool3o`0005Gooooo000Qooooo`?o0000M_ooool00ol0
003oooooooooo`1_ooooo`Co0000F?ooool0027ooooo00?o0000ooooooooool0Moooool00ol0003o
ooooooooo`1Yooooo`05o`000?oo003oo`00ool00?l00000G?ooool0027ooooo00?o0000oooooooo
ool0N?ooool00ol0003oooooooooo`1Tooooo`Goo`00H?ooool0027ooooo00?o0000ooooooooool0
NOooool00ol0003oooooooooo`1Oooooo`04o`000?oo003oo`00ool006Gooooo000Qooooo`03o`00
0?oooooooooo07[ooooo0_l0001Jooooo`?o00000ooo001Xooooo`008Oooool00ol0003ooooooooo
o`1jooooo`;oo`0000?o0000ooooooooool0Doooool4o`000003oooooooo003oo`0006_ooooo000Q
ooooo`03o`000?oooooooooo07cooooo00?oo`00o`000?l00000D?ooool3o`0007;ooooo000Qoooo
o`03o`000?oooooooooo07gooooo0_oo00000ol0003oooooooooo`18ooooo`?oo`000_l0001eoooo
o`008Oooool3o`0007oooooo00?oo`00o`000?l00000A?ooool4ool000;o0000N?ooool0027ooooo
00?o0000ooooooooool0P?ooool2ool000;o0000?_ooool4ool000?o0000Noooool0027ooooo00?o
0000ooooooooool0P_ooool2ool000;o0000>Oooool3ool000Co0000O_ooool0027ooooo00?o0000
ooooooooool0Q?ooool2ool000?o0000=?ooool2ool000?o0000P_ooool0027ooooo00?o0000oooo
ooooool0Q_ooool3ool000?o0000;_ooool4o`0008Kooooo000Qooooo`03o`000?oooooooooo08co
oooo0ol0000Pooooo`Coo`000_ooool5o`0008[ooooo000Qooooo`03o`000?oooooooooo08oooooo
0ol0000Iooooo`Coo`001_l0002?ooooo`008Oooool3o`0009;ooooo1_oo00000ol0003ooooooooo
o`08ooooo`Soo`000ol0002Fooooo`008Oooool00ol0003oooooooooo`2Hooooo`;oo`002_l0002P
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom5ooooo`00
1oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413o
oooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00001Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0
003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
AOooool001[ooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00Z?ooool00omgMgOoIVIVooooo`0Gooooo`03
ofIVI_mgMgOooooo0:?ooooo0027ooooo`?o00004oooool00olQ8B7ogMgMooooo`07ooooo`03omgM
gOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Xoooool007kooooo00OoQhN7o`000?mEEEGoIVIV
o`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool02oooool01OnHV9So0000o`000?m4A4Co^[Zj
00;ooooo00?oV9RHoeEEEOooool01oooool01?mEEEGoV9RHooooooooool5o`0000Wooooo00?oEEEE
ojVYZOooool00_ooool00onj^[[oA4A4ooooo`02ooooo`03ohN7QomVIVKooooo01?ooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<07_ooooo001n
ooooo`07oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP03ooooo`03o`000?oooooooooo00_ooooo
00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oMgMgooooo00Kooooo00Wo0000oooooooo
oooooooooiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P?o
oooo00?ok^k^o`000?ooool02oooool6o`0000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Co
oooo00Go410@okZj^_ooooooMgMgoc8b<P1kooooo`00O_ooool01ol0003oooooomgMgOlb<S;ooooo
onk^k_l@41000oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo0_mgMgL7
ooooo`03oc8b<_oooooooooo00;ooooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool0
0005ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`1iooooo`00O_ooool01?mEEEGoZJVYooooool00002ooooo`05o`000?ooooooooooooooool00000
3Oooool00ol0003oooooooooo`05ooooo`03onk^k_l@413ok^k^00Kooooo00?o<S8booooooooool0
0oooool00onHV9So8B4Qonk^kP0;ooooo`04ohN7QomVIVKoooooo`0000Gooooo00?o0000oooooooo
ool02_ooool6o`0000Cooooo00?o0000ooooooooool03Oooool00onYZJWo410@ooooo`1jooooo`00
O_ooool00ooMgMgo8B4Qonk^kP03ooooo`03o`000?oooooooooo00;o00003Oooool00ol0003ooooo
ooooo`06ooooo`03oeEEEOnHV9Sooooo00Gooooo00?o0000onk^k_ooool01?ooool00omgMgOoIVIV
ooooo`0:ooooo`04omgMgOl@413oooooo`0000Cooooo00?ok^k^o`000?ooool05Oooool00ol0003o
ooooooooo`0<ooooo`03oa0@4?l0003o^[Zj07_ooooo001oooooo`03oiRHV?mgMgOooooo00;ooooo
00?o0000ooooooooool03Oooool00ol@413o0000o`000003o`0000Gooooo00?ogMgMoa0@4?ooool0
1Oooool00omEEEGoMgMgooooo`05ooooo`03o`000?oooooooooo00Sooooo1ol00002ooooo`03ogMg
MomEEEGooooo01Gooooo00?o0000ooooooooool03Oooool00onj^[[o8B4Qooooo`1jooooo`00U_oo
ool00ol0003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00WogMgMoa0@4?o^k^kooooo
o`000?nj^[[ooooooiRHV?l@41004_ooool00oo^k^ko410@omgMg@0Fooooo`03o`000?oooooooooo
00[ooooo00Go410@oiRHV?oooooo^[Zjo`00001kooooo`00U_ooool00ol0003oooooooooo`07oooo
o`03okZj^_m4A4Cooooo00Gooooo00SoMgMgofIVI_ooooooV9RHoa0@4?l0003o8B4Qolc<c1;ooooo
00?oIVIVogMgMoooool05?ooool00omEEEGoIVIVo`00000<ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT0Noooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.35) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .27411 L
.06244 .24026 L
.08426 .20932 L
.0949 .19729 L
.10458 .18827 L
.11403 .1813 L
.12297 .17641 L
.12787 .17442 L
.1324 .17301 L
.13476 .17244 L
.13737 .17194 L
.13868 .17174 L
.14009 .17156 L
.14142 .17143 L
.14264 .17133 L
.14392 .17127 L
.14514 .17123 L
.14622 .17122 L
.1474 .17124 L
.14869 .17128 L
.14934 .17132 L
.15005 .17136 L
.15131 .17147 L
.15248 .17159 L
.15479 .1719 L
.15689 .17226 L
.16162 .17335 L
.16672 .17492 L
.17226 .17707 L
.18234 .18204 L
.20212 .19501 L
.22313 .21176 L
.26088 .24339 L
.28185 .25913 L
.30108 .27138 L
.31993 .28105 L
.32952 .28505 L
.33977 .28863 L
.35011 .29156 L
.35951 .29363 L
.36404 .29443 L
.36896 .29517 L
.37326 .2957 L
.37788 .29616 L
.38043 .29636 L
.38277 .29652 L
.38514 .29665 L
.38734 .29674 L
.38868 .29679 L
Mistroke
.3899 .29682 L
.39125 .29685 L
.39199 .29686 L
.39268 .29687 L
.39395 .29688 L
.39512 .29689 L
.3964 .29688 L
.39705 .29688 L
.39775 .29687 L
.39843 .29686 L
.39917 .29685 L
.4005 .29682 L
.40301 .29674 L
.40594 .29662 L
.40864 .29647 L
.41357 .29612 L
.4188 .29565 L
.42819 .29456 L
.43831 .29305 L
.4566 .28962 L
.49779 .2797 L
.53747 .26922 L
.57563 .26004 L
.59692 .25573 L
.61624 .25248 L
.63636 .24983 L
.64541 .2489 L
.65534 .24807 L
.66508 .24745 L
.67041 .24719 L
.67539 .247 L
.67778 .24693 L
.68005 .24688 L
.68211 .24683 L
.6843 .2468 L
.68543 .24679 L
.68667 .24677 L
.68781 .24677 L
.68887 .24676 L
.69012 .24676 L
.69127 .24676 L
.69253 .24676 L
.69316 .24676 L
.69386 .24676 L
.69517 .24677 L
.69639 .24679 L
.69913 .24683 L
.70155 .24687 L
.70411 .24694 L
.70855 .24708 L
Mistroke
.71344 .24728 L
.72426 .2479 L
.73438 .24869 L
.75465 .25087 L
.77318 .25351 L
.81291 .26109 L
.85112 .27043 L
.89178 .28203 L
.93093 .29426 L
.97254 .30782 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .27247 L
.06244 .237 L
.08255 .20801 L
.09396 .19543 L
.10458 .18633 L
.10961 .1829 L
.11508 .17979 L
.11989 .17759 L
.125 .17577 L
.12959 .17458 L
.13221 .17408 L
.13346 .17389 L
.13466 .17373 L
.13573 .17362 L
.1369 .17351 L
.13796 .17344 L
.13895 .17339 L
.14012 .17335 L
.14119 .17334 L
.14242 .17335 L
.14357 .17338 L
.14473 .17344 L
.14598 .17352 L
.14823 .17374 L
.1509 .1741 L
.15334 .17452 L
.15863 .17575 L
.16365 .17727 L
.1725 .18071 L
.18212 .18544 L
.22291 .21286 L
.26217 .24277 L
.29992 .26786 L
.31927 .27805 L
.34013 .28664 L
.35051 .28996 L
.36017 .29248 L
.37024 .29453 L
.37553 .29538 L
.38127 .29613 L
.38674 .29668 L
.38914 .29687 L
.39179 .29705 L
.39411 .29717 L
.39661 .29728 L
.39799 .29732 L
.39925 .29735 L
.40052 .29738 L
.40172 .29739 L
Mistroke
.4029 .2974 L
.40396 .29741 L
.40518 .2974 L
.40634 .29739 L
.40741 .29738 L
.40839 .29736 L
.41062 .29731 L
.41287 .29723 L
.41533 .29711 L
.42031 .29681 L
.42557 .29637 L
.43054 .29586 L
.43986 .29466 L
.46079 .29093 L
.49917 .28146 L
.54 .26972 L
.57932 .25898 L
.61712 .25081 L
.63651 .24782 L
.6474 .24654 L
.65738 .24565 L
.66214 .24532 L
.66721 .24503 L
.672 .24482 L
.67411 .24475 L
.67634 .24469 L
.67761 .24466 L
.67901 .24463 L
.68029 .24461 L
.68146 .24459 L
.68212 .24459 L
.68284 .24458 L
.68361 .24457 L
.68433 .24457 L
.685 .24457 L
.68572 .24457 L
.687 .24457 L
.68819 .24458 L
.68947 .24459 L
.69067 .2446 L
.69178 .24462 L
.69435 .24467 L
.69706 .24474 L
.70205 .24492 L
.70659 .24514 L
.71677 .24583 L
.72621 .2467 L
.73513 .24771 L
.75512 .2506 L
.77357 .25393 L
Mistroke
.81294 .2627 L
.85079 .27247 L
.8911 .28362 L
.92989 .29495 L
.97114 .30751 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool08Oooool6o`000?oooooo7_ooool0027ooooo00?o0000ooooooooool07Ooo
ool5o`0000?ooooo0ooo0004o`000?oooooo6Oooool0027ooooo00?o0000ooooooooool06oooool2
o`0000_ooooo1?oo0002o`000?oooooo5oooool0027ooooo00?o0000ooooooooool06Oooool3ool0
013ooooo0_oo00000ol0003oooooooooo`3ooooooaCooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooo
oooo01Sooooo00?oo`00o`000?ooool04oooool00ooo003o0000o`00003ooooooaCooooo0007oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool0
0ol0003oooooooooo`0Fooooo`;oo`0000?o0000ooooooooool05?ooool2ool00003o`000?oooooo
oooo0?oooooo4Oooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000
ooooooooool00_ooool3o`0001Gooooo00?oo`00o`000?l000006Oooool00ooo003o0000o`00003o
oooooa7ooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo01Cooooo00?oo`00o`000?ooool06oooool00ooo003oooooo`00003o
oooooa3ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool04oooool00ooo003o0000ooooo`0Mooooo`04ool00?oo
oooo0000o`000?oooooo3_ooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool04oooool00ooo003oooooooooo`0Qooooo`03o`00
0?oooooooooo0?oooooo2oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`0Sooooo`;o0000
ooooool;ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`00
0?oooooooooo017ooooo00?oo`00ooooooooool09_ooool00ol0003oooooooooo`3oooooo`Sooooo
000Qooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0:?ooool00ol0003ooooooooo
o`3oooooo`Oooooo000Qooooo`03o`000?oooooooooo00oooooo00?oo`00o`000?ooool0:_ooool2
o`000?oooooo1oooool0027ooooo0ol0000?ooooo`03o`000?oooooooooo02[ooooo0_oo00000ol0
003oooooooooo`3oooooo`Cooooo000Qooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0;Oooool00ooo003o0000ooooo`3oooooo`Cooooo000Qooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0;_ooool00ooo003o0000ooooo`3oooooo`?ooooo000Qooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0<?ooool2ool00?oooooo0oooool0027ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0cooooo`03ool00?oooooooooo0?oooooo000Qoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=Oooool00ooo003oooooooooo`3noooo
o`008Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Kooooo0_oo003nooooo`00
8Oooool3o`0000[ooooo00?o0000ooooooooool0>?ooool00ol0003oo`00ooooo`3looooo`008Ooo
ool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo03[ooooo00?o0000ool00?ooool0nooo
ool0027ooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`0kooooo`03o`000?oo003o
o`0007[ooooo2ooo001eooooo`008Oooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo
03kooooo00?o0000ooooooooool0L_ooool6ool001Co00002?oo001Tooooo`008Oooool00ol0003o
ooooooooo`07ooooo`03ool00?oooooooooo043ooooo0_l0001^ooooo`Oo00006_ooool5o`0000Ko
o`00G_ooool0027ooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`12ooooo`03o`00
0?oooooooooo06;ooooo0ooo0006o`0002cooooo1?oo00000ol0003oooooooooo`1Gooooo`008Ooo
ool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo04Cooooo00?o0000ooooooooool0GOoo
ool4ool000;o0000=oooool5ool000?o0000D_ooool0027ooooo00?o0000ooooooooool01_ooool0
0ooo003oooooooooo`15ooooo`;o0000F?ooool00ol0003oo`00ool00002ool004;ooooo1?oo0004
o`0004gooooo000Qooooo`?o00001Oooool00ooo003oooooooooo`18ooooo`03o`000?ooooooo`00
057ooooo0_l00003ool004[ooooo0_oo0002ooooo`Co0000BOooool0027ooooo00?o0000oooooooo
ool01?ooool00ooo003oooooooooo`0fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00?oA4A4o`000?l000000_l000000ooo003oooooooooo`0jooooo`Co000000?o410@oooo
ooooool02Oooool4o`0000;oo`00;?ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd05?ooool4o`0002Gooooo1Ol0000Kooooo`008Oooool00ol0
003oooooooooo`04ooooo`03ool00?oooooooooo03Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8bo`000002ool003cooooo00?o0000ooooooooool01oooool4
o`0003Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool4
o`00027ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`03
ooooo`03ool00?oooooooooo03Oooooo00Go410@oooooooooooooooooa0@400@ooooo`04o`000?oo
oooo0000o`0000;oo`00>_ooool00ol0003oooooooooo`02ooooo`Go0000>?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01Gooooo1Ooo0003o`0001oooooo00?oV9RHob4Q8Oo^k^h0
7?ooool0027ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0gooooo`05o`000?oo
ooooooooooooool000003oooool00omgMgOo<S8booooo`02ooooo`;o00000_oo000hooooo`Go0000
00Coooooool00?oo003oo`00>Oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo01_o
oooo1?oo0002o`0001gooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0
0_ooool00ooo003oooooooooo`0hooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo0_l00003ool003;ooooo1?l000000oooooooo`00ool00002ool0
03cooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<023ooooo1?oo0000
0ol0003oooooooooo`0Iooooo`03ogMgMomVIVKooooo01[ooooo000Qooooo`03o`000?oooooooooo
00;ooooo00?oo`00ooooooooool0>?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool02Oooool3o`0000?oo`00:oooool4o`000003oooooooo003oo`0000;oo`00@?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Kooooo0_oo0002o`0001Wooooo00?o0000
ooooooooool06Oooool0027ooooo0ol000000oooooooo`00ooooo`0jooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`0<ooooo`?o000000?oo`00ooooooooool09?ooool4
o`000003oooooooo003oo`0000;oo`000_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0:?ooool00ooo003oooooo`000002o`0001;ooooo00Go0000
okZj^_ooooooV9RHoa0@400Kooooo`008Oooool01Ol0003ooooooooooooooooo000003_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003_ooool3o`0001oooooo1Ol00003ooooo`;oo`00
1?ooool00omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000/ooooo`?o0000
3oooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qooooo`04o`000?ooooooooooo`0006;o
oooo0ol0000Hooooo`Co0000Toooool3o`0002cooooo000Qooooo`03o`000?oooooo000006Kooooo
1Ol00004ool000Kooooo1Ol00007ool009Oooooo0ooo00000ol0003oooooooooo`0Vooooo`008Ooo
ool00ol0003oooooo`00001_ooooo`_oo`00XOooool3ool00003o`000?oooooooooo02?ooooo000Q
ooooo`;o0000oooooolPooooo`?oo`0000?o0000ooooooooool05_ooool2o`0000;ooooo0_l00004
ooooo`008Oooool2o`000?oooooo8oooool3ool00003o`000?oooooooooo01?ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooooooo`0002oo00001?oo0007o`0000cooooo00CogMgM
o`000?l@413oc<c<1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Co8B4Q
ogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000ooooooooool0oooooolkooooo`;o00000_ooool2
o`0000Cooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02
ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o
410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3o`000?oo
ooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo
000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIV
I_l000001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool0
0omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:Oooooo0023ooooo`?o00005?ooool00olQ
8B7ogMgMooooo`06ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Yoooool007_o
oooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool02oooool0
1OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?oV9RHoeEEEOooool01_ooool00omEEEGoV9RHoooo
o`02ooooo`Go00002Oooool00omEEEGoZJVYooooo`02ooooo`06okZj^_m4A4Cooooooooooon7QhOo
IVIV5Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b
<_o<c<`01?ooool01Om4A4Co0000o`000?lb<S;ogMgM07Gooooo001kooooo`07oa0@4?oMgMgoMgMg
ob4Q8OooooooQhN7ofIVIP02ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_o^k^koMgMg
oa0@4004ooooo`03o`000?oMgMgooooo00Gooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Q
onk^k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X2ooooo`03onk^k_l0003o
oooo00_ooooo1_l00005ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oa0@4?nj^[[o
ooooogMgMolb<S801oooool00omgMgOo<S8booooo`1dooooo`00Noooool01ol0003oooooomgMgOlb
<S;oooooonk^k_l@41000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
0_mgMgL6ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgM
ooooool00004ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo07?ooooo001kooooo`04oeEEEOnYZJWoooooo`0000;o
oooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`06ooooo`03onk^k_l@413ok^k^
00Gooooo00?o<S8booooooooool01?ooool00onHV9So8B4Qonk^kP0;ooooo`04ohN7QomVIVKooooo
o`0000Cooooo00?o0000ooooooooool02_ooool6o`0000Gooooo00?o0000ooooooooool03Oooool0
0onYZJWo410@ooooo`06ooooo`03ogMgMolb<S;ooooo07Cooooo001kooooo`03omgMgOlQ8B7ok^k^
00?ooooo00Co0000ooooool0003o00003Oooool00ol0003oooooooooo`07ooooo`03oeEEEOnHV9So
oooo00Cooooo00?o0000onk^k_ooool01Oooool00omgMgOoIVIVooooo`0:ooooo`04omgMgOl@413o
ooooo`0000?ooooo00?ok^k^o`000?ooool05_ooool00ol0003oooooooooo`0<ooooo`03oa0@4?l0
003o^[Zj00Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c01eooooo`00O?ooool00onHV9SoMgMgoooo
o`02ooooo`03o`000?oooooooooo00cooooo00?o410@o`000?l000000ol00006ooooo`03omgMgOl@
413ooooo00Cooooo00?oEEEEogMgMoooool01_ooool00ol0003oooooooooo`08ooooo`Oo000000?o
ooooogMgMomEEED05oooool00ol0003oooooooooo`0=ooooo`03okZj^_lQ8B7ooooo00?ooooo00?o
0000ooooooooool0Moooool009;ooooo00?o0000ooooooooool02?ooool00omEEEGoV9RHooooo`03
ooooo`03omgMgOl@413ok^k^00;ooooo00Go0000okZj^_ooooooV9RHoa0@400Aooooo`03onk^k_l@
413ogMgM01Oooooo00?o0000ooooooooool02_ooool01Ol@413oV9RHoooooonj^[[o000000Cooooo
00?o0000ooooooooool0Moooool009;ooooo00?o0000ooooooooool02?ooool00onj^[[oA4A4oooo
o`04ooooo`09ogMgMomVIVKooooooooooonHV9So410@o`000?lQ8B7oc<c<017ooooo00?oIVIVogMg
Moooool05Oooool00omEEEGoIVIVo`00000<ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01?ooool4
o`0007Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .30147 L
.0522 .29812 L
.06244 .29516 L
.0679 .29389 L
.07286 .29294 L
.07784 .29218 L
.08255 .29166 L
.08522 .29144 L
.08668 .29135 L
.08805 .29128 L
.08931 .29122 L
.09046 .29119 L
.09174 .29116 L
.09244 .29115 L
.09312 .29114 L
.09384 .29114 L
.09449 .29114 L
.09525 .29114 L
.09596 .29115 L
.09723 .29118 L
.09794 .2912 L
.0986 .29122 L
.10151 .29135 L
.10297 .29144 L
.10458 .29156 L
.10982 .29206 L
.11478 .29268 L
.12409 .29419 L
.145 .29856 L
.16322 .30242 L
.1736 .30422 L
.17868 .30493 L
.18333 .30547 L
.18797 .30589 L
.1903 .30605 L
.19285 .30619 L
.1942 .30625 L
.19542 .30629 L
.1961 .30631 L
.19683 .30632 L
.19752 .30633 L
.19816 .30634 L
.19931 .30635 L
.20057 .30635 L
.20188 .30634 L
.20311 .30632 L
.20441 .30628 L
.20582 .30623 L
.2084 .3061 L
Mistroke
.21091 .30593 L
.21324 .30573 L
.21851 .30514 L
.22412 .30429 L
.23443 .30215 L
.24557 .299 L
.26575 .29126 L
.30681 .26898 L
.34635 .24238 L
.38437 .21539 L
.42485 .18826 L
.46381 .16595 L
.48366 .1565 L
.50522 .14785 L
.5242 .1417 L
.53499 .13882 L
.54512 .13654 L
.55546 .13461 L
.56493 .1332 L
.57505 .13208 L
.58037 .13165 L
.58324 .13147 L
.58595 .13132 L
.58836 .13121 L
.59097 .13111 L
.59212 .13108 L
.59334 .13105 L
.59448 .13103 L
.59552 .13101 L
.59674 .13099 L
.59804 .13099 L
.59924 .13098 L
.60039 .13098 L
.60103 .13099 L
.60172 .13099 L
.60295 .13101 L
.60363 .13102 L
.60427 .13103 L
.60573 .13106 L
.60798 .13112 L
.61034 .1312 L
.61457 .13141 L
.61913 .1317 L
.62411 .1321 L
.63437 .1332 L
.6437 .13452 L
.66464 .13854 L
.6838 .14344 L
.70459 .15 L
.74548 .16627 L
Mistroke
.78485 .18558 L
.8227 .20687 L
.86301 .23183 L
.9018 .25747 L
.94305 .28584 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .30282 L
.06244 .29659 L
.06747 .29535 L
.07286 .29422 L
.07751 .29342 L
.08255 .29274 L
.08564 .29242 L
.08848 .2922 L
.0912 .29203 L
.09258 .29197 L
.09335 .29195 L
.09409 .29192 L
.09474 .29191 L
.09545 .29189 L
.0967 .29187 L
.0974 .29187 L
.09815 .29187 L
.09886 .29187 L
.0995 .29188 L
.10076 .29189 L
.10147 .29191 L
.10212 .29192 L
.10338 .29196 L
.10458 .29201 L
.10704 .29214 L
.10928 .29228 L
.11432 .29271 L
.1234 .2938 L
.14407 .29727 L
.16229 .30065 L
.17266 .30236 L
.17774 .30308 L
.1824 .30366 L
.18694 .30414 L
.19191 .30456 L
.1945 .30473 L
.19691 .30485 L
.19945 .30495 L
.20088 .30499 L
.20217 .30501 L
.20348 .30503 L
.20414 .30503 L
.20487 .30503 L
.20615 .30503 L
.20736 .30501 L
.20808 .305 L
.20877 .30499 L
.21007 .30495 L
.21146 .3049 L
Mistroke
.21298 .30483 L
.21554 .30468 L
.21827 .30447 L
.22318 .30398 L
.22855 .30325 L
.23349 .3024 L
.24463 .29987 L
.25445 .29693 L
.26481 .29312 L
.30284 .27354 L
.34331 .24574 L
.38227 .21646 L
.42369 .1871 L
.46359 .16373 L
.50197 .14739 L
.52178 .14146 L
.5319 .13907 L
.5428 .13696 L
.55299 .13542 L
.56231 .13436 L
.57123 .13364 L
.57571 .13338 L
.57826 .13327 L
.5806 .13319 L
.58315 .13312 L
.58449 .13309 L
.58591 .13306 L
.58714 .13305 L
.58829 .13304 L
.58955 .13303 L
.59026 .13303 L
.59091 .13303 L
.5921 .13304 L
.5932 .13305 L
.59442 .13306 L
.5957 .13308 L
.59787 .13313 L
.60025 .13319 L
.60545 .1334 L
.61106 .13371 L
.62122 .13452 L
.63077 .13554 L
.64123 .13695 L
.66233 .14065 L
.68191 .14509 L
.70285 .15086 L
.74432 .16543 L
.78427 .18339 L
.8227 .20419 L
.86359 .22958 L
Mistroke
.90296 .25632 L
.94082 .28324 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`2Uooooo`Ko00000_oo000Bo`0008Gooooo000Qooooo`03o`000?oooooooooo0:7o
oooo2_oo000<ooooo`Ooo`0000?oooooo`000?l000000_l00021ooooo`008Oooool00ol0003ooooo
ooooo`2Looooo`Goo`0000?o0000ooooooooool06_ooool5ool000Go0000O?ooool0027ooooo0ol0
002Iooooo`?o00009oooool4ool00004ooooool0003o0000o`0007Wooooo000Qooooo`03o`000?oo
oooooooo09Kooooo0ol0000booooo`?o0000M_ooool0027ooooo00?o0000ooooooooool0TOooool2
ool000?o0000>?ooool3o`0007?ooooo000Qooooo`03o`000?oooooooooo08oooooo0_oo0002o`00
03kooooo0_oo00000ol0003oooooooooo`1^ooooo`008Oooool00ol0003oooooooooo`2<ooooo`?o
o`0000?o0000ooooooooool0@Oooool3ool00003o`000?oooooooooo06_ooooo000Qooooo`03o`00
0?oooooooooo08[ooooo0_oo0002o`0004Sooooo0ooo00000ol0003oooooooooo`1Xooooo`008Ooo
ool00ol0003oooooooooo`28ooooo`;oo`000_l0001=ooooo`;oo`0000?o0000ooooooooool0I_oo
ool0027ooooo00?o0000ooooooooool0Q_ooool2ool000;o0000DOooool3ool00003o`000?oooooo
oooo06?ooooo000Qooooo`?o0000QOooool00ooo003o0000o`00001Fooooo`;oo`0000?o0000oooo
ooooool0HOooool0027ooooo00?o0000ooooooooool0Q?ooool00ooo003o0000ooooo`1Jooooo`;o
0000HOooool0027ooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`1Mooooo`;o0000
Goooool0027ooooo00?o0000ooooooooool0POooool2o`0006;ooooo0_l0001Mooooo`008Oooool0
0ol0003oooooooooo`1oooooo`;o0000I_ooool2o`0000;oo`00FOooool000Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o
0000ooooooooool0O_ooool00ol0003oooooooooo`1Xooooo`;o00000_oo001Gooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o
0000ooooooooool0NOooool2ool00003ooooool0003o000006gooooo0_l00002ool005Gooooo0005
o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0
001hooooo`04ool00?oooooo0000o`00077ooooo0_l000000ooo003oooooooooo`1Booooo`001ooo
ool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooo
ooooo`1fooooo`;oo`0000?oooooo`000?ooool0M?ooool00ol0003oo`00ool0001Booooo`001ooo
ool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03
o`000?oooooooooo07Gooooo00Coo`00ooooool0003o0000N?ooool00ol0003oo`00ool0001@oooo
o`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`1cooooo`;oo`000_l0001looooo`03o`000?oo003ooooo04kooooo0007ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
07;ooooo00?oo`00ooooool00000P?ooool2ool004gooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0LOooool00ooo003o0000o`000023oooo
o`03ool00?l0003ooooo04[ooooo000Qooooo`03o`000?oooooooooo06oooooo0_oo00000ol0003o
ooooooooo`25ooooo`03o`000?oooooooooo04Sooooo000Qooooo`03o`000?oooooooooo06kooooo
00?oo`00o`000?ooool0ROooool2o`0004Sooooo000Qooooo`?o0000KOooool00ooo003o0000oooo
o`2<ooooo`03o`000?oooooooooo04Gooooo000Qooooo`03o`000?oooooooooo06cooooo00?o0000
ooooooooool0S_ooool2o`0004Gooooo000Qooooo`03o`000?oooooooooo06_ooooo00?o0000oooo
ooooool0TOooool00ol0003oooooooooo`12ooooo`008Oooool00ol0003oooooooooo`1Yooooo`;o
0000UOooool2ool004;ooooo000Qooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0
Uoooool2ool0043ooooo000Qooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0VOoo
ool00ol0003oo`00ooooo`0nooooo`008Oooool00ol0003oooooooooo`1Uooooo`;o0000W_ooool0
0ol0003oooooooooo`0looooo`008Oooool3o`0006Cooooo0_oo002Pooooo`;o0000??ooool0027o
oooo00?o0000ooooooooool0Hoooool00ooo003oooooooooo`2Rooooo`;o0000>_ooool0027ooooo
00?o0000ooooooooool0HOooool00ol0003oo`00ooooo`2Vooooo`;oo`00>?ooool0027ooooo00?o
0000ooooooooool0H?ooool2ool00:Wooooo00?o0000ool00?ooool0=_ooool0027ooooo00?o0000
ooooooooool0G_ooool00ol0003oo`00ooooo`2/ooooo`;oo`00=Oooool0027ooooo00?o0000oooo
ooooool0GOooool2ool00;3ooooo00?oo`00ooooooooool0<_ooool0027ooooo00?o0000oooooooo
ool0Foooool00ol0003oo`00ooooo`2booooo`;oo`00<_ooool0027ooooo00?o0000ooooooooool0
F_ooool2ool00;Kooooo00?oo`00ooooooooool0;oooool0027ooooo0ol0001Hooooo`03o`000?oo
003ooooo0;Sooooo0_oo000_ooooo`008Oooool00ol0003oooooooooo`0mooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`00
0?oo003ooooo03Kooooo1?l000000ol@413oooooooooo`0kooooo`Co000000?o410@ooooooooool0
0_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0]ooooo`03o`000?oo003ooooo00go
oooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00CoMgMgoc8b<_oooooooooo0_l0000kooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0;_ooool00ooo
003oooooooooo`0;ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0027ooooo00?o0000oooo
ooooool0?Oooool01Ol@413ooooooooooooooooo410@013ooooo0ol0000mooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0^ooooo`03ool00?oooooo
oooo00_ooooo00?oV9RHob4Q8Oo^k^h07?ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol0
003ooooooooooooooooo000000oooooo0_l0000oooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool03_ooool00omgMgOo<S8booooo`0`ooooo`;o00003?ooool00onHV9So8B4Qonk^kP0K
ooooo`008Oooool00ol0003oooooooooo`0mooooo`05o`000?ooooooooooooooool000003?ooool3
o`000003oc8b<_o<c<cooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0<oooool00ol0003oooooooooo`0:ooooo`03ogMgMomV
IVKooooo01[ooooo000Qooooo`03o`000?oooooooooo03gooooo00Go410@oooooooooooooooooa0@
400;ooooo`;oo`00@oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Wooooo000Q
ooooo`?o0000?Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo0_oo0002o`0004?ooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Oooooo0_l0
0006ooooo`05o`000?nj^[[ooooooiRHV?l@41006oooool0027ooooo00?o0000ooooooooool0?Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00Coo`00o`000?oooooooooo1?l0000nooooo`03
oeEEEOmVIVKo000003oooooo00?oEEEEofIVI_l000003Oooool4o`0003Sooooo00?o0000oooooooo
ool00oooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qooooo`03o`000?oooooooooo00co
oooo1Ol0000<ool002_ooooo0_oo003Eooooo`03o`000?oo003oo`0002;ooooo000Qooooo`03o`00
0?oooooooooo00Sooooo1?l0000Aooooo`Coo`009?ooool00ol0003oo`00ool0003Iooooo`03o`00
0?oo003ooooo023ooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0000Iooooo`Ko00006_oo
ool3o`0000;oo`00gOooool2ool001oooooo000Qooooo`03o`000?oooooooooo00;ooooo1Ooo000P
ooooo`Co00000_oo000Aooooo`;o00001?oo003Pooooo`03o`000?oo003ooooo01?ooooo0_l00002
ooooo`;o00001?ooool0027ooooo00?o0000oooooooo00000_oo000Zooooo`03o`000?oo003oo`00
00[oo`001Ol0003Xooooo`03ool00?oooooooooo017ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oM
gMd4ooooo`006_ooool7o`0000;oo`00ool0000Yo`000003ool00?l0003o000000Go00003?ooool0
1?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool04Oooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool0
1?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003oooooooooo`3ooooooc_ooooo0_l00002
ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo1?l0
00000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`?o
0000oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
AOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool00omE
EEGoIVIVo`000006ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002X
ooooo`03ogMgMomVIVKooooo01Oooooo00?oIVIVogMgMoooool0Xoooool008Oooooo0ol0000Coooo
o`03ob4Q8OoMgMgooooo00Oooooo00?ogMgMoa0@4?o^k^h06?ooool00oo^k^ko410@omgMg@2Soooo
o`00O_ooool01on7QhOo0000oeEEEOmVIVKo0000oc8b<_o^k^h00oooool00ol0003oooooooooo`0;
ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool00onHV9SoEEEEooooo`07ooooo`04oeEEEOnH
V9Soooooooooo`Go00002Oooool00omEEEGoZJVYooooo`02ooooo`03okZj^_m4A4Cooooo00;ooooo
00?oQhN7ofIVI_ooool04oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`;o0000
00?o410@ooooooooool0NOooool007kooooo00Oo410@omgMgOmgMgOo8B4Qoooooon7QhOoIVIV00?o
oooo00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000omgM
gOooool01_ooool02Ol0003oooooooooooooooooV9RHob4Q8Oo^k^koooooodA4A00:ooooo`06oeEE
EOnHV9Soooooooooool@413o^[Zj0oooool00oo^k^ko0000ooooo`0;ooooo`Ko00001?ooool00ol0
003oooooooooo`04ooooo`;o8B4Q1oooool00ol0003oooooooooo`1jooooo`00O_ooool01ol0003o
ooooomgMgOlb<S;oooooonk^k_l@41000oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Gooooo0_mgMgL7ooooo`03oc8b<_oooooooooo00;ooooo00?oV9RHob4Q8Oo^k^h03?ooool0
1?l@413ogMgMooooool00005ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02_oo
ool5o`0007_ooooo001nooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Go0000oooooooooooooooo
o`00000=ooooo`03o`000?oooooooooo00Gooooo00?ok^k^oa0@4?o^k^h01_ooool00olb<S;ooooo
ooooo`03ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001Oooool00ol0003o
ooooooooo`0:ooooo`Ko00001?ooool00ol0003oooooooooo`0:ooooo`04odA4A?oMgMgoooooo`00
07cooooo001nooooo`03omgMgOlQ8B7ok^k^00?ooooo00?o0000ooooooooool00_l0000=ooooo`03
o`000?oooooooooo00Kooooo00?oEEEEoiRHV?ooool01Oooool00ol0003ok^k^ooooo`04ooooo`03
ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo00001?ooool00oo^k^ko0000ooooo`0Eoooo
o`03o`000?oooooooooo00[ooooo00CogMgMoeEEEOoooooo0000O?ooool007oooooo00?oV9RHogMg
Moooool00_ooool00ol0003oooooooooo`0=ooooo`03oa0@4?l0003o000000?o00001Oooool00ooM
gMgo410@ooooo`05ooooo`03oeEEEOmgMgOooooo00Gooooo00?o0000ooooooooool02?ooool7o`00
00;ooooo00?oMgMgoeEEEOooool05Oooool00ol0003oooooooooo`0;ooooo`03ogMgMoo<c<co0000
07cooooo002Fooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool02OoMgMgo
410@onk^k_oooooo0000okZj^_ooooooV9RHoa0@400Booooo`03onk^k_l@413ogMgM01Kooooo00?o
0000ooooooooool02oooool00oo^k^koA4A4o`00001looooo`00U_ooool00ol0003oooooooooo`07
ooooo`03okZj^_m4A4Cooooo00Gooooo00SoMgMgofIVI_ooooooV9RHoa0@4?l0003o8B4Qolc<c1;o
oooo00?oIVIVogMgMoooool05?ooool00omEEEGoIVIVo`00000>ooooo`03ogMgMol0003ooooo07_o
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.45) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .33986 L
.06244 .36986 L
.08426 .39716 L
.0949 .40755 L
.10458 .41509 L
.10911 .41795 L
.11403 .42057 L
.11828 .42242 L
.12297 .42401 L
.12553 .42469 L
.12793 .42519 L
.13047 .42558 L
.13189 .42575 L
.13319 .42586 L
.13439 .42593 L
.13551 .42597 L
.13673 .42598 L
.13803 .42596 L
.13928 .4259 L
.14045 .42583 L
.1415 .42573 L
.14264 .4256 L
.14501 .42525 L
.14755 .42475 L
.15214 .42352 L
.1576 .42154 L
.16257 .41925 L
.17339 .41277 L
.18364 .40491 L
.22197 .3637 L
.26275 .30724 L
.30202 .24925 L
.33977 .1962 L
.37997 .14687 L
.41866 .1086 L
.43831 .09291 L
.4598 .07867 L
.48033 .06789 L
.49942 .06028 L
.50995 .05705 L
.51988 .05461 L
.5288 .05292 L
.53379 .05217 L
.53847 .0516 L
.54303 .05116 L
.54538 .05098 L
.54793 .05082 L
.55072 .05068 L
.55201 .05063 L
Mistroke
.55337 .05059 L
.55473 .05055 L
.55595 .05053 L
.55718 .05052 L
.55834 .05051 L
.55957 .05052 L
.56026 .05052 L
.56091 .05053 L
.56222 .05055 L
.56295 .05056 L
.56362 .05058 L
.5661 .05066 L
.56846 .05076 L
.57118 .05092 L
.5737 .0511 L
.57939 .05161 L
.58904 .05284 L
.59809 .05439 L
.61871 .05927 L
.63893 .06574 L
.65744 .073 L
.69712 .09234 L
.73528 .11509 L
.77589 .14288 L
.81499 .17237 L
.85654 .20589 L
.89658 .23967 L
.93509 .27301 L
.97607 .30891 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .34081 L
.06244 .37178 L
.08255 .3972 L
.09396 .40818 L
.09905 .41222 L
.10458 .41598 L
.11004 .41906 L
.11508 .42133 L
.11989 .42301 L
.12232 .42367 L
.125 .42425 L
.12741 .42465 L
.12962 .42492 L
.13084 .42502 L
.13153 .42506 L
.13217 .42509 L
.13334 .42513 L
.13459 .42514 L
.13575 .42513 L
.13701 .42508 L
.1382 .425 L
.1393 .42491 L
.14138 .42466 L
.14357 .42432 L
.14612 .4238 L
.14853 .4232 L
.15305 .42179 L
.16321 .4173 L
.17199 .41206 L
.18154 .40502 L
.22233 .36247 L
.26159 .30927 L
.29934 .25431 L
.33955 .19786 L
.37823 .14972 L
.41937 .10801 L
.4399 .09132 L
.459 .07836 L
.4786 .06762 L
.49711 .05984 L
.50692 .05663 L
.51756 .05383 L
.52724 .0519 L
.53615 .05062 L
.54083 .05013 L
.5434 .04992 L
.54585 .04975 L
.54811 .04963 L
.54931 .04958 L
Mistroke
.55058 .04953 L
.55176 .04949 L
.55283 .04947 L
.55391 .04945 L
.55492 .04944 L
.55612 .04943 L
.55743 .04943 L
.55809 .04943 L
.5588 .04944 L
.56009 .04946 L
.56136 .04949 L
.56257 .04952 L
.56484 .04961 L
.56751 .04974 L
.56997 .0499 L
.57555 .05038 L
.5802 .0509 L
.58521 .05157 L
.59426 .05311 L
.61487 .05801 L
.63495 .0645 L
.65607 .07296 L
.69423 .09184 L
.73484 .11603 L
.77394 .14238 L
.81549 .173 L
.85552 .20465 L
.89404 .23679 L
.93501 .27241 L
.97447 .30748 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000X?ooool2
ool000Gooooo0ooo002Jooooo`008Oooool00ol0003oooooooooo`2Jooooo`Koo`002_l00009ool0
097ooooo000Qooooo`03o`000?oooooooooo09Kooooo1?oo000Gooooo`;o00000ooo002>ooooo`00
8Oooool00ol0003oooooooooo`2Cooooo`?oo`0000?o0000ooooooooool07?ooool00ol0003oo`00
ool00002o`0008[ooooo000Qooooo`03o`000?oooooooooo097ooooo0ol0000Vooooo`?o0000Qooo
ool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo08kooooo0ol0000/
ooooo`;o0000QOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2;oooo
o`?o0000<Oooool2o`0008?ooooo000?ooooo`Ko00001Oooool00ol0003oooooooooo`04ooooo`?o
0000R?ooool2ool00003o`000?oooooooooo03Cooooo0_oo0021ooooo`006_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo08Kooooo0_oo00000ol0003oooooooooo`0hooooo`;oo`00
Ooooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`24ooooo`;oo`0000?o
0000ooooooooool0??ooool2ool007gooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0Poooool00ooo003o0000ooooo`11ooooo`;oo`00Noooool001[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`21ooooo`;oo`0000?o0000ooooooooool0@oooool2ool0
0003o`000?oooooooooo07Kooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0P?ooool00ooo003o0000ooooo`18ooooo`;oo`0000?o0000ooooooooool0M?ooool0027ooooo
00?o0000ooooooooool0Ooooool00ooo003o0000ooooo`1;ooooo`;oo`0000?o0000ooooooooool0
L_ooool0027ooooo00?o0000ooooooooool0O_ooool00ooo003o0000ooooo`1>ooooo`03ool00?l0
003o000007;ooooo000Qooooo`?o0000OOooool00ooo003oooooooooo`1Booooo`;o0000L?ooool0
027ooooo00?o0000ooooooooool0O?ooool00ooo003oooooooooo`1Eooooo`03o`000?oooooooooo
06gooooo000Qooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0Eoooool2o`0006go
oooo000Qooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0F_ooool2o`0006_ooooo
000Qooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0G?ooool2ool006[ooooo000Q
ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0Goooool00ooo003o0000ooooo`1W
ooooo`008Oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo067ooooo0_oo00000ol0
003oooooooooo`1Tooooo`008Oooool3o`0007Kooooo00?o0000ooooooooool0I?ooool00ooo003o
0000ooooo`1Tooooo`008Oooool00ol0003oooooooooo`1dooooo`03ool00?l0003ooooo06Oooooo
0_oo00000ol0003oooooooooo`1Qooooo`008Oooool00ol0003oooooooooo`1dooooo`03ool00?oo
oooooooo06Wooooo00?oo`00o`000?ooool0HOooool0027ooooo00?o0000ooooooooool0Loooool0
0ooo003oooooooooo`1[ooooo`03ool00?l0003o0000063ooooo000Qooooo`03o`000?oooooooooo
07;ooooo00?oo`00ooooooooool0KOooool2ool00003o`000?oooooooooo05gooooo000Qooooo`03
o`000?oooooooooo077ooooo00?oo`00ooooooooool0L?ooool00ooo003o0000o`00001Mooooo`00
8Oooool00ol0003oooooooooo`1`ooooo`03ool00?oooooooooo07;ooooo00?oo`00ooooool00000
G?ooool0027ooooo0ol0001_ooooo`03ool00?oooooooooo07Kooooo0_l0001Jooooo`008Oooool0
0ol0003oooooooooo`1^ooooo`03ool00?oooooooooo07Wooooo00?o0000ooooooooool0Eoooool0
027ooooo00?o0000ooooooooool0KOooool00ooo003oooooooooo`1kooooo`03o`000?oooooooooo
05Kooooo000Qooooo`03o`000?oooooooooo06cooooo00?oo`00o`000?ooool0OOooool00ol0003o
ooooooooo`1Eooooo`008Oooool00ol0003oooooooooo`1/ooooo`03ool00?oooooooooo07kooooo
00?o0000ooooooooool0E?ooool0027ooooo00?o0000ooooooooool0Joooool00ooo003ooooooooo
o`20ooooo`;oo`00E?ooool0027ooooo00?o0000ooooooooool0J_ooool00ooo003oooooooooo`23
ooooo`03ool00?oooooooooo057ooooo000Qooooo`03o`000?oooooooooo06Wooooo00?o0000oooo
ooooool0QOooool2ool0057ooooo000Qooooo`?o0000J?ooool00ol0003oooooooooo`27ooooo`03
o`000?oo003ooooo04oooooo000Qooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0
ROooool00ol0003oo`00ooooo`1>ooooo`008Oooool00ol0003oooooooooo`1Vooooo`03o`000?oo
oooooooo08_ooooo00?o0000ool00?oo0000COooool0027ooooo00?o0000ooooooooool0I_ooool0
0ol0003oooooooooo`2=ooooo`03o`000?oo003ooooo04_ooooo000Qooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool0Soooool00ol0003oo`00ooooo`1:ooooo`001oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo097ooooo00?o0000ool00?ooool0BOooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo06?ooooo00?oo`00ooooooooool0U?ooool00ooo003oooooooooo`17
ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02
ooooo`?o0000H_ooool00ol0003oo`00ooooo`2Fooooo`03ool00?oooooooooo04Kooooo0007oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo067ooooo00?o0000ool00?ooool0V?ooool00ol0003oooooooooo`15ooooo`001oooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oo
oooooooo063ooooo00?o0000ool00?ooool0V_ooool2o`0004Gooooo0007ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo063ooooo00?o
o`00ooooooooool0W?ooool00ol0003oooooooooo`12ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Oooooo`03o`000?oo
003ooooo09kooooo00?o0000ooooooooool0@Oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001Oooool00ol0003oooooooooo`1Nooooo`03o`000?oo003ooooo0:3ooooo0_l0
0011ooooo`008Oooool00ol0003oooooooooo`1Nooooo`03ool00?oooooooooo0:;ooooo00?o0000
ooooooooool0?_ooool0027ooooo00?o0000ooooooooool0GOooool00ooo003oooooooooo`2Soooo
o`;oo`00?oooool0027ooooo0ol0001Looooo`03ool00?oooooooooo0:Kooooo00?oo`00oooooooo
ool0??ooool0027ooooo00?o0000ooooooooool0Foooool00ol0003oo`00ooooo`2Xooooo`03ool0
0?oooooooooo03_ooooo000Qooooo`03o`000?oooooooooo05_ooooo00?oo`00ooooooooool0ZOoo
ool00ooo003o0000ooooo`0jooooo`008Oooool00ol0003oooooooooo`1Jooooo`03ool00?oooooo
oooo0:_ooooo0_oo000jooooo`008Oooool00ol0003oooooooooo`1Iooooo`03ool00?oooooooooo
0:kooooo00?oo`00ooooooooool0=oooool0027ooooo00?o0000ooooooooool0FOooool00ol0003o
ooooooooo`2_ooooo`03ool00?oooooooooo03Kooooo000Qooooo`03o`000?oooooooooo05Sooooo
00?o0000ooooooooool0/Oooool00ooo003oooooooooo`0eooooo`008Oooool3o`0005Oooooo00?o
0000ooooooooool0/oooool00ooo003oooooooooo`0dooooo`008Oooool00ol0003oooooooooo`1F
ooooo`03o`000?oooooooooo0;Gooooo00?oo`00o`000?ooool0<oooool0027ooooo00?o0000oooo
ooooool0E_ooool00ol0003oooooooooo`2fooooo`03ool00?l0003ooooo03;ooooo000Qooooo`03
o`000?oooooooooo05Gooooo00?o0000ooooooooool0^Oooool00ol0003oooooooooo`0`ooooo`00
8Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo0;_ooooo00?o0000ooooooooool0
;oooool0027ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`2looooo`03o`000?oo
oooooooo02kooooo000Qooooo`03o`000?oooooooooo05?ooooo00?oo`00ooooooooool0__ooool2
o`0002kooooo000Qooooo`03o`000?oooooooooo05;ooooo00?o0000ool00?ooool0`Oooool00ol0
003oooooooooo`0[ooooo`008Oooool3o`0005;ooooo00?oo`00ooooooooool0`_ooool00ol0003o
ooooooooo`0Zooooo`008Oooool00ol0003oooooooooo`0mooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003oo`00omgMg@0mooooo`Co000000?o410@oooo
ooooool0>oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd0<?ooool2ool000_ooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0moooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ool00?lb<S80?oooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo037ooooo00?oo`00ooooooooool02?ooool01OnHV9So8B4Qonk^k_ooooooA4A401_ooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go410@oooooooooooooooooa0@400>ooooo`03ool00?oo
oooo000003oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo037ooooo0_oo0009ooooo`03oiRHV?lQ8B7ok^k^01cooooo000Qooooo`03o`000?oooooo
oooo03gooooo00Go0000ooooooooooooooooo`00000=ooooo`04ool00?ooooooMgMgoc8b<Soooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03Cooooo
00?oo`00ooooooooool01oooool00onHV9So8B4Qonk^kP0Kooooo`008Oooool00ol0003ooooooooo
o`0mooooo`05o`000?ooooooooooooooool000003?ooool01Ooo003o8B4Qo`000?lb<S;oc<c<03oo
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`0=_ooool00ooo003oooooooooo`07ooooo`03ogMgMomVIVKooooo01[ooooo000Qooooo`03
o`000?oooooooooo03gooooo00Go410@oooooooooooooooooa0@400<ooooo`03ool00?oooooooooo
047ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
03Wooooo00?oo`00ooooooooool01oooool00ol0003oooooooooo`0Iooooo`008Oooool3o`0003go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03ool00?l0003ooooo04;ooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03[ooooo00?oo`00oooo
ooooool00_ooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`03o`000?oooooooooo
03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`03ool00?oooooo000000?o0000?_ooool0
0omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000jooooo`09ool00?l0003o
oooooooooonHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qooooo`03o`000?oooooooooo04cooooo
00?oo`00ooooooooool0d_ooool00ooo003o0000ooooo`0Pooooo`008Oooool00ol0003ooooooooo
o`1;ooooo`03ool00?oooooooooo0=Cooooo00?oo`00o`000?ooool07oooool0027ooooo00?o0000
ooooooooool0B_ooool00ooo003oooooooooo`3Fooooo`03ool00?l0003ooooo01kooooo000Qoooo
o`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0f?ooool00ol0003oooooooooo`0Boooo
o`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo04Wooooo00?o0000oooooooo
ool0f_ooool00ol0003oooooooooo`0Aooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool0
01[oooooool0000jo`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Cok^k^ob4Q
8Ol@413ok^k^1Oooool0027ooooo0_l0000=ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0_l0000>oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aoooo
o`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03o`000?oooooo000004Kooooo00?o0000oooo
ooooool0lOooool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooo`000015ooooo`03
o`000?oooooooooo0?cooooo000Qooooo`04o`000?ooooooooooo`0004Cooooo00?o0000oooooooo
ool0o?ooool0027ooooo00Co0000ooooooooooooo`00@oooool00ooo003oooooooooo`3mooooo`00
8Oooool01Ol0003ooooooooooooo003o0000047ooooo00?o0000ool00?ooool0o_ooool0027ooooo
0ol000000oooooooo`00o`00000oooooo`03o`000?oo003ooooo0?oooooo000Qooooo`03o`000?oo
oooooooo00;ooooo00?oo`00ooooooooool0??ooool00ol0003oo`00ooooo`3oooooo`7ooooo000Q
ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0>oooool00ooo003oooooooooo`3o
ooooo`7ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0>_ooool00ooo
003oooooooooo`3oooooo`;ooooo000Qooooo`03o`000?oooooooooo00Cooooo00?oo`00oooooooo
ool0>?ooool00ooo003oooooooooo`3oooooo`?ooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?oo`00ooooooooool0=_ooool00ol0003oo`00ooooo`3oooooo`Cooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?oo`00ooooooooool0=_ooool00ooo003oooooooooo`3oooooo`Cooooo000Q
ooooo`?o00001_ooool00ooo003oooooooooo`0dooooo`03ool00?oooooooooo0?oooooo1Oooool0
027ooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`0booooo`03ool00?oooooooooo
0?oooooo1_ooool0027ooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`0aooooo`03
ool00?oooooooooo0?oooooo1oooool0027ooooo00?o0000ooooooooool02?ooool00ooo003ooooo
ooooo`0`ooooo`03ool00?oooooooooo0?oooooo1oooool0027ooooo00?o0000ooooooooool02Ooo
ool00ooo003oooooooooo`0^ooooo`03o`000?oooooooooo0?oooooo2?ooool0027ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo0?oooooo2Oooool0
027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
0?oooooo2_ooool0027ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo0?oooooo2oooool0027ooooo0ol0000<ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0ooooool<ooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0ooooool=ooooo`008Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0ooooool>ooooo`008Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo02;ooooo00?oo`00ooooooooool0ooooool?oooo
o`008Oooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo023ooooo00?oo`00oooooooo
ool0ooooool@ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03ool00?l0003ooooo01kooooo
00?oo`00ooooooooool0oooooolAooooo`008Oooool00ol0003oooooooooo`0Aooooo`03ool00?l0
003ooooo01cooooo00?oo`00ooooooooool0oooooolBooooo`008Oooool3o`0001;ooooo00?oo`00
o`000?ooool06_ooool00ooo003oooooooooo`3ooooooa?ooooo000Qooooo`03o`000?oooooooooo
01?ooooo00?oo`00o`000?l000006?ooool00ooo003oooooooooo`3ooooooaCooooo000Qooooo`03
o`000?oooooooooo01Cooooo00?oo`00ooooool000005_ooool00ooo003oooooooooo`3ooooooaGo
oooo000Qooooo`03o`000?oooooooooo01Gooooo0_oo00000ol0003oooooooooo`0Aooooo`;oo`00
oooooolHooooo`008Oooool00ol0003oooooooooo`0Gooooo`03ool00?l0003o000000kooooo0ooo
003ooooooa[ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo01Sooooo0ooo000;ooooo`04o`00
0?oo003o0000o`000?oooooo6oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01_ooooo0_oo00000ol0003o
ooooooooo`04ooooo`;o0000oooooolOooooo`001oooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00_ooool3o`0001kooooo1_l0003oooooob7ooooo0007ooooo`05o`00
0?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?oo
ooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005oooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo
0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGo
oooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_oo
ool00ol0003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo002Tooooo`03ogMgMomVIVKooooo01Oooooo00?oIVIVogMgMooo
ool0Yoooool008?ooooo0ol0000Dooooo`03ob4Q8OoMgMgooooo00Kooooo00?ogMgMoa0@4?o^k^h0
6?ooool00oo^k^ko410@omgMg@2Wooooo`00Noooool01on7QhOo0000oeEEEOmVIVKo0000oc8b<_o^
k^h00_ooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool00onH
V9SoEEEEooooo`06ooooo`03oeEEEOnHV9Sooooo00;ooooo1Ol00009ooooo`03oeEEEOnYZJWooooo
00;ooooo00Ko^[ZjodA4A?ooooooooooohN7QomVIVHEooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`02ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
MOooool007_ooooo00Oo410@omgMgOmgMgOo8B4Qoooooon7QhOoIVIV00;ooooo00?o0000oooooooo
ool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000omgMgOooool01Oooool00ol0
003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooooooo
oooo410@okZj^P;ooooo00?ok^k^o`000?ooool02oooool6o`0000Gooooo00?o0000ooooooooool0
1?ooool2ob4Q8@Oooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`1dooooo`00Nooo
ool01ol0003oooooomgMgOlb<S;oooooonk^k_l@41000_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Kooooo0_mgMgL6ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^
k^h03?ooool01?l@413ogMgMooooool00004ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool02_ooool5o`0000Sooooo00?o0000ooooooooool0Loooool007_ooooo00CoEEEEojVYZOoo
oooo00000_ooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00Kooooo00?ok^k^
oa0@4?o^k^h01Oooool00olb<S;oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7
ofIVI_oooooo00001?ooool00ol0003oooooooooo`0:ooooo`Ko00001Oooool00ol0003ooooooooo
o`0:ooooo`04odA4A?oMgMgoooooo`0000Sooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00?o
gMgMob4Q8Oo^k^h00oooool01?l0003oooooo`000?l0000=ooooo`03o`000?oooooooooo00Oooooo
00?oEEEEoiRHV?ooool01?ooool00ol0003ok^k^ooooo`05ooooo`03ogMgMomVIVKooooo00[ooooo
00CogMgMoa0@4?oooooo00000oooool00oo^k^ko0000ooooo`0Fooooo`03o`000?oooooooooo00[o
oooo00CogMgMoeEEEOoooooo00001Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<07Gooooo001loooo
o`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool03?ooool00ol@413o0000o`000003o`00
00Kooooo00?ogMgMoa0@4?ooool01?ooool00omEEEGoMgMgooooo`06ooooo`03o`000?oooooooooo
00Sooooo1ol000000oooooooMgMgoeEEE@0Gooooo`03o`000?oooooooooo00_ooooo00?oMgMgolc<
c?l000001Oooool00ol0003oooooooooo`1gooooo`00T_ooool00ol0003oooooooooo`08ooooo`03
oeEEEOnHV9Sooooo00?ooooo00?ogMgMoa0@4?o^k^h00_ooool01Ol0003o^[ZjoooooonHV9So410@
017ooooo00?ok^k^oa0@4?oMgMd05oooool00ol0003oooooooooo`0;ooooo`03onk^k_m4A4Co0000
00Gooooo00?o0000ooooooooool0Moooool009;ooooo00?o0000ooooooooool02?ooool00onj^[[o
A4A4ooooo`04ooooo`09ogMgMomVIVKooooooooooonHV9So410@o`000?lQ8B7oc<c<017ooooo00?o
IVIVogMgMoooool05Oooool00omEEEGoIVIVo`00000>ooooo`03ogMgMol0003ooooo00Cooooo1?l0
001fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .3589 L
.06244 .40538 L
.08255 .44164 L
.09396 .45641 L
.09905 .46161 L
.10458 .46627 L
.11004 .46988 L
.11243 .47116 L
.11508 .47235 L
.1174 .47322 L
.11989 .47397 L
.12127 .4743 L
.12253 .47455 L
.12372 .47474 L
.125 .4749 L
.12624 .47501 L
.12736 .47507 L
.12849 .47509 L
.12955 .47507 L
.13079 .47501 L
.13194 .47492 L
.13319 .47478 L
.13452 .47458 L
.13675 .47413 L
.13884 .47359 L
.14357 .47192 L
.14858 .46954 L
.15402 .46624 L
.16392 .45852 L
.18248 .43875 L
.22326 .37799 L
.26253 .30853 L
.30028 .24156 L
.34048 .17686 L
.37917 .12467 L
.39882 .10252 L
.42031 .08181 L
.44107 .06527 L
.45994 .05315 L
.47955 .04337 L
.49045 .03913 L
.5005 .03595 L
.50981 .0336 L
.51968 .03173 L
.5248 .03099 L
.52958 .03045 L
.53484 .03002 L
.53778 .02985 L
.53917 .02978 L
Mistroke
.54048 .02973 L
.54168 .0297 L
.54299 .02967 L
.54417 .02965 L
.54526 .02964 L
.54644 .02963 L
.54774 .02964 L
.54839 .02964 L
.54909 .02965 L
.55035 .02967 L
.55153 .0297 L
.55281 .02974 L
.55514 .02984 L
.55741 .02996 L
.5595 .0301 L
.56429 .0305 L
.56956 .03109 L
.58024 .0327 L
.59036 .03474 L
.59962 .03703 L
.62049 .04357 L
.66017 .06072 L
.69833 .08214 L
.73894 .1091 L
.77804 .13817 L
.81959 .17154 L
.85963 .20541 L
.89814 .2391 L
.93912 .27564 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .35671 L
.06244 .40297 L
.08255 .44006 L
.09396 .45554 L
.09905 .46107 L
.10458 .46609 L
.11004 .47005 L
.11508 .47283 L
.11989 .47472 L
.12232 .47539 L
.12369 .47569 L
.125 .47591 L
.12615 .47607 L
.12741 .4762 L
.12855 .47627 L
.12962 .4763 L
.13088 .47629 L
.13202 .47624 L
.13334 .47614 L
.13459 .47599 L
.13568 .47582 L
.13684 .47561 L
.1389 .47514 L
.14357 .47362 L
.14853 .47136 L
.15305 .46874 L
.16321 .46103 L
.18154 .44152 L
.22139 .38133 L
.25972 .31234 L
.3005 .23924 L
.33977 .17655 L
.37752 .12671 L
.41772 .08579 L
.45641 .05773 L
.47645 .04722 L
.48665 .04287 L
.49755 .03893 L
.50789 .03586 L
.51729 .03361 L
.52674 .03187 L
.53566 .03069 L
.54029 .03025 L
.54295 .03005 L
.54538 .02991 L
.54794 .02979 L
.54935 .02974 L
.5507 .0297 L
.55193 .02967 L
Mistroke
.55308 .02965 L
.55433 .02964 L
.55504 .02964 L
.55567 .02964 L
.55683 .02965 L
.55805 .02966 L
.5591 .02968 L
.56024 .02971 L
.5628 .02979 L
.56518 .0299 L
.5695 .03018 L
.57412 .03058 L
.57943 .03118 L
.58432 .03187 L
.5954 .03386 L
.60517 .03613 L
.61554 .03905 L
.65334 .05395 L
.6936 .07645 L
.73233 .10336 L
.77353 .136 L
.8132 .16965 L
.85136 .2027 L
.89198 .23772 L
.93107 .27102 L
.97262 .30604 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo09_ooooo2?l0
0008ool009Wooooo000Qooooo`03o`000?oooooooooo09Cooooo0_l00004ool00003o`000?oooooo
oooo00_ooooo0ol00008ool0097ooooo000Qooooo`03o`000?oooooooooo097ooooo0_l00003ool0
01Sooooo1Ol000000ooo003oooooooooo`2>ooooo`008Oooool00ol0003oooooooooo`2>ooooo`;o
00000ooo000Qooooo`?o0000SOooool0027ooooo00?o0000ooooooooool0Roooool2o`0000?oo`00
9oooool3o`0008[ooooo000Qooooo`03o`000?oooooooooo08Wooooo0_l000000oooooooo`00oooo
o`0/ooooo`;o0000R?ooool0027ooooo0ol00027ooooo`;o000000?oooooool00?oo0000<?ooool0
0ol0003oo`00ool00025ooooo`008Oooool00ol0003oooooooooo`25ooooo`;o0000=oooool01?l0
003oo`00ool00?oo0022ooooo`008Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo
03Wooooo0_l00002ool0083ooooo000Qooooo`03o`000?oooooooooo08;ooooo0_l0000nooooo`;o
00000_oo001nooooo`008Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo043ooooo
0_l00002ool007cooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003ooooooooo
o`1oooooo`03o`000?oo003oo`0004Cooooo0_l000000ooo003oooooooooo`1iooooo`006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo07kooooo00?o0000ool00?ooool0Aoooool0
0ol0003oo`00ool0001iooooo`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`00
07cooooo0_l000000ooo003oooooooooo`18ooooo`;o000000?oo`00ooooooooool0M_ooool001[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1kooooo`03o`000?oo003oo`0004go
oooo0_l0001gooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07[ooooo
00?o0000ool00?ooool0D?ooool00ol0003oooooooooo`1dooooo`006_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo07Wooooo00?o0000ool00?ooool0D_ooool2o`0007Cooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0N?ooool00ol0003oo`00ooooo`1E
ooooo`;o0000L_ooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`1goooo
o`03o`000?oo003ooooo05Sooooo00?o0000ooooooooool0Koooool0027ooooo00?o0000oooooooo
ool0M_ooool00ol0003oo`00ooooo`1Jooooo`03o`000?oo003oo`0006kooooo000Qooooo`03o`00
0?oooooooooo07Gooooo00?o0000ool00?ooool0GOooool00ol0003oo`00ool0001/ooooo`008Ooo
ool3o`0007Cooooo00?o0000ool00?ooool0H?ooool00ol0003oo`00ooooo`1Zooooo`008Oooool0
0ol0003oooooooooo`1cooooo`03o`000?oooooooooo06;ooooo00?o0000ool00?oo0000JOooool0
027ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1Uooooo`03o`000?oo003ooooo
06Oooooo000Qooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Ioooool00ooo003o
ooooooooo`1Uooooo`008Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo06Wooooo
00?oo`00o`000?ooool0I?ooool0027ooooo00?o0000ooooooooool0L?ooool00ol0003ooooooooo
o`1[ooooo`03ool00?l0003ooooo06?ooooo000Qooooo`03o`000?oooooooooo06oooooo00?o0000
ooooooooool0KOooool00ooo003o0000ooooo`1Rooooo`008Oooool3o`0006kooooo00?o0000oooo
ooooool0Koooool00ooo003o0000o`00001Qooooo`008Oooool00ol0003oooooooooo`1]ooooo`03
ool00?oooooooooo07?ooooo00?o0000ooooooooool0G_ooool0027ooooo00?o0000ooooooooool0
K?ooool00ooo003oooooooooo`1eooooo`03o`000?oooooooooo05gooooo000Qooooo`03o`000?oo
oooooooo06cooooo00?oo`00ooooooooool0M_ooool2o`0005gooooo000Qooooo`03o`000?oooooo
oooo06_ooooo00?oo`00ooooooooool0NOooool00ol0003oooooooooo`1Jooooo`008Oooool00ol0
003oooooooooo`1Zooooo`03ool00?oooooooooo07_ooooo00?o0000ooooooooool0FOooool0027o
oooo00?o0000ooooooooool0JOooool00ooo003oooooooooo`1mooooo`;o0000FOooool0027ooooo
0ol0001Yooooo`03ool00?oooooooooo07gooooo0_oo00000ol0003oooooooooo`1Fooooo`008Ooo
ool00ol0003oooooooooo`1Xooooo`03ool00?oooooooooo083ooooo00?oo`00o`000?ooool0E_oo
ool0027ooooo00?o0000ooooooooool0Ioooool00ooo003oooooooooo`22ooooo`03ool00?l0003o
000005Gooooo000Qooooo`03o`000?oooooooooo06Kooooo00?o0000ool00?ooool0Q?ooool00ooo
003oooooo`00001Dooooo`008Oooool00ol0003oooooooooo`1Vooooo`03ool00?oooooooooo08Go
oooo0_oo00000ol0003oooooooooo`1Aooooo`008Oooool00ol0003oooooooooo`1Uooooo`03ool0
0?oooooooooo08Sooooo00?oo`00o`000?ooool0DOooool0027ooooo00?o0000ooooooooool0I?oo
ool00ooo003oooooooooo`2:ooooo`03ool00?l0003o0000053ooooo000Qooooo`03o`000?oooooo
oooo06?ooooo00?o0000ooooooooool0S?ooool00ooo003oooooo`00001?ooooo`008Oooool3o`00
06?ooooo00?o0000ooooooooool0SOooool00ooo003oooooo`00001>ooooo`008Oooool00ol0003o
ooooooooo`1Rooooo`03o`000?oooooooooo08oooooo00Coo`00ooooool0003o0000C?ooool0027o
oooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`2Aooooo`04ool00?ooooooooooo`00
04_ooooo000Qooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0U_ooool00ol0003o
ooooooooo`18ooooo`008Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo09Oooooo
00?o0000ooooooooool0Aoooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0Goooool00ol0003o
ooooooooo`2Iooooo`03o`000?oooooooooo04Kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`1Nooooo`03
o`000?oooooooooo09_ooooo00?o0000ooooooooool0AOooool000Go00000_ooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`0005gooooo00?oo`00o`000?oo
ool0WOooool00ol0003oooooooooo`14ooooo`001oooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`1Mooooo`03ool00?oooooooooo09ko
oooo00?o0000ooooooooool0@oooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`1Looooo`03ool00?l0003ooooo
09kooooo0_oo00000ol0003oooooooooo`12ooooo`001oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Looooo`03ool00?oooooooooo
0:3ooooo00?oo`00o`000?ooool0@_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00ooo003oooooooooo`2Roooo
o`;oo`00@_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0
003oooooooooo`1Jooooo`03ool00?l0003ooooo0:Gooooo00?oo`00o`000?ooool0?oooool0027o
oooo00?o0000ooooooooool0F_ooool00ooo003oooooooooo`2Vooooo`03ool00?l0003ooooo03ko
oooo000Qooooo`03o`000?oooooooooo05Wooooo00?oo`00o`000?ooool0Z?ooool00ooo003o0000
ooooo`0mooooo`008Oooool3o`0005Wooooo00?oo`00ooooooooool0ZOooool00ooo003o0000oooo
o`0looooo`008Oooool00ol0003oooooooooo`1Hooooo`03ool00?oooooooooo0:_ooooo00?oo`00
o`000?ooool0>oooool0027ooooo00?o0000ooooooooool0F?ooool00ooo003oooooooooo`2/oooo
o`03ool00?l0003ooooo03[ooooo000Qooooo`03o`000?oooooooooo05Oooooo00?oo`00oooooooo
ool0[_ooool00ooo003o0000ooooo`0iooooo`008Oooool00ol0003oooooooooo`1Fooooo`03ool0
0?l0003ooooo0;3ooooo00?oo`00o`000?ooool0>?ooool0027ooooo00?o0000ooooooooool0E_oo
ool00ooo003oooooooooo`2booooo`03o`000?oooooooooo03Kooooo000Qooooo`03o`000?oooooo
oooo05Gooooo00?oo`00ooooooooool0]?ooool00ol0003oooooooooo`0eooooo`008Oooool3o`00
05Gooooo00?o0000ooooooooool0]Oooool00ol0003oooooooooo`0dooooo`008Oooool00ol0003o
ooooooooo`1Dooooo`03o`000?oooooooooo0;Oooooo0_l0000dooooo`008Oooool00ol0003ooooo
ooooo`1Dooooo`03o`000?oooooooooo0;Wooooo00?o0000ooooooooool0<Oooool0027ooooo00?o
0000ooooooooool0Doooool00ol0003oooooooooo`2kooooo`03o`000?oooooooooo033ooooo000Q
ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0^oooool2ool0037ooooo000Qoooo
o`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0__ooool00ooo003oooooooooo`0^oooo
o`008Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo0<3ooooo00?oo`00o`000?oo
ool0;Oooool0027ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`31ooooo`;oo`00
;Oooool0027ooooo0ol0001@ooooo`03ool00?oooooooooo0<Cooooo00?oo`00ooooooooool0:_oo
ool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003oo`00oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo03_ooooo
1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM037o
oooo00?oo`00ooooooooool02Oooool5o`0001_ooooo000Qooooo`03o`000?oooooooooo03gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool01?oo003oooooogMgMolb<S8ooooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool0<Oooool00ooo003oooooooooo`08ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0
027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo410@00gooooo00Coo`00
oooooooooooo0000?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0<Oooool00ooo003oooooooooo`08ooooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000<ooooo`05ool00?oo
ooooooooogMgMolb<S80?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00kooooo
00?oMgMgoc8b<_ooool0<oooool00ooo003o0000ooooo`08ooooo`03oiRHV?lQ8B7ok^k^01_ooooo
000Qooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000;ooooo`06ool0
0?l0003o8B4Qo`000?lb<S;oc<c<?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00eooooo`03ool00?l0003ooooo00Sooooo00?oMgMg
ofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo
410@00_ooooo00?oo`00o`000?ooool0@_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0>?ooool00ooo003o0000ooooo`08ooooo`03o`000?oooooo
oooo01Wooooo000Qooooo`?o0000?Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?oo`00
ooooool00000@oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@41006ooo
ool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo00?o
o`00ooooool000000ol0000nooooo`03oeEEEOmVIVKo000003oooooo00?oEEEEofIVI_l000003Ooo
ool4o`0003[ooooo00Wo0000oooooooooooooooooiRHV?l@413o0000ob4Q8Oo<c<`06oooool0027o
oooo00?o0000ooooooooool0Boooool00ooo003oooooooooo`3Cooooo`;o00008Oooool0027ooooo
00?o0000ooooooooool0Boooool00ooo003oooooooooo`3Eooooo`03o`000?oooooooooo01kooooo
000Qooooo`03o`000?oooooooooo04[ooooo00?oo`00ooooooooool0eoooool00ol0003ooooooooo
o`0Mooooo`008Oooool00ol0003oooooooooo`19ooooo`03ool00?oooooooooo0=Wooooo00?o0000
ooooooooool04_ooool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`19oooo
o`03ool00?oooooooooo0=[ooooo00?oo`00ooooooooool04Oooool01_o^k^ko8B4QohN7Qonj^[[o
0000omgMg@Cooooo000Joooooe;o000000?oo`00o`000?l00000g?l000000ooo003o0000o`000005
o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?o0000ool00?ooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Ooo
ool0027ooooo00?o0000ool00?ooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`;o00003_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool0
1?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool2o`000003ool00?oooooooooo04Gooooo00?o0000
ooooooooool0l?ooool2o`0000;ooooo0_l00004ooooo`008Oooool2o`000003ool00?oooooooooo
04Cooooo00?o0000ooooooooool0noooool0027ooooo00?o0000oooooooo0000A_ooool00ol0003o
ooooooooo`3kooooo`008Oooool01?l0003oooooo`000?oo0014ooooo`03o`000?oooooooooo0?co
oooo000Qooooo`04o`000?oooooo0000ool004?ooooo00?o0000ooooooooool0oOooool0027ooooo
0ol000000ooo003oooooooooo`11ooooo`03o`000?oooooooooo0?gooooo000Qooooo`05o`000?oo
ooooooooo`000?oo0000@Oooool00ooo003oooooooooo`3nooooo`008Oooool01Ol0003ooooooooo
ooooooooo`00047ooooo00?oo`00ooooooooool0o_ooool0027ooooo00Go0000oooooooooooooooo
ool00010ooooo`03ool00?oooooooooo0?oooooo000Qooooo`06o`000?ooooooooooooooool0003o
o`00?oooool00ooo003oooooooooo`3oooooo`008Oooool00ol0003oooooooooo`02ooooo`03ool0
0?oooooooooo03cooooo00?oo`00ooooooooool0ooooool1ooooo`008Oooool00ol0003ooooooooo
o`02ooooo`03ool00?oooooooooo03_ooooo00?oo`00o`000?ooool0ooooool2ooooo`008Oooool3
o`0000;ooooo00?o0000ool00?ooool0>oooool00ooo003oooooooooo`3oooooo`;ooooo000Qoooo
o`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0>Oooool00ooo003o0000ooooo`3ooooo
o`?ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0>Oooool00ooo003o
ooooooooo`3oooooo`?ooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
=oooool00ooo003oooooooooo`3oooooo`Cooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0=oooool00ooo003oooooooooo`3oooooo`Cooooo000Qooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0=Oooool00ooo003oooooooooo`3oooooo`Gooooo000Qoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=?ooool00ooo003o0000ooooo`3ooooo
o`Kooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=?ooool00ooo003o
ooooooooo`3oooooo`Kooooo000Qooooo`?o00001_ooool00ol0003oooooooooo`0booooo`03ool0
0?l0003ooooo0?oooooo1oooool0027ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo0?oooooo1oooool0027ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo0?oooooo2?ooool0027ooooo00?o0000oooo
ooooool01oooool00ol0003oo`00ooooo`0`ooooo`03o`000?oooooooooo0?oooooo2?ooool0027o
oooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`0^ooooo`03o`000?oooooooooo0?oo
oooo2Oooool0027ooooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`0]ooooo`03o`00
0?oooooooooo0?oooooo2_ooool0027ooooo00?o0000ooooooooool02?ooool00ol0003oo`00oooo
o`0]ooooo`03o`000?oooooooooo0?oooooo2_ooool0027ooooo0ol00009ooooo`03ool00?oooooo
oooo02_ooooo00?o0000ooooooooool0ooooool;ooooo`008Oooool00ol0003oooooooooo`09oooo
o`03ool00?oooooooooo02[ooooo00?o0000ooooooooool0ooooool<ooooo`008Oooool00ol0003o
ooooooooo`0:ooooo`03ool00?oooooooooo02Sooooo00?oo`00ooooooooool0ooooool=ooooo`00
8Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo003ooooo02Sooooo00?oo`00ooooooooool0
ooooool=ooooo`008Oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo02Kooooo00?o
o`00ooooooooool0ooooool>ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0<ooooo`03ool0
0?oooooooooo02Cooooo00?oo`00ooooooooool0ooooool?ooooo`001oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0
3?ooool00ooo003oooooooooo`0Tooooo`03ool00?oooooooooo0?oooooo3oooool000Oooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0000=ooooo`03ool0
0?oooooooooo02;ooooo00?oo`00ooooooooool0ooooool@ooooo`001oooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oo003ooooo027ooooo00?o0000ool00?ooool0oooooolAooooo`001oooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo00ko
oooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`3ooooooa7ooooo0007ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oo
oooo00?oo`00ooooooooool07_ooool00ooo003oooooooooo`3ooooooa;ooooo0007ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool07Oooool00ol0003oo`00ooooo`3ooooooa?ooooo0007ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oo003ooooo0?oooooo5?ooool0027ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Jooooo`03o`000?oo003ooooo0?oooooo5Oooool0027ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Hooooo`03o`000?oo003ooooo0?oooooo5_oo
ool0027ooooo0ol0000Booooo`03o`000?oooooooooo01Kooooo00?o0000ool00?ooool0oooooolG
ooooo`008Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0oooooolHooooo`008Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo017o
oooo0_l0003ooooooa_ooooo000Qooooo`03o`000?oooooooooo01Gooooo0_oo000@ooooo`03o`00
0?oooooooooo0?oooooo6oooool0027ooooo00?o0000ooooooooool05oooool00ooo003ooooooooo
o`0;ooooo`;o0000oooooolNooooo`008Oooool00ol0003oooooooooo`0Gooooo`03ool00?oooooo
oooo00[ooooo00?o0000ooooooooool0oooooolNooooo`008Oooool00ol0003oooooooooo`0Hoooo
o`;oo`0000?o0000ooooooooool01Oooool2o`000003ool00?oooooooooo0?oooooo7_ooool0027o
oooo0ol0000Jooooo`Coo`000_l00004ool00?oooooo8Oooool0027ooooo00?o0000ooooooooool0
7Oooool4ool00?oooooo9?ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o410@oooooooo
ool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool0
01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_oo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z?ooool00omgMgOoIVIV
ooooo`0Gooooo`03ofIVI_mgMgOooooo0:?ooooo0027ooooo`?o00004oooool00olQ8B7ogMgMoooo
o`07ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Xoooool007kooooo00OoQhN7
o`000?mEEEGoIVIVo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool02oooool01OnHV9So0000
o`000?m4A4Co^[Zj00;ooooo00?oV9RHoeEEEOooool01oooool01?mEEEGoV9RHooooooooool5o`00
00Wooooo00?oEEEEojVYZOooool00_ooool00onj^[[oA4A4ooooo`02ooooo`03ohN7QomVIVKooooo
01?ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM07[ooooo001nooooo`07oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP03ooooo`03o`000?oo
oooooooo00_ooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oMgMgooooo00Kooooo
00Wo0000oooooooooooooooooiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooooooo
oooo410@okZj^P?ooooo00?ok^k^o`000?ooool02oooool6o`0000Cooooo00?o0000ooooooooool0
1?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0NOooool007kooooo00Oo0000oooooooMgMgo<S8b
ooooooo^k^ko410@00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`;o
MgMg1oooool00olb<S;oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co410@omgMgOoo
oooo00001Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0N?ooool007kooooo00CoEEEEojVYZOoooooo00000_ooool01Ol0003ooooooooooooooooo
000000gooooo00?o0000ooooooooool01Oooool00oo^k^ko410@onk^kP06ooooo`03oc8b<_oooooo
oooo00?ooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7QhOoIVIVooooool00005ooooo`03o`000?oo
oooooooo00[ooooo1_l00004ooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0NOoo
ool007kooooo00?ogMgMob4Q8Oo^k^h00oooool00ol0003oooooooooo`02o`0000gooooo00?o0000
ooooooooool01_ooool00omEEEGoV9RHooooo`05ooooo`03o`000?o^k^kooooo00Cooooo00?oMgMg
ofIVI_ooool02_ooool01?oMgMgo410@ooooool00004ooooo`03onk^k_l0003ooooo01Gooooo00?o
0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<07[ooooo001oooooo`03oiRHV?mg
MgOooooo00;ooooo00?o0000ooooooooool03Oooool00ol@413o0000o`000003o`0000Gooooo00?o
gMgMoa0@4?ooool01Oooool00omEEEGoMgMgooooo`05ooooo`03o`000?oooooooooo00Sooooo1ol0
0002ooooo`03ogMgMomEEEGooooo01Gooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`1looooo`00U_ooool00ol0003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00WogMgM
oa0@4?o^k^koooooo`000?nj^[[ooooooiRHV?l@41004_ooool00oo^k^ko410@omgMg@0Fooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0O?ooool009Kooooo00?o0000ooooooooool0
1oooool00onj^[[oA4A4ooooo`05ooooo`08ogMgMomVIVKooooooiRHV?l@413o0000ob4Q8Oo<c<`B
ooooo`03ofIVI_mgMgOooooo01Cooooo00?oEEEEofIVI_l000003Oooool4o`0007_ooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.55) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .33605 L
.06244 .36245 L
.08426 .38662 L
.0949 .3959 L
.10458 .40266 L
.10911 .40524 L
.11403 .40762 L
.11828 .40931 L
.12297 .41077 L
.12536 .41136 L
.12793 .41187 L
.12935 .4121 L
.13065 .41227 L
.13197 .41242 L
.13319 .41253 L
.13431 .4126 L
.13551 .41265 L
.13619 .41267 L
.13683 .41268 L
.13803 .41267 L
.13919 .41264 L
.14025 .41259 L
.14141 .41252 L
.14264 .41241 L
.14518 .4121 L
.14759 .4117 L
.15211 .41067 L
.15698 .40918 L
.16227 .40711 L
.1718 .40227 L
.18061 .39661 L
.19927 .38132 L
.21987 .36024 L
.26008 .31097 L
.29876 .25966 L
.3399 .20732 L
.37953 .16326 L
.41764 .12888 L
.43889 .11341 L
.4582 .10171 L
.47851 .09177 L
.49724 .08473 L
.51643 .07956 L
.52653 .07764 L
.53212 .0768 L
.53723 .07619 L
.54207 .07572 L
.54666 .07539 L
.54918 .07525 L
Mistroke
.55151 .07515 L
.55283 .0751 L
.55407 .07507 L
.55476 .07505 L
.5555 .07504 L
.5568 .07502 L
.55795 .07501 L
.55901 .07501 L
.56019 .07501 L
.56144 .07502 L
.56276 .07503 L
.56401 .07506 L
.56513 .07509 L
.56634 .07512 L
.56855 .07521 L
.5709 .07532 L
.57511 .07559 L
.58002 .076 L
.58451 .07646 L
.59462 .07783 L
.60354 .07939 L
.61292 .08137 L
.65108 .09271 L
.67073 .10042 L
.69169 .10986 L
.73324 .13185 L
.77327 .15645 L
.81179 .18261 L
.85276 .21245 L
.89222 .24258 L
.93016 .27237 L
.97055 .30451 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .33623 L
.06244 .36302 L
.08255 .38544 L
.09396 .39536 L
.10458 .40257 L
.10961 .40528 L
.11508 .4077 L
.12023 .40948 L
.12269 .41016 L
.125 .4107 L
.12724 .41113 L
.12929 .41144 L
.13156 .4117 L
.13282 .41181 L
.13401 .41188 L
.13516 .41193 L
.13638 .41195 L
.13754 .41195 L
.13858 .41193 L
.13982 .41188 L
.14051 .41184 L
.14115 .41179 L
.14357 .41156 L
.14483 .4114 L
.14603 .41123 L
.14827 .41083 L
.15331 .40964 L
.15766 .40828 L
.1624 .40646 L
.17313 .40109 L
.18306 .39467 L
.20172 .37928 L
.22233 .35813 L
.26253 .3086 L
.30122 .25684 L
.34236 .20403 L
.38198 .15978 L
.42009 .12569 L
.44134 .11066 L
.46065 .09949 L
.48074 .09033 L
.4997 .08389 L
.50942 .08139 L
.51971 .0793 L
.5285 .07796 L
.53349 .07738 L
.53816 .07695 L
.54314 .0766 L
.54596 .07646 L
Mistroke
.5473 .07641 L
.54857 .07636 L
.54978 .07633 L
.55108 .0763 L
.55227 .07628 L
.55335 .07627 L
.55454 .07626 L
.55583 .07626 L
.55649 .07626 L
.55719 .07627 L
.55845 .07628 L
.55969 .0763 L
.56084 .07633 L
.56343 .07641 L
.56572 .0765 L
.56815 .07663 L
.57235 .07691 L
.57699 .0773 L
.58711 .07846 L
.59637 .07987 L
.61724 .08422 L
.6362 .08946 L
.65692 .09645 L
.69753 .11352 L
.73663 .13358 L
.77818 .1582 L
.81821 .18468 L
.85673 .21241 L
.8977 .24405 L
.93716 .27626 L
.9751 .3081 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Pooooo`_o0000VOooool001[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`2Iooooo`03o`000?oo003oo`0000goo`000_oo
ool7o`0009;ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0U?ooool6
ool001Sooooo00Co0000ool00?oo003oo`000_l0002<ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo093ooooo0_l00002ool002;ooooo1?oo00000ol0003oooooooooo`27
ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo08kooooo0_l000000ooo
ooooo`00ooooo`0Wooooo`?oo`0000?o0000ooooooooool0Q?ooool0027ooooo00?o0000oooooooo
ool0S?ooool2o`0002oooooo0_oo0002o`0008?ooooo000Qooooo`03o`000?oooooooooo08[ooooo
0_l0000cooooo`?oo`000_l00020ooooo`008Oooool3o`0008Sooooo0_l0000hooooo`03ool00?oo
oooo000000;o0000OOooool0027ooooo00?o0000ooooooooool0QOooool3ool003oooooo0_l0001k
ooooo`008Oooool00ol0003oooooooooo`23ooooo`;oo`0000?o0000ooooooooool0@Oooool3o`00
07Sooooo000Qooooo`03o`000?oooooooooo087ooooo0_oo00000ol0003oooooooooo`16ooooo`;o
0000M_ooool0027ooooo00?o0000ooooooooool0Ooooool2ool00003o`000?oooooooooo04Sooooo
0ooo00000ol0003oooooooooo`1booooo`008Oooool00ol0003oooooooooo`1nooooo`03ool00?l0
003ooooo04kooooo0ooo001booooo`008Oooool00ol0003oooooooooo`1looooo`;oo`00E?ooool2
ool0073ooooo000Qooooo`?o0000Noooool00ooo003o0000ooooo`1Fooooo`03ool00?l0003ooooo
06gooooo000Qooooo`03o`000?oooooooooo07[ooooo00?oo`00ooooooooool0F?ooool2ool006go
oooo000Qooooo`03o`000?oooooooooo07Wooooo00?oo`00ooooooooool0Foooool2ool006_ooooo
000Qooooo`03o`000?oooooooooo07Oooooo0_l0001Pooooo`03ool00?l0003ooooo06Sooooo000Q
ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0HOooool00ooo003o0000o`00001W
ooooo`008Oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo06Gooooo00?o0000oooo
ooooool0I?ooool0027ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`1Wooooo`;o
0000I?ooool0027ooooo0ol0001cooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
HOooool0027ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1/ooooo`;o0000HOoo
ool0027ooooo00?o0000ooooooooool0LOooool00ooo003oooooooooo`1_ooooo`;oo`00Goooool0
027ooooo00?o0000ooooooooool0L?ooool00ooo003oooooooooo`1aooooo`03o`000?oo003oo`00
05gooooo000Qooooo`03o`000?oooooooooo06oooooo00?oo`00ooooooooool0M?ooool00ol0003o
o`00ool0001Kooooo`008Oooool00ol0003oooooooooo`1^ooooo`03ool00?oooooooooo07Kooooo
0_l00002ool005Wooooo000Qooooo`03o`000?oooooooooo06gooooo00?oo`00ooooooooool0NOoo
ool00ol0003oooooool0001Hooooo`008Oooool00ol0003oooooooooo`1/ooooo`03ool00?oooooo
oooo07_ooooo0_l00002ool005Kooooo000Qooooo`?o0000Joooool00ooo003o0000ooooo`1noooo
o`04o`000?ooooooo`00ool005Cooooo000Qooooo`03o`000?oooooooooo06[ooooo00?oo`00o`00
0?ooool0P?ooool2o`000003oooooooo003ooooo05;ooooo000Qooooo`03o`000?oooooooooo06Wo
oooo00?oo`00o`000?ooool0Poooool00ol0003oooooool0001Booooo`008Oooool00ol0003ooooo
ooooo`1Xooooo`03ool00?l0003ooooo08Gooooo0_l0001Booooo`008Oooool00ol0003ooooooooo
o`1Wooooo`03ool00?l0003ooooo08Sooooo00?o0000ooooooooool0Coooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo
00?o0000ooooooooool0I_ooool00ooo003o0000ooooo`2:ooooo`;o0000Coooool000Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`00
0?oooooooooo06Kooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1<ooooo`001Ol0
0002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000
I_ooool00ol0003oooooooooo`2=ooooo`;o0000C?ooool000Oooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0IOooool00ol0003ooooo
ooooo`2@ooooo`03o`000?oooooooooo04Wooooo0007ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0I?ooool00ol0003o
ooooooooo`2Booooo`03o`000?oo003oo`0004Sooooo0007ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06?ooooo00?o0000oooooooo
ool0UOooool00ol0003oo`00ooooo`16ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo09Oo
oooo00?o0000ool00?oo0000AOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00001Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo09Wooooo0_l000000ooo003o
ooooooooo`12ooooo`008Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo09cooooo
00?o0000ool00?ooool0@_ooool0027ooooo00?o0000ooooooooool0Goooool00ooo003o0000oooo
o`2Nooooo`03o`000?oo003oo`00047ooooo000Qooooo`?o0000Goooool00ooo003oooooooooo`2P
ooooo`03o`000?oo003ooooo03oooooo000Qooooo`03o`000?oooooooooo05kooooo00?oo`00oooo
ooooool0X_ooool00ol0003oo`00ooooo`0nooooo`008Oooool00ol0003oooooooooo`1Mooooo`03
ool00?oooooooooo0:Cooooo00?o0000ool00?ooool0?Oooool0027ooooo00?o0000ooooooooool0
G?ooool00ooo003oooooooooo`2Wooooo`03ool00?oooooooooo03_ooooo000Qooooo`03o`000?oo
oooooooo05cooooo00?oo`00ooooooooool0Z?ooool00ol0003oooooooooo`0jooooo`008Oooool0
0ol0003oooooooooo`1Kooooo`03ool00?oooooooooo0:[ooooo00?o0000ooooooooool0>Oooool0
027ooooo00?o0000ooooooooool0F_ooool00ooo003oooooooooo`2/ooooo`;o0000>Oooool0027o
oooo0ol0001Iooooo`03ool00?oooooooooo0:oooooo00?o0000ooooooooool0=_ooool0027ooooo
00?o0000ooooooooool0F?ooool00ol0003oo`00ooooo`2aooooo`03o`000?oooooooooo03Gooooo
000Qooooo`03o`000?oooooooooo05Oooooo00?o0000ool00?ooool0/oooool2o`0003Gooooo000Q
ooooo`03o`000?oooooooooo05Oooooo00?oo`00ooooooooool0]Oooool2ool003?ooooo000Qoooo
o`03o`000?oooooooooo05Kooooo00?oo`00ooooooooool0]oooool00ol0003oo`00ooooo`0aoooo
o`008Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo0;Wooooo00?o0000ool00?oo
ool0<?ooool0027ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`2kooooo`03o`00
0?oo003oo`0002oooooo000Qooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0__oo
ool00ol0003oo`00ooooo`0]ooooo`008Oooool3o`0005?ooooo00?o0000ooooooooool0_oooool0
0ol0003oo`00ooooo`0/ooooo`008Oooool00ol0003oooooooooo`0mooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bo`00000mooooo`Co000000?o
410@ooooooooool0>oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd0;oooool00ol0003oo`00ool0000;ooooo`Go00006oooool0027ooooo00?o
0000ooooooooool0?Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03o`00
0?lb<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`0_ooooo`03o`000?ooooooo`0000[ooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?ooooooooooooooool@
41003_ooool00ol0003oooooo`00000oooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0_ooooo`;o000000?oo`00ooooooooool02?ooool00onHV9So
8B4Qonk^kP0Looooo`008Oooool00ol0003oooooooooo`0mooooo`05o`000?ooooooooooooooool0
00003_ooool00ol0003oMgMgoc8b<P0oooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool03_ooool00omgMgOo<S8booooo`0booooo`03o`000?oo003ooooo00Wooooo00?oV9RHob4Q8Oo^
k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ool00?l0003o<S8bolc<c00oooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<03Cooooo00?o0000ooooooooool02Oooool0
0omgMgOoIVIVooooo`0Jooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00ol0003oo`00ooooo`11ooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0gooooo`;o00002_ooool00ol0003oooooooooo`0I
ooooo`008Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oo003o
oooo04;ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool00oooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`03ool00?l0
003o000000;o0000?_ooool00omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0
000iooooo`03o`000?oooooooooo00;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Kooooo`008Ooo
ool00ol0003oooooooooo`1<ooooo`03ool00?oooooooooo0=7ooooo00?o0000ooooooooool08Ooo
ool0027ooooo00?o0000ooooooooool0Boooool00ooo003oooooooooo`3Cooooo`;o00008Oooool0
027ooooo00?o0000ooooooooool0B_ooool00ol0003oo`00ooooo`3Fooooo`03ool00?oooooooooo
01kooooo000Qooooo`03o`000?oooooooooo04[ooooo00?oo`00ooooooooool0eoooool00ooo003o
ooooooooo`0Cooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo04Wooooo
00?oo`00ooooooooool0fOooool00ooo003o0000ooooo`0Booooo`06onk^k_lQ8B7oQhN7okZj^_l0
003ogMgM1?ooool001[ooooo1ol000000ooo003o0000o`000018o`000003ool00?l0003o00000=_o
00000_oo0007o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?oo`00oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo003ooooo00gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Cok^k^ob4Q8Ol@
413ok^k^1Oooool0027ooooo00?o0000ool00?ooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03
ool00?l0003ooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo017ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000oooooooo
0000A_ooool00ooo003oooooooooo`3aooooo`;o00000_ooool2o`0000Cooooo000Qooooo`04o`00
0?oooooo0000ool004Cooooo00?o0000ooooooooool0o?ooool0027ooooo00Co0000oooooooooooo
o`00@oooool00ol0003oooooooooo`3mooooo`008Oooool01Ol0003oooooooooooooooooo`00047o
oooo00?o0000ooooooooool0o_ooool0027ooooo00Ko0000ooooooooooooooooo`000?oo0010oooo
o`03o`000?oooooooooo0?kooooo000Qooooo`?o00000_ooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo0?oooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`3oooooo`7ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`3oooooo`;ooooo000Qooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`3oooooo`?ooooo000Qoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=oooool00ooo003oooooooooo`3ooooo
o`?ooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=Oooool00ooo003o
ooooooooo`3oooooo`Cooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
=?ooool00ooo003oooooooooo`3oooooo`Gooooo000Qooooo`?o00001oooool00ol0003oo`00oooo
o`0booooo`03ool00?oooooooooo0?oooooo1_ooool0027ooooo00?o0000ooooooooool02?ooool0
0ooo003oooooooooo`0`ooooo`03ool00?oooooooooo0?oooooo1oooool0027ooooo00?o0000oooo
ooooool02Oooool00ooo003oooooooooo`0^ooooo`03ool00?oooooooooo0?oooooo2?ooool0027o
oooo00?o0000ooooooooool02Oooool00ol0003oo`00ooooo`0]ooooo`03ool00?oooooooooo0?oo
oooo2Oooool0027ooooo00?o0000ooooooooool02_ooool00ol0003oo`00ooooo`0[ooooo`03ool0
0?oooooooooo0?oooooo2_ooool0027ooooo00?o0000ooooooooool02oooool00ol0003oo`00oooo
o`0Yooooo`03ool00?oooooooooo0?oooooo2oooool0027ooooo00?o0000ooooooooool03?ooool0
0ol0003oo`00ooooo`0Wooooo`03ool00?oooooooooo0?oooooo3?ooool0027ooooo00?o0000oooo
ooooool03Oooool00ol0003oo`00ooooo`0Uooooo`03ool00?oooooooooo0?oooooo3Oooool0027o
oooo0ol0000>ooooo`03o`000?oo003ooooo02;ooooo00?o0000ool00?ooool0ooooool?ooooo`00
8Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo003ooooo023ooooo00?o0000ooooooooool0
ooooool@ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo003ooooo01kooooo00?o
0000ooooooooool0oooooolAooooo`008Oooool00ol0003oooooooooo`0Booooo`03ool00?l0003o
oooo01_ooooo00?o0000ooooooooool0oooooolBooooo`008Oooool00ol0003oooooooooo`0Coooo
o`03ool00?l0003ooooo01Wooooo00?o0000ooooooooool0oooooolCooooo`008Oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo01Gooooo0_l0003ooooooaKooooo000Qooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool04_ooool00ooo003o0000ooooo`3ooooooaOooooo
000Qooooo`?o00005oooool3o`00013ooooo00?oo`00ooooooooool0oooooolHooooo`008Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo0ooo003ooooooa_ooooo000Qoooo
o`03o`000?oooooooooo01_ooooo00?o0000ool00?oo00002Ooo00000ol0003oooooooooo`3ooooo
oa_ooooo000Qooooo`03o`000?oooooooooo01kooooo1_l0003oooooob7ooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?o
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooo
ooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004oooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGo
oooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00:Cooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2Wooooo`00
Poooool3o`0001Cooooo00?o8B4QomgMgOooool01_ooool00ooMgMgo410@onk^kP0Hooooo`03onk^
k_l@413ogMgM0:Oooooo001kooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP02ooooo`03
o`000?oooooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03oiRHV?mEEEGooooo
00Kooooo00?oEEEEoiRHV?ooool00_ooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool01_nj
^[[oA4A4ooooooooooooQhN7ofIVIQGooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00?ooooo00GoA4A4o`000?l0003o<S8bomgMg@1eooooo`00
Noooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00_ooool00ol0003oooooooooo`0;oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ogMgMooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o
^[Zj0_ooool00oo^k^ko0000ooooo`0;ooooo`Ko00001Oooool00ol0003oooooooooo`04ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`05ooooo`03ogMgMolb<S;ooooo07Cooooo001kooooo`07o`00
0?oooooogMgMoc8b<_ooooook^k^oa0@4002ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01_ooool2ogMgM`Kooooo00?o<S8booooooooool00oooool00onHV9So8B4Qonk^kP0<oooo
o`04oa0@4?oMgMgoooooo`0000Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Loooool007_ooooo00CoEEEEojVY
ZOoooooo00000_ooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00Kooooo00?o
k^k^oa0@4?o^k^h01Oooool00olb<S;oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00Co
QhN7ofIVI_oooooo00001?ooool00ol0003oooooooooo`0:ooooo`Ko00001Oooool00ol0003ooooo
ooooo`0>ooooo`03ogMgMolb<S;ooooo00Gooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00?o
gMgMob4Q8Oo^k^h00oooool01?l0003oooooo`000?l0000=ooooo`03o`000?oooooooooo00Oooooo
00?oEEEEoiRHV?ooool01?ooool00ol0003ok^k^ooooo`05ooooo`03ogMgMomVIVKooooo00[ooooo
00CogMgMoa0@4?oooooo00000oooool00oo^k^ko0000ooooo`0Fooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c003ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0MOooool0
07cooooo00?oV9RHogMgMoooool00_ooool00ol0003oooooooooo`0<ooooo`03oa0@4?l0003o0000
00?o00001_ooool00ooMgMgo410@ooooo`04ooooo`03oeEEEOmgMgOooooo00Kooooo00?o0000oooo
ooooool02?ooool7o`000003oooooomgMgOoEEEE01Oooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo00So
oooo00?oEEEEoiRHV?ooool00oooool00ooMgMgo410@onk^kP02ooooo`05o`000?nj^[[ooooooiRH
V?l@41004Oooool00oo^k^ko410@omgMg@0Gooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1gooooo`00T_ooool00ol0003oooooooooo`08ooooo`03
okZj^_m4A4Cooooo00Cooooo00WoMgMgofIVI_oooooooooooiRHV?l@413o0000ob4Q8Oo<c<`04Ooo
ool00omVIVKoMgMgooooo`0Eooooo`03oeEEEOmVIVKo000000gooooo1?l00004ooooo`Co0000M_oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .29673 L
.06244 .28587 L
.07286 .28156 L
.08255 .27858 L
.08813 .27733 L
.0932 .27649 L
.096 .27614 L
.09748 .276 L
.09905 .27586 L
.10042 .27577 L
.10192 .27569 L
.10258 .27566 L
.1033 .27563 L
.10458 .2756 L
.10526 .27559 L
.10591 .27558 L
.10712 .27558 L
.10841 .27559 L
.10915 .2756 L
.10982 .27562 L
.11095 .27566 L
.11219 .27572 L
.11468 .27587 L
.11744 .2761 L
.12039 .27642 L
.12571 .27715 L
.13622 .27912 L
.1458 .28136 L
.1665 .28686 L
.18565 .29162 L
.19524 .29357 L
.20423 .29501 L
.20913 .29563 L
.21362 .29608 L
.2186 .29645 L
.22122 .29658 L
.22254 .29664 L
.22398 .29668 L
.2253 .29671 L
.22652 .29674 L
.22715 .29674 L
.22785 .29675 L
.22858 .29675 L
.22926 .29675 L
.23052 .29674 L
.23167 .29673 L
.2323 .29671 L
.233 .2967 L
.23425 .29666 L
Mistroke
.2366 .29657 L
.2391 .29643 L
.24359 .2961 L
.24925 .29551 L
.25458 .29479 L
.26454 .29303 L
.27433 .29079 L
.28466 .28791 L
.30314 .2816 L
.34117 .26502 L
.38164 .24443 L
.4206 .22441 L
.46202 .2053 L
.50191 .19054 L
.52017 .18522 L
.5403 .18047 L
.56011 .17696 L
.57096 .17554 L
.57582 .17502 L
.58113 .17453 L
.5859 .17416 L
.59099 .17384 L
.59381 .17369 L
.59636 .17359 L
.59896 .17349 L
.60135 .17343 L
.60358 .17338 L
.6047 .17336 L
.60593 .17335 L
.60717 .17333 L
.60786 .17333 L
.60849 .17333 L
.60972 .17333 L
.61088 .17333 L
.61197 .17333 L
.61312 .17334 L
.6141 .17335 L
.61519 .17337 L
.6176 .17342 L
.61987 .17348 L
.62456 .17365 L
.62969 .1739 L
.63504 .17425 L
.64003 .17465 L
.65853 .17672 L
.66903 .1783 L
.67896 .18006 L
.69754 .18401 L
.73597 .1947 L
.77686 .20931 L
Mistroke
.81623 .22599 L
.85409 .24393 L
.89439 .26454 L
.93318 .28537 L
.97443 .30804 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .29825 L
.06244 .28751 L
.07286 .28306 L
.08255 .27987 L
.08813 .27848 L
.0932 .2775 L
.096 .27707 L
.09905 .27669 L
.10192 .27641 L
.10329 .27631 L
.10458 .27623 L
.10574 .27617 L
.10701 .27612 L
.10817 .27609 L
.10924 .27607 L
.11051 .27606 L
.11166 .27606 L
.1123 .27606 L
.11299 .27608 L
.11425 .2761 L
.11534 .27614 L
.11654 .27619 L
.11897 .27633 L
.12121 .27649 L
.12331 .27668 L
.12851 .27728 L
.13326 .27796 L
.14393 .27993 L
.18378 .28948 L
.202 .29329 L
.20699 .29413 L
.21237 .29491 L
.21702 .29548 L
.22211 .29597 L
.22454 .29616 L
.22713 .29632 L
.22857 .2964 L
.22987 .29646 L
.2312 .29651 L
.23242 .29654 L
.23356 .29657 L
.23476 .29659 L
.23596 .2966 L
.23665 .2966 L
.23729 .2966 L
.23844 .2966 L
.2395 .29658 L
.24072 .29656 L
.24188 .29653 L
Mistroke
.24321 .29649 L
.24441 .29644 L
.2471 .29629 L
.24959 .29612 L
.25193 .29593 L
.2572 .29536 L
.26289 .29456 L
.27242 .29279 L
.28287 .29022 L
.30394 .28325 L
.34442 .26456 L
.38338 .24308 L
.42479 .2205 L
.46469 .20197 L
.50307 .18868 L
.52289 .18372 L
.53301 .18169 L
.54391 .17985 L
.55409 .17846 L
.56342 .17746 L
.57233 .17672 L
.57682 .17643 L
.58171 .17618 L
.58426 .17607 L
.58701 .17597 L
.58944 .1759 L
.59201 .17584 L
.59433 .1758 L
.59565 .17579 L
.59688 .17578 L
.59801 .17577 L
.59904 .17576 L
.60023 .17576 L
.60136 .17576 L
.60256 .17577 L
.60324 .17577 L
.60389 .17578 L
.60518 .17579 L
.60657 .17581 L
.60909 .17585 L
.6114 .1759 L
.61672 .17607 L
.62232 .17631 L
.63185 .17687 L
.64204 .17767 L
.6604 .17964 L
.68172 .18274 L
.70186 .18646 L
.7403 .19576 L
.78119 .20901 L
Mistroke
.82056 .22509 L
.85841 .24328 L
.89872 .2648 L
.93751 .28663 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`2[oooooaOo0000P_oo
ool0027ooooo00?o0000ooooooooool0X_ooool3o`0000Koo`002_ooool=ool000Go0000OOooool0
027ooooo00?o0000ooooooooool0WOooool00ol0003oo`00ool00005ool001gooooo0ooo0002oooo
o`Oo0000M_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0V_ooool01?l0003oo`00ool00?oo
000`ooooo`Go0000LOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo09Kooooo1?l0000eooooo`Goo`000_l0
001^ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`02ooooo`?o0000T_ooool4o`0003kooooo1?oo00000ol0003oooooooooo`1Yooooo`001oooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooooooo
o`2?ooooo`;oo`0000?o0000ooooooooool0A?ooool4ool006Sooooo0007ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0
S?ooool3ool004gooooo0ooo001Uooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`29ooooo`?oo`00Doooool3o`0006;ooooo
0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo08Kooooo0ooo00000ol0003oooooooooo`1Fooooo`?o0000Goooool000Oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`24ooooo`;oo`00
00?o0000ooooooooool0G?ooool3o`0005cooooo000Qooooo`03o`000?oooooooooo08;ooooo0_oo
00000ol0003oooooooooo`1Qooooo`03o`000?oo003oo`0000;oo`00Eoooool0027ooooo00?o0000
ooooooooool0POooool00ooo003o0000ooooo`1Wooooo`;o00000ooo001Dooooo`008Oooool3o`00
07kooooo0ol0001]ooooo`;o000000?oo`00ooooooooool0DOooool0027ooooo00?o0000oooooooo
ool0O?ooool2o`0007;ooooo0_l0001Booooo`008Oooool00ol0003oooooooooo`1jooooo`;o0000
M_ooool3o`0004oooooo000Qooooo`03o`000?oooooooooo07Oooooo0_oo00000ol0003ooooooooo
o`1iooooo`;o0000COooool0027ooooo00?o0000ooooooooool0MOooool2ool00003o`000?oooooo
oooo07gooooo0_l0001;ooooo`008Oooool00ol0003oooooooooo`1dooooo`03ool00?l0003ooooo
08;ooooo00?o0000ool00?oo0000B?ooool0027ooooo00?o0000ooooooooool0L_ooool2ool008Oo
oooo00?o0000ool00?oo0000A_ooool0027ooooo0ol0001`ooooo`;oo`00Roooool00ol0003oo`00
ool00014ooooo`008Oooool00ol0003oooooooooo`1^ooooo`03o`000?oo003ooooo08kooooo00?o
0000ool00?oo0000@_ooool0027ooooo00?o0000ooooooooool0K?ooool00ol0003oo`00ool0002B
ooooo`03o`000?oo003oo`00043ooooo000Qooooo`03o`000?oooooooooo06[ooooo00?o0000ool0
0?oo0000U_ooool00ol0003oo`00ool0000nooooo`008Oooool00ol0003oooooooooo`1Xooooo`;o
000000?oo`00ooooooooool0V?ooool00ol0003oo`00ool0000looooo`008Oooool00ol0003ooooo
ooooo`1Vooooo`;o0000Woooool00ol0003oo`00ooooo`0jooooo`008Oooool00ol0003ooooooooo
o`1Uooooo`03o`000?oooooooooo0:7ooooo0_l0000iooooo`008Oooool00ol0003oooooooooo`1S
ooooo`;o0000Y_ooool2o`0003Oooooo000Qooooo`?o0000HOooool2o`000:[ooooo0_l0000eoooo
o`008Oooool00ol0003oooooooooo`0mooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0<ooooo`;oo`00;oooool4o`000003oa0@4?oooooo
oooo03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM02Sooooo0_l0000Cooooo`Go00006oooool0027ooooo00?o0000ooooooooool0?Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Wooooo0_oo
000cooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool0:Oooool2ool0017ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Ooo
ool00ol0003oooooooooo`0mooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooo
ooooo`05ooooo`?oo`00=Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0:Oooool00ol0003oo`00ool0000@ooooo`03oiRHV?lQ8B7ok^k^01cooooo
000Qooooo`03o`000?oooooooooo017ooooo3ol0000Mooooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`04ooooo`;oo`00>?ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo00kooooo00?oMgMgoc8b<_ooool0;?ooool00ol0003oo`00ool0000?ooooo`03oiRH
V?lQ8B7ok^k^01_ooooo000Qooooo`03o`000?oooooooooo00oooooo1Ooo000:ooooo`Soo`005ooo
ool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c003ooooo`;o
o`00>_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c00_ooooo`03o`000?oo003oo`0000kooooo00?oMgMgofIVI_ooool06_ooool0027o
oooo00?o0000ooooooooool02oooool01?l0003oo`00ool00?oo000Dooooo`?o00000ooo000Doooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`03ooooo`;oo`00??ooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<_ooool2
o`0000;oo`003Oooool00ol0003oooooooooo`0Iooooo`008Oooool3o`0000Sooooo0_l00002ool0
01cooooo00Go0000ool00?oo003oo`00o`00000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool01?l0003oooooooooool00002ool003kooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo03Cooooo0_l00002ool000Oooooo00Go0000okZj^_oooooo
V9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oo003oo`0002;ooooo
0_oo0002o`0000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000?_ooool00omEEEGo
IVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000eooooo`;o000000?oo`00oooooooo
ool01?ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qooooo`03o`000?oooooooooo00Go
oooo00?o0000ool00?oo0000:?ooool3o`0001Cooooo1ol0003?ooooo`03o`000?oo003ooooo02Co
oooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ool00?ooool0;?ooool5o`00017oo`00
e_ooool00ooo003o0000ooooo`0Rooooo`008Oooool00ol0003oooooooooo`02ooooo`;o0000>?oo
ool4o`000>7ooooo00?o0000ooooooooool08?ooool0027ooooo00?o0000ooooooooool00_l0003o
ooooob7ooooo0_l0000Fooooo`;o00000_ooool2o`0000Cooooo000Qooooo`?o0000oooooolUoooo
o`;o00005?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooooooo0000>_l0000<
ooooo`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Q
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0A
ooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03o`000?oooooooooo0?oooooo>oooool2
o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000
ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000
ooooooooool00_ooool3o`000?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000?
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oo
oooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodGooooo0007
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`006?oo
ool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Co
oooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOoo
ool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Hoooo
o`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0
003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00:Sooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2Sooooo`00Qoooool3o`00
01?ooooo00?o8B4QomgMgOooool01oooool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@413ogMgM
0:?ooooo001nooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP03ooooo`03o`000?oooooo
oooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P02ooooo`03oiRHV?mEEEGooooo00Oooooo00Co
EEEEoiRHV?oooooooooo1Ol00009ooooo`03oeEEEOnYZJWooooo00;ooooo00?o^[ZjodA4A?ooool0
0_ooool00on7QhOoIVIVooooo`0Cooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo
00Gok^k^oc8b<_l0003o410@olc<c01kooooo`00O_ooool01ol@413ogMgMogMgMolQ8B7oooooohN7
QomVIVH00oooool00ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool0
0ol0003ogMgMooooo`06ooooo`09o`000?oooooooooooooooonHV9So8B4Qonk^k_ooooooA4A400[o
oooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X3ooooo`03onk^k_l0003ooooo00_ooooo1_l00004
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40Nooo
ool007kooooo00Oo0000oooooooMgMgo<S8booooooo^k^ko410@00?ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`05ooooo`;oMgMg1oooool00olb<S;oooooooooo`02ooooo`03oiRH
V?lQ8B7ok^k^00cooooo00Co410@omgMgOoooooo00001Oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00001kooooo`00O_ooool01?mEEEGo
ZJVYooooool00002ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`05
ooooo`03onk^k_l@413ok^k^00Kooooo00?o<S8booooooooool00oooool00onHV9So8B4Qonk^kP0;
ooooo`04ohN7QomVIVKoooooo`0000Gooooo00?o0000ooooooooool02_ooool6o`0000Cooooo00?o
0000ooooooooool02_ooool01Ol0003oV9RHoooooonHV9So8B4Q07_ooooo001nooooo`03omgMgOlQ
8B7ok^k^00?ooooo00?o0000ooooooooool00_l0000=ooooo`03o`000?oooooooooo00Kooooo00?o
EEEEoiRHV?ooool01Oooool00ol0003ok^k^ooooo`04ooooo`03ogMgMomVIVKooooo00[ooooo00Co
gMgMoa0@4?oooooo00001?ooool00oo^k^ko0000ooooo`0Eooooo`03o`000?oooooooooo00[ooooo
00Go0000oeEEEOl0003o410@olc<c01kooooo`00Ooooool00onHV9SoMgMgooooo`02ooooo`03o`00
0?oooooooooo00gooooo00?o410@o`000?l000000ol00005ooooo`03omgMgOl@413ooooo00Gooooo
00?oEEEEogMgMoooool01Oooool00ol0003oooooooooo`08ooooo`Oo00000_ooool00omgMgOoEEEE
ooooo`0Eooooo`03o`000?oooooooooo00[ooooo00?oEEEEohN7Qoooool0OOooool009Kooooo00?o
0000ooooooooool01oooool00omEEEGoV9RHooooo`04ooooo`09omgMgOl@413ok^k^ooooool0003o
^[ZjoooooonHV9So410@01;ooooo00?ok^k^oa0@4?oMgMd05_ooool00ol0003oooooooooo`0:oooo
o`03omgMgOl@413oV9RH07gooooo002Fooooo`03o`000?oooooooooo00Oooooo00?o^[ZjodA4A?oo
ool01Oooool02?mgMgOoIVIVoooooonHV9So410@o`000?lQ8B7oc<c<4_ooool00omVIVKoMgMgoooo
o`0Dooooo`03oeEEEOmVIVKo000000gooooo00Coc<c<odA4A?l0003o410@Noooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.65) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .27166 L
.06244 .2354 L
.08426 .20222 L
.0949 .18931 L
.10458 .17963 L
.11403 .17216 L
.12297 .16694 L
.12787 .16483 L
.1324 .16335 L
.13476 .16276 L
.13737 .16224 L
.13868 .16204 L
.14009 .16186 L
.14142 .16173 L
.14264 .16165 L
.14392 .16159 L
.14514 .16157 L
.14622 .16157 L
.1474 .1616 L
.14869 .16167 L
.14934 .16172 L
.15005 .16178 L
.15248 .16207 L
.15476 .16244 L
.15721 .16295 L
.16162 .16415 L
.16719 .16616 L
.17246 .16855 L
.18234 .17418 L
.20225 .18929 L
.22067 .2064 L
.25994 .24628 L
.29769 .28113 L
.31866 .29699 L
.33789 .30893 L
.35674 .31819 L
.36633 .32201 L
.37658 .32543 L
.38693 .32824 L
.39632 .33025 L
.40577 .33179 L
.41469 .33282 L
.41932 .33321 L
.42441 .33351 L
.42698 .33362 L
.42839 .33367 L
.42973 .33371 L
.43097 .33374 L
.43163 .33375 L
Mistroke
.43233 .33376 L
.43356 .33377 L
.4347 .33378 L
.43595 .33378 L
.4371 .33378 L
.43836 .33377 L
.439 .33376 L
.43969 .33375 L
.44087 .33373 L
.44212 .33371 L
.44439 .33364 L
.44675 .33355 L
.44898 .33345 L
.45316 .33322 L
.46284 .33245 L
.47311 .33134 L
.49154 .32869 L
.52934 .32149 L
.5696 .31275 L
.60834 .3047 L
.64953 .29754 L
.67009 .2947 L
.6892 .29256 L
.70767 .29097 L
.71799 .29029 L
.72737 .28979 L
.73223 .28959 L
.73737 .2894 L
.74182 .28927 L
.74659 .28916 L
.74927 .28911 L
.75171 .28908 L
.75417 .28905 L
.75651 .28903 L
.75782 .28902 L
.75854 .28902 L
.75921 .28901 L
.7604 .28901 L
.76172 .28901 L
.76241 .28901 L
.76315 .28901 L
.76445 .28901 L
.76518 .28902 L
.76586 .28902 L
.7674 .28903 L
.76867 .28904 L
.77002 .28905 L
.77244 .28908 L
.77791 .28917 L
.78263 .28928 L
Mistroke
.78783 .28943 L
.79743 .28978 L
.80641 .29021 L
.82667 .29148 L
.8452 .29297 L
.88493 .29705 L
.92315 .30179 L
.96381 .3073 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .27083 L
.06244 .23352 L
.08255 .20253 L
.09396 .18883 L
.10458 .17875 L
.10961 .17489 L
.11508 .17135 L
.11989 .16879 L
.125 .16664 L
.12959 .16519 L
.13221 .16456 L
.13466 .1641 L
.13581 .16393 L
.1369 .16378 L
.13789 .16368 L
.13895 .16358 L
.1401 .16351 L
.14116 .16346 L
.14243 .16343 L
.14357 .16344 L
.14477 .16346 L
.1459 .16352 L
.14713 .1636 L
.14845 .16372 L
.15114 .16406 L
.1536 .16448 L
.15833 .16558 L
.16282 .16697 L
.17279 .17113 L
.18364 .17718 L
.20341 .19147 L
.22442 .20986 L
.26217 .24623 L
.30238 .28264 L
.34106 .31012 L
.3611 .32056 L
.3713 .32483 L
.3822 .32862 L
.39255 .3315 L
.40194 .33352 L
.40648 .3343 L
.41139 .33501 L
.41569 .33551 L
.42031 .33594 L
.42287 .33612 L
.4252 .33626 L
.42755 .33637 L
.42978 .33644 L
.43103 .33647 L
Mistroke
.43171 .33649 L
.43236 .3365 L
.43362 .33651 L
.43476 .33652 L
.43542 .33652 L
.43612 .33652 L
.43737 .33651 L
.43806 .33651 L
.43871 .3365 L
.44019 .33647 L
.4415 .33644 L
.44292 .33639 L
.44551 .33628 L
.45035 .336 L
.456 .33555 L
.46123 .33502 L
.47993 .33232 L
.50055 .32819 L
.5408 .31808 L
.57954 .3079 L
.59923 .30319 L
.62074 .2987 L
.64154 .29516 L
.66041 .2927 L
.67053 .29169 L
.68006 .29093 L
.69013 .29032 L
.6958 .29007 L
.70102 .28989 L
.70571 .28977 L
.70834 .28973 L
.71074 .28969 L
.71183 .28968 L
.71298 .28967 L
.71424 .28966 L
.71541 .28966 L
.71649 .28965 L
.71751 .28965 L
.71862 .28965 L
.71983 .28965 L
.72112 .28966 L
.72233 .28967 L
.72365 .28968 L
.72507 .28969 L
.72796 .28973 L
.7306 .28978 L
.73568 .2899 L
.74048 .29005 L
.75019 .29043 L
.76047 .29095 L
Mistroke
.77891 .29214 L
.81677 .29516 L
.85708 .29863 L
.89587 .3019 L
.93711 .30548 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo1_l0003o
oooooakooooo000Qooooo`03o`000?oooooooooo01gooooo00Go0000ool00?oo003oo`00o`000004
ooooo`Co0000oooooolKooooo`008Oooool3o`0001cooooo0_oo000<ooooo`;o0000oooooolIoooo
o`008Oooool00ol0003oooooooooo`0Iooooo`?oo`003oooool3ool00003o`000?oooooooooo0?oo
oooo5?ooool0027ooooo00?o0000ooooooooool06?ooool00ooo003o0000o`00000Cooooo`03ool0
0?l0003o00000?oooooo5?ooool0027ooooo00?o0000ooooooooool06?ooool00ooo003ooooooooo
o`0Dooooo`;oo`0000?o0000ooooooooool0oooooolAooooo`008Oooool00ol0003oooooooooo`0F
ooooo`;oo`006Oooool00ooo003o0000ooooo`3ooooooa7ooooo0007ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oo
oooooooo01Gooooo00?oo`00o`000?ooool06_ooool00ooo003o0000ooooo`3ooooooa3ooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`0Dooooo`03ool00?l0003ooooo01cooooo00?oo`00o`000?ooool0oooo
ool?ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`02ooooo`?o00004oooool00ooo003o0000ooooo`0Nooooo`03ool00?l0003o00000?oooooo3_oo
ool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Oooooo`;oo`0000?o0000ooooooooool0oooo
ool;ooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08_ooool00ooo003o0000
ooooo`3oooooo`_ooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool09?ooool00ooo003o0000
ooooo`3oooooo`[ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`3oooooo`Sooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0?oooooo
1oooool0027ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo0?oooooo1oooool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo0?oooooo1_ooool0027ooooo0ol0000>ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool0ooooool5ooooo`008Oooool00ol0003oooooooooo`0=ooooo`03
ool00?oooooooooo02kooooo00?o0000ooooooooool0ooooool4ooooo`008Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oo003ooooo033ooooo00?o0000ool00?ooool0ooooool3ooooo`008Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oo003ooooo03;ooooo00?o0000ool00?ooool0oooo
ool2ooooo`008Oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo03?ooooo00?o0000
ool00?ooool0ooooool1ooooo`008Oooool00ol0003oooooooooo`0:ooooo`03ool00?oooooooooo
03Gooooo00?o0000ool00?ooool0ooooool0027ooooo00?o0000ooooooooool02Oooool00ooo003o
ooooooooo`0gooooo`03o`000?oo003ooooo0?kooooo000Qooooo`?o00002Oooool00ooo003ooooo
ooooo`0hooooo`03o`000?oo003ooooo0?gooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o
o`00ooooooooool0>_ooool00ol0003oo`00ooooo`3looooo`008Oooool00ol0003oooooooooo`08
ooooo`03ool00?oooooooooo03_ooooo00?o0000ool00?ooool0noooool0027ooooo00?o0000oooo
ooooool01oooool00ooo003oooooooooo`0mooooo`03o`000?oo003ooooo0?[ooooo000Qooooo`03
o`000?oooooooooo00Oooooo00?oo`00ooooooooool0?oooool00ooo003oooooooooo`3hooooo`00
8Oooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo047ooooo00?oo`00ooooooooool0
moooool0027ooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`12ooooo`03ool00?oo
oooooooo0?Kooooo000Qooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool0A?ooool0
0ol0003oooooooooo`3eooooo`008Oooool3o`0000Gooooo00?o0000ooooooooool0AOooool00ol0
003oooooooooo`3dooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool3o`000003oc8b<_oMgMgooooo
03cooooo1?l000000ol@413oooooooooo`0kooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0mooooo`Go00006oooool0027ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0fooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Kooooo00Co0000oooooomgMgOo<S8b?oooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Kooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Oooooo00Go
410@oooooooooooooooooa0@400>ooooo`03o`000?oooooo000003oooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03cooooo00?oV9RHob4Q8Oo^k^h0
7?ooool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0gooooo`05o`000?oo
ooooooooooooool000003oooool00ol0003o<S8booooo`0nooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0nooooo`03oiRHV?lQ8B7ok^k^01_ooooo
000Qooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>?ooool01Ol0003ooooooooo
oooooooo000000cooooo00Ko0000ob4Q8Ol0003o<S8bo`000?oo000nooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043ooooo00?oMgMg
ofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0hoooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0003cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool06Oooool0027ooooo0ol000000ooooooo0000ooooo`0joooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`04ooooo`03o`000?oo003o
oooo03[ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo03oooooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool01Ol0003ooooooooooooo
oooo000003_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001?ooool00ol0003oo`00
ool0000gooooo`03oeEEEOmVIVKo000003_ooooo1Ooo00000omVIVKo0000ooooo`02ooooo`Go0000
0ooo000Fo`0002kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Kooooo`008Oooool01?l0003ooooo
oooooooo001Fooooo`03o`000?ooooooo`0006Wooooo2ooo000:o`0000Sooooo3?oo000:ooooo`co
0000@_ooool0027ooooo00Co0000ooooool0003oo`00Eoooool01?l0003oooooool00?oo001Xoooo
o`Ko0000;?ooool7ool000Gooooo1_l0000looooo`008Oooool00ol0003oooooool0001Iooooo`;o
000000?oooooool00?ooool0F?ooool3ool000Gooooo1_l0000iooooo`Woo`000_ooool9o`0003?o
oooo000Qooooo`03o`000?oo003ooooo05_ooooo0_l00002ool005Cooooo0ooo00000ooooooo0000
o`000005o`0005;ooooo1ooo0003o`00023ooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o
0000ool00?ooool0GOooool2o`000003ool00?oooooooooo04cooooo1Ooo0004o`00063ooooo2?oo
0002o`0001Wooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool0
0?l0003o0000063o000000?oo`00o`000?l00000Aol00004ool0077o00000_oo000>o`0000cooooo
00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool2o`0000;ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03ool00?l0003o000000;o0000
0_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
4Oooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`?o0000
3_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool01?l0003oooooooooooooool5o`0000Kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027o
oooo00?o0000ooooooooool0IOooool3o`0003Cooooo0ooo0006o`0009Gooooo0_l00002ooooo`;o
00001?ooool0027ooooo00?o0000ooooooooool0J?ooool3o`0002gooooo1?oo0002o`000:Kooooo
000Qooooo`03o`000?oooooooooo06[ooooo0ooo0002o`0002Gooooo1?oo00000ol0003ooooooooo
o`2Yooooo`008Oooool00ol0003oooooooooo`1]ooooo`?oo`000_l0000Oooooo`?oo`0000?o0000
ooooooooool0[Oooool0027ooooo00?o0000ooooooooool0L?ooool3ool000Co00004Oooool7o`00
00;oo`00/oooool0027ooooo0ol0001cooooo`Goo`004?l0002looooo`008Oooool00ol0003ooooo
ooooo`1hooooo`;oo`000oooool8ool00;oooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0
003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?o
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooo
ooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004oooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGo
oooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00:Cooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2Wooooo`00
Poooool3o`0001Cooooo00?o8B4QomgMgOooool01_ooool00ooMgMgo410@onk^kP0Hooooo`03onk^
k_l@413ogMgM0:Oooooo001kooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP02ooooo`03
o`000?oooooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03oiRHV?mEEEGooooo
00Kooooo00?oEEEEoiRHV?ooool00_ooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool01_nj
^[[oA4A4ooooooooooooQhN7ofIVIQGooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?oo
ool01Oo^k^ko<S8bo`000?l@413oc<c<00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@1eooooo`00
Noooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00_ooool00ol0003oooooooooo`0;oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ogMgMooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o
^[Zj0_ooool00oo^k^ko0000ooooo`0;ooooo`Ko00001Oooool00ol0003oooooooooo`04ooooo`;o
8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Oooooo00?oMgMgoc8b<_ooool0M?ooool007_o
oooo00Oo0000oooooooMgMgo<S8booooooo^k^ko410@00;ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`06ooooo`;oMgMg1_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7o
k^k^00cooooo00Co410@omgMgOoooooo00001?ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00[ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo07?ooooo
001kooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Co0000oooooooooooo00003Oooool00ol0003o
ooooooooo`06ooooo`03onk^k_l@413ok^k^00Gooooo00?o<S8booooooooool01?ooool00onHV9So
8B4Qonk^kP0;ooooo`04ohN7QomVIVKoooooo`0000Cooooo00?o0000ooooooooool02_ooool6o`00
00Gooooo00?o0000ooooooooool02_ooool01Ol0003oV9RHoooooonHV9So8B4Q00Oooooo00?oMgMg
oc8b<_ooool0M?ooool007_ooooo00?ogMgMob4Q8Oo^k^h00oooool01?l0003oooooo`000?l0000=
ooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool00ol0003ok^k^ooooo`05
ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo00000oooool00oo^k^ko0000oooo
o`0Fooooo`03o`000?oooooooooo00[ooooo00Go0000oeEEEOl0003o410@olc<c004ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0MOooool007cooooo00?oV9RHogMgMoooool00_ooool00ol0003ooooo
ooooo`0<ooooo`03oa0@4?l0003o000000?o00001_ooool00ooMgMgo410@ooooo`04ooooo`03oeEE
EOmgMgOooooo00Kooooo00?o0000ooooooooool02?ooool7o`000003oooooomgMgOoEEEE01Oooooo
00?o0000ooooooooool02_ooool00omEEEGoQhN7ooooo`06ooooo`03o`000?oooooooooo07Oooooo
002Booooo`03o`000?oooooooooo00Sooooo00?oEEEEoiRHV?ooool00oooool00ooMgMgo410@onk^
kP02ooooo`05o`000?nj^[[ooooooiRHV?l@41004Oooool00oo^k^ko410@omgMg@0Gooooo`03o`00
0?oooooooooo00[ooooo00?ogMgMoa0@4?nHV9P01_ooool00ol0003oooooooooo`1gooooo`00T_oo
ool00ol0003oooooooooo`08ooooo`03okZj^_m4A4Cooooo00Cooooo00WoMgMgofIVI_oooooooooo
oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool00omVIVKoMgMgooooo`0Eooooo`03oeEEEOmVIVKo0000
00gooooo00Coc<c<odA4A?l0003o410@1?ooool4o`0007Kooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .22969 L
.08255 .19361 L
.10458 .16081 L
.11448 .14877 L
.12507 .13794 L
.13499 .12977 L
.14415 .12398 L
.14911 .12156 L
.15437 .11954 L
.15691 .11877 L
.15964 .11809 L
.16121 .11777 L
.16265 .11752 L
.16401 .11732 L
.16546 .11715 L
.1668 .11703 L
.16802 .11695 L
.16924 .1169 L
.17039 .11689 L
.17105 .11689 L
.17174 .1169 L
.17298 .11695 L
.17367 .11699 L
.17432 .11703 L
.17578 .11716 L
.17705 .11731 L
.17826 .11748 L
.18052 .11788 L
.1856 .11915 L
.19019 .12071 L
.19525 .12291 L
.20551 .12878 L
.21501 .13586 L
.22393 .14382 L
.26261 .19037 L
.30375 .25215 L
.34338 .31195 L
.38149 .36192 L
.40274 .38509 L
.42205 .40296 L
.44236 .41849 L
.46109 .42993 L
.48028 .43897 L
.49102 .44291 L
.50107 .44592 L
.51088 .44825 L
.51984 .44988 L
.5246 .45057 L
.52979 .45118 L
Mistroke
.53263 .45146 L
.53527 .45167 L
.53799 .45186 L
.54048 .452 L
.54296 .45211 L
.54557 .4522 L
.54693 .45223 L
.5482 .45225 L
.54892 .45226 L
.54959 .45226 L
.55035 .45227 L
.55107 .45227 L
.55228 .45227 L
.55356 .45226 L
.55465 .45224 L
.55585 .45222 L
.55714 .45219 L
.55853 .45215 L
.56104 .45206 L
.56578 .45182 L
.57076 .45146 L
.57966 .45059 L
.58923 .44934 L
.59944 .44768 L
.61782 .44394 L
.65937 .43262 L
.6994 .41915 L
.73792 .40477 L
.77889 .38863 L
.81835 .37272 L
.85629 .35732 L
.89668 .34097 L
.93556 .32532 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .22922 L
.08255 .19343 L
.10458 .16071 L
.11448 .14865 L
.12507 .13779 L
.13499 .12961 L
.14415 .12385 L
.14911 .12146 L
.15437 .11948 L
.15691 .11873 L
.15964 .11808 L
.16121 .11777 L
.16265 .11754 L
.16401 .11735 L
.16546 .1172 L
.16615 .11714 L
.1668 .1171 L
.16802 .11703 L
.16916 .117 L
.17039 .117 L
.17104 .11701 L
.17176 .11703 L
.1725 .11707 L
.1732 .11711 L
.17445 .11721 L
.17578 .11735 L
.17842 .11774 L
.18092 .11823 L
.1856 .11948 L
.19019 .12111 L
.19525 .12337 L
.20551 .12936 L
.22393 .14447 L
.24327 .16549 L
.26413 .19264 L
.30527 .25379 L
.34489 .31332 L
.383 .36365 L
.40425 .38708 L
.42356 .40508 L
.44388 .42056 L
.46261 .43177 L
.48179 .44037 L
.4919 .44381 L
.50259 .44671 L
.51203 .44865 L
.51723 .4495 L
.52216 .45017 L
.52674 .45066 L
Mistroke
.53173 .45108 L
.53393 .45122 L
.53627 .45135 L
.53828 .45144 L
.54048 .45151 L
.54183 .45155 L
.54309 .45157 L
.54379 .45158 L
.54443 .45159 L
.54516 .4516 L
.54585 .4516 L
.54708 .4516 L
.54822 .4516 L
.54947 .45159 L
.5501 .45158 L
.55079 .45157 L
.55224 .45154 L
.55356 .45151 L
.55654 .45141 L
.55917 .45129 L
.56193 .45114 L
.57158 .45038 L
.57704 .44981 L
.58211 .4492 L
.60261 .44596 L
.62121 .44212 L
.66124 .43159 L
.69976 .4192 L
.74073 .40425 L
.78019 .38869 L
.81813 .37332 L
.85852 .35706 L
.8974 .34155 L
.93873 .32458 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`0Zooooo`Co0000oooooolGoooo
o`008Oooool3o`0002Kooooo1?l00003ooooo`;o00000_oo003ooooooaCooooo000Qooooo`03o`00
0?oooooooooo02Cooooo00?oo`00o`000?ooool02_ooool4ool00?oooooo4?ooool0027ooooo00?o
0000ooooooooool08_ooool2ool0017ooooo00?oo`00ooooooooool0ooooool=ooooo`008Oooool0
0ol0003oooooooooo`0Pooooo`;oo`005?ooool2ool00?oooooo3Oooool0027ooooo00?o0000oooo
ooooool07oooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo0?oooooo2_ooool0027o
oooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo0?oo
oooo2Oooool0027ooooo00?o0000ooooooooool07Oooool00ooo003oooooooooo`0Jooooo`03ool0
0?oooooooooo0?oooooo2?ooool0027ooooo0ol0000Looooo`03ool00?oooooooooo01cooooo00?o
o`00ooooooooool0ooooool7ooooo`008Oooool00ol0003oooooooooo`0Kooooo`03ool00?oooooo
oooo01kooooo00?oo`00ooooooooool0ooooool6ooooo`008Oooool00ol0003oooooooooo`0Joooo
o`03ool00?oooooooooo01oooooo00?o0000ooooooooool0ooooool6ooooo`008Oooool00ol0003o
ooooooooo`0Iooooo`03ool00?l0003ooooo027ooooo00?o0000ooooooooool0ooooool5ooooo`00
8Oooool00ol0003oooooooooo`0Hooooo`03ool00?l0003ooooo02?ooooo00?o0000ooooooooool0
ooooool4ooooo`008Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0ooooool3ooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool0ooooool2ooooo`008Oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0ooooool1ooooo`008Oooool3o`0001Ko
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3oooooo`008Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo02[ooooo00?o0000ool00?ooool0ooooool0027ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0[ooooo`03ool00?oooooooooo0?kooooo000Q
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;Oooool00ooo003oooooooooo`3m
ooooo`008Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oooooo00?oo`00oooo
ooooool0o?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`0a
ooooo`03ool00?oooooooooo0?_ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Booooo`03ool00?oooooo
oooo037ooooo00?oo`00o`000?ooool0noooool000Go00000_ooool01Ol@413ooooooooooooooooo
410@013ooooo00?o0000ooooooooool00_ooool3o`00017ooooo00?oo`00ooooooooool0<oooool0
0ooo003o0000ooooo`3jooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo03Gooooo00?oo`00
ooooooooool0nOooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo03Gooooo00?o
o`00o`000?ooool0nOooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`0gooooo`03ool00?l0
003ooooo0?Sooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00kooooo00?oo`00o`000?ooool0>Oooool00ooo003ooooooooo
o`3gooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oo
oooooooo00kooooo00?oo`00ooooooooool0>Oooool00ooo003o0000ooooo`3gooooo`008Oooool0
0ol0003oooooooooo`0=ooooo`03ool00?oooooooooo03_ooooo00?oo`00o`000?ooool0m_ooool0
027ooooo00?o0000ooooooooool03Oooool00ooo003oooooooooo`0looooo`03ool00?oooooooooo
0?Gooooo000Qooooo`?o00003?ooool00ooo003oooooooooo`0nooooo`03o`000?oooooooooo0?Co
oooo000Qooooo`03o`000?oooooooooo00_ooooo00?oo`00o`000?ooool0@?ooool00ol0003ooooo
ooooo`3cooooo`008Oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo043ooooo00?o
0000ooooooooool0loooool0027ooooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`12
ooooo`03o`000?oooooooooo0?;ooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0@_ooool00ol0003oooooooooo`3booooo`008Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0lOooool0027ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo0?3ooooo000Qooooo`?o00002?oo
ool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo0?3ooooo000Qooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0Aoooool00ol0003oo`00ooooo`3_ooooo`008Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo04Wooooo00?oo`00ooooooooool0k_ooool0027o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`19ooooo`03o`000?oo003ooooo0>ko
oooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Boooool00ooo003ooooo
ooooo`3]ooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04cooooo00?o
o`00ooooooooool0k?ooool0027ooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`1=
ooooo`03ool00?oooooooooo0>cooooo000Qooooo`03o`000?oooooooooo00Gooooo00?oo`00oooo
ooooool0C_ooool00ooo003oooooooooo`3[ooooo`008Oooool3o`0000Cooooo00?oo`00oooooooo
ool0D?ooool00ooo003oooooooooo`3Zooooo`008Oooool00ol0003oooooooooo`04ooooo`03ool0
0?oooooooooo03Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Cooooo00?oo`00ooooooooool0=_ooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo
03Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04
ooooo`03ool00?oooooooooo03Oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06ooo
ool0027ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0gooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo03Kooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03cooooo00?o
V9RHob4Q8Oo^k^h07?ooool0027ooooo00?o0000ooooooooool00_ooool00ol0003oo`00ooooo`0h
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`05ooooo`03ool00?oo
oooooooo03Kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool00_ooool0
0ooo003oooooooooo`0hooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Oooooo00?oo`00ooooooooool0=Oooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c010ooooo`03ogMgMomVIVKooooo01[o
oooo000Qooooo`06o`000?ooooooooooooooool0003oo`00>_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`0dooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo01Wooooo000Qooooo`?o000000?oooooool00?ooool0>_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0oooooo`05o`000?nj^[[o
oooooiRHV?l@41006oooool0027ooooo00Go0000oooooooooooo0000ool0000kooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000[ooooo00?o0000ooooooooool0<Oooool00omEEEGoIVIV
o`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000nooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`06oooool0027ooooo00Co0000ooooooooooooo`00G?ooool00ol0003oooooooooo`3Tooooo`00
8Oooool01?l0003oooooo`000?oo001Looooo`03o`000?oooooooooo0>Cooooo000Qooooo`04o`00
0?oooooo0000ool005gooooo00?o0000ooooooooool0hoooool0027ooooo0_l000000ooo003ooooo
ooooo`1Mooooo`03o`000?oooooooooo0=Sooooo0_l00002ooooo`;o00001?ooool0027ooooo0_l0
001Pooooo`03o`000?oooooooooo0=Sooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`00
6_ooooooo`00037o00000_oo0007o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01oooool01Ooo003ooooooooooooooooo000000kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo0ooo00000ooooooo
0000ooooo`0Booooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oo
oooo00Go0000ool00?ooooooooooo`00000>ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oo003oo`0000Cooooo00?o0000oooo
ooooool04Oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003oooooooooo`1Roooo
o`03ool00?oooooooooo0;Wooooo00?o0000ool00?oo00006Oooool2o`0000;ooooo0_l00004oooo
o`008Oooool00ol0003oooooooooo`1Sooooo`03ool00?oooooooooo0;Gooooo00Co0000ool00?oo
003oo`009Oooool0027ooooo00?o0000ooooooooool0I?ooool00ooo003oooooooooo`2booooo`;o
000000?oo`00ooooooooool09_ooool0027ooooo00?o0000ooooooooool0I?ooool00ol0003oo`00
ooooo`2_ooooo`?o0000:oooool0027ooooo00?o0000ooooooooool0IOooool00ooo003ooooooooo
o`2/ooooo`;o0000;_ooool0027ooooo0ol0001Vooooo`03ool00?oooooooooo0:Wooooo0_l0000`
ooooo`008Oooool00ol0003oooooooooo`1Wooooo`03ool00?oooooooooo0:Gooooo00?o0000ool0
0?oo0000<_ooool0027ooooo00?o0000ooooooooool0Ioooool00ol0003oo`00ooooo`2Sooooo`;o
000000?oo`00ooooooooool0<_ooool0027ooooo00?o0000ooooooooool0J?ooool00ooo003ooooo
ooooo`2Oooooo`?o00000_oo000eooooo`008Oooool00ol0003oooooooooo`1Yooooo`03ool00?oo
oooooooo09_ooooo0ol00003ool003Oooooo000Qooooo`03o`000?oooooooooo06[ooooo00?oo`00
ooooooooool0V?ooool2o`0000?oo`00>_ooool0027ooooo00?o0000ooooooooool0J_ooool00ol0
003oo`00ooooo`2Eooooo`;o00000ooo000mooooo`008Oooool3o`0006_ooooo00?o0000oooooooo
ool0T_ooool2o`0000;oo`00@?ooool0027ooooo00?o0000ooooooooool0K?ooool00ol0003ooooo
ooooo`2>ooooo`?o0000A?ooool0027ooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`2;ooooo`;o0000Aoooool0027ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`28
ooooo`;o0000BOooool0027ooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`24oooo
o`03o`000?oo003oo`0004_ooooo000Qooooo`03o`000?oooooooooo073ooooo00?o0000oooooooo
ool0POooool3ool004gooooo000Qooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0
OOooool00ol0003oo`00ool0001@ooooo`008Oooool00ol0003oooooooooo`1booooo`03ool00?oo
oooooooo07[ooooo0ooo001Booooo`008Oooool3o`0007;ooooo00?oo`00o`000?ooool0N?ooool2
ool005Gooooo000Qooooo`03o`000?oooooooooo07?ooooo00?oo`00o`000?ooool0M?ooool00ol0
003oo`00ool0001Gooooo`008Oooool00ol0003oooooooooo`1dooooo`;oo`00L_ooool2o`000003
ool00?oooooooooo05Oooooo000Qooooo`03o`000?oooooooooo07Kooooo00?oo`00ooooooooool0
K?ooool3o`0005cooooo000Qooooo`03o`000?oooooooooo07Oooooo00?oo`00ooooooooool0J?oo
ool3o`0005oooooo000Qooooo`03o`000?oooooooooo07Sooooo00?oo`00ooooooooool0IOooool2
o`0006;ooooo000Qooooo`03o`000?oooooooooo07Wooooo00?oo`00ooooooooool0HOooool00ol0
003oo`00ool0001Tooooo`008Oooool3o`0007[ooooo00?oo`00o`000?ooool0G_ooool00ol0003o
o`00ool0001Vooooo`008Oooool00ol0003oooooooooo`1kooooo`03ool00?l0003ooooo05[ooooo
00Co0000ool00?oo003oo`00J?ooool0027ooooo00?o0000ooooooooool0O?ooool00ooo003o0000
ooooo`1Gooooo`03o`000?oo003oo`0006_ooooo000Qooooo`03o`000?oooooooooo07gooooo00?o
o`00o`000?ooool0E?ooool00ol0003oo`00ool0001]ooooo`008Oooool00ol0003oooooooooo`1o
ooooo`03o`000?oooooooooo04oooooo00Co0000ool00?oo003oo`00Koooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo
00?o0000ooooooooool0P?ooool2o`0004gooooo0_l000000ooo003oooooooooo`1`ooooo`001ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo
00?o0000ooooooooool0P_ooool2o`0004Sooooo0ol0001eooooo`001oooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`0008Cooooo0_l00013ooooo`?o0000
N?ooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo
00?o0000ooooooooool0Q_ooool2o`0003gooooo0_oo0002o`0007_ooooo0007ooooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooooooo
ool0Q_ooool3ool00003o`000?oooooooooo03Kooooo0ooo00000ol0003oooooooooo`1looooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`29ooooo`?oo`00<Oooool00ol0003oo`00ool00002ool008;ooooo0007ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08co
oooo0ooo000Zooooo`03o`000?oo003oo`0000;oo`00Q_ooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`2?ooooo`Coo`008oooool01?l0003o
o`00ool00?oo002:ooooo`008Oooool00ol0003oooooooooo`2Booooo`03o`000?oo003oo`0001ko
oooo0ol0002>ooooo`008Oooool00ol0003oooooooooo`2Eooooo`03ool00?l0003o000000;o0000
3Oooool7ool000Go0000TOooool0027ooooo0ol0002Jooooo`?o00002_oo0006o`0009Oooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`00
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000oooo
ooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oo
ooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo
000Jooooo`03o`000?oooooooooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00:Sooooo00?oMgMgofIVI_ooool05oooool00omVIVKo
MgMgooooo`2Sooooo`00Qoooool3o`0001?ooooo00?o8B4QomgMgOooool01oooool00ooMgMgo410@
onk^kP0Hooooo`03onk^k_l@413ogMgM0:?ooooo001nooooo`07ohN7Qol0003oEEEEofIVI_l0003o
<S8bonk^kP03ooooo`03o`000?oooooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P02oooo
o`03oiRHV?mEEEGooooo00Oooooo00CoEEEEoiRHV?oooooooooo1Ol00009ooooo`03oeEEEOnYZJWo
oooo00;ooooo00?o^[ZjodA4A?ooool00_ooool00on7QhOoIVIVooooo`0Cooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool0Noooool007kooooo00Oo410@omgM
gOmgMgOo8B4Qoooooon7QhOoIVIV00?ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^
k_mgMgOo410@00?ooooo00?o0000omgMgOooool01_ooool02Ol0003oooooooooooooooooV9RHob4Q
8Oo^k^koooooodA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj0oooool00oo^k^ko0000
ooooo`0;ooooo`Ko00001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVY
ooooo`1kooooo`00O_ooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@41000oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo0_mgMgL7ooooo`03oc8b<_oooooooooo00;o
oooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool00005ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`1kooooo`00O_ooool01?mEEEGo
ZJVYooooool00002ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`05
ooooo`03onk^k_l@413ok^k^00Kooooo00?o<S8booooooooool00oooool00onHV9So8B4Qonk^kP0;
ooooo`04ohN7QomVIVKoooooo`0000Gooooo00?o0000ooooooooool02_ooool6o`0000Cooooo00?o
0000ooooooooool03Oooool00olQ8B7oooooooooo`1jooooo`00O_ooool00ooMgMgo8B4Qonk^kP03
ooooo`03o`000?oooooooooo00;o00003Oooool00ol0003oooooooooo`06ooooo`03oeEEEOnHV9So
oooo00Gooooo00?o0000onk^k_ooool01?ooool00omgMgOoIVIVooooo`0:ooooo`04omgMgOl@413o
ooooo`0000Cooooo00?ok^k^o`000?ooool05Oooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<
c<cooooo07[ooooo001oooooo`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool03Oooool0
0ol@413o0000o`000003o`0000Gooooo00?ogMgMoa0@4?ooool01Oooool00omEEEGoMgMgooooo`05
ooooo`03o`000?oooooooooo00Sooooo1ol00002ooooo`03ogMgMomEEEGooooo01Gooooo00?o0000
ooooooooool03Oooool00onYZJWoMgMgooooo`1jooooo`00U_ooool00ol0003oooooooooo`07oooo
o`03oeEEEOnHV9Sooooo00Cooooo00WogMgMoa0@4?o^k^koooooo`000?nj^[[ooooooiRHV?l@4100
4_ooool00oo^k^ko410@omgMg@0Fooooo`03o`000?oooooooooo00[ooooo00Go410@oooooooooooo
oooooc8b<P1kooooo`00U_ooool00ol0003oooooooooo`07ooooo`03okZj^_m4A4Cooooo00Gooooo
00SoMgMgofIVI_ooooooV9RHoa0@4?l0003o8B4Qolc<c1;ooooo00?oIVIVogMgMoooool05?ooool0
0omEEEGoIVIVo`00000<ooooo`Go0000Noooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .25681 L
.10458 .20635 L
.12507 .18613 L
.14415 .17074 L
.16254 .15959 L
.17284 .15509 L
.18221 .15216 L
.18704 .15108 L
.18948 .15066 L
.19216 .15028 L
.19445 .15004 L
.19573 .14993 L
.19691 .14986 L
.198 .1498 L
.19919 .14976 L
.20031 .14974 L
.20135 .14973 L
.20266 .14975 L
.20339 .14976 L
.20407 .14979 L
.20532 .14985 L
.20663 .14993 L
.20891 .15014 L
.21141 .15044 L
.21409 .15087 L
.21696 .15143 L
.22214 .15274 L
.23231 .15638 L
.24338 .16195 L
.2635 .17629 L
.28327 .19537 L
.30428 .22044 L
.34203 .27494 L
.38223 .33968 L
.42092 .40065 L
.46206 .45715 L
.48259 .48073 L
.50169 .49957 L
.52129 .51571 L
.53979 .52797 L
.54961 .53332 L
.56025 .53824 L
.56986 .54191 L
.57884 .54469 L
.5883 .54696 L
.59332 .5479 L
.59872 .5487 L
.60141 .54903 L
.60436 .54932 L
Mistroke
.60695 .54953 L
.60837 .54963 L
.60971 .54971 L
.61103 .54977 L
.61245 .54983 L
.61374 .54987 L
.61492 .54989 L
.61605 .54991 L
.61728 .54992 L
.61856 .54992 L
.61976 .5499 L
.62103 .54988 L
.62166 .54987 L
.62237 .54985 L
.62478 .54975 L
.62614 .54968 L
.6276 .5496 L
.63024 .54941 L
.63541 .5489 L
.64015 .5483 L
.6492 .54677 L
.65872 .54466 L
.6785 .53869 L
.69688 .5314 L
.73598 .51106 L
.77753 .48357 L
.81756 .45276 L
.85608 .42021 L
.89705 .3834 L
.93651 .34662 L
.97445 .31067 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .25939 L
.10458 .20641 L
.12507 .18486 L
.14415 .16869 L
.1536 .1623 L
.16254 .15733 L
.16748 .15505 L
.17284 .15295 L
.17735 .15149 L
.18221 .15025 L
.18475 .14973 L
.18708 .14934 L
.18945 .14902 L
.19165 .1488 L
.19288 .14871 L
.1942 .14863 L
.19495 .1486 L
.19566 .14857 L
.19629 .14856 L
.19698 .14855 L
.19826 .14855 L
.19891 .14856 L
.19962 .14857 L
.20087 .14862 L
.20205 .14869 L
.20335 .14878 L
.20477 .14891 L
.20735 .14923 L
.20987 .14962 L
.21219 .15007 L
.21747 .15137 L
.22307 .15318 L
.23244 .15718 L
.24255 .16282 L
.26083 .17632 L
.28087 .19559 L
.30197 .22019 L
.34007 .27298 L
.38063 .33542 L
.41968 .39537 L
.46118 .45293 L
.50116 .49799 L
.51948 .51445 L
.53963 .52926 L
.5595 .54042 L
.57037 .54508 L
.58054 .54852 L
.58552 .54989 L
.59095 .55114 L
Mistroke
.59574 .55205 L
.60083 .55281 L
.60343 .55312 L
.60588 .55336 L
.60826 .55355 L
.61045 .55369 L
.61254 .55378 L
.61359 .55382 L
.61474 .55385 L
.61589 .55387 L
.61713 .55388 L
.6183 .55387 L
.61937 .55386 L
.62055 .55384 L
.62166 .55381 L
.62288 .55377 L
.62419 .55371 L
.62686 .55355 L
.62931 .55336 L
.63378 .5529 L
.63849 .55226 L
.64842 .55043 L
.65927 .54769 L
.67892 .54092 L
.69988 .5314 L
.74143 .5068 L
.78146 .47775 L
.81998 .44657 L
.86095 .41136 L
.90041 .37647 L
.93835 .34268 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`0aooooo`Goo`00ooooool?oooo
o`008Oooool00ol0003oooooooooo`0]ooooo`Coo`002_l0003oooooo`[ooooo000Qooooo`03o`00
0?oooooooooo02[ooooo0ooo00000ol0003oooooooooo`0;ooooo`?o0000ooooool7ooooo`008Ooo
ool00ol0003oooooooooo`0Xooooo`;oo`0000?o0000ooooooooool04Oooool01?l0003oo`00ool0
0?l0003oooooo`?ooooo000Qooooo`03o`000?oooooooooo02Kooooo0_oo0002o`0001Oooooo00?o
o`00o`000?l00000ooooool1ooooo`008Oooool00ol0003oooooooooo`0Vooooo`;o00006_ooool2
ool00003o`000?oooooooooo0?gooooo000Qooooo`?o00009?ooool2o`0001kooooo00?oo`00o`00
0?ooool0oOooool0027ooooo00?o0000ooooooooool08_ooool2o`00027ooooo00?oo`00o`000?oo
ool0o?ooool0027ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Rooooo`03ool0
0?l0003ooooo0?_ooooo000Qooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool09?oo
ool2ool00?_ooooo000Qooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09oooool0
0ooo003oooooooooo`3hooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Nooooo`03ool00?oo
oooooooo02Wooooo00?oo`00ooooooooool0moooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01gooooo00?o
o`00ooooooooool0:oooool00ooo003oooooooooo`3fooooo`001Ol00002ooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o00007?ooool00ooo003ooooooooo
o`0]ooooo`03ool00?oooooooooo0?Gooooo0007ooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01_ooooo00?oo`00ooooooooool0;ooo
ool00ol0003oooooooooo`3dooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo01[ooooo00?oo`00ooooooooool0
<Oooool00ol0003oooooooooo`3cooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03ool00?oooooooooo03;ooooo
00?o0000ooooooooool0loooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool06?ooool00ooo003oooooooooo`0dooooo`03o`00
0?oooooooooo0?;ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo
00?o0000ooooooooool05oooool00ooo003oooooooooo`0fooooo`03o`000?oooooooooo0?7ooooo
000Qooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0=oooool00ol0003ooooooooo
o`3`ooooo`008Oooool00ol0003oooooooooo`0Fooooo`03ool00?oooooooooo03Wooooo00?o0000
ooooooooool0koooool0027ooooo0ol0000Eooooo`03ool00?oooooooooo03_ooooo00?oo`00oooo
ooooool0k_ooool0027ooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`0looooo`03
ool00?l0003ooooo0>kooooo000Qooooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool0
?_ooool00ooo003o0000ooooo`3]ooooo`008Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo03oooooo00?oo`00o`000?ooool0kOooool0027ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`11ooooo`03ool00?l0003ooooo0>cooooo000Qooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0@oooool00ooo003o0000ooooo`3[ooooo`008Oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo04Cooooo00?oo`00ooooooooool0j_ooool0027ooooo
0ol0000?ooooo`03o`000?oooooooooo04Gooooo00?oo`00o`000?ooool0j_ooool0027ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`17ooooo`03ool00?l0003ooooo0>Wooooo000Q
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0BOooool00ooo003o0000ooooo`3X
ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo04[ooooo00?oo`00o`00
0?ooool0j?ooool0027ooooo00?o0000ooooooooool02oooool00ol0003oo`00ooooo`1<ooooo`03
ool00?l0003ooooo0>Oooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000ool00?ooool0
C_ooool00ooo003o0000ooooo`3Vooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
003ooooo053ooooo00?oo`00ooooooooool0iOooool0027ooooo00?o0000ooooooooool02Oooool0
0ooo003oooooooooo`1Aooooo`03o`000?oooooooooo0>Cooooo000Qooooo`?o00002?ooool00ol0
003oo`00ooooo`1Cooooo`03o`000?oooooooooo0>?ooooo000Qooooo`03o`000?oooooooooo00Oo
oooo00?o0000ool00?ooool0<oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd03?ooool00ol0003oooooooooo`0^ooooo`Co000000?o410@
ooooooooool0>oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd0?Oooool5o`0001_ooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000
ool00?ooool0=?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Kooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oo003ooooo03Cooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
??ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
003ooooo03Gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00gooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00kooooo
00?oMgMgoc8b<_ooool0?_ooool00onHV9So8B4Qonk^kP0Kooooo`008Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oo003ooooo03Kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`03_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043ooooo00?oMgMgofIV
I_ooool06_ooool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooool0000gooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool06Oooool0027ooooo0ol00003ooooo`03o`000?oo003ooooo03Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00?oo`00o`00
0?ooool0;Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0?oooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`03o`000?oooooooooo
00;ooooo00?o0000ool00?ooool0>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@
ooooo`03ool00?l0003ooooo02_ooooo00?oEEEEofIVI_l00000?oooool00omEEEGoIVIVo`00000=
ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qooooo`05o`000?oooooo
ooooooooool00000HOooool00ooo003o0000ooooo`3Nooooo`008Oooool01?l0003oooooooooool0
001Sooooo`03ool00?oooooooooo0=gooooo000Qooooo`04o`000?ooooooooooo`0006?ooooo00?o
o`00o`000?ooool0gOooool0027ooooo00?o0000ooooool00000IOooool00ooo003o0000ooooo`3B
ooooo`;o00000_ooool2o`0000Cooooo000Qooooo`;o0000Ioooool00ooo003oooooooooo`3Aoooo
o`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool001[oooooLOl000000ooo003o0000o`00002m
o`000003ool00?l0003o000000Go00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?ooooooo`0000cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ool00?l000004oooool0
1?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`04o`000?oooooo
ooooool000_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Wooooo00Co0000ool00?oooooo00004oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`00
8Oooool00ol0003oooooooooo`1Yooooo`03ool00?oooooooooo0;Oooooo00?o0000ool00?ooool0
5?ooool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`1Yooooo`03ool00?oo
oooooooo0;Kooooo00?o0000ool00?ooool07oooool0027ooooo00?o0000ooooooooool0J_ooool0
0ooo003oooooooooo`2dooooo`03o`000?oooooooooo023ooooo000Qooooo`03o`000?oooooooooo
06[ooooo00?o0000ool00?ooool0/oooool00ol0003oooooooooo`0Qooooo`008Oooool00ol0003o
ooooooooo`1[ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool08_ooool0027ooooo
0ol0001/ooooo`03o`000?oooooooooo0:oooooo00?o0000ooooooooool08oooool0027ooooo00?o
0000ooooooooool0K?ooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo02Cooooo000Q
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`0U
ooooo`008Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo0:[ooooo0_oo000Xoooo
o`008Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo0:Sooooo00?oo`00o`000?oo
ool0:?ooool0027ooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`2Vooooo`03ool0
0?l0003ooooo02Wooooo000Qooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0YOoo
ool00ooo003o0000ooooo`0Zooooo`008Oooool3o`00073ooooo00?o0000ool00?ooool0Xoooool0
0ooo003o0000ooooo`0[ooooo`008Oooool00ol0003oooooooooo`1`ooooo`03o`000?oo003ooooo
0:7ooooo0_oo00000ol0003oooooooooo`0[ooooo`008Oooool00ol0003oooooooooo`1aooooo`03
o`000?oo003ooooo09oooooo00?oo`00ooooool00000;_ooool0027ooooo00?o0000ooooooooool0
L_ooool00ol0003oo`00ooooo`2Mooooo`03ool00?oooooo000002oooooo000Qooooo`03o`000?oo
oooooooo07;ooooo00?o0000ool00?ooool0W?ooool00ooo003oooooo`00000`ooooo`008Oooool0
0ol0003oooooooooo`1cooooo`03o`000?oo003ooooo09[ooooo00?oo`00ooooool00000<Oooool0
027ooooo00?o0000ooooooooool0M?ooool00ol0003oo`00ooooo`2Hooooo`03ool00?oooooo0000
03;ooooo000Qooooo`03o`000?oooooooooo07Cooooo00?o0000ool00?ooool0VOooool00ol0003o
ooooooooo`0aooooo`008Oooool3o`0007Gooooo00?o0000ool00?ooool0Uoooool00ol0003ooooo
ooooo`0booooo`008Oooool00ol0003oooooooooo`1fooooo`03o`000?oo003ooooo09Cooooo0_l0
000eooooo`008Oooool00ol0003oooooooooo`1fooooo`03o`000?oo003ooooo09?ooooo00?o0000
ooooooooool0=Oooool0027ooooo00?o0000ooooooooool0Moooool00ol0003oo`00ooooo`2Aoooo
o`03o`000?oooooooooo03Kooooo000Qooooo`03o`000?oooooooooo07Oooooo00?o0000oooooooo
0000T?ooool00ol0003oooooooooo`0gooooo`008Oooool00ol0003oooooooooo`1hooooo`03o`00
0?oo003ooooo08kooooo00?o0000ooooooooool0>?ooool0027ooooo00?o0000ooooooooool0NOoo
ool00ol0003oooooooooo`2:ooooo`;oo`0000?o0000ooooooooool0>Oooool0027ooooo0ol0001i
ooooo`03o`000?oooooooooo08Wooooo00?oo`00o`000?ooool0??ooool0027ooooo00?o0000oooo
ooooool0N_ooool00ol0003oooooooooo`27ooooo`03ool00?l0003ooooo03gooooo000Qooooo`03
o`000?oooooooooo07_ooooo00?o0000ooooooooool0Q?ooool2ool00003o`000?oooooooooo03go
oooo000Qooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0P_ooool00ooo003ooooo
o`000010ooooo`008Oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo087ooooo00?o
o`00ooooool00000@Oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0OOooool00ol0003ooooo
ooooo`1oooooo`03ool00?l0003o000004;ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo07gooooo00?oo`00o`000?ooool0@oooool000Oooooo00Go410@oooooooooooooooo
oa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0001nooooo`03o`000?ooooooo`0007cooooo
00?oo`00o`000?ooool0A?ooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo00?ooooo00?o0000ooooooooool0Ooooool00ol0003oo`00ooooo`1jooooo`03ool0
0?l0003ooooo04Gooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0P?ooool00ol0003oo`00ooooo`1hooooo`03
ool00?l0003ooooo04Kooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo087ooooo00?o0000ool00?ooool0M_ooool2o`0004So
oooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo087ooooo00?o0000oooooooo0000MOooool00ol0003oooooooooo`18ooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo08;o
oooo00?o0000ool00?ooool0Loooool00ol0003oooooooooo`19ooooo`008Oooool00ol0003ooooo
ooooo`23ooooo`03o`000?oo003ooooo077ooooo00?o0000ooooooooool0B_ooool0027ooooo00?o
0000ooooooooool0Poooool00ol0003oooooool0001`ooooo`03o`000?oooooooooo04_ooooo000Q
ooooo`?o0000Q?ooool00ol0003oooooool0001]ooooo`;o0000C_ooool0027ooooo00?o0000oooo
ooooool0QOooool00ol0003oo`00ooooo`1Zooooo`;oo`00D?ooool0027ooooo00?o0000oooooooo
ool0Q_ooool00ol0003oo`00ooooo`1Xooooo`03ool00?l0003ooooo053ooooo000Qooooo`03o`00
0?oooooooooo08Oooooo00?o0000ool00?ooool0I_ooool00ooo003o0000ooooo`1Aooooo`008Ooo
ool00ol0003oooooooooo`28ooooo`03o`000?oo003ooooo06?ooooo0_oo00000ol0003ooooooooo
o`1Aooooo`008Oooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo067ooooo00?oo`00
o`000?l00000E?ooool0027ooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`1Ooooo
o`03ool00?l0003ooooo05Gooooo000Qooooo`?o0000Roooool00ol0003oooooooooo`1Mooooo`03
ool00?l0003ooooo05Kooooo000Qooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0
F_ooool2ool00003o`000?oooooooooo05Kooooo000Qooooo`03o`000?oooooooooo08gooooo00?o
0000ooooooooool0F?ooool00ooo003oooooo`00001Iooooo`008Oooool00ol0003oooooooooo`2>
ooooo`03o`000?oooooooooo05Kooooo00?oo`00o`000?l00000F_ooool0027ooooo00?o0000oooo
ooooool0Soooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo05[ooooo000Qooooo`03
o`000?oooooooooo093ooooo00?o0000ool00?ooool0D_ooool2o`0005gooooo000Qooooo`03o`00
0?oooooooooo097ooooo00?oo`00ooooooooool0Coooool2o`0005oooooo000Qooooo`03o`000?oo
oooooooo09;ooooo00?oo`00ooooooooool0COooool00ol0003oooooooooo`1Oooooo`008Oooool3
o`0009?ooooo00?oo`00o`000?ooool0B_ooool2o`0006;ooooo000Qooooo`03o`000?oooooooooo
09Cooooo00?oo`00o`000?ooool0Aoooool2o`0006Cooooo000Qooooo`03o`000?oooooooooo09Go
oooo00?oo`00o`000?ooool0A?ooool3ool006Gooooo000Qooooo`03o`000?oooooooooo09Kooooo
00?oo`00o`000?ooool0@_ooool00ooo003o0000ooooo`1Vooooo`008Oooool00ol0003ooooooooo
o`2Gooooo`03ool00?l0003ooooo03oooooo0_oo001Yooooo`008Oooool00ol0003oooooooooo`2H
ooooo`;oo`0000?o0000ooooooooool0>_ooool2ool006_ooooo000Qooooo`03o`000?oooooooooo
09[ooooo00?oo`00o`000?ooool0>Oooool00ooo003o0000ooooo`1[ooooo`008Oooool3o`0009_o
oooo00?oo`00o`000?l00000=_ooool2ool006kooooo000Qooooo`03o`000?oooooooooo09cooooo
00?oo`00ooooool00000<oooool2ool0073ooooo000Qooooo`03o`000?oooooooooo09oooooo0ol0
000_ooooo`03ool00?l0003ooooo073ooooo000Qooooo`03o`000?oooooooooo0:;ooooo0_l0000[
ooooo`03o`000?oo003ooooo07;ooooo000Qooooo`03o`000?oooooooooo0:Cooooo00?o0000oooo
ooooool09Oooool3o`0007Gooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003o
ooooooooo`2Uooooo`?o00008Oooool3o`0007Sooooo000Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0Y_ooool2ool000?o00006oooool3o`0007_ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0Z?ooool3ool000?o00005Oooool2o`0000;oo`00OOoo
ool001[ooooo00?o0000ooooooooool01?ooool3o`000:_ooooo0_oo00000ooooooo0000o`000005
o`0000Gooooo2?l00003ool007oooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0[Oooool2ool000Gooooo1_l00003ooooo`Goo`00P_ooool001[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`2gooooo`Koo`00Qoooool001[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Cooooo00?oMgMgofIVI_ooool0
5oooool00omVIVKoMgMgooooo`2Wooooo`00Poooool3o`0001Cooooo00?o8B4QomgMgOooool01_oo
ool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@413ogMgM0:Oooooo001kooooo`07ohN7Qol0003o
EEEEofIVI_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo00_ooooo00GoV9RHo`000?l0003o
A4A4okZj^P03ooooo`03oiRHV?mEEEGooooo00Kooooo00?oEEEEoiRHV?ooool00_ooool5o`0000Wo
oooo00?oEEEEojVYZOooool00_ooool01_nj^[[oA4A4ooooooooooooQhN7ofIVIQGooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o
0000oc8b<_oMgMd0MOooool007_ooooo00Oo410@omgMgOmgMgOo8B4Qoooooon7QhOoIVIV00;ooooo
00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000omgMgOoo
ool01Oooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mE
EEGoV9RHoooooooooooo410@okZj^P;ooooo00?ok^k^o`000?ooool02oooool6o`0000Gooooo00?o
0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8boooo
o`1dooooo`00Noooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@41000_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Kooooo0_mgMgL6ooooo`03oc8b<_oooooooooo00?ooooo
00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool00004ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo07?o
oooo001kooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Co0000oooooooooooo00003Oooool00ol0
003oooooooooo`06ooooo`03onk^k_l@413ok^k^00Gooooo00?o<S8booooooooool01?ooool00onH
V9So8B4Qonk^kP0;ooooo`04ohN7QomVIVKoooooo`0000Cooooo00?o0000ooooooooool02_ooool6
o`0000Gooooo00?o0000ooooooooool03Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;o
oooo07Cooooo001kooooo`03omgMgOlQ8B7ok^k^00?ooooo00Co0000ooooool0003o00003Oooool0
0ol0003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00?o0000onk^k_ooool01Oooool0
0omgMgOoIVIVooooo`0:ooooo`04omgMgOl@413oooooo`0000?ooooo00?ok^k^o`000?ooool05_oo
ool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c01eooooo`00O?ooool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo00cooooo00?o
410@o`000?l000000ol00006ooooo`03omgMgOl@413ooooo00Cooooo00?oEEEEogMgMoooool01_oo
ool00ol0003oooooooooo`08ooooo`Oo000000?oooooogMgMomEEED05oooool00ol0003ooooooooo
o`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0Moooool009;ooooo00?o0000
ooooooooool02?ooool00omEEEGoV9RHooooo`03ooooo`03omgMgOl@413ok^k^00;ooooo00Go0000
okZj^_ooooooV9RHoa0@400Aooooo`03onk^k_l@413ogMgM01Oooooo00?o0000ooooooooool02_oo
ool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool0Moooool009;ooooo00?o
0000ooooooooool02?ooool00onj^[[oA4A4ooooo`04ooooo`09ogMgMomVIVKooooooooooonHV9So
410@o`000?lQ8B7oc<c<017ooooo00?oIVIVogMgMoooool05Oooool00omEEEGoIVIVo`00000<oooo
o`Go00001?ooool4o`0007Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .29627 L
.10458 .28019 L
.14415 .26335 L
.18221 .24786 L
.20342 .24083 L
.21345 .23817 L
.22272 .23619 L
.22729 .23539 L
.23233 .23466 L
.23739 .2341 L
.24016 .23387 L
.24276 .23369 L
.24393 .23363 L
.24521 .23358 L
.24641 .23354 L
.24753 .23351 L
.24864 .23349 L
.24964 .23348 L
.2508 .23347 L
.25189 .23348 L
.25308 .2335 L
.25435 .23353 L
.25542 .23357 L
.25661 .23362 L
.25925 .23377 L
.26171 .23397 L
.26672 .23451 L
.27216 .23534 L
.2773 .23635 L
.28206 .2375 L
.29106 .24021 L
.30062 .24389 L
.32009 .25399 L
.33837 .26667 L
.37706 .30306 L
.4182 .35321 L
.45782 .40729 L
.49593 .45866 L
.53649 .50674 L
.57554 .54246 L
.59688 .55674 L
.60667 .56199 L
.61703 .56663 L
.62656 .57008 L
.63162 .57159 L
.63705 .57297 L
.64203 .57401 L
.64658 .57478 L
.65116 .57538 L
Mistroke
.65324 .57559 L
.6555 .57578 L
.65685 .57587 L
.6581 .57595 L
.65926 .576 L
.66054 .57605 L
.66169 .57608 L
.66277 .5761 L
.6639 .57612 L
.66511 .57612 L
.66643 .5761 L
.66717 .57609 L
.66786 .57607 L
.66913 .57603 L
.67047 .57598 L
.67279 .57584 L
.67534 .57565 L
.67992 .57517 L
.68484 .57447 L
.69374 .57273 L
.70334 .57018 L
.71382 .56662 L
.73494 .55713 L
.75459 .54568 L
.77555 .53093 L
.8171 .495 L
.85713 .4536 L
.89565 .40926 L
.93662 .359 L
.97608 .30916 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .29399 L
.10458 .28043 L
.14415 .26499 L
.18221 .249 L
.20342 .24122 L
.21345 .23817 L
.22272 .23583 L
.23233 .23397 L
.23739 .23324 L
.23998 .23294 L
.24276 .23267 L
.24519 .23249 L
.24742 .23236 L
.24849 .23231 L
.24965 .23227 L
.25075 .23224 L
.25178 .23222 L
.25308 .23222 L
.2543 .23222 L
.2554 .23223 L
.25659 .23226 L
.25788 .23231 L
.25925 .23237 L
.26171 .23252 L
.26426 .23274 L
.26667 .23299 L
.27119 .23362 L
.27605 .23451 L
.28135 .23573 L
.29087 .23861 L
.29968 .24206 L
.31835 .25192 L
.33895 .26672 L
.37915 .30621 L
.41784 .3541 L
.45898 .40995 L
.4986 .46246 L
.53671 .50676 L
.55796 .52742 L
.57727 .5432 L
.59736 .55635 L
.61632 .5656 L
.62604 .56914 L
.63633 .572 L
.64512 .57373 L
.65011 .57442 L
.65237 .57466 L
.65478 .57488 L
.65614 .57498 L
Mistroke
.65737 .57506 L
.65862 .57512 L
.65976 .57517 L
.66111 .57522 L
.66181 .57523 L
.66256 .57525 L
.66381 .57526 L
.66453 .57526 L
.66519 .57526 L
.66647 .57525 L
.66769 .57522 L
.66878 .57519 L
.66996 .57514 L
.67262 .575 L
.67507 .57482 L
.67935 .57439 L
.68406 .57375 L
.69361 .57194 L
.70373 .56929 L
.71299 .56623 L
.73386 .5572 L
.75282 .54659 L
.77354 .5326 L
.81415 .49869 L
.85325 .45911 L
.8948 .41138 L
.93483 .36191 L
.97335 .31271 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo04?o
oooo1_oo003kooooo`008Oooool00ol0003oooooooooo`0mooooo`Co00000_oo0005o`0000Woo`00
loooool0027ooooo0ol0000gooooo`Ko00004?ooool4o`000003ool00?oooooooooo0?3ooooo000Q
ooooo`03o`000?oooooooooo03Cooooo0ooo000Jooooo`?o0000l?ooool0027ooooo00?o0000oooo
ooooool0<Oooool00ol0003oo`00ool0000Pooooo`;o0000k_ooool0027ooooo00?o0000oooooooo
ool0;_ooool2o`0000;oo`009?ooool2o`000>cooooo000Qooooo`03o`000?oooooooooo02_ooooo
0ol00002ool002Sooooo0_l0003Zooooo`008Oooool00ol0003oooooooooo`0Yooooo`;o00000ooo
000/ooooo`;oo`00j?ooool0027ooooo00?o0000ooooooooool09oooool2o`0000;oo`00<Oooool0
0ooo003oooooooooo`3Uooooo`008Oooool00ol0003oooooooooo`0Tooooo`?o000000?oooooool0
0?ooool0<oooool2ool00>Gooooo000Qooooo`?o00008_ooool2o`0003_ooooo00?oo`00oooooooo
ool0h_ooool0027ooooo00?o0000ooooooooool07oooool3o`0001_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00gooooo00?oo`00o`00
0?ooool0;Oooool4o`000003oa0@4?oooooooooo03_ooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03gooooo1Ol0000Kooooo`008Oooool00ol0
003oooooooooo`0Mooooo`;o00007_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00gooooo00?oo`00o`000?ooool0;_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0Kooooo`04o`000?oo003o
o`00ool001kooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00gooooo
00?oo`00o`000?ooool0;Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0??ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003ooooooooo
o`0Hooooo`04o`000?oo003oo`00ool0027ooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo00oooooo00?oo`00o`000?ooool0;?ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0?_ooool00onHV9So8B4Qonk^kP0Kooooo`00
8Oooool00ol0003oooooooooo`0Fooooo`?oo`009?ooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00Aooooo`03ool00?l0003ooooo02_ooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0@?ooool0
0omgMgOoIVIVooooo`0Jooooo`008Oooool00ol0003oooooooooo`0Cooooo`?oo`009oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool00ooo003o0000ooooo`0Z
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`13
ooooo`03o`000?oooooooooo01Wooooo000Qooooo`?o00004?ooool3ool002[ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo01Gooooo00?oo`00o`000?ooool0:Oooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0?oooool0
1Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`03o`000?oooooooooo00gooooo0_l00000
0ooo003oooooooooo`0[ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0001Kooooo00?o
0000ooooooooool09Oooool00omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0
000nooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`06oooool0027ooooo00?o0000ooooooooool02_oo
ool3o`0005cooooo00?o0000ooooooooool0f?ooool0027ooooo00?o0000ooooooooool02?ooool2
o`00063ooooo00?o0000ooooooooool0eoooool0027ooooo00?o0000ooooooooool01?ooool2ool0
00;o0000Hoooool00ol0003oooooooooo`3Fooooo`008Oooool01?l0003oooooooooooooool3ool0
0003o`000?oooooooooo06Gooooo00?o0000ooooooooool0boooool2o`0000;ooooo0_l00004oooo
o`008Oooool01Ol0003oo`00ool00?oo003o000006[ooooo00?o0000ooooooooool0boooool01_o^
k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Jooooo`Oo000000?oo`00o`000?l00000ool0000X
o`000003ool00?l0003o000000Go00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool00oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ooo003oooooooooo`0Aooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01_ooool00ooo003o0000ooooo`03ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03ool00?l0003o
oooo01;ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000ooooooooool0Koooool0
0ooo003o0000ooooo`2cooooo`03o`000?oo003ooooo01;ooooo0_l00002ooooo`;o00001?ooool0
027ooooo00?o0000ooooooooool0L?ooool00ooo003oooooooooo`2aooooo`03o`000?oo003ooooo
01gooooo000Qooooo`03o`000?oooooooooo077ooooo00?oo`00ooooooooool0[oooool00ol0003o
o`00ooooo`0Nooooo`008Oooool00ol0003oooooooooo`1booooo`03ool00?oooooooooo0:kooooo
00?oo`00ooooooooool07_ooool0027ooooo00?o0000ooooooooool0Loooool00ooo003ooooooooo
o`2/ooooo`03ool00?oooooooooo01oooooo000Qooooo`?o0000Loooool00ooo003o0000ooooo`2[
ooooo`03ool00?oooooooooo023ooooo000Qooooo`03o`000?oooooooooo07Cooooo00?oo`00o`00
0?ooool0ZOooool00ol0003oooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`1eooooo`03
ool00?oooooooooo0:Oooooo00?o0000ooooooooool08_ooool0027ooooo00?o0000ooooooooool0
M_ooool00ooo003oooooooooo`2Uooooo`03o`000?oooooooooo02?ooooo000Qooooo`03o`000?oo
oooooooo07Oooooo00?oo`00ooooooooool0Y?ooool00ol0003oooooooooo`0Sooooo`008Oooool0
0ol0003oooooooooo`1hooooo`03ool00?oooooooooo0:;ooooo00?o0000ooooooooool09?ooool0
027ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo
02Gooooo000Qooooo`?o0000NOooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo02Ko
oooo000Qooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0WOooool00ooo003ooooo
ooooo`0Wooooo`008Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo09cooooo00?o
o`00ooooooooool09oooool0027ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`2K
ooooo`03o`000?oo003ooooo02Sooooo000Qooooo`03o`000?oooooooooo07cooooo00?o0000oooo
ooooool0VOooool00ol0003oo`00ooooo`0Yooooo`008Oooool00ol0003oooooooooo`1mooooo`03
o`000?oooooooooo09Oooooo00?o0000ool00?ooool0:_ooool0027ooooo00?o0000ooooooooool0
O_ooool00ol0003oooooooooo`2Fooooo`03ool00?oooooooooo02[ooooo000Qooooo`03o`000?oo
oooooooo07kooooo00?oo`00ooooooooool0UOooool00ooo003oooooooooo`0[ooooo`008Oooool3
o`0007kooooo00?oo`00o`000?ooool0U?ooool00ooo003oooooooooo`0/ooooo`008Oooool00ol0
003oooooooooo`1oooooo`03ool00?l0003ooooo09;ooooo00?o0000ool00?ooool0;Oooool0027o
oooo00?o0000ooooooooool0P?ooool00ooo003oooooooooo`2Aooooo`03ool00?oooooooooo02go
oooo000Qooooo`03o`000?oooooooooo083ooooo00?oo`00o`000?ooool0T?ooool00ooo003ooooo
ooooo`0^ooooo`008Oooool00ol0003oooooooooo`21ooooo`03ool00?l0003ooooo08kooooo00?o
o`00ooooooooool0;oooool0027ooooo00?o0000ooooooooool0P_ooool00ooo003o0000ooooo`2<
ooooo`03ool00?oooooooooo033ooooo000Qooooo`03o`000?oooooooooo08?ooooo00?oo`00oooo
ooooool0Roooool00ol0003oooooooooo`0`ooooo`008Oooool3o`0008?ooooo00?oo`00o`000?oo
ool0R_ooool00ol0003oooooooooo`0aooooo`008Oooool00ol0003oooooooooo`24ooooo`03ool0
0?l0003ooooo08Sooooo00?o0000ooooooooool0<_ooool0027ooooo00?o0000ooooooooool0QOoo
ool00ooo003oooooooooo`26ooooo`03o`000?oooooooooo03?ooooo000Qooooo`03o`000?oooooo
oooo08Gooooo00?oo`00o`000?ooool0Q_ooool00ol0003oooooooooo`0cooooo`008Oooool00ol0
003oooooooooo`26ooooo`03ool00?l0003ooooo08Cooooo00?o0000ooooooooool0=?ooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Cooooo00?o0000ooooooooool0Qoooool00ooo003o0000ooooo`22ooooo`03o`000?oooooo
oooo03Gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo083ooooo00?o0000
ooooooooool0=_ooool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol00029ooooo`03o`000?oooooooooo07gooooo00?oo`00o`000?ooool0>?ooool0
00Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000
ooooooooool0R_ooool00ol0003oooooooooo`1looooo`03ool00?oooooooooo03Sooooo0007oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o
0000ooooooooool0Roooool00ol0003oooooooooo`1jooooo`03ool00?oooooooooo03Wooooo0007
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo08_ooooo00?o0000ooooooooool0NOooool00ooo003o0000ooooo`0jooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`2<ooooo`03o`000?oooooooooo07Oooooo00?oo`00o`000?ooool0>oooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`2=ooooo`03o`000?oo
oooooooo07Gooooo00?oo`00o`000?ooool0??ooool0027ooooo00?o0000ooooooooool0S_ooool0
0ooo003oooooooooo`1cooooo`03ool00?l0003ooooo03gooooo000Qooooo`03o`000?oooooooooo
08kooooo00?oo`00ooooooooool0L_ooool00ooo003o0000ooooo`0nooooo`008Oooool3o`0008oo
oooo00?oo`00ooooooooool0L?ooool00ooo003o0000ooooo`0oooooo`008Oooool00ol0003ooooo
ooooo`2@ooooo`03ool00?oooooooooo06kooooo00?oo`00o`000?ooool0@?ooool0027ooooo00?o
0000ooooooooool0TOooool00ooo003oooooooooo`1/ooooo`03ool00?oooooooooo047ooooo000Q
ooooo`03o`000?oooooooooo097ooooo00?o0000ool00?ooool0Joooool00ooo003oooooooooo`12
ooooo`008Oooool00ol0003oooooooooo`2Booooo`03ool00?oooooooooo06Wooooo00?o0000oooo
ooooool0@oooool0027ooooo00?o0000ooooooooool0Toooool00ooo003oooooooooo`1Wooooo`03
o`000?oooooooooo04Cooooo000Qooooo`03o`000?oooooooooo09Cooooo00?oo`00ooooooooool0
IOooool00ol0003oooooooooo`15ooooo`008Oooool3o`0009Gooooo00?oo`00ooooooooool0Hooo
ool00ol0003oooooooooo`16ooooo`008Oooool00ol0003oooooooooo`2Eooooo`03o`000?oo003o
oooo06;ooooo00?o0000ooooooooool0Aoooool0027ooooo00?o0000ooooooooool0U_ooool00ol0
003oo`00ooooo`1Pooooo`03o`000?oooooooooo04Sooooo000Qooooo`03o`000?oooooooooo09Oo
oooo00?o0000ool00?ooool0G_ooool00ol0003oooooooooo`19ooooo`008Oooool00ol0003ooooo
ooooo`2Hooooo`03o`000?oooooooooo05cooooo00?oo`00ooooooooool0B_ooool0027ooooo00?o
0000ooooooooool0VOooool00ol0003oooooooooo`1Jooooo`03o`000?oo003ooooo04_ooooo000Q
ooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool0F?ooool2o`000003ool00?oooooo
oooo04_ooooo000Qooooo`03o`000?oooooooooo09[ooooo00?o0000ooooooooool0E_ooool00ol0
003oooooool0001>ooooo`008Oooool3o`0009_ooooo00?o0000ooooooooool0E?ooool00ol0003o
o`00ool0001?ooooo`008Oooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo05;ooooo
00?o0000ool00?ooool0D?ooool0027ooooo00?o0000ooooooooool0WOooool2o`00057ooooo00?o
0000ool00?ooool0DOooool0027ooooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`1=
ooooo`03o`000?oo003ooooo05;ooooo000Qooooo`03o`000?oooooooooo09oooooo00?oo`00o`00
0?ooool0C?ooool00ol0003oo`00ooooo`1Cooooo`008Oooool00ol0003oooooooooo`2Pooooo`03
ool00?l0003ooooo04[ooooo00?o0000ool00?ooool0E?ooool0027ooooo00?o0000ooooooooool0
XOooool00ooo003o0000ooooo`18ooooo`03o`000?oo003ooooo05Gooooo000Qooooo`?o0000X_oo
ool00ooo003o0000o`000016ooooo`03o`000?oo003ooooo05Kooooo000Qooooo`03o`000?oooooo
oooo0:?ooooo00?oo`00ooooool00000A?ooool00ol0003oooooooooo`1Gooooo`008Oooool00ol0
003oooooooooo`2Tooooo`;oo`0000?o0000ooooooooool0@?ooool00ol0003oooooooooo`1Hoooo
o`008Oooool00ol0003oooooooooo`2Vooooo`03ool00?l0003ooooo03kooooo0_l0001Kooooo`00
8Oooool00ol0003oooooooooo`2Wooooo`;oo`00?Oooool00ol0003oooooooooo`1Kooooo`006?oo
ool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0ZOooool00ooo003ooooooooo
o`0hooooo`;o0000G_ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Z
ooooo`03ool00?l0003ooooo03Kooooo00?oo`00ooooooooool0G_ooool001[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`2[ooooo`03ool00?l0003ooooo03?ooooo00?o0000ool0
0?ooool0H?ooool001[ooooo00?o0000ooooooooool01?ooool3o`000:gooooo00?o0000oooooooo
ool0;oooool00ol0003oo`00ool0001Rooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0:kooooo00?o0000ooooooooool0;Oooool2ool006Cooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0[oooool00ol0003oooooooooo`0Zooooo`;oo`00I_oo
ool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2`ooooo`?o00009oooool2
ool006Sooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0/oooool00ol0
003oo`00ool0000Qooooo`?oo`00J_ooool0027ooooo00?o0000ooooooooool0]Oooool00ol0003o
o`00ool0000Mooooo`;oo`0000?o0000ooooooooool0J_ooool0027ooooo00?o0000ooooooooool0
]oooool00ol0003oo`00o`00000Jooooo`;o0000K_ooool0027ooooo0ol0002iooooo`Koo`004_oo
ool3o`00073ooooo000Qooooo`03o`000?oooooooooo0;gooooo0_l0000=ool000Go0000Loooool0
027ooooo00?o0000ooooooooool0`Oooool9o`0007[ooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00Z?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOo
oooo0:?ooooo0027ooooo`?o00004oooool00olQ8B7ogMgMooooo`07ooooo`03omgMgOl@413ok^k^
01Sooooo00?ok^k^oa0@4?oMgMd0Xoooool007kooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;o
k^k^00?ooooo00?o0000ooooooooool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00?o
V9RHoeEEEOooool01oooool01?mEEEGoV9RHooooooooool5o`0000Wooooo00?oEEEEojVYZOooool0
0_ooool00onj^[[oA4A4ooooo`02ooooo`03ohN7QomVIVKooooo01?ooooo1?l000000ol@413ooooo
ooooo`02ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<07_ooooo001nooooo`07oa0@
4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP03ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj
^_o^k^koMgMgoa0@4003ooooo`03o`000?oMgMgooooo00Kooooo00Wo0000oooooooooooooooooiRH
V?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P?ooooo00?ok^k^
o`000?ooool02oooool6o`0000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@1kooooo`00O_ooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@4100
0oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo0_mgMgL7ooooo`03oc8b
<_oooooooooo00;ooooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool00005ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo0000
07_ooooo001nooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Go0000ooooooooooooooooo`00000=
ooooo`03o`000?oooooooooo00Gooooo00?ok^k^oa0@4?o^k^h01_ooool00olb<S;oooooooooo`03
ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001Oooool00ol0003ooooooooo
o`0:ooooo`Ko00001?ooool00ol0003oooooooooo`0:ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80
Noooool007kooooo00?ogMgMob4Q8Oo^k^h00oooool00ol0003oooooooooo`02o`0000gooooo00?o
0000ooooooooool01_ooool00omEEEGoV9RHooooo`05ooooo`03o`000?o^k^kooooo00Cooooo00?o
MgMgofIVI_ooool02_ooool01?oMgMgo410@ooooool00004ooooo`03onk^k_l0003ooooo01Gooooo
00?o0000ooooooooool02_ooool01Oo<c<co0000o`000?l0003oc<c<07_ooooo001oooooo`03oiRH
V?mgMgOooooo00;ooooo00?o0000ooooooooool03Oooool00ol@413o0000o`000003o`0000Gooooo
00?ogMgMoa0@4?ooool01Oooool00omEEEGoMgMgooooo`05ooooo`03o`000?oooooooooo00Sooooo
1ol00002ooooo`03ogMgMomEEEGooooo01Gooooo00?o0000ooooooooool02_ooool01Ol@413o^[Zj
oooooonj^[[o410@07_ooooo002Fooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool0
1?ooool02OoMgMgo410@onk^k_oooooo0000okZj^_ooooooV9RHoa0@400Booooo`03onk^k_l@413o
gMgM01Kooooo00?o0000ooooooooool02_ooool01Ol0003o^[Zjoooooonj^[[o000007_ooooo002F
ooooo`03o`000?oooooooooo00Oooooo00?o^[ZjodA4A?ooool01Oooool02?mgMgOoIVIVoooooonH
V9So410@o`000?lQ8B7oc<c<4_ooool00omVIVKoMgMgooooo`0Dooooo`03oeEEEOmVIVKo000000co
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@1kooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.85) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .33202 L
.08255 .34212 L
.0932 .34667 L
.10458 .35084 L
.11531 .35407 L
.12507 .35642 L
.12977 .35734 L
.13488 .35819 L
.13935 .35881 L
.14415 .35934 L
.1467 .35957 L
.14903 .35974 L
.15139 .35989 L
.15359 .36 L
.15614 .36009 L
.15749 .36012 L
.15824 .36014 L
.15892 .36015 L
.16018 .36016 L
.16088 .36017 L
.16153 .36017 L
.16273 .36016 L
.16399 .36015 L
.1653 .36013 L
.16649 .3601 L
.16787 .36006 L
.16917 .36002 L
.17401 .35977 L
.17675 .35958 L
.17928 .35937 L
.18502 .35879 L
.19465 .3575 L
.20368 .35597 L
.22428 .35151 L
.26297 .34118 L
.28262 .33595 L
.30411 .33102 L
.31404 .32918 L
.32464 .3276 L
.32979 .32699 L
.33464 .32652 L
.33901 .32618 L
.34374 .32591 L
.34609 .32582 L
.34742 .32578 L
.34863 .32575 L
.34975 .32573 L
.35097 .32571 L
.35213 .3257 L
Mistroke
.3532 .3257 L
.35386 .3257 L
.35456 .32571 L
.35585 .32572 L
.3571 .32574 L
.35824 .32577 L
.36086 .32586 L
.36361 .32599 L
.36612 .32614 L
.36881 .32635 L
.37365 .32681 L
.37941 .32753 L
.38465 .32835 L
.39459 .33032 L
.40378 .33265 L
.42455 .33972 L
.44325 .34816 L
.46387 .35958 L
.50413 .38708 L
.54287 .41723 L
.58406 .44872 L
.60462 .46274 L
.62373 .47411 L
.64338 .48376 L
.6619 .49072 L
.67174 .49351 L
.67692 .49471 L
.68239 .49578 L
.68701 .49653 L
.69208 .49717 L
.6943 .4974 L
.69669 .49761 L
.69873 .49775 L
.70099 .49788 L
.70231 .49793 L
.70355 .49797 L
.70486 .49801 L
.70559 .49802 L
.70627 .49803 L
.7074 .49804 L
.70864 .49803 L
.70994 .49802 L
.71115 .498 L
.71184 .49798 L
.71259 .49796 L
.71395 .4979 L
.71649 .49777 L
.71947 .49756 L
.72221 .49731 L
.72686 .49677 L
Mistroke
.73197 .496 L
.74232 .4939 L
.75247 .49115 L
.76175 .48804 L
.78263 .47908 L
.82236 .45516 L
.86057 .42502 L
.90124 .38719 L
.94039 .34713 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .33179 L
.08255 .3421 L
.0932 .34679 L
.10458 .35113 L
.11531 .3545 L
.12507 .35695 L
.12977 .35791 L
.13488 .35879 L
.13935 .35943 L
.14415 .35997 L
.1467 .3602 L
.14903 .36038 L
.15139 .36052 L
.15359 .36062 L
.15482 .36067 L
.15614 .3607 L
.15689 .36072 L
.1576 .36073 L
.15823 .36074 L
.15892 .36075 L
.16021 .36075 L
.16085 .36075 L
.16156 .36075 L
.16282 .36074 L
.16399 .36071 L
.16529 .36068 L
.16672 .36064 L
.1693 .36052 L
.17181 .36038 L
.17414 .36021 L
.17941 .35974 L
.18502 .35908 L
.19439 .35767 L
.20449 .35574 L
.22277 .35143 L
.26391 .33984 L
.28444 .33432 L
.30353 .33005 L
.31301 .32836 L
.32196 .3271 L
.32691 .32654 L
.33227 .32607 L
.33464 .3259 L
.33715 .32575 L
.3393 .32565 L
.34164 .32556 L
.34295 .32553 L
.34417 .3255 L
.34533 .32548 L
Mistroke
.34657 .32547 L
.34779 .32547 L
.34894 .32547 L
.34997 .32548 L
.35108 .3255 L
.3523 .32553 L
.35365 .32556 L
.35636 .32567 L
.35887 .3258 L
.36122 .32596 L
.36584 .32635 L
.37006 .32681 L
.37953 .32821 L
.38947 .33021 L
.39865 .33256 L
.41943 .33959 L
.43813 .34784 L
.45874 .35884 L
.499 .3848 L
.53774 .41294 L
.57893 .4427 L
.61861 .46777 L
.63861 .47809 L
.65677 .48575 L
.67642 .49196 L
.6816 .49321 L
.68721 .49438 L
.69247 .49529 L
.69738 .49598 L
.70196 .49648 L
.70431 .49668 L
.70687 .49686 L
.70832 .49694 L
.70967 .497 L
.71093 .49705 L
.7116 .49707 L
.71232 .49709 L
.71357 .49712 L
.71473 .49713 L
.71538 .49714 L
.71607 .49714 L
.7173 .49713 L
.71861 .49711 L
.71981 .49709 L
.7212 .49704 L
.7225 .49699 L
.72483 .49687 L
.72735 .4967 L
.73307 .49614 L
.73835 .49543 L
Mistroke
.74803 .49362 L
.75709 .49135 L
.77772 .48409 L
.79799 .47423 L
.81652 .46299 L
.85624 .43249 L
.89446 .39664 L
.93512 .35412 L
.97427 .31115 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`3ooooooc_ooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooooooo`0003[o00003?ooool01?oMgMgo0000oa0@
4?o<c<`5ooooo`008Oooool00ol0003oo`00ool0000<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool04Oooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool00ol0003ooooooooo
o`02ool000[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool2o`0001?ooooo00Co8B4QogMgMomgMgOo<S8b
1Oooool0027ooooo00?o0000ooooooooool00_ooool2ool00?oooooo8Oooool00ooo003o0000oooo
o`0Cooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000
ool00?ooool0oooooolOooooo`03ool00?oooooooooo01gooooo000Qooooo`03o`000?oooooooooo
00Gooooo0_oo001Kooooo`;oo`00_oooool00ooo003oooooooooo`0Nooooo`008Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oo003oo`0004kooooo0ooo000:o`0000[oo`000ol0002aooooo`03
ool00?oooooooooo01oooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ool00?oo0000
Aoooool5ool000?o00005?ooool00ooo003oooooooooo`03o`000:gooooo00?oo`00ooooooooool0
8?ooool0027ooooo0ol00009ooooo`;o000000?oo`00ooooooooool0@?ooool4ool00003o`000?oo
oooooooo01oooooo0ol0002Yooooo`03ool00?oooooooooo027ooooo000Qooooo`03o`000?oooooo
oooo00_ooooo00?o0000ool00?l00000?Oooool3ool000;o00009oooool3o`000:Gooooo00?oo`00
ooooooooool08_ooool0027ooooo00?o0000ooooooooool03_ooool2o`0003Oooooo0_l00002ool0
02gooooo1?oo00000ol0003oooooooooo`2Oooooo`03ool00?oooooooooo02?ooooo000Qooooo`03
o`000?oooooooooo013ooooo0ol0000aooooo`?o0000=Oooool3ool009kooooo00?oo`00oooooooo
ool09?ooool0027ooooo00?o0000ooooooooool04oooool3o`0002_ooooo0ol0000kooooo`;oo`00
Voooool00ooo003oooooooooo`0Uooooo`008Oooool00ol0003oooooooooo`0Fooooo`04ool00?l0
003o0000o`0002Cooooo0_oo00000ol0003oooooooooo`0mooooo`03o`000?oo003ooooo09Sooooo
00?oo`00ooooooooool09_ooool0027ooooo00?o0000ooooooooool05oooool3ool000?o00007?oo
ool5ool004Cooooo0_oo00000ol0003oooooooooo`2Cooooo`03ool00?oooooooooo02Oooooo000Q
ooooo`?o00006_ooool4ool000;o00004_ooool3o`0000Coo`00Boooool00ooo003o0000o`00002B
ooooo`03ool00?oooooooooo02Sooooo000Qooooo`03o`000?oooooooooo01kooooo2?oo000:o`00
00Goo`00D?ooool01?oo003oooooo`000?l0002?ooooo`03o`000?oooooooooo02Wooooo000Qoooo
o`03o`000?oooooooooo08Kooooo00Coo`00oooooooooooo0000SOooool00ol0003oooooooooo`0Z
ooooo`008Oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo08Wooooo00?o0000oooo
ooooool0:oooool0027ooooo00?o0000ooooooooool0Roooool2o`0008Sooooo00?o0000oooooooo
ool0;?ooool0027ooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`24ooooo`03o`00
0?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool0P_oo
ool00ol0003oooooooooo`0^ooooo`008Oooool00ol0003oooooooooo`2?ooooo`;o0000POooool0
0ol0003oooooooooo`0_ooooo`008Oooool3o`0008oooooo0ooo001oooooo`03o`000?oo003ooooo
033ooooo000Qooooo`03o`000?oooooooooo09;ooooo0_oo001looooo`03o`000?oo003ooooo037o
oooo000Qooooo`03o`000?oooooooooo09?ooooo00?o0000ool00?ooool0NOooool00ol0003oo`00
ooooo`0booooo`008Oooool00ol0003oooooooooo`2Eooooo`03ool00?oooooooooo07Kooooo00?o
0000ool00?ooool0<oooool0027ooooo00?o0000ooooooooool0U_ooool00ooo003oooooooooo`1d
ooooo`03o`000?oo003ooooo03Cooooo000Qooooo`03o`000?oooooooooo09Oooooo0_oo001coooo
o`03o`000?oo003ooooo03Gooooo000Qooooo`03o`000?oooooooooo09Wooooo00?oo`00oooooooo
ool0Koooool00ol0003oo`00ooooo`0fooooo`008Oooool3o`0009[ooooo00?oo`00ooooooooool0
KOooool00ol0003oo`00ooooo`0gooooo`008Oooool00ol0003oooooooooo`2Kooooo`03ool00?l0
003ooooo06_ooooo00?o0000ool00?ooool0>?ooool0027ooooo00?o0000ooooooooool0W?ooool0
0ooo003o0000ooooo`1Yooooo`03o`000?oo003ooooo03Wooooo000Qooooo`03o`000?oooooooooo
09kooooo00?o0000ooooooooool0I_ooool00ol0003oo`00ooooo`0jooooo`008Oooool00ol0003o
ooooooooo`2Oooooo`;o0000IOooool00ol0003oo`00ooooo`0kooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0
003oooooooooo`2Qooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0??ooool000Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03oooo
o`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0moooo
o`001oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`00
0:?ooooo0_l0001Mooooo`;o0000@?ooool000Oooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0YOooool2ool005[ooooo00?o0000oooo
ooooool0@?ooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01?ooool00ol0003oooooooooo`2Vooooo`03o`000?oo003ooooo05Oooooo00?o0000
ooooooooool0@Oooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0Yoooool00ol0003oo`00ool0001Dooooo`;o0000A?ooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0Z?ooool2o`000003ool00?oooooooooo053ooooo00?o0000ool00?oo0000A?ooool0
00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`2Z
ooooo`03o`000?oo003oo`0004oooooo00?o0000ool00?ooool0AOooool0027ooooo00?o0000oooo
ooooool0Zoooool00ol0003oooooool0001<ooooo`03o`000?oo003oo`0004Oooooo000Qooooo`03
o`000?oooooooooo0:cooooo0_l00002ool004Wooooo00?o0000ool00?ooool0B?ooool0027ooooo
0ol0002^ooooo`;o000000?oo`00ooooooooool0AOooool00ol0003oo`00ooooo`19ooooo`008Ooo
ool00ol0003oooooooooo`2`ooooo`03o`000?oo003ooooo04?ooooo00?o0000ool00?oo0000Booo
ool0027ooooo00?o0000ooooooooool0/Oooool00ol0003oo`00ooooo`10ooooo`;o000000?oo`00
ooooooooool0Boooool0027ooooo00?o0000ooooooooool0/oooool2o`0003gooooo0_l00002ool0
04kooooo000Qooooo`03o`000?oooooooooo0;Gooooo00?o0000ooooooooool0>?ooool2o`000003
oooooooo003ooooo04oooooo000Qooooo`03o`000?oooooooooo0;Kooooo0_l0000gooooo`04o`00
0?ooooooooooool0057ooooo000Qooooo`03o`000?oooooooooo0;Sooooo00?o0000ooooooooool0
<_ooool2o`0005Gooooo000Qooooo`?o0000^Oooool2o`0000;oo`00;_ooool2o`0005Oooooo000Q
ooooo`03o`000?oooooooooo0;_ooooo0_l00002ool002[ooooo0_l0001Iooooo`008Oooool00ol0
003oooooooooo`2mooooo`;o00000_oo000Vooooo`;o0000Foooool0027ooooo00?o0000oooooooo
ool0_oooool2o`0000;oo`008_ooool2o`0000;oo`00Foooool0027ooooo00?o0000ooooooooool0
`_ooool00ol0003oo`00ool00002ool001cooooo00Co0000ool00?oo003oo`00GOooool0027ooooo
00?o0000ooooooooool0aOooool2o`0000?oo`005_ooool01?l0003oo`00ool00?oo001Pooooo`00
8Oooool00ol0003oooooooooo`38ooooo`;o000000?oo`00ooooooooool04?ooool2o`0000;oo`00
Hoooool0027ooooo00?o0000ooooooooool0boooool:o`0000[oo`00IOooool0027ooooo0ol0003o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co
000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3
o`000?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooo
odGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?o
EEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
Y?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:Oooooo0023ooooo`?o00005?oo
ool00olQ8B7ogMgMooooo`06ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Yooo
ool007_ooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool0
2oooool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?oV9RHoeEEEOooool01_ooool00omEEEGo
V9RHooooo`02ooooo`Go00002Oooool00omEEEGoZJVYooooo`02ooooo`06okZj^_m4A4Cooooooooo
oon7QhOoIVIV5Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`05olc<c?lQ8B7o
0000ob4Q8Oo<c<`01?ooool01Om4A4Co0000o`000?lb<S;ogMgM07Gooooo001kooooo`07oa0@4?oM
gMgoMgMgob4Q8OooooooQhN7ofIVIP02ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_o^
k^koMgMgoa0@4004ooooo`03o`000?oMgMgooooo00Gooooo00?o0000ooooooooool00_ooool01OnH
V9So8B4Qonk^k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X2ooooo`03onk^
k_l0003ooooo00_ooooo1_l00005ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05ob4Q
8OnHV9SooooooiRHV?lQ8B401oooool00omgMgOo<S8booooo`1dooooo`00Noooool01ol0003ooooo
omgMgOlb<S;oooooonk^k_l@41000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Kooooo0_mgMgL6ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@
413ogMgMooooool00004ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0Loooool007_ooooo00CoEEEE
ojVYZOoooooo00000_ooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00Kooooo
00?ok^k^oa0@4?o^k^h01Oooool00olb<S;oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00_ooooo
00CoQhN7ofIVI_oooooo00001?ooool00ol0003oooooooooo`0:ooooo`Ko00001Oooool00ol0003o
ooooooooo`0:ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801oooool00omgMgOo<S8booooo`1doooo
o`00Noooool00ooMgMgo8B4Qonk^kP03ooooo`04o`000?oooooo0000o`0000gooooo00?o0000oooo
ooooool01oooool00omEEEGoV9RHooooo`04ooooo`03o`000?o^k^kooooo00Gooooo00?oMgMgofIV
I_ooool02_ooool01?oMgMgo410@ooooool00003ooooo`03onk^k_l0003ooooo01Kooooo00?o0000
ooooooooool02_ooool01Oo<c<co0000o`000?l0003oc<c<00Cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c01eooooo`00O?ooool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo00cooooo00?o
410@o`000?l000000ol00006ooooo`03omgMgOl@413ooooo00Cooooo00?oEEEEogMgMoooool01_oo
ool00ol0003oooooooooo`08ooooo`Oo000000?oooooogMgMomEEED05oooool00ol0003ooooooooo
o`0:ooooo`05oa0@4?nj^[[ooooookZj^_l@41001?ooool00ol0003oooooooooo`1gooooo`00T_oo
ool00ol0003oooooooooo`08ooooo`03oeEEEOnHV9Sooooo00?ooooo00?ogMgMoa0@4?o^k^h00_oo
ool01Ol0003o^[ZjoooooonHV9So410@017ooooo00?ok^k^oa0@4?oMgMd05oooool00ol0003ooooo
ooooo`0:ooooo`05o`000?nj^[[ooooookZj^_l000001?ooool00ol0003oooooooooo`1gooooo`00
T_ooool00ol0003oooooooooo`08ooooo`03okZj^_m4A4Cooooo00Cooooo00WoMgMgofIVI_oooooo
oooooiRHV?l@413o0000ob4Q8Oo<c<`04Oooool00omVIVKoMgMgooooo`0Eooooo`03oeEEEOmVIVKo
000000cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@04ooooo`Co0000M_ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .35624 L
.10458 .40076 L
.12507 .41833 L
.14415 .43187 L
.16254 .44218 L
.17277 .44672 L
.18221 .45017 L
.19242 .45308 L
.1977 .45426 L
.20351 .45531 L
.20856 .45601 L
.21329 .45649 L
.2159 .45668 L
.21828 .45681 L
.2196 .45686 L
.22029 .45689 L
.22104 .45691 L
.22175 .45693 L
.22239 .45694 L
.22365 .45695 L
.22486 .45695 L
.22598 .45695 L
.22721 .45693 L
.22853 .4569 L
.22991 .45685 L
.23122 .45679 L
.23368 .45666 L
.23597 .45649 L
.2381 .4563 L
.2429 .45576 L
.2477 .45507 L
.253 .45414 L
.26372 .4517 L
.28307 .44558 L
.30392 .43683 L
.34506 .41461 L
.38469 .38987 L
.4228 .36603 L
.46336 .34337 L
.5024 .32621 L
.52375 .31924 L
.53354 .31666 L
.5439 .31436 L
.55343 .31263 L
.56391 .31116 L
.56851 .31065 L
.57345 .3102 L
.57777 .30988 L
.58237 .30962 L
Mistroke
.58512 .3095 L
.58762 .30941 L
.58883 .30938 L
.59013 .30935 L
.59136 .30932 L
.5925 .30931 L
.5932 .3093 L
.59383 .30929 L
.59454 .30929 L
.5953 .30929 L
.59603 .30929 L
.59682 .30929 L
.59756 .30929 L
.59825 .30929 L
.59947 .3093 L
.60017 .30931 L
.60082 .30932 L
.60354 .30937 L
.606 .30944 L
.60859 .30953 L
.61322 .30975 L
.6182 .31005 L
.62364 .31045 L
.64329 .3125 L
.66426 .31545 L
.70581 .32231 L
.72665 .3256 L
.74584 .32822 L
.76456 .33024 L
.774 .33102 L
.77931 .33138 L
.78436 .33167 L
.78924 .3319 L
.79181 .332 L
.79455 .33209 L
.79684 .33215 L
.79937 .33221 L
.80168 .33225 L
.80384 .33228 L
.80506 .33229 L
.80576 .3323 L
.8064 .3323 L
.80707 .3323 L
.80779 .33231 L
.80909 .33231 L
.81028 .33231 L
.81156 .3323 L
.81278 .33229 L
.8139 .33228 L
.81641 .33225 L
Mistroke
.81917 .33219 L
.82205 .33212 L
.82475 .33204 L
.82972 .33184 L
.83514 .33157 L
.84501 .33092 L
.86354 .3292 L
.88323 .3267 L
.90421 .3234 L
.94581 .31544 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .35913 L
.10458 .40096 L
.12507 .4172 L
.14415 .42998 L
.16371 .44064 L
.18221 .44835 L
.192 .45147 L
.19716 .45283 L
.20263 .45407 L
.20722 .45494 L
.21228 .45573 L
.21689 .45627 L
.2212 .45665 L
.22377 .45681 L
.225 .45686 L
.22616 .45691 L
.22682 .45693 L
.22754 .45695 L
.22879 .45697 L
.22949 .45698 L
.23024 .45699 L
.23088 .45699 L
.23158 .45699 L
.23287 .45698 L
.23404 .45695 L
.23469 .45694 L
.2354 .45692 L
.23668 .45687 L
.23916 .45674 L
.24145 .45659 L
.24572 .4562 L
.25043 .45562 L
.25997 .45396 L
.27007 .45155 L
.27932 .44875 L
.30018 .44057 L
.3398 .41917 L
.37791 .3942 L
.41847 .36697 L
.45751 .34377 L
.47743 .33399 L
.49901 .3253 L
.50912 .32196 L
.51981 .31895 L
.52984 .3166 L
.53899 .31485 L
.54843 .31344 L
.55328 .31285 L
.55857 .31233 L
Mistroke
.56344 .31195 L
.56796 .31167 L
.57228 .31148 L
.5747 .3114 L
.57688 .31135 L
.57809 .31133 L
.57921 .31131 L
.58045 .3113 L
.58177 .31129 L
.58244 .31129 L
.58316 .31129 L
.58447 .31129 L
.58575 .3113 L
.58693 .31131 L
.58803 .31132 L
.58906 .31134 L
.59141 .31139 L
.5937 .31146 L
.59617 .31155 L
.60147 .31179 L
.60704 .31213 L
.617 .3129 L
.63678 .31497 L
.65516 .3173 L
.69426 .32256 L
.71421 .32495 L
.73581 .32705 L
.74594 .32783 L
.75665 .32849 L
.7658 .32893 L
.77061 .32911 L
.77584 .32927 L
.77856 .32933 L
.78107 .32939 L
.78343 .32943 L
.78603 .32946 L
.78835 .32949 L
.78942 .3295 L
.79054 .3295 L
.79174 .32951 L
.79284 .32952 L
.79403 .32952 L
.79533 .32952 L
.796 .32952 L
.79674 .32952 L
.79743 .32951 L
.79807 .32951 L
.79928 .32951 L
.80056 .3295 L
.80322 .32947 L
Mistroke
.80615 .32943 L
.81136 .32934 L
.81623 .32922 L
.82663 .32886 L
.8365 .32839 L
.85503 .32719 L
.87485 .32544 L
.89324 .32333 L
.93239 .31724 L
.97399 .30938 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`3ooooooc_ooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0003o00000?oo00009Ol0
0004ool000Oo00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool00ooo003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo0ol0000:ool000;ooooo00Co0000oooooooooooooooo
3ol0000;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`05ooooo`Coo`0000Co0000oooooooooooo00004oooool01?o^k^ko8B4Qoa0@4?o^k^h5oooo
o`008Oooool00ol0003oo`00ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo1?oo00000ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo2Ooo0002ooooo`Go00001_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00ol00002ool000Oo
oooo00?o0000ooooooooool04Oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003o
ooooool0002Gooooo`Koo`000_l0000Rooooo`Goo`000_ooool5o`0004Wooooo1Ol0000Oooooo`;o
00000_ooool2o`0000Cooooo000Qooooo`04o`000?ooooooooooool009?ooooo0ooo00001?oooooo
0000o`000?l0000[ooooo`;oo`001Oooool4o`00043ooooo1?oo00000ol0003oooooooooo`0/oooo
o`008Oooool01Ol0003oooooooooooooooooo`00093ooooo0_oo00001?oooooo0000o`000?l0000i
ooooo`03o`000?oo003oo`0000Koo`00;?ooool;ool00003o`000?oooooooooo033ooooo000Qoooo
o`05o`000?ooooooooooooooool00000Soooool01?oo003o0000o`000?l00012ooooo`?o00002Ooo
000Qooooo`;oo`0000?oooooo`000?l000001?l0000gooooo`008Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo08[ooooo0ol0001Aooooo`Wo000000?oooooool00?oo00002ooo000=
o`0003gooooo000Qooooo`?o00000oooool00ol0003oooooooooo`27ooooo`;o0000GOooool<o`00
04cooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Q?ooool2o`000;Oo
oooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0O_ooool2ool000?o0000
^Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1looooo`;oo`000_l0
002looooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07Wooooo0_oo0002
o`000;kooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Moooool00ooo
003o0000o`000030ooooo`008Oooool00ol0003oooooooooo`07ooooo`03ool00?l0003ooooo07Go
oooo0_oo00000ol0003oooooooooo`30ooooo`008Oooool3o`0000Sooooo00?oo`00o`000?ooool0
L_ooool2ool00003o`000?oooooooooo0<;ooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o
o`00o`000?ooool0L?ooool00ooo003o0000o`000035ooooo`008Oooool00ol0003oooooooooo`0:
ooooo`03ool00?l0003ooooo06gooooo0_oo00000ol0003oooooooooo`35ooooo`008Oooool00ol0
003oooooooooo`0;ooooo`03ool00?l0003ooooo06_ooooo00?oo`00o`000?ooool0b?ooool0027o
oooo00?o0000ooooooooool03?ooool00ooo003o0000ooooo`1Yooooo`03o`000?oooooooooo0<Wo
oooo000Qooooo`03o`000?oooooooooo00gooooo00?oo`00o`000?ooool0I_ooool2o`000<cooooo
000Qooooo`03o`000?oooooooooo00kooooo00?oo`00o`000?ooool0I?ooool00ol0003ooooooooo
o`3<ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03ool00?l0003ooooo067ooooo0_l0003?
ooooo`008Oooool3o`00013ooooo00?oo`00o`000?ooool0Goooool00ol0003oooooooooo`3?oooo
o`008Oooool00ol0003oooooooooo`0Aooooo`03ool00?l0003ooooo05_ooooo0_oo00000ol0003o
ooooooooo`3@ooooo`008Oooool00ol0003oooooooooo`0Booooo`03ool00?l0003ooooo05Wooooo
00?oo`00o`000?ooool0doooool0027ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`1Fooooo`03ool00?l0003ooooo0=Cooooo000Qooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0Doooool2ool00=Oooooo000Qooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0DOooool00ooo003oooooooooo`3Gooooo`008Oooool00ol0003oooooooooo`0Gooooo`;o
0000Coooool2ool00=[ooooo000Qooooo`?o00006Oooool00ol0003oooooooooo`1:ooooo`03o`00
0?oo003ooooo0=_ooooo000Qooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0B?oo
ool2ool00=gooooo000Qooooo`03o`000?oooooooooo01[ooooo0_oo0017ooooo`03o`000?oo003o
oooo0=kooooo000Qooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0@_ooool2o`00
0003ool00?oooooooooo0=kooooo000Qooooo`03o`000?oooooooooo01gooooo0_oo0010ooooo`;o
0000hoooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool07oooool00ooo003oooooooooo`0koooo
o`;o0000iOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`03ooooo`03o`000?oooooooooo023ooooo0_oo000iooooo`;o0000ioooool000Oo
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0000Qoooo
o`03o`000?oo003ooooo03Kooooo00?o0000ooooooooool0ioooool000Oooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool08_ooool00ol0
003oo`00ool0000cooooo`03o`000?oo003oo`000>Wooooo0007ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool08oooool2
o`000003ool00?oooooooooo02kooooo00?o0000ool00?oo0000joooool000Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09Oooool0
0ol0003oo`00ooooo`0/ooooo`03o`000?oo003oo`000>gooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00?oo`00
o`000?ooool09oooool2o`0000;oo`00koooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co00001Oooool00ol0003oooooooooo`0Yooooo`?o00008oooool01?l0003oo`00ool00?oo
003aooooo`008Oooool00ol0003oooooooooo`0/ooooo`?o00007_ooool00ol0003oo`00ool0003d
ooooo`008Oooool00ol0003oooooooooo`0_ooooo`?o00006?ooool2o`0000;oo`00m_ooool0027o
oooo0ol0000aooooo`Coo`004_ooool3o`000?[ooooo000Qooooo`03o`000?oooooooooo03Cooooo
00?o0000ool00?oo00001Ooo0002ooooo`?o000000?oo`00o`000?l000000ol0003mooooo`008Ooo
ool00ol0003oooooooooo`0jooooo`;o00001Ooo003oooooo`Cooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0
003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000oooooooo
ool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool0
01Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00Z?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:?ooooo0027oooo
o`?o00004oooool00olQ8B7ogMgMooooo`07ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@
4?oMgMd0Xoooool007kooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00?ooooo00?o0000
ooooooooool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00?oV9RHoeEEEOooool01ooo
ool01?mEEEGoV9RHooooooooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool00onj^[[oA4A4
ooooo`02ooooo`03ohN7QomVIVKooooo01?ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q
1?ooool01?l@413o0000odA4A?o<c<alooooo`00O_ooool01ol@413ogMgMogMgMolQ8B7oooooohN7
QomVIVH00oooool00ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool0
0ol0003ogMgMooooo`06ooooo`09o`000?oooooooooooooooonHV9So8B4Qonk^k_ooooooA4A400[o
oooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X3ooooo`03onk^k_l0003ooooo00_ooooo1_l00004
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oiRHV?l@413ogMgM07_ooooo001noooo
o`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@4003ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01Oooool2ogMgM`Oooooo00?o<S8booooooooool00_ooool00onHV9So8B4Qonk^
kP0<ooooo`04oa0@4?oMgMgoooooo`0000Gooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0=ooooo`03ohN7QomEEEGooooo07[ooooo001nooooo`04oeEEEOnYZJWoooooo`0000;ooooo
00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00Gooooo00?ok^k^oa0@4?o^
k^h01_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oo
oooo00001Oooool00ol0003oooooooooo`0:ooooo`Ko00001?ooool00ol0003oooooooooo`0:oooo
o`05olc<c?lQ8B7o0000oeEEEOl00000Noooool007kooooo00?ogMgMob4Q8Oo^k^h00oooool00ol0
003oooooooooo`02o`0000gooooo00?o0000ooooooooool01_ooool00omEEEGoV9RHooooo`05oooo
o`03o`000?o^k^kooooo00Cooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgo410@ooooool00004
ooooo`03onk^k_l0003ooooo01Gooooo00?o0000ooooooooool02_ooool01OlQ8B7oQhN7oooooonH
V9So000007_ooooo001oooooo`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool03Oooool0
0ol@413o0000o`000003o`0000Gooooo00?ogMgMoa0@4?ooool01Oooool00omEEEGoMgMgooooo`05
ooooo`03o`000?oooooooooo00Sooooo1ol00002ooooo`03ogMgMomEEEGooooo01Gooooo00?o0000
ooooooooool02_ooool01Ol0003ooooooooooooooooo000007_ooooo002Fooooo`03o`000?oooooo
oooo00Oooooo00?oEEEEoiRHV?ooool01?ooool02OoMgMgo410@onk^k_oooooo0000okZj^_oooooo
V9RHoa0@400Booooo`03onk^k_l@413ogMgM01Kooooo00?o0000ooooooooool02_ooool01OlQ8B7o
V9RHoooooomgMgOoEEEE07_ooooo002Fooooo`03o`000?oooooooooo00Oooooo00?o^[ZjodA4A?oo
ool01Oooool02?mgMgOoIVIVoooooonHV9So410@o`000?lQ8B7oc<c<4_ooool00omVIVKoMgMgoooo
o`0Dooooo`03oeEEEOmVIVKo000000cooooo00Goc<c<oa0@4?l0003o<S8bonk^kP1kooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.95) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36755 L
.10458 .42582 L
.14415 .47106 L
.16408 .4894 L
.18221 .50317 L
.20178 .5147 L
.21254 .5195 L
.22272 .52301 L
.23241 .52541 L
.2373 .52627 L
.24012 .52666 L
.24269 .52695 L
.24504 .52716 L
.24728 .52731 L
.2485 .52737 L
.24964 .52741 L
.25088 .52744 L
.25158 .52745 L
.25221 .52746 L
.25336 .52746 L
.25442 .52745 L
.25558 .52743 L
.2568 .52739 L
.25787 .52734 L
.25887 .52729 L
.26113 .52713 L
.26373 .52689 L
.26614 .52661 L
.27158 .52578 L
.27638 .52481 L
.28148 .52354 L
.2903 .52079 L
.30004 .51693 L
.31939 .50682 L
.34024 .4925 L
.38138 .45513 L
.42101 .41025 L
.45912 .36215 L
.49968 .30946 L
.53872 .2609 L
.58022 .21516 L
.6202 .17975 L
.63852 .16699 L
.65867 .15575 L
.67854 .14766 L
.68941 .14452 L
.69959 .14242 L
.70457 .14168 L
.70719 .14137 L
Mistroke
.70999 .14109 L
.71268 .14088 L
.71512 .14074 L
.7163 .14069 L
.71757 .14065 L
.71877 .14062 L
.71987 .1406 L
.72095 .14059 L
.7221 .14059 L
.72319 .1406 L
.72418 .14061 L
.72534 .14064 L
.7266 .14068 L
.72889 .14079 L
.73129 .14095 L
.73384 .14116 L
.73841 .14165 L
.74331 .14235 L
.74781 .14315 L
.75792 .14545 L
.77621 .15136 L
.79517 .15971 L
.81589 .17117 L
.8565 .19953 L
.8956 .23239 L
.93715 .27105 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36516 L
.10458 .42504 L
.14415 .47198 L
.16408 .49075 L
.18221 .50461 L
.20178 .51599 L
.21254 .52062 L
.21738 .52233 L
.22272 .52394 L
.22739 .52512 L
.23241 .52614 L
.23518 .5266 L
.23772 .52695 L
.2403 .52725 L
.24269 .52746 L
.24488 .52761 L
.2461 .52767 L
.24721 .52771 L
.24843 .52775 L
.24975 .52777 L
.251 .52777 L
.25214 .52776 L
.25322 .52774 L
.25423 .52771 L
.25533 .52767 L
.25651 .52761 L
.25893 .52744 L
.26113 .52725 L
.26594 .52665 L
.27104 .52578 L
.28022 .52362 L
.29008 .52043 L
.30098 .51591 L
.32032 .50542 L
.34118 .4908 L
.38232 .45325 L
.42194 .40863 L
.46005 .36095 L
.50061 .30864 L
.53966 .26031 L
.58116 .21482 L
.60196 .19533 L
.62114 .17974 L
.64101 .16621 L
.6596 .15612 L
.67837 .14855 L
.68832 .14562 L
.69386 .14431 L
.69901 .1433 L
Mistroke
.70432 .14247 L
.70914 .1419 L
.71189 .14165 L
.71449 .14147 L
.71582 .14139 L
.71722 .14133 L
.71796 .1413 L
.71877 .14127 L
.71944 .14126 L
.72018 .14124 L
.72088 .14123 L
.72153 .14122 L
.72281 .14121 L
.72397 .14122 L
.72521 .14124 L
.72653 .14126 L
.72776 .1413 L
.72912 .14136 L
.73058 .14143 L
.73305 .14159 L
.73565 .14181 L
.74028 .14231 L
.7453 .14302 L
.74985 .14381 L
.76006 .1461 L
.77844 .15191 L
.79767 .16017 L
.81848 .17141 L
.85945 .19959 L
.8989 .23291 L
.93684 .2692 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000<oooooo0_l0000>ool006Gooooo000Q
ooooo`03o`000?oooooooooo0<cooooo0ol0000@ooooo`?oo`000ol0001Oooooo`008Oooool00ol0
003oooooooooo`39ooooo`?o00006Oooool3o`0005cooooo000Qooooo`03o`000?oooooooooo0<Ko
oooo0_oo00000ol0003oooooooooo`0Mooooo`;o0000F_ooool0027ooooo00?o0000ooooooooool0
aOooool00ooo003o0000ooooo`0Rooooo`03o`000?oo003oo`0005Oooooo000Qooooo`03o`000?oo
oooooooo0<?ooooo0_oo000Wooooo`03o`000?oo003oo`0005Gooooo000Qooooo`03o`000?oooooo
oooo0<3ooooo00?o0000ool00?oo0000:oooool00ol0003oo`00ool0001Cooooo`008Oooool00ol0
003oooooooooo`2nooooo`03o`000?oo003oo`0002oooooo00Co0000ool00?oo003oo`00D?ooool0
027ooooo0ol0002looooo`03o`000?oo003oo`0003Cooooo00?o0000ool00?oo0000C_ooool0027o
oooo00?o0000ooooooooool0^oooool00ol0003oo`00ooooo`0gooooo`03o`000?oo003ooooo04co
oooo000Qooooo`03o`000?oooooooooo0;[ooooo00?o0000ool00?ooool0>_ooool00ooo003ooooo
ooooo`1:ooooo`008Oooool00ol0003oooooooooo`2iooooo`03o`000?oo003ooooo03cooooo00?o
o`00ooooooooool0BOooool0027ooooo00?o0000ooooooooool0]oooool2o`00043ooooo00?oo`00
o`000?ooool0B?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0]_ooool00ol0003ooooooooo
o`12ooooo`03o`000?oooooooooo04Kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2eooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool0AOooool000Go00000_ooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o0000ooooooooool00_ooool3o`000;Cooooo00?o0000ooooooooool0A_oo
ool2o`0004Gooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8boooo
o`03ooooo`03o`000?oooooooooo0;?ooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`12ooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo0;7ooooo0_l0001=ooooo`03o`000?oooooooooo047ooooo
0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo0;3ooooo0_oo001?ooooo`03o`000?oo003oo`00043ooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0:oooooo
00?oo`00ooooooooool0DOooool00ol0003oo`00ooooo`0nooooo`001oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0:kooooo00?oo`00ooooooooool0
Doooool00ol0003oo`00ooooo`0mooooo`008Oooool00ol0003oooooooooo`2]ooooo`03ool00?oo
oooooooo05Gooooo00?o0000ool00?ooool0??ooool0027ooooo00?o0000ooooooooool0[?ooool0
0ooo003oooooooooo`1Hooooo`03ool00?oooooooooo03[ooooo000Qooooo`?o0000Zoooool00ooo
003oooooooooo`1Jooooo`;oo`00>_ooool0027ooooo00?o0000ooooooooool0Zoooool00ooo003o
ooooooooo`1Kooooo`03o`000?oo003ooooo03Sooooo000Qooooo`03o`000?oooooooooo0:[ooooo
00?oo`00ooooooooool0GOooool00ol0003oo`00ooooo`0gooooo`008Oooool00ol0003ooooooooo
o`2Yooooo`03ool00?oooooooooo063ooooo00?oo`00ooooooooool0=Oooool0027ooooo00?o0000
ooooooooool0Z?ooool00ooo003oooooooooo`1Rooooo`03ool00?oooooooooo03Cooooo000Qoooo
o`03o`000?oooooooooo0:Oooooo00?oo`00ooooooooool0I?ooool00ooo003oooooooooo`0coooo
o`008Oooool00ol0003oooooooooo`2Vooooo`03ool00?oooooooooo06Kooooo00?o0000oooooooo
ool0<_ooool0027ooooo0ol0002Uooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0
<Oooool0027ooooo00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`1Zooooo`03o`000?oo
oooooooo033ooooo000Qooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0K?ooool0
0ol0003oooooooooo`0_ooooo`008Oooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool0;_ooool0027ooooo00?o0000ooooooooool0XOooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo0:3ooooo
00?o0000ooooooooool0L_ooool00ol0003oo`00ooooo`0/ooooo`008Oooool00ol0003ooooooooo
o`2Oooooo`03o`000?oooooooooo07Cooooo00?oo`00ooooooooool0:oooool0027ooooo00?o0000
ooooooooool0W_ooool2ool007Oooooo00?oo`00ooooooooool0:_ooool0027ooooo0ol0002Noooo
o`03ool00?oooooooooo07Oooooo00?oo`00ooooooooool0:Oooool0027ooooo00?o0000oooooooo
ool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo00Kooooo00?oo`00ooooooooool0<_ooool4
o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0<_oo
ool00ooo003oooooooooo`08ooooo`Go00006oooool0027ooooo00?o0000ooooooooool0?Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03kooooo00?o
0000ooooooooool01oooool00ooo003oooooooooo`0eooooo`03o`000?oooooooooo00Cooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo03;ooooo0_oo0008ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
6oooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo03Kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0booooo`03o`000?oo003ooooo00Oooooo
00?oV9RHob4Q8Oo^k^h07?ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oo003ooooo03Oooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0eooooo`03ool0
0?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Ooo
ool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03
o`000?oooooooooo00Gooooo00?oo`00ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`0=oooool00ooo003oooooooooo`06ooooo`03ogMgMomVIVKooooo
01[ooooo000Qooooo`03o`000?oooooooooo03gooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`0hoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>_ooool00ooo003oooooooooo`06oooo
o`03o`000?oooooooooo01Wooooo000Qooooo`?o0000?Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo
03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0kooooo`09ool00?oooooooooo
ooooool0003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`03o`000?oooooooooo03gooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000?_ooool00omEEEGoIVIVo`000004ooooo`03o`00
0?oo003ooooo03Sooooo00?oEEEEofIVI_l000003Oooool4o`0003_ooooo00Soo`00oooooooooooo
V9RHoa0@4?l0003o8B4Qolc<c1_ooooo000Qooooo`03o`000?oooooooooo09Kooooo00?o0000ool0
0?ooool0ROooool00ol0003oooooooooo`0Oooooo`008Oooool00ol0003oooooooooo`2Fooooo`03
ool00?oooooooooo08[ooooo00?o0000ooooooooool07_ooool0027ooooo00?o0000ooooooooool0
UOooool00ooo003oooooooooo`2<ooooo`03o`000?oooooooooo01gooooo000Qooooo`03o`000?oo
oooooooo09Cooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`0Booooo`;o00000_oo
ool2o`0000Cooooo000Qooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool0T?ooool0
0ol0003oooooooooo`0Aooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool001[oooooool0
000jo`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?o0000ool00?ooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^
1Oooool0027ooooo00?o0000ool00?ooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool2o`0000kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Ooo
ool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003oooooool0002@ooooo`03o`000?oo
oooooooo0:Oooooo0_l00002ooooo`;o00001?ooool0027ooooo00Co0000ooooool0003oo`00S_oo
ool00ol0003oooooooooo`2booooo`008Oooool01?l0003ooooooooooooo002=ooooo`03ool00?l0
003ooooo0;?ooooo000Qooooo`05o`000?ooooooooooo`000?oo0000S?ooool00ooo003ooooooooo
o`2cooooo`008Oooool01_l0003ooooooooooooooooo0000ool008[ooooo00?oo`00ooooooooool0
]?ooool0027ooooo0ol00002ooooo`03o`000?oo003ooooo08Oooooo00?oo`00ooooooooool0]Ooo
ool0027ooooo00?o0000ooooooooool00_ooool00ol0003oo`00ooooo`26ooooo`03o`000?oo003o
oooo0;Kooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?ooool0QOooool00ooo
003oooooooooo`2fooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oo003ooooo08?o
oooo00?oo`00ooooooooool0]oooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oo`00
ooooo`22ooooo`03o`000?oo003ooooo0;Sooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o
0000ool00?ooool0P?ooool00ol0003oo`00ooooo`2iooooo`008Oooool00ol0003oooooooooo`06
ooooo`03o`000?oo003ooooo07oooooo00?oo`00ooooooooool0^Oooool0027ooooo0ol00006oooo
o`03o`000?oooooooooo07kooooo00?o0000ool00?ooool0^_ooool0027ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1looooo`03o`000?oo003ooooo0;_ooooo000Qooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0Noooool00ol0003oo`00ooooo`2looooo`008Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07[ooooo00?oo`00ooooooooool0_?oo
ool0027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooo
oooo0;gooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Moooool00ol0
003oooooooooo`2nooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07Go
oooo00?o0000ooooooooool0_oooool0027ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo0<3ooooo000Qooooo`?o00003?ooool00ol0003oo`00oooo
o`1booooo`03o`000?oooooooooo0<3ooooo000Qooooo`03o`000?oooooooooo00gooooo00?oo`00
ooooooooool0L?ooool00ol0003oooooooooo`31ooooo`008Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oo003ooooo06oooooo00?o0000ooooooooool0`_ooool0027ooooo00?o0000oooooooo
ool03_ooool00ol0003oo`00ooooo`1]ooooo`03ool00?oooooooooo0<?ooooo000Qooooo`03o`00
0?oooooooooo00oooooo00?oo`00ooooooooool0Joooool00ol0003oo`00ooooo`34ooooo`008Ooo
ool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo06[ooooo00?oo`00ooooooooool0a?oo
ool0027ooooo00?o0000ooooooooool04?ooool00ol0003oo`00ooooo`1Yooooo`03ool00?oooooo
oooo0<Gooooo000Qooooo`?o00004Oooool00ol0003oo`00ooooo`1Wooooo`03ool00?oooooooooo
0<Kooooo000Qooooo`03o`000?oooooooooo01;ooooo00?oo`00ooooooooool0IOooool00ooo003o
ooooooooo`37ooooo`008Oooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo06?ooooo
00?o0000ool00?ooool0b?ooool0027ooooo00?o0000ooooooooool05?ooool00ooo003ooooooooo
o`1Rooooo`03ool00?oooooooooo0<Sooooo000Qooooo`03o`000?oooooooooo01Cooooo00?oo`00
ooooooooool0HOooool00ooo003oooooooooo`39ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003ooooooooo
o`0Eooooo`03ool00?oooooooooo05oooooo00?oo`00ooooooooool0b_ooool000Oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oo
oooooooo01Kooooo00?oo`00ooooooooool0GOooool00ooo003oooooooooo`3;ooooo`001oooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`0001Oooooo00?o
0000ooooooooool0Foooool00ooo003oooooooooo`3<ooooo`001oooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo05[ooooo00?oo`00ooooooooool0cOooool000Oooooo00Go0000ooooooooooooooooo`00
000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo05Sooooo00?o0000ooooooooool0c_ooool000Oooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`1Gooooo`03o`000?oooooooooo0<kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
EOooool00ol0003oooooooooo`3?ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l00005ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Doooool00ol0003ooooo
ooooo`3@ooooo`008Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo057ooooo00?o
0000ooooooooool0dOooool0027ooooo00?o0000ooooooooool07Oooool00ooo003oooooooooo`1?
ooooo`03o`000?oooooooooo0=;ooooo000Qooooo`?o00007Oooool00ooo003oooooooooo`1>oooo
o`03o`000?oooooooooo0=?ooooo000Qooooo`03o`000?oooooooooo01kooooo00?oo`00oooooooo
ool0Boooool00ooo003o0000ooooo`3Eooooo`008Oooool00ol0003oooooooooo`0Oooooo`03ool0
0?oooooooooo04Wooooo00?oo`00ooooooooool0e_ooool0027ooooo00?o0000ooooooooool08?oo
ool00ooo003oooooooooo`17ooooo`03ool00?oooooooooo0=Oooooo000Qooooo`03o`000?oooooo
oooo027ooooo00?oo`00ooooooooool0AOooool00ooo003oooooooooo`3Hooooo`008Oooool00ol0
003oooooooooo`0Rooooo`03ool00?oooooooooo04?ooooo00?oo`00ooooooooool0fOooool0027o
oooo00?o0000ooooooooool08oooool00ooo003oooooooooo`11ooooo`03ool00?oooooooooo0=[o
oooo000Qooooo`?o00008oooool00ooo003o0000ooooo`10ooooo`03ool00?oooooooooo0=_ooooo
000Qooooo`03o`000?oooooooooo02Cooooo00?oo`00o`000?ooool0?_ooool00ooo003ooooooooo
o`3Looooo`008Oooool00ol0003oooooooooo`0Uooooo`03ool00?l0003ooooo03cooooo00?oo`00
ooooooooool0gOooool0027ooooo00?o0000ooooooooool09_ooool00ooo003o0000ooooo`0joooo
o`03ool00?oooooooooo0=kooooo000Qooooo`03o`000?oooooooooo02Oooooo00?oo`00o`000?oo
ool0>?ooool00ooo003oooooooooo`3Oooooo`008Oooool00ol0003oooooooooo`0Yooooo`;o0000
=_ooool00ooo003oooooooooo`3Pooooo`008Oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo037ooooo0_l0003Sooooo`008Oooool00ol0003oooooooooo`0/ooooo`;o0000<?ooool0
0ol0003oooooooooo`3Sooooo`008Oooool3o`0002kooooo00?o0000ooooooooool0:oooool2o`00
0>Kooooo000Qooooo`03o`000?oooooooooo02oooooo0_l0000Zooooo`03o`000?oooooooooo0>Ko
oooo000Qooooo`03o`000?oooooooooo033ooooo0_oo000Wooooo`;o0000jOooool0027ooooo00?o
0000ooooooooool0<_ooool2ool002?ooooo0_oo003[ooooo`008Oooool00ol0003oooooooooo`0d
ooooo`03ool00?oooooooooo01kooooo0_oo003]ooooo`008Oooool00ol0003oooooooooo`0eoooo
o`?oo`006oooool2ool00>oooooo000Qooooo`03o`000?oooooooooo03Sooooo0_oo00000ol0003o
ooooooooo`0Booooo`Coo`00lOooool0027ooooo0ol0000jooooo`?oo`000_l0000=ooooo`?oo`00
00?o0000ooooooooool0l_ooool0027ooooo00?o0000ooooooooool0?Oooool2ool000Co00001Ooo
ool01Ol0003oo`00ool00?oo003o00000?Oooooo000Qooooo`03o`000?oooooooooo04?ooooo1Ol0
003looooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?oo
ooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo
000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool0
0ol0003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo002Tooooo`03ogMgMomVIVKooooo01Oooooo00?oIVIVogMgMoooool0
Yoooool008?ooooo0ol0000Dooooo`03ob4Q8OoMgMgooooo00Kooooo00?ogMgMoa0@4?o^k^h06?oo
ool00oo^k^ko410@omgMg@2Wooooo`00Noooool01on7QhOo0000oeEEEOmVIVKo0000oc8b<_o^k^h0
0_ooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool00onHV9So
EEEEooooo`06ooooo`03oeEEEOnHV9Sooooo00;ooooo1Ol00009ooooo`03oeEEEOnYZJWooooo00;o
oooo00Ko^[ZjodA4A?ooooooooooohN7QomVIVHEooooo`Co000000?o410@ooooooooool00_ooool2
ob4Q8@Cooooo00Co410@o`000?m4A4Coc<c<1Oooool01Om4A4Co0000o`000?lb<S;ogMgM07Gooooo
001kooooo`07oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP02ooooo`03o`000?oooooooooo00_o
oooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oMgMgooooo00Gooooo00?o0000oooo
ooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@
4?nj^[X2ooooo`03onk^k_l0003ooooo00_ooooo1_l00005ooooo`03o`000?oooooooooo00Cooooo
0_lQ8B46ooooo`03oiRHV?l@413ogMgM00Oooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00Oo
0000oooooooMgMgo<S8booooooo^k^ko410@00;ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`06ooooo`;oMgMg1_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00co
oooo00Co410@omgMgOoooooo00001?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00gooooo00?oQhN7oeEEEOooool01oooool00ol0003oooooooooo`1cooooo`00Noooool01?mEEEGo
ZJVYooooool00002ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool01_ooool0
0oo^k^ko410@onk^kP05ooooo`03oc8b<_oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h02oooool0
1?n7QhOoIVIVooooool00004ooooo`03o`000?oooooooooo00[ooooo1_l00005ooooo`03o`000?oo
oooooooo00[ooooo00Goc<c<ob4Q8Ol0003oEEEEo`000007ooooo`03ogMgMolb<S;ooooo07Cooooo
001kooooo`03omgMgOlQ8B7ok^k^00?ooooo00Co0000ooooool0003o00003Oooool00ol0003ooooo
ooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00?o0000onk^k_ooool01Oooool00omgMgOoIVIV
ooooo`0:ooooo`04omgMgOl@413oooooo`0000?ooooo00?ok^k^o`000?ooool05_ooool00ol0003o
ooooooooo`0:ooooo`05ob4Q8On7QhOooooooiRHV?l000001?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<07Gooooo001looooo`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool03?ooool00ol@
413o0000o`000003o`0000Kooooo00?ogMgMoa0@4?ooool01?ooool00omEEEGoMgMgooooo`06oooo
o`03o`000?oooooooooo00Sooooo1ol000000oooooooMgMgoeEEE@0Gooooo`03o`000?oooooooooo
00[ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo07Oooooo002Boooo
o`03o`000?oooooooooo00Sooooo00?oEEEEoiRHV?ooool00oooool00ooMgMgo410@onk^kP02oooo
o`05o`000?nj^[[ooooooiRHV?l@41004Oooool00oo^k^ko410@omgMg@0Gooooo`03o`000?oooooo
oooo00[ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@04ooooo`03o`000?oooooooooo07Oooooo002B
ooooo`03o`000?oooooooooo00Sooooo00?o^[ZjodA4A?ooool01?ooool02OmgMgOoIVIVoooooooo
ooooV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`03ofIVI_mgMgOooooo01Gooooo00?oEEEEofIVI_l0
00003?ooool01Oo<c<co410@o`000?lb<S;ok^k^00Cooooo1?l0001fooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -43.625 0 ]
[.5 .63053 43.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -104.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
146.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36837 L
.10458 .42854 L
.14415 .47688 L
.18221 .51262 L
.20178 .52611 L
.21267 .53206 L
.22272 .53653 L
.23293 .54006 L
.23832 .5415 L
.24402 .54271 L
.24641 .54311 L
.24897 .54348 L
.25119 .54375 L
.25361 .54399 L
.25507 .5441 L
.25643 .54419 L
.25773 .54425 L
.2584 .54428 L
.25912 .5443 L
.25983 .54432 L
.26048 .54433 L
.26176 .54434 L
.26293 .54433 L
.26416 .54431 L
.26538 .54428 L
.26607 .54425 L
.26671 .54422 L
.26912 .54407 L
.27131 .54388 L
.27364 .54363 L
.27847 .54293 L
.2838 .54187 L
.29326 .53929 L
.30213 .53605 L
.32232 .52577 L
.34082 .51293 L
.38045 .47548 L
.41855 .42874 L
.45912 .37074 L
.49816 .31056 L
.53966 .24641 L
.57964 .1889 L
.61811 .14137 L
.63759 .12121 L
.65902 .1026 L
.67938 .08871 L
.69843 .07927 L
.70884 .07561 L
.71396 .07421 L
Mistroke
.71872 .07315 L
.72301 .07239 L
.72758 .07179 L
.7302 .07154 L
.73148 .07145 L
.73266 .07137 L
.73371 .07132 L
.73487 .07128 L
.73603 .07124 L
.73725 .07123 L
.73856 .07122 L
.73977 .07124 L
.7404 .07125 L
.7411 .07127 L
.74251 .07132 L
.74375 .07139 L
.74508 .07147 L
.74748 .07168 L
.74985 .07193 L
.75235 .07227 L
.7568 .07302 L
.76198 .07416 L
.7668 .07546 L
.77773 .07929 L
.78828 .08411 L
.79823 .08967 L
.81683 .10259 L
.85534 .13899 L
.89632 .18965 L
.93577 .24656 L
.97371 .30514 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36699 L
.10458 .42815 L
.14415 .47767 L
.18221 .51376 L
.20178 .52707 L
.21274 .53286 L
.22272 .53707 L
.22755 .53875 L
.23267 .54027 L
.2371 .54136 L
.24186 .54231 L
.24453 .54275 L
.24697 .54308 L
.24945 .54335 L
.25175 .54356 L
.25315 .54365 L
.25442 .54372 L
.25583 .54378 L
.25661 .5438 L
.25734 .54382 L
.25798 .54383 L
.25867 .54383 L
.25989 .54383 L
.2612 .54381 L
.26195 .5438 L
.26265 .54377 L
.26391 .54372 L
.26525 .54365 L
.26765 .54347 L
.27024 .54322 L
.2731 .54286 L
.2782 .54203 L
.283 .541 L
.29193 .53851 L
.30156 .53496 L
.3216 .5248 L
.3427 .51023 L
.3808 .47473 L
.42136 .42581 L
.46041 .37054 L
.50191 .30663 L
.54189 .2442 L
.58036 .1876 L
.62127 .13576 L
.64163 .11457 L
.66068 .09807 L
.67894 .08558 L
.68912 .08011 L
.69856 .07603 L
Mistroke
.7087 .07273 L
.71404 .07144 L
.71678 .0709 L
.71974 .07042 L
.72257 .07004 L
.72517 .06977 L
.72766 .06959 L
.72892 .06952 L
.72962 .06949 L
.73029 .06946 L
.73154 .06943 L
.73268 .06942 L
.7339 .06942 L
.73459 .06943 L
.73523 .06944 L
.7363 .06947 L
.73747 .06952 L
.73869 .06958 L
.73984 .06966 L
.74228 .06987 L
.74455 .07013 L
.7497 .07091 L
.75471 .07195 L
.76006 .07336 L
.76977 .07668 L
.77858 .08053 L
.7978 .0916 L
.81862 .10742 L
.85959 .14855 L
.89904 .19783 L
.93698 .25109 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000=Gooooo3_oo001Qooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=;ooooo1Ol0000;ooooo`05o`00
0?oo003oo`00ool00?l00000GOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3?ooooo`;oo`0000?o0000ooooooooool04oooool2o`0005_ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0c?ooool3ool000;o00006?ooool3o`0005Sooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0boooool01?oo003oooooo`000?l0
000Mooooo`;o0000E_ooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`39
ooooo`;oo`000_l0000Qooooo`03o`000?oooooooooo05?ooooo000Qooooo`03o`000?oooooooooo
0<Oooooo0_oo0002o`0002?ooooo0ooo001Cooooo`008Oooool00ol0003oooooooooo`35ooooo`;o
o`0000?oooooo`000?ooool09oooool00ooo003oooooooooo`1@ooooo`008Oooool3o`000<Cooooo
00Coo`00ooooool0003o0000:_ooool2ool0053ooooo000Qooooo`03o`000?oooooooooo0<Cooooo
00?oo`00o`000?ooool0;Oooool00ooo003oooooooooo`1=ooooo`008Oooool00ol0003ooooooooo
o`33ooooo`03ool00?l0003ooooo02oooooo00?oo`00o`000?ooool0C?ooool0027ooooo00?o0000
ooooooooool0`_ooool00ol0003oooooooooo`0aooooo`03ool00?l0003ooooo04_ooooo000Qoooo
o`03o`000?oooooooooo0<7ooooo00?o0000ooooooooool0<_ooool00ooo003oooooo`00001;oooo
o`008Oooool00ol0003oooooooooo`30ooooo`03o`000?oooooooooo03Cooooo00?oo`00ooooool0
0000B_ooool0027ooooo00?o0000ooooooooool0_oooool00ol0003oooooooooo`0fooooo`03ool0
0?oooooo000004Wooooo000Qooooo`?o0000__ooool00ol0003oooooooooo`0hooooo`03ool00?oo
oooo000004Sooooo000Qooooo`03o`000?oooooooooo0;gooooo00?o0000ooooooooool0>_ooool0
0ooo003oooooo`000017ooooo`008Oooool00ol0003oooooooooo`2kooooo`03ool00?l0003ooooo
03oooooo00?o0000ooooooooool0A?ooool0027ooooo00?o0000ooooooooool0^_ooool00ooo003o
0000ooooo`11ooooo`03o`000?oooooooooo04?ooooo000Qooooo`03o`000?oooooooooo0;Wooooo
00?oo`00o`000?ooool0@oooool00ol0003oooooooooo`12ooooo`008Oooool00ol0003ooooooooo
o`2hooooo`03ool00?l0003ooooo04Gooooo00?o0000ooooooooool0@Oooool0027ooooo00?o0000
ooooooooool0^?ooool00ooo003oooooooooo`16ooooo`03o`000?oooooooooo043ooooo000Qoooo
o`?o0000]oooool00ooo003oooooooooo`17ooooo`03o`000?oooooooooo043ooooo000Qooooo`03
o`000?oooooooooo0;Kooooo00?oo`00o`000?ooool0BOooool00ol0003oooooooooo`0oooooo`00
8Oooool00ol0003oooooooooo`2eooooo`03ool00?l0003ooooo04[ooooo00?oo`00o`000?ooool0
?oooool0027ooooo00?o0000ooooooooool0]?ooool00ooo003o0000ooooo`1;ooooo`03ool00?oo
oooo000003oooooo000Qooooo`03o`000?oooooooooo0;Cooooo00?oo`00ooooooooool0C?ooool0
0ooo003oooooo`00000nooooo`008Oooool00ol0003oooooooooo`2cooooo`03ool00?oooooooooo
04kooooo00?oo`00o`000?ooool0?Oooool0027ooooo00?o0000ooooooooool0/_ooool00ooo003o
0000ooooo`1@ooooo`03ool00?l0003ooooo03cooooo000Qooooo`03o`000?oooooooooo0;7ooooo
00?oo`00o`000?ooool0D_ooool00ooo003o0000ooooo`0kooooo`008Oooool3o`000;7ooooo00?o
0000ooooooooool0Doooool00ooo003o0000ooooo`0jooooo`008Oooool00ol0003oooooooooo`2`
ooooo`03o`000?oooooooooo05Cooooo00?oo`00ooooool00000>_ooool0027ooooo00?o0000oooo
ooooool0[oooool00ol0003oooooooooo`1Fooooo`03ool00?oooooo000003Wooooo000Qooooo`03
o`000?oooooooooo0:oooooo00?o0000ooooooooool0Eoooool00ooo003o0000ooooo`0hooooo`00
8Oooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo05Wooooo00?oo`00o`000?ooool0
=oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0[Oooool00ol0003oooooooooo`1Kooooo`03
ool00?l0003ooooo03Kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo05go
oooo00?oo`00o`000?ooool0=Oooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00_ooool3o`000:_ooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`0cooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`2Zooooo`03ool00?l0003ooooo067ooooo00?o0000oooooooo
ool0<oooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01?ooool00ol0003oooooooooo`2Zooooo`03ool00?oooooooooo06;ooooo00?o0000oooo
ooooool0<_ooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0ZOooool00ooo003oooooooooo`1Tooooo`03o`000?oooooooooo
037ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0:Sooooo00?oo`00ooooooooool0IOooool00ol0003oooooooooo`0aoooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo
0:Sooooo00?oo`00ooooooooool0I_ooool00ol0003oooooooooo`0`ooooo`008Oooool00ol0003o
ooooooooo`2Wooooo`03ool00?oooooooooo06Sooooo00?o0000ooooooooool0;oooool0027ooooo
00?o0000ooooooooool0Y_ooool00ooo003oooooooooo`1Yooooo`03o`000?oooooooooo02oooooo
000Qooooo`?o0000YOooool00ooo003o0000ooooo`1Zooooo`03ool00?l0003ooooo02oooooo000Q
ooooo`03o`000?oooooooooo0:Gooooo00?oo`00ooooooooool0J_ooool00ooo003oooooo`00000_
ooooo`008Oooool00ol0003oooooooooo`2Tooooo`03ool00?oooooooooo06cooooo00?oo`00o`00
0?ooool0;_ooool0027ooooo00?o0000ooooooooool0Xoooool00ooo003oooooooooo`1^ooooo`03
ool00?l0003ooooo02gooooo000Qooooo`03o`000?oooooooooo0:?ooooo00?oo`00ooooooooool0
Koooool00ooo003o0000ooooo`0/ooooo`008Oooool00ol0003oooooooooo`2Rooooo`03ool00?oo
oooooooo077ooooo00?oo`00ooooooooool0:oooool0027ooooo00?o0000ooooooooool0XOooool0
0ooo003oooooooooo`1cooooo`03ool00?oooooooooo02[ooooo000Qooooo`?o0000XOooool00ol0
003oooooooooo`1cooooo`03ool00?l0003ooooo02[ooooo000Qooooo`03o`000?oooooooooo0:3o
oooo00?o0000ooooooooool0MOooool00ooo003oooooooooo`0Yooooo`008Oooool00ol0003ooooo
ooooo`2Oooooo`03o`000?oooooooooo07Oooooo00?oo`00ooooooooool0:?ooool0027ooooo00?o
0000ooooooooool0W_ooool00ol0003oooooooooo`1iooooo`03ool00?oooooooooo02Oooooo000Q
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0NOooool00ol0003oo`00ooooo`0W
ooooo`008Oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo07_ooooo00?oo`00oooo
ooooool09_ooool0027ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`1looooo`03
ool00?l0003ooooo02Kooooo000Qooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool0
OOooool00ol0003oooooooooo`0Uooooo`008Oooool3o`0009_ooooo00?oo`00ooooooooool0Oooo
ool00ol0003oooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`0mooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0mooooo`Co0000
00?o410@ooooooooool01?ooool00ooo003oooooooooo`0dooooo`Co000000?o410@ooooooooool0
0_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0gooooo`03o`000?oooooooooo00?o
oooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`05ooooo`03
ool00?oooooooooo03Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool0=_ooool00ol0003oooooooooo`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0027o
oooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo03Sooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00?ooooo00?oV9RHob4Q
8Oo^k^h07?ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo
03Sooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0hooooo`03o`000?oooooooooo
00?ooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`000?oooooo
oooo00?ooooo00?oo`00ooooooooool0>Oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`0>Oooool00ol0003oooooooooo`04ooooo`03ogMgMomVIVKooooo01[ooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo047ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0iooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01Wooooo000Qooooo`?o0000?Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
0000ooooooooool0@Oooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo03[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0mooooo`07ool00?oooooo0000okZj^_oooooo
V9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l000000oooool00ooo003oooooooooo`0iooooo`03
oeEEEOmVIVKo000000gooooo1?l0000looooo`07ool00?ooooooV9RHoa0@4?l0003o8B4Qolc<c00K
ooooo`008Oooool00ol0003oooooooooo`2Fooooo`03ool00?oooooooooo08[ooooo00?oo`00oooo
ooooool07_ooool0027ooooo00?o0000ooooooooool0UOooool00ooo003oooooooooo`2<ooooo`03
ool00?oooooooooo01gooooo000Qooooo`03o`000?oooooooooo09Gooooo00?oo`00ooooooooool0
S?ooool00ol0003oo`00ooooo`0Mooooo`008Oooool00ol0003oooooooooo`2Dooooo`03ool00?oo
oooooooo08kooooo00?oo`00ooooooooool04_ooool2o`0000;ooooo0_l00004ooooo`008Oooool0
0ol0003oooooooooo`2Cooooo`03ool00?oooooooooo093ooooo00?oo`00ooooooooool04Oooool0
1_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooooooo0000<_l000000ooo003o0000o`00
0005o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^
1Oooool0027ooooo0_l0000=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Ooo
ool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003oooooo`00002Aooooo`03o`000?oo
oooooooo0:Kooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooool00000T?ooool0
0ol0003oooooooooo`2aooooo`008Oooool01?l0003ooooooooooooo002?ooooo`03o`000?oooooo
oooo0;7ooooo000Qooooo`04o`000?ooooooooooool008kooooo00?o0000ooooooooool0/_ooool0
027ooooo00Go0000ooooooooooooooooool0002<ooooo`03o`000?oooooooooo0;?ooooo000Qoooo
o`?o00000_ooool00ooo003oooooooooo`28ooooo`03ool00?l0003ooooo0;Cooooo000Qooooo`03
o`000?oooooooooo00;ooooo00?oo`00ooooooooool0R?ooool00ooo003oooooooooo`2dooooo`00
8Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo08Kooooo00?oo`00ooooooooool0
]Oooool0027ooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`24ooooo`03o`000?oo
003ooooo0;Kooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ool00?ooool0Q?ooool0
0ooo003oooooooooo`2fooooo`008Oooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo
08;ooooo00?oo`00ooooooooool0]oooool0027ooooo00?o0000ooooooooool01_ooool00ooo003o
ooooooooo`20ooooo`03o`000?oo003ooooo0;Sooooo000Qooooo`?o00001_ooool00ol0003oo`00
ooooo`20ooooo`03ool00?oooooooooo0;Sooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o
o`00ooooooooool0O_ooool00ol0003oo`00ooooo`2iooooo`008Oooool00ol0003oooooooooo`07
ooooo`03o`000?oo003ooooo07gooooo00?o0000ool00?ooool0^_ooool0027ooooo00?o0000oooo
ooooool02?ooool00ol0003oo`00ooooo`1looooo`03ool00?oooooooooo0;[ooooo000Qooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0N_ooool00ol0003oo`00ooooo`2kooooo`00
8Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo07Wooooo00?o0000ool00?ooool0
_?ooool0027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1hooooo`03ool00?oo
oooooooo0;cooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0M_ooool0
0ol0003oooooooooo`2mooooo`008Oooool3o`0000cooooo00?o0000ooooooooool0M?ooool00ol0
003oooooooooo`2nooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07Co
oooo00?o0000ooooooooool0__ooool0027ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo0;oooooo000Qooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`30ooooo`008Oooool00ol0003oooooooooo`0?
ooooo`03ool00?oooooooooo06oooooo00?o0000ooooooooool0`?ooool0027ooooo00?o0000oooo
ooooool03oooool00ooo003oooooooooo`1^ooooo`03o`000?oooooooooo0<7ooooo000Qooooo`03
o`000?oooooooooo013ooooo00?oo`00ooooooooool0K?ooool00ol0003oooooooooo`32ooooo`00
8Oooool3o`00017ooooo00?oo`00ooooooooool0J_ooool00ooo003o0000ooooo`33ooooo`008Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oo003ooooo06[ooooo00?oo`00ooooooooool0`ooo
ool0027ooooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`1Xooooo`03ool00?oooooo
oooo0<Cooooo000Qooooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool0Ioooool00ooo
003oooooooooo`34ooooo`008Oooool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo06Go
oooo00?oo`00ooooooooool0aOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool05?ooool00ooo
003oooooooooo`1Tooooo`03ool00?oooooooooo0<Kooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Eoooo
o`03ool00?oooooooooo06?ooooo00?oo`00ooooooooool0a_ooool000Oooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0000Fooooo`03ool00?oooooooooo
067ooooo00?oo`00ooooooooool0aoooool000Oooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`1Ooooo
o`03o`000?oo003ooooo0<Sooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`1O
ooooo`03ool00?oooooooooo0<Sooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo00?oo`00ooooooooool0GOooool0
0ooo003oooooooooo`39ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05_ooooo00?oo`00
ooooooooool0b_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05Wooooo00?oo`00ooooooooool0boooool0
027ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Gooooo`03ool00?oooooooooo
0<cooooo000Qooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0E_ooool00ol0003o
ooooooooo`3=ooooo`008Oooool3o`0001cooooo00?o0000ooooooooool0E?ooool00ol0003ooooo
ooooo`3>ooooo`008Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05?ooooo00?o
0000ooooooooool0c_ooool0027ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1A
ooooo`03o`000?oooooooooo0<oooooo000Qooooo`03o`000?oooooooooo01oooooo00?oo`00oooo
ooooool0Coooool00ol0003oooooooooo`3@ooooo`008Oooool00ol0003oooooooooo`0Oooooo`03
ool00?oooooooooo04kooooo00?o0000ooooooooool0dOooool0027ooooo00?o0000ooooooooool0
8?ooool00ooo003oooooooooo`1<ooooo`03o`000?oooooooooo0=;ooooo000Qooooo`03o`000?oo
oooooooo027ooooo00?oo`00ooooooooool0B_ooool00ooo003oooooooooo`3Cooooo`008Oooool3
o`0002;ooooo00?oo`00ooooooooool0Aoooool2ool00=Kooooo000Qooooo`03o`000?oooooooooo
02?ooooo00?oo`00o`000?ooool0AOooool00ooo003oooooooooo`3Fooooo`008Oooool00ol0003o
ooooooooo`0Tooooo`03ool00?l0003ooooo04?ooooo00?oo`00ooooooooool0eoooool0027ooooo
00?o0000ooooooooool09Oooool00ooo003o0000ooooo`11ooooo`03ool00?oooooooooo0=Sooooo
000Qooooo`03o`000?oooooooooo02Kooooo00?oo`00o`000?ooool0?oooool00ooo003ooooooooo
o`3Iooooo`008Oooool00ol0003oooooooooo`0Wooooo`03ool00?l0003ooooo03gooooo00?oo`00
ooooooooool0f_ooool0027ooooo00?o0000ooooooooool0:?ooool00ooo003o0000ooooo`0koooo
o`03ool00?oooooooooo0=_ooooo000Qooooo`03o`000?oooooooooo02Wooooo00?oo`00o`000?oo
ool0>Oooool00ooo003oooooooooo`3Looooo`008Oooool3o`0002[ooooo00?oo`00o`000?ooool0
=oooool00ooo003oooooooooo`3Mooooo`008Oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo03Cooooo00?oo`00ooooooooool0g_ooool0027ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0booooo`03ool00?oooooooooo0=oooooo000Qooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`3Pooooo`008Oooool00ol0003o
ooooooooo`0_ooooo`;o0000;_ooool2o`000>?ooooo000Qooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`3Sooooo`008Oooool00ol0003ooooooooo
o`0booooo`;o0000:Oooool00ol0003oooooooooo`3Tooooo`008Oooool3o`0003;ooooo0ooo000W
ooooo`03o`000?oooooooooo0>Gooooo000Qooooo`03o`000?oooooooooo03Gooooo0_oo000Roooo
o`;oo`0000?o0000ooooooooool0i_ooool0027ooooo00?o0000ooooooooool0=oooool00ooo003o
ooooooooo`0Mooooo`;oo`0000?o0000ooooooooool0j?ooool0027ooooo00?o0000ooooooooool0
>?ooool2ool00003o`000?oooooooooo01Sooooo0_oo003]ooooo`008Oooool00ol0003ooooooooo
o`0jooooo`;oo`000ol0000Dooooo`;oo`00koooool001Sooooo1?l000000ol@413oooooooooo`02
ooooo`03o`000?oooooooooo03cooooo0ooo00000ol0003oooooooooo`0>ooooo`?oo`00lOooool0
01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0oooooo`;oo`000ol00007oooo
o`Goo`0000?o0000ooooooooool0lOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`14ooooo`So0000n?ooool001[ooooo00?o0000ooooooooool01?ooool3o`000?oooooo
AOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l0
00001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool00omg
MgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo09oooooo002;ooooo`?o00004oooool00olQ8B7o
gMgMooooo`07ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Woooool008;ooooo
00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool02oooool01OnH
V9So0000o`000?m4A4Co^[Zj00;ooooo00?oV9RHoeEEEOooool01oooool01?mEEEGoV9RHoooooooo
ool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool00onj^[[oA4A4ooooo`02ooooo`03ohN7QomV
IVKooooo01;ooooo1Ol00005ooooo`;o8B4QP?ooool008;ooooo00Oo410@omgMgOmgMgOo8B4Qoooo
oon7QhOoIVIV00?ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?o
oooo00?o0000omgMgOooool01_ooool02Ol0003oooooooooooooooooV9RHob4Q8Oo^k^koooooodA4
A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj0oooool00oo^k^ko0000ooooo`0;ooooo`Ko
000000KooooooiRHV?lQ8B7ok^k^oooooom4A4@5ooooo`;o8B4QP?ooool008;ooooo00Oo0000oooo
oooMgMgo<S8booooooo^k^ko410@00?ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`05ooooo`;oMgMg1oooool00olb<S;oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co
410@omgMgOoooooo00001Oooool00ol0003oooooooooo`0Booooo`03oiRHV?lQ8B7ok^k^08Sooooo
0022ooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03
o`000?oooooooooo00Gooooo00?ok^k^oa0@4?o^k^h01_ooool00olb<S;oooooooooo`03ooooo`03
oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001Oooool00ol0003oooooooooo`0:oooo
o`Ko00000oooool00onHV9So8B4Qonk^kP27ooooo`00P_ooool00ooMgMgo8B4Qonk^kP03ooooo`03
o`000?oooooooooo00;o00003Oooool00ol0003oooooooooo`06ooooo`03oeEEEOnHV9Sooooo00Go
oooo00?o0000onk^k_ooool01?ooool00omgMgOoIVIVooooo`0:ooooo`04omgMgOl@413oooooo`00
00Cooooo00?ok^k^o`000?ooool05Oooool00omgMgOoIVIVooooo`26ooooo`00Poooool00onHV9So
MgMgooooo`02ooooo`03o`000?oooooooooo00gooooo00?o410@o`000?l000000ol00005ooooo`03
omgMgOl@413ooooo00Gooooo00?oEEEEogMgMoooool01Oooool00ol0003oooooooooo`08ooooo`Oo
00000_ooool00omgMgOoEEEEooooo`0Fooooo`03o`000?oooooooooo08Gooooo002Jooooo`03o`00
0?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool02OoMgMgo410@onk^k_oooooo0000okZj
^_ooooooV9RHoa0@400Booooo`03onk^k_l@413ogMgM01?ooooo00Go0000okZj^_ooooooV9RHoa0@
4027ooooo`00V_ooool00ol0003oooooooooo`07ooooo`03okZj^_m4A4Cooooo00Gooooo00SoMgMg
ofIVI_ooooooV9RHoa0@4?l0003o8B4Qolc<c1;ooooo00?oIVIVogMgMoooool04oooool01OnHV9So
410@o`000?lQ8B7oc<c<08Oooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}]
}, Closed]],

Cell[TextData[{
  "Fig. 6.13 (animation). WKB-shooting (solid) and Galerkin (dashed) \
solutions for the oscillations of an inhomogeneous string, with the same \
parameters as in Fig. ",
  ButtonBox["6.12",
    ButtonData:>"Fig. 6.12",
    ButtonStyle->"Hyperlink"],
  "."
}], "Caption",
  CellTags->"Fig. 6.13"],

Cell[TextData[{
  "The accuracy of the numerical eigenmode method has been considerably \
improved by using the shooting method for the low",
  "-order",
  " eigenmodes. (In fact, the small remaining difference between the \
solutions is now due to errors in the ",
  StyleBox["Galerkin",
    FontSlant->"Italic"],
  " solution rather than the WKB/shooting solution.)"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Eigenvalues in the Presence of Turning Points", "Section",
  CellTags->{"i:44", "c:41"}],

Cell[TextData[{
  "\tWe observed in Sec. ",
  ButtonBox["5.2.2",
    ButtonData:>{"Chapter5.nb", "c:30"},
    ButtonStyle->"Hyperlink"],
  " that the WKB method breaks down at turning points, where ",
  Cell[BoxData[
      \(TraditionalForm\`k(x) \[Rule] \ 0\)]],
  ".   When there are turning points, construction of WKB eigenmodes is more \
difficult.  However, it is still possible to obtain simple approximate \
results for  the eigenvalues using the technique of ",
  StyleBox["asymptotic matching",
    FontSlant->"Italic"],
  " .  The approximate eigenvalues can then be used as an initial guess in \
the shooting method to obtain accurate eigenfunctions and eigenvalues."
}], "Text"],

Cell["\<\
\tTo analyze the turning-point problem, we consider an eigenvalue \
problem of the type encountered when dealing with the 1D \
Schr\[ODoubleDot]dinger equation,\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\([\(-c\) \[PartialD]\^2\/\[PartialD]x\^2 + 
              V(x)]\) \(\(\[Psi]\_n\)(x)\) = \(E\_n\) \(\(\[Psi]\_n\)(
            x)\)\)]],
  "."
}], "NE3",
  CellTags->"(6.3.21)"],

Cell[TextData[{
  "Here, ",
  Cell[BoxData[
      \(TraditionalForm\`c = \[HBar]\^2/2  m\)]],
  " is a positive constant,  ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\)]],
  " is a potential function, and the energy levels ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(E\_n\)\(\ \)\)\)]],
  "are  the eigenvalues. We assume that ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\)]],
  " has a single minimum in which classical particles can be trapped, and \
that ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\)]],
  " is finite  and smooth for finite ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tWe will determine the energy levels for this potential in the WKB \
approximation. In this kind of potential, the boundary conditions to be \
applied to Eq. ",
  ButtonBox["(6.3.21)",
    ButtonData:>"(6.3.21)",
    ButtonStyle->"Hyperlink"],
  " are that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \[Rule] \ 0\)]],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Rule] \ \(\[PlusMinus]\[Infinity]\)\)]],
  ".\n\tThe general WKB solution to this ODE is given by Eq. ",
  ButtonBox["(5.2.15)",
    ButtonData:>{"Chapter5.nb", "(5.2.15)"},
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_n\)(x) = \ 
        A\/\@\(k(x)\)\ \[ExponentialE]\^\(\(\ \)\(\[ImaginaryI]\ \
\(\[Integral]\^x\(\( k\_n\)(x)\) \(\(\[DifferentialD]x\)\(\ \)\)\)\)\) + \ 
          B\/\@\(k(x)\)\ \[ExponentialE]\^\(\(\ \)\(\(-\ \[ImaginaryI]\)\ \(\
\[Integral]\^x\(\( k\_n\)(x)\) \(\(\[DifferentialD]x\)\(\ \)\)\)\)\)\)]],
  ","
}], "NE3",
  CellTags->"(6.3.22)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(k\_n\%2\)(x) = \(c\^\(-1\)\)(E\_n - V(x))\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tNow, for some range of values of ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n\)]],
  ", there will be two turning points,  at ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_R\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_L\)]],
  ",  defined by the solution  of the equation ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n = V(x)\)]],
  ". Equation ",
  ButtonBox["(6.3.22)",
    ButtonData:>"(6.3.22)",
    ButtonStyle->"Hyperlink"],
  " is valid far from the turning points, but breaks down as ",
  Cell[BoxData[
      \(TraditionalForm\`\(k\_n\)(x) \[Rule] 0\)]],
  ". However, near such a  turning point we already observed in Sec. 5.2.2 \
that we can Taylor-expand ",
  Cell[BoxData[
      \(TraditionalForm\`\(k\_n\)(x)\)]],
  ", allowing us to solve Eq. ",
  ButtonBox["(6.3.21)",
    ButtonData:>"(6.3.21)",
    ButtonStyle->"Hyperlink"],
  " via Airy functions. Let us consider the right turning point,  at ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_\(\(\ \)\(R\)\)\)]],
  ". Near this turning point,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(k\_n\%2\)(
          x) = \(-\(\(\[Alpha]\_\(\(\ \)\(R\)\)\)(
              x - x\_\(\(\ \)\(R\)\))\)\)\  + \ O(\((x - x\_R)\)\^2)\)]],
  ","
}], "UNNEQ"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\_\(\(\ \)\(R\)\) = \(c\^\(-1\)\) \
\[PartialD]V/\[PartialD]x\_\(\(\ \)\(R\)\)\)]],
  " >0 (since ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(\(\ \)\(R\)\)\)]],
  " is the right turning point). Equation ",
  ButtonBox["(6.3.21)",
    ButtonData:>"(6.3.21)",
    ButtonStyle->"Hyperlink"],
  " then becomes the Airy equation"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\([\(-\(\[PartialD]\^2\/\[PartialD]x\^2\)\) + \(\
\[Alpha]\_\(\(\ \)\(R\)\)\)(x - x\_\(\(\ \)\(R\)\))]\) \(\(\[Psi]\_n\)(x)\) = 
        0\)]],
  ","
}], "UNNEQ"],

Cell[TextData[{
  "with a general solution ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_n\)(x)\  = \ 
        C\_\(1\ R\)\ \(Ai(\[Alpha]\_\(\(\ \)\(R\)\)\^\(1/3\)\ \((x - 
                    x\_R)\))\)\  + \ \(\(C\_\(2\ R\)\)\(\ \)\(Bi(\[Alpha]\_\(\
\(\ \)\(R\)\)\^\(1/3\)\ \((x - x\_\(\(\ \)\(R\)\))\))\)\(\ \)\)\)]],
  ". Since ",
  Cell[BoxData[
      \(TraditionalForm\`Bi\)]],
  " blows up for large positive argument, we must set ",
  Cell[BoxData[
      \(TraditionalForm\`C\_2 = 0\)]],
  " to keep ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_n\)]],
  " finite for ",
  Cell[BoxData[
      \(TraditionalForm\`x > x\_\(\(\ \)\(R\)\)\)]],
  ". Thus, the wave function must have the form"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_n\)(
          x)\  = \ \(\(C\_\(1\ R\)\)\(\ \)\(Ai(\[Alpha]\_\(\(\ \
\)\(R\)\)\^\(1/3\)\ \((x - x\_\(\(\ \)\(R\)\))\))\)\(\ \)\)\)]]
}], "NE3",
  CellTags->"(6.3.23)"],

Cell[TextData[{
  "near the right turning point. This is the same result as was obtained in \
Sec. 5.2.2 for traveling waves reflecting from a potential. Here however, \
there is also a left turning point, ",
  Cell[BoxData[
      \(TraditionalForm\`x\_L\)]],
  ",  near which analogous results apply:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(k\_n\%2\)(x) = \(\[Alpha]\_L\)(x - x\_L)\  + \ 
          O[\((x - x\_\(\(\ \)\(L\)\))\)\^2]\)]],
  ","
}], "NE3",
  CellTags->"(6.3.24)"],

Cell[TextData[{
  " with ",
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            \(TraditionalForm\`\[Alpha]\_\(\(\ \)\(L\)\) = \(-c\^\(-1\)\)\
\ \ \[PartialD]V/\[PartialD]x\_R > 0\)]]]], TraditionalForm]]],
  ", and "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_n\)(
          x)\  = \ \(\(C\_\(1\ L\)\)\(\ \)\(Ai(\(-\[Alpha]\_L\^\(1/3\)\)\ \
\((x - x\_L)\))\)\(\ \)\)\)]],
  ","
}], "NE3",
  CellTags->"(6.3.25)"],

Cell[TextData[{
  "The wave function near these two turning points is shown schematically in \
Fig. ",
  ButtonBox["6.14",
    ButtonData:>"Fig. 6.14",
    ButtonStyle->"Hyperlink"],
  ". We need to connect these two solutions, and we will do so using the WKB \
wave function, Eq. ",
  ButtonBox["(6.3.22)",
    ButtonData:>"(6.3.22)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0.273056 0.411038 [
[.18254 .26056 -7.625 -12 ]
[.18254 .26056 7.625 0 ]
[.81746 .26056 -7.625 -12 ]
[.81746 .26056 7.625 0 ]
[1.025 .27306 0 -6 ]
[1.025 .27306 10 6 ]
[.5 .64303 -7.625 0 ]
[.5 .64303 7.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .27306 m
.18254 .27931 L
s
gsave
.18254 .26056 -68.625 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 14.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
74.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.81746 .27306 m
.81746 .27931 L
s
gsave
.81746 .26056 -68.625 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 14.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(R) show
74.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .27306 m
1 .27306 L
s
gsave
1.025 .27306 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -68.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 14.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
74.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.6746 .1584 m
.68056 .25113 L
.68359 .3075 L
.68684 .36183 L
.68856 .38509 L
.69013 .40162 L
.69089 .40781 L
.69171 .41316 L
.69209 .41511 L
.69249 .41684 L
.69286 .41812 L
.69321 .41904 L
.69341 .41946 L
.69364 .41981 L
.69403 .42014 L
.69425 .42017 L
.69449 .42007 L
.69472 .41987 L
.69492 .41959 L
.69532 .41877 L
.69554 .41815 L
.69575 .41749 L
.69652 .41413 L
.69737 .40902 L
.6983 .40172 L
.70018 .38207 L
.70341 .33586 L
.70636 .28545 L
.7098 .22511 L
.71298 .17578 L
.71449 .15648 L
.71591 .14147 L
.71739 .12939 L
.71818 .12456 L
.71862 .12235 L
.71903 .12062 L
.71944 .11918 L
.71982 .11815 L
.72003 .11771 L
.72024 .11733 L
.72048 .11702 L
.7207 .11682 L
.72091 .11672 L
.72114 .1167 L
.72138 .11679 L
.72161 .11698 L
.72202 .11755 L
.72225 .118 L
.72245 .1185 L
.72323 .12105 L
Mistroke
.72366 .12296 L
.72407 .12503 L
.7256 .13538 L
.72721 .15028 L
.72895 .1704 L
.73211 .21503 L
.73801 .31069 L
.74128 .36043 L
.74433 .39896 L
.746 .41565 L
.74752 .42778 L
.74833 .43298 L
.7492 .43761 L
.74968 .43969 L
.75013 .44133 L
.75056 .44263 L
.75101 .44372 L
.75137 .4444 L
.75178 .44492 L
.75214 .4452 L
.75248 .44529 L
.75288 .44519 L
.75325 .4449 L
.75345 .44466 L
.75367 .44434 L
.75406 .44359 L
.75479 .44168 L
.75556 .4389 L
.75693 .43205 L
.75854 .42116 L
.76004 .40843 L
.76346 .37178 L
.77577 .20173 L
.78204 .12709 L
.78558 .09548 L
.78727 .08348 L
.78886 .07406 L
.79037 .06676 L
.79176 .06147 L
.7933 .05713 L
.79411 .05547 L
.79456 .05474 L
.79497 .05418 L
.79534 .05376 L
.79574 .0534 L
.79597 .05324 L
.79617 .05312 L
.79657 .05296 L
.79692 .05289 L
.7973 .05289 L
Mistroke
.7977 .05299 L
.79807 .05315 L
.79828 .05327 L
.79851 .05343 L
.79892 .0538 L
.79971 .05472 L
.80062 .05617 L
.80146 .05785 L
.80307 .06189 L
.80481 .06736 L
.80797 .07967 L
.81386 .10813 L
.82685 .17499 L
.83332 .20272 L
.83936 .22342 L
.84517 .23869 L
.85139 .25062 L
.85462 .2553 L
.85812 .25941 L
.86115 .26227 L
.8645 .26481 L
.86751 .26662 L
.87076 .26817 L
.8742 .26943 L
.87742 .27034 L
.88045 .271 L
.88377 .27155 L
.88723 .27197 L
.89045 .27226 L
.89379 .27249 L
.89694 .27264 L
.89976 .27275 L
.90282 .27283 L
.90582 .27289 L
.90912 .27294 L
.91078 .27296 L
.91257 .27298 L
.91579 .273 L
.919 .27302 L
.92081 .27303 L
.9225 .27303 L
.92558 .27304 L
.9273 .27304 L
.92886 .27304 L
.93041 .27305 L
.93205 .27305 L
.93498 .27305 L
.93661 .27305 L
.93812 .27305 L
.93978 .27305 L
Mistroke
.94157 .27305 L
.9433 .27305 L
.9449 .27305 L
.94639 .27306 L
.94804 .27306 L
.95089 .27306 L
.95245 .27306 L
.95392 .27306 L
.95549 .27306 L
.9572 .27306 L
.95872 .27306 L
.96033 .27306 L
.96192 .27306 L
.96337 .27306 L
.96474 .27306 L
.96619 .27306 L
.96869 .27306 L
.97099 .27306 L
.97347 .27306 L
.97488 .27306 L
.97619 .27306 L
Mfstroke
.02381 .27306 m
.02725 .27306 L
.03102 .27306 L
.03292 .27306 L
.03495 .27307 L
.03862 .27307 L
.0407 .27307 L
.04297 .27308 L
.04496 .27308 L
.04708 .27308 L
.05108 .2731 L
.05477 .27311 L
.05838 .27314 L
.06226 .27317 L
.06592 .27321 L
.06927 .27326 L
.07305 .27334 L
.07655 .27344 L
.0804 .27358 L
.0845 .27379 L
.08844 .27406 L
.0927 .27446 L
.09673 .27497 L
.10044 .27558 L
.10417 .27638 L
.10765 .27733 L
.11148 .27865 L
.11557 .28048 L
.11947 .2827 L
.12372 .28579 L
.12738 .28912 L
.13143 .29367 L
.13901 .30525 L
.14316 .31365 L
.14706 .3231 L
.1548 .34698 L
.16189 .37555 L
.17708 .45772 L
.19169 .54792 L
.19556 .56844 L
.19921 .58452 L
.20123 .59163 L
.20229 .59478 L
.20341 .59762 L
.20436 .5996 L
.2054 .60131 L
.20586 .6019 L
.20635 .60243 L
.20681 .60281 L
.20724 .60307 L
Mistroke
.20773 .60326 L
.2082 .60332 L
.20862 .60327 L
.20907 .60312 L
.20957 .60282 L
.20981 .60262 L
.21009 .60236 L
.21102 .60115 L
.2119 .59955 L
.21284 .59732 L
.21453 .59194 L
.21667 .58251 L
.21869 .57082 L
.22248 .54152 L
.22619 .50354 L
.23013 .45386 L
.23719 .34538 L
.24476 .21675 L
.25168 .10952 L
.25531 .06544 L
.25715 .04758 L
.25911 .03246 L
.26015 .02625 L
.2611 .02173 L
.26155 .01993 L
.26204 .01829 L
.26251 .01702 L
.26294 .01608 L
.26344 .01529 L
.26371 .01501 L
.26399 .01481 L
.26429 .01472 L
.26458 .01473 L
.26483 .01484 L
.26511 .01506 L
.26562 .01572 L
.26587 .01618 L
.26615 .01679 L
.26711 .01968 L
.26801 .02349 L
.269 .02889 L
.27098 .04365 L
.27281 .06175 L
.27452 .08222 L
.28251 .21409 L
.28969 .35296 L
.29346 .41807 L
.29553 .44805 L
.29747 .47136 L
.29949 .49002 L
Mistroke
.30056 .49732 L
.30112 .50034 L
.30172 .50305 L
.30226 .50496 L
.30277 .50628 L
.30325 .50711 L
.30352 .5074 L
.30377 .50755 L
.30423 .50755 L
.30473 .50711 L
.30521 .50628 L
.30564 .50517 L
.30609 .50367 L
.30657 .50167 L
.30743 .49704 L
.30846 .48983 L
.3094 .48168 L
.31143 .45905 L
.31336 .43189 L
.32035 .30025 L
.32433 .21669 L
.32806 .14523 L
.32984 .11631 L
.33172 .09081 L
.3327 .07978 L
.33377 .06972 L
.33474 .06248 L
.33565 .05746 L
.33615 .0554 L
.33642 .05452 L
.3367 .05376 L
.33695 .05323 L
.33722 .0528 L
.33769 .05241 L
.33815 .05249 L
.33865 .0531 L
.33912 .05415 L
.33955 .05552 L
.34008 .05776 L
.34057 .06037 L
.34168 .06815 L
.34266 .0771 L
.3437 .0887 L
.34766 .14976 L
.35193 .23735 L
.35563 .31913 L
.35967 .40054 L
.36159 .43194 L
.36264 .44652 L
.36364 .4583 L
Mistroke
.36457 .46741 L
.36557 .47514 L
.36602 .47781 L
.36649 .48014 L
.36689 .4817 L
.36734 .48298 L
.36759 .4835 L
.36787 .48389 L
.36814 .48407 L
.36839 .48409 L
.36885 .48373 L
.36935 .48275 L
.36963 .48193 L
.36993 .48083 L
.37048 .47826 L
.37151 .47151 L
.3725 .46267 L
.37354 .45094 L
.37542 .42423 L
.37878 .36123 L
.38238 .28054 L
.38889 .14107 L
Mfstroke
gsave
.56349 .10864 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
(...) show
81.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00GOooool2o`0004[ooooo00?o0000ooooooooool0_?ooool005cooooo0ol0001:oooo
o`03o`000?oooooooooo0;cooooo001Looooo`03o`000?oooooo000004[ooooo00?o0000oooooooo
ool0_?ooool005cooooo00?o0000ooooool00000B_ooool00ol0003oooooooooo`2looooo`00G?oo
ool01?l0003oooooooooool00019ooooo`03o`000?oooooooooo0;cooooo001Looooo`04o`000?oo
ooooooooo`0004Wooooo00?o0000ooooooooool0_?ooool005_ooooo00Go0000oooooooooooooooo
o`000019ooooo`03o`000?oooooooooo0;cooooo001Kooooo`05o`000?ooooooooooooooool00000
BOooool00ol0003oooooooooo`2looooo`00Foooool01Ol0003ooooooooooooooooo000004Wooooo
00?o0000ooooooooool0_?ooool005_ooooo00Go0000ooooooooooooooooo`000019ooooo`03o`00
0?oooooooooo0;cooooo001Kooooo`05o`000?ooooooooooooooool00000BOooool00ol0003ooooo
ooooo`2looooo`00Foooool01Ol0003ooooooooooooooooo000004Wooooo00?o0000ooooooooool0
_?ooool005_ooooo00Go0000ooooooooooooooooo`00000Dooooo`;o0000<oooool00ol0003ooooo
ooooo`1Kooooo`?o0000G_ooool005_ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Aooooo`;o0000<oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooo000005kooooo001J
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool2o`0003?ooooo00?o0000
ooooooooool0Foooool00ol0003oooooo`00001Nooooo`00F_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooool00000<_ooool00ol0003oooooooooo`1Joooo
o`05o`000?ooooooooooooooool00000GOooool005[ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooo000003;ooooo00?o0000ooooooooool0F_ooool01Ol0
003ooooooooooooooooo000005gooooo001Jooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04?ooool01?l0003oooooooooool0000booooo`03o`000?oooooooooo05[ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Jooooo`00F_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo013ooooo00Co0000oooooooooooo0000<_ooool00ol0003oooooooooo`1J
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0F_ooool005[ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0@ooooo`04o`000?ooooooooooo`0003;ooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05[ooooo001Joooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04?ooool01?l0003oooooooooool0000b
ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1I
ooooo`00F_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo013ooooo00Co0000oooo
oooooooo0000<_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0FOooool005[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@oooo
o`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05Wooooo001Jooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04?ooool01Ol0003ooooooooooooooooo0000037ooooo00?o0000ooooooooool0FOooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo001Iooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool04?ooool01Ol0003ooooooooooooooooo0000037ooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo001Ioooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04?ooool01Ol0003ooooooooooooooooo
0000037ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05Wooooo001Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04?ooool01Ol0
003ooooooooooooooooo0000037ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo05Sooooo001Iooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool04?ooool01Ol0003ooooooooooooooooo0000037ooooo00?o0000ooooooooool02Oooool2
ob4Q8@Kooooo0_lQ8B46ooooo`;o8B4Q?Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo05Sooooo001Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04?ooool01Ol0
003ooooooooooooooooo0000037ooooo00?o0000ooooooooool02Oooool2ob4Q8@Kooooo0_lQ8B46
ooooo`;o8B4Q?Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Sooooo001Ioooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo05Sooooo001Iooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool0F?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Sooooo001Iooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo05Sooooo001Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0Eooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Sooooo001Iooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool0@oooool2o`0001;ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1Gooooo`00FOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
04?ooooo0_l0000Booooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Eoooool005Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooo0000017o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Gooooo`00FOooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooool000004Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo05Oooooo001Iooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0@_ooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0E_ooool005Wooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`12ooooo`04o`000?ooooooooooo`00017ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1Fooooo`00FOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04;ooooo00Co
0000oooooooooooo00004Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Kooooo
001Hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`12ooooo`04o`000?ooooooooooo`00017ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1Fooooo`00F?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool0@_ooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0EOooool005Sooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo04;ooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0EOooool005Sooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04;ooooo00Go0000oooooooooooooooo
o`00000?ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0EOooool005Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04;ooooo00Go
0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
EOooool005Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo04;ooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0EOooool005Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooo
oooooooo000000oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Dooooo`00F?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000003oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo05Cooooo001Hooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00[ooooo00Go
0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
E?ooool005Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Dooooo`00F?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05?ooooo001Hooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0Doooool005Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Cooooo`00F?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05?ooooo
001Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0D_ooool005Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Booooo`00F?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo05;ooooo001Gooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0D_ooool005Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Booooo`00Eooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo057ooooo001Gooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0DOooool005Oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`1Aooooo`00Eoooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo057o
oooo001Gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D?ooool005Oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1@ooooo`00Eoooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo053ooooo001Gooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0Coooool004?ooooo1Ol0000?ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0_l00002ooooo`04
o`000?ooooooooooo`00057ooooo0014ooooo`04o`000?ooooooooooo`0000oooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo04oooooo000mooooo`;o
00000_ooool2o`000003ooooool0003ooooo017ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool2o`0000;o
oooo0_l000000ooooooo0000o`000004ooooo`03o`000?oooooooooo04oooooo000mooooo`08onk^
k_lQ8B7oQhN7okZj^_l0003ogMgMooooool0000Booooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00[ok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMgoooooo`000?oooooo00001?ooool00ol0003oooooooooo`1>oooo
o`00?_ooool01?oMgMgo0000oa0@4?o<c<`2ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01oooool01?oMgMgo0000oa0@4?o<c<`2ooooo`03o`000?oooooo000000Cooooo00?o0000
ooooooooool0C_ooool003kooooo00Gok^k^ob4Q8Ol@413ok^k^ooooo`03o`00017ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01oooool01Oo^k^ko8B4Qoa0@4?o^k^kooooo00?o00001Oooool00ol0003ooooooooo
o`1>ooooo`00?_ooool01?lQ8B7oMgMgogMgMolb<S8Dooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00Co
8B4QogMgMomgMgOo<S8b2Oooool00ol0003oooooooooo`1>ooooo`00?Oooool2o`0000;ooooo0_l0
000Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Kooooo0_l00002ooooo`;o00002Oooool00ol0003ooooooooo
o`1=ooooo`00E_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04gooooo001Foooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01Kooooo0_l0001=ooooo`00E_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo04[ooooo001Fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
BOooool005Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`18ooooo`00E_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03Cooooo0_l00002ooooo`;o00003Oooool0
05Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool07Oooool2o`0003Cooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oM
gMd=ooooo`00E_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Oooooo`Go0000<?ooool01?oMgMgo0000oa0@4?o<
c<`>ooooo`002?ooooooo`0004?o00003?ooool01?o^k^ko8B4Qoa0@4?o^k^h>ooooo`00:Oooool3
o`0001Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo04Cooooo00Co8B4QogMgMomgMgOo<S8b3_ooool002cooooo0ol0000Dooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`13ooooo`;o00000_ooool2
o`0000gooooo000_ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0I_ooool0033o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Vooooo`00<Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo06Kooooo000booooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0I_ooool003;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1V
ooooo`00<oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06Kooooo000dooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0I_ooool003Gooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1Vooooo`00=Oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo06Kooooo000fooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Ioooool0
03Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Wooooo`00=_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo06Oooooo000gooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0Ioooool003Sooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1Wooooo`00>?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Oooooo000hoooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Ioooool003Wooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`1Wooooo`00>Oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo06Oooooo000iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Iooo
ool003Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Wooooo`00>_ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo06Oooooo000jooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0Ioooool003[ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1Xooooo`00>_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Sooooo000k
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0J?ooool003_ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0>Oooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Xooooo`00>oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`05o`000?oooooooooo
ooooool000003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Sooooo000koooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo03Wooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0J?ooool003_ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>Oooool01Ol0
003ooooooooooooooooo000000cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1X
ooooo`00??ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0iooooo`05o`000?ooooooooooooooool000003?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Sooooo000looooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
03Wooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0J?ooool003cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>Oooool01Ol0003ooooooooooooooooo
000000cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Xooooo`00??ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0iooooo`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo06Sooooo000looooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0J?ooool0
03gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0>Oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1Xooooo`00?Oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0ioooo
o`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo06Wooooo000mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03[ooooo00?o0000ooooool000003_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo06Wooooo000mooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooool000003_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Wo
oooo000mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03[ooooo00?o0000ooooool000003_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo06Wooooo000nooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooool000003_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Wooooo000n
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooool000003_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo06Wooooo000nooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ool000003oooool01Ol0003ooooooooooooooooo000006_ooooo000nooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooool000003oooool01Ol0003ooooooooooooooooo000006_ooooo000noooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03_ooooo0_l0000?ooooo`05o`000?ooooooooooooooool00000Joooool0
03oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0>ooooo`05o`000?oooooooooo
ooooool00000Joooool003oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0C?ooool01Ol0003ooooooooooooooooo
000006_ooooo000oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo04cooooo00Go0000ooooooooooooooooo`00001[
ooooo`00?oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1<ooooo`04o`000?ooooooooooo`0006cooooo000ooooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo04cooooo00Co0000oooooooooooo0000K?ooool0043ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0C?ooool01?l0003oooooooooool0001/ooooo`00@?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<oooo
o`05o`000?ooooooooooooooool00000:?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooo
000006cooooo0010ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo0000:?ooool0
0ol0003oooooooooo`1=ooooo`;o0000KOooool0043ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool01?l0
003oooooooooool0000Xooooo`03o`000?oooooooooo04gooooo0_l0001]ooooo`00@?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0>ooooo`04o`000?ooooooooooo`0002Sooooo00?o0000ooooooooool0_?ooool0
047ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03_ooool01?l0003oooooooooool0000Xooooo`03o`000?oooooo
oooo0;cooooo0011ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo0000:?ooool0
0ol0003oooooooooo`2looooo`00@Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`04o`000?oooooooooo
o`0002Sooooo00?o0000ooooooooool0_?ooool0047ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Cooooo`05o`000?ooooooooooooooool000004?ooool01?l0003oooooooooool0
000Xooooo`03o`000?oooooooooo0;cooooo0011ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool04oooool01Ol0003ooooooooooooooooo0000013ooooo00Co0000oooooooooooo0000
:?ooool00ol0003oooooooooo`2looooo`00@Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo01?ooooo00Go0000ooooooooooooooooo`00000@ooooo`04o`000?ooooooooooo`0002So
oooo00?o0000ooooooooool0_?ooool004;ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Cooooo`05o`000?ooooooooooooooool000004?ooool01?l0003oooooooooool0000Xoooo
o`03o`000?oooooooooo0;cooooo0012ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool04oooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooool00000:?ooool00ol0
003oooooooooo`2looooo`00@_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01?o
oooo00Go0000ooooooooooooooooo`00000Aooooo`;o0000:Oooool00ol0003oooooooooo`2loooo
o`00@_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01?ooooo00Go0000oooooooo
ooooooooo`00000Aooooo`;o0000:Oooool00ol0003oooooooooo`2looooo`00@_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo01Cooooo00Go0000ooooooooooooooooo`00000Aoooo
o`;o0000:Oooool00ol0003oooooooooo`2looooo`00@_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo01Cooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0_?ooool004?ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Dooooo`04o`000?ooooooooooo`0003gooooo00?o0000ooooooooool0_?ooool004?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Dooooo`04o`000?ooooooooooo`00
03gooooo00?o0000ooooooooool0_?ooool004?ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooo000003gooooo00?o0000ooooooooool0_?ooool004?ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo000003gooooo
00?o0000ooooooooool0_?ooool004?ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooo000003gooooo00?o0000ooooooooool0_?ooool004Cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Eooooo`?o0000?Oooool00ol0003oooooooooo`2l
ooooo`00A?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo0_l0000noooo
o`03o`000?oooooooooo0;cooooo0014ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0EOooool00ol0003oooooooooo`2looooo`00A?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo05Gooooo00?o0000ooooooooool0_?ooool004Cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo0;cooooo0014ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`2looooo`00AOooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0_?ooool004Go
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo0;co
oooo0015ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0E_ooool00ol0003ooooo
ooooo`2looooo`00AOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Kooooo00?o
0000ooooooooool0_?ooool004Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1F
ooooo`03o`000?oooooooooo0;cooooo0015ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0E_ooool00ol0003oooooooooo`2looooo`00A_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo05Kooooo00?o0000ooooooooool0_?ooool004Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo0;cooooo0016ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`2looooo`00A_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0_?ooool0
04Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo
0;cooooo0016ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Eoooool00ol0003o
ooooooooo`2looooo`00Aoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Oooooo
00?o0000ooooooooool0_?ooool004Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Gooooo`03o`000?oooooooooo0;cooooo0017ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0F?ooool00ol0003oooooooooo`2looooo`00Aoooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0_?ooool004Oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo0;cooooo0017ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`2looooo`00B?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0_?oo
ool004Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooo
oooo0;cooooo0018ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0F?ooool00ol0
003oooooooooo`2looooo`00B?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Wo
oooo00?o0000ooooooooool0_?ooool004Wooooo00Go0000ooooooooooooooooo`00001Kooooo`03
o`000?oooooooooo0;cooooo0019ooooo`05o`000?ooooooooooooooool00000Foooool00ol0003o
ooooooooo`2looooo`00B_ooool01?l0003oooooooooool0001Kooooo`03o`000?oooooooooo0;co
oooo001:ooooo`?o0000G?ooool00ol0003oooooooooo`2looooo`00Boooool2o`0005cooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00:Cooooo00?o^[Zjoc8b<_ooool00_ooool01?l0003oooooooooool0002kooooo`00YOoo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0^Oooool00:?ooooo00Oo
V9RHoa0@4?l0003o0000ojVYZOoooooo000000;ooooo00?o0000ooooooooool0^Oooool00:?ooooo
00Ko0000ojVYZOmEEEGoV9RHoeEEEOnj^[X3o`000;cooooo002Sooooo`06oc8b<_o^k^koV9RHoeEE
EOoMgMgo410@_oooool00:?ooooo00Oo^[ZjodA4A?o<c<co8B4Qooooool@413oc<c<0;kooooo002S
ooooo`07onk^k_l0003oooooo`000?ooooooIVIVohN7Q`2nooooo`00Xoooool01?mVIVKoV9RHoooo
oolb<S82okZj^P03o`000?oooooooooo0;cooooo002Vooooo`03ofIVI_n7QhOooooo0;oooooo002V
ooooo`03ojVYZOm4A4Cooooo0;oooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.312, 0}} -> {-16.6159, -0.664316, \
0.122724, 0.00947847}}],

Cell["\<\
Fig. 6.14  Schematic of the wave function near left and right \
turning points.\
\>", "Caption",
  CellTags->"Fig. 6.14"],

Cell[TextData[{
  "\tWe first match the WKB solution to the Airy solution near the left \
turning point. To do so, we use the following ",
  StyleBox["asymptotic",
    FontSlant->"Italic"],
  " form for the Airy function for large negative argument (see Problem 2 in \
the exercises accompanying Sec. 5.2):"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(Ai(\(-y\))\)\ ~\(1\/\(\(\@\[Pi]\) 
                y\^\(1/4\)\)\) \(cos(\(2\/3\) y\^\(3/2\) - \[Pi]/4)\)\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \ \ \)\(y \[Rule] \ \[Infinity]\)\)\)]]
}], "NE3",
  CellTags->"(6.3.26)"],

Cell[TextData[{
  "This asymptotic form for ",
  Cell[BoxData[
      \(TraditionalForm\`Ai(\(-y\))\)]],
  " is s compared with the exact form of ",
  Cell[BoxData[
      \(TraditionalForm\`Ai(\(-y\))\)]],
  " in Cell ",
  ButtonBox["6.178",
    ButtonData:>"Cell 6.178",
    ButtonStyle->"Hyperlink"],
  ". The match is excellent for ",
  Cell[BoxData[
      \(TraditionalForm\`y\  \[GreaterTilde] 3. \)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Graphics`;\)\), "\n", 
    \(\(Plot[{AiryAi[\(-y\)], \(1\/\(\(\@\[Pi]\) \((y)\)\^\(1/4\)\)\) 
            Cos[\(2\/3\) \((y)\)\^\(3/2\) - \[Pi]/4]}, {y,  .25, 8}, 
        PlotStyle \[Rule] {Red, Blue}, 
        AxesLabel \[Rule] {"\<y\>", "\<Ai(-y)\>"}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.178"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.254983 0.571798 [
[.2619 .24248 -3 -9 ]
[.2619 .24248 3 0 ]
[.5 .24248 -3 -9 ]
[.5 .24248 3 0 ]
[.7381 .24248 -3 -9 ]
[.7381 .24248 3 0 ]
[.97619 .24248 -3 -9 ]
[.97619 .24248 3 0 ]
[1.025 .25498 0 -6 ]
[1.025 .25498 10 6 ]
[.01131 .02626 -24 -4.5 ]
[.01131 .02626 0 4.5 ]
[.01131 .14062 -24 -4.5 ]
[.01131 .14062 0 4.5 ]
[.01131 .36934 -18 -4.5 ]
[.01131 .36934 0 4.5 ]
[.01131 .4837 -18 -4.5 ]
[.01131 .4837 0 4.5 ]
[.01131 .59806 -18 -4.5 ]
[.01131 .59806 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .25498 m
.2619 .26123 L
s
[(2)] .2619 .24248 0 1 Mshowa
.5 .25498 m
.5 .26123 L
s
[(4)] .5 .24248 0 1 Mshowa
.7381 .25498 m
.7381 .26123 L
s
[(6)] .7381 .24248 0 1 Mshowa
.97619 .25498 m
.97619 .26123 L
s
[(8)] .97619 .24248 0 1 Mshowa
.125 Mabswid
.08333 .25498 m
.08333 .25873 L
s
.14286 .25498 m
.14286 .25873 L
s
.20238 .25498 m
.20238 .25873 L
s
.32143 .25498 m
.32143 .25873 L
s
.38095 .25498 m
.38095 .25873 L
s
.44048 .25498 m
.44048 .25873 L
s
.55952 .25498 m
.55952 .25873 L
s
.61905 .25498 m
.61905 .25873 L
s
.67857 .25498 m
.67857 .25873 L
s
.79762 .25498 m
.79762 .25873 L
s
.85714 .25498 m
.85714 .25873 L
s
.91667 .25498 m
.91667 .25873 L
s
.25 Mabswid
0 .25498 m
1 .25498 L
s
gsave
1.025 .25498 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .02626 m
.03006 .02626 L
s
[(-0.4)] .01131 .02626 1 0 Mshowa
.02381 .14062 m
.03006 .14062 L
s
[(-0.2)] .01131 .14062 1 0 Mshowa
.02381 .36934 m
.03006 .36934 L
s
[(0.2)] .01131 .36934 1 0 Mshowa
.02381 .4837 m
.03006 .4837 L
s
[(0.4)] .01131 .4837 1 0 Mshowa
.02381 .59806 m
.03006 .59806 L
s
[(0.6)] .01131 .59806 1 0 Mshowa
.125 Mabswid
.02381 .05485 m
.02756 .05485 L
s
.02381 .08344 m
.02756 .08344 L
s
.02381 .11203 m
.02756 .11203 L
s
.02381 .16921 m
.02756 .16921 L
s
.02381 .1978 m
.02756 .1978 L
s
.02381 .22639 m
.02756 .22639 L
s
.02381 .28357 m
.02756 .28357 L
s
.02381 .31216 m
.02756 .31216 L
s
.02381 .34075 m
.02756 .34075 L
s
.02381 .39793 m
.02756 .39793 L
s
.02381 .42652 m
.02756 .42652 L
s
.02381 .45511 m
.02756 .45511 L
s
.02381 .51229 m
.02756 .51229 L
s
.02381 .54088 m
.02756 .54088 L
s
.02381 .56947 m
.02756 .56947 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Ai) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(L) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.05357 .49441 m
.07179 .5151 L
.091 .53422 L
.11048 .54941 L
.11582 .55263 L
.12153 .55557 L
.12688 .55781 L
.13182 .5594 L
.1343 .56003 L
.13662 .5605 L
.13905 .56087 L
.14033 .56102 L
.14105 .56109 L
.14171 .56115 L
.14244 .56119 L
.14309 .56123 L
.14382 .56125 L
.14459 .56127 L
.14527 .56127 L
.146 .56126 L
.14669 .56124 L
.14732 .56122 L
.14851 .56114 L
.14919 .56108 L
.14982 .56102 L
.15108 .56087 L
.15246 .56066 L
.15499 .56017 L
.15738 .55955 L
.16187 .55803 L
.16712 .55563 L
.17197 .55277 L
.18129 .54555 L
.19005 .53663 L
.21001 .5083 L
.22956 .46982 L
.24749 .42577 L
.28587 .30944 L
.32279 .18633 L
.34338 .12301 L
.36208 .07451 L
.37142 .0548 L
.38154 .0375 L
.38618 .03111 L
.3911 .02548 L
.39529 .02163 L
.39991 .01844 L
.40232 .01721 L
.4036 .01669 L
.40496 .01623 L
Mistroke
.40626 .01588 L
.40745 .01565 L
.40863 .01549 L
.40975 .01541 L
.41085 .01539 L
.41201 .01545 L
.41299 .01556 L
.41408 .01574 L
.41524 .01601 L
.41649 .01638 L
.41875 .01727 L
.42136 .01865 L
.42419 .02058 L
.42934 .02523 L
.43435 .03116 L
.43899 .03786 L
.4571 .07475 L
.46741 .10268 L
.47708 .13274 L
.51461 .27092 L
.53368 .34215 L
.54376 .37643 L
.55451 .40879 L
.56496 .43488 L
.57443 .45316 L
.57901 .45993 L
.58396 .46568 L
.58624 .46775 L
.58864 .46953 L
.59069 .47073 L
.59179 .47124 L
.59295 .47169 L
.59421 .47207 L
.59537 .47231 L
.59663 .47246 L
.59734 .4725 L
.59801 .47249 L
.59922 .47241 L
.60032 .47223 L
.60154 .47193 L
.60282 .4715 L
.60504 .47046 L
.60712 .46916 L
.61182 .46503 L
.61695 .45869 L
.62161 .45129 L
.63208 .42926 L
.65064 .37397 L
.67078 .29725 L
.68963 .21937 L
Mistroke
.71039 .13981 L
.71988 .10931 L
.73008 .08257 L
.73502 .07225 L
.73972 .06419 L
.74393 .05846 L
.74633 .05587 L
.74853 .05392 L
.751 .05222 L
.75231 .05155 L
.75368 .05099 L
.75488 .05065 L
.75599 .05044 L
.75722 .05034 L
.75791 .05034 L
.75853 .05038 L
.75969 .05054 L
.76076 .0508 L
.76194 .0512 L
.76319 .05176 L
.76529 .05301 L
.7676 .05484 L
.77265 .06048 L
.77808 .069 L
.78792 .09058 L
.7972 .11754 L
.80735 .15316 L
.8278 .2377 L
.8484 .3262 L
.86711 .39437 L
.87645 .42004 L
.88137 .4307 L
.88658 .43962 L
.89113 .44534 L
.89372 .44769 L
.89496 .44858 L
.89614 .44928 L
.8972 .4498 L
.89836 .45023 L
.89941 .4505 L
.90039 .45065 L
.90155 .45071 L
.9026 .45064 L
.90381 .45043 L
.90495 .45009 L
.90609 .44962 L
.9073 .44897 L
.90948 .44743 L
.91208 .44496 L
.91445 .44213 L
Mistroke
.91959 .43408 L
.92446 .42415 L
.93304 .40151 L
.94237 .37038 L
.97619 .22485 L
Mfstroke
0 0 1 r
.05357 .60332 m
.05807 .59678 L
.06227 .59224 L
.06687 .58855 L
.07179 .58572 L
.07427 .58464 L
.07696 .58368 L
.07933 .58299 L
.08185 .5824 L
.08411 .58197 L
.08661 .58159 L
.08887 .58133 L
.091 .58113 L
.09353 .58095 L
.09622 .58081 L
.09778 .58075 L
.09918 .58071 L
.10193 .58063 L
.10692 .58053 L
.10954 .58046 L
.11232 .58037 L
.11481 .58026 L
.11755 .58011 L
.12003 .57993 L
.12236 .57971 L
.12692 .57916 L
.13182 .57832 L
.13665 .57721 L
.14191 .57564 L
.15146 .57168 L
.16077 .56626 L
.16938 .5597 L
.18746 .54055 L
.19775 .52615 L
.20742 .5102 L
.2449 .42637 L
.28475 .30578 L
.32314 .17885 L
.34248 .12027 L
.36005 .07503 L
.36917 .05567 L
.37905 .03847 L
.38448 .03086 L
.38949 .02508 L
.39428 .02071 L
.39688 .01883 L
.39935 .01736 L
.40163 .01628 L
.40284 .01583 L
.40412 .01543 L
Mistroke
.40531 .01513 L
.40639 .01493 L
.40747 .0148 L
.40849 .01473 L
.40969 .01472 L
.41095 .01479 L
.41203 .01492 L
.41321 .01513 L
.41448 .01545 L
.41585 .01589 L
.41831 .01695 L
.4206 .01823 L
.42308 .01994 L
.42759 .02393 L
.43605 .0344 L
.44518 .04999 L
.45524 .07206 L
.47561 .13046 L
.51461 .27371 L
.53254 .34059 L
.55213 .40403 L
.56155 .42863 L
.57159 .44949 L
.57714 .45836 L
.58219 .46463 L
.58462 .46703 L
.58726 .46916 L
.58975 .47072 L
.59204 .47176 L
.59326 .47216 L
.59441 .47243 L
.59545 .4726 L
.59658 .47269 L
.59781 .47268 L
.59843 .47263 L
.59911 .47255 L
.60032 .47231 L
.60146 .47199 L
.60253 .4716 L
.60366 .4711 L
.60569 .46996 L
.60787 .4684 L
.61025 .46629 L
.61526 .4605 L
.62061 .45233 L
.63026 .43262 L
.64017 .40624 L
.65092 .37155 L
.67043 .29699 L
.68928 .21915 L
Mistroke
.71004 .13966 L
.71953 .10919 L
.72974 .08248 L
.73468 .07217 L
.73937 .06411 L
.74358 .05838 L
.74598 .05579 L
.74818 .05384 L
.75066 .05214 L
.75196 .05146 L
.75333 .05091 L
.75453 .05056 L
.75565 .05035 L
.75687 .05025 L
.75756 .05025 L
.75819 .05028 L
.75935 .05045 L
.76042 .0507 L
.76159 .0511 L
.76284 .05166 L
.76494 .0529 L
.76725 .05473 L
.7723 .06035 L
.77774 .06886 L
.78758 .0904 L
.79686 .11732 L
.807 .15289 L
.82745 .23736 L
.84805 .32585 L
.86676 .3941 L
.87611 .41983 L
.88103 .43054 L
.88623 .43951 L
.89079 .44527 L
.89337 .44765 L
.89462 .44855 L
.89579 .44927 L
.89686 .4498 L
.89802 .45024 L
.89907 .45053 L
.90004 .45069 L
.9012 .45076 L
.90225 .45071 L
.90347 .4505 L
.90461 .45018 L
.90574 .44972 L
.90695 .44909 L
.90914 .44757 L
.91173 .44514 L
.9141 .44234 L
Mistroke
.91924 .43436 L
.92411 .42449 L
.9327 .40194 L
.94202 .37091 L
.97619 .22397 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0Loooool7o`00ol[ooooo0007ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03ooooo`03o`00
0?oooooooooo077ooooo0_l00?l00ooo003oooooooooo`03ooooo`;o003obOooool000Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo077ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`36ooooo`001Ol0
0002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo0ol0001`ooooo`03o`00
oooooooooooo00Sooooo00?o003oool00?ooool0a_ooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000ooooooooool0Koooool00ol00?oo
o`00ooooo`0:ooooo`03o`00oooo003ooooo0<Gooooo0007ooooo`05o`000?ooooooooooooooool0
00002oooool01?oMgMgoEEEEooooool00006ooooo`03o`000?oooooooooo06kooooo00?o003oool0
0?ooool03?ooool00ol00?ooo`00ooooo`34ooooo`001oooool01Ol@413ooooooooooooooooo410@
00cooooo00?oMgMgolc<c?l000001_ooool00ol0003oooooooooo`1]ooooo`03o`00oooo003ooooo
00kooooo00?o003oooooooooool0`oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000000Kooooo00?o0000ooooooooool0K?ooool00ol00?ooo`00ooooo`0?oooo
o`03o`00oooo003ooooo0<?ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omg
MgOo0000ooooo`05ooooo`03o`000?oooooooooo06cooooo00?o003oool00?ooool04?ooool00ol0
0?ooooooooooo`32ooooo`008Oooool00ol0003oooooooooo`1[ooooo`03o`00oooo003ooooo01;o
oooo00?o003oooooooooool0`Oooool0027ooooo00?o0000ooooooooool0J_ooool00ol00?ooo`00
ooooo`0Cooooo`03o`00oooooooooooo0<7ooooo000Qooooo`03o`000?oooooooooo06[ooooo00?o
003oool00?ooool05?ooool00ol00?ooooooooooo`1Looooo`Ko003oG_ooool0027ooooo0ol0001Y
ooooo`03o`00oooo003ooooo01Gooooo00?o003oooooooooool0Foooool2o`00o`Gooooo00?o003o
ooooooooool0Foooool0027ooooo00?o0000ooooooooool0JOooool00ol00?ooo`00ooooo`0Foooo
o`03o`00oooooooooooo05Wooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1Koooo
o`008Oooool00ol0003oooooooooo`1Xooooo`03o`00oooo003ooooo01Oooooo00?o003oool00?oo
ool0FOooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo05[ooooo000Qooooo`03o`00
0?oooooooooo06Sooooo00?o003oool00?ooool06?ooool00ol00?ooooooooooo`1Gooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool0FOooool0027ooooo00?o0000ooooooooool0Iooo
ool00ol00?ooo`00ooooo`0Iooooo`03o`00oooo003ooooo05Kooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`1Hooooo`008Oooool00ol0003oooooooooo`1Wooooo`03o`00oooo003o
oooo01[ooooo00?o003oooooooooool0E?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo05Sooooo000Qooooo`03o`000?oooooooooo06Kooooo00?o003oool00?ooool06oooool00ol0
0?ooo`00ooooo`1Dooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0Eoooool0027o
oooo00?o0000ooooooooool0I_ooool00ol00?ooo`00ooooo`0Kooooo`03o`00oooo003ooooo05Co
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Gooooo`008Oooool00ol0003ooooo
ooooo`1Uooooo`03o`00oooo003ooooo01gooooo00?o003oool00?ooool0D_ooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo05Kooooo000Qooooo`?o0000IOooool00ol00?ooo`00oooo
o`0Mooooo`03o`00oooo003ooooo05;ooooo00?o003oooooooooool03_ooool00ol00?oooooooooo
o`1Fooooo`008Oooool00ol0003oooooooooo`1Uooooo`03o`00oooo003ooooo01gooooo00?o003o
ool00?ooool0D_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo05Kooooo000Qoooo
o`03o`000?oooooooooo06Cooooo00?o003oool00?ooool07oooool00ol00?ooo`00ooooo`1@oooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool0EOooool0027ooooo00?o0000oooooooo
ool0I?ooool00ol00?ooo`00ooooo`0Oooooo`03o`00oooo003ooooo053ooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`1Eooooo`008Oooool00ol0003oooooooooo`1Tooooo`03o`00
oooooooooooo01oooooo00?o003oool00?ooool0D?ooool00ol00?ooooooooooo`0Aooooo`03o`00
oooooooooooo05Cooooo000Qooooo`03o`000?oooooooooo06?ooooo00?o003oool00?ooool08Ooo
ool00ol00?ooo`00ooooo`1>ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool0E?oo
ool0027ooooo00?o0000ooooooooool0Hoooool00ol00?ooo`00ooooo`0Qooooo`03o`00oooo003o
oooo04kooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`1Dooooo`008Oooool00ol0
003oooooooooo`1Sooooo`03o`00oooooooooooo027ooooo00?o003oool00?ooool0C_ooool00ol0
0?ooooooooooo`0Cooooo`03o`00oooooooooooo05?ooooo000Qooooo`03o`000?oooooooooo06;o
oooo00?o003oool00?ooool08oooool00ol00?ooo`00ooooo`1<ooooo`03o`00oooooooooooo01Co
oooo00?o003oooooooooool0Doooool0027ooooo0ol0001Rooooo`03o`00oooooooooooo02?ooooo
00?o003oool00?ooool0C?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo05?ooooo
000Qooooo`03o`000?oooooooooo06;ooooo00?o003oooooooooool08oooool00ol00?ooo`00oooo
o`1<ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0D_ooool0027ooooo00?o0000
ooooooooool0HOooool00ol00?ooo`00ooooo`0Uooooo`03o`00oooo003ooooo04[ooooo00?o003o
ooooooooool05_ooool00ol00?ooooooooooo`1Booooo`008Oooool00ol0003oooooooooo`1Qoooo
o`03o`00oooooooooooo02Gooooo00?o003oool00?ooool0B_ooool00ol00?ooooooooooo`0Foooo
o`03o`00oooooooooooo05;ooooo000Qooooo`03o`000?oooooooooo067ooooo00?o003ooooooooo
ool09Oooool00ol00?ooo`00ooooo`1:ooooo`03o`00oooooooooooo01Kooooo00?o003ooooooooo
ool0D_ooool0027ooooo00?o0000ooooooooool0H?ooool00ol00?ooo`00ooooo`0Wooooo`03o`00
oooo003ooooo04Sooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`1Aooooo`001ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool00ol0003ooooo
ooooo`1Pooooo`03o`00oooooooooooo02Oooooo00?o003oool00?ooool0B?ooool00ol00?oooooo
ooooo`0Hooooo`03o`00oooooooooooo057ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo063o
oooo00?o003oooooooooool09oooool00ol00?ooo`00ooooo`18ooooo`03o`00oooooooooooo01So
oooo00?o003oooooooooool0DOooool000Go00000_ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`1Oooooo`03o`00oooo003ooooo02So
oooo00?o003oool00?ooool0Aoooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo053o
oooo0007ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05ooooo`?o
0000Goooool00ol00?ooooooooooo`0Yooooo`03o`00oooo003ooooo04Kooooo00?o003ooooooooo
ool06_ooool00ol00?ooooooooooo`1@ooooo`001oooool01Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`1Oooooo`03o`00oooooooooooo02Wo
oooo00?o003oool00?ooool0A_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo053o
oooo0007ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo05kooooo00?o003oool00?ooool0:_ooool00ol00?ooo`00ooooo`16ooooo`03
o`00oooooooooooo01[ooooo00?o003oooooooooool0D?ooool000Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`1Noooo
o`03o`00oooooooooooo02_ooooo00?o003oool00?ooool0A?ooool00ol00?ooooooooooo`0Loooo
o`03o`00oooooooooooo04oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnH
V9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0G_ooool00ol00?ooooooooooo`0[
ooooo`03o`00oooo003ooooo04Cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`1?
ooooo`008Oooool00ol0003oooooooooo`1Mooooo`03o`00oooo003ooooo02cooooo00?o003oool0
0?ooool0A?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo04oooooo000Qooooo`03
o`000?oooooooooo05gooooo00?o003oool00?ooool0;Oooool00ol00?ooooooooooo`12ooooo`03
o`00oooooooooooo01gooooo00?o003oooooooooool0Coooool0027ooooo00?o0000ooooooooool0
GOooool00ol00?ooooooooooo`0]ooooo`03o`00oooo003ooooo04;ooooo00?o003oooooooooool0
7_ooool00ol00?ooooooooooo`1>ooooo`008Oooool00ol0003oooooooooo`1Looooo`03o`00oooo
003ooooo02kooooo00?o003oool00?ooool0@_ooool00ol00?ooooooooooo`0Nooooo`03o`00oooo
oooooooo04kooooo000Qooooo`?o0000G?ooool00ol00?ooo`00ooooo`0^ooooo`03o`00oooo003o
oooo04;ooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`1>ooooo`008Oooool00ol0
003oooooooooo`1Looooo`03o`00oooooooooooo02oooooo00?o003oooooooooool0@?ooool00ol0
0?ooooooooooo`0Oooooo`03o`00oooooooooooo04kooooo000Qooooo`03o`000?oooooooooo05_o
oooo00?o003oool00?ooool0<?ooool00ol00?ooo`00ooooo`10ooooo`03o`00oooooooooooo023o
oooo00?o003oooooooooool0COooool0027ooooo00?o0000ooooooooool0Foooool00ol00?ooo`00
ooooo`0`ooooo`03o`00oooo003ooooo043ooooo00?o003oooooooooool08?ooool00ol00?oooooo
ooooo`1=ooooo`008Oooool00ol0003oooooooooo`1Kooooo`03o`00oooooooooooo037ooooo00?o
003oooooooooool0?_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo04gooooo000Q
ooooo`03o`000?oooooooooo05_ooooo00?o003oooooooooool0<Oooool00ol00?ooo`00ooooo`0n
ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool0COooool0027ooooo00?o0000oooo
ooooool0F_ooool00ol00?ooo`00ooooo`0booooo`03o`00oooo003ooooo03kooooo00?o003ooooo
ooooool08Oooool00ol00?ooooooooooo`1=ooooo`008Oooool00ol0003oooooooooo`1Jooooo`03
o`00oooo003ooooo03;ooooo00?o003oool00?ooool0?Oooool00ol00?ooooooooooo`0Sooooo`03
o`00oooooooooooo04cooooo000Qooooo`03o`000?oooooooooo05[ooooo00?o003oooooooooool0
<oooool00ol00?ooooooooooo`0looooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool0
C?ooool0027ooooo0ol0001Iooooo`03o`00oooo003ooooo03Cooooo00?o003oool00?ooool0??oo
ool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo04cooooo000Qooooo`03o`000?oooooo
oooo05Wooooo00?o003oool00?ooool0=?ooool00ol00?ooo`00ooooo`0looooo`03o`00oooooooo
oooo02?ooooo00?o003oooooooooool0C?ooool0027ooooo00?o0000ooooooooool0FOooool00ol0
0?ooooooooooo`0eooooo`03o`00oooooooooooo03[ooooo00?o003oooooooooool09Oooool00ol0
0?ooooooooooo`1;ooooo`008Oooool00ol0003oooooooooo`1Hooooo`03o`00oooo003ooooo03Ko
oooo00?o003oooooooooool0>_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo04_o
oooo000Qooooo`03o`000?oooooooooo05Sooooo00?o003oool00?ooool0=_ooool00ol00?ooo`00
ooooo`0jooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool0Boooool0027ooooo00?o
0000ooooooooool0AOooool5o`0000kooooo00?o003oooooooooool0=_ooool00ol0003o003ooa0@
400iooooo`03o`00oooooooooooo00Wooooo00Gok^k^oc8b<_l0003o410@olc<c00Hooooo`03o`00
oooooooooooo02_ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Kooooo`008Oooool00ol0003ooooo
ooooo`15ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@03Oooool00ol00?ooo`00ooooo`0hooooo`03
o`00oooooooooooo03Sooooo00?o003oooooooooool02Oooool01OmEEEGoMgMgoooooonHV9So8B4Q
01Wooooo00?o003oooooooooool0:_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01_ooooo000Qoooo
o`03o`000?oooooooooo04Kooooo00?oV9RHob4Q8Oo^k^h03_ooool00ol00?ooo`00ooooo`0eoooo
o`?o000000?o003oool00?ooool0>?ooool00ol00?ooooooooooo`09ooooo`05o`000?oooooooooo
ooooool000006Oooool00ol00?ooooooooooo`0Zooooo`05o`000?ooooooooooooooool000006ooo
ool0027ooooo00?o0000ooooooooool0Aoooool00onHV9So8B4Qonk^kP0=ooooo`03o`00oooooooo
oooo03Gooooo00GoA4A4omgMgOoooooo003oool0000iooooo`03o`00oooooooooooo00Wooooo00Go
0000oiRHV?ooooooV9RHob4Q8@0Iooooo`03o`00oooooooooooo02[ooooo00Go<S8boiRHV?oooooo
003ooc8b<P0Kooooo`008Oooool3o`0004Sooooo00?oMgMgofIVI_ooool03?ooool00ol00?oooooo
ooooo`0eooooo`05omgMgOmEEEGoooooo`000?l00?l0>?ooool00ol00?ooooooooooo`0:ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`06Oooool00ol00?ooooooooooo`0Zooooo`05olc<c?l0003o0000
o`00ooo<c<`06oooool0027ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0:oooo
o`03o`00oooo003ooooo03Oooooo00CoMgMgolc<c?l0003o003o>?ooool00ol00?ooooooooooo`0:
ooooo`03oeEEEOn7QhOooooo01_ooooo00?o003oooooooooool0:_ooool01Ol@413o^[Zjooooool0
0?oo410@01_ooooo000Qooooo`03o`000?oooooooooo04Gooooo00Go0000okZj^_ooooooV9RHoa0@
400<ooooo`03o`00oooo003ooooo03Oooooo00Gok^k^odA4A?l0003o003oool0000gooooo`03o`00
oooooooooooo00[ooooo00?ogMgMoa0@4?nHV9P07?ooool00ol00?ooooooooooo`0Yooooo`05o`00
0?nj^[[o003ookZj^_l000006oooool0027ooooo00?o0000ooooooooool0AOooool01OnHV9So410@
o`000?lQ8B7oc<c<00cooooo00?o003oooooooooool0>?ooool01?mgMgOo0000ooooool00?lgoooo
o`03o`00oooooooooooo00_ooooo00Coc<c<odA4A?l0003o410@6_ooool00ol00?ooooooooooo`0Y
ooooo`05ojVYZOl@413o003ooa0@4?nYZJT04?ooool3o`000003oa0@4?oooooooooo00Gooooo000Q
ooooo`03o`000?oooooooooo05Gooooo00?o003oool00?ooool0??ooool00ol00?ooooooooooo`0d
ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool0:oooool00ol00?ooooooooooo`0B
ooooo`03oa0@4?nj^[[ooooo00Kooooo000Qooooo`03o`000?oooooooooo05Gooooo00?o003oool0
0?ooool0??ooool00ol00?ooooooooooo`0dooooo`03o`00oooooooooooo02[ooooo00?o003ooooo
ooooool0:oooool00ol00?ooooooooooo`0Booooo`03oiRHV?lb<S;ooooo00Kooooo000Qooooo`03
o`000?oooooooooo05Gooooo00?o003oooooooooool0??ooool00ol00?ooo`00ooooo`0dooooo`03
o`00oooooooooooo02_ooooo00?o003oooooooooool0:Oooool00ol00?ooooooooooo`0Cooooo`03
omgMgOl0003o^[Zj00Kooooo000Qooooo`03o`000?oooooooooo05Cooooo00?o003oool00?ooool0
?_ooool00ol00?ooooooooooo`0cooooo`03o`00oooooooooooo02_ooooo00?o003oooooooooool0
:Oooool00ol00?ooooooooooo`0Cooooo`03oeEEEOmgMgOoA4A400Kooooo000Qooooo`03o`000?oo
oooooooo05Cooooo00?o003oool00?ooool0?_ooool00ol00?ooooooooooo`0booooo`03o`00oooo
oooooooo02cooooo00?o003oooooooooool0:Oooool00ol00?ooooooooooo`0Booooo`05omgMgOl@
413oooooob4Q8OoMgMd01Oooool001[oooooG_l000000ol00?oo0000o`00000no`000003o`00oooo
003o000003;o000000?o003oo`000?l00000;?l000000ol00?oo0000o`00000Yo`000003o`00ool0
003o000000Oo00002oooool01OmVIVKoQhN7oooooonHV9SoEEEE00Gooooo000Qooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool02?ooool00ol00?ooo`00ooooo`04ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`05o`000?oo
ooooooooooooool00?l03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo
00?o003oooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo
00?o003oooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo
00Co003ooooooooooooo00004Oooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo00?o
oooo000Qooooo`03o`000?oooooooooo05?ooooo00?o003oool00?ooool0@?ooool00ol00?oooooo
ooooo`0aooooo`03o`00oooooooooooo02gooooo00?o003oooooooooool09oooool00ol00?oooooo
ooooo`0Booooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00_ooool0027ooooo
00?o0000ooooooooool0Doooool00ol00?ooooooooooo`10ooooo`03o`00oooooooooooo037ooooo
00?o003oooooooooool0;Oooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo01gooooo
000Qooooo`03o`000?oooooooooo05?ooooo00?o003oooooooooool0@Oooool00ol00?oooooooooo
o`0_ooooo`03o`00oooooooooooo02kooooo00?o003oooooooooool09oooool00ol00?oooooooooo
o`0Mooooo`008Oooool00ol0003oooooooooo`1Booooo`03o`00oooo003ooooo04;ooooo00?o003o
ooooooooool0;oooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo02Kooooo00?o003o
ooooooooool07Oooool0027ooooo00?o0000ooooooooool0D_ooool00ol00?ooo`00ooooo`12oooo
o`03o`00oooooooooooo02oooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`0Uoooo
o`03o`00oooooooooooo01kooooo000Qooooo`03o`000?oooooooooo05;ooooo00?o003ooooooooo
ool0@_ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo02oooooo00?o003ooooooooo
ool09Oooool00ol00?ooooooooooo`0Nooooo`008Oooool3o`00057ooooo00?o003oool00?ooool0
A?ooool00ol00?ooooooooooo`0]ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0
9Oooool00ol00?ooooooooooo`0Nooooo`008Oooool00ol0003oooooooooo`1Aooooo`03o`00oooo
003ooooo04Cooooo00?o003oooooooooool0;Oooool00ol00?ooooooooooo`0aooooo`03o`00oooo
oooooooo02Cooooo00?o003oooooooooool07_ooool0027ooooo00?o0000ooooooooool0DOooool0
0ol00?ooooooooooo`14ooooo`03o`00oooooooooooo02gooooo00?o003oooooooooool0<Oooool0
0ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo01oooooo000Qooooo`03o`000?oooooooooo
053ooooo00?o003oool00?ooool0AOooool00ol00?ooo`00ooooo`0]ooooo`03o`00oooooooooooo
037ooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`0Oooooo`008Oooool00ol0003o
ooooooooo`1@ooooo`03o`00oooo003ooooo04Kooooo00?o003oooooooooool0:oooool00ol00?oo
ooooooooo`0booooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool07oooool0027ooooo
00?o0000ooooooooool0D?ooool00ol00?ooooooooooo`16ooooo`03o`00oooooooooooo02_ooooo
00?o003oooooooooool0<oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo01oooooo
000Qooooo`03o`000?oooooooooo04oooooo00?o003oool00?ooool0Aoooool00ol00?oooooooooo
o`0[ooooo`03o`00oooooooooooo03?ooooo00?o003oooooooooool08Oooool00ol00?oooooooooo
o`0Pooooo`008Oooool00ol0003oooooooooo`1?ooooo`03o`00oooo003ooooo04Oooooo00?o003o
ool00?ooool0:oooool00ol00?ooooooooooo`0cooooo`03o`00oooooooooooo027ooooo00?o003o
ooooooooool08?ooool0027ooooo00?o0000ooooooooool0Coooool00ol00?ooooooooooo`18oooo
o`03o`00oooooooooooo02Wooooo00?o003oooooooooool0=?ooool00ol00?ooooooooooo`0Qoooo
o`03o`00oooooooooooo023ooooo000Qooooo`?o0000C_ooool00ol00?ooo`00ooooo`19ooooo`03
o`00oooooooooooo02Wooooo00?o003oooooooooool0=Oooool00ol00?ooooooooooo`0Pooooo`03
o`00oooooooooooo023ooooo000Qooooo`03o`000?oooooooooo04kooooo00?o003oool00?ooool0
BOooool00ol00?ooooooooooo`0Yooooo`03o`00oooooooooooo03Gooooo00?o003oooooooooool0
7oooool00ol00?ooooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`1>ooooo`03o`00oooo
oooooooo04Wooooo00?o003oool00?ooool0:Oooool00ol00?ooooooooooo`0eooooo`03o`00oooo
oooooooo01oooooo00?o003oooooooooool08Oooool0027ooooo00?o0000ooooooooool0COooool0
0ol00?ooo`00ooooo`1:ooooo`03o`00oooo003ooooo02Sooooo00?o003oooooooooool0=_ooool0
0ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo027ooooo000Qooooo`03o`000?oooooooooo
04gooooo00?o003oool00?ooool0Boooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo
03Oooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0Qooooo`008Oooool00ol0003o
ooooooooo`1=ooooo`03o`00oooooooooooo04_ooooo00?o003oool00?ooool09oooool00ol00?oo
ooooooooo`0gooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool08_ooool0027ooooo
00?o0000ooooooooool0C?ooool00ol00?ooo`00ooooo`1<ooooo`03o`00oooo003ooooo02Oooooo
00?o003oooooooooool0=oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo02;ooooo
000Qooooo`03o`000?oooooooooo04cooooo00?o003oool00?ooool0C?ooool00ol00?ooo`00oooo
o`0Vooooo`03o`00oooooooooooo03Sooooo00?o003oooooooooool07Oooool00ol00?oooooooooo
o`0Rooooo`008Oooool00ol0003oooooooooo`1<ooooo`03o`00oooooooooooo04gooooo00?o003o
ooooooooool09Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo01cooooo00?o003o
ooooooooool08_ooool0027ooooo0ol0001;ooooo`03o`00oooo003ooooo04kooooo00?o003oool0
0?ooool09Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo01cooooo00?o003ooooo
ooooool08_ooool0027ooooo00?o0000ooooooooool0Boooool00ol00?ooo`00ooooo`1>ooooo`03
o`00oooo003ooooo02Cooooo00?o003oool00?ooool0>_ooool00ol00?ooooooooooo`0Kooooo`03
o`00oooooooooooo02?ooooo000Qooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool0
C_ooool00ol00?ooo`00ooooo`0Tooooo`03o`00oooooooooooo03_ooooo00?o003oooooooooool0
6_ooool00ol00?ooooooooooo`0Sooooo`008Oooool00ol0003oooooooooo`1:ooooo`03o`00oooo
003ooooo053ooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`0kooooo`03o`00oooo
oooooooo01[ooooo00?o003oooooooooool08oooool0027ooooo00?o0000ooooooooool0B_ooool0
0ol00?ooo`00ooooo`1@ooooo`03o`00oooo003ooooo02?ooooo00?o003oooooooooool0>oooool0
0ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo02?ooooo000Qooooo`03o`000?oooooooooo
04[ooooo00?o003oooooooooool0D?ooool00ol00?ooo`00ooooo`0Rooooo`03o`00oooo003ooooo
03cooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0Tooooo`008Oooool00ol0003o
ooooooooo`19ooooo`03o`00oooo003ooooo05;ooooo00?o003oooooooooool08Oooool00ol00?oo
ooooooooo`0mooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool09?ooool000Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000oooooooo
ool0BOooool00ol00?ooo`00ooooo`1Booooo`03o`00oooo003ooooo027ooooo00?o003ooooooooo
ool0?Oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo02Cooooo0007ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005oooo
o`03o`000?oooooooooo04Wooooo00?o003oooooooooool0D_ooool00ol00?ooo`00ooooo`0Qoooo
o`03o`00oooooooooooo03gooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0Toooo
o`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`00
04Sooooo00?o003oool00?ooool0E?ooool00ol00?ooooooooooo`0Oooooo`03o`00oooo003ooooo
03oooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0Uooooo`001oooool01Ol0003o
oooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`18oooo
o`03o`00oooo003ooooo05Cooooo00?o003oool00?ooool07oooool00ol00?ooooooooooo`0ooooo
o`03o`00oooooooooooo01Kooooo00?o003oooooooooool09Oooool000Oooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0B?ooool00ol0
0?ooooooooooo`1Dooooo`03o`00oooo003ooooo01oooooo00?o003oooooooooool0?oooool00ol0
0?ooooooooooo`0Fooooo`03o`00oooooooooooo02Gooooo0007ooooo`05oa0@4?oooooooooooooo
ool@41003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Oooooo00?o003oool0
0?ooool0EOooool00ol00?ooo`00ooooo`0Oooooo`03o`00oooooooooooo03oooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`0Vooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo04Oooooo00?o003o
ool00?ooool0E_ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo047ooooo00?o003o
ooooooooool05?ooool00ol00?ooooooooooo`0Vooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo04Oooooo00?o
003oooooooooool0E_ooool00ol00?ooo`00ooooo`0Mooooo`03o`00oooooooooooo047ooooo00?o
003oooooooooool05?ooool00ol00?ooooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`16
ooooo`03o`00oooo003ooooo05Oooooo00?o003oool00?ooool07Oooool00ol00?ooooooooooo`11
ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool09oooool0027ooooo00?o0000oooo
ooooool0A_ooool00ol00?ooo`00ooooo`1Hooooo`03o`00oooooooooooo01_ooooo00?o003ooooo
ooooool0@oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo02Oooooo000Qooooo`03
o`000?oooooooooo04Kooooo00?o003oooooooooool0F?ooool00ol00?ooo`00ooooo`0Kooooo`03
o`00oooooooooooo04?ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Wooooo`00
8Oooool3o`0004Gooooo00?o003oool00?ooool0FOooool00ol00?ooo`00ooooo`0Kooooo`03o`00
oooooooooooo04?ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Xooooo`008Ooo
ool00ol0003oooooooooo`15ooooo`03o`00oooo003ooooo05[ooooo00?o003oooooooooool06Ooo
ool00ooo003o003oooooo`15ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0:?oo
ool0027ooooo00?o0000ooooooooool0AOooool00ol00?ooooooooooo`1Jooooo`03o`00oooooooo
oooo01Wooooo00?o003oooooooooool0AOooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo
oooo02Sooooo000Qooooo`03o`000?oooooooooo04Cooooo00?o003oool00?ooool0Foooool00ol0
0?ooo`00ooooo`0Iooooo`03o`00oooooooooooo04Gooooo00?o003oooooooooool04?ooool00ol0
0?ooooooooooo`0Xooooo`008Oooool00ol0003oooooooooo`14ooooo`03o`00oooo003ooooo05co
oooo00?o003oooooooooool05oooool00ooo003o003oooooo`17ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool0:Oooool0027ooooo00?o0000ooooooooool0A?ooool00ol00?oooooo
ooooo`1Looooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool0Aoooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo02Wooooo000Qooooo`03o`000?oooooooooo04?ooooo00?o
003oool00?ooool0GOooool00ol00?ooo`00ooooo`0Gooooo`03o`00oooooooooooo04Oooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`0Yooooo`008Oooool00ol0003oooooooooo`13
ooooo`03o`00oooo003ooooo05kooooo00?o003oooooooooool05Oooool00ooo003o003oooooo`19
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0:_ooool0027ooooo00?o0000oooo
ooooool0@oooool00ol00?ooooooooooo`1Nooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool0BOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02[ooooo000Qooooo`?o
0000@_ooool00ol00?ooo`00ooooo`1Oooooo`03o`00oooo003ooooo01Gooooo00?o003ooooooooo
ool0B_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo02[ooooo000Qooooo`03o`00
0?oooooooooo04;ooooo00?o003oool00?ooool0H?ooool00ol00?ooooooooooo`0Cooooo`03ool0
0?l00?oooooo04_ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0[ooooo`008Ooo
ool00ol0003oooooooooo`11ooooo`03o`00oooo003ooooo067ooooo00?o003oooooooooool04ooo
ool00ol00?ooooooooooo`1;ooooo`03o`00oooooooooooo00Wooooo00?oo`00o`00ooooool0;?oo
ool0027ooooo00?o0000ooooooooool0@Oooool00ol00?ooo`00ooooo`1Rooooo`03o`00oooooooo
oooo017ooooo00?oo`00o`00ooooool0COooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo02cooooo000Qooooo`03o`000?oooooooooo047ooooo00?o003oool00?ooool0H_ooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo04kooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0]ooooo`008Oooool00ol0003oooooooooo`10ooooo`03o`00oooo003ooooo06Co
oooo00?o003oooooooooool03oooool00ooo003o003oooooo`1?ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool0;_ooool0027ooooo00?o0000ooooooooool0@?ooool00ol00?ooo`00
ooooo`1Tooooo`03o`00oooo003ooooo00oooooo00?o003oooooooooool0D?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo02kooooo000Qooooo`03o`000?oooooooooo03oooooo00?o
003ooooooooo0000I_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo057ooooo0_l0
0?l01?oooooo003oo`00ool00?laooooo`008Oooool00ol0003oooooooooo`0oooooo`03o`00oooo
003ooooo06Kooooo00?o003oool00?ooool03Oooool00ol00?ooooooooooo`1Cooooo`?o003o<ooo
ool0027ooooo0ol0000nooooo`03o`00ooooooooo`0006Sooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`29ooooo`008Oooool00ol0003oooooooooo`0nooooo`03o`00ooooooooo`00
06Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`2:ooooo`008Oooool00ol0003o
ooooooooo`0nooooo`03o`00oooo003ooooo06[ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`2;ooooo`008Oooool00ol0003oooooooooo`0mooooo`03o`00ooooooooo`0006cooooo
00?o003oooooooooool01_ooool00ooo003o003oooooo`2<ooooo`008Oooool00ol0003ooooooooo
o`0mooooo`03o`00ooooooooo`0006gooooo00?o003oooooooooool01?ooool2o`00ohkooooo000Q
ooooo`03o`000?oooooooooo03cooooo00?o003ooooooooo0000Koooool6o`00oi3ooooo0007oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo03cooooo00?o003ooooooooo0000LOooool2o`00oi;ooooo0007oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0kooooo`03o`00ooooooooo`000?oooooo1oooool000Oooooo00Go410@oooo
oooooooooooooa0@400;ooooo`Go00001Oooool00ol0003oooooooooo`0kooooo`03o`00oooooooo
o`000?oooooo1oooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgo
ooooo`0000Kooooo0ol0000kooooo`03o`00oooo003ooooo0?oooooo1oooool000Oooooo00Go0000
ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0
>_ooool00ol00?ooooooool0003oooooo`Sooooo0007ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00omgMgOoc<c<o`000006ooooo`03o`000?oooooooooo03[ooooo00?o003oool00?ooool0
ooooool8ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
1_ooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo02oooooo00?o003ooooooooo0000
ooooool9ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0
1Oooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo02oooooo00?o003oool00?ooool0
ooooool9ooooo`008Oooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo02gooooo00?o
003ooooooooo0000ooooool:ooooo`008Oooool00ol0003oooooooooo`09ooooo`03ool00?oooooo
oooo02cooooo00?o003oool00?ooool0ooooool:ooooo`008Oooool00ol0003oooooooooo`0:oooo
o`03ool00?oooooooooo02_ooooo00?o003oool00?ooool0ooooool:ooooo`008Oooool00ol0003o
ooooooooo`0:ooooo`03ool00?oooooooooo02[ooooo00?o003oool00?ooool0ooooool;ooooo`00
8Oooool3o`0000_ooooo00?oo`00ooooooooool0:Oooool00ol00?ooo`00ooooo`3oooooo`_ooooo
000Qooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool09oooool00ol00?ooo`00oooo
o`3oooooo`cooooo000Qooooo`03o`000?oooooooooo00gooooo00?oo`00ooooooooool09Oooool0
0ol00?ooo`00ooooo`3oooooo`gooooo000Qooooo`03o`000?oooooooooo00kooooo00?oo`00oooo
ooooool09?ooool00ol00?ooooooooooo`3oooooo`gooooo000Qooooo`03o`000?oooooooooo00oo
oooo00?oo`00ooooooooool08_ooool00ol00?ooooooooooo`3oooooo`kooooo000Qooooo`03o`00
0?oooooooooo013ooooo00?oo`00ooooooooool08?ooool00ooo003o003oooooo`3oooooo`oooooo
000Qooooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool07_ooool00ooo003o003ooooo
o`3ooooooa3ooooo000Qooooo`03o`000?oooooooooo01;ooooo0_oo000Mooooo`03ool00?l00?oo
oooo0?oooooo4Oooool0027ooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`0Joooo
o`03ool00?l00?oooooo0?oooooo4Oooool0027ooooo0ol0000Eooooo`;oo`006Oooool00ooo003o
003oooooo`3ooooooa;ooooo000Qooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0
5Oooool00ooo003o003oooooo`3ooooooa?ooooo000Qooooo`03o`000?oooooooooo01Sooooo0_oo
000Dooooo`03ool00?l00?oooooo0?oooooo5?ooool0027ooooo00?o0000ooooooooool06_ooool2
ool0017ooooo00?oo`00o`00ooooool0oooooolEooooo`008Oooool00ol0003oooooooooo`0Loooo
o`;oo`003?ooool3ool00003o`00oooooooooooo0?oooooo5Oooool0027ooooo00?o0000oooooooo
ool07_ooool00ooo003oooooooooo`07ooooo`;oo`000_ooool00ol00?ooooooooooo`3ooooooaKo
oooo000Qooooo`03o`000?oooooooooo01oooooo2Ooo0002ooooo`;o003ooooooolIooooo`008Ooo
ool00ol0003oooooooooo`0Yooooo`03o`00oooooooooooo0?oooooo6Oooool0027ooooo00?o0000
ooooooooool09oooool2o`00oooooooo7?ooool0027ooooo0ol0000Tooooo`?o003ooooooolNoooo
o`008Oooool00ol0003oooooooooo`0Sooooo`03o`00oooooooooooo0?oooooo7oooool0027ooooo
00?o0000ooooooooool07oooool4o`00oooooooo8_ooool0027ooooo00?o0000ooooooooool04_oo
ool=o`00oooooooo9_ooool0027ooooo00?o0000ooooooooool03Oooool5o`00oooooooo<oooool0
027ooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`3oooooocKooooo0007ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c005
ooooo`03o`000?oooooooooo00[ooooo0_l00?ooooooocWooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@05ooooo`03o`000?oo
oooooooo00Wooooo00?o003oooooooooool0ooooooliooooo`001oooool01Ol@413ooooooooooooo
oooo410@00_ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Sooooo
00?o003oooooooooool0ooooooljooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000oiRHV?ooooooV9RHob4Q8@05ooooo`?o00002?ooool00ol00?ooooooooooo`3ooooooc[o
oooo0007ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<
00Gooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`3ooooooc_ooooo0007ooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`07ooooo`03o`000?oooooooooo
0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH
00Oooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo00Coc<c<odA4A?l0003o410@1Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00:Oooool3o`000003oa0@4?oooooooooo
0?oooooo>_ooool001oooooo00?oMgMgofIVI_ooool02Oooool00ol@413o^[Zjooooo`03ooooo`03
ofIVI_mgMgOooooo0?oooooo=Oooool001kooooo00?ogMgMoa0@4?o^k^h02_ooool00onHV9So<S8b
ooooo`03ooooo`03onk^k_l@413ogMgM0?oooooo=Oooool000_ooooo0ol00002ooooo`?o00000_oo
ool5o`0000Cooooo00?oEEEEoiRHV?ooool02_ooool00ooMgMgo0000okZj^P04ooooo`03ohN7QomV
IVKooooo0?oooooo=?ooool000_ooooo00?ok^k^o`000?o^k^h00oooool00ol0003ogMgMooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00omEEEGoMgMgodA4A004
ooooo`03onk^k_l0003ooooo0?oooooo=?ooool000cooooo00?oEEEEo`000?l000000_l000000om4
A4Coooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Co<S8boooooooooooooooo1_l00002
ooooo`05omgMgOl@413oooooob4Q8OoMgMd01?ooool00ol0003oooooooooo`3ooooooc?ooooo000<
ooooo`06ojVYZOm4A4Cooooooooooom4A4CoV9RH1Oooool00ol0003oooooooooo`04ooooo`03oc8b
<_oooooooooo00Wooooo00GoIVIVohN7QoooooooV9RHoeEEE@04ooooo`03o`000?oooooooooo0?oo
oooo<oooool000gooooo00Co0000onk^k_o^k^ko00001_ooool00ol0003oooooooooo`04ooooo`03
o`000?o^k^kooooo00Sooooo00?ok^k^o`000?o^k^h00_ooool01_l0003ogMgMooooooooooook^k^
o`000?oooooo=Oooool000gooooo00CoIVIVoiRHV?n7QhOoIVIV1?ooool00ol@413o0000o`000006
ooooo`03oeEEEOmgMgOooooo00Sooooo00Co410@o`000?l0003ooooo0_l000001Ol@413ooooooooo
oomgMgOoEEEE0?oooooo=Oooool000gooooo00Coc<c<odA4A?lQ8B7ogMgM3Oooool00ooMgMgo410@
onk^kP0@ooooo`03onk^k_l@413ogMgM0?oooooo=Oooool000cooooo00Co410@o`000?l0003o<S8b
1oooool00ol0003oooooooooo`05ooooo`03ogMgMomVIVKooooo00oooooo00?oIVIVogMgMoooool0
ooooooleooooo`005oooool00ol@413oooooooooo`3oooooodoooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.912152, -0.461634, \
0.0336298, 0.00700169}}]
}, Open  ]],

Cell[TextData[{
  "\tAs one moves away from the left turning point  toward increasing ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " values, one can replace the exact Airy function solution, Eq. ",
  ButtonBox["(6.3.25)",
    ButtonData:>"(6.3.25)",
    ButtonStyle->"Hyperlink"],
  " by the asymptotic solution, Eq. ",
  ButtonBox["(6.3.26)",
    ButtonData:>"(6.3.26)",
    ButtonStyle->"Hyperlink"],
  ", taking ",
  Cell[BoxData[
      \(TraditionalForm\`y = \[Alpha]\_L\^\(1/3\)\ \((x - x\_L)\)\)]],
  ": "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\(\[Psi]\_n\)(x)\), " ", "~", 
            FractionBox[
              RowBox[{Cell[TextData[Cell[BoxData[
                    \(TraditionalForm\`C\_\(1\ L\)\)]]]], 
                " "}], \(\(\@\[Pi]\)[\[Alpha]\_L\^\(1/3\)\ \((x - 
                          x\_L)\)]\^\(1/
                    4\)\)]}], \(cos(\(2\/3\) \[Alpha]\_L\^\(1/2\)\ \((x - \
x\_L)\)\^\(3/2\) - \[Pi]/4)\)}], TraditionalForm]]],
  ",    ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\_L\^\(1/3\)\ \((x - x\_L)\) \[GreaterTilde] 
        3. \)]]
}], "NE3",
  CellTags->"(6.3.27)"],

Cell[TextData[{
  "However, comparing to the form of ",
  Cell[BoxData[
      \(TraditionalForm\`k(x)\)]],
  " near the left turning point, Eq. ",
  ButtonBox["(6.3.24)",
    ButtonData:>"(6.3.24)",
    ButtonStyle->"Hyperlink"],
  ", we see that Eq. ",
  ButtonBox["(6.3.27)",
    ButtonData:>"(6.3.27)",
    ButtonStyle->"Hyperlink"],
  " can be written as"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\(\[Psi]\_n\)(x)\), " ", "~", 
            FractionBox[
              RowBox[{Cell[TextData[Cell[BoxData[
                    \(TraditionalForm\`C\_\(1\ L\)\)]]]], 
                " ", \(\[Alpha]\_L\^\(1/12\)\)}], \(\(\@\[Pi]\)[\(k\_n\)(
                      x)]\^\(1/
                    4\)\)]}], \(cos(\[Integral]\_\(x\_L\)\%x\(\( k\_n\)(
                    x)\) \[DifferentialD]x - \[Pi]/4)\)}], 
        TraditionalForm]]],
  ",   ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\_L\^\(1/3\)\ \((x - x\_L)\) \[GreaterTilde] 
        3. \)]]
}], "NE3",
  CellTags->"(6.3.28)"],

Cell[TextData[{
  "Furthermore, this result is identical to the WKB expression for the mode, \
Eq. ",
  ButtonBox["(6.3.22)",
    ButtonData:>"(6.3.22)",
    ButtonStyle->"Hyperlink"],
  ", provided that we set ",
  Cell[BoxData[
      \(TraditionalForm\`A = \(\(B\)\(=\)\)\)]],
  Cell[BoxData[
      FormBox[
        RowBox[{Cell[TextData[Cell[BoxData[
              \(TraditionalForm\`C\_\(1\ L\)\)]]]], 
          " ", \(\[Alpha]\_L\^\(1/12\)/2\), \(\@\[Pi]\)}], 
        TraditionalForm]]],
  ", and take  a lower bound in the integrals to be ",
  Cell[BoxData[
      \(TraditionalForm\`x\_L\)]],
  ". Thus, we have matched the WKB expression for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_n\)]],
  ",",
  " valid for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(\ \)\)\)]],
  " far from the turning points, to the Airy expression, valid near the left \
turning point."
}], "Text"],

Cell[TextData[{
  "\t On the other hand, we can also match the WKB solution to the Airy \
solution near the right turning point, and this provides us with a criterion \
to determine the eigenvalues. Replacing Eq. ",
  ButtonBox["(6.3.23)",
    ButtonData:>"(6.3.23)",
    ButtonStyle->"Hyperlink"],
  " by its asymptotic form as ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " moves away from the right turning point, we obtain "
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Psi]\_n\)(
            x)\)\ ~\(1\/\(\@\[Pi]\)[\[Alpha]\_R\^\(1/3\)\ \((x\_R - \
x)\)]\^\(1/4\)\) \(cos(\(2\/3\) \[Alpha]\_R\^\(1/2\)\ \((x\_R - x)\)\^\(3/2\) \
- \[Pi]/4)\), \ \ \ \ \[Alpha]\_R\^\(1/3\)\ \((x\_R - x)\) \[GreaterTilde] 
        3\)]]
}], "NE3",
  CellTags->"(6.3.29)"],

Cell[TextData[{
  "This expression can also be matched to the WKB form for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\(\[Psi]\_n\)(x)\), " ", "~", 
            FractionBox[
              RowBox[{Cell[TextData[Cell[BoxData[
                    \(TraditionalForm\`C\_\(1\ R\)\)]]]], 
                " ", \(\[Alpha]\_R\^\(1/12\)\)}], \(\(\@\[Pi]\)[\(k\_n\)(
                      x)]\^\(1/
                    4\)\)]}], \(cos(\(-\(\[Integral]\_\(x\_R\)\%x\(\( k\_n\)(
                      x)\) \[DifferentialD]x\)\) + \[Pi]/4)\)}], 
        TraditionalForm]]],
  ",     ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\_R\^\(1/3\)\ \((x\_R - x)\) \[GreaterTilde] 
        3\)]],
  "."
}], "NE3",
  CellTags->"(6.3.30)"],

Cell[TextData[{
  "The regions of validity of Eqs. ",
  ButtonBox["(6.3.29)",
    ButtonData:>"(6.3.29)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(6.3.30)",
    ButtonData:>"(6.3.30)",
    ButtonStyle->"Hyperlink"],
  " overlap, so these WKB expressions must be identical. This is only \
possible if the arguments of the cosines differ by integer multiples of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\)]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{Cell[TextData[Cell[BoxData[
                \(TraditionalForm\`C\_\(1\ R\)\)]]]], 
            " ", \(\[Alpha]\_R\^\(1/12\)\)}], "=", 
          RowBox[{
            RowBox[{"\[PlusMinus]", Cell[TextData[Cell[BoxData[
                  \(TraditionalForm\`C\_\(1\ L\)\)]]]]}], 
            " ", \(\[Alpha]\_L\^\(1/12\)\)}]}], TraditionalForm]]],
  ", with the + sign for ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
          "even", " ", "multiples", " ", "of", " ", "\[Pi]", " ", "and", " ", 
            "the", " ", Cell[TextData[Cell[BoxData[
                \(TraditionalForm\`-\)]]]]}]}], TraditionalForm]]],
  " sign for odd multiples. Therefore, "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Integral]\_\(x\_L\)\%x\(\( k\_n\)(
              x)\) \[DifferentialD]x - \[Pi]/
          4 = \(\(-\(\[Integral]\_\(x\_R\)\%x\(\( k\_n\)(
                  x)\) \[DifferentialD]x\)\) + \[Pi]/4 + \ 
          n\ \[Pi] = \(-\(\[Integral]\_\(x\_L\)\%\(x\_R\)\ \(\(k\_n\)(
                  x)\) \[DifferentialD]x\)\)\  + \[Integral]\_\(x\_L\)\%x\(\( 
                    k\_n\)(x)\) \[DifferentialD]x + \[Pi]/4 + \ 
          n\ \[Pi]\)\)]]], "UNNEQ"],

Cell["Rearranging the terms in this equation, we are left with ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(x\_L\)\%\(x\_R\)\ \(\(k\_n\)(
              x)\) \[DifferentialD]x = \ \[Pi](n\  + 1/2), \ \ \ \ n = 0, 1, 
      2,  ... \)]],
  "."
}], "NE3",
  CellTags->"(6.3.31)"],

Cell[TextData[{
  "\tEquation ",
  ButtonBox["(6.3.31)",
    ButtonData:>"(6.3.31)",
    ButtonStyle->"Hyperlink"],
  " is the expression we have been looking for. It can be used to determine  \
the WKB eigenvalues ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n\)]],
  " associated with Eq. ",
  ButtonBox["(6.3.21)",
    ButtonData:>"(6.3.21)",
    ButtonStyle->"Hyperlink"],
  ". Note that the integral on the ",
  "left-hand",
  " side of Eq. ",
  ButtonBox["(6.3.31)",
    ButtonData:>"(6.3.31)",
    ButtonStyle->"Hyperlink"],
  " must be larger than zero, so we require that ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0, 1, 2,  ... \)]],
  ". Then ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0\)]],
  " corresponds to the ground state, ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1\)]],
  " to the first excited state, etc."
}], "Text",
  CellTags->"i:45"],

Cell[TextData[{
  " \tIt is instructive to compare Eq. ",
  ButtonBox["(6.3.31)",
    ButtonData:>"(6.3.31)",
    ButtonStyle->"Hyperlink"],
  " to the expression for WKB Dirichlet mode frequencies of a string \
stretched between points ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", Cell[TextData[Cell[BoxData[
              \(TraditionalForm\`0\)]]]]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%L\(\( k\_n\)(
              x)\) \[DifferentialD]x = \ n\ \[Pi], \ \ n = 1, 2,  ... \)]],
  ". [See Eq. ",
  ButtonBox["(6.3.17)",
    ButtonData:>"(6.3.17)",
    ButtonStyle->"Hyperlink"],
  ".] The ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]/2\)]],
  " difference in the ",
  "right-hand",
  " sides of these expressions arises from the difference in the boundary \
conditions in these two cases; for a string the eigenmodes go to zero at the \
ends, but for the quantum particle the eigenmodes  are finite at the turning \
points."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example: Quantum Harmonic Oscillator Frequencies", "Section",
  CellTags->"c:42"],

Cell[TextData[{
  "\tAs an example of the use of Eq. ",
  ButtonBox["(6.3.31)",
    ButtonData:>"(6.3.31)",
    ButtonStyle->"Hyperlink"],
  ", let's apply it to determine the eigenmodes of the dimensionless quantum \
harmonic oscillator, Eq. ",
  ButtonBox["(6.3.12)",
    ButtonData:>"(6.3.12)",
    ButtonStyle->"Hyperlink"],
  ". We already know that the energy levels for this system are ",
  Cell[BoxData[
      \(TraditionalForm\`E\_\(\(n\)\(\ \)\) = \((n + 1/2)\)\)]],
  ".  In the WKB approximation, we determine these energy levels by \
performing the integral in Eq. ",
  ButtonBox["(6.3.31)",
    ButtonData:>"(6.3.31)",
    ButtonStyle->"Hyperlink"],
  ". The turning points are determined by solving ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n = \(V(x) = x\^2/2\)\)]],
  ", which implies that ",
  Cell[BoxData[
      \(TraditionalForm\`x\_L = \ \(\(-\@\(2  E\_n\)\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\_R\)\(=\)\(\ \)\(\@\(2  E\_n\)\)\(\ \)\)\)]],
  ". Then ",
  Cell[BoxData[
      \(TraditionalForm\`\(k\_n\)(x) = \@\(2 \((E\_n - \ x\^2/2)\)\)\)]],
  ", and Eq. ",
  ButtonBox["(6.3.31)",
    ButtonData:>"(6.3.31)",
    ButtonStyle->"Hyperlink"],
  " becomes"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\@\(2  E\_n\)\)\%\(\@\(2  E\_n\)\)\(\
\@\(2 \((E\_n - \ x\^2/2)\)\)\) \[DifferentialD]x = \ 
        n\ \[Pi]\  + \ \[Pi]/2\)]],
  "."
}], "NE3",
  CellTags->"(6.3.32)"],

Cell[TextData[{
  "The integral on the ",
  "left-hand",
  " side can be performed analytically using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[
      Integrate[\@\(2 \((\[Epsilon]\_n - \ x\^2/2)\)\), {x, \(-\@\(2  \
\[Epsilon]\_n\)\), \@\(2  \[Epsilon]\_n\)}], \ \ \[Epsilon]\_n > \ 
        0]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.179"],

Cell[BoxData[
    \(\[Pi]\ \[Epsilon]\_n\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Using this result for the integral in Eq. ",
  ButtonBox["(6.3.32)",
    ButtonData:>"(6.3.32)",
    ButtonStyle->"Hyperlink"],
  " we obtain ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(E\_n\)\(=\)\((n + 1/2)\)\(\ \)\)\)]],
  ", which precisely matches the exact result for the eigenvalues of the \
harmonic oscillator. However, this is a lucky coincidence. For general \
potentials, the match is not exact, although it is good if the potential is \
slowly varying with respect to the wavelength of the eigenmode."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Shooting Method for Problems with Turning Points", "Section",
  CellTags->{"i:46", "c:43"}],

Cell[TextData[{
  "\tWe now use the WKB eigenvalues as an initial guess in the shooting \
method, in order to determine the eigenmodes.  For a symmetric potential well \
where ",
  Cell[BoxData[
      \(TraditionalForm\`V(\(-x\)) = V(x)\)]],
  ", this task is simplified somewhat, because the modes break into even and \
odd sets. The odd modes correspond to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(n\)\(\ \)\)\)]],
  "odd and vanish at the origin, and this provides a boundary condition in \
the shooting.  For the even modes, with ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(n\)\(\ \)\)\)]],
  "even, the slope of the eigenmode vanishes at the origin, so this is the \
boundary condition used for even modes. The other boundary condition is that \
",
  Cell[BoxData[
      \(TraditionalForm\`x \[Rule] 0\)]],
  " well beyond the turning point. For general potentials without symmetry, \
one must shoot from a point well to the left of the left turning point to a \
point well beyond the right turning point, setting the eigenmode equal to \
zero at these points. (A slightly more accurate method of setting the \
boundary conditions is discussed in Exercise (7). )"
}], "Text"],

Cell[TextData[{
  "\tBelow, we use the shooting method to determine the eigenmodes of the \
dimensionless quantum harmonic oscillator, Eq. ",
  ButtonBox["(6.3.12)",
    ButtonData:>"(6.3.12)",
    ButtonStyle->"Hyperlink"],
  ", using the symmetry of the modes."
}], "Text"],

Cell["\<\
\tFirst, we define the right-hand turning point as a function of \
the energy:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(xR[\[Epsilon]_]\  = \ Sqrt[2\ \[Epsilon]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.180"],

Cell[BoxData[
    \(\@2\ \@\[Epsilon]\)], "Output"]
}, Open  ]],

Cell["The potential is", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(V[x] = 1/2\ x^2\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.181"],

Cell[BoxData[
    \(x\^2\/2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We now shoot toward the origin,  starting to the right of the right \
turning point at ",
  Cell[BoxData[
      \(TraditionalForm\`x = \ x\_1\)]],
  ". We choose ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  " sufficiently far to the right of the right turning point so that the \
eigenmode is nearly zero there. "
}], "Text"],

Cell[BoxData[{
    \(\(x1[\[Epsilon]_]\  = \ xR[\[Epsilon]]\  + \ 7;\)\), "\n", 
    \(Sol[\[Epsilon]_] := \(NDSolve[{\(-\ \(1\/2\)\)\ D[\[Psi][x], {x, 2}] + 
                V[x] \[Psi][x] \[Equal] \[Epsilon]\ \[Psi][x], \[Psi][
                x1[\[Epsilon]]] \[Equal] 
              0, \(\[Psi]'\)[
                x1[\[Epsilon]]] \[Equal] \(-10\^\(-11\)\)}, \[Psi], {x, 
            x1[\[Epsilon]], 0}, AccuracyGoal \[Rule] 13, 
          PrecisionGoal \[Rule] \ 13, 
          MaxSteps \[Rule] 10000]\)[\([1]\)]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.182"],

Cell[TextData[{
  "We then define ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Psi]end[\[Epsilon]]\),
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  " as the value of the solution at the origin. This function is used for odd \
modes:"
}], "Text"],

Cell[BoxData[
    \(\[Psi]end[\[Epsilon]_] := \ \[Psi][0] /. Sol[\[Epsilon]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.183"],

Cell[TextData[{
  "For even modes, we define the derivative at the origin as ",
  StyleBox["\[Psi]primeend",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\[Psi]primeend[\[Epsilon]_] := \ \(\[Psi]'\)[0] /. 
        Sol[\[Epsilon]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.184"],

Cell[TextData[{
  "The energy eigenvalue is then determined by finding the value of \
\[Epsilon] that makes ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[Psi]end",
            FontFamily->"Courier",
            FontWeight->"Bold"], "=", "0"}], TraditionalForm]]],
  " for odd modes and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[Psi]primeend",
            FontFamily->"Courier",
            FontWeight->"Bold"], "=", "0"}], TraditionalForm]]],
  " for even modes. We use the WKB method eigenvalue as the initial guess in \
",
  StyleBox["FindRoot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " :"
}], "Text"],

Cell[BoxData[{
    \(\(\(\[Epsilon]WKB[n_]\  = \ n\  + 1/2\ ;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Epsilon]shooting[
          n_]\  := \ \((\[Epsilon] /. \(FindRoot[\[Psi]primeend[\[Epsilon]] \
\[Equal] 0, {\[Epsilon], 1.01  \[Epsilon]WKB[n], 1.1  \[Epsilon]WKB[n]}, 
                  MaxIterations \[Rule] 40]\)[\([1]\)]\ )\) /; \ 
          n/2\ \  \[Element] Integers;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\[Epsilon]shooting[
        n_]\  := \ \((\[Epsilon] /. \(FindRoot[\[Psi]end[\[Epsilon]] \[Equal] 
                  0, {\[Epsilon], 1.01  \[Epsilon]WKB[n], 
                  1.1  \[Epsilon]WKB[n]}, 
                MaxIterations \[Rule] 40]\)[\([1]\)]\ )\) /; \ \((n + 1)\)/
            2\ \  \[Element] Integers\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.185"],

Cell["\<\
The first few shooting method energy levels are given by the \
following list:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[FullForm[\[Epsilon]shooting[n]], {n, 0, 12, 1}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.186"],

Cell[BoxData[
    \(FindRoot::"frmp" \(\(:\)\(\ \)\) 
      "Machine precision is insufficient to achieve the accuracy \
\!\(1.0000000000000006`*^-6\)."\)], "Message"],

Cell[BoxData[
    \(FindRoot::"frmp" \(\(:\)\(\ \)\) 
      "Machine precision is insufficient to achieve the accuracy \
\!\(1.0000000000000006`*^-6\)."\)], "Message"],

Cell[BoxData[
    \(FindRoot::"frsec" \(\(:\)\(\ \)\) 
      "Secant method failed to converge to the prescribed accuracy after \
\!\(40\) iterations."\)], "Message"],

Cell[BoxData[
    \(FindRoot::"frmp" \(\(:\)\(\ \)\) 
      "Machine precision is insufficient to achieve the accuracy \
\!\(1.0000000000000006`*^-6\)."\)], "Message"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(FindRoot :: \"frmp\"\) will be suppressed during \
this calculation."\)], "Message"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          StyleBox["0.5000000000342457`",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm], ",", 
        TagBox[
          StyleBox["1.4999999999999425`",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm], ",", 
        TagBox[
          StyleBox["2.5000000000004245`",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm], ",", 
        TagBox[
          StyleBox["3.500000000000405`",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm], ",", 
        TagBox[
          StyleBox["4.499999999993332`",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm], ",", 
        TagBox[
          StyleBox["5.499999999995752`",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm], ",", 
        TagBox[
          StyleBox["6.499999999994303`",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm], ",", 
        TagBox[
          StyleBox["7.499999999989863`",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm], ",", 
        TagBox[
          StyleBox["8.499999999996888`",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm], ",", 
        TagBox[
          StyleBox["9.49999999999108`",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm], ",", 
        TagBox[
          StyleBox["10.499999999990823`",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm], ",", 
        TagBox[
          StyleBox["11.49999999999825`",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm], ",", 
        TagBox[
          StyleBox["12.499999999990976`",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The error messages occur because the solution is increasing exponentially \
as one shoots toward smaller ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(,\)\)\)]],
  " until one hits the turning point, where the solution begins to oscillate. \
This means that the point ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  "where one starts the numerical integration must be chosen carefully: Too \
far beyond the turning point, and the solution blows up before the turning \
point is reached. Too close to the turning point, and setting the solution \
equal to zero initially is not a good approximation.  "
}], "Text"],

Cell[TextData[{
  "\tThe eigenvalues found using the shooting method are very accurate, \
equaling the exact eigenvalues ",
  Cell[BoxData[
      \(TraditionalForm\`n + 1/2\)]],
  " to 10 significant figures. Such accuracy is difficult to achieve in the \
Galerkin and grid methods, particularly for high",
  "-order",
  " modes."
}], "Text"],

Cell["\<\
\tThe eigenmodes can now be found numerically,  using these \
eigenvalues:\
\>", "Text"],

Cell[BoxData[
    \(\[Psi]shooting[
        n_]\  := \(\[Psi]shooting[n]\  = \ \ \[Psi] /. 
          Sol[\[Epsilon]shooting[n]]\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.187"],

Cell[TextData[{
  "We use double equal signs so that the eigenmodes are evaluated only once. \
In order to extend the definition to ",
  Cell[BoxData[
      \(TraditionalForm\`x < 0\)]],
  ", we use the symmetry of the modes:"
}], "Text"],

Cell[BoxData[{
    \(\(\[Psi]sh[x_, n_] := \ \(\[Psi]shooting[n]\)[x]\  /; \ 
          x \[GreaterEqual] \ 0;\)\), "\n", 
    \(\(\[Psi]sh[x_, n_] := \ \(-\(\[Psi]shooting[n]\)[\(-x\)]\)\  /; \ 
          x < \ 0\  && \ \((n + 1)\)/2\  \[Element] Integers;\)\), "\n", 
    \(\[Psi]sh[x_, n_] := \ \(\[Psi]shooting[n]\)[\(-x\)]\  /; \ 
        x < \ 0\  && \ n/2\  \[Element] Integers\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.188"],

Cell[TextData[{
  "The eigenmodes can now be evaluated and plotted: see Cell ",
  ButtonBox["6.189",
    ButtonData:>"Cell 6.189",
    ButtonStyle->"Hyperlink"],
  ". One can see that the computed eigenfunctions have very large amplitude \
because we started the numerical integration well beyond the right turning \
point, at ",
  Cell[BoxData[
      \(TraditionalForm\`x\_R + 7\)]],
  ".  The reader is invited to vary this distance, in order to observe the \
effect this has on the accuracy of the eigenvalues and on the eigenmodes \
themselves. See Exercise (7) for a more accurate method of setting the \
bondary conditions. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        Plot[Evaluate[\[Psi]sh[x, n]], {x, \(-8\), 8}, PlotRange \[Rule] All, 
          PlotLabel \[Rule] \*"\"\<Shooting method \!\(\[Psi]\_n\)(x), \
n=\>\"" <> ToString[n]], {n, 0, 5}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.189"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0595238 0.0147151 0.01167 [
[.05357 .00222 -12 -9 ]
[.05357 .00222 12 0 ]
[.20238 .00222 -6 -9 ]
[.20238 .00222 6 0 ]
[.35119 .00222 -12 -9 ]
[.35119 .00222 12 0 ]
[.64881 .00222 -9 -9 ]
[.64881 .00222 9 0 ]
[.79762 .00222 -3 -9 ]
[.79762 .00222 3 0 ]
[.94643 .00222 -9 -9 ]
[.94643 .00222 9 0 ]
[.4875 .13141 -12 -4.5 ]
[.4875 .13141 0 4.5 ]
[.4875 .24811 -12 -4.5 ]
[.4875 .24811 0 4.5 ]
[.4875 .36481 -12 -4.5 ]
[.4875 .36481 0 4.5 ]
[.4875 .48151 -12 -4.5 ]
[.4875 .48151 0 4.5 ]
[.4875 .59821 -12 -4.5 ]
[.4875 .59821 0 4.5 ]
[.5 .63053 -79.625 0 ]
[.5 .63053 79.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05357 .01472 m
.05357 .02097 L
s
[(-7.5)] .05357 .00222 0 1 Mshowa
.20238 .01472 m
.20238 .02097 L
s
[(-5)] .20238 .00222 0 1 Mshowa
.35119 .01472 m
.35119 .02097 L
s
[(-2.5)] .35119 .00222 0 1 Mshowa
.64881 .01472 m
.64881 .02097 L
s
[(2.5)] .64881 .00222 0 1 Mshowa
.79762 .01472 m
.79762 .02097 L
s
[(5)] .79762 .00222 0 1 Mshowa
.94643 .01472 m
.94643 .02097 L
s
[(7.5)] .94643 .00222 0 1 Mshowa
.125 Mabswid
.08333 .01472 m
.08333 .01847 L
s
.1131 .01472 m
.1131 .01847 L
s
.14286 .01472 m
.14286 .01847 L
s
.17262 .01472 m
.17262 .01847 L
s
.23214 .01472 m
.23214 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.29167 .01472 m
.29167 .01847 L
s
.32143 .01472 m
.32143 .01847 L
s
.38095 .01472 m
.38095 .01847 L
s
.41071 .01472 m
.41071 .01847 L
s
.44048 .01472 m
.44048 .01847 L
s
.47024 .01472 m
.47024 .01847 L
s
.52976 .01472 m
.52976 .01847 L
s
.55952 .01472 m
.55952 .01847 L
s
.58929 .01472 m
.58929 .01847 L
s
.61905 .01472 m
.61905 .01847 L
s
.67857 .01472 m
.67857 .01847 L
s
.70833 .01472 m
.70833 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.76786 .01472 m
.76786 .01847 L
s
.82738 .01472 m
.82738 .01847 L
s
.85714 .01472 m
.85714 .01847 L
s
.8869 .01472 m
.8869 .01847 L
s
.91667 .01472 m
.91667 .01847 L
s
.02381 .01472 m
.02381 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .13141 m
.50625 .13141 L
s
[(10)] .4875 .13141 1 0 Mshowa
.5 .24811 m
.50625 .24811 L
s
[(20)] .4875 .24811 1 0 Mshowa
.5 .36481 m
.50625 .36481 L
s
[(30)] .4875 .36481 1 0 Mshowa
.5 .48151 m
.50625 .48151 L
s
[(40)] .4875 .48151 1 0 Mshowa
.5 .59821 m
.50625 .59821 L
s
[(50)] .4875 .59821 1 0 Mshowa
.125 Mabswid
.5 .03806 m
.50375 .03806 L
s
.5 .0614 m
.50375 .0614 L
s
.5 .08473 m
.50375 .08473 L
s
.5 .10807 m
.50375 .10807 L
s
.5 .15475 m
.50375 .15475 L
s
.5 .17809 m
.50375 .17809 L
s
.5 .20143 m
.50375 .20143 L
s
.5 .22477 m
.50375 .22477 L
s
.5 .27145 m
.50375 .27145 L
s
.5 .29479 m
.50375 .29479 L
s
.5 .31813 m
.50375 .31813 L
s
.5 .34147 m
.50375 .34147 L
s
.5 .38815 m
.50375 .38815 L
s
.5 .41149 m
.50375 .41149 L
s
.5 .43483 m
.50375 .43483 L
s
.5 .45817 m
.50375 .45817 L
s
.5 .50485 m
.50375 .50485 L
s
.5 .52819 m
.50375 .52819 L
s
.5 .55153 m
.50375 .55153 L
s
.5 .57487 m
.50375 .57487 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -140.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Shooting) show
117.000 13.000 moveto
(method) show
159.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
165.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
170.250 13.000 moveto
(H) show
176.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
182.250 13.000 moveto
(L) show
188.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
200.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
206.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
212.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
218.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .01472 m
.02846 .01472 L
.03279 .01472 L
.03527 .01472 L
.03754 .01472 L
.04015 .01472 L
.04262 .01472 L
.04502 .01472 L
.04756 .01472 L
.04973 .01472 L
.05212 .01472 L
.05469 .01472 L
.05745 .01472 L
.06006 .01472 L
.06244 .01472 L
.06504 .01472 L
.0678 .01472 L
.07041 .01472 L
.07277 .01472 L
.07556 .01472 L
.07858 .01472 L
.08143 .01472 L
.08405 .01472 L
.08651 .01472 L
.08881 .01472 L
.09133 .01472 L
.09403 .01472 L
.09686 .01472 L
.09955 .01472 L
.10196 .01472 L
.10458 .01472 L
.10691 .01472 L
.10943 .01472 L
.1118 .01472 L
.11398 .01472 L
.11639 .01472 L
.11903 .01472 L
.12179 .01472 L
.12435 .01472 L
.12709 .01472 L
.12968 .01472 L
.132 .01472 L
.13451 .01472 L
.13725 .01472 L
.14016 .01472 L
.14264 .01472 L
.14536 .01472 L
.14786 .01472 L
.15057 .01472 L
.15314 .01472 L
Mistroke
.15552 .01472 L
.16002 .01472 L
.16253 .01472 L
.16481 .01472 L
.16733 .01472 L
.16998 .01472 L
.1729 .01472 L
.17557 .01472 L
.18041 .01472 L
.18315 .01472 L
.1857 .01472 L
.19072 .01472 L
.19356 .01472 L
.19618 .01472 L
.20099 .01472 L
.20342 .01472 L
.20609 .01472 L
.21071 .01472 L
.2133 .01472 L
.21568 .01472 L
.22006 .01472 L
.22466 .01473 L
.22724 .01473 L
.22968 .01473 L
.23423 .01474 L
.23914 .01475 L
.2419 .01476 L
.24444 .01477 L
.2487 .01479 L
.25338 .01483 L
.25826 .01487 L
.26282 .01493 L
.26782 .01501 L
.27326 .01513 L
.27839 .01529 L
.28315 .01549 L
.28742 .01572 L
.29214 .01604 L
.29707 .01648 L
.3017 .017 L
.30639 .01768 L
.31151 .01863 L
.31687 .0199 L
.32186 .0214 L
.3308 .02507 L
.3358 .02782 L
.34035 .03085 L
.35032 .03965 L
.35952 .05105 L
.36961 .06815 L
Mistroke
.3803 .09265 L
.38973 .12053 L
.39985 .15766 L
.41816 .24345 L
.43788 .35619 L
.4594 .48118 L
.46938 .53038 L
.47486 .55308 L
.48001 .57105 L
.48483 .58452 L
.48737 .59021 L
.49004 .59514 L
.4923 .59842 L
.4935 .59982 L
.49478 .60106 L
.49596 .60197 L
.49703 .60259 L
.49811 .60303 L
.49913 .60326 L
.50027 .60332 L
.5015 .60314 L
.50266 .60274 L
.50373 .60217 L
.50491 .60133 L
.5062 .60014 L
.5088 .59693 L
.51137 .59269 L
.51411 .58701 L
.51906 .57392 L
.52871 .53868 L
.53748 .49747 L
.57748 .26699 L
.59582 .17584 L
.60623 .13445 L
.61597 .10294 L
.62556 .07833 L
.63586 .05822 L
.64151 .0496 L
.64686 .04277 L
.65214 .03717 L
.65691 .03295 L
.66653 .02647 L
.67181 .02385 L
.67677 .02187 L
.68562 .01927 L
.6906 .01821 L
.69517 .01744 L
.69989 .01681 L
.70494 .01628 L
.70971 .0159 L
Mistroke
.71405 .01563 L
.71915 .01539 L
.72468 .01519 L
.72991 .01505 L
.73473 .01496 L
.73939 .0149 L
.7444 .01484 L
.74912 .01481 L
.75345 .01478 L
.7585 .01476 L
.76136 .01475 L
.76402 .01475 L
.76888 .01474 L
.7716 .01473 L
.77407 .01473 L
.77894 .01473 L
.7814 .01472 L
.78409 .01472 L
.78639 .01472 L
.78886 .01472 L
.79331 .01472 L
.79599 .01472 L
.7989 .01472 L
.80147 .01472 L
.8042 .01472 L
.80665 .01472 L
.80935 .01472 L
.81413 .01472 L
.81647 .01472 L
.81904 .01472 L
.82154 .01472 L
.82421 .01472 L
.82672 .01472 L
.829 .01472 L
.83346 .01472 L
.83614 .01472 L
.83861 .01472 L
.84132 .01472 L
.84419 .01472 L
.84668 .01472 L
.84901 .01472 L
.85157 .01472 L
.85432 .01472 L
.85686 .01472 L
.85957 .01472 L
.86213 .01472 L
.86444 .01472 L
.86717 .01472 L
.87013 .01472 L
.87292 .01472 L
Mistroke
.87548 .01472 L
.8779 .01472 L
.88015 .01472 L
.88262 .01472 L
.88526 .01472 L
.88804 .01472 L
.89066 .01472 L
.89302 .01472 L
.89558 .01472 L
.89792 .01472 L
.90044 .01472 L
.90282 .01472 L
.905 .01472 L
.90742 .01472 L
.91006 .01472 L
.91282 .01472 L
.91538 .01472 L
.91813 .01472 L
.92071 .01472 L
.92304 .01472 L
.92555 .01472 L
.9283 .01472 L
.9312 .01472 L
.93368 .01472 L
.9364 .01472 L
.93887 .01472 L
.94155 .01472 L
.94409 .01472 L
.94644 .01472 L
.94854 .01472 L
.95087 .01472 L
.95331 .01472 L
.95559 .01472 L
.95811 .01472 L
.96076 .01472 L
.96302 .01472 L
.9655 .01472 L
.96817 .01472 L
.97104 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008oooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM02;ooooo00GoA4A4o`000?l0003o<S8bomgMg@0Pooooo`Go00001Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@12ooooo`Go00001Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@0Qooooo`05odA4A?l0003o0000oc8b<_oMgMd08oooool00ol0003o
k^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01oooooo000Sooooo`03
oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo02Cooooo00?oMgMgoc8b<_oo
ool07oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
047ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0S
ooooo`03ogMgMolb<S;ooooo02;ooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool07_ooool001Wooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000oooo
ooooool05oooool6o`0000Oooooo00?o0000ooooooooool05_ooool6o`0000?ooooo00?oV9RHob4Q
8Oo^k^h04Oooool00ol0003oooooooooo`11ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0Qooooo`03ojVYZOmEEEGooooo013ooooo00?o0000oooo
ooooool07Oooool002Cooooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8booooo`0Tooooo`03
ogMgMolb<S;ooooo027ooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`13ooooo`03
oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool08oooool00omgMgOo<S8booooo`0Sooooo`03
ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool07_ooool002Cooooo00?oEEEEolc<c?ooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<02;ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Soooo
o`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c015ooooo`03ogMgMomVIVKo
oooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Qooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
9?ooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07oooool002Cooooo
00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0Vooooo`03ojVYZOmgMgOooooo00_ooooo
00?o0000ooooooooool08Oooool0027ooooo00Go410@oooooooooooooooooc8b<P0<ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool08_ooool01Ol0003o^[ZjoooooonHV9So410@00co
oooo00?o0000ooooooooool0A?ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0Sooooo`05oa0@4?oooooooooooooooolb<S803?ooool0
0ol0003oooooooooo`0Qooooo`008Oooool5o`0000cooooo1?l0000Sooooo`Co00008Oooool01OnH
V9So410@o`000?lQ8B7oc<c<00cooooo1?l00013ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?oo
ool4o`0002;ooooo1?l0000Rooooo`Go00003?ooool4o`00023ooooo003oooooofWooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`00
0?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo000Hoooooooo0000>?l0000I
ooooo`007oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool9o`0000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00Co0000oooooooooooooooo2?l00007ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Nooooo`00:?ooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo023ooooo1?l00007ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`05ooooo`Go00008Oooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo02Oooooo001nooooo`;o0000<oooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo07gooooo0020ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0<?ooool2o`00083ooooo0021ooooo`;o0000<?ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo083ooooo0023ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0;Oooool2o`0008?ooooo0024ooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`23ooooo`00QOooool00ol0003oooooooooo`0[ooooo`;o
0000;Oooool00ol0003oooooooooo`23ooooo`00QOooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0Q?ooool008Kooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08Gooooo0026ooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`26ooooo`00Qoooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Q_ooool008Oo
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo08Oo
oooo0028ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`28ooooo`00ROooool00ol0003oooooooooo`0Wooooo`;o0000:?ooool00ol0003ooooooooo
o`28ooooo`00R_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0ROooool008_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo08Wooooo002;ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`2:ooooo`00S?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0R_ooool008cooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo08_ooooo002=ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2;ooooo`00SOooool00ol0
003oooooooooo`0Sooooo`;o00009?ooool00ol0003oooooooooo`2<ooooo`00SOooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0S?ooool008kooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo08cooooo
002>ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`2=ooooo`00Soooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool0SOooool008oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo08gooooo002?ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`2>ooooo`00T?ooool00ol0003oooooooooo`0Pooooo`;o0000
8_ooool00ol0003oooooooooo`2>ooooo`00T?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0Soooool0093ooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo08oooooo002Aooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2?ooooo`00TOooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0T?ooool0097ooooo
00?o0000ooooooooool03Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0T?ooool0097ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo093ooooo002Booooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo0ol0000N
ooooo`03o`000?oooooooooo097ooooo002Booooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`2Aooooo`00T_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0TOooool009;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo097ooooo002Cooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`2B
ooooo`00Toooool00ol0003oooooooooo`0;ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0T_ooool0
09?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
09;ooooo002Cooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`2Booooo`00U?ooool00ol0003oooooooooo`0Looooo`;o00007Oooool00ol0003ooooo
ooooo`2Cooooo`00U?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0Toooool009Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo09?ooooo002Dooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`2Cooooo`00UOooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0Toooool009Gooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo09Cooooo002Eooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`2Dooooo`00UOooool0
0ol0003oooooooooo`0Kooooo`;o00007?ooool00ol0003oooooooooo`2Dooooo`00U_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0U?ooool009Ko
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo09Go
oooo002Fooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`2Eooooo`00U_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0UOooool009Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo09Gooooo002Gooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`2Eooooo`00Uoooool00ol0003oooooooooo`0Iooooo`;o
00006_ooool00ol0003oooooooooo`2Fooooo`00Uoooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0U_ooool009Oooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo09Kooooo002Hooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2Fooooo`00V?ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0U_ooool009So
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo09Oo
oooo002Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`2Gooooo`00VOooool00ol0003oooooooooo`0Gooooo`;o00006Oooool00ol0003ooooooooo
o`2Gooooo`00VOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0Uoooool009Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo09Oooooo002Iooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`2Hooooo`00VOooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0V?ooool009[ooooo00?o0000ooooooooool00ooo
ool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0V?ooool009[ooooo00?o0000ooooooooool00oooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0V?ooool009[ooooo00?o0000ooooooooool01?ooool00onHV9So8B4Q
onk^kP04ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo09Sooooo002Jooooo`03o`000?oooooooooo00Gooooo00?oV9RHob4Q8Oo^k^h0
0oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000Fooooo`03o`000?oooooooooo09Wo
oooo002Jooooo`03o`000?oooooooooo00Kooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`2Iooooo`00
Voooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0VOooool009_ooooo
00?o0000ooooooooool00_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`06ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0VOooool009_o
oooo00?o0000ooooooooool00_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0VOooool0
09_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
09[ooooo002Kooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`2Jooooo`00Voooool00ol0003oooooooooo`0Eooooo`;o00005_ooool00ol0003ooooo
ooooo`2Jooooo`00W?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0V_ooool009cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo09[ooooo002Looooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`2Kooooo`00W?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0Voooool009cooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo09_ooooo002Looooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Kooooo`00WOooool0
0ol0003oooooooooo`0Cooooo`;o00005Oooool00ol0003oooooooooo`2Kooooo`00WOooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Voooool009go
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo09co
oooo002Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`2Looooo`00WOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0W?ooool009kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo09cooooo002Nooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`2Looooo`00W_ooool00ol0003oooooooooo`0Booooo`;o
00005?ooool00ol0003oooooooooo`2Looooo`00W_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0WOooool009kooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo09gooooo002Nooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`2Mooooo`00Woooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0WOooool009oo
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo09go
oooo002Oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`2Mooooo`00Woooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0W_ooool009oooooo00?o0000ooooooooool04Oooool2o`0001;ooooo00?o0000
ooooooooool0W_ooool009oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo09kooooo002Pooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`2Nooooo`00X?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool0W_ooool00:3ooooo00Go0000oa0@4?l0003o<S8b
olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo09kooooo002Pooooo`05o`000?nj^[[oooooogMgMolb<S800oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`2Ooooo
o`00X?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@4006
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Woooool00:3ooooo00Go0000oooo
ooooooooZJVYoa0@4003ooooo`05o`000?ooooooooooooooool000001_ooool3o`00013ooooo00?o
0000ooooooooool0Woooool00:7ooooo00Co0000oa0@4?l0003o^[Zj0oooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`2Oooooo`00XOoo
ool01?l0003ooooookZj^_lQ8B43ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo09oooooo002Pooooo`05oa0@4?l0003ooooookZj^_l0
00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`2Oooooo`00X?ooool01OnYZJWo0000o`000?l@413oZJVY00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0X?ooool0
0:7ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
0:3ooooo002Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`2Pooooo`00XOooool00ol0003oooooooooo`0?ooooo`;o00004?ooool00ol0003ooooo
ooooo`2Pooooo`00X_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0X?ooool00:;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo0:7ooooo002Rooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`2Qooooo`00X_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0XOooool00:;ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0:7ooooo002Rooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2Qooooo`00Xoooool0
0ol0003oooooooooo`0=ooooo`;o00003oooool00ol0003oooooooooo`2Qooooo`00Xoooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0X_ooool00:?o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:;o
oooo002Sooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`2Rooooo`00Xoooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0X_ooool00:?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo0:;ooooo002Sooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`2Rooooo`00Y?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0Xoooool00:Cooooo00?o0000ooooooooool0
3?ooool2o`0000gooooo00?o0000ooooooooool0Xoooool00:Cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0:?ooooo002Tooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2Sooooo`00Y?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Xoooool00:Co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0:?o
oooo002Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`2Tooooo`00YOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0Y?ooool00:Gooooo00?o0000ooooooooool02oooool2o`0000cooooo00?o0000
ooooooooool0Y?ooool00:Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo0:Cooooo002Uooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`2Tooooo`00YOooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0Y?ooool00:Gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0:Gooooo002Rooooo`;o000000Wo410@
ooooool0003oooooonk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo0:Gooooo002Sooooo`0:o`000?ooooooooooo`000?ooooooMgMgoiRHV?oooooo
V9RHogMgM`Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Uooooo`00X?ooool5
o`000004ooooool0003ooooooa0@40?ooooo00?o410@ooooooooool01?ooool3o`0000[ooooo00?o
0000ooooooooool0YOooool00:3ooooo00CoA4A4omgMgOoooooo00000_ooool00ol0003oooooo`00
0003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`2Uooooo`00X?ooool01?oMgMgoEEEEooooool00002ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0:Gooooo002Q
ooooo`03ogMgMoo<c<co000000?ooooo00?o0000oa0@4?ooool00_ooool00ol@413oooooooooo`04
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Y_ooool00:7ooooo00?ok^k^odA4
A?l000000oooool01_l0003oMgMgoiRHV?ooooooV9RHogMgM`Kooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`2Vooooo`00X_ooool00omgMgOo0000ooooo`02ooooo`06o`000?o^k^ko
<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0:Kooooo
002Wooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`2Vooooo`00Yoooool00ol0003oooooooooo`09ooooo`;o00002_ooool00ol0003oooooooooo`2V
ooooo`00Z?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0Yoooool00:Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo0:Oooooo002Xooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`2Wooooo`00Z?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0Yoooool00:Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0:Sooooo002Yooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Xooooo`00ZOooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Z?ooool00:Wooooo
00?o0000ooooooooool01oooool2o`0000Sooooo00?o0000ooooooooool0Z?ooool00:Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0:Sooooo002Y
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Y
ooooo`00Z_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0ZOooool00:[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo0:Wooooo002Zooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`2Yooooo`00Zoooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0Z_ooool00:_ooooo00?o0000ooooooooool01Oooool2
o`0000Kooooo00?o0000ooooooooool0Z_ooool00:_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0:[ooooo002/ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2[ooooo`00[?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Zoooool00:cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:_ooooo002]
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2[
ooooo`00[Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0[?ooool00:gooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000oooooooo
ool0[?ooool00:gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0:cooooo002^ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`2]ooooo`00[_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0[Oooool00:kooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo00000;3ooooo002Qooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo0:kooooo002Tooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo0:kooooo002Uoooo
o`04o`000?oooooooooooa0@40?ooooo00Go410@ooooooooooooooooo`000002ooooo`Co0000/Ooo
ool00:Cooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooool0003oooooo`00002booooo`00XOooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo
00Go0000ooooooooooooooooo`000005ooooo`?o0000/oooool00:7ooooo00?o0000ooooooooool0
1?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0/_ooool00:7ooooo
00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooooooo
ool0/_ooool00:7ooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00S?oo
ool01OlQ8B7o0000o`000?m4A4CogMgM0=Oooooo002?ooooo`03ogMgMolb<S;ooooo03[ooooo00?o
^[Zjoc8b<_ooool00_ooool01?l0003oooooooooool00008ooooo`03ogMgMomVIVKooooo00Sooooo
00?oIVIVogMgMoooool01_ooool00ol0003o^[Zjooooo`1dooooo`00T?ooool00ol0003ooooooooo
o`0jooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`05ooooo`03omgM
gOl@413ok^k^00Wooooo00?ok^k^oa0@4?oMgMd01_ooool2oc8b<WGooooo001Cooooo`06oa0@4?lQ
8B7o0000o`000?m4A4CogMgM0_ooool01?l@413o0000o`000?ooool2o`000004oa0@4?ooooook^k^
oeEEE@;o000000KoEEEEonk^k_ooooooooooonk^k_mEEED2o`000003oeEEEOo^k^kooooo00;ooooo
00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`Go00000_ooool01?l@413o0000o`000?ooool2o`00
0008oa0@4?ooooook^k^oeEEEOl0003o410@olc<c?l00004ooooo`;o00000_ooool01ol0003ooooo
ooooool0003o410@onk^k_mEEED00_l000000om4A4Co^[Zjooooo`02ooooo`05oiRHV?l0003o0000
odA4A?nj^[X00_ooool01?l@413o0000o`000?ooool2o`000004oa0@4?ooooook^k^oeEEE@;o0000
00KoEEEEonk^k_ooooooooooonk^k_mEEED2o`000003oiRHV?l0003o410@00Kooooo00OoV9RHoa0@
4?l0003o0000ojVYZOoooooo000000;ooooo00?o0000ooooooooool01Oooool00omEEEGoV9RHoooo
o`02ooooo`;o00000_ooool2o`0000;ooooo00?oQhN7ofIVI_ooool01Oooool00on7QhOo0000okZj
^P0;ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool01_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^05Gooooo001Cooooo`06o`000?n7QhOooooooooooon7QhOo8B4Q0oooool01Ol0
003ooooooooooooooooo000000;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED2ooooo`06oeEE
EOmgMgOooooooooooomgMgOoEEEE0oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Gooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMoooooook^k^
oeEEEOl00005ooooo`04o`000?ooooooooooo`0000;ooooo00So0000oooooomEEEGoMgMgooooooo^
k^koMgMgoa0@40?ooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`05o`000?oooooooooooooo
ool000000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@;ooooo00KoEEEEogMgMoooooook^k^
oeEEEOl00007ooooo`06o`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj0ol00008ooooo`03o`000?oooooo
oooo00;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03onk^k_l0003ooooo00Gooooo
00?oc<c<o`000?l@41003?ooool01_l0003ooooooooooooooooo0000ooooo`Ko00000_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg05Gooooo001Cooooo`06ob4Q8Oooooooooooooooooo^k^ko00000ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00004ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool000000_ooool01_l0003oooooooooooooooook^k^o`0000Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00Go
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000oooool00oo^k^ko0000ooooo`06ooooo`06oc8b<_o^k^koV9RHoeEEEOoMgMgo410@
2oooool00olb<S;oooooooooo`03ooooo`04omgMgOl0003o410@olc<c0Cooooo00?o0000oooooooo
ool04oooool01Ol0003ooooooooooooooooo000000Wooooo00Go410@oooooooooooooooooa0@401E
ooooo`00E?ooool01OoMgMgoV9RHogMgMol@413oIVIV00?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooo
oooooooooooo000000Wooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Ko0000ooooooooooooooooonk^k_l00005ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooool000001Ol00003ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooo
ooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool00oo^
k^ko0000ooooo`06ooooo`07okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c00:ooooo`03oc8b<_oo
oooooooo00?ooooo00Cok^k^ob4Q8Ol@413ok^k^1?ooool00ol0003oooooooooo`0Cooooo`06o`00
0?ooooooooooooooool0003ooooo1_l00002ooooo`05o`000?ooooooooooooooool00000EOooool0
05?ooooo00GoIVIVoa0@4?mEEEGoQhN7okZj^P04ooooo`05o`000?mgMgOoooooojVYZOl000000_oo
ool01_mEEEGoMgMgooooooooooooMgMgoeEEE@;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED3
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool01Ol0003oQhN7oooooonY
ZJWo000000;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00005ooooo`0>o`000?o<c<coc<c<o`00
0?nYZJWogMgMob4Q8OooooooEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?oooooooooo
00Gooooo00Go0000ogMgMoooooooZJVYo`000002ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE
0_ooool01_mVIVKoMgMgooooooo^k^koEEEEo`0000Oooooo00Ook^k^o`000?oooooo0000oooooomV
IVKoQhN700[ooooo00?o0000onk^k_ooool00oooool01?lQ8B7oMgMgogMgMolb<S83ooooo`03onk^
k_l0003ooooo01Cooooo00Go0000ohN7QoooooooZJVYo`000009ooooo`05o`000?oooooooooooooo
ool00000EOooool005?ooooo00Ko0000onk^k_ooooooooooolc<c?l00003ooooo`05o`000?mgMgOo
0000o`000?nHV9P00_ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kP;ooooo00Sok^k^oeEEEOl0
003o0000oeEEEOo^k^kooooooa0@40Go00001?ooool00ol@413o0000o`000004ooooo`03oa0@4?l0
003oMgMg00;o000000[oV9RHooooooooooook^k^oeEEEOl0003o8B4QojVYZOl0003o410@0oooool0
2ol@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^k^koEEEE00;o000000CoA4A4onk^
k_oooooo410@1Ol00004ooooo`05o`000?mgMgOo0000o`000?nHV9P00_ooool01_o^k^koEEEEo`00
0?l0003oEEEEonk^kP;ooooo00Kok^k^oeEEEOl0003o410@olc<c?l00007ooooo`04ofIVI_nHV9So
oooooc8b<P;o^[Zj00?o0000ooooooooool02?ooool00omEEEGoMgMgooooo`02ooooo`;o00000_oo
ool2o`0000;ooooo00?oMgMgoeEEEOooool04oooool00ol@413o0000ogMgM`02o`000003oiRHV?oo
oooooooo00Oooooo00Go410@oooooooooooooooooa0@401Eooooo`00Doooool01_lb<S;oQhN7oooo
ooo^k^koIVIVo`0000?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`03
ofIVI_n7QhOooooo00_ooooo00?ogMgMoa0@4?o^k^h02Oooool00oo^k^ko410@omgMg@0Sooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0EOooool005?ooooo00Kok^k^odA4A?l0003o0000oc8b<_l@4103
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08
ooooo`03ojVYZOm4A4Cooooo00cooooo00?oMgMgofIVI_ooool02?ooool00omVIVKoMgMgooooo`0S
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0EOooool005_ooooo00?o410@o`000?ooool08?ooool0
0ol@413oooooooooo`0]ooooo`03oa0@4?l0003ooooo017ooooo0_l0002Tooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-9.71045, -4.17515, \
0.0676215, 0.344909}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0595238 0.30902 0.000199467 [
[.05357 .29652 -12 -9 ]
[.05357 .29652 12 0 ]
[.20238 .29652 -6 -9 ]
[.20238 .29652 6 0 ]
[.35119 .29652 -12 -9 ]
[.35119 .29652 12 0 ]
[.64881 .29652 -9 -9 ]
[.64881 .29652 9 0 ]
[.79762 .29652 -3 -9 ]
[.79762 .29652 3 0 ]
[.94643 .29652 -9 -9 ]
[.94643 .29652 9 0 ]
[.4875 .00982 -30 -4.5 ]
[.4875 .00982 0 4.5 ]
[.4875 .10955 -30 -4.5 ]
[.4875 .10955 0 4.5 ]
[.4875 .20929 -24 -4.5 ]
[.4875 .20929 0 4.5 ]
[.4875 .40875 -18 -4.5 ]
[.4875 .40875 0 4.5 ]
[.4875 .50849 -24 -4.5 ]
[.4875 .50849 0 4.5 ]
[.4875 .60822 -24 -4.5 ]
[.4875 .60822 0 4.5 ]
[.5 .63053 -79.625 0 ]
[.5 .63053 79.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05357 .30902 m
.05357 .31527 L
s
[(-7.5)] .05357 .29652 0 1 Mshowa
.20238 .30902 m
.20238 .31527 L
s
[(-5)] .20238 .29652 0 1 Mshowa
.35119 .30902 m
.35119 .31527 L
s
[(-2.5)] .35119 .29652 0 1 Mshowa
.64881 .30902 m
.64881 .31527 L
s
[(2.5)] .64881 .29652 0 1 Mshowa
.79762 .30902 m
.79762 .31527 L
s
[(5)] .79762 .29652 0 1 Mshowa
.94643 .30902 m
.94643 .31527 L
s
[(7.5)] .94643 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.1131 .30902 m
.1131 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.17262 .30902 m
.17262 .31277 L
s
.23214 .30902 m
.23214 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.29167 .30902 m
.29167 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.41071 .30902 m
.41071 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.47024 .30902 m
.47024 .31277 L
s
.52976 .30902 m
.52976 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.58929 .30902 m
.58929 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.70833 .30902 m
.70833 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.76786 .30902 m
.76786 .31277 L
s
.82738 .30902 m
.82738 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.8869 .30902 m
.8869 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .00982 m
.50625 .00982 L
s
[(-1500)] .4875 .00982 1 0 Mshowa
.5 .10955 m
.50625 .10955 L
s
[(-1000)] .4875 .10955 1 0 Mshowa
.5 .20929 m
.50625 .20929 L
s
[(-500)] .4875 .20929 1 0 Mshowa
.5 .40875 m
.50625 .40875 L
s
[(500)] .4875 .40875 1 0 Mshowa
.5 .50849 m
.50625 .50849 L
s
[(1000)] .4875 .50849 1 0 Mshowa
.5 .60822 m
.50625 .60822 L
s
[(1500)] .4875 .60822 1 0 Mshowa
.125 Mabswid
.5 .02977 m
.50375 .02977 L
s
.5 .04971 m
.50375 .04971 L
s
.5 .06966 m
.50375 .06966 L
s
.5 .08961 m
.50375 .08961 L
s
.5 .1295 m
.50375 .1295 L
s
.5 .14945 m
.50375 .14945 L
s
.5 .16939 m
.50375 .16939 L
s
.5 .18934 m
.50375 .18934 L
s
.5 .22923 m
.50375 .22923 L
s
.5 .24918 m
.50375 .24918 L
s
.5 .26913 m
.50375 .26913 L
s
.5 .28907 m
.50375 .28907 L
s
.5 .32897 m
.50375 .32897 L
s
.5 .34891 m
.50375 .34891 L
s
.5 .36886 m
.50375 .36886 L
s
.5 .38881 m
.50375 .38881 L
s
.5 .4287 m
.50375 .4287 L
s
.5 .44865 m
.50375 .44865 L
s
.5 .46859 m
.50375 .46859 L
s
.5 .48854 m
.50375 .48854 L
s
.5 .52843 m
.50375 .52843 L
s
.5 .54838 m
.50375 .54838 L
s
.5 .56833 m
.50375 .56833 L
s
.5 .58827 m
.50375 .58827 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -140.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Shooting) show
117.000 13.000 moveto
(method) show
159.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
165.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
170.250 13.000 moveto
(H) show
176.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
182.250 13.000 moveto
(L) show
188.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
200.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
206.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
212.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
218.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .30902 m
.02605 .30902 L
.02846 .30902 L
.03072 .30902 L
.03279 .30902 L
.03521 .30902 L
.03784 .30902 L
.04032 .30902 L
.04262 .30902 L
.04498 .30902 L
.0472 .30902 L
.04963 .30902 L
.05224 .30902 L
.05497 .30902 L
.05757 .30902 L
.0599 .30902 L
.06244 .30902 L
.0653 .30902 L
.06799 .30902 L
.07041 .30902 L
.07302 .30902 L
.07588 .30902 L
.07889 .30902 L
.08147 .30902 L
.08429 .30902 L
.08694 .30902 L
.08936 .30902 L
.09215 .30902 L
.09479 .30902 L
.09722 .30902 L
.09948 .30902 L
.10195 .30902 L
.10458 .30902 L
.10696 .30902 L
.10947 .30902 L
.11161 .30902 L
.11395 .30902 L
.11648 .30902 L
.11918 .30902 L
.12173 .30902 L
.12405 .30902 L
.12856 .30902 L
.13111 .30902 L
.13345 .30902 L
.13777 .30902 L
.13994 .30902 L
.14233 .30902 L
.14482 .30902 L
.14754 .30902 L
.15011 .30902 L
Mistroke
.15249 .30902 L
.15699 .30902 L
.1595 .30902 L
.16178 .30902 L
.16695 .30902 L
.16987 .30902 L
.17254 .30902 L
.17747 .30902 L
.17995 .30902 L
.18267 .30902 L
.18519 .30902 L
.18793 .30902 L
.19034 .30902 L
.1929 .30902 L
.19521 .30901 L
.19774 .30901 L
.20222 .30901 L
.20493 .30901 L
.20742 .30901 L
.2101 .309 L
.21302 .309 L
.21796 .30899 L
.22065 .30898 L
.22315 .30897 L
.22821 .30895 L
.23107 .30894 L
.2337 .30892 L
.23853 .30888 L
.24364 .30882 L
.24823 .30875 L
.25251 .30866 L
.2572 .30854 L
.26224 .30835 L
.26752 .3081 L
.2724 .30778 L
.27776 .30732 L
.28346 .30666 L
.28839 .30591 L
.29302 .30503 L
.29809 .3038 L
.30357 .30211 L
.31313 .29799 L
.31855 .29483 L
.32359 .29122 L
.33378 .28156 L
.34468 .26695 L
.35491 .24839 L
.366 .22234 L
.38615 .16003 L
.40561 .09017 L
Mistroke
.41593 .05623 L
.42162 .0405 L
.42703 .02842 L
.42949 .02403 L
.43211 .02022 L
.43362 .01845 L
.43499 .01712 L
.43636 .01608 L
.43765 .01535 L
.43884 .01492 L
.44008 .01472 L
.44115 .01474 L
.44232 .01499 L
.44358 .01552 L
.44429 .01593 L
.44493 .01639 L
.44611 .01742 L
.44737 .01878 L
.4498 .02225 L
.45205 .02644 L
.45714 .03942 L
.46155 .05458 L
.4664 .07546 L
.47651 .13185 L
.48576 .19624 L
.50663 .36271 L
.51656 .4389 L
.52717 .50859 L
.53232 .53638 L
.53718 .5584 L
.54151 .57437 L
.54397 .58188 L
.54627 .58786 L
.54869 .59308 L
.5509 .59689 L
.55326 .59997 L
.55456 .60124 L
.55579 .60216 L
.55685 .60273 L
.55797 .60314 L
.55903 .60332 L
.55999 .60332 L
.56113 .60313 L
.56235 .60268 L
.56351 .60205 L
.56457 .60128 L
.56695 .59896 L
.56918 .59606 L
.57422 .58711 L
.57914 .5756 L
Mistroke
.5844 .56081 L
.60426 .49232 L
.62583 .41883 L
.6359 .39078 L
.64658 .36663 L
.6557 .35049 L
.66575 .33701 L
.67094 .33157 L
.67588 .32724 L
.68515 .32098 L
.69032 .31837 L
.69513 .3164 L
.70036 .31468 L
.70602 .31322 L
.71152 .31214 L
.71659 .31137 L
.72142 .3108 L
.72654 .31034 L
.73112 .31002 L
.73541 .30979 L
.7401 .30959 L
.74514 .30943 L
.75042 .30931 L
.75531 .30923 L
.76067 .30917 L
.76338 .30914 L
.76637 .30912 L
.77136 .30909 L
.77417 .30908 L
.77675 .30907 L
.78149 .30905 L
.78406 .30905 L
.78649 .30904 L
.78889 .30904 L
.79149 .30903 L
.79603 .30903 L
.7986 .30903 L
.80133 .30903 L
.80369 .30903 L
.80622 .30902 L
.80858 .30902 L
.81074 .30902 L
.81497 .30902 L
.81733 .30902 L
.8199 .30902 L
.82459 .30902 L
.82715 .30902 L
.82991 .30902 L
.83235 .30902 L
.83493 .30902 L
Mistroke
.83725 .30902 L
.8398 .30902 L
.84429 .30902 L
.84703 .30902 L
.84953 .30902 L
.85242 .30902 L
.85515 .30902 L
.85767 .30902 L
.86 .30902 L
.86256 .30902 L
.86527 .30902 L
.86766 .30902 L
.87017 .30902 L
.87234 .30902 L
.87466 .30902 L
.87717 .30902 L
.87949 .30902 L
.88226 .30902 L
.88477 .30902 L
.88713 .30902 L
.88929 .30902 L
.89167 .30902 L
.89419 .30902 L
.89637 .30902 L
.89842 .30902 L
.90066 .30902 L
.90306 .30902 L
.90562 .30902 L
.90833 .30902 L
.91065 .30902 L
.91321 .30902 L
.91595 .30902 L
.91891 .30902 L
.9217 .30902 L
.92427 .30902 L
.92669 .30902 L
.92894 .30902 L
.93141 .30902 L
.93406 .30902 L
.93684 .30902 L
.93946 .30902 L
.94182 .30902 L
.94438 .30902 L
.94621 .30902 L
.94817 .30902 L
.94987 .30902 L
.95173 .30902 L
.9539 .30902 L
.95596 .30902 L
.95796 .30902 L
Mistroke
.95982 .30902 L
.96196 .30902 L
.96398 .30902 L
.96579 .30902 L
.96775 .30902 L
.96988 .30902 L
.97214 .30902 L
.97407 .30902 L
.97619 .30902 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00TOooool4o`000005oa0@4?oooooooooooooooom4
A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`2booooo`00Toooool00ol0003ooooooooo
o`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;;ooooo0028ooooo`Ko00001Oooool00ol0
003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@
4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000
ooooooooool01_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00Cooooo0ol0002booooo`00Toooool00ol0003ooooooooo
o`03ooooo`06o`000?lQ8B7o0000oc8b<_o<c<cooooo0_l00003ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`000005oa0@4?l0003o0000oooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0/_ooool0
09?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2o`000006oooooomgMgOo
V9RHo`000?nHV9SoMgMg0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooooooo
ool0/_ooool0097ooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o
0000onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`2boooo
o`00W?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0/_ooool009_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`;o0000
/oooool009_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`2booooo`00V_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0/_ooool009[ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo0;;ooooo002Jooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2booooo`00VOooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0/_ooool009Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`;o0000/oooool009Wooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0;;ooooo002Hooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2booooo`00
V?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
/_ooool009Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo0;;ooooo002Gooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`2booooo`00Uoooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00Sooooo0_l0002cooooo`00U_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0/_ooool009Kooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo0;;ooooo002Fooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`2booooo`00UOooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0/_ooool009Gooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0;;ooooo002Eooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00
U?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo0_l0002cooooo`00U?oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_oo
ool009Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;;ooooo002Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2booooo`00TOooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko0000o`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So0000
oiRHV?mgMgL01_ooool00ol0003oooooooooo`2booooo`00R?ooool6o`0000Cooooo0_l00004oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@ooooool0003ooooooa0@4006ooooo`?o0000/_ooool009;ooooo0_l00004ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooool0
003oooooo`000006ooooo`03o`000?oooooooooo0;;ooooo002Booooo`;o00001?ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
0000ooooool000001_ooool00ol0003oooooooooo`2booooo`00T_ooool2o`0000Cooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
o`000?oooooo410@00Kooooo00?o0000ooooooooool0/_ooool0097ooooo00?o0000ooooool00000
1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9So0000oiRHV?mgMgL01_ooool00ol0003oooooooooo`2booooo`00TOooool00ol0
003oIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o0000onk^kP06ooooo`03o`000?oooooooooo0;;ooooo
002Aooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01Oooool2o`000;?ooooo002A
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2b
ooooo`00T?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0/_ooool0093ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0;;ooooo002@ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`2booooo`00Soooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0/_ooool008oooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;;ooooo002?ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool01?ooool2o`000;?ooooo002?ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2booooo`00S_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/_ooool008kooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;;ooooo002>
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2b
ooooo`00S_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0/_ooool008gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`03ooooo`;o
0000/oooool008gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0;;ooooo002=ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`2booooo`00S?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0/_ooool008cooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0;;ooooo002<ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2booooo`00Roooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0/_ooool008_ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`02ooooo`;o0000/oooool008_ooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;;ooooo002;oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2boooo
o`00R_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0/_ooool008[ooooo00?o0000ooooooooool03?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`07onk^k_lb<S;o0000oc8b<_o^k^koooooo`00
0004ooooo`03o`000?oooooooooo0;;ooooo002:ooooo`03o`000?oooooooooo00oooooo00WoMgMg
oc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool01omgMgOoV9RHoooooonHV9SoMgMg
ooooool000001?ooool00ol0003oooooooooo`2booooo`00ROooool00ol0003oooooooooo`04oooo
o`Ko00001oooool01?l0003oooooooooool@4103ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool00ol@413oooooo`000004ooooo`?o0000/_ooool008Wooooo00?o0000ooooooooool04?ooool0
1OmgMgOo<S8boooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool0/_ooool008Wooooo00?o0000ooooooooool0
3Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo00000;Cooooo0028
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4002ooooo`05o`000?ooooooooooooooool0
0000]?ooool008Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00Go0000oooo
ooooooooooooo`00002dooooo`00R?ooool00ol0003oooooooooo`0>ooooo`Co00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`05o`000?oo
ooooooooooooool00000]?ooool008Oooooo00?o0000ooooooooool09Oooool01Ol0003ooooooooo
oooooooo00000;Cooooo0027ooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooooooo
0_l0002cooooo`00Q_ooool00ol0003oooooooooo`0Vooooo`05o`000?ooooooooooooooool00000
]?ooool008Kooooo00?o0000ooooooooool09oooool01?l0003oooooooooool0002dooooo`00Q_oo
ool00ol0003oooooooooo`0Wooooo`04o`000?ooooooooooo`000;Cooooo0025ooooo`03o`000?oo
oooooooo02Sooooo00Co0000oooooooooooo0000]?ooool008Gooooo00?o0000ooooooooool0:?oo
ool01?l0003oooooooooool0002dooooo`00Q?ooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo00;o0000/oooool008Cooooo00?o0000ooooooooool0:Oooool01?l0003oooooooooool0
002dooooo`00Poooool00ol0003oooooooooo`0Zooooo`04o`000?ooooooooooo`000;Cooooo0023
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooool00000]?ooool008;ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooo`00002dooooo`00P_ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooo00000;Cooooo000Nooooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd08oooool01Om4A4Co0000o`000?lb<S;ogMgM02;ooooo1_l00004oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01oooooo00?o0000ooooool000009?ooool5
o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd08oooool01Om4A4Co0000o`00
0?lb<S;ogMgM02Cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@0Jooooo`007_ooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`0Uooooo`03ogMgMolb<S;ooooo027ooooo00KoV9RHob4Q8Oo^k^koooooodA4A?l00004oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`0Nooooo`04o`000?oooooo0000o`0002?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Uooooo`03ogMgMolb
<S;ooooo02?ooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06Ooo
ool001Cooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool06?ooool6
o`0000Oooooo00?o0000ooooooooool06?ooool6o`0000?ooooo00CoV9RHob4Q8Oo^k^ko00004?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooo000002Gooooo00?oV9RHob4Q8Oo^k^h04Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02;ooooo00?oZJVYoeEEEOooool04?oo
ool00ol0003oooooooooo`0Hooooo`007oooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;o
oooo02Gooooo00?oMgMgoc8b<_ooool08oooool00onHV9So0000onk^kP0?ooooo`03ogMgMolb<S;o
oooo01kooooo00?o0000ooooool000009_ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;o
oooo02Gooooo00?oMgMgoc8b<_ooool09?ooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;o
oooo01Wooooo000Oooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00S
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`09?ooool00ol0003oMgMgofIVIP0<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`07oooool00ol0003oooooo`00000Wooooo`03ogMgMomVIVKooooo00_ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00Sooooo`05o`000?lQ8B7o0000oc8b<_o<c<`09Oooool00omE
EEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool001oooooo00?oZJVYogMg
Moooool02oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Gooooo00Co0000oooo
oooooooo00003?ooool00ol0003oooooooooo`0Rooooo`;o0000:?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09oooool00onYZJWoMgMgooooo`0;
ooooo`03o`000?oooooooooo01cooooo000Looooo`05oa0@4?oooooooooooooooolb<S803?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Cooooo00Go0000okZj^_ooooooV9RHoa0@
400<ooooo`03o`000?oooooooooo02;ooooo0_l0000Tooooo`05o`000?nj^[[ooooooiRHV?l@4100
3?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Cooooo00Go410@oooooooooooo
oooooc8b<P0<ooooo`03o`000?oooooooooo01cooooo000Looooo`Go00003?ooool4o`0002Cooooo
1?l0000Rooooo`06o`000?nHV9So410@o`000?lQ8B7oc<c<3?ooool4o`00027ooooo0ol0000Soooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0002Cooooo1?l0000Sooooo`Go00003?ooool4
o`0001_ooooo001iooooo`;o0000=oooool2o`000;Cooooo001hooooo`03o`000?oooooooooo03Oo
oooo0_l0002dooooo`00MOooool3o`0003[ooooo0_l0002dooooo`00Loooool2o`0003gooooo0_l0
002dooooo`00L?ooool3o`0003oooooo0_l0002dooooo`00FOoooolGo`0004?ooooo00?o0000oooo
ooooool0/_ooool0017oooooool00016o`0001;ooooo000Iooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00oooool5o`0000Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01Sooooo000Sooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool08_ooool00;?ooooo00?o0000ooooooooool0>?ooool4o`0007Kooooo002coooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0N?ooool00;?ooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`1iooooo`00/oooool2o`0003Kooooo00?o0000ooooooooool0
N_ooool00;?ooooo0_l0000eooooo`03o`000?oooooooooo07_ooooo002cooooo`;o0000=Oooool0
0ol0003oooooooooo`1kooooo`00/oooool2o`0003Cooooo00?o0000ooooooooool0O?ooool00;?o
oooo0_l0000cooooo`03o`000?oooooooooo07gooooo002cooooo`;o0000<_ooool00ol0003ooooo
ooooo`1nooooo`00/oooool2o`00037ooooo00?o0000ooooooooool0Ooooool00;?ooooo0_l0000`
ooooo`03o`000?oooooooooo083ooooo002cooooo`03o`000?oooooo000002oooooo00?o0000oooo
ooooool0P?ooool00;?ooooo00?o0000ooooool00000;_ooool00ol0003oooooooooo`21ooooo`00
/oooool00ol0003oooooo`00000]ooooo`03o`000?oooooooooo08;ooooo002cooooo`03o`000?oo
oooo000002gooooo00?o0000ooooooooool0P_ooool00;?ooooo00?o0000ooooool00000;?ooool0
0ol0003oooooooooo`23ooooo`00/oooool3o`0002cooooo00?o0000ooooooooool0Poooool00;?o
oooo00?o0000ooooool00000:oooool00ol0003oooooooooo`24ooooo`00/oooool00ol0003ooooo
o`00000[ooooo`03o`000?oooooooooo08Cooooo002cooooo`04o`000?ooooooooooo`0002[ooooo
00?o0000ooooooooool0Q?ooool00;?ooooo00Co0000oooooooooooo0000:Oooool00ol0003ooooo
ooooo`25ooooo`00/oooool01?l0003oooooooooool0000Yooooo`03o`000?oooooooooo08Gooooo
002cooooo`;o000000?oooooo`000?ooool0:?ooool00ol0003oooooooooo`25ooooo`00/oooool0
1?l0003oooooooooool0000Xooooo`03o`000?oooooooooo08Kooooo002cooooo`04o`000?oooooo
ooooo`0002Sooooo00?o0000ooooooooool0Q_ooool00;?ooooo00Co0000oooooooooooo00009ooo
ool00ol0003oooooooooo`27ooooo`00VOooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool01?l0003o
ooooooooool0000Wooooo`03o`000?oooooooooo08Oooooo002Looooo`09ogMgMolb<S;ooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`05o`00
0?ooooooooooooooool000009_ooool00ol0003oooooooooo`27ooooo`00WOooool01?l0003ooooo
ooooool@4103ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`04oooo
o`05o`000?ooooooooooooooool000009Oooool00ol0003oooooooooo`28ooooo`00W?ooool01Omg
MgOo<S8boooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00Cooooo0ol000000ooooooo0000ooooo`0Tooooo`03o`000?oooooooooo08Sooooo002I
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000009Oooool00ol0
003oooooooooo`28ooooo`00VOooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo00Go0000ooooooooooooooooo`00
000Tooooo`03o`000?oooooooooo08Wooooo002Iooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool01Ol0003ooooo
oooooooooooo000002Cooooo00?o0000ooooooooool0ROooool009Wooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00Go0000oooo
ooooooooooooo`00000Tooooo`03o`000?oooooooooo08Wooooo002cooooo`05o`000?oooooooooo
ooooool000009?ooool00ol0003oooooooooo`29ooooo`00/oooool2o`0000;ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`2:ooooo`00/oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0R_ooool00;?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo08[ooooo002cooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`2;ooooo`00/oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0Roooool0
0;?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
08_ooooo002cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`2;ooooo`00/oooool2o`0000?ooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`2<ooooo`00/oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0S?ooool00;?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo08cooooo002cooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`2=ooooo`00/oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0SOooool00;?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo08gooooo002cooooo`;o00001Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo08kooooo002cooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2>ooooo`00/oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0S_ooool00;?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo08ko
oooo002cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`2?ooooo`00/oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0Soooool00;?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo08oooooo002cooooo`;o00001_ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo093ooooo002cooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`2@ooooo`00/oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0T?ooool00;?ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo093ooooo002Aooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0TOooool009?ooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0TOooool009?ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41001_ooool3o`0000Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2Aoooo
o`00Toooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Booooo`00Toooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Booooo`00Toooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`2Booooo`00Toooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`2Cooooo`00TOooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`2Cooooo`00/oooool2o`0000Sooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`2Cooooo`00/oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0U?ooool00;?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo09Cooooo002cooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`2Dooooo`00/oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0UOooool00;?ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo09Gooooo002cooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Eooooo`00/ooo
ool2o`0000Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2Fooooo`00/oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0U_ooool0
0;?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
09Kooooo002cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`2Gooooo`00/oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0Uoooool00;?ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo09Oooooo002cooooo`;o00002oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo09Oooooo002cooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`2Hooooo`00/oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0V?ooool00;?ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo09Sooooo002cooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Hooooo`00/oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0VOooool0
0;?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
09[ooooo002cooooo`;o00003Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo09[o
oooo002cooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2Kooooo`00/oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0W?ooool00;?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo09cooooo002Aooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP06ooooo`03o`000?oooooooooo00kooooo0_l000000ooooooo0000o`00002Ooooo
o`00Toooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00oooooo
0ol0002Pooooo`00Toooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo
00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo0ol0002booooo`00
Toooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2boooo
o`00Toooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2kooooo`00
TOooool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP2kooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00S?ooool01OlQ8B7o0000o`000?m4A4CogMgM0=Oooooo002?ooooo`03ogMgMolb<S;o
oooo03[ooooo00?o^[Zjoc8b<_ooool00_ooool01?l0003oooooooooool00008ooooo`03ogMgMomV
IVKooooo00Sooooo00?oIVIVogMgMoooool01_ooool00ol0003o^[Zjooooo`1dooooo`00T?ooool0
0ol0003oooooooooo`0jooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`05ooooo`03omgMgOl@413ok^k^00Wooooo00?ok^k^oa0@4?oMgMd01_ooool2oc8b<WGooooo001C
ooooo`06oa0@4?lQ8B7o0000o`000?m4A4CogMgM0_ooool01?l@413o0000o`000?ooool2o`000004
oa0@4?ooooook^k^oeEEE@;o000000KoEEEEonk^k_ooooooooooonk^k_mEEED2o`000003oeEEEOo^
k^kooooo00;ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`Go00000_ooool01?l@413o0000
o`000?ooool2o`000008oa0@4?ooooook^k^oeEEEOl0003o410@olc<c?l00004ooooo`;o00000_oo
ool01ol0003oooooooooool0003o410@onk^k_mEEED00_l000000om4A4Co^[Zjooooo`02ooooo`05
oiRHV?l0003o0000odA4A?nj^[X00_ooool01?l@413o0000o`000?ooool2o`000004oa0@4?oooooo
k^k^oeEEE@;o000000KoEEEEonk^k_ooooooooooonk^k_mEEED2o`000003oiRHV?l0003o410@00Ko
oooo00OoV9RHoa0@4?l0003o0000ojVYZOoooooo000000;ooooo00?o0000ooooooooool01Oooool0
0omEEEGoV9RHooooo`02ooooo`;o00000_ooool2o`0000;ooooo00?oQhN7ofIVI_ooool01Oooool0
0on7QhOo0000okZj^P0;ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool01ooo
ool4o`000003oa0@4?oooooooooo05;ooooo001Cooooo`06o`000?n7QhOooooooooooon7QhOo8B4Q
0oooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED2
ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Go
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMg
Moooooook^k^oeEEEOl00005ooooo`04o`000?ooooooooooo`0000;ooooo00So0000oooooomEEEGo
MgMgooooooo^k^koMgMgoa0@40?ooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`05o`000?oo
ooooooooooooool000000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@;ooooo00KoEEEEogMg
Moooooook^k^oeEEEOl00007ooooo`06o`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj0ol00008ooooo`03
o`000?oooooooooo00;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03onk^k_l0003o
oooo00Gooooo00?oc<c<o`000?l@41003?ooool01_l0003ooooooooooooooooo0000ooooo`Ko0000
1Oooool00ol0003oooooooooo`1Dooooo`00Doooool01_lQ8B7oooooooooooooooook^k^o`0000?o
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001?ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000ooooooooooooooooonk^k_l00005oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000?ooooo00?ok^k^o`000?ooool01_ooool01_lb<S;ok^k^oiRHV?mEEEGogMgMoa0@
40_ooooo00?o<S8booooooooool00oooool01?oMgMgo0000oa0@4?o<c<`4ooooo`03o`000?oooooo
oooo01?ooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo05Cooooo001D
ooooo`05omgMgOnHV9SoMgMgoa0@4?mVIVH00oooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`05o`000?oooooooooooooo
ool000002Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool0
1_l0003oooooooooooooooook^k^o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooo`000005o`0000?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03onk^k_l0003o
oooo00Kooooo00Oo^[ZjodA4A?o<c<co8B4Qooooool@413oc<c<00[ooooo00?o<S8booooooooool0
0oooool01?o^k^ko8B4Qoa0@4?o^k^h4ooooo`03o`000?oooooooooo01?ooooo00Ko0000oooooooo
ooooooooo`000?ooool6o`0000Gooooo00?o0000ooooooooool0E?ooool005?ooooo00GoIVIVoa0@
4?mEEEGoQhN7okZj^P04ooooo`05o`000?mgMgOoooooojVYZOl000000_ooool01_mEEEGoMgMgoooo
ooooooooMgMgoeEEE@;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED3ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00oooool01Ol0003oQhN7oooooonYZJWo000000;ooooo00Ko
EEEEogMgMoooooook^k^oeEEEOl00005ooooo`0>o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8Ooo
ooooEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?oooooooooo00Gooooo00Go0000ogMg
MoooooooZJVYo`000002ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0_ooool01_mVIVKoMgMg
ooooooo^k^koEEEEo`0000Oooooo00Ook^k^o`000?oooooo0000oooooomVIVKoQhN700[ooooo00?o
0000onk^k_ooool00oooool01?lQ8B7oMgMgogMgMolb<S83ooooo`03onk^k_l0003ooooo01Cooooo
00Go0000ohN7QoooooooZJVYo`00000<ooooo`03o`000?oooooooooo05Cooooo001Cooooo`06o`00
0?o^k^koooooooooooo<c<co00000oooool01Ol0003oMgMgo`000?l0003oV9RH00;ooooo00Kok^k^
oeEEEOl0003o0000oeEEEOo^k^h2ooooo`08onk^k_mEEEGo0000o`000?mEEEGok^k^ooooool@4105
o`0000Cooooo00?o410@o`000?l000001?ooool00ol@413o0000ogMgM`02o`00000:oiRHV?oooooo
ooooonk^k_mEEEGo0000ob4Q8OnYZJWo0000oa0@40?ooooo00_o410@o`000?lQ8B7o0000ogMgMol@
413o0000ojVYZOooooook^k^oeEEE@02o`000004odA4A?o^k^kooooooa0@40Go00001?ooool01Ol0
003oMgMgo`000?l0003oV9RH00;ooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h2ooooo`06onk^
k_mEEEGo0000oa0@4?o<c<co00001oooool01?mVIVKoV9RHoooooolb<S82okZj^P03o`000?oooooo
oooo00Sooooo00?oEEEEogMgMoooool00_ooool2o`0000;ooooo0_l00002ooooo`03ogMgMomEEEGo
oooo01?ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0:ooooo`03o`000?oooooo
oooo05Cooooo001Cooooo`06oc8b<_n7QhOoooooonk^k_mVIVKo00000oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Sooooo00?oIVIVohN7Qoooool02oooool00ooMgMgo410@onk^
kP09ooooo`03onk^k_l@413ogMgM02Kooooo00?o0000ooooooooool0E?ooool005?ooooo00Kok^k^
odA4A?l0003o0000oc8b<_l@4103ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`08ooooo`03ojVYZOm4A4Cooooo00cooooo00?oMgMgofIVI_ooool0
2?ooool00omVIVKoMgMgooooo`0Tooooo`03oeEEEOmVIVKo000005Kooooo001Kooooo`03oa0@4?l0
003ooooo023ooooo00?o410@ooooooooool0;Oooool00ol@413o0000ooooo`0Aooooo`;o0000Y?oo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-9.32419, -1587.21, \
0.0649317, 19.3766}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0595238 0.289 2.4686e-05 [
[.05357 .2765 -12 -9 ]
[.05357 .2765 12 0 ]
[.20238 .2765 -6 -9 ]
[.20238 .2765 6 0 ]
[.35119 .2765 -12 -9 ]
[.35119 .2765 12 0 ]
[.64881 .2765 -9 -9 ]
[.64881 .2765 9 0 ]
[.79762 .2765 -3 -9 ]
[.79762 .2765 3 0 ]
[.94643 .2765 -9 -9 ]
[.94643 .2765 9 0 ]
[.4875 .04214 -36 -4.5 ]
[.4875 .04214 0 4.5 ]
[.4875 .16557 -30 -4.5 ]
[.4875 .16557 0 4.5 ]
[.4875 .41243 -24 -4.5 ]
[.4875 .41243 0 4.5 ]
[.4875 .53586 -30 -4.5 ]
[.4875 .53586 0 4.5 ]
[.5 .63053 -79.625 0 ]
[.5 .63053 79.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05357 .289 m
.05357 .29525 L
s
[(-7.5)] .05357 .2765 0 1 Mshowa
.20238 .289 m
.20238 .29525 L
s
[(-5)] .20238 .2765 0 1 Mshowa
.35119 .289 m
.35119 .29525 L
s
[(-2.5)] .35119 .2765 0 1 Mshowa
.64881 .289 m
.64881 .29525 L
s
[(2.5)] .64881 .2765 0 1 Mshowa
.79762 .289 m
.79762 .29525 L
s
[(5)] .79762 .2765 0 1 Mshowa
.94643 .289 m
.94643 .29525 L
s
[(7.5)] .94643 .2765 0 1 Mshowa
.125 Mabswid
.08333 .289 m
.08333 .29275 L
s
.1131 .289 m
.1131 .29275 L
s
.14286 .289 m
.14286 .29275 L
s
.17262 .289 m
.17262 .29275 L
s
.23214 .289 m
.23214 .29275 L
s
.2619 .289 m
.2619 .29275 L
s
.29167 .289 m
.29167 .29275 L
s
.32143 .289 m
.32143 .29275 L
s
.38095 .289 m
.38095 .29275 L
s
.41071 .289 m
.41071 .29275 L
s
.44048 .289 m
.44048 .29275 L
s
.47024 .289 m
.47024 .29275 L
s
.52976 .289 m
.52976 .29275 L
s
.55952 .289 m
.55952 .29275 L
s
.58929 .289 m
.58929 .29275 L
s
.61905 .289 m
.61905 .29275 L
s
.67857 .289 m
.67857 .29275 L
s
.70833 .289 m
.70833 .29275 L
s
.7381 .289 m
.7381 .29275 L
s
.76786 .289 m
.76786 .29275 L
s
.82738 .289 m
.82738 .29275 L
s
.85714 .289 m
.85714 .29275 L
s
.8869 .289 m
.8869 .29275 L
s
.91667 .289 m
.91667 .29275 L
s
.02381 .289 m
.02381 .29275 L
s
.97619 .289 m
.97619 .29275 L
s
.25 Mabswid
0 .289 m
1 .289 L
s
.5 .04214 m
.50625 .04214 L
s
[(-10000)] .4875 .04214 1 0 Mshowa
.5 .16557 m
.50625 .16557 L
s
[(-5000)] .4875 .16557 1 0 Mshowa
.5 .41243 m
.50625 .41243 L
s
[(5000)] .4875 .41243 1 0 Mshowa
.5 .53586 m
.50625 .53586 L
s
[(10000)] .4875 .53586 1 0 Mshowa
.125 Mabswid
.5 .06683 m
.50375 .06683 L
s
.5 .09151 m
.50375 .09151 L
s
.5 .1162 m
.50375 .1162 L
s
.5 .14088 m
.50375 .14088 L
s
.5 .19026 m
.50375 .19026 L
s
.5 .21494 m
.50375 .21494 L
s
.5 .23963 m
.50375 .23963 L
s
.5 .26431 m
.50375 .26431 L
s
.5 .31369 m
.50375 .31369 L
s
.5 .33837 m
.50375 .33837 L
s
.5 .36306 m
.50375 .36306 L
s
.5 .38774 m
.50375 .38774 L
s
.5 .43712 m
.50375 .43712 L
s
.5 .4618 m
.50375 .4618 L
s
.5 .48649 m
.50375 .48649 L
s
.5 .51117 m
.50375 .51117 L
s
.5 .01745 m
.50375 .01745 L
s
.5 .56055 m
.50375 .56055 L
s
.5 .58523 m
.50375 .58523 L
s
.5 .60992 m
.50375 .60992 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -140.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Shooting) show
117.000 13.000 moveto
(method) show
159.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
165.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
170.250 13.000 moveto
(H) show
176.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
182.250 13.000 moveto
(L) show
188.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
200.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
206.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
212.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
218.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .289 m
.02605 .289 L
.02846 .289 L
.03072 .289 L
.03279 .289 L
.03521 .289 L
.03784 .289 L
.04032 .289 L
.04262 .289 L
.04498 .289 L
.0472 .289 L
.04963 .289 L
.05224 .289 L
.05497 .289 L
.05757 .289 L
.0599 .289 L
.06244 .289 L
.0653 .289 L
.06799 .289 L
.07041 .289 L
.07302 .289 L
.07588 .289 L
.07889 .289 L
.08147 .289 L
.08429 .289 L
.08694 .289 L
.08936 .289 L
.09215 .289 L
.09479 .289 L
.09722 .289 L
.09948 .289 L
.10195 .289 L
.10458 .289 L
.10696 .289 L
.10947 .289 L
.11161 .289 L
.11395 .289 L
.11648 .289 L
.11918 .289 L
.12173 .289 L
.12405 .289 L
.12856 .289 L
.13111 .289 L
.13345 .289 L
.13777 .289 L
.13994 .289 L
.14233 .289 L
.14482 .289 L
.14754 .289 L
.15011 .289 L
Mistroke
.15249 .289 L
.15699 .289 L
.1595 .289 L
.16178 .289 L
.16695 .289 L
.16987 .289 L
.17254 .289 L
.17747 .28901 L
.17995 .28901 L
.18267 .28901 L
.18519 .28901 L
.18793 .28902 L
.19034 .28902 L
.1929 .28902 L
.19774 .28903 L
.20222 .28905 L
.20469 .28906 L
.20736 .28907 L
.21217 .2891 L
.21497 .28913 L
.2179 .28916 L
.22315 .28923 L
.22816 .28933 L
.23272 .28945 L
.23797 .28964 L
.24293 .28989 L
.24752 .29019 L
.25175 .29055 L
.2564 .29106 L
.26131 .29175 L
.26625 .29267 L
.27077 .29373 L
.27598 .2953 L
.28092 .29719 L
.28969 .3018 L
.29465 .30529 L
.29925 .30921 L
.30886 .32003 L
.31789 .33409 L
.32779 .35472 L
.33848 .38382 L
.3585 .4565 L
.36869 .4992 L
.37959 .54368 L
.3849 .56299 L
.38992 .57871 L
.39442 .59008 L
.39674 .59474 L
.39931 .59879 L
.40046 .60022 L
Mistroke
.4017 .60147 L
.40287 .60236 L
.40394 .60294 L
.40515 .60329 L
.40646 .60331 L
.4077 .60298 L
.40885 .60235 L
.41001 .60141 L
.41109 .60024 L
.41312 .59727 L
.4153 .59293 L
.41766 .58686 L
.42259 .56956 L
.42718 .5477 L
.43762 .47854 L
.45869 .28111 L
.46773 .19136 L
.47734 .10783 L
.48235 .07268 L
.48501 .05698 L
.48787 .04264 L
.4905 .03198 L
.4929 .0244 L
.4952 .01915 L
.49635 .01727 L
.49762 .0158 L
.49831 .01526 L
.49905 .01488 L
.49976 .01472 L
.50041 .01474 L
.50164 .01522 L
.50294 .01638 L
.50362 .01723 L
.50434 .01834 L
.50565 .02086 L
.50863 .02898 L
.51138 .03935 L
.51398 .05162 L
.51887 .08059 L
.5285 .15658 L
.539 .25767 L
.55001 .36838 L
.56037 .4624 L
.56967 .5296 L
.57491 .55831 L
.57723 .56879 L
.57971 .57844 L
.58218 .58642 L
.58443 .59231 L
.58669 .59693 L
Mistroke
.58882 .60013 L
.59003 .60144 L
.59131 .60246 L
.5924 .60302 L
.5936 .60332 L
.59489 .60328 L
.59562 .6031 L
.59628 .60284 L
.59757 .60206 L
.5988 .601 L
.60121 .59807 L
.60378 .59376 L
.60841 .58326 L
.61392 .56693 L
.61892 .54934 L
.63977 .46361 L
.64892 .42716 L
.65897 .39182 L
.66801 .36527 L
.67771 .34255 L
.68795 .32454 L
.69751 .31244 L
.70279 .30738 L
.70768 .30356 L
.71293 .30023 L
.71874 .29733 L
.72377 .29538 L
.72849 .29393 L
.73348 .29272 L
.73886 .29173 L
.74381 .29103 L
.74842 .29053 L
.75348 .29012 L
.75889 .28979 L
.76457 .28954 L
.76994 .28938 L
.77476 .28927 L
.77999 .28919 L
.78487 .28913 L
.78944 .28909 L
.79446 .28906 L
.79728 .28905 L
.79985 .28904 L
.80501 .28903 L
.80794 .28902 L
.81064 .28902 L
.81561 .28901 L
.81838 .28901 L
.82089 .28901 L
.82578 .289 L
Mistroke
.82824 .289 L
.83094 .289 L
.83324 .289 L
.83571 .289 L
.84017 .289 L
.84285 .289 L
.84577 .289 L
.84852 .289 L
.85107 .289 L
.85589 .289 L
.85832 .289 L
.861 .289 L
.86355 .289 L
.86593 .289 L
.8684 .289 L
.87111 .289 L
.87559 .289 L
.8781 .289 L
.88037 .289 L
.88306 .289 L
.88553 .289 L
.88824 .289 L
.89111 .289 L
.89361 .289 L
.89594 .289 L
.8985 .289 L
.90124 .289 L
.9038 .289 L
.90651 .289 L
.90883 .289 L
.91139 .289 L
.91413 .289 L
.91709 .289 L
.91988 .289 L
.92245 .289 L
.92487 .289 L
.92712 .289 L
.92959 .289 L
.93224 .289 L
.93502 .289 L
.93764 .289 L
.94 .289 L
.94256 .289 L
.94449 .289 L
.94657 .289 L
.94837 .289 L
.95033 .289 L
.95262 .289 L
.9548 .289 L
.95692 .289 L
Mistroke
.95889 .289 L
.96115 .289 L
.96328 .289 L
.96519 .289 L
.96726 .289 L
.96952 .289 L
.97191 .289 L
.97395 .289 L
.97619 .289 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/_ooool3o`000;?ooooo002aooooo`Co0000/oooool00;7ooooo00Go0000ooooool0
003oooooo`00002booooo`00/Oooool01Ol0003oooooo`000?oooooo00000;;ooooo002aooooo`03
o`000?oooooo000000;ooooo00?o0000ooooooooool0[oooool00;3ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`2_ooooo`00ROooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool0[oooool008_ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`2^ooooo`00P?ooool6o`0000Gooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo0:kooooo002;ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooooooo`?o000000?oooooo`000?ooool0[oooool008_ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo0:kooooo002;oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4002ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`2]oooo
o`00Roooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`07ogMgMonH
V9SooooooiRHV?mgMgOoooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0[Oooool008Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1oo^k^ko<S8bo`000?lb<S;ok^k^ooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0:gooooo002^ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`2]ooooo`00[_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0[Oooool00:kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0:gooooo002]ooooo`03o`000?oooooooooo00?o
oooo0_l00003ooooo`03o`000?oooooooooo0:gooooo002]ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`2/ooooo`00[Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[?ooool00:gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0:cooooo002]oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2/oooo
o`00[Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0[?ooool00:gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0:cooooo002]ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`2/ooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o00001?ooool0
0ol0003oooooooooo`2/ooooo`00[?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0[?ooool00:cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0:_ooooo002/ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`2[ooooo`00[?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Zoooool00:cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:_ooooo002/oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2[oooo
o`00[?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0Zoooool00:cooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o0000ooooooooool0
Zoooool00:_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0:_ooooo002[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`2Zooooo`00Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0Z_ooool00:_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0:[ooooo002[ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Zooooo`00Zoooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Z_ooool00:_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:[ooooo002Zoooo
o`03o`000?oooooooooo00Kooooo0_l00006ooooo`03o`000?oooooooooo0:[ooooo002Zooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Zooooo`00
Z_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
ZOooool00:[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0:Wooooo002Zooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`2Yooooo`00Z_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0ZOooool0097ooooo00GoA4A4o`000?l0003o<S8bomgMg@02oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
ZOooool009Cooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgo`000?ooooooV9RHogMgM`06ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0ZOooool008Sooooo1_l00007ooooo`04o`000?oooooo
oooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`06oa0@4?ooooooooooooooool@
413o00000_ooool00ol@413oooooooooo`04ooooo`?o00001_ooool00ol0003oooooooooo`2Yoooo
o`00U?ooool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0ZOooool0097ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo0_l00002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2Xooooo`00TOooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@o`000?oooooooooooa0@4006
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Z?ooool0097ooooo00?o0000oooo
ooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMol0003ooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0:Sooooo002Aooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_l0003o0000oc8b<_o^k^h01_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0:Sooooo002Xooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Xooooo`00Z?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Z?ooool00:Sooooo00?o
0000ooooooooool02?ooool2o`0000Sooooo00?o0000ooooooooool0Z?ooool00:Sooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0:Sooooo002Xoooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Woooo
o`00Z?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0Yoooool00:Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo0:Oooooo002Xooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`2Wooooo`00Z?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0Yoooool00:Oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo0:Oooooo002Wooooo`03o`000?oooooooooo00Wo
oooo0_l00009ooooo`03o`000?oooooooooo0:Oooooo002Wooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Wooooo`00Yoooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Yoooool00:Oooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0:Kooooo002Woooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Voooo
o`00Yoooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0Y_ooool00:Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo0:Kooooo002Wooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`2Vooooo`00Y_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0Y_ooool00:Kooooo00?o0000ooooooooool02_ooool2o`00
00[ooooo00?o0000ooooooooool0Y_ooool00:Kooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo0:Kooooo002Vooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Uooooo`007?ooool00ol0003ok^k^oooo
o`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM02Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@0Rooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Eoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Foooo
o`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Sooooo`05odA4A?l0003o
0000oc8b<_oMgMd09Oooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM01Sooooo000Looooo`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo02Kooooo00?oMgMgoc8b<_ooool08Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo01Cooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0Uooooo`03ogMgMolb<S;ooooo02Cooooo00?oEEEEojVYZOoo
ool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool001;ooooo1_l00004ooooo`03ojVY
ZOmEEEGooooo013ooooo00?o0000ooooooooool06Oooool6o`0000Oooooo00?o0000ooooooooool0
6?ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Gooooo`03oiRH
V?lQ8B7ok^k^017ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Sooooo`03ojVY
ZOmEEEGooooo013ooooo00?o0000ooooooooool05_ooool001gooooo00?o8B4Qooooooooool03_oo
ool00omgMgOo<S8booooo`0Vooooo`03ogMgMolb<S;ooooo02?ooooo00?oV9RHob4Q8Oo^k^h03ooo
ool00omgMgOo<S8booooo`0Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Hooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool09Ooo
ool00omgMgOo<S8booooo`0Uooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool05ooo
ool001gooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00Uooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c00Eooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Iooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Soooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`09_ooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`06?ooool001gooooo00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo00[ooooo0_l0000;ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Sooooo00?oZJVY
ogMgMoooool02oooool00ol0003oooooooooo`0Jooooo`006_ooool01Ol@413ooooooooooooooooo
<S8b00cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Tooooo`05o`000?nj^[[o
oooooiRHV?l@41003?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Fooooo`05o`000?nj^[[ooooooiRHV?l@4100
3?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Gooooo00Go410@oooooooooooo
oooooc8b<P0<ooooo`03o`000?oooooooooo01[ooooo000Jooooo`Go00003?ooool4o`0002Gooooo
1?l0000Sooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0001Gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c00<ooooo`Co00009?ooool4o`0002Cooooo1Ol0000<ooooo`Co00006Oooool00:Go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0:Go
oooo002Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`2Tooooo`00YOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0Y?ooool00:Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo0:Cooooo002Uooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`2Tooooo`003oooooooo`0004[o00004?ooool001Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`Go00001Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Wooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00?ooooo1Ol00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool0027o
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Eooooo`?o00005Oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo01?ooooo0ol0000Gooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool08?ooool006gooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=?ooool2o`0006kooooo
001^ooooo`;o0000=?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`1^ooooo`00L?ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo06oooooo001aooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0L?ooool0077ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1aooooo`00
L_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00cooooo0_l0000=ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool0LOooool007?ooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`1booooo`00M?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo07?ooooo001dooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0M?ooool007Go
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1dooooo`00M_ooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo07Gooooo001gooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0M_ooool007Oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1f
ooooo`00N?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00gooooo0_l0000=oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Moooool007Sooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`1hooooo`00NOooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo07Sooooo001jooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0NOoo
ool007[ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1iooooo`00Noooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo07Wooooo001kooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0N_ooool007_ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1jooooo`00O?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00gooooo0_l0
000>ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0N_ooool007cooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`1kooooo`00O?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo07_ooooo001mooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool0O?ooool007gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1looooo`00OOoo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07cooooo001nooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool0OOooool007kooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`1mooooo`00O_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00ko
oooo0_l0000?ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0OOooool007kooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`1nooooo`00Ooooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo07kooooo001oooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0O_ooool007oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1ooooo
o`00P?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo07oooooo0020ooooo`03o`00
0?oooooooooo00kooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko0000o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`1oooooo`00P?ooool00ol0003oooooooooo`0Aooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgo`000?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0Ooooool0083ooooo00?o0000ooooooooool04_ooool01?l0003oooooooooool@4103
ooooo`06oa0@4?ooooooooooooooool@413o00000_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool01?ooool3o`0000oooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`20ooooo`00POooool00ol0003oooooooooo`0@ooooo`05ogMgMolb<S;oooooooooool0
00000oooool01?l0003oooooooooooooool2o`0000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo083ooooo0021ooooo`03o`000?oooooooooo00gooooo00Go0000ob4Q
8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000000oooool2o`0000;ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo083ooooo0021ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@o`000?oooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0P?ooool008;o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOo0000oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`06ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`21ooooo`00P_ooool00ol0003oooooooooo`0<ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^o`000?l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0POooool008;ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`21ooooo`00Pooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo087ooooo0023ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool04?ooool2o`00017ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`22ooooo`00Poooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
08;ooooo0023ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0P_ooool008Cooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`22ooooo`00Q?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo08?ooooo0024ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0Poooool008Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`23oooo
o`00QOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo08?ooooo0025ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool04?ooool2o`0001;ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`24ooooo`00QOooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo08Cooooo0026ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Q?ooool0
08Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`24ooooo`00Q_ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo08Gooooo0026ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0QOooool008Kooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`25ooooo`00Qoooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo08Gooooo0027oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04Oooool2o`0001?ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`26ooooo`00Qoooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo08Kooooo0027ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
Q_ooool008Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`26ooooo`00R?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo08Oooooo0028ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0Qoooool008Sooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`27ooooo`00R?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo08Oooooo
0029ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04oooool2o`0001Cooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`28ooooo`00ROooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo08Sooooo0029ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0R?ooool008[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`28ooooo`00
R_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo08Wooooo002:ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0ROooool008Wooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;o000000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0ROooool008_ooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RH
o`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
08Wooooo002;ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`2:ooooo`00Roooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool3o`0001Gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`2:ooooo`00Roooool2o`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00;o00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`2:ooooo`00Roooool2o`0000?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooo`000?l@41000oooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2:ooooo`00Roooool2o`00
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Soooooo`000?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2;ooooo`00
ROooool01?mEEEGoIVIVo`000?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?l0003ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0Roooool008cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`2;ooooo`00SOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo08cooooo002=oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0S?ooool008gooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Fooooo`;o00005oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo08cooooo002=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
SOooool008kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2=ooooo`00S_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo08gooooo002>ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo08kooooo
002?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Soooool0093ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Hooooo`;o00006Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo08oooooo002@ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0T?ooool0093ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2@ooooo`00
TOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo093ooooo002Booooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0TOooool009;ooooo1Ol0000Looooo`03o`000?oooooo
oooo01[ooooo0_l000000ooooooo0000ooooo`2Cooooo`00U?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0Toooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool0
0ol0003oooooooooo`2booooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00S?ooool01OlQ8B7o0000o`000?m4A4CogMgM0=Oooooo002?oooo
o`03ogMgMolb<S;ooooo03[ooooo00?o^[Zjoc8b<_ooool00_ooool01?l0003oooooooooool00008
ooooo`03ogMgMomVIVKooooo00Sooooo00?oIVIVogMgMoooool01_ooool00ol0003o^[Zjooooo`1d
ooooo`00T?ooool00ol0003oooooooooo`0jooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`05ooooo`03omgMgOl@413ok^k^00Wooooo00?ok^k^oa0@4?oMgMd01_ooool2
oc8b<WGooooo001Cooooo`06oa0@4?lQ8B7o0000o`000?m4A4CogMgM0_ooool01?l@413o0000o`00
0?ooool2o`000004oa0@4?ooooook^k^oeEEE@;o000000KoEEEEonk^k_ooooooooooonk^k_mEEED2
o`000003oeEEEOo^k^kooooo00;ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`Go00000_oo
ool01?l@413o0000o`000?ooool2o`000008oa0@4?ooooook^k^oeEEEOl0003o410@olc<c?l00004
ooooo`;o00000_ooool01ol0003oooooooooool0003o410@onk^k_mEEED00_l000000om4A4Co^[Zj
ooooo`02ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool01?l@413o0000o`000?ooool2o`00
0004oa0@4?ooooook^k^oeEEE@;o000000KoEEEEonk^k_ooooooooooonk^k_mEEED2o`000003oiRH
V?l0003o410@00Kooooo00OoV9RHoa0@4?l0003o0000ojVYZOoooooo000000;ooooo00?o0000oooo
ooooool01Oooool00omEEEGoV9RHooooo`02ooooo`;o00000_ooool2o`0000;ooooo00?oQhN7ofIV
I_ooool01Oooool00on7QhOo0000okZj^P0;ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@
ooooooooool01_ooool5o`0005Gooooo001Cooooo`06o`000?n7QhOooooooooooon7QhOo8B4Q0ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED2oooo
o`06oeEEEOmgMgOooooooooooomgMgOoEEEE0oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Gooooo
00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMooo
ooook^k^oeEEEOl00005ooooo`04o`000?ooooooooooo`0000;ooooo00So0000oooooomEEEGoMgMg
ooooooo^k^koMgMgoa0@40?ooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`05o`000?oooooo
ooooooooool000000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@;ooooo00KoEEEEogMgMooo
ooook^k^oeEEEOl00007ooooo`06o`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj0ol00008ooooo`03o`00
0?oooooooooo00;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03onk^k_l0003ooooo
00Gooooo00?oc<c<o`000?l@41003?ooool01_l0003ooooooooooooooooo0000ooooo`Ko00000_oo
ool01OnHV9So8B4Qonk^k_ooooooA4A405Gooooo001Cooooo`06ob4Q8Oooooooooooooooooo^k^ko
00000oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00004ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003oooooooooooooooook^k^o`00
00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000008ooooo`03o`000?oooooo
oooo00Gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000oooool00oo^k^ko0000ooooo`06ooooo`06oc8b<_o^k^koV9RHoeEEEOoM
gMgo410@2oooool00olb<S;oooooooooo`03ooooo`04omgMgOl0003o410@olc<c0Cooooo00?o0000
ooooooooool04oooool01Ol0003ooooooooooooooooo000000[ooooo00?oV9RHob4Q8Oo^k^h0E_oo
ool005Cooooo00GogMgMoiRHV?mgMgOo410@ofIVIP03ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooo
ooooooooo`000009ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002
ooooo`06o`000?ooooooooooooooooo^k^ko00001Oooool01?l0003oooooooooool00002ooooo`03
o`000?oooooo000000Go00000oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000000_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?ok^k^
o`000?ooool01_ooool01onj^[[oA4A4olc<c?lQ8B7ooooooa0@4?o<c<`02_ooool00olb<S;ooooo
ooooo`03ooooo`04onk^k_lQ8B7o410@onk^kPCooooo00?o0000ooooooooool04oooool01_l0003o
oooooooooooooooo0000ooooo`Ko00001?ooool00onHV9So8B4Qonk^kP1Eooooo`00Doooool01OmV
IVKo410@oeEEEOn7QhOo^[Zj00Cooooo00Go0000ogMgMoooooooZJVYo`000002ooooo`06oeEEEOmg
MgOooooooooooomgMgOoEEEE0_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`03ooooo`05o`000?n7QhOoooooojVYZOl000000_oo
ool01_mEEEGoMgMgooooooo^k^koEEEEo`0000Gooooo00ko0000olc<c?o<c<co0000ojVYZOoMgMgo
8B4QoooooomEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o0000ooooooooool01Oooool01Ol0
003oMgMgoooooonYZJWo000000;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED2ooooo`06ofIV
I_mgMgOoooooonk^k_mEEEGo00001oooool01oo^k^ko0000ooooool0003oooooofIVI_n7QhL02_oo
ool00ol0003ok^k^ooooo`03ooooo`04ob4Q8OmgMgOoMgMgoc8b<P?ooooo00?ok^k^o`000?ooool0
5?ooool01Ol0003oQhN7oooooonYZJWo000000cooooo00?oMgMgofIVI_ooool0E?ooool005?ooooo
00Ko0000onk^k_ooooooooooolc<c?l00003ooooo`05o`000?mgMgOo0000o`000?nHV9P00_ooool0
1_o^k^koEEEEo`000?l0003oEEEEonk^kP;ooooo00Sok^k^oeEEEOl0003o0000oeEEEOo^k^kooooo
oa0@40Go00001?ooool00ol@413o0000o`000004ooooo`03oa0@4?l0003oMgMg00;o000000[oV9RH
ooooooooooook^k^oeEEEOl0003o8B4QojVYZOl0003o410@0oooool02ol@413o0000ob4Q8Ol0003o
MgMgoa0@4?l0003oZJVYooooooo^k^koEEEE00;o000000CoA4A4onk^k_oooooo410@1Ol00004oooo
o`05o`000?mgMgOo0000o`000?nHV9P00_ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kP;ooooo
00Kok^k^oeEEEOl0003o410@olc<c?l00007ooooo`04ofIVI_nHV9Sooooooc8b<P;o^[Zj00?o0000
ooooooooool02?ooool00omEEEGoMgMgooooo`02ooooo`;o00000_ooool2o`0000;ooooo00?oMgMg
oeEEEOooool04oooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo00_ooooo00?o0000
ooooooooool0Doooool005?ooooo00Ko<S8bohN7Qoooooook^k^ofIVI_l00003ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool02?ooool00omVIVKoQhN7ooooo`0;ooooo`03omgMgOl@
413ok^k^00Wooooo00?ok^k^oa0@4?oMgMd08oooool01Ol0003o^[ZjoooooonHV9So410@05Gooooo
001Cooooo`06onk^k_m4A4Co0000o`000?lb<S;o410@0oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool00onYZJWoA4A4ooooo`0<ooooo`03
ogMgMomVIVKooooo00Sooooo00?oIVIVogMgMoooool08oooool01OnHV9So410@o`000?lQ8B7oc<c<
05Gooooo001Kooooo`03oa0@4?l0003ooooo023ooooo00?o410@ooooooooool0;Oooool00ol@413o
0000ooooo`0Aooooo`;o0000Y?ooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-9.21355, -11707.2, \
0.0641612, 154.708}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0595238 0.309023 4.39428e-06 [
[.05357 .29652 -12 -9 ]
[.05357 .29652 12 0 ]
[.20238 .29652 -6 -9 ]
[.20238 .29652 6 0 ]
[.35119 .29652 -12 -9 ]
[.35119 .29652 12 0 ]
[.64881 .29652 -9 -9 ]
[.64881 .29652 9 0 ]
[.79762 .29652 -3 -9 ]
[.79762 .29652 3 0 ]
[.94643 .29652 -9 -9 ]
[.94643 .29652 9 0 ]
[.4875 .04537 -36 -4.5 ]
[.4875 .04537 0 4.5 ]
[.4875 .13325 -36 -4.5 ]
[.4875 .13325 0 4.5 ]
[.4875 .22114 -36 -4.5 ]
[.4875 .22114 0 4.5 ]
[.4875 .39691 -30 -4.5 ]
[.4875 .39691 0 4.5 ]
[.4875 .48479 -30 -4.5 ]
[.4875 .48479 0 4.5 ]
[.4875 .57268 -30 -4.5 ]
[.4875 .57268 0 4.5 ]
[.5 .63053 -79.625 0 ]
[.5 .63053 79.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05357 .30902 m
.05357 .31527 L
s
[(-7.5)] .05357 .29652 0 1 Mshowa
.20238 .30902 m
.20238 .31527 L
s
[(-5)] .20238 .29652 0 1 Mshowa
.35119 .30902 m
.35119 .31527 L
s
[(-2.5)] .35119 .29652 0 1 Mshowa
.64881 .30902 m
.64881 .31527 L
s
[(2.5)] .64881 .29652 0 1 Mshowa
.79762 .30902 m
.79762 .31527 L
s
[(5)] .79762 .29652 0 1 Mshowa
.94643 .30902 m
.94643 .31527 L
s
[(7.5)] .94643 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.1131 .30902 m
.1131 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.17262 .30902 m
.17262 .31277 L
s
.23214 .30902 m
.23214 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.29167 .30902 m
.29167 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.41071 .30902 m
.41071 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.47024 .30902 m
.47024 .31277 L
s
.52976 .30902 m
.52976 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.58929 .30902 m
.58929 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.70833 .30902 m
.70833 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.76786 .30902 m
.76786 .31277 L
s
.82738 .30902 m
.82738 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.8869 .30902 m
.8869 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .04537 m
.50625 .04537 L
s
[(-60000)] .4875 .04537 1 0 Mshowa
.5 .13325 m
.50625 .13325 L
s
[(-40000)] .4875 .13325 1 0 Mshowa
.5 .22114 m
.50625 .22114 L
s
[(-20000)] .4875 .22114 1 0 Mshowa
.5 .39691 m
.50625 .39691 L
s
[(20000)] .4875 .39691 1 0 Mshowa
.5 .48479 m
.50625 .48479 L
s
[(40000)] .4875 .48479 1 0 Mshowa
.5 .57268 m
.50625 .57268 L
s
[(60000)] .4875 .57268 1 0 Mshowa
.125 Mabswid
.5 .06734 m
.50375 .06734 L
s
.5 .08931 m
.50375 .08931 L
s
.5 .11128 m
.50375 .11128 L
s
.5 .15522 m
.50375 .15522 L
s
.5 .17719 m
.50375 .17719 L
s
.5 .19917 m
.50375 .19917 L
s
.5 .24311 m
.50375 .24311 L
s
.5 .26508 m
.50375 .26508 L
s
.5 .28705 m
.50375 .28705 L
s
.5 .33099 m
.50375 .33099 L
s
.5 .35297 m
.50375 .35297 L
s
.5 .37494 m
.50375 .37494 L
s
.5 .41888 m
.50375 .41888 L
s
.5 .44085 m
.50375 .44085 L
s
.5 .46282 m
.50375 .46282 L
s
.5 .50677 m
.50375 .50677 L
s
.5 .52874 m
.50375 .52874 L
s
.5 .55071 m
.50375 .55071 L
s
.5 .0234 m
.50375 .0234 L
s
.5 .00142 m
.50375 .00142 L
s
.5 .59465 m
.50375 .59465 L
s
.5 .61662 m
.50375 .61662 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -140.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Shooting) show
117.000 13.000 moveto
(method) show
159.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
165.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
170.250 13.000 moveto
(H) show
176.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
182.250 13.000 moveto
(L) show
188.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
200.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
206.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
212.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
218.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .30902 m
.02605 .30902 L
.02846 .30902 L
.03072 .30902 L
.03279 .30902 L
.03521 .30902 L
.03784 .30902 L
.04032 .30902 L
.04262 .30902 L
.04498 .30902 L
.0472 .30902 L
.04963 .30902 L
.05224 .30902 L
.05497 .30902 L
.05757 .30902 L
.0599 .30902 L
.06244 .30902 L
.0653 .30902 L
.06799 .30902 L
.07041 .30902 L
.07302 .30902 L
.07588 .30902 L
.07889 .30902 L
.08147 .30902 L
.08429 .30902 L
.08694 .30902 L
.08936 .30902 L
.09215 .30902 L
.09479 .30902 L
.09722 .30902 L
.09948 .30902 L
.10195 .30902 L
.10458 .30902 L
.10696 .30902 L
.10947 .30902 L
.11161 .30902 L
.11395 .30902 L
.11648 .30902 L
.11918 .30902 L
.12173 .30902 L
.12405 .30902 L
.12856 .30902 L
.13111 .30902 L
.13345 .30902 L
.13777 .30902 L
.13994 .30902 L
.14233 .30902 L
.14482 .30902 L
.14754 .30902 L
.14994 .30902 L
Mistroke
.15249 .30902 L
.15502 .30902 L
.15731 .30902 L
.16178 .30902 L
.16447 .30901 L
.16695 .30901 L
.16962 .30901 L
.17254 .309 L
.17747 .309 L
.18016 .30899 L
.18267 .30898 L
.18769 .30896 L
.19053 .30895 L
.19315 .30893 L
.19796 .30889 L
.20306 .30882 L
.20762 .30875 L
.21189 .30865 L
.21658 .3085 L
.22163 .30829 L
.22661 .308 L
.23123 .30764 L
.2363 .30712 L
.24171 .30636 L
.24741 .30528 L
.25278 .30392 L
.2576 .30234 L
.26282 .30015 L
.27231 .29452 L
.2777 .29013 L
.28274 .28505 L
.2929 .27135 L
.29859 .2613 L
.30379 .25043 L
.32286 .19557 L
.34361 .11365 L
.35379 .07229 L
.36336 .0395 L
.36816 .0272 L
.37086 .02191 L
.37333 .01825 L
.37466 .01679 L
.3759 .01577 L
.37661 .01534 L
.37725 .01504 L
.378 .01481 L
.3787 .01472 L
.37939 .01473 L
.38011 .01488 L
.38141 .01546 L
Mistroke
.38214 .01597 L
.38281 .01656 L
.38436 .01836 L
.3856 .02028 L
.38693 .02278 L
.38933 .0285 L
.39217 .0374 L
.39475 .04745 L
.39983 .07283 L
.40462 .10327 L
.42315 .26836 L
.44154 .45 L
.44658 .48996 L
.44935 .50865 L
.45198 .52385 L
.45442 .53561 L
.45708 .54561 L
.45825 .54907 L
.45949 .55207 L
.46055 .55409 L
.46172 .55572 L
.46298 .55678 L
.46361 .55703 L
.46431 .55709 L
.46553 .55666 L
.46667 .55563 L
.46737 .5547 L
.46803 .55362 L
.46926 .55106 L
.47058 .54753 L
.47201 .5428 L
.47446 .53264 L
.47704 .5191 L
.48167 .48819 L
.49171 .39771 L
.50274 .27909 L
.51273 .17704 L
.51765 .13506 L
.5222 .10341 L
.52495 .08827 L
.52743 .07732 L
.52876 .07259 L
.53019 .06837 L
.53098 .06644 L
.5317 .06493 L
.53239 .06371 L
.53313 .06266 L
.53433 .06148 L
.53544 .06098 L
.53613 .06097 L
Mistroke
.53677 .06115 L
.53798 .06201 L
.53926 .06365 L
.54044 .06582 L
.54173 .06892 L
.5431 .07301 L
.54562 .08261 L
.54801 .09415 L
.55251 .12165 L
.56263 .2058 L
.58093 .39063 L
.59051 .47774 L
.59576 .51744 L
.60072 .54833 L
.60535 .57102 L
.60779 .5805 L
.61036 .58868 L
.61253 .59413 L
.61368 .59649 L
.61492 .59862 L
.61605 .60022 L
.61708 .60138 L
.61812 .60228 L
.61911 .60287 L
.62024 .60325 L
.62147 .60332 L
.62263 .60305 L
.62369 .60254 L
.62487 .60168 L
.62616 .6004 L
.62875 .59679 L
.63132 .59197 L
.63406 .58558 L
.63901 .57132 L
.65742 .50008 L
.67733 .42184 L
.68781 .38884 L
.69891 .36176 L
.70881 .34404 L
.71443 .33631 L
.7197 .33041 L
.72894 .32264 L
.73413 .31945 L
.73888 .31712 L
.74366 .31526 L
.74874 .3137 L
.75354 .31256 L
.75789 .31175 L
.76303 .31101 L
.76857 .31043 L
Mistroke
.77381 .31002 L
.77863 .30975 L
.78334 .30955 L
.78838 .30939 L
.79314 .30929 L
.79748 .30922 L
.80257 .30915 L
.80544 .30913 L
.8081 .30911 L
.81298 .30908 L
.81544 .30907 L
.81815 .30906 L
.82308 .30905 L
.82556 .30904 L
.82827 .30904 L
.83059 .30904 L
.83307 .30903 L
.83753 .30903 L
.84023 .30903 L
.84316 .30903 L
.84574 .30903 L
.84847 .30903 L
.85093 .30903 L
.85364 .30903 L
.8584 .30902 L
.8609 .30902 L
.86362 .30902 L
.86602 .30902 L
.86858 .30902 L
.87087 .30902 L
.8734 .30902 L
.87787 .30902 L
.88058 .30902 L
.88306 .30902 L
.88578 .30902 L
.88865 .30902 L
.89115 .30902 L
.89348 .30902 L
.89604 .30902 L
.89878 .30902 L
.90136 .30902 L
.90409 .30902 L
.90643 .30902 L
.909 .30902 L
.91176 .30902 L
.91472 .30902 L
.91753 .30902 L
.92009 .30902 L
.92265 .30902 L
.92503 .30902 L
Mistroke
.92763 .30902 L
.93041 .30902 L
.93307 .30902 L
.93556 .30902 L
.9378 .30902 L
.94023 .30902 L
.94231 .30902 L
.94454 .30902 L
.94665 .30902 L
.94857 .30902 L
.95082 .30902 L
.95327 .30902 L
.95558 .30902 L
.95772 .30902 L
.95991 .30902 L
.96198 .30902 L
.96424 .30902 L
.96668 .30902 L
.96909 .30902 L
.97164 .30902 L
.97381 .30902 L
.97619 .30902 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o/oooool0
0ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002:
ooooo`?o00009_ooool00ol0003oooooooooo`2booooo`00R_ooool01?l0003oooooooooool0000U
ooooo`03o`000?oooooooooo0;;ooooo0029ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`2booooo`00ROooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo02;ooooo0_l0002cooooo`00R?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0/_ooool008Sooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0;;ooooo0027ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2booooo`00Qoooool01_l0
003ok^k^oc8b<_l0003o410@olc<c0?ooooo00Go0000oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0;;ooooo0026ooooo`07o`000?ooooooEEEE
ogMgMoooooooV9RHob4Q8@03ooooo`05o`000?nHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01_ooool00ol0003oooooooooo`2booooo`00P?ooool7o`000003ooooool0003ooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/_ooool008Kooooo00Oo0000ooooool0003o
V9RHoooooonHV9So8B4Q00?ooooo0_l00002ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00Cooooo0ol0002booooo`00QOooool02?l0003oooooooooool0003oEEEEo`000?l@
413oc<c<0oooool2o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`2booooo`00QOooool01Ol0003ooooooooooomEEEGoQhN700Kooooo
00Go410@o`000?oooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oo
oooooooo0;;ooooo0025ooooo`06o`000?ooooooooooomgMgOl@413oV9RH1Oooool01OmgMgOo0000
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0/_oo
ool008Cooooo00?o0000ooooooooool00_ooool01?o<c<coA4A4o`000?l@4103ooooo`05onk^k_l0
003o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`2b
ooooo`00Q?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool02?ooool2o`000:Sooooo0024ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`07ooooo`;o000000?oooooo`000?ooool0Y_ooool008Cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Nooooo`;o00002?ooool01?l0003ooooo
ooooool0002Wooooo`00Poooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo00000:Kooooo0023ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0Y?ooool008?ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`2Tooooo`00Poooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0:?ooooo0022ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Xoooool008;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Sooooo`00P_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo01gooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0Xoooool008;ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2Rooooo`00POooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:;ooooo0021oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0X_ooool0087ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`2Rooooo`00POooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo0:;ooooo0021ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0X_oo
ool0083ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Qooooo`00P?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01cooooo0_l00005ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0XOooool0083ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2Qooooo`00P?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0:7ooooo
001oooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0XOooool007oooooo00?o0000
ooooooooool02?ooool2o`00000:oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^o`00
00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo0:7ooooo001oooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00_ooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo0:7ooooo001oooooo`Oo00000_ooool5o`0000?ooooo00Ko410@oooooooooooooooooa0@
4?l00002ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`2Qooooo`00O_ooool00ol0003oooooooooo`07oooo
o`04odA4A?oMgMgoooooo`0000Cooooo00Co0000oooooooooooooooo0_l00002ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000006ooooo`?o00000oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
0:3ooooo001nooooo`03o`000?oooooooooo00Oooooo00CogMgMoeEEEOoooooo00001?ooool01?l0
003oooooooooooooool2o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0:3ooooo001nooooo`03o`00
0?oooooooooo00Sooooo00?oMgMgolc<c?l000001?ooool01_l@413ooooooooooooooooo410@o`00
00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo0:3ooooo001nooooo`03o`000?oooooooooo00Sooooo00?o
k^k^odA4A?l000001?ooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo0:3ooooo001mooooo`03o`000?oooooooooo00[ooooo00?oMgMgo`000?ooool00oooool0
3Oo^k^ko<S8bo`000?lb<S;ok^k^ooooool0003oooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Pooooo`00OOoo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0:3ooooo001mooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0X?ooool007cooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Jooooo`;o00000oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
09oooooo001looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Woooool007cooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`2Oooooo`00O?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo09oooooo001kooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool06_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool0Wooo
ool007_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`05o`000?oooooo
ooooooooool000003_ooool00ol0003oooooooooo`2Oooooo`00Noooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oo
oooooooo09oooooo001kooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool2
o`0000;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2Nooooo`00N_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`00000?
ooooo`03o`000?oooooooooo09kooooo001jooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06Oooool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooooooool0W_ooool0
07[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`05o`000?oooooooooo
ooooool000003oooool00ol0003oooooooooo`2Nooooo`00N_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooo
oooo09kooooo001iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06Oooool01Ol0
003ooooooooooooooooo000000oooooo00?o0000ooooooooool0W_ooool007Wooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Iooooo`04o`000?ooooooooooo`00013ooooo00?o0000
ooooooooool0W_ooool007Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Ioooo
o`;o000000?oooooo`000?ooool04?ooool00ol0003oooooooooo`2Mooooo`00N?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo00004Oooool00ol0
003oooooooooo`2Mooooo`00N?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01So
oooo00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`2Mooooo`00N?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo00004Oooool00ol0
003oooooooooo`2Mooooo`00Moooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01So
oooo00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`2Mooooo`00Moooool00ol0003o
ooooooooo`0>ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go0000oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`2Mooooo`00
Moooool00ol0003oooooooooo`0>ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00Go0000oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00Co0000oooooooooooo
00004Oooool00ol0003oooooooooo`2Mooooo`00M_ooool00ol0003oooooooooo`07ooooo`Ko0000
0oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol0003o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41001_ooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo09gooooo
001fooooo`03o`000?oooooooooo017ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000Kooooo1?l0000Aooooo`03o`000?oooooo
oooo09gooooo001fooooo`03o`000?oooooooooo01;ooooo00?oMgMgofIVI_ooool00_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooo
oooo00004_ooool00ol0003oooooooooo`2Looooo`00MOooool00ol0003oooooooooo`0Dooooo`05
o`000?ooooooooooooooool@41000oooool01_l@413ooooooooooooooooo410@o`0000;ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`04ooooo`03o`000?oooooo000001?ooooo00?o0000ooooooooool0W?ooool007Gooooo
00?o0000ooooooooool04?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMol0003ooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooo000001?ooooo
00?o0000ooooooooool0W?ooool007Gooooo00?o0000ooooooooool04?ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_l0003o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooo000001?ooooo00?o0000ooooooooool0W?ooool007Cooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo000001?ooooo00?o0000
ooooooooool0W?ooool007Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooo000001?ooooo00?o0000ooooooooool0W?ooool007Cooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0Gooooo`?o00004oooool00ol0003oooooooooo`2Looooo`00
Loooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Oooooo00?o0000ooooool00000
4oooool00ol0003oooooooooo`2Looooo`00Loooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooool000004oooool00ol0003oooooooooo`2Looooo`00Loooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Oooooo00?o0000ooooool000004oooool0
0ol0003oooooooooo`2Looooo`00L_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooool000004oooool00ol0003oooooooooo`2Looooo`00L_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01Kooooo00?o0000ooooool000004oooool00ol0003o
ooooooooo`2Looooo`00LOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Kooooo
0_l0000Eooooo`03o`000?oooooooooo09_ooooo001aooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool05_ooool2o`0001Gooooo00?o0000ooooooooool0Voooool001cooooo00?o0000
onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Tooooo`05odA4A?l0
003o0000oc8b<_oMgMd05oooool00ol0003oooooooooo`08ooooo`Go00001Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@09ooooo`03o`000?oooooooooo01Kooooo0_l0000Eooooo`03
o`000?oooooooooo00cooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
02?ooooo00GoA4A4o`000?l0003o<S8bomgMg@0Uooooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?ooool001cooooo00?oEEEEojVYZOooool01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool09_ooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooo
oooo00Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`08ooooo`03o`000?oooooooooo01Kooooo0_l0000Eooooo`03o`000?oooooooooo00cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Uooooo`03ogMg
Molb<S;ooooo02Cooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
5oooool001;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool06Ooo
ool6o`0000Oooooo00?o0000ooooooooool05?ooool01?l0003oooooooooooooool6o`0000?ooooo
00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo
0_l0000Eooooo`03o`000?oooooooooo00gooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo02?ooooo00?oZJVYoeEEEOooool04?ooool00ol0003ooooo
ooooo`0Fooooo`007Oooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo02Kooooo00?o
MgMgoc8b<_ooool05?ooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00oooooo00?o
MgMgoc8b<_ooool02?ooool00ol0003oooooooooo`0Fooooo`;o00005Oooool00ol0003ooooooooo
o`0>ooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool09Oooool00omgMgOo<S8boooo
o`0Uooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool05oooool001gooooo00?oEEEE
olc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00Dooooo`03o`000?oooooooooo00kooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Wooooo00?o0000ooooooooool05_ooool2o`0001Gooooo00?o0000oooooooo
ool03oooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`08oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<02Kooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<01Sooooo000Mooooo`03ojVYZOmgMgOooooo00_ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Kooooo0_l0000Eooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo02Sooooo00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`0Jooooo`006_ooool01Ol@
413ooooooooooooooooo<S8b00cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00gooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool05Oooool2o`0001Gooooo00?o0000ooooooooool03?oo
ool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Uooooo`05oa0@4?oooooooooooooooolb<S803?ooool00ol0003oooooooooo`0Jooooo`00
6_ooool5o`0000cooooo1?l0000Uooooo`Co00004_ooool00ol0003oooooooooo`0>ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`03?ooool4o`0000_ooooo00?o0000ooooooooool05Oooool2o`0001Go
oooo00?o0000ooooooooool03?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0000Toooo
o`Co00009?ooool5o`0000cooooo1?l0000Iooooo`00JOooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo01Gooooo0_l0000Eooooo`03o`000?oooooooooo09_ooooo001Wooooo`;o0000
<_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
Voooool006Gooooo0_l0000dooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`2Jooooo`00Hoooool2o`0003Kooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo09[ooooo001Nooooo`Go0000>?ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0V_ooool000oo
ooooool0001:o`00013ooooo000Gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool01?l0003oooooooooooooool:o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool0027ooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool06oooool3o`0000oooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0Pooooo`00W?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`1Tooooo`00W?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0<Oooool2o`0006Oooooo002Loooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0_oooo
o`;o0000JOooool009cooooo00?o0000ooooooooool04oooool2o`0001Oooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`1Yooooo`00W?ooool00ol0003oooooooooo`0Cooooo`?o0000
5_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06[ooooo002Looooo`03o`000?oo
oooooooo01?ooooo0_l0000Gooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Jooo
ool009cooooo00?o0000ooooooooool04oooool2o`0001Oooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`1/ooooo`00W?ooool00ol0003oooooooooo`0Cooooo`;o00006?ooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo06cooooo002Looooo`03o`000?oooooooooo01?o
oooo0_l0000Hooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0KOooool009cooooo
00?o0000ooooooooool04oooool2o`0001Sooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`1^ooooo`00WOooool00ol0003oooooooooo`0Booooo`;o00006?ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo06kooooo002Mooooo`03o`000?oooooooooo01;ooooo0_l0000H
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool009gooooo00?o0000oooo
ooooool04Oooool01?l0003oooooo`000?l0000Gooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0Koooool009gooooo00?o0000ooooooooool04Oooool00ol0003oooooo`00000Hoooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0L?ooool009gooooo00?o0000oooooooo
ool04Oooool00ol0003oooooo`00000Hooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0L?ooool009gooooo00?o0000ooooooooool04Oooool00ol0003oooooo`00000Hooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0LOooool009gooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooo`00000Hooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0LOoo
ool009gooooo00?o0000ooooooooool04Oooool00ol0003oooooo`00000Hooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0L_ooool009gooooo00?o0000ooooooooool04Oooool00ol0
003oooooo`00000Hooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0L_ooool009ko
oooo00?o0000ooooooooool04?ooool01?l0003oooooo`000?l0000Hooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool0Loooool009kooooo00?o0000ooooooooool04?ooool00ol0003o
ooooo`00000Iooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Loooool009kooooo
00?o0000ooooooooool04?ooool00ol0003oooooo`00000Iooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0M?ooool009kooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
ool0000Iooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0M?ooool009kooooo00?o
0000ooooooooool03oooool01?l0003oooooooooool0000Iooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool0MOooool008Sooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool03Oo^k^ko<S8bo`000?lb<S;ok^k^ooooool0003oooooonk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Co0000oooooooooooo00006Oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo07Gooooo0028ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00goMgMgoiRHV?ooooooV9RHogMg
Mooooooo0000oooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`04o`000?ooooooooooo`0001Wooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`1eooooo`00ROooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@4100
0oooool02Ol@413ooooooooooooooooo410@ooooool0003ooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo000000;ooooo0ol0000Gooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0M_ooool008[ooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Wo0000ooooooooooooooooo`000?oooooo0000
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`1fooooo`00Roooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool02Ol0003ooooooooooooooooo0000ooooool0003oooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo07Kooooo002<ooooo`05o`000?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooo0000oa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo07Oooooo0028ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`06o`000?mgMgOoV9RHoooo
oonHV9SoMgMg0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Co0000oooooooooooo0000
6_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo07Oooooo0028ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP02ooooo`06o`000?o^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Co0000oooooooooooo00006_ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo07Oooooo002Oooooo`03o`000?oooooooooo00gooooo00Go0000oooooooooooo
ooooo`00000Jooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0Moooool009oooooo
00?o0000ooooooooool03Oooool01?l0003oooooooooooooool2o`0001Wooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`1hooooo`00Woooool00ol0003oooooooooo`0=ooooo`05o`00
0?ooooooooooooooool000006_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo07So
oooo002Oooooo`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00000Kooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool0N?ooool009oooooo00?o0000ooooooooool0
3Oooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`1hooooo`00Woooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool0
00006oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo07Wooooo002Oooooo`03o`00
0?oooooooooo00gooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0NOooool00:3ooooo00?o0000ooooooooool03?ooool01Ol0003ooooo
oooooooooooo000001_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1iooooo`00
X?ooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooooooo`;o00006_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo07Wooooo002Pooooo`03o`000?oooooooooo00cooooo
00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0N_ooool00:3ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1jooooo`00X?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo07[ooooo002Pooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0N_ooool00:3ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`1jooooo`00X?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo07_o
oooo002Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Noooool00:7ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`;o00006oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo07_ooooo002Qooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0Noooool00:7ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1loooo
o`00XOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo07cooooo002:ooooo`;o0000
00Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^o`000?l0003o<S8bonk^kP03ooooo`06onk^k_lb<S;o0000oc8b<_o^
k^ko00001Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0O?ooool008_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMol0003ooooooiRHV?mgMgL00ooo
ool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000Gooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo07cooooo0028ooooo`Go00000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo0000
ooooool@41000oooool01_l@413ooooooooooooooooo410@o`0000Gooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo07gooooo0028ooooo`04odA4A?oM
gMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003oooooo`000?oooooo000000?ooooo00Co0000oooooooooooooooo0_l0
0005ooooo`?o00006oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo07gooooo0028
ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003oooooo`000?oooooo000000?ooooo00Co0000oooo
oooooooooooo0_l00005ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`1mooooo`00ROooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@ooooool0003ooooo
oa0@4003ooooo`06oa0@4?ooooooooooooooool@413o00001Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0OOooool008Wooooo00?ok^k^odA4A?l0
00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9So0000oiRHV?mgMgL00oooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000Go
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo07go
oooo002:ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bo`000006ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`1nooooo`00X_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo07kooooo002Rooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0O_ooool00:;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`;o00007Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo07kooooo002Rooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0Ooooool00:;ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`1oooooo`00X_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo07oooooo002Soooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Ooooool00:?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`20ooooo`00Xoooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo083ooooo002Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool2o`0001kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`20ooooo`00Y?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo083ooooo002Tooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0POooool00:Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`21ooooo`00Y?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo087ooooo
002Uooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0P_ooool00:Gooooo00Go0000
ooooooooooooooooo`000009ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`22ooooo`00YOooool01Ol0003ooooooooooooooooo000000Wooooo0_l0
000Oooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0P_ooool00:Kooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0P_ooool00:Kooooo0ol0000:ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`23ooooo`00/oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Poooool00;?ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo08?ooooo0028ooooo`05onk^
k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo08?ooooo0028ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo08Cooooo0028ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo08Cooooo0028ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000Oooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0Q?ooool008Sooooo00Go0000oeEEEOl0003o410@olc<c003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0QOooool008Sooooo
00?oEEEEohN7Qoooool01Oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo08Gooooo0028ooooo`03omgMgOl@413oV9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`25ooooo`00ROooool01?o<c<coA4A4o`000?l@4103oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Q_ooool00;?ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Kooooo
002cooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`27ooooo`00/oooool2o`0002?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`28
ooooo`00/oooool00ol0003oooooooooo`0Sooooo`05o`000?ooooooooooooooool00000R_ooool0
0;?ooooo00?o0000ooooooooool08oooool4o`0008_ooooo002cooooo`03o`000?oooooooooo02Co
oooo0_l0002<ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002<ooooo`05
ob4Q8Ol0003o0000odA4A?oMgMd0eoooool008oooooo00?oMgMgoc8b<_ooool0>_ooool00onj^[[o
<S8booooo`02ooooo`04o`000?ooooooooooo`0000Sooooo00?oMgMgofIVI_ooool02?ooool00omV
IVKoMgMgooooo`06ooooo`03o`000?nj^[[ooooo07Cooooo002@ooooo`03o`000?oooooooooo03[o
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Gooooo00?ogMgMoa0@
4?o^k^h02Oooool00oo^k^ko410@omgMg@06ooooo`;o<S8bMOooool005?ooooo00Ko410@ob4Q8Ol0
003o0000odA4A?oMgMd2ooooo`04oa0@4?l0003o0000ooooo`;o000000Co410@ooooooo^k^koEEEE
0_l000001_mEEEGok^k^ooooooooooook^k^oeEEE@;o000000?oEEEEonk^k_ooool00_ooool01OnH
V9So0000o`000?m4A4Co^[Zj00?ooooo1Ol00002ooooo`04oa0@4?l0003o0000ooooo`;o000000So
410@ooooooo^k^koEEEEo`000?l@413oc<c<o`0000Cooooo0_l00002ooooo`07o`000?oooooooooo
o`000?l@413ok^k^oeEEE@02o`000003odA4A?nj^[[ooooo00;ooooo00GoV9RHo`000?l0003oA4A4
okZj^P02ooooo`04oa0@4?l0003o0000ooooo`;o000000Co410@ooooooo^k^koEEEE0_l000001_mE
EEGok^k^ooooooooooook^k^oeEEE@;o000000?oV9RHo`000?l@41001_ooool01onHV9So410@o`00
0?l0003oZJVYooooool000000_ooool00ol0003oooooooooo`05ooooo`03oeEEEOnHV9Sooooo00;o
oooo0_l00002ooooo`;o00000_ooool00on7QhOoIVIVooooo`05ooooo`03ohN7Qol0003o^[Zj00_o
oooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`06ooooo`05oiRHV?l@413o0000
oc8b<_o<c<`0EOooool005?ooooo00Ko0000ohN7QoooooooooooohN7QolQ8B43ooooo`05o`000?oo
ooooooooooooool000000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@;ooooo00KoEEEEogMg
MoooooooooooogMgMomEEED3ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001Oooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01_mEEEGoMgMgooooooo^k^koEEEE
o`0000Gooooo00Co0000oooooooooooo00000_ooool02?l0003ooooooeEEEOmgMgOoooooonk^k_mg
MgOo410@0oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0_ooool01_mEEEGoMgMgooooooo^k^koEEEE
o`0000Oooooo00Ko0000ojVYZOmEEEGoV9RHoeEEEOnj^[X3o`0000Sooooo00?o0000ooooooooool0
0_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?ok^k^o`000?ooool01Oooool00oo<
c<co0000oa0@400<ooooo`06o`000?ooooooooooooooool0003ooooo1_l00002ooooo`05oa0@4?nj
^[[oooooogMgMolb<S80EOooool005?ooooo00Ko8B4Qooooooooooooooooonk^k_l00003ooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Cooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`000002ooooo`06o`000?ooooooooooooooooo^k^ko00001Oooool01?l0
003oooooooooool00002ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool01Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00003ooooo`03onk^k_l0003ooooo00Kooooo00Ko<S8bonk^k_nHV9SoEEEEomgMgOl@410;oooo
o`03oc8b<_oooooooooo00?ooooo00CogMgMo`000?l@413oc<c<1?ooool00ol0003oooooooooo`0C
ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`1Cooooo`00E?ooool0
1OoMgMgoV9RHogMgMol@413oIVIV00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo0000
00Wooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000
ooooooooooooooooonk^k_l00005ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool0
00001Ol00003ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool00oo^k^ko0000ooooo`06
ooooo`07okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c00:ooooo`03oc8b<_oooooooooo00?ooooo
00Cok^k^ob4Q8Ol@413ok^k^1?ooool00ol0003oooooooooo`0Cooooo`06o`000?oooooooooooooo
ool0003ooooo1_l00005ooooo`03ojVYZOl@413ooooo05Cooooo001Cooooo`05ofIVI_l@413oEEEE
ohN7Qonj^[X01?ooool01Ol0003oMgMgoooooonYZJWo000000;ooooo00KoEEEEogMgMooooooooooo
ogMgMomEEED2ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00?ooooo00Go0000ohN7QoooooooZJVYo`000002ooooo`06oeEEEOmg
MgOoooooonk^k_mEEEGo00001Oooool03_l0003oc<c<olc<c?l0003oZJVYomgMgOlQ8B7ooooooeEE
EOn7QhOok^k^oooooon7QhOo<S8b0oooool00ol0003oooooooooo`05ooooo`05o`000?mgMgOooooo
ojVYZOl000000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@;ooooo00KoIVIVogMgMooooooo
k^k^oeEEEOl00007ooooo`07onk^k_l0003oooooo`000?ooooooIVIVohN7Q`0:ooooo`03o`000?o^
k^kooooo00?ooooo00Co8B4QogMgMomgMgOo<S8b0oooool00oo^k^ko0000ooooo`0Dooooo`05o`00
0?n7QhOoooooojVYZOl000002oooool00ol@413o0000okZj^P1Eooooo`00Doooool01_l0003ok^k^
ooooooooooooc<c<o`0000?ooooo00Go0000ogMgMol0003o0000oiRHV002ooooo`06onk^k_mEEEGo
0000o`000?mEEEGok^k^0_ooool02?o^k^koEEEEo`000?l0003oEEEEonk^k_oooooo410@1Ol00004
ooooo`03oa0@4?l0003o000000Cooooo00?o410@o`000?mgMgL00_l000002_nHV9Soooooooooooo^
k^koEEEEo`000?lQ8B7oZJVYo`000?l@4103ooooo`0;oa0@4?l0003o8B4Qo`000?mgMgOo410@o`00
0?nYZJWoooooonk^k_mEEED00_l000001?m4A4Cok^k^ooooool@4105o`0000Cooooo00Go0000ogMg
Mol0003o0000oiRHV002ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^0_ooool01_o^k^koEEEE
o`000?l@413oc<c<o`0000Oooooo00CoIVIVoiRHV?oooooo<S8b0_nj^[X00ol0003oooooooooo`08
ooooo`03oeEEEOmgMgOooooo00;ooooo0_l00002ooooo`;o00000_ooool00omgMgOoEEEEooooo`0C
ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool02_ooool00onj^[[o8B4Qooooo`1D
ooooo`00Doooool01_lb<S;oQhN7ooooooo^k^koIVIVo`0000?ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`08ooooo`03ofIVI_n7QhOooooo00_ooooo00?ogMgMoa0@4?o^k^h02Ooo
ool00oo^k^ko410@omgMg@0Sooooo`05oa0@4?nHV9SooooookZj^_l00000EOooool005?ooooo00Ko
k^k^odA4A?l0003o0000oc8b<_l@4103ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`08ooooo`03ojVYZOm4A4Cooooo00cooooo00?oMgMgofIVI_oo
ool02?ooool00omVIVKoMgMgooooo`0Sooooo`05ojVYZOl@413o0000oa0@4?nYZJT0EOooool005_o
oooo00?o410@o`000?ooool08?ooool00ol@413oooooooooo`0]ooooo`03oa0@4?l0003ooooo017o
oooo0_l0002Tooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-9.21355, -70324.6, \
0.0641612, 869.111}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0595238 0.281495 1.2108e-06 [
[.05357 .26899 -12 -9 ]
[.05357 .26899 12 0 ]
[.20238 .26899 -6 -9 ]
[.20238 .26899 6 0 ]
[.35119 .26899 -12 -9 ]
[.35119 .26899 12 0 ]
[.64881 .26899 -9 -9 ]
[.64881 .26899 9 0 ]
[.79762 .26899 -3 -9 ]
[.79762 .26899 3 0 ]
[.94643 .26899 -9 -9 ]
[.94643 .26899 9 0 ]
[.4875 .03933 -42 -4.5 ]
[.4875 .03933 0 4.5 ]
[.4875 .16041 -42 -4.5 ]
[.4875 .16041 0 4.5 ]
[.4875 .40258 -36 -4.5 ]
[.4875 .40258 0 4.5 ]
[.4875 .52366 -36 -4.5 ]
[.4875 .52366 0 4.5 ]
[.5 .63053 -79.625 0 ]
[.5 .63053 79.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05357 .28149 m
.05357 .28774 L
s
[(-7.5)] .05357 .26899 0 1 Mshowa
.20238 .28149 m
.20238 .28774 L
s
[(-5)] .20238 .26899 0 1 Mshowa
.35119 .28149 m
.35119 .28774 L
s
[(-2.5)] .35119 .26899 0 1 Mshowa
.64881 .28149 m
.64881 .28774 L
s
[(2.5)] .64881 .26899 0 1 Mshowa
.79762 .28149 m
.79762 .28774 L
s
[(5)] .79762 .26899 0 1 Mshowa
.94643 .28149 m
.94643 .28774 L
s
[(7.5)] .94643 .26899 0 1 Mshowa
.125 Mabswid
.08333 .28149 m
.08333 .28524 L
s
.1131 .28149 m
.1131 .28524 L
s
.14286 .28149 m
.14286 .28524 L
s
.17262 .28149 m
.17262 .28524 L
s
.23214 .28149 m
.23214 .28524 L
s
.2619 .28149 m
.2619 .28524 L
s
.29167 .28149 m
.29167 .28524 L
s
.32143 .28149 m
.32143 .28524 L
s
.38095 .28149 m
.38095 .28524 L
s
.41071 .28149 m
.41071 .28524 L
s
.44048 .28149 m
.44048 .28524 L
s
.47024 .28149 m
.47024 .28524 L
s
.52976 .28149 m
.52976 .28524 L
s
.55952 .28149 m
.55952 .28524 L
s
.58929 .28149 m
.58929 .28524 L
s
.61905 .28149 m
.61905 .28524 L
s
.67857 .28149 m
.67857 .28524 L
s
.70833 .28149 m
.70833 .28524 L
s
.7381 .28149 m
.7381 .28524 L
s
.76786 .28149 m
.76786 .28524 L
s
.82738 .28149 m
.82738 .28524 L
s
.85714 .28149 m
.85714 .28524 L
s
.8869 .28149 m
.8869 .28524 L
s
.91667 .28149 m
.91667 .28524 L
s
.02381 .28149 m
.02381 .28524 L
s
.97619 .28149 m
.97619 .28524 L
s
.25 Mabswid
0 .28149 m
1 .28149 L
s
.5 .03933 m
.50625 .03933 L
s
[(-200000)] .4875 .03933 1 0 Mshowa
.5 .16041 m
.50625 .16041 L
s
[(-100000)] .4875 .16041 1 0 Mshowa
.5 .40258 m
.50625 .40258 L
s
[(100000)] .4875 .40258 1 0 Mshowa
.5 .52366 m
.50625 .52366 L
s
[(200000)] .4875 .52366 1 0 Mshowa
.125 Mabswid
.5 .06355 m
.50375 .06355 L
s
.5 .08777 m
.50375 .08777 L
s
.5 .11198 m
.50375 .11198 L
s
.5 .1362 m
.50375 .1362 L
s
.5 .18463 m
.50375 .18463 L
s
.5 .20885 m
.50375 .20885 L
s
.5 .23306 m
.50375 .23306 L
s
.5 .25728 m
.50375 .25728 L
s
.5 .30571 m
.50375 .30571 L
s
.5 .32993 m
.50375 .32993 L
s
.5 .35414 m
.50375 .35414 L
s
.5 .37836 m
.50375 .37836 L
s
.5 .42679 m
.50375 .42679 L
s
.5 .45101 m
.50375 .45101 L
s
.5 .47522 m
.50375 .47522 L
s
.5 .49944 m
.50375 .49944 L
s
.5 .01512 m
.50375 .01512 L
s
.5 .54787 m
.50375 .54787 L
s
.5 .57209 m
.50375 .57209 L
s
.5 .5963 m
.50375 .5963 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -140.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Shooting) show
117.000 13.000 moveto
(method) show
159.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
165.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
170.250 13.000 moveto
(H) show
176.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
182.250 13.000 moveto
(L) show
188.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
200.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
206.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
212.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
218.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .28149 m
.02605 .28149 L
.02846 .28149 L
.03072 .28149 L
.03279 .28149 L
.03521 .28149 L
.03784 .28149 L
.04032 .28149 L
.04262 .28149 L
.04498 .28149 L
.0472 .28149 L
.04963 .28149 L
.05224 .28149 L
.05497 .28149 L
.05757 .28149 L
.0599 .28149 L
.06244 .28149 L
.0653 .28149 L
.06799 .28149 L
.07041 .28149 L
.07302 .28149 L
.07588 .28149 L
.07889 .28149 L
.08147 .28149 L
.08429 .2815 L
.08694 .2815 L
.08936 .2815 L
.09215 .2815 L
.09479 .2815 L
.09722 .2815 L
.09948 .2815 L
.10195 .2815 L
.10458 .2815 L
.10696 .2815 L
.10947 .2815 L
.11395 .2815 L
.11645 .2815 L
.11877 .2815 L
.12133 .2815 L
.12405 .2815 L
.12641 .2815 L
.12898 .2815 L
.13124 .2815 L
.13363 .2815 L
.13578 .2815 L
.13816 .2815 L
.14233 .2815 L
.14482 .2815 L
.14754 .2815 L
.14994 .28151 L
Mistroke
.15249 .28151 L
.15502 .28151 L
.15731 .28152 L
.16178 .28153 L
.16447 .28153 L
.16695 .28154 L
.16962 .28156 L
.17254 .28157 L
.17747 .28161 L
.18016 .28163 L
.18267 .28166 L
.18769 .28174 L
.19053 .2818 L
.19315 .28186 L
.19796 .28201 L
.20306 .28224 L
.20762 .28251 L
.21189 .28284 L
.21658 .28333 L
.22163 .28403 L
.22661 .28495 L
.23123 .28607 L
.2363 .28766 L
.24171 .28988 L
.24741 .29296 L
.25278 .29673 L
.25757 .30095 L
.26282 .30669 L
.27257 .32107 L
.2779 .33135 L
.28288 .34273 L
.30134 .40146 L
.31995 .48382 L
.32978 .53004 L
.34022 .57274 L
.34545 .58872 L
.34843 .59551 L
.3498 .59797 L
.35123 .60009 L
.35245 .60149 L
.3531 .60207 L
.35379 .60258 L
.35501 .60315 L
.35614 .60332 L
.35682 .60324 L
.35756 .603 L
.35827 .60263 L
.35891 .60215 L
.36014 .6009 L
.36143 .59905 L
Mistroke
.36382 .59425 L
.36638 .58699 L
.3688 .57807 L
.37101 .56815 L
.37641 .53676 L
.38155 .49783 L
.40159 .28332 L
.41032 .1811 L
.41976 .08734 L
.42233 .06715 L
.42504 .049 L
.42755 .03537 L
.42878 .0299 L
.4299 .02562 L
.43095 .02222 L
.4321 .01923 L
.43331 .01687 L
.43445 .01542 L
.43571 .01472 L
.43635 .01472 L
.43705 .01499 L
.43829 .01619 L
.43945 .01814 L
.44067 .02106 L
.44201 .02527 L
.44472 .03692 L
.44722 .05136 L
.44954 .06778 L
.46042 .17643 L
.47917 .41028 L
.48431 .46316 L
.48712 .48719 L
.48975 .50596 L
.49217 .51983 L
.49439 .52939 L
.49565 .53347 L
.49685 .5364 L
.49811 .53848 L
.49883 .5392 L
.49949 .53956 L
.50019 .53964 L
.50084 .53942 L
.50154 .53887 L
.50229 .53793 L
.50355 .53554 L
.50426 .53373 L
.50492 .53175 L
.5073 .52239 L
.50984 .50857 L
.5128 .48779 L
Mistroke
.5156 .46393 L
.52085 .40999 L
.53063 .2892 L
.54101 .1597 L
.54558 .11066 L
.55051 .06739 L
.55333 .04792 L
.55591 .03385 L
.55715 .02843 L
.5585 .02352 L
.55978 .01987 L
.56097 .01734 L
.56213 .01568 L
.56338 .01479 L
.56456 .01479 L
.56565 .01552 L
.56663 .01678 L
.56771 .0188 L
.56884 .02163 L
.56989 .02491 L
.5723 .03466 L
.57449 .0462 L
.57941 .08051 L
.58932 .17707 L
.59849 .28426 L
.60919 .40808 L
.61443 .46166 L
.61924 .50436 L
.62353 .53635 L
.62822 .56427 L
.63293 .58465 L
.6355 .59254 L
.6379 .59789 L
.63918 .6 L
.63986 .60089 L
.64058 .60169 L
.6419 .60273 L
.64311 .60323 L
.64428 .6033 L
.64537 .60302 L
.64657 .60233 L
.64786 .60117 L
.64922 .59947 L
.65071 .59711 L
.65341 .59152 L
.6585 .57709 L
.66883 .53629 L
.6782 .49262 L
.68913 .44152 L
.69918 .39944 L
Mistroke
.70838 .36724 L
.71846 .33951 L
.72859 .31907 L
.73413 .31063 L
.73929 .30424 L
.74431 .2992 L
.74976 .29483 L
.75457 .2918 L
.75967 .28925 L
.76426 .28746 L
.76932 .28592 L
.77392 .28484 L
.77824 .28405 L
.78294 .28339 L
.78809 .28285 L
.79346 .28244 L
.79845 .28216 L
.80314 .28197 L
.80741 .28185 L
.81232 .28174 L
.81696 .28167 L
.8216 .28162 L
.82424 .28159 L
.8267 .28158 L
.83167 .28155 L
.83446 .28154 L
.83701 .28153 L
.84154 .28152 L
.84411 .28151 L
.84648 .28151 L
.85084 .28151 L
.85304 .2815 L
.85547 .2815 L
.86037 .2815 L
.86284 .2815 L
.86554 .2815 L
.86785 .2815 L
.87033 .2815 L
.87478 .2815 L
.87748 .2815 L
.8804 .2815 L
.88315 .2815 L
.8857 .2815 L
.88819 .2815 L
.89052 .2815 L
.89295 .2815 L
.89563 .2815 L
.8982 .2815 L
.90059 .2815 L
.90322 .2815 L
Mistroke
.90601 .2815 L
.90868 .2815 L
.91119 .2815 L
.91344 .2815 L
.91588 .2815 L
.91812 .28149 L
.92057 .28149 L
.92314 .28149 L
.92553 .28149 L
.92777 .28149 L
.92982 .28149 L
.93217 .28149 L
.93441 .28149 L
.93678 .28149 L
.939 .28149 L
.94144 .28149 L
.94407 .28149 L
.94667 .28149 L
.94942 .28149 L
.95176 .28149 L
.95432 .28149 L
.95674 .28149 L
.95894 .28149 L
.96147 .28149 L
.96387 .28149 L
.96608 .28149 L
.96813 .28149 L
.97037 .28149 L
.97275 .28149 L
.97453 .28149 L
.97619 .28149 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00W_ooool2o`0001?ooooo0_l0000Booooo`;o0000Woooool009gooooo00?o0000oooo
ool000004oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo000009kooooo002Looooo`05
o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Aooooo`04o`000?oooooooooo
o`0009gooooo002Looooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0@
ooooo`05o`000?ooooooooooooooool00000WOooool009cooooo00Go0000ooooooooooooooooo`00
000Booooo`03o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`00002Mooooo`00P?oo
ool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o000000?ooooo00Go0000oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0V_ooool0083ooooo00GoV9RHob4Q8Oo^k^koooooodA4
A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHo`000003ooooo`05ogMgMol0003ooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo09[ooooo001hooooo`Ko00000oooool00onHV9So8B4Qonk^kP04
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooo0000oa0@4003ooooo`05oa0@4?l0003oooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo09[ooooo0022ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`02o`0000?ooooo0_l00002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`04ooooo`?o00003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09[ooooo
0023ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`02o`0000?ooooo0_l00002ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Jooooo`00Q?ooool01Ol0003o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`09oa0@4?oooooo
ooooooooool@413oooooo`000?oooooo410@00?ooooo00Go410@ooooool0003ooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0V_ooool0083ooooo00Go0000okZj^_ooooooV9RHoa0@4003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?l0003oV9RHogMgM`03ooooo`05ogMgMonHV9So0000oiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo09[ooooo0020ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`2Jooooo`00V_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
09[ooooo002Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0VOooool009[ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Iooooo`00V_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00kooooo0_l0000?ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0VOooool009[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2I
ooooo`00V_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09Wooooo002Jooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0V?ooool009[ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`2Hooooo`00VOooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo09Sooooo002Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0V?ooool0
09Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Hooooo`00VOooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00gooooo0_l0000>ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0V?ooool009Wooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2Hooooo`00VOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo09Sooooo002I
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Uoooool009Wooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`2Gooooo`00VOooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo09Oooooo002Hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
Uoooool009Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Gooooo`00V?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo0_l0000=ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0Uoooool009Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`2Gooooo`00V?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo09Oo
oooo002Hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Uoooool009Sooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`2Gooooo`00V?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo09Oooooo002Hooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0U_ooool009Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2Fooooo`00
Uoooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0_l0000<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0U_ooool009Oooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`2Fooooo`00Uoooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo09Kooooo002Gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0U_ooool009Oo
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2Fooooo`00POooool4o`000008oa0@
4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_oo
ool01_l0003ok^k^oc8b<_l0003o<S8bonk^kP?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l00002
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0U_ooool008?ooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`06o`00
0?mgMgOoV9RHoooooonHV9SoMgMg0oooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`2Fooooo`00N?ooool6o`0000Gooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4002ooooo`03
o`000?l@413ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?l0003ooooo
ooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2Fooooo`00Poooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo0_l0
0003ooooo`05o`000?ooooooooooooooool000000oooool2o`0000;ooooo00Go0000oooooooooooo
ooooo`000006ooooo`?o00002_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo09Ko
oooo0023ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000_ooool2o`0000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?oooooo0000ooooool000000oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2Eooooo`00Poooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool02Ol@413ooooooooo
oooooooo410@ooooool0003ooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413oooooo`000?oooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0UOooool008?ooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00goMgMgoiRHV?ooooooV9RH
ogMgMooooooo0000oooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00goMgMgoiRHV?ooooooV9RH
ogMgMooooooo0000oooooomgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo09Gooooo0021ooooo`03oeEEEOmVIVKo
000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`0=onk^k_lb<S;o0000oc8b<_o^k^ko
ooooo`000?ooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`0=onk^k_lb<S;o0000oc8b<_o^k^ko
ooooo`000?ooooook^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`2Eooooo`00U_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo09Gooooo002Fooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0UOooool009Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2Eooooo`00
U_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l0000:ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0UOooool009Kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`2Eooooo`00U_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo09Gooooo002Fooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0UOooool009Ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Dooooo`00UOooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo09Cooooo002Eooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0U?ooool009Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`09
ooooo`;o00002_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09Cooooo002Eoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0U?ooool009Gooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`2Dooooo`00UOooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo09Cooooo002Eooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0U?oo
ool009Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Dooooo`00UOooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo09Cooooo002Eooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0U?ooool009Gooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`09ooooo`;o00002Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo09?ooooo
002Dooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Toooool009Cooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`2Cooooo`007?ooool00ol0003ok^k^ooooo`05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM02Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@0Rooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@03ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool01?ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd08oooool01Om4A4Co0000o`000?lb<S;ogMgM02Gooooo00?o0000onk^
k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`007?ooool00omE
EEGoZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Vooooo`03ogMgMolb<S;ooooo
027ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`02
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo02Gooooo00?oMgMgoc8b<_ooool09?oo
ool00omEEEGoZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Gooooo`004_ooool6
o`0000Cooooo00?oZJVYoeEEEOooool04?ooool00ol0003oooooooooo`0Iooooo`Ko00001oooool0
0ol0003oooooooooo`0Hooooo`Ko00000oooool00onHV9So8B4Qonk^kP0Aooooo`05o`000?oooooo
ooooooooool000004oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Sooooo`03ojVYZOmEEEGooooo013ooooo00?o
0000ooooooooool05_ooool001gooooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8booooo`0V
ooooo`03ogMgMolb<S;ooooo02?ooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`02
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00onHV9So8B4Qonk^kP0?
ooooo`03ogMgMolb<S;ooooo02Gooooo00?oMgMgoc8b<_ooool09Oooool00olQ8B7oooooooooo`0>
ooooo`03ogMgMolb<S;ooooo01Oooooo000Mooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Tooooo`05o`000?lQ8B7o0000oc8b<_o<c<`09Oooool00omgMgOoIVIVoooo
o`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00Oooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<02?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00Vooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Hooooo`007Oooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`;o00002Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo02Sooooo00?oZJVYogMgMoooool02oooool00ol0
003oooooooooo`0Jooooo`006_ooool01Ol@413ooooooooooooooooo<S8b00cooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Tooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool0
1Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0Uooooo`05oa0@4?oooooooooooooooolb<S803?ooool00ol0003oooooooooo`0Jooooo`006_oo
ool5o`0000cooooo1?l0000Uooooo`Co00008oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo
1?l00004ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool01OnHV9So410@
o`000?lQ8B7oc<c<00cooooo1?l0000Tooooo`Co00009?ooool5o`0000cooooo1?l0000Iooooo`00
U?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo09?ooooo002Cooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0T_ooool009?ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`2Booooo`00Toooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
09;ooooo002Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0T_ooool000oooooo
ool0001:o`00013ooooo000Gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`[o00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Cooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo2_l00009ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Fooooo`008Oooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo00Kooooo0ol0000Tooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02;ooooo0ol00008ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool08?ooool005kooooo0_l0000cooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0<Oooool2o`0005oooooo001Pooooo`;o0000<Oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0Goooool0
06;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
02kooooo0_l0001Rooooo`00Hoooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Rooooo`00I?ooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`1Sooooo`00I?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool01oooool2o`0000Sooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo06Cooooo001Uooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo06Cooooo001Voooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo06Gooooo001Wooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo06Gooooo001Xooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo06Kooooo001Yooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo06Oooooo001Yooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo06Oooooo001Yooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo06Sooooo001Zooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`06ooooo`;o00001oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0J?ooool006[ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0JOooool006[ooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0JOooool006_ooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool0J_ooool006cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0J_ooool006cooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0Joooool006cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool0Joooool006gooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0K?oo
ool006gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00Gooooo0_l00006ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`1/ooooo`00KOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1/ooooo`00K_ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`1]ooooo`00K_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`1]ooooo`00K_ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`1^ooooo`00Koooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`1^ooooo`00Koooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1^oooo
o`00Koooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`1_ooooo`00Koooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo06oooooo001`ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo06oooooo001`ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo073ooooo001`ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
073ooooo001aooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo073ooooo001aooooo`03o`000?oooooooooo00gooooo
1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0_ooool01_l0003ok^k^oc8b<_l0
003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o000000Kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0L?ooool0
077ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00_ooool01_l0003oMgMgoiRHV?ooooooV9RHogMgM`?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
000000Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0LOooool007;ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000_ooool00ol0003o410@ooooo`02
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4003ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0LOooool007;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000_ooool2o`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool01?ooool3o`0000Cooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo077ooooo001booooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0LOooool007;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41000_ooool00ol0003o410@ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0L_ooool007?ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool01_l0003oMgMg
oiRHV?ooooooV9RHogMgM`?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So000000Kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
L_ooool007?ooooo00?o0000ooooooooool02oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00_ooool01_l0003ok^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;o000000Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0L_ooool007?ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0L_oo
ool007?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0L_ooool007Cooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Loooool007Co
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00?o
oooo0_l00004ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`1cooooo`00M?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`1cooooo`00M?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`1cooooo`00M?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`1cooooo`00MOooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1doooo
o`00MOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`1dooooo`00MOooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1dooooo`00MOoo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`1dooooo`00M_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool00_ooool2o`0000?ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo07Gooooo001fooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
07Gooooo001fooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo07Gooooo001fooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo07Gooooo
001gooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo07Kooooo001gooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo07Kooooo001goooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo07Kooooo001gooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo07Kooooo001gooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`;o0000
0oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
Moooool007Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Oooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0Moooool007Sooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Oooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0Moooool007Sooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Moooool007Sooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
N?ooool007Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Pooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0N?ooool007Wooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Pooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0N?ooool007Wooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0N?ooool007Wooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;o000000?o
ooooo`000?ooool08_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07Wooooo001i
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool08Oooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`1iooooo`00NOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo027ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0NOooool007[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Q
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo07Wooooo001jooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool08Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1iooooo`00N_ooool00ol0003oooooooooo`03
ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o000000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo07[ooooo001j
ooooo`03o`000?oooooooooo00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonH
V9Soooooo`000?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00Ko0000oooooooooooo0000ooooool0000Tooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0N_ooool007[ooooo00?o0000ooooooooool01?ooool00onHV9So8B4Q
onk^kP04ooooo`05oa0@4?ooooooooooo`000?l@41000oooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Ko0000oooooooooooo0000ooooool0000Uoooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0N_ooool007_ooooo00?o0000oooooooo
ool01?ooool00onHV9So8B4Qonk^kP03ooooo`03o`000?oooooooooo00;o00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooool00000
0_l0000Uooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0N_ooool007_ooooo00?o
0000ooooooooool01Oooool00omgMgOoIVIVooooo`02ooooo`03o`000?oooooooooo00;o00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000
ooooool0003oooooo`00000Uooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0N_oo
ool007_ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo410@00;ooooo00?o
0000oa0@4?ooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00Cooooo00Go0000ooooool0003oooooo`00000Uooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0Noooool007_ooooo00?o0000ooooooooool00_ooool01Ol0003o^[ZjoooooonH
V9So410@00?ooooo00GoMgMgoiRHV?oooooo0000ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool3o`0002Kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`1kooooo`00Noooool00ol0003oooooooooo`02ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?l0003ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`?o00009_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo07_ooooo001looooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0Noooool007cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1koooo
o`00O?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Kooooo0_l0000Wooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0O?ooool007gooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`1looooo`00OOooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo07cooooo001mooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0O?ooool0
07gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1mooooo`00O_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo07gooooo001nooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0OOooool007kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`1mooooo`00Ooooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Oooooo0_l0000Y
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0OOooool007oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1nooooo`00Ooooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo07kooooo001oooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
O_ooool0083ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1oooooo`00P?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo07oooooo0020ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0Ooooool0083ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`20ooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02[ooooo
0_l0000Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0P?ooool008;ooooo00Go
0000ooooooooooooooooo`00000/ooooo`03o`000?oooooooooo02[ooooo00Go0000oooooooooooo
ooooo`000023ooooo`00P_ooool4o`0002gooooo00?o0000ooooooooool0:oooool00ol0003ooooo
o`000024ooooo`00Q?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool0Poooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0
/_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool008cooooo00Go8B4Qo`000?l0003oA4A4omgMg@3Gooooo`00Soooool00omgMgOo<S8boooo
o`0jooooo`03okZj^_lb<S;ooooo00;ooooo00Co0000oooooooooooo00002?ooool00omgMgOoIVIV
ooooo`08ooooo`03ofIVI_mgMgOooooo00Kooooo00?o0000okZj^_ooool0M?ooool0093ooooo00?o
0000ooooooooool0>_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0
1Oooool00ooMgMgo410@onk^kP09ooooo`03onk^k_l@413ogMgM00Kooooo0_lb<S9eooooo`00Dooo
ool01_l@413o8B4Qo`000?l0003oA4A4omgMg@;ooooo00Co410@o`000?l0003ooooo0_l000001?l@
413oooooonk^k_mEEED2o`000006oeEEEOo^k^koooooooooooo^k^koEEEE0_l000000omEEEGok^k^
ooooo`02ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool5o`0000;ooooo00Co410@o`000?l0
003ooooo0_l000002?l@413oooooonk^k_mEEEGo0000oa0@4?o<c<co00001?ooool2o`0000;ooooo
00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE00;o000000?oA4A4okZj^_ooool00_ooool01OnH
V9So0000o`000?m4A4Co^[Zj00;ooooo00Co410@o`000?l0003ooooo0_l000001?l@413oooooonk^
k_mEEED2o`000006oeEEEOo^k^koooooooooooo^k^koEEEE0_l000000onHV9So0000oa0@4006oooo
o`07oiRHV?l@413o0000o`000?nYZJWoooooo`000002ooooo`03o`000?oooooooooo00Gooooo00?o
EEEEoiRHV?ooool00_ooool2o`0000;ooooo0_l00002ooooo`03ohN7QomVIVKooooo00Gooooo00?o
QhN7o`000?nj^[X02oooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00Sooooo
0_l000000ol@413oooooooooo`1Cooooo`00Doooool01_l0003oQhN7ooooooooooooQhN7ob4Q8@?o
oooo00Go0000ooooooooooooooooo`000002ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0_oo
ool01_mEEEGoMgMgooooooooooooMgMgoeEEE@?ooooo00Go410@okZj^_o^k^koMgMgoa0@4005oooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`06oeEEEOmgMgOo
ooooonk^k_mEEEGo00001Oooool01?l0003oooooooooool00002ooooo`08o`000?ooooooEEEEogMg
Moooooook^k^ogMgMol@4103ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED2ooooo`06oeEEEOmgMgOo
ooooonk^k_mEEEGo00001oooool01_l0003oZJVYoeEEEOnHV9SoEEEEokZj^P?o00002?ooool00ol0
003oooooooooo`02ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo^k^ko0000oooo
o`05ooooo`03olc<c?l0003o410@00cooooo00Ko0000ooooooooooooooooo`000?ooool6o`0000Go
oooo00?o0000ooooooooool0E?ooool005?ooooo00Ko8B4Qooooooooooooooooonk^k_l00003oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`000002ooooo`06o`000?ooooooooooooooooo^k^ko00001Oooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00003ooooo`03onk^k_l0003ooooo00Kooooo00Ko<S8bonk^k_nHV9SoEEEEomgMgOl@410;
ooooo`03oc8b<_oooooooooo00?ooooo00CogMgMo`000?l@413oc<c<1?ooool00ol0003ooooooooo
o`0Cooooo`05o`000?ooooooooooooooool000002Oooool5o`0005Gooooo001Dooooo`05omgMgOnH
V9SoMgMgoa0@4?mVIVH00oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000002Oooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003ooooooooo
ooooooook^k^o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000005o`00
00?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03onk^k_l0003ooooo00Kooooo00Oo
^[ZjodA4A?o<c<co8B4Qooooool@413oc<c<00[ooooo00?o<S8booooooooool00oooool01?o^k^ko
8B4Qoa0@4?o^k^h4ooooo`03o`000?oooooooooo01?ooooo00Ko0000ooooooooooooooooo`000?oo
ool6o`0000;ooooo00CoA4A4omgMgOoooooo0000E_ooool005?ooooo00GoIVIVoa0@4?mEEEGoQhN7
okZj^P04ooooo`05o`000?mgMgOoooooojVYZOl000000_ooool01_mEEEGoMgMgooooooooooooMgMg
oeEEE@;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED3ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00oooool01Ol0003oQhN7oooooonYZJWo000000;ooooo00KoEEEEogMgMooo
ooook^k^oeEEEOl00005ooooo`0>o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8OooooooEEEEohN7
Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?oooooooooo00Gooooo00Go0000ogMgMoooooooZJVY
o`000002ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0_ooool01_mVIVKoMgMgooooooo^k^ko
EEEEo`0000Oooooo00Ook^k^o`000?oooooo0000oooooomVIVKoQhN700[ooooo00?o0000onk^k_oo
ool00oooool01?lQ8B7oMgMgogMgMolb<S83ooooo`03onk^k_l0003ooooo01Cooooo00Go0000ohN7
QoooooooZJVYo`000009ooooo`04omgMgOmEEEGoooooo`0005Kooooo001Cooooo`06o`000?o^k^ko
ooooooooooo<c<co00000oooool01Ol0003oMgMgo`000?l0003oV9RH00;ooooo00Kok^k^oeEEEOl0
003o0000oeEEEOo^k^h2ooooo`08onk^k_mEEEGo0000o`000?mEEEGok^k^ooooool@4105o`0000Co
oooo00?o410@o`000?l000001?ooool00ol@413o0000ogMgM`02o`00000:oiRHV?ooooooooooonk^
k_mEEEGo0000ob4Q8OnYZJWo0000oa0@40?ooooo00_o410@o`000?lQ8B7o0000ogMgMol@413o0000
ojVYZOooooook^k^oeEEE@02o`000004odA4A?o^k^kooooooa0@40Go00001?ooool01Ol0003oMgMg
o`000?l0003oV9RH00;ooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h2ooooo`06onk^k_mEEEGo
0000oa0@4?o<c<co00001oooool01?mVIVKoV9RHoooooolb<S82okZj^P03o`000?oooooooooo00So
oooo00?oEEEEogMgMoooool00_ooool2o`0000;ooooo0_l00002ooooo`03ogMgMomEEEGooooo01?o
oooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`08ooooo`03ogMgMoo<c<co000005Ko
oooo001Cooooo`06oc8b<_n7QhOoooooonk^k_mVIVKo00000oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Sooooo00?oIVIVohN7Qoooool02oooool00ooMgMgo410@onk^kP09oooo
o`03onk^k_l@413ogMgM02Cooooo00?ok^k^odA4A?l00000E_ooool005?ooooo00Kok^k^odA4A?l0
003o0000oc8b<_l@4103ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`08ooooo`03ojVYZOm4A4Cooooo00cooooo00?oMgMgofIVI_ooool02?ooool0
0omVIVKoMgMgooooo`0Uooooo`03ogMgMol0003ooooo05Gooooo001Kooooo`03oa0@4?l0003ooooo
023ooooo00?o410@ooooooooool0;Oooool00ol@413o0000ooooo`0Aooooo`;o0000Y?ooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-9.21355, -232489, \
0.0641612, 3154.21}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0595238 0.309032 3.36326e-07 [
[.05357 .29653 -12 -9 ]
[.05357 .29653 12 0 ]
[.20238 .29653 -6 -9 ]
[.20238 .29653 6 0 ]
[.35119 .29653 -12 -9 ]
[.35119 .29653 12 0 ]
[.64881 .29653 -9 -9 ]
[.64881 .29653 9 0 ]
[.79762 .29653 -3 -9 ]
[.79762 .29653 3 0 ]
[.94643 .29653 -9 -9 ]
[.94643 .29653 9 0 ]
[.4875 .05679 -42 -4.5 ]
[.4875 .05679 0 4.5 ]
[.4875 .14087 -42 -4.5 ]
[.4875 .14087 0 4.5 ]
[.4875 .22495 -42 -4.5 ]
[.4875 .22495 0 4.5 ]
[.4875 .39311 -36 -4.5 ]
[.4875 .39311 0 4.5 ]
[.4875 .4772 -36 -4.5 ]
[.4875 .4772 0 4.5 ]
[.4875 .56128 -36 -4.5 ]
[.4875 .56128 0 4.5 ]
[.5 .63053 -79.625 0 ]
[.5 .63053 79.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05357 .30903 m
.05357 .31528 L
s
[(-7.5)] .05357 .29653 0 1 Mshowa
.20238 .30903 m
.20238 .31528 L
s
[(-5)] .20238 .29653 0 1 Mshowa
.35119 .30903 m
.35119 .31528 L
s
[(-2.5)] .35119 .29653 0 1 Mshowa
.64881 .30903 m
.64881 .31528 L
s
[(2.5)] .64881 .29653 0 1 Mshowa
.79762 .30903 m
.79762 .31528 L
s
[(5)] .79762 .29653 0 1 Mshowa
.94643 .30903 m
.94643 .31528 L
s
[(7.5)] .94643 .29653 0 1 Mshowa
.125 Mabswid
.08333 .30903 m
.08333 .31278 L
s
.1131 .30903 m
.1131 .31278 L
s
.14286 .30903 m
.14286 .31278 L
s
.17262 .30903 m
.17262 .31278 L
s
.23214 .30903 m
.23214 .31278 L
s
.2619 .30903 m
.2619 .31278 L
s
.29167 .30903 m
.29167 .31278 L
s
.32143 .30903 m
.32143 .31278 L
s
.38095 .30903 m
.38095 .31278 L
s
.41071 .30903 m
.41071 .31278 L
s
.44048 .30903 m
.44048 .31278 L
s
.47024 .30903 m
.47024 .31278 L
s
.52976 .30903 m
.52976 .31278 L
s
.55952 .30903 m
.55952 .31278 L
s
.58929 .30903 m
.58929 .31278 L
s
.61905 .30903 m
.61905 .31278 L
s
.67857 .30903 m
.67857 .31278 L
s
.70833 .30903 m
.70833 .31278 L
s
.7381 .30903 m
.7381 .31278 L
s
.76786 .30903 m
.76786 .31278 L
s
.82738 .30903 m
.82738 .31278 L
s
.85714 .30903 m
.85714 .31278 L
s
.8869 .30903 m
.8869 .31278 L
s
.91667 .30903 m
.91667 .31278 L
s
.02381 .30903 m
.02381 .31278 L
s
.97619 .30903 m
.97619 .31278 L
s
.25 Mabswid
0 .30903 m
1 .30903 L
s
.5 .05679 m
.50625 .05679 L
s
[(-750000)] .4875 .05679 1 0 Mshowa
.5 .14087 m
.50625 .14087 L
s
[(-500000)] .4875 .14087 1 0 Mshowa
.5 .22495 m
.50625 .22495 L
s
[(-250000)] .4875 .22495 1 0 Mshowa
.5 .39311 m
.50625 .39311 L
s
[(250000)] .4875 .39311 1 0 Mshowa
.5 .4772 m
.50625 .4772 L
s
[(500000)] .4875 .4772 1 0 Mshowa
.5 .56128 m
.50625 .56128 L
s
[(750000)] .4875 .56128 1 0 Mshowa
.125 Mabswid
.5 .0736 m
.50375 .0736 L
s
.5 .09042 m
.50375 .09042 L
s
.5 .10724 m
.50375 .10724 L
s
.5 .12405 m
.50375 .12405 L
s
.5 .15769 m
.50375 .15769 L
s
.5 .1745 m
.50375 .1745 L
s
.5 .19132 m
.50375 .19132 L
s
.5 .20813 m
.50375 .20813 L
s
.5 .24177 m
.50375 .24177 L
s
.5 .25858 m
.50375 .25858 L
s
.5 .2754 m
.50375 .2754 L
s
.5 .29222 m
.50375 .29222 L
s
.5 .32585 m
.50375 .32585 L
s
.5 .34266 m
.50375 .34266 L
s
.5 .35948 m
.50375 .35948 L
s
.5 .3763 m
.50375 .3763 L
s
.5 .40993 m
.50375 .40993 L
s
.5 .42675 m
.50375 .42675 L
s
.5 .44356 m
.50375 .44356 L
s
.5 .46038 m
.50375 .46038 L
s
.5 .49401 m
.50375 .49401 L
s
.5 .51083 m
.50375 .51083 L
s
.5 .52764 m
.50375 .52764 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .03997 m
.50375 .03997 L
s
.5 .02315 m
.50375 .02315 L
s
.5 .00634 m
.50375 .00634 L
s
.5 .57809 m
.50375 .57809 L
s
.5 .59491 m
.50375 .59491 L
s
.5 .61173 m
.50375 .61173 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -140.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Shooting) show
117.000 13.000 moveto
(method) show
159.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
165.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
170.250 13.000 moveto
(H) show
176.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
182.250 13.000 moveto
(L) show
188.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
200.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
206.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
212.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
218.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .30903 m
.02605 .30903 L
.02846 .30903 L
.03072 .30903 L
.03279 .30903 L
.03521 .30903 L
.03784 .30903 L
.04032 .30903 L
.04262 .30903 L
.04498 .30903 L
.0472 .30903 L
.04963 .30903 L
.05224 .30903 L
.05497 .30903 L
.05757 .30903 L
.0599 .30903 L
.06244 .30903 L
.0653 .30903 L
.06799 .30903 L
.07041 .30903 L
.07302 .30903 L
.07588 .30903 L
.07889 .30903 L
.08147 .30903 L
.08429 .30903 L
.08694 .30903 L
.08936 .30903 L
.09215 .30903 L
.09479 .30903 L
.09722 .30903 L
.09948 .30903 L
.10195 .30903 L
.10458 .30903 L
.10696 .30903 L
.10947 .30903 L
.11395 .30903 L
.11645 .30903 L
.11877 .30903 L
.12149 .30903 L
.12405 .30903 L
.12627 .30903 L
.12868 .30903 L
.13289 .30902 L
.13527 .30902 L
.1378 .30902 L
.14233 .30901 L
.14486 .30901 L
.14726 .309 L
.15177 .30899 L
.15428 .30898 L
Mistroke
.15662 .30897 L
.15934 .30895 L
.1619 .30893 L
.16656 .30889 L
.17077 .30883 L
.17531 .30875 L
.18022 .30862 L
.18515 .30845 L
.18975 .30822 L
.19479 .30789 L
.2002 .30738 L
.20586 .30664 L
.21123 .30567 L
.21604 .30452 L
.22127 .30286 L
.22614 .30085 L
.2307 .29847 L
.2357 .29517 L
.24109 .29066 L
.24644 .285 L
.25206 .27755 L
.26211 .25965 L
.27168 .23614 L
.28189 .20343 L
.30027 .12754 L
.31054 .0818 L
.31594 .05961 L
.32165 .03941 L
.32666 .02578 L
.32803 .02288 L
.3295 .02022 L
.33077 .01831 L
.33215 .01667 L
.3328 .01606 L
.3335 .01554 L
.33475 .01491 L
.33592 .01472 L
.33721 .01494 L
.33835 .01555 L
.33958 .01665 L
.34075 .01812 L
.34182 .01984 L
.3443 .02526 L
.34655 .03196 L
.35161 .05331 L
.35629 .08094 L
.36072 .11375 L
.38141 .32799 L
.39112 .43334 L
.39643 .4817 L
Mistroke
.39902 .50157 L
.4014 .51714 L
.40342 .52826 L
.40563 .53797 L
.40684 .54217 L
.40796 .54532 L
.40904 .54767 L
.41018 .54943 L
.41143 .55046 L
.41214 .55063 L
.41279 .55053 L
.41399 .54966 L
.41525 .54781 L
.41638 .54532 L
.41744 .5423 L
.41984 .53297 L
.42245 .51909 L
.42486 .50292 L
.43031 .45575 L
.44021 .3431 L
.44915 .2328 L
.45384 .18033 L
.45877 .1341 L
.46117 .11597 L
.4638 .09996 L
.46496 .09428 L
.46619 .08915 L
.46734 .08526 L
.46841 .08248 L
.46958 .08031 L
.47085 .07904 L
.47196 .07885 L
.47315 .0796 L
.47421 .0811 L
.4752 .08321 L
.47628 .0863 L
.47745 .09052 L
.4801 .10342 L
.48298 .12248 L
.48822 .16898 L
.49806 .28425 L
.50823 .41058 L
.51321 .46313 L
.51779 .50112 L
.52036 .51722 L
.52168 .5238 L
.52308 .52959 L
.52382 .53211 L
.5245 .53407 L
.52581 .537 L
Mistroke
.52655 .53812 L
.52735 .5389 L
.52811 .53923 L
.5288 .53918 L
.52999 .53831 L
.53111 .5366 L
.53233 .53374 L
.53364 .52953 L
.53632 .51744 L
.53878 .50243 L
.54354 .4637 L
.54862 .41114 L
.55775 .30034 L
.563 .23589 L
.56854 .17392 L
.57368 .12646 L
.57847 .09363 L
.58084 .0821 L
.58205 .07745 L
.58337 .07338 L
.58412 .07154 L
.58482 .07014 L
.58548 .06907 L
.58619 .06823 L
.58741 .06748 L
.5881 .06745 L
.58875 .06769 L
.5894 .06819 L
.59011 .06901 L
.59085 .07019 L
.59154 .07158 L
.59278 .07475 L
.5941 .0791 L
.59713 .09262 L
.59987 .10895 L
.60485 .14711 L
.61025 .19848 L
.62004 .30667 L
.6303 .4205 L
.63991 .50934 L
.64474 .54383 L
.64993 .57215 L
.65288 .58414 L
.65569 .59275 L
.6582 .59826 L
.65963 .60046 L
.66095 .60194 L
.66224 .60287 L
.66289 .60315 L
.6636 .60332 L
Mistroke
.66486 .60326 L
.66604 .60281 L
.66675 .60235 L
.66743 .6018 L
.66869 .60045 L
.67006 .59856 L
.67154 .59602 L
.67672 .58358 L
.6815 .568 L
.70012 .48879 L
.70988 .44643 L
.7204 .40661 L
.72949 .37869 L
.73942 .35527 L
.74904 .33893 L
.75428 .33223 L
.75915 .32718 L
.76789 .32045 L
.77278 .31773 L
.77722 .31578 L
.78208 .31409 L
.78722 .31273 L
.79161 .31184 L
.79643 .31109 L
.80162 .31049 L
.80718 .31003 L
.81244 .30972 L
.81724 .30952 L
.82203 .30938 L
.82713 .30927 L
.83148 .3092 L
.83629 .30915 L
.83897 .30913 L
.84143 .30911 L
.84408 .30909 L
.84699 .30908 L
.85188 .30906 L
.85455 .30906 L
.85704 .30905 L
.86207 .30905 L
.86491 .30904 L
.86754 .30904 L
.87235 .30904 L
.87478 .30904 L
.87746 .30904 L
.88208 .30903 L
.88468 .30903 L
.88705 .30903 L
.88926 .30903 L
.89166 .30903 L
Mistroke
.89604 .30903 L
.89859 .30903 L
.90135 .30903 L
.90396 .30903 L
.90636 .30903 L
.91091 .30903 L
.9132 .30903 L
.91572 .30903 L
.91846 .30903 L
.92095 .30903 L
.92384 .30903 L
.92657 .30903 L
.92909 .30903 L
.93142 .30903 L
.93397 .30903 L
.93669 .30903 L
.93907 .30903 L
.94158 .30903 L
.94372 .30903 L
.94607 .30903 L
.9486 .30903 L
.9513 .30903 L
.95385 .30903 L
.95617 .30903 L
.95852 .30903 L
.96068 .30903 L
.96306 .30903 L
.96557 .30903 L
.96776 .30903 L
.9698 .30903 L
.97204 .30903 L
.97445 .30903 L
.97619 .30903 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo001l
ooooo`?o0000=?ooool00ol0003oooooooooo`2booooo`00O?ooool01?l0003oooooo`000?l0000c
ooooo`03o`000?oooooooooo0;;ooooo001kooooo`05o`000?ooooooooooooooool00000<oooool0
0ol0003oooooooooo`2booooo`00Noooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
033ooooo0_l0002cooooo`00N_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool0/_ooool007[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo0;;ooooo001jooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`2booooo`00NOooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0/_ooool007Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0_ooooo`;o0000/oooool007Wooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo0;;ooooo001iooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`2booooo`00N?oo
ool00ol0003oooooooooo`07ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_oo
ool00ol0003oooooooooo`2booooo`00N?ooool00ol0003oooooooooo`07ooooo`03o`000?nYZJWo
oooo00Oooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01_ooool00ol0003oooooooooo`2booooo`00N?ooool6o`0000Cooooo00?o0000
oeEEEOooool02?ooool01?l0003oooooooooool@4103ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/_ooool007Oooooo00?o0000oooooooo
ool02?ooool00ol0003o8B4Qooooo`07ooooo`05ogMgMolb<S;oooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`04ooooo`?o0000/_ooool007Oooooo00?o
0000ooooooooool02?ooool00ol0003oEEEEolc<c004ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool0/_ooool007Oooooo00?o0000ooooooooool02Oooool00ol0003oMgMgooooo`03
ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4006ooooo`03o`000?oooooooooo0;;ooooo001gooooo`03o`000?oooooooooo00Ko
oooo00Go410@oooooooooooo0000oc8b<P04ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo01Wo
oooo0_l0002Gooooo`00M_ooool00ol0003oooooooooo`07ooooo`Go00001?ooool4o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo01Wooooo0ol0002Fooooo`00M_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo02gooooo0_l0000Iooooo`;o000000?oooooo`000?ooool0UOooool007Kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Sooooo00Co0000oooo
oooooooo0000U_ooool007Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Roooo
o`;o00002?ooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool00000UOooool0
07Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo0000
00Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
09?ooooo001eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool08Oooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`2Cooooo`00MOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo027o
oooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0T_ooool007Cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Qooooo`05o`000?ooooooooooooooool000001_ooool2o`0001Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`2Booooo`00M?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Booooo`00M?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Boooo
o`00M?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`2Booooo`00M?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Aooooo`00Looo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`;o00005oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo097ooooo001cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo097ooooo001cooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
097ooooo001cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo097ooooo001cooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo097ooooo
001booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo097ooooo001booooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0_l0000F
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0TOooool007;ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0TOooool007;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0T?ooool007;ooooo00?o0000ooooooooool0
3?ooool03?m4A4Co0000o`000?lb<S;ogMgMo`000?ooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool03_o^
k^ko<S8bo`000?lb<S;ok^k^ooooool0003oooooonk^k_lb<S;o0000oc8b<_o^k^ko00001Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0T?ooool0
077ooooo00?o0000ooooooooool04?ooool02OmgMgOo<S8bo`000?ooooooMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00ooMgMgoiRHV?ooooooV9RHogMgMooooooo0000oooooomgMgOoV9RHoooooonHV9SoMgMg
ooooool000001?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0T?ooool0077ooooo00?o0000ooooooooool01?ooool6o`0000Oooooo0_l000000ooo
oooo410@ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo0000ooooool@
41000oooool00ol@413oooooo`000004ooooo`?o00005Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo093ooooo001aooooo`03o`000?oooooooooo013ooooo00GoMgMgoc8b<_l0003o
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo0000ooooool00000
0oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`2@ooooo`00LOooool00ol0003oooooooooo`0=ooooo`08o`000?lQ
8B7o0000oc8b<_o<c<co0000ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?oooooo0000ooooool000000oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2@ooooo`00L?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413o0000oooooooooooo410@00?ooooo00?o410@ooooool000001?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0T?oo
ool0073ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`07o`000?oooooo
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00KoMgMgoiRHV?ooooooV9RHogMgMol00002ooooo`07ogMgMonH
V9SooooooiRHV?mgMgOoooooo`000004ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`2@ooooo`00L?ooool00ol0003oooooooooo`0>ooooo`Co0000
00Soooooo`000?ooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`00
00;ooooo00Ook^k^oc8b<_l0003o<S8bonk^k_oooooo000000Cooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo093ooooo001`ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooo
ooooooooo`;o00005Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo093ooooo001_
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07
ooooo`05o`000?ooooooooooooooool000005_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo08oooooo001_ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000005Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo08oooooo001_ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000005Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo08oooooo001_ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08ooooo`05o`000?oooooo
ooooooooool000005Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo08oooooo001_
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08
ooooo`04o`000?ooooooooooooooo`;o00005?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo08oooooo001^ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000005Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo08oooooo001^ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000005Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo08oooooo001^ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08ooooo`05o`000?oooooo
ooooooooool000005Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo08oooooo001^
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08
ooooo`05o`000?ooooooooooooooool000005Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo08oooooo001]ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`2>ooooo`00KOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02o`0001Cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`2>ooooo`00KOooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool0000E
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0S_ooool006gooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo00Co0000oooo
oooooooo00005Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo08kooooo001/oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:oooo
o`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2>
ooooo`00K?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool02_ooool01?l0003oooooooooool0000Eooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0S_ooool006cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_l0000Cooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0S_ooool006_ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00005?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo08kooooo001[ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`00
01Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2>ooooo`00Joooool00ol0003o
ooooooooo`0Booooo`Go00000oooool01_l0003oA4A4o`000?l0003o<S8bomgMg@;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?l0003ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`04o`000?oooooooooo
o`0001Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2>ooooo`00J_ooool00ol0
003oooooooooo`0Cooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01_l0003ooooooooooooo
ooooMgMgoc8b<P;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHooooool0003oMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`04o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`2=ooooo`00J_ooool00ol0003oooooooooo`0;ooooo`Ko00000oooool00onHV9So8B4Qonk^
kP05ooooo`05o`000?ooooooooooooooool000000_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo0000ooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Co0000oooooooooooo00005?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo08gooooo001Yooooo`03o`000?oooooooooo01Kooooo00?o
V9RHob4Q8Oo^k^h01?ooool01Ol0003ooooooooooomgMgOo<S8b00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003oooooo`000?oooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?o00004_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08gooooo001Yooooo`03o`000?oooooo
oooo01Oooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
ooooo`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
000001Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2=ooooo`00JOooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
oooo0000ooooool@41000oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o0000ooooool0
00005?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08gooooo001Xooooo`03o`00
0?oooooooooo01Gooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHo`000?nHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`00
0?oooooo000001Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2=ooooo`00J?oo
ool00ol0003oooooooooo`0Eooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oo
oooo000001Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2=ooooo`00Ioooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03?ooool0
1?l0003oooooo`000?l0000Cooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0SOoo
ool006Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooool000005?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo08gooooo001Wooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooo000001Cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`2=ooooo`00I_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooo`00000Dooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0SOooool006Kooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00gooooo00?o0000ooooool000004oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo08cooooo001Vooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo000001?ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2<ooooo`00IOooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03Oooool01?l0003oooooo`000?l0
000Booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0S?ooool006Gooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00gooooo00?o0000
ooooool000004oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo08cooooo001Toooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooo000001?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2<oooo
o`007?ooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
02Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0;ooooo`03o`000?oooooooooo01Cooooo1Ol00005
ooooo`;o8B4Q0oooool00ol0003oooooodA4A002o`000003oc8b<_oMgMgooooo00oooooo00?o0000
ooooooooool03_ooool2o`0001?ooooo00?o0000ooooooooool03oooool5o`0000Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd08oooool01Om4A4Co0000o`000?lb<S;ogMgM02Gooooo
00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`00
7?ooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Vooooo`03ogMg
Molb<S;ooooo00Wooooo00?o0000ooooooooool05Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Go
oooo0_lQ8B43ooooo`03o`000?oooooooooo00;ooooo00?oMgMgoc8b<_ooool03oooool00ol0003o
ooooooooo`0>ooooo`;o00004oooool00ol0003oooooooooo`0?ooooo`05o`000?lQ8B7ok^k^oooo
oom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool09Oooool00omgMgOo<S8booooo`0Toooo
o`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01Oooooo000Booooo`Ko
00001?ooool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo01Wooooo1_l00007ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^
k^h02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03_ooool3o`0001;ooooo00?o0000ooooooooool03oooool01?l0003oV9RHob4Q8Oo^k^hAoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool08oooool00onYZJWoEEEEooooo`0@oooo
o`03o`000?oooooooooo01Kooooo000Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_oo
ool09_ooool00omgMgOo<S8booooo`08ooooo`03o`000?oooooooooo01Sooooo00?oV9RHob4Q8Oo^
k^h02_ooool00ol0003oooooooooo`02ooooo`03ogMgMolb<S;ooooo00oooooo00?o0000oooooooo
ool03_ooool2o`0001?ooooo00?o0000ooooooooool03oooool01Ol0003ooooooiRHV?lQ8B7ok^k^
00oooooo00?oMgMgoc8b<_ooool09Oooool00omgMgOo<S8booooo`0Uooooo`03ob4Q8Ooooooooooo
00kooooo00?oMgMgoc8b<_ooool05oooool001gooooo00?oEEEEolc<c?ooool02oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<02Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c008ooooo`03o`000?oooooo
oooo01[ooooo00?oMgMgofIVI_ooool02Oooool01ol0003oooooo`000?lQ8B7o0000oc8b<_o<c<`0
4?ooool00ol0003oooooooooo`0>ooooo`;o00004oooool00ol0003oooooooooo`0?ooooo`05o`00
0?ooooooooooogMgMomVIVH03?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<02?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Vooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Hooooo`007Oooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Wooooo0_l0000D
ooooo`03o`000?oooooooooo00kooooo0_l0000Cooooo`03o`000?oooooooooo00oooooo00Go0000
ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0:?oo
ool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo01[ooooo000Jooooo`05oa0@4?oooooo
oooooooooolb<S803?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool06Oooool01Ol0003o^[ZjoooooonHV9So410@00_ooooo0_l0000Dooooo`03o`00
0?oooooooooo00kooooo0_l0000Booooo`03o`000?oooooooooo013ooooo00Go0000okZj^_oooooo
V9RHoa0@400<ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09Oooool01Ol@413o
oooooooooooooooo<S8b00cooooo00?o0000ooooooooool06_ooool001[ooooo1Ol0000<ooooo`Co
00009Oooool4o`0000Kooooo00?o0000ooooooooool06_ooool01OnHV9So410@o`000?lQ8B7oc<c<
00_ooooo1Ol0000@ooooo`03o`000?oooooooooo00oooooo0_l0000Booooo`03o`000?oooooooooo
013ooooo00GoV9RHo`000?l0003o8B4Qolc<c00<ooooo`Co00009?ooool4o`0002Cooooo1Ol0000<
ooooo`Co00006Oooool005gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00oooooo0ol0000Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0Roooool005cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00oooooo0_l0000Booooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0Roooool005[ooooo0_l0000_ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
3oooool2o`0001;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`2;ooooo`00Eooo
ool3o`00037ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`2;ooooo`00D_ooool5
o`0003Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`2;ooooo`003oooooooo`00
04[o00004?ooool001Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo0_l00009ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo2Ol00005ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Fooooo`00
8Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
9_ooool3o`0000Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Pooooo`00S?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0FOoo
ool008cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0]ooooo`;o0000G?ooool0
08cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
05cooooo002<ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool2o`00013o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo05go
oooo002<ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`1Nooooo`00S?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool0Goooool008cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0A
ooooo`;o00004?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool0Goooool008cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aoooo
o`;o00004?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0H?ooool008cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`;o
00004?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool0H?ooool008cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`;o0000
4?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
HOooool008gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Aooooo`;o00004?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0H_oo
ool008gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Aooooo`;o00004?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0Hoooool0
08gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Aooooo`;o00004?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0I?ooool008go
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Aooooo`;o00003oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0I?ooool008gooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Aooooo`;o00003oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0IOooool008gooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Booooo`;o00003oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0IOooool008gooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo000000kooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo06Gooooo002=oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool04_ooool00ol0003oooooo`00000>oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Voooo
o`00SOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooool0
00003_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0I_ooool008gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Booooo`?o0000
3_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
I_ooool008gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooo000000kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo06Oooooo002>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04_ooool0
0ol0003oooooo`00000>ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`1Wooooo`00P?ooool5o`0000Cooooo00coA4A4o`000?l0003o<S8bomgMgOl0
003oooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`0=onk^k_lb<S;o0000oc8b<_o^k^koooooo`00
0?ooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool0
0ol0003oooooo`00000>ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`1Xooooo`00P?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMg
oc8b<_l0003oooooogMgMonHV9SooooooiRHV?mgMgL00oooool03OmgMgOoV9RHoooooonHV9SoMgMg
ooooool0003oooooogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Kooooo00?o0000ooooool000003_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0J?ooool0087ooooo00?oV9RHob4Q8Oo^k^h02Oooool2o`000003
ooooool@413ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo0000
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?oo
ool00ol0003oooooo`00000>ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`1Xooooo`00P_ooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;o
0000ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooool0003o
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`04oooo
o`?o00003_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0JOooool008?ooooo00?oMgMgofIVI_ooool00oooool02?l0003o8B4Qo`000?lb<S;oc<c<
o`000?oooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooool0003o
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooo000000gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo06Wooooo0024ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003ooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413o0000oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo00Cooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0JOooool0083ooooo00Go0000okZj^_ooooooV9RH
oa0@4004ooooo`03o`000?oooooooooo00;ooooo00Oo0000oooooomgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00KoMgMgoiRHV?ooooooV9RHogMgMol00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00Co0000oooooooooooo00003?ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0J_ooool0083o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co000000Soooooo`000?ooooook^k^oc8b<_l0
003o<S8bonk^kP?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l00002ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00Co0000oooooooooooo0000
3?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
J_ooool008kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Cooooo`;o000000?o
ooooo`000?ooool02oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0J_ooool008kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0C
ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo06[ooooo002>ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool04oooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`1[ooooo`00Soooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo00003?ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Joooool008oooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0000cooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo06_ooooo002?
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04oooool01?l0003oooooooooool0
000<ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`1[ooooo`00Soooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01?ooooo0_l00000
0ooooooo0000ooooo`0:ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`1/ooooo`00Soooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01?ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0K?ooool008oooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Cooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo06cooooo002?ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool04oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1/ooooo`00Soooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01Cooooo00Go0000ooooooooooooooooo`00000:
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1/
ooooo`00Soooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Cooooo0_l00002oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo06gooooo002?ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool05?ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo06gooooo002@ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool05?ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo06gooooo002@ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool05?ooool01Ol0003ooooooooooooooooo0000
00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
06gooooo002@ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05?ooool01Ol0003o
oooooooooooooooo000000Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo06kooooo002@ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool05?ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo06kooooo002@ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool05?ooool2o`0000;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0K_ooool0093ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Dooooo`05o`000?ooooooooooooooool0
00002Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0K_ooool0093ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Dooooo`05o`00
0?ooooooooooooooool000002Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0K_ooool0087ooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Ol0003o<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o0000onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1_ooooo`00Q?ooool02OmgMgOo
<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMol0003ooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHooooool0003oMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool01Ol0003ooooooooooooooooo000000Wooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo06oooooo0025
ooooo`04o`000?oooooooooooa0@40?ooooo00Ko410@oooooooooooooooooa0@4?l00002ooooo`05
oa0@4?ooooooooooooooool@41000_ooool00ol0003o410@ooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo0ol00002ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo06oooooo0024ooooo`05ogMgMolb<S;oooooooooool000000oooool01?l0003ooooooooo
ooooool2o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`;o00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0Koooool0087ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool000000oooool2o`0000;ooooo00Go0000oooooooooooooooo
o`000002ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Koooool0087o
oooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@o`00
0?oooooooooooa0@4003ooooo`05oa0@4?ooooooooooo`000?l@41000oooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0L?ooool0087ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgo`000?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
o`000?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0L?ooool0087ooooo1?l0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko0000o`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o0000onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`1`ooooo`00T_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo0_l00004
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo073ooooo002Booooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo077ooooo002Booooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo077ooooo002Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo077ooooo002Booooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo077ooooo002Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05_ooool2
o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0L_ooool009?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0L_ooool009?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0L_ooool009?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Loooool009?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0Loooool009?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000Rooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0Loooool009?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Gooooo`;o00001_ooool01?l0003oooooooooool0000Sooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0Loooool009?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00008ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07Cooooo002Dooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`05ooooo`04o`000?oooooo
ooooo`0002?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1dooooo`00U?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01Oooool3
o`0002Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1dooooo`00U?ooool01Ol0
003ooooooooooooooooo000001[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0M?ooool009Gooooo00Co0000oooo
oooooooo00006_ooool2o`0002gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1e
ooooo`00UOooool01?l0003oooooo`000?l0000Jooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1eooooo`00U_ooool2o`0001_ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07Gooooo0022ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0M_ooool008;ooooo00?oEEEEojVYZOooool0
1oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1fooooo`00P_ooool00onYZJWoEEEEooooo`08ooooo`04o`000?oooooooooooa0@40?o
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0M_ooool008?ooooo00?o8B4Q
ooooooooool01_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool01?ooool3o`0002gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`1fooooo`00Poooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07Oo
oooo0023ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Oooooo0020ooooo`05oa0@4?oooooo
oooooooooolb<S801?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0Moooool0083ooooo1Ol00004ooooo`Co00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Oooooo002cooooo`;o0000
;oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07Sooooo002cooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1hooooo`00/oooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0N?ooool0
0;?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
07Sooooo002cooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1iooooo`00/oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0NOooool00;?ooooo0_l0000aooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0N_ooool00;?ooooo00?o0000ooooooooool0<Oooool01Ol0003ooooooooooooo
oooo000007cooooo002cooooo`03o`000?oooooooooo037ooooo1?l0001mooooo`00/oooool00ol0
003oooooooooo`0booooo`;o0000O_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo
0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2b
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00S?ooool01OlQ8B7o0000o`000?m4A4CogMgM0=Oooooo002?ooooo`03ogMgMolb<S;ooooo
03[ooooo00?o^[Zjoc8b<_ooool00_ooool01?l0003oooooooooool00008ooooo`03ogMgMomVIVKo
oooo00Sooooo00?oIVIVogMgMoooool01_ooool00ol0003o^[Zjooooo`1dooooo`00T?ooool00ol0
003oooooooooo`0jooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`05
ooooo`03omgMgOl@413ok^k^00Wooooo00?ok^k^oa0@4?oMgMd01_ooool2oc8b<WGooooo001Coooo
o`06oa0@4?lQ8B7o0000o`000?m4A4CogMgM0_ooool01?l@413o0000o`000?ooool2o`000004oa0@
4?ooooook^k^oeEEE@;o000000KoEEEEonk^k_ooooooooooonk^k_mEEED2o`000003oeEEEOo^k^ko
oooo00;ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`Go00000_ooool01?l@413o0000o`00
0?ooool2o`000008oa0@4?ooooook^k^oeEEEOl0003o410@olc<c?l00004ooooo`;o00000_ooool0
1ol0003oooooooooool0003o410@onk^k_mEEED00_l000000om4A4Co^[Zjooooo`02ooooo`05oiRH
V?l0003o0000odA4A?nj^[X00_ooool01?l@413o0000o`000?ooool2o`000004oa0@4?ooooook^k^
oeEEE@;o000000KoEEEEonk^k_ooooooooooonk^k_mEEED2o`000003oiRHV?l0003o410@00Kooooo
00OoV9RHoa0@4?l0003o0000ojVYZOoooooo000000;ooooo00?o0000ooooooooool01Oooool00omE
EEGoV9RHooooo`02ooooo`;o00000_ooool2o`0000;ooooo00?oQhN7ofIVI_ooool01Oooool00on7
QhOo0000okZj^P0;ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool01oooool0
1Om4A4Co0000o`000?lb<S;ogMgM05Cooooo001Cooooo`06o`000?n7QhOooooooooooon7QhOo8B4Q
0oooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED2
ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Go
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMg
Moooooook^k^oeEEEOl00005ooooo`04o`000?ooooooooooo`0000;ooooo00So0000oooooomEEEGo
MgMgooooooo^k^koMgMgoa0@40?ooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`05o`000?oo
ooooooooooooool000000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@;ooooo00KoEEEEogMg
Moooooook^k^oeEEEOl00007ooooo`06o`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj0ol00008ooooo`03
o`000?oooooooooo00;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03onk^k_l0003o
oooo00Gooooo00?oc<c<o`000?l@41003?ooool01_l0003ooooooooooooooooo0000ooooo`Ko0000
1_ooool00omgMgOo<S8booooo`1Cooooo`00Doooool01_lQ8B7oooooooooooooooook^k^o`0000?o
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001?ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000ooooooooooooooooonk^k_l00005oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000?ooooo00?ok^k^o`000?ooool01_ooool01_lb<S;ok^k^oiRHV?mEEEGogMgMoa0@
40_ooooo00?o<S8booooooooool00oooool01?oMgMgo0000oa0@4?o<c<`4ooooo`03o`000?oooooo
oooo01?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo05;ooooo001D
ooooo`05omgMgOnHV9SoMgMgoa0@4?mVIVH00oooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`05o`000?oooooooooooooo
ool000002Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool0
1_l0003oooooooooooooooook^k^o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooo`000005o`0000?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03onk^k_l0003o
oooo00Kooooo00Oo^[ZjodA4A?o<c<co8B4Qooooool@413oc<c<00[ooooo00?o<S8booooooooool0
0oooool01?o^k^ko8B4Qoa0@4?o^k^h4ooooo`03o`000?oooooooooo01?ooooo00Ko0000oooooooo
ooooooooo`000?ooool6o`0000Kooooo00?oMgMgoc8b<_ooool0Doooool005?ooooo00GoIVIVoa0@
4?mEEEGoQhN7okZj^P04ooooo`05o`000?mgMgOoooooojVYZOl000000_ooool01_mEEEGoMgMgoooo
ooooooooMgMgoeEEE@;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED3ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00oooool01Ol0003oQhN7oooooonYZJWo000000;ooooo00Ko
EEEEogMgMoooooook^k^oeEEEOl00005ooooo`0>o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8Ooo
ooooEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?oooooooooo00Gooooo00Go0000ogMg
MoooooooZJVYo`000002ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0_ooool01_mVIVKoMgMg
ooooooo^k^koEEEEo`0000Oooooo00Ook^k^o`000?oooooo0000oooooomVIVKoQhN700[ooooo00?o
0000onk^k_ooool00oooool01?lQ8B7oMgMgogMgMolb<S83ooooo`03onk^k_l0003ooooo01Cooooo
00Go0000ohN7QoooooooZJVYo`00000:ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0E?ooool005?o
oooo00Ko0000onk^k_ooooooooooolc<c?l00003ooooo`05o`000?mgMgOo0000o`000?nHV9P00_oo
ool01_o^k^koEEEEo`000?l0003oEEEEonk^kP;ooooo00Sok^k^oeEEEOl0003o0000oeEEEOo^k^ko
oooooa0@40Go00001?ooool00ol@413o0000o`000004ooooo`03oa0@4?l0003oMgMg00;o000000[o
V9RHooooooooooook^k^oeEEEOl0003o8B4QojVYZOl0003o410@0oooool02ol@413o0000ob4Q8Ol0
003oMgMgoa0@4?l0003oZJVYooooooo^k^koEEEE00;o000000CoA4A4onk^k_oooooo410@1Ol00004
ooooo`05o`000?mgMgOo0000o`000?nHV9P00_ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kP;o
oooo00Kok^k^oeEEEOl0003o410@olc<c?l00007ooooo`04ofIVI_nHV9Sooooooc8b<P;o^[Zj00?o
0000ooooooooool02?ooool00omEEEGoMgMgooooo`02ooooo`;o00000_ooool2o`0000;ooooo00?o
MgMgoeEEEOooool04oooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo00Sooooo00?o
0000ooooooooool0E_ooool005?ooooo00Ko<S8bohN7Qoooooook^k^ofIVI_l00003ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool02?ooool00omVIVKoQhN7ooooo`0;ooooo`03omgM
gOl@413ok^k^00Wooooo00?ok^k^oa0@4?oMgMd09?ooool00ol0003oooooooooo`1Fooooo`00Dooo
ool01_o^k^koA4A4o`000?l0003o<S8boa0@40?ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?oZJVYodA4A?ooool03?ooool00omgMgOo
IVIVooooo`08ooooo`03ofIVI_mgMgOooooo02Cooooo1?l0001Eooooo`00Foooool00ol@413o0000
ooooo`0Pooooo`03oa0@4?oooooooooo02gooooo00?o410@o`000?ooool04Oooool2o`000:Cooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-9.21355, -918856, \
0.0641612, 11355.4}}]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 6.3", "Subsubtitle",
  CellTags->"c:44"],

Cell[TextData[{
  StyleBox["(1)(a)",
    FontWeight->"Bold"],
  " A rope consists of a thin segment of length ",
  Cell[BoxData[
      \(TraditionalForm\`L/2\)]],
  " and mass per unit length ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_1\)]],
  " and a thick segment of equal length and mass ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_2 = 3\ \[Rho]\_1\)]],
  ". The rope is stretched between posts, and is under constant tension ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ". Find and plot the spatial form of the first four eigenmodes, using a \
grid method, and find the corresponding frequencies.  Use a sufficiently fine \
grid so  that all the frequencies are accurate to within 1%. "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Perform the analysis using the Galerkin method."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Perform the analysis using the WKB-shooting method."
}], "Text"],

Cell[TextData[{
  StyleBox["(2)(a)",
    FontWeight->"Bold"],
  " Find the WKB eigenmodes of a string with fixed ends, and with nonuniform \
mass density but uniform tension and of Length ",
  Cell[BoxData[
      \(TraditionalForm\`L = 1\)]],
  ", with propagation speed ",
  Cell[BoxData[
      \(TraditionalForm\`c(x)\  = \ exp(2\ x)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(0 < x < 1\)\)\)]],
  ", and find the frequencies of the first 5 modes."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Compare the first two modes and their frequencies with the eigenmodes \
determined via the shooting method."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Use these eigenmodes to solve the following problem: ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(y(x, 0)\  = \ 0\)\(,\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_t\ \(y(x, 0)\) = \ x(1 - x)\)]],
  ".  Make an animation of the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 3\)]],
  " .  "
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Perform the analysis of parts (a) and (c) using the Galerkin method."
}], "Text"],

Cell[TextData[{
  StyleBox["(e)",
    FontWeight->"Bold"],
  " Perform the analysis of parts (a) and (c) using the grid method."
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  "  A vertically hanging rope has mass per unit length ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\  = \ 1\)]],
  " kg/m, and is attached between floor and ceiling and given tension ",
  Cell[BoxData[
      \(TraditionalForm\`T = \ 1\)]],
  " newton at the base. (See Fig. ",
  ButtonBox["6.15",
    ButtonData:>"Fig. 6.15",
    ButtonStyle->"Hyperlink"],
  ".) Transverse waves on the rope,  of amplitude ",
  Cell[BoxData[
      \(TraditionalForm\`y(z, t)\)]],
  ", satisfy the following differential equation: "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\^2\/\[PartialD]t\^2\) \(y(z, 
            t)\) = \(\[PartialD]\/\[PartialD]z\) \((\(\(c(
                    z)\)\^2\) \(\[PartialD]\/\[PartialD]z\) y)\)\)]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`c(z)\  = \ \@\(T/\[Rho]\  + \ g\ z\)\)]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"g", "=", 
          RowBox[{"9.8", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              SuperscriptBox[
                StyleBox["s",
                  FontSlant->"Plain"], "2"]}]}]}], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tSince the rope is attached to the ceiling and the floor, the boundary \
conditions on the waves are ",
  Cell[BoxData[
      \(TraditionalForm\`u(0, t)\  = \ \(u(L, t)\  = \ 0\)\)]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"L", "=", 
          RowBox[{"3", 
            StyleBox["m",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  " is the height of the ceiling."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008b0001GB000`400?l00000o`00003ooooooooo
ooooocCooooo003ooooooooooooo=?ooool00?ooooooooooooldooooo`00ooooooooooooocCooooo
003ooooooooooooo=?ooool00?ooooooooooooldooooo`00ooooooooooooocCooooo003ooooooooo
oooo=?ooool00?ooooooooooooldooooo`003Ooooooo0?ooool0oooo603oool?ooooo`003OoooomL
0?ooo`<000006`3oool2000001X0oooo00<0P8200000000000000P00000I0?ooo`040820P0000000
0000000001X0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`040820P00000000000000001X0oooo
0`00000J0?ooo`<0000000<0P8200?ooo`3oool05`3oool01020P800000000000000000J0?ooo`@0
00006P3oool01020P800000000000020P80J0?ooo`<000006P3oool3000001X0oooo00@0P8200000
00000000P8206P3oool00`20P80000000000000J0?ooo`oooooo000=oooooe`0oooo00@0`<300000
00000000@4106P3oool01010@400000000000030`<0I0?ooo`050410@0000000000000000020P800
6@3oool01010@400000000000020P80J0?ooo`<0000000<0P8200?ooo`3oool05`3oool300000003
0820P03oool0oooo01L0oooo00D0`<3000000000000000000<30`00I0?ooo`040410@00000000000
0820P1T0oooo00@0P820000000000000@4106@3oool01@30`<000000000000000000P82001X0oooo
0`00000J0?ooo`040410@000000000000410@1X0oooo00<0@4100000000000006P3oool01010@400
000000000020P80I0?ooo`040<30`000000000000410@1T0oooo3oooool000goooooG@3oool40000
01X0oooo0`00000J0?ooo`@000006@3oool01@20P8000000000000000000P82001T0oooo00@0P820
00000000000000006P3oool3000001X0oooo1000000J0?ooo`<0000000<0P8200?ooo`3oool05`3o
ool01020P800000000000020P80J0?ooo`<0000000<0P8200?ooo`3oool0603oool3000001X0oooo
0`00000K0?ooo`80000000<0P8200?ooo`3oool05`3oool01@20P8000000000000000000P82001T0
oooo00<0P8200000000000006@3oool?ooooo`003OoooomM0?ooo`050<30`0000000000000000020
P8006@3oool01030`<00000000000020P80J0?ooo`@0000000<0`<300?ooo`3oool05P3oool01020
P800000000000000000J0?ooo`040820P000000000000410@1T0oooo00D0`<300000000000000000
0<30`00I0?ooo`040410@000000000000820P1T0oooo00@0P820000000000000@4106P3oool30000
01X0oooo00D0@41000000000000000000820P00I0?ooo`040<30`000000000000410@1T0oooo00D0
`<3000000000000000000<30`00I0?ooo`040410@000000000000820P1T0oooo00@0P82000000000
0000@4106P3oool3000000030<30`03oool0oooo01D0oooo3oooool000goooooG`3oool3000001X0
oooo0`0000000`20P800oooo0?ooo`0G0?ooo`050820P0000000000000000020P8006@3oool01020
P800000000000000000J0?ooo`<0000000<0P8200?ooo`3oool0603oool3000001X0oooo0`00000J
0?ooo`040820P000000000000820P1X0oooo0`00000J0?ooo`@000006P3oool01020P80000000000
0000000I0?ooo`@000006P3oool3000001X0oooo00@0P82000000000000000006P3oool3000001L0
oooo3oooool000goooooG`3oool01@20P8000000000000000000`<3001T0oooo00<0@41000000000
00006P3oool01@20P8000000000000000000`<3001P0oooo00D0`<3000000000000000000410@00I
0?ooo`040<30`00000000000000001X0oooo00@0@410000000000000`<306P3oool3000000030<30
`03oool0oooo01L0oooo00@0P820000000000000P8206@3oool01030`<00000000000010@40I0?oo
o`050<30`0000000000000000010@4006@3oool01@30`<000000000000000000`<3001T0oooo00@0
@410000000000000P8206P3oool2000000030410@03oool0oooo01L0oooo00D0`<30000000000000
00000410@00I0?ooo`030<30`0000000000001L0oooo3oooool000goooooH03oool01020P8000000
00000010@40J0?ooo`<0000000<0`<300?ooo`3oool05`3oool01@10@4000000000000000000P820
01T0oooo00@0@410000000000000P8206P3oool01010@400000000000030`<0I0?ooo`040820P000
000000000820P1T0oooo00@0`<3000000000000000006P3oool01010@400000000000030`<0I0?oo
o`040820P00000000000000001T0oooo00<0P8200000000000000P00000J0?ooo`040410@0000000
00000820P1T0oooo0`0000000`10@400oooo0?ooo`0G0?ooo`050<30`0000000000000000030`<00
6@3oool01010@400000000000030`<0J0?ooo`030000003oool0oooo01D0oooo3oooool000gooooo
H@3oool01020P800000000000000000J0?ooo`<000006P3oool4000001X0oooo0`00000J0?ooo`04
0820P00000000000000001X0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`040820P00000000000
000001X0oooo0`00000J0?ooo`<0000000<0P8200?ooo`3oool05`3oool01@20P800000000000000
0000P82001T0oooo00D0P82000000000000000000820P00I0?ooo`<0000000<0P8200?ooo`3oool0
603oool2000000030820P03oool0oooo01P0oooo0`00000J0?ooo`030820P03oool0oooo01D0oooo
3oooool000goooooH@3oool01@30`<000000000000000000@41001T0oooo00@0`<30000000000000
P8206P3oool01010@400000000000010@40I0?ooo`050820P0000000000000000030`<006@3oool0
1010@400000000000000000I0?ooo`040<30`000000000000410@1X0oooo0`0000000`10@400oooo
0?ooo`0G0?ooo`040820P00000000000000001X0oooo00@0@410000000000000P8206@3oool40000
00030820P03oool0oooo01L0oooo00@0P820000000000000@4106@3oool01030`<00000000000010
@40J0?ooo`040820P000000000000<30`1T0oooo00D0P82000000000000000000<30`00`0?ooo`oo
oooo000=ooooof<0oooo0`00000K0?ooo`8000006P3oool00`20P800000000000002000001T0oooo
00@0P82000000000000000006P3oool3000000030820P03oool0oooo01L0oooo00@0P82000000000
000000006P3oool3000001X0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`040820P00000000000
000001X0oooo100000000`20P800oooo0?ooo`0G0?ooo`040820P000000000000820P1X0oooo0`00
000J0?ooo`<000006P3oool01020P800000000000020P80`0?ooo`oooooo000=ooooof<0oooo00@0
`<30000000000000@4106P3oool01010@400000000000030`<0I0?ooo`050410@000000000000000
0020P8006@3oool01010@400000000000020P80J0?ooo`<0000000<0P8200?ooo`3oool05`3oool3
000000030820P03oool0oooo01L0oooo00D0`<3000000000000000000<30`00I0?ooo`040410@000
000000000820P1T0oooo00@0P820000000000000@4106@3oool01@30`<000000000000000000@410
01X0oooo0`00000J0?ooo`040410@000000000000410@1X0oooo00<0@4100000000000006P3oool0
1010@400000000000020P80_0?ooo`oooooo000=ooooof@0oooo1000000J0?ooo`<000006P3oool4
000001T0oooo00D0P82000000000000000000820P00I0?ooo`040820P00000000000000001X0oooo
0`00000J0?ooo`@000006P3oool3000000030820P03oool0oooo01L0oooo00@0P820000000000000
P8206P3oool3000000030820P03oool0oooo01P0oooo0`00000J0?ooo`<000006`3oool200000003
0820P03oool0oooo01L0oooo00D0P82000000000000000000820P00^0?ooo`oooooo000=ooooofD0
oooo00@0@410000000000000P8206@3oool01030`<00000000000020P80J0?ooo`@0000000<0`<30
0?ooo`3oool05P3oool01020P800000000000000000J0?ooo`040820P000000000000410@1T0oooo
00D0`<3000000000000000000<30`00I0?ooo`040410@000000000000820P1T0oooo00@0P8200000
00000000@4106P3oool3000001X0oooo00D0@41000000000000000000820P00I0?ooo`040<30`000
000000000410@1T0oooo00D0`<3000000000000000000<30`00I0?ooo`040410@000000000000820
P1T0oooo00@0P820000000000000@410;P3oool?ooooo`003OoooomV0?ooo`040410@00000000000
0820P1T0oooo00@0P820000000000000@4106@3oool01@30`<000000000000000000@41001T0oooo
00D0P82000000000000000000<30`00I0?ooo`040410@000000000000410@1X0oooo0`00000J0?oo
o`040820P000000000000820P1T0oooo00@0`<30000000000000@4106P3oool01010@40000000000
0030`<0I0?ooo`050820P0000000000000000030`<006@3oool01020P800000000000000000I0?oo
o`040820P00000000000000001X0oooo00@0P820000000000000`<306@3oool01@20P80000000000
00000000`<3002`0oooo3oooool000goooooIP3oool01@20P8000000000000000000P82001T0oooo
00<0P8200000000000006`3oool3000000030820P03oool0oooo01L0oooo1000000J0?ooo`<00000
6P3oool01020P800000000000020P80J0?ooo`<0000000<0P8200?ooo`3oool0603oool3000001X0
oooo0`00000J0?ooo`040820P00000000000000001X0oooo0`0000000`20P800oooo0?ooo`0G0?oo
o`040820P00000000000000001X0oooo0`00000J0?ooo`@00000;03oool?ooooo`003OoooomW0?oo
o`040820P000000000000410@1X0oooo0`0000000`30`<00oooo0?ooo`0G0?ooo`050410@0000000
000000000020P8006@3oool01010@400000000000020P80J0?ooo`040410@000000000000<30`1T0
oooo00@0P820000000000000P8206@3oool01030`<00000000000000000J0?ooo`040410@0000000
00000<30`1T0oooo00@0P82000000000000000006@3oool00`30`<00000000000002000001X0oooo
00@0@410000000000000P8206@3oool3000000030410@03oool0oooo01L0oooo00D0`<3000000000
000000000<30`00I0?ooo`040410@000000000000<30`2/0oooo3oooool000goooooJ03oool01020
P800000000000000000J0?ooo`<000006P3oool4000001X0oooo0`00000J0?ooo`040820P0000000
0000000001X0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`040820P00000000000000001X0oooo
0`00000J0?ooo`<0000000<0P8200?ooo`3oool05`3oool01@20P8000000000000000000P82001T0
oooo00D0P82000000000000000000820P00I0?ooo`<0000000<0P8200?ooo`3oool0603oool20000
00030820P03oool0oooo01P0oooo0`00000[0?ooo`oooooo000=ooooofP0oooo00D0`<3000000000
000000000410@00I0?ooo`040<30`000000000000820P1X0oooo00@0@410000000000000@4106@3o
ool01@20P8000000000000000000`<3001T0oooo00@0@41000000000000000006@3oool01030`<00
000000000010@40J0?ooo`<0000000<0@4100?ooo`3oool05`3oool01030`<00000000000000000J
0?ooo`040410@000000000000820P1T0oooo100000000`20P800oooo0?ooo`0G0?ooo`040820P000
000000000410@1T0oooo00@0`<30000000000000@4106P3oool01020P800000000000030`<0I0?oo
o`050820P0000000000000000030`<00:@3oool?ooooo`003Ooooom?0?ooo`030820P03oool0oooo
01P0oooo0`00000K0?ooo`8000006P3oool00`20P800000000000002000001T0oooo00@0P8200000
0000000000006P3oool3000000030820P03oool0oooo01L0oooo00@0P82000000000000000006P3o
ool3000001X0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`040820P00000000000000001X0oooo
100000000`20P800oooo0?ooo`0G0?ooo`040820P000000000000820P1X0oooo0`00000J0?ooo`<0
00006P3oool01020P800000000000020P80Y0?ooo`oooooo000=ooooodl0oooo00<000000?ooo`3o
ool0603oool01030`<00000000000010@40J0?ooo`040410@000000000000<30`1T0oooo00D0@410
00000000000000000820P00I0?ooo`040410@000000000000820P1X0oooo0`0000000`20P800oooo
0?ooo`0G0?ooo`<0000000<0P8200?ooo`3oool05`3oool01@30`<000000000000000000`<3001T0
oooo00@0@410000000000000P8206@3oool01020P800000000000010@40I0?ooo`050<30`0000000
000000000010@4006P3oool3000000030820P03oool0oooo01L0oooo00@0@410000000000000@410
6P3oool00`10@40000000000000J0?ooo`040410@000000000000820P2P0oooo3oooool000gooooo
C`3oool2000000030<30`03oool0oooo01L0oooo00D0P82000000000000000000<30`00I0?ooo`03
0410@0000000000001X0oooo00D0P82000000000000000000820P00H0?ooo`050<30`00000000000
00000010@4006@3oool01@30`<000000000000000000`<3001T0oooo00@0@410000000000000P820
6@3oool01@20P8000000000000000000`<3001T0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`04
0<30`000000000000410@1X0oooo0`0000000`10@400oooo0?ooo`0H0?ooo`040410@00000000000
0<30`1T0oooo00@0@410000000000000P8206P3oool2000000030410@03oool0oooo01L0oooo00D0
`<3000000000000000000820P00W0?ooo`oooooo000=ooooodl0oooo0`00000J0?ooo`040820P000
000000000820P1X0oooo0`00000J0?ooo`@0000000<0P8200?ooo`3oool05`3oool3000001/0oooo
0`00000J0?ooo`<0000000<0P8200?ooo`3oool05`3oool01020P800000000000020P80J0?ooo`<0
00006P3oool3000001X0oooo00<0P8200000000000000P00000J0?ooo`<000006P3oool300000003
0820P03oool0oooo01L0oooo00@0P82000000000000000006P3oool3000002L0oooo3oooool000go
ooooC`3oool01030`<00000000000000000J0?ooo`040410@000000000000820P1T0oooo00@0P820
000000000000@4106@3oool01@30`<000000000000000000@41001T0oooo00D0P820000000000000
00000<30`00I0?ooo`040410@000000000000410@1X0oooo0`00000J0?ooo`040820P00000000000
0820P1T0oooo00@0`<30000000000000@4106P3oool01010@400000000000030`<0I0?ooo`050820
P0000000000000000030`<006@3oool01020P800000000000000000I0?ooo`040820P00000000000
000001X0oooo00@0P820000000000000`<306@3oool01@20P8000000000000000000`<3002D0oooo
3oooool000goooooD@3oool2000000030820P03oool0oooo01L0oooo00D0P8200000000000000000
0820P00I0?ooo`030820P0000000000001/0oooo1000000I0?ooo`@000006P3oool3000001X0oooo
00@0P820000000000000P8206P3oool3000000030820P03oool0oooo01P0oooo0`00000J0?ooo`<0
00006P3oool01020P800000000000000000J0?ooo`<0000000<0P8200?ooo`3oool05`3oool01020
P800000000000000000J0?ooo`<000006P3oool4000002D0oooo3oooool000goooooD@3oool01010
@400000000000020P80I0?ooo`040820P000000000000410@1X0oooo0`0000000`30`<00oooo0?oo
o`0G0?ooo`050410@0000000000000000010@4006@3oool01010@400000000000020P80J0?ooo`04
0410@000000000000<30`1T0oooo00@0P820000000000000P8206@3oool01030`<00000000000000
000J0?ooo`040410@000000000000<30`1T0oooo00@0P82000000000000000006@3oool00`30`<00
000000000002000001X0oooo00@0@410000000000000P8206@3oool3000000030410@03oool0oooo
01L0oooo00D0`<3000000000000000000<30`00I0?ooo`040410@000000000000<30`2@0oooo3ooo
ool000goooooDP3oool3000001X0oooo00@0P82000000000000000006P3oool3000001X0oooo1000
000J0?ooo`<000006P3oool01020P800000000000000000J0?ooo`<0000000<0P8200?ooo`3oool0
5`3oool01020P800000000000000000J0?ooo`<000006P3oool3000000030820P03oool0oooo01L0
oooo00D0P82000000000000000000820P00I0?ooo`050820P0000000000000000020P8006@3oool4
000001X0oooo0P0000000`20P800oooo0?ooo`0H0?ooo`<00000903oool?ooooo`003OoooomC0?oo
o`80000000<0@4100?ooo`3oool05`3oool01@30`<000000000000000000@41001T0oooo00@0`<30
000000000000P8206P3oool01010@400000000000010@40I0?ooo`050820P0000000000000000030
`<006@3oool01010@400000000000000000I0?ooo`040<30`000000000000410@1X0oooo0`000000
0`10@400oooo0?ooo`0G0?ooo`040<30`00000000000000001X0oooo00@0@410000000000000P820
6@3oool4000000030820P03oool0oooo01L0oooo00@0P820000000000000@4106@3oool01@30`<00
0000000000000000`<3001T0oooo00@0P820000000000000`<306@3oool01@20P800000000000000
0000`<300280oooo3oooool000goooooD`3oool01030`<00000000000010@40J0?ooo`040410@000
000000000<30`1X0oooo0P0000000`20P800oooo0?ooo`0G0?ooo`030<30`0000000000000800000
00<0`<300?ooo`3oool05P3oool01030`<00000000000000000J0?ooo`040820P000000000000410
@1T0oooo00D0`<3000000000000000000<30`00I0?ooo`040410@000000000000820P1T0oooo00@0
P820000000000000@4106@3oool01@30`<000000000000000000P82001T0oooo00D0@41000000000
000000000820P00I0?ooo`040<30`000000000000410@1X0oooo0`0000000`30`<00oooo0?ooo`0G
0?ooo`040820P000000000000820P1T0oooo00@0`<30000000000000@4108P3oool?ooooo`003Ooo
oomE0?ooo`8000006`3oool3000001X0oooo00@0P820000000000000P8206P3oool3000000030820
P03oool0oooo01L0oooo00@0P82000000000000000006P3oool4000001T0oooo0`0000000`20P800
oooo0?ooo`0H0?ooo`<0000000<0P8200?ooo`3oool05`3oool01020P800000000000000000J0?oo
o`<000006P3oool4000001X0oooo1000000I0?ooo`040820P00000000000000001X0oooo00<0P820
0000000000006P3oool01020P800000000000000000Q0?ooo`oooooo000=oooooeD0oooo00@0P820
000000000000`<306@3oool01@20P8000000000000000000`<3001T0oooo00<0@410000000000000
6P3oool01@30`<000000000000000000P82001P0oooo00D0`<3000000000000000000410@00I0?oo
o`050<30`0000000000000000030`<006@3oool01010@400000000000020P80I0?ooo`050820P000
0000000000000030`<006@3oool3000000030820P03oool0oooo01L0oooo00@0`<30000000000000
@4106P3oool3000000030410@03oool0oooo01P0oooo00@0@410000000000000`<306@3oool01020
P800000000000020P80J0?ooo`80000000<0@4100?ooo`3oool05`3oool01@30`<00000000000000
0000P8200200oooo3oooool000goooooEP3oool3000001X0oooo00@0P820000000000000P8206P3o
ool3000001X0oooo100000000`20P800oooo0?ooo`0G0?ooo`<000006`3oool3000001X0oooo0`00
00000`20P800oooo0?ooo`0G0?ooo`040820P000000000000820P1X0oooo0`00000J0?ooo`<00000
6P3oool00`20P800000000000002000001X0oooo0`00000J0?ooo`040820P000000000000820P1T0
oooo00@0P82000000000000000006P3oool300000200oooo3oooool000goooooEP3oool01030`<00
000000000000000J0?ooo`040410@000000000000820P1T0oooo00@0P820000000000000@4106@3o
ool01@30`<000000000000000000@41001T0oooo00D0P82000000000000000000<30`00I0?ooo`05
0410@0000000000000000030`<006@3oool3000001X0oooo00@0P820000000000000P8206@3oool0
1030`<00000000000010@40J0?ooo`040410@000000000000<30`1T0oooo00D0P820000000000000
00000<30`00I0?ooo`040820P00000000000000001T0oooo00@0`<3000000000000000006P3oool0
1020P800000000000030`<0I0?ooo`050820P0000000000000000030`<007P3oool?ooooo`003Ooo
oomH0?ooo`80000000<0P8200?ooo`3oool05`3oool01@20P8000000000000000000P82001T0oooo
00<0P8200000000000006`3oool4000001T0oooo1000000J0?ooo`<0000000<0P8200?ooo`3oool0
5`3oool01020P800000000000020P80J0?ooo`<0000000<0P8200?ooo`3oool0603oool3000001X0
oooo0`00000J0?ooo`040820P00000000000000001X0oooo0`0000000`20P800oooo0?ooo`0G0?oo
o`040820P00000000000000001X0oooo0`00000J0?ooo`@000007P3oool?ooooo`003OoooomH0?oo
o`040410@000000000000820P1T0oooo00@0P820000000000000@4106P3oool3000000030<30`03o
ool0oooo01L0oooo00D0@41000000000000000000410@00I0?ooo`040410@000000000000820P1X0
oooo00@0@410000000000000`<306@3oool01020P800000000000020P80I0?ooo`040<30`0000000
0000000001X0oooo00@0@410000000000000`<306@3oool01020P800000000000000000I0?ooo`03
0<30`00000000000008000006P3oool01010@400000000000020P80I0?ooo`<0000000<0@4100?oo
o`3oool05`3oool01@30`<000000000000000000`<3001T0oooo00@0@410000000000000P8207@3o
ool?ooooo`003OoooomI0?ooo`<000006P3oool01020P800000000000000000J0?ooo`<000006P3o
ool4000001X0oooo0`00000J0?ooo`040820P00000000000000001X0oooo00@0P820000000000000
P8206@3oool01020P800000000000000000J0?ooo`<000006P3oool3000000030820P03oool0oooo
01L0oooo00D0P82000000000000000000820P00I0?ooo`050820P0000000000000000020P8006@3o
ool4000001X0oooo0P0000000`20P800oooo0?ooo`0H0?ooo`<0000000<0P8200?ooo`3oool06P3o
ool?ooooo`003OoooomJ0?ooo`80000000<0@4100?ooo`3oool05`3oool01@30`<00000000000000
0000@41001T0oooo00@0`<30000000000000P8206P3oool01010@400000000000010@40I0?ooo`05
0820P0000000000000000030`<006@3oool01020P800000000000000000I0?ooo`040<30`0000000
00000410@1X0oooo0`0000000`10@400oooo0?ooo`0G0?ooo`040<30`00000000000000001X0oooo
00@0@410000000000000P8206@3oool4000000030820P03oool0oooo01L0oooo00@0P82000000000
0000@4106@3oool01@30`<000000000000000000`<3001T0oooo00@0P820000000000000`<306@3o
ool01@20P8000000000000000000`<3001/0oooo3oooool000goooooFP3oool01030`<0000000000
0010@40J0?ooo`040410@000000000000<30`1X0oooo0P0000000`20P800oooo0?ooo`0G0?ooo`03
0<30`000000000000080000000<0`<300?ooo`3oool05P3oool01030`<00000000000000000J0?oo
o`040<30`000000000000410@1T0oooo00D0`<3000000000000000000<30`00I0?ooo`040410@000
000000000820P1T0oooo00@0P820000000000000@4106@3oool01@30`<000000000000000000P820
01T0oooo00D0@41000000000000000000820P00I0?ooo`040<30`000000000000410@1X0oooo0`00
00000`30`<00oooo0?ooo`0G0?ooo`040820P000000000000820P1T0oooo00@0`<30000000000000
@4106`3oool?ooooo`003OoooomL0?ooo`8000006`3oool3000001X0oooo00@0P820000000000000
P8206P3oool3000000030820P03oool0oooo01L0oooo00@0P82000000000000000006P3oool40000
01T0oooo0`0000000`20P800oooo0?ooo`0H0?ooo`<0000000<0P8200?ooo`3oool05`3oool01020
P800000000000000000J0?ooo`<000006P3oool4000001X0oooo1000000I0?ooo`040820P0000000
0000000001X0oooo00<0P8200000000000006`3oool3000001X0oooo3oooool000goooooG03oool0
1020P800000000000030`<0I0?ooo`050820P0000000000000000030`<006@3oool00`10@4000000
0000000J0?ooo`050<30`0000000000000000020P800603oool01@30`<000000000000000000@410
01T0oooo00D0`<3000000000000000000<30`00I0?ooo`040410@000000000000820P1T0oooo00D0
P82000000000000000000820P00I0?ooo`<0000000<0P8200?ooo`3oool05`3oool01030`<000000
00000010@40J0?ooo`<0000000<0@4100?ooo`3oool0603oool01010@400000000000030`<0I0?oo
o`040820P000000000000820P1X0oooo0P0000000`10@400oooo0?ooo`0H0?ooo`040410@0000000
00000820P1T0oooo3oooool000goooooG@3oool3000001X0oooo00@0P820000000000000P8206P3o
ool3000001X0oooo100000000`20P800oooo0?ooo`0G0?ooo`<000006`3oool3000001X0oooo0`00
00000`20P800oooo0?ooo`0G0?ooo`040820P00000000000000001X0oooo0`00000J0?ooo`<00000
6P3oool00`20P800000000000002000001X0oooo0`00000J0?ooo`040820P000000000000820P1T0
oooo00@0P82000000000000000006P3oool3000001T0oooo3oooool000goooooG@3oool01030`<00
000000000000000J0?ooo`040410@000000000000820P1T0oooo00@0P820000000000000@4106@3o
ool01@30`<000000000000000000@41001T0oooo00D0P82000000000000000000<30`00I0?ooo`05
0410@0000000000000000030`<006@3oool3000001X0oooo00@0P820000000000000@4106@3oool0
1030`<00000000000010@40J0?ooo`040410@000000000000<30`1T0oooo00D0P820000000000000
00000<30`00I0?ooo`050820P0000000000000000030`<00603oool01030`<00000000000000000J
0?ooo`040820P000000000000<30`1T0oooo00D0P82000000000000000000<30`00G0?ooo`oooooo
000=oooooel0oooo0P0000000`20P800oooo0?ooo`0G0?ooo`050820P0000000000000000020P800
6@3oool00`20P80000000000000K0?ooo`@000006@3oool4000001X0oooo0`0000000`20P800oooo
0?ooo`0G0?ooo`040820P000000000000820P1X0oooo0`0000000`20P800oooo0?ooo`0H0?ooo`<0
00006P3oool3000001X0oooo00@0P82000000000000000006P3oool3000000030820P03oool0oooo
01L0oooo00@0P82000000000000000006P3oool3000001X0oooo1000000G0?ooo`oooooo000=oooo
oel0oooo00@0@410000000000000P8206@3oool01020P800000000000010@40J0?ooo`<0000000<0
`<300?ooo`3oool05`3oool01@10@4000000000000000000@41001T0oooo00@0@410000000000000
P8206P3oool01010@400000000000030`<0I0?ooo`040820P000000000000820P1T0oooo00@0`<30
00000000000000006P3oool01010@400000000000030`<0I0?ooo`040820P00000000000000001T0
oooo00<0`<300000000000000P00000J0?ooo`040410@000000000000820P1T0oooo0`0000000`10
@400oooo0?ooo`0G0?ooo`050<30`0000000000000000030`<006@3oool00`10@40000000000000G
0?ooo`oooooo000=ooooof00oooo00@0P820000000000000`<306@3oool01@20P800000000000000
0000`<3001T0oooo00@0@410000000000000`<306@3oool01@20P8000000000000000000`<3001T0
oooo0`0000000`20P800oooo0?ooo`0G0?ooo`050<30`0000000000000000020P8006@3oool01020
P800000000000020P80J0?ooo`040410@000000000000<30`1T0oooo00@0@410000000000000P820
6@3oool01020P800000000000010@40I0?ooo`050<30`0000000000000000010@4006@3oool01@30
`<000000000000000000P82001T0oooo00@0@41000000000000000006P3oool00`10@40000000410
@00J0?ooo`8000005`3oool?ooooo`003OoooomQ0?ooo`<000006P3oool4000001X0oooo0P000000
0`20P800oooo0?ooo`0H0?ooo`040820P00000000000000001X0oooo0`0000000`20P800oooo0?oo
o`0H0?ooo`<000006P3oool3000001X0oooo00@0P82000000000000000006P3oool3000001X0oooo
00@0P82000000000000000006@3oool5000001X0oooo0`00000J0?ooo`<0000000<0P8200?ooo`3o
ool05`3oool01020P800000000000020P80J0?ooo`030000003oool0oooo01D0oooo3oooool000go
ooooH@3oool01@30`<000000000000000000`<3001T0oooo00@0@410000000000000`<306P3oool2
000000030820P03oool0oooo01L0oooo00<0`<300000000000000P0000000`30`<00oooo0?ooo`0F
0?ooo`040<30`00000000000000001X0oooo00@0`<30000000000000@4106@3oool01@30`<000000
000000000000`<3001T0oooo00@0@410000000000000P8206@3oool01020P800000000000010@40I
0?ooo`050<30`0000000000000000020P8006@3oool01@10@4000000000000000000P82001T0oooo
00@0`<30000000000000@4106P3oool3000000030<30`03oool0oooo01L0oooo00@0P82000000000
0000P8206@3oool00`30`<00oooo0?ooo`0E0?ooo`oooooo000=ooooof<0oooo0P0000000`20P800
oooo0?ooo`0H0?ooo`<000006P3oool01020P800000000000020P80J0?ooo`<0000000<0P8200?oo
o`3oool05`3oool01020P800000000000000000J0?ooo`@000006@3oool3000000030820P03oool0
oooo01P0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`040820P00000000000000001X0oooo0`00
000J0?ooo`@000006P3oool4000001T0oooo00@0P82000000000000000006P3oool00`20P8000000
0000000a0?ooo`oooooo000=ooooof<0oooo00@0P820000000000000`<306@3oool01@20P8000000
000000000000`<3001T0oooo00<0@4100000000000006P3oool01@30`<000000000000000000P820
01P0oooo00D0`<3000000000000000000410@00I0?ooo`050<30`0000000000000000030`<006@3o
ool01010@400000000000020P80I0?ooo`050820P0000000000000000020P8006@3oool01020P800
000000000020P80I0?ooo`050<30`0000000000000000030`<006@3oool3000000030410@03oool0
oooo01P0oooo00@0@410000000000000`<306@3oool01020P800000000000020P80J0?ooo`800000
00<0@4100?ooo`3oool0;P3oool?ooooo`003OoooomT0?ooo`<000006P3oool01020P80000000000
0020P80J0?ooo`<000006P3oool4000000030820P03oool0oooo01L0oooo0`00000K0?ooo`<00000
6P3oool3000000030820P03oool0oooo01L0oooo00@0P82000000000000000006P3oool3000001X0
oooo0`0000000`20P800oooo0?ooo`0G0?ooo`030820P00000000000008000006P3oool3000001X0
oooo00@0P820000000000000P8206@3oool01020P800000000000000000_0?ooo`oooooo000=oooo
ofD0oooo00<0@4100000000000006P3oool01010@400000000000020P80I0?ooo`040820P0000000
00000410@1T0oooo00D0`<3000000000000000000410@00I0?ooo`050820P0000000000000000030
`<006@3oool01@10@4000000000000000000`<3001T0oooo0`00000J0?ooo`040820P00000000000
0410@1T0oooo00@0`<30000000000000@4106P3oool01010@400000000000030`<0I0?ooo`050820
P0000000000000000030`<006@3oool01@20P8000000000000000000`<3001P0oooo00@0`<300000
0000000000006P3oool01020P800000000000030`<0^0?ooo`oooooo000=ooooofH0oooo0P000000
0`10@400oooo0?ooo`0G0?ooo`050<30`0000000000000000020P8006@3oool01030`<0000000000
0020P80J0?ooo`@0000000<0`<300?ooo`3oool05P3oool01@20P8000000000000000000`<3001T0
oooo00@0P820000000000000@4106@3oool01030`<00000000000010@40J0?ooo`040410@0000000
00000410@1X0oooo0`00000J0?ooo`040820P000000000000820P1T0oooo00D0P820000000000000
00000820P00I0?ooo`040820P000000000000410@1T0oooo00D0`<3000000000000000000<30`00I
0?ooo`040410@000000000000820P2d0oooo3oooool000goooooIP3oool01020P800000000000000
000J0?ooo`<000006P3oool3000000030820P03oool0oooo01L0oooo00<0P8200000000000000P00
000I0?ooo`040820P000000000000820P1X0oooo00@0P820000000000000P8206P3oool3000001X0
oooo0`00000J0?ooo`040820P000000000000820P1X0oooo0`00000J0?ooo`@000006P3oool01020
P800000000000000000I0?ooo`@000006P3oool3000000030820P03oool0oooo02X0oooo3oooool0
00goooooI`3oool01020P800000000000030`<0I0?ooo`050820P0000000000000000030`<006@3o
ool01010@400000000000030`<0I0?ooo`050820P0000000000000000030`<006@3oool300000003
0820P03oool0oooo01L0oooo00D0`<3000000000000000000820P00I0?ooo`040820P00000000000
0820P1X0oooo00@0@410000000000000`<306@3oool01010@400000000000020P80I0?ooo`040<30
`000000000000410@1T0oooo00D0`<3000000000000000000410@00I0?ooo`050<30`00000000000
00000020P8006@3oool01010@400000000000000000J0?ooo`030410@0000000@41002`0oooo3ooo
ool000goooooJ03oool3000001X0oooo1000000J0?ooo`80000000<0P8200?ooo`3oool0603oool0
1020P800000000000000000J0?ooo`<0000000<0P8200?ooo`3oool0603oool3000001X0oooo0`00
000J0?ooo`040820P00000000000000001X0oooo0`00000J0?ooo`040820P00000000000000001T0
oooo1@00000J0?ooo`<000006P3oool3000000030820P03oool0oooo01L0oooo00@0P82000000000
0000P820:`3oool?ooooo`003OoooomX0?ooo`050<30`0000000000000000030`<006@3oool01010
@400000000000030`<0J0?ooo`80000000<0P8200?ooo`3oool05`3oool00`30`<00000000000002
000000030<30`03oool0oooo01H0oooo00@0`<3000000000000000006P3oool01030`<0000000000
0010@40I0?ooo`050<30`0000000000000000030`<006@3oool01010@400000000000020P80I0?oo
o`040820P000000000000410@1T0oooo00D0`<3000000000000000000820P00I0?ooo`050410@000
0000000000000020P8006@3oool01030`<00000000000010@40J0?ooo`<0000000<0`<300?ooo`3o
ool05`3oool01020P800000000000020P80Z0?ooo`oooooo000=ooooodl0oooo00<0P8200?ooo`3o
ool0603oool2000000030820P03oool0oooo01P0oooo0`00000J0?ooo`040820P000000000000820
P1X0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`040820P00000000000000001X0oooo1000000J
0?ooo`80000000<0P8200?ooo`3oool0603oool3000000030820P03oool0oooo01L0oooo00@0P820
00000000000000006P3oool3000001X0oooo1000000J0?ooo`@000006@3oool01020P80000000000
0000000J0?ooo`030820P0000000000002X0oooo3oooool000goooooC`3oool00`10@400oooo0?oo
o`0H0?ooo`040820P000000000000<30`1T0oooo00D0P82000000000000000000<30`00I0?ooo`03
0410@0000000000001X0oooo00D0`<3000000000000000000820P00H0?ooo`050<30`00000000000
00000010@4006@3oool01@30`<000000000000000000`<3001T0oooo00@0@410000000000000P820
6@3oool01@20P8000000000000000000P82001T0oooo00@0P820000000000000P8206@3oool01@30
`<000000000000000000`<3001T0oooo0`0000000`10@400oooo0?ooo`0H0?ooo`040410@0000000
00000<30`1T0oooo00@0P820000000000000P8206P3oool2000000030410@03oool0oooo02L0oooo
3oooool000goooooC`3oool2000000030<30`03oool0oooo01L0oooo00@0P820000000000000P820
6@3oool01030`<00000000000010@40J0?ooo`<0000000<0`<300?ooo`3oool05`3oool01@10@400
0000000000000000P82001T0oooo00@0@410000000000000P8206P3oool3000000030820P03oool0
oooo01L0oooo00@0P820000000000000@4106@3oool01@30`<000000000000000000`<3001T0oooo
00@0@410000000000000`<306@3oool01020P800000000000000000I0?ooo`030<30`00000000000
008000006P3oool01010@400000000000020P80I0?ooo`040820P000000000000410@1T0oooo00@0
`<300000000000000000:03oool?ooooo`003Ooooom?0?ooo`<000006P3oool00`20P80000000000
000J0?ooo`040820P00000000000000001X0oooo0`00000J0?ooo`@000006@3oool01@20P8000000
000000000000P82001T0oooo00D0P82000000000000000000820P00I0?ooo`<000006`3oool30000
01X0oooo0`00000J0?ooo`040820P000000000000820P1X0oooo0`0000000`20P800oooo0?ooo`0G
0?ooo`050820P0000000000000000020P8006@3oool3000001/0oooo0P0000000`20P800oooo0?oo
o`0U0?ooo`oooooo000=ooooodl0oooo00@0@410000000000000P8206P3oool2000000030410@03o
ool0oooo01L0oooo00D0`<3000000000000000000820P00I0?ooo`040<30`000000000000820P1X0
oooo100000000`30`<00oooo0?ooo`0F0?ooo`050820P0000000000000000030`<006@3oool01020
P800000000000010@40I0?ooo`040<30`000000000000410@1X0oooo00@0@410000000000000@410
6P3oool3000001X0oooo00@0P820000000000000P8206@3oool01@20P8000000000000000000P820
01T0oooo00@0P820000000000000@4106@3oool01@30`<000000000000000000`<3001T0oooo00@0
@410000000000000P8209P3oool?ooooo`003Ooooom@0?ooo`<0000000<0P8200?ooo`3oool05`3o
ool01020P800000000000000000J0?ooo`<000006P3oool3000000030820P03oool0oooo01L0oooo
00<0P8200000000000000P00000I0?ooo`040820P000000000000820P1X0oooo00@0P82000000000
0000P8206P3oool3000001X0oooo0`00000J0?ooo`040820P000000000000820P1X0oooo0`00000J
0?ooo`@000006P3oool01020P800000000000000000I0?ooo`@000006P3oool3000000030820P03o
ool0oooo02<0oooo3oooool000goooooD03oool01020P800000000000000000J0?ooo`040820P000
000000000<30`1T0oooo00D0P82000000000000000000<30`00I0?ooo`040410@000000000000820
P1T0oooo00D0P82000000000000000000<30`00I0?ooo`<0000000<0P8200?ooo`3oool05`3oool0
1@30`<000000000000000000P82001T0oooo00@0P820000000000000P8206P3oool01010@4000000
00000030`<0I0?ooo`040410@000000000000820P1T0oooo00@0`<30000000000000@4106@3oool0
1@30`<000000000000000000@41001T0oooo00D0`<3000000000000000000820P00I0?ooo`040410
@00000000000000001X0oooo00<0@41000000010@4009@3oool?ooooo`003OoooomA0?ooo`040820
P00000000000000001X0oooo0`00000J0?ooo`@000006P3oool3000001X0oooo00@0P82000000000
000000006P3oool3000000030820P03oool0oooo01P0oooo0`00000J0?ooo`<000006P3oool01020
P800000000000000000J0?ooo`<000006P3oool01020P800000000000000000I0?ooo`D000006P3o
ool3000001X0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`040820P000000000000820P2@0oooo
3oooool000goooooDP3oool3000000030410@03oool0oooo01L0oooo00D0`<300000000000000000
0<30`00I0?ooo`040410@000000000000<30`1X0oooo0P0000000`10@400oooo0?ooo`0G0?ooo`03
0<30`000000000000080000000<0`<300?ooo`3oool05P3oool01030`<00000000000000000J0?oo
o`040<30`000000000000410@1T0oooo00D0`<3000000000000000000<30`00I0?ooo`040410@000
000000000820P1T0oooo00@0P820000000000000@4106@3oool01@30`<000000000000000000P820
01T0oooo00D0@41000000000000000000820P00I0?ooo`050<30`0000000000000000030`<006@3o
ool3000000030<30`03oool0oooo01L0oooo00@0P820000000000000P8208`3oool?ooooo`003Ooo
oomC0?ooo`040410@000000000000820P1X0oooo00<0@41000000010@4006P3oool3000000030820
P03oool0oooo01L0oooo00@0`<30000000000000@4106P3oool01010@400000000000010@40I0?oo
o`050820P0000000000000000030`<006@3oool01010@400000000000000000J0?ooo`80000000<0
@4100?ooo`3oool0603oool3000000030410@03oool0oooo01L0oooo00D0`<300000000000000000
0<30`00I0?ooo`040410@000000000000820P1T0oooo00D0P82000000000000000000<30`00I0?oo
o`040820P00000000000000001T0oooo00@0`<3000000000000000006P3oool01030`<0000000000
0030`<0R0?ooo`oooooo000=oooooe@0oooo0`00000J0?ooo`040820P000000000000820P1X0oooo
0`0000000`20P800oooo0?ooo`0H0?ooo`8000006`3oool4000001T0oooo1000000J0?ooo`<00000
00<0P8200?ooo`3oool05`3oool01020P800000000000000000J0?ooo`@000006P3oool200000003
0820P03oool0oooo01P0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`@000006P3oool01020P800
000000000020P80J0?ooo`<000006P3oool300000280oooo3oooool000goooooE@3oool300000003
0<30`03oool0oooo01L0oooo00@0P820000000000000P8206@3oool01030`<00000000000010@40J
0?ooo`040820P000000000000<30`1T0oooo00D0@41000000000000000000820P00I0?ooo`040410
@000000000000820P1X0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`040820P000000000000410
@1T0oooo00D0`<3000000000000000000<30`00I0?ooo`040410@000000000000<30`1T0oooo00@0
P82000000000000000006@3oool00`30`<00000000000002000001X0oooo00@0P820000000000000
P8206@3oool01020P800000000000010@40I0?ooo`040<30`0000000000000000240oooo3oooool0
00goooooE@3oool01020P800000000000000000J0?ooo`030820P0000000000001X0oooo00@0P820
00000000000000006P3oool3000001X0oooo1000000I0?ooo`050820P0000000000000000020P800
6@3oool01@20P8000000000000000000P82001T0oooo0`00000K0?ooo`<000006P3oool3000001X0
oooo00@0P820000000000000P8206P3oool3000000030820P03oool0oooo01P0oooo0`0000000`20
P800oooo0?ooo`0G0?ooo`<000006`3oool2000000030820P03oool0oooo01h0oooo3oooool000go
ooooEP3oool01010@400000000000020P80J0?ooo`80000000<0@4100?ooo`3oool05`3oool01@30
`<000000000000000000P82001T0oooo00@0`<30000000000000P8206P3oool4000000030<30`03o
ool0oooo01H0oooo00D0P82000000000000000000820P00I0?ooo`040820P000000000000410@1T0
oooo00@0`<30000000000000@4106P3oool01010@400000000000010@40J0?ooo`<000006P3oool0
1020P800000000000020P80I0?ooo`050820P0000000000000000020P8006@3oool01030`<000000
00000010@40I0?ooo`050<30`0000000000000000030`<006@3oool01010@400000000000020P80O
0?ooo`oooooo000=oooooeL0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`040820P00000000000
000001X0oooo0`00000J0?ooo`<0000000<0P8200?ooo`3oool05`3oool00`20P800000000000002
000001T0oooo00@0P82000000000000000006P3oool01020P800000000000020P80J0?ooo`<00000
6P3oool3000001X0oooo00@0P820000000000000P8206P3oool3000001X0oooo1000000J0?ooo`04
0820P00000000000000001T0oooo1000000J0?ooo`<0000000<0P8200?ooo`3oool0703oool?oooo
o`003OoooomG0?ooo`040820P00000000000000001X0oooo00@0P820000000000000`<306@3oool0
1@20P8000000000000000000`<3001T0oooo00@0@410000000000000P8206@3oool01@20P8000000
000000000000`<3001T0oooo0`0000000`10@400oooo0?ooo`0G0?ooo`050<30`000000000000000
0020P8006@3oool01020P800000000000020P80J0?ooo`040410@000000000000<30`1T0oooo00@0
@410000000000000P8206@3oool01030`<00000000000010@40I0?ooo`050<30`000000000000000
0010@4006@3oool01@30`<000000000000000000@41001T0oooo00@0@41000000000000000006P3o
ool00`10@40000000410@00N0?ooo`oooooo000=oooooeP0oooo00D0`<3000000000000000000<30
`00I0?ooo`040410@000000000000820P1T0oooo00@0P82000000000000000006P3oool01020P800
000000000030`<0I0?ooo`050820P0000000000000000020P8006@3oool01010@400000000000010
@40J0?ooo`040410@000000000000<30`1T0oooo00@0@410000000000000P8206@3oool01030`<00
000000000000000J0?ooo`<0000000<0`<300?ooo`3oool05`3oool01@20P8000000000000000000
`<3001P0oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`0G0?ooo`040410@0000000
00000820P1T0oooo00@0P820000000000000@4106@3oool01@30`<000000000000000000`<3001`0
oooo3oooool000goooooF@3oool4000001X0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`040820
P000000000000820P1X0oooo0`00000J0?ooo`@0000000<0P8200?ooo`3oool05`3oool3000001/0
oooo0`00000J0?ooo`<0000000<0P8200?ooo`3oool05`3oool01020P800000000000000000J0?oo
o`<000006P3oool3000000030820P03oool0oooo01L0oooo00D0P82000000000000000000820P00J
0?ooo`<0000000<0P8200?ooo`3oool05`3oool3000000030820P03oool0oooo01P0oooo0`00000L
0?ooo`oooooo000=oooooeX0oooo00@0@410000000000000P8206P3oool00`10@40000000410@00J
0?ooo`<0000000<0P8200?ooo`3oool05`3oool01030`<00000000000010@40J0?ooo`040410@000
000000000410@1X0oooo0`0000000`30`<00oooo0?ooo`0G0?ooo`040410@00000000000000001X0
oooo0P0000000`10@400oooo0?ooo`0H0?ooo`<0000000<0@4100?ooo`3oool05`3oool01@30`<00
0000000000000000`<3001T0oooo00@0@410000000000000P8206@3oool01@20P800000000000000
0000`<3001T0oooo00@0P82000000000000000006@3oool01030`<00000000000000000J0?ooo`04
0<30`000000000000<30`1/0oooo3oooool000goooooF`3oool3000001X0oooo00@0P82000000000
0000P8206P3oool3000000030820P03oool0oooo01P0oooo0P00000K0?ooo`@000006@3oool01020
P800000000000000000J0?ooo`<0000000<0P8200?ooo`3oool05`3oool01020P800000000000000
000J0?ooo`@000006P3oool2000000030820P03oool0oooo01P0oooo0`0000000`20P800oooo0?oo
o`0G0?ooo`@000006P3oool01020P800000000000020P80J0?ooo`<000006P3oool3000001/0oooo
3oooool000goooooG03oool3000000030<30`03oool0oooo01L0oooo00@0P820000000000000P820
6@3oool01030`<00000000000010@40J0?ooo`040820P000000000000<30`1T0oooo00D0@4100000
0000000000000820P00I0?ooo`040410@000000000000820P1X0oooo0`0000000`20P800oooo0?oo
o`0G0?ooo`040820P000000000000410@1T0oooo00D0`<3000000000000000000<30`00I0?ooo`04
0410@000000000000<30`1T0oooo00@0P82000000000000000006@3oool00`30`<00000000000002
000001X0oooo00@0P820000000000000P8206@3oool01020P800000000000010@40J0?ooo`030410
@0000000000001X0oooo3oooool000goooooG03oool01020P800000000000000000J0?ooo`030820
P0000000000001X0oooo00@0P82000000000000000006P3oool3000001X0oooo1000000I0?ooo`05
0820P0000000000000000020P8006@3oool01@20P8000000000000000000P82001T0oooo0`00000K
0?ooo`<000006P3oool3000001X0oooo00@0P820000000000000P8206P3oool3000000030820P03o
ool0oooo01P0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`<000006`3oool2000000030820P03o
ool0oooo01L0oooo3oooool000gooooo@03oool01030`<00P8200820P020P80I0?ooo`040410@000
000000000820P1X0oooo0P0000000`10@400oooo0?ooo`0G0?ooo`050<30`0000000000000000020
P8006@3oool01030`<00000000000020P80J0?ooo`@0000000<0`<300?ooo`3oool05P3oool01@20
P8000000000000000000P82001T0oooo00@0P820000000000000@4106@3oool01@30`<0000000000
00000000`<3001T0oooo00@0@410000000000000@4106P3oool00`10@40000000000000J0?ooo`04
0820P000000000000820P1T0oooo00D0P82000000000000000000820P00I0?ooo`040<30`0000000
00000410@1T0oooo00D0`<3000000000000000000<30`00I0?ooo`040410@000000000000820P1P0
oooo3oooool000gooooo4P3oool00`20P80000000000000;000000030820P03oool0oooo01/0oooo
00<0@4100000000000001@0000000`20P800oooo0?ooo`0E0?ooo`<0000000<0@4100?ooo`3oool0
5`3oool01030`<00000000000000000J0?ooo`040410@000000000000820P1T0oooo00@0P8200000
00000000@4106@3oool00`30`<00000000000002000001D0oooo00D0];Bd0=[JfP3oool0oooo0<30
`003000000030<30`03oool0oooo01L0oooo00@0P820000000000000@4106P3oool01010@4000000
00000030`<0I0?ooo`040820P000000000000820P1T0oooo00@0`<30000000000000@4106P3oool0
1010@400000000000020P80I0?ooo`050410@0000000000000000030`<006@3oool01@20P8000000
000000000000`<3001P0oooo00D0P82000000000000000000820P00I0?ooo`040820P00000000000
0820P1L0oooo3oooool000gooooo4P3oool00`20P80000000000000;000000030820P03oool0oooo
01T0oooo00<0P8200000000000002@0000070?ooool00000/`00000E0?ooo`oooooo000=oooooa<0
oooo1000000:0820P1/0oooo00D0@41000000000000000000<30`0030?ooo`050820P00000000000
00000030`<001P3ooooo00000;<000005@3oool?ooooo`003OoooolD0?ooo`<0000000<0P8200?oo
o`3oool08@3oool4000000H0oooo00@0P82000000000000000001P3ooooo00000;<000005@3oool?
ooooo`003OoooolD0?ooo`050<30`0000000000000000020P8008@3oool01@30`<00000000000000
0000`<3000L0oooo00@0P820000000000000P820X03oool606UYJOl0oooo9`3oool?ooooo`003Ooo
oolE0?ooo`050820P0000000000000000020P8002P3ooolA000000D0oooo00@0P820000000000000
00002@3oool300000:00oooo00<0];Bd06UYJ@1YJFT0101YJFWo0?ooobH0oooo3oooool000gooooo
5P3oool01@20P8000000000000000000P82000T0oooo4@0000050?ooo`<0000000<0P8200?ooo`3o
ool01`3oool01010@400000000000020P82P0?ooo`030;Bd]01YJFT0JFUY00<0JFUY00<0];Bd0?oo
o`3oool0oP3oool00`20P800oooo0?ooo`0Q0?ooo`oooooo000=oooooaL0oooo00D0`<3000000000
000000000410@0080?oooa40P8201@3oool3000000X0oooo00@0P820000000000000P820X@3oool0
0`2?Shl0JFUY06UYJ@0306UYJ@030;Bd]03oool0oooo0?`0oooo00<0`<300000003oool08P3oool?
ooooo`003OoooolI0?ooo`<0000000<0P8200?ooo`3oool06P3oool01020P800000000000020P80;
0?ooo`<00000XP3oool606UYJOh0oooo00<0P82000000020P8008P3oool?ooooo`003OoooolI0?oo
o`050<30`0000000000000000020P8006`3oool01020P800000000000020P80;0?ooo`<00000X`3o
ool506UYJ@030;Bd]03oool0oooo0?/0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=
ooooo`T0oooo0P0000000`20P800oooo0?ooo`0=0?ooo`<0000000<0P8200?ooo`3oool0603oool0
1020P800000000000020P80;0?ooo`<00000X`3oool00`2d];@0JFUY06UYJ@0306UYJO`0oooo00@0
P82000000000000000008P3oool?ooooo`003Oooool90?ooo`80000000<0P8200?ooo`3oool03@3o
ool01@30`<000000000000000000P82000@0oooo4@0000040?ooo`040820P000000000000820P0/0
oooo0`00002T0?ooo`0308n?S`1YJFT0JFUY00<0JFUY00<0];Bd0?ooo`3oool0n03oool01020P800
000000000000000R0?ooo`oooooo000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`0>0?ooo`05
0820P0000000000000000020P8000`3ooolA000000@0oooo00@0P820000000000000P8202`3oool3
00000:@0oooo00<0];Bd06UYJ@1YJFT0101YJFWj0?ooo`D000008@3oool?ooooo`003Oooool90?oo
o`80000000<0P8200?ooo`3oool03`3oool01@20P8000000000000000000P8200080oooo4@20P804
0?ooo`040820P000000000000820P0/0oooo0`00002T0?ooo`030=[JfP1YJFT0JFUY00@0JFUY00<0
f][J0?ooo`3oool0m`3oool500000240oooo3oooool000gooooo2@3oool2000000030820P03oool0
oooo0100oooo00D0`<3000000000000000000410@00F0?ooo`040820P000000000000820P0/0oooo
0`00002U0?ooo`030;Bd]01YJFT0JFUY00@0JFUYn03oool6000000030820P03oool0oooo01h0oooo
3oooool000gooooo2@3oool2000000030820P03oool0oooo00L0oooo00<0P8200000000000003000
000E0?ooo`040820P000000000000820P0/0oooo0`00002V0?ooo`L0JFUYm`3oool6000000030820
P03oool0oooo01h0oooo3oooool000gooooo2@3oool2000000030820P03oool0oooo00L0oooo00<0
P8200000000000003000000F0?ooo`<000002P3oool01020P800000000000020P82V0?ooo`030;Bd
]01YJFT0JFUY00@0JFUY00<0f][J0?ooo`3oool0l`3oool00`20P80000000000000500000200oooo
3oooool000gooooo2@3oool2000000030820P03oool0oooo00L0oooo00<0P8200000000000003000
000F0?ooo`<000002P3oool01020P800000000000020P82W0?ooo`L0JFUYm@3oool800000200oooo
3oooool000gooooo2@3oool2000000030820P03oool0oooo02`0oooo00@0@4100000000000000000
2@3oool3000000030<30`03oool0oooo0:H0oooo1P1YJFT00`2d];@0oooo0?ooo`3b0?ooo`T00000
7`3oool?ooooo`003Oooool90?ooo`80000000<0P8200?ooo`3oool0;03oool01020P80000000000
000000090?ooo`<00000Z@3oool00`2d];@0JFUY06UYJ@0406UYJO<0oooo2P00000O0?ooo`oooooo
000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`0]0?ooo`<0000000<0@4100?ooo`3oool0103o
ool01030`<00000000000000002Z0?ooo`030=[JfP1YJFT0JFUY00@0JFUY00<0];Bd0?ooo`3oool0
l03oool:000000030820P03oool0oooo01`0oooo3oooool000gooooo2@3oool2000000030820P03o
ool0oooo02h0oooo100000050?ooo`<0000000<0P8200?ooo`3oool0Z@3oool606UYJ@030;Bd]03o
ool0oooo0>l0oooo00<0P8200000000000002@00000N0?ooo`oooooo000=ooooo`T0oooo0P000000
0`20P800oooo0?ooo`0^0?ooo`050820P0000000000000000010@4000`20P80400000:d0oooo1P1Y
JFWa0?ooo`030410@0000000000000T000007P3oool?ooooo`003Oooool90?ooo`80000000<0P820
0?ooo`3oool0<03oool00`10@400000000000005000000030820P03oool0oooo0:`0oooo00<0f][J
06UYJ@1YJFT0101YJFW`0?ooo`d000007@3oool?ooooo`003Oooool90?ooo`80000000<0P8200?oo
o`3oool0<P3oool500000;40oooo1P1YJFT00`2d];@0oooo0?ooo`3]0?ooo`d000007@3oool?oooo
o`003Oooool90?ooo`80000000<0P8200?ooo`3oool0j03oool00`2d];@0JFUY06UYJ@0306UYJ@03
08n?S`3oool0oooo0>`0oooo3P0000000`20P800oooo0?ooo`0J0?ooo`oooooo000=ooooo`T0oooo
0P0000000`20P800oooo0?ooo`3Y0?ooo`H0JFUYkP3oool>000000030820P03oool0oooo01X0oooo
3oooool000gooooo2@3oool2000000030820P03oool0oooo0>T0oooo00<0];Bd06UYJ@1YJFT00`1Y
JFT00`3Jf]X0oooo0?ooo`3Z0?ooo`030820P0000000000000d00000703oool?ooooo`003Oooool9
0?ooo`80000000<0P8200?ooo`3oool0jP3oool506UYJ@030;Bd]03oool0oooo0>X0oooo00<0P820
0000000000003@00000L0?ooo`oooooo000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3Z0?oo
o`030;Bd]01YJFT0JFUY00<0JFUYk03oool@000000030820P03oool0oooo01T0oooo3oooool000go
oooo2@3oool2000000030820P03oool0oooo0>/0oooo1P1YJFWZ0?ooo`030820P0000000000000h0
000000<0@4100?ooo`3oool06@3oool?ooooo`003Oooool90?ooo`80000000<0P8200?ooo`3oool0
k03oool506UYJNX0oooo00<0P8200000000000003`00000K0?ooo`oooooo000=ooooo`T0oooo0P00
00000`20P800oooo0?ooo`3/0?ooo`0308n?S`1YJFT0JFUY0080JFUY00<0];Bd0?ooo`3oool0i`3o
oolB000000030820P03oool0oooo01P0oooo3oooool000gooooo2@3oool2000000030820P03oool0
oooo0>`0oooo00<0];Bd06UYJ@1YJFT00`1YJFWY0?oooa<000006P3oool?ooooo`003Oooool90?oo
o`80000000<0P8200?ooo`3oool0k@3oool506UYJNP0oooo500000000`30`<00oooo0?ooo`0G0?oo
o`oooooo000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3]0?ooo`H0JFUYj03oool00`20P800
00000000000@000000030820P03oool0oooo01L0oooo3oooool000gooooo2@3oool2000000030820
P03oool0oooo0>h0oooo1@1YJFT00`3Jf]X0oooo0?ooo`3V0?ooo`030<30`020P800000000`00000
00<0P8200<30`03oool06P3oool?ooooo`003Oooool90?ooo`80000000<0P8200?ooo`3oool0kP3o
ool00`2?Shl0JFUY06UYJ@0206UYJ@0308n?S`3oool0oooo0>`0oooo00@0P820000000000000P820
8P3oool?ooooo`003Oooool90?ooo`80000000<0P8200?ooo`3oool0kP3oool00`2d];@0JFUY06UY
J@0306UYJNl0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooo`T0oooo0P000000
0`20P800oooo0?ooo`3_0?ooo`D0JFUY00<0];Bd0?ooo`3oool0k03oool2000000030820P03oool0
oooo0200oooo3oooool000gooooo2@3oool2000000030820P03oool0oooo0>l0oooo1P1YJFW^0?oo
o`80000000<0P8200?ooo`3oool0803oool?ooooo`003Oooool90?ooo`80000000<0P8200?ooo`3o
ool0k`3oool00`2d];@0JFUY06UYJ@0306UYJ@030;Bd]03oool0oooo0>/0oooo0P0000000`20P800
oooo0?ooo`0P0?ooo`oooooo000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3_0?ooo`030;Bd
]01YJFT0JFUY00<0JFUY00<0];Bd0?ooo`3oool0j`3oool2000000030820P03oool0oooo0200oooo
3oooool000gooooo2@3oool2000000030820P03oool0oooo0?00oooo1P1YJFW]0?ooo`80000000<0
P8200?ooo`3oool0803oool?ooooo`003Oooool90?ooo`80000000<0P8200?ooo`3oool0l03oool0
0`2d];@0JFUY06UYJ@0306UYJNd0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=oooo
o`T0oooo0P0000000`20P800oooo0?ooo`3a0?ooo`D0JFUY00<0];Bd0?ooo`3oool0jP3oool20000
00030820P03oool0oooo0200oooo3oooool000gooooo2@3oool2000000030820P03oool0oooo0?40
oooo1@1YJFT00`2d];@0oooo0?ooo`3Z0?ooo`80000000<0P8200?ooo`3oool0803oool?ooooo`00
3Oooool90?ooo`80000000<0P8200?ooo`3oool0l@3oool00`2d];@0JFUY06UYJ@0306UYJN`0oooo
0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooo`T0oooo0P0000000`20P800oooo0?oo
o`3a0?ooo`030;Bd]01YJFT0JFUY00<0JFUYk03oool2000000030820P03oool0oooo0200oooo3ooo
ool000gooooo2@3oool2000000030820P03oool0oooo0?80oooo1P1YJFW[0?ooo`80000000<0P820
0?ooo`3oool0803oool?ooooo`003Oooool90?ooo`80000000<0P8200?ooo`3oool0lP3oool606UY
JN/0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooo`T0oooo0P0000000`20P800
oooo0?ooo`3c0?ooo`D0JFUY00<0f][J0?ooo`3oool0j03oool2000000030820P03oool0oooo0200
oooo3oooool000gooooo2@3oool2000000030820P03oool0oooo0?<0oooo1@1YJFT00`2d];@0oooo
0?ooo`3X0?ooo`80000000<0P8200?ooo`3oool0803oool?ooooo`003Oooool90?ooo`80000000<0
P8200?ooo`3oool0l`3oool00`2?Shl0JFUY06UYJ@0206UYJ@030;Bd]03oool0oooo0>P0oooo0P00
00000`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3c
0?ooo`030;Bd]01YJFT0JFUY0080JFUY00<0];Bd0?ooo`3oool0j03oool2000000030820P03oool0
oooo0200oooo3oooool000gooooo2@3oool2000000030820P03oool0oooo0?<0oooo00<0f][J06UY
J@1YJFT00`1YJFWZ0?ooo`80000000<0P8200?ooo`3oool0803oool?ooooo`003Oooool90?ooo`80
000000<0P8200?ooo`3oool0m03oool506UYJNX0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oo
oooo000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3d0?ooo`D0JFUYjP3oool2000000030820
P03oool0oooo0200oooo3oooool000gooooo2@3oool2000000030820P03oool0oooo0?@0oooo1@1Y
JFT00`2d];@0oooo0?ooo`3W0?ooo`80000000<0P8200?ooo`3oool0803oool?ooooo`003Oooool9
0?ooo`80000000<0P8200?ooo`3oool0m@3oool506UYJNT0oooo0P0000000`20P800oooo0?ooo`0P
0?ooo`oooooo000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3e0?ooo`D0JFUYj@3oool20000
00030820P03oool0oooo0200oooo3oooool000gooooo2@3oool2000000030820P03oool0oooo0?D0
oooo1@1YJFWY0?ooo`80000000<0P8200?ooo`3oool0803oool?ooooo`003Oooool90?ooo`800000
00<0P8200?ooo`3oool0m@3oool506UYJ@030=[JfP3oool0oooo0>H0oooo0P0000000`20P800oooo
0?ooo`0P0?ooo`oooooo000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3e0?ooo`030;Bd]01Y
JFT0JFUY0080JFUY00<0];Bd0?ooo`3oool0iP3oool2000000030820P03oool0oooo0200oooo3ooo
ool000gooooo2@3oool2000000030820P03oool0oooo0?D0oooo00<0];Bd06UYJ@1YJFT00P1YJFT0
0`2d];@0oooo0?ooo`3V0?ooo`80000000<0P8200?ooo`3oool0803oool?ooooo`003Oooool90?oo
o`80000000<0P8200?ooo`3oool0m@3oool00`2d];@0JFUY06UYJ@0206UYJ@0308n?S`3oool0oooo
0>H0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooo`T0oooo0P0000000`20P800
oooo0?ooo`3e0?ooo`030;Bd]01YJFT0JFUY00<0JFUYj03oool2000000030820P03oool0oooo0200
oooo3oooool000gooooo2@3oool2000000030820P03oool0oooo0?D0oooo00<0f][J06UYJ@1YJFT0
0`1YJFWX0?ooo`80000000<0P8200?ooo`3oool0803oool?ooooo`003Oooool90?ooo`80000000<0
P8200?ooo`3oool0mP3oool506UYJNP0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=
ooooo`T0oooo0P0000000`20P800oooo0?ooo`3f0?ooo`D0JFUY00<0];Bd0?ooo`3oool0i@3oool2
000000030820P03oool0oooo0200oooo3oooool000gooooo2@3oool2000000030820P03oool0oooo
0?H0oooo1P1YJFWW0?ooo`80000000<0P8200?ooo`3oool0803oool?ooooo`003Oooool90?ooo`80
000000<0P8200?ooo`3oool0mP3oool606UYJNL0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oo
oooo000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3f0?ooo`H0JFUYi`3oool2000000030820
P03oool0oooo00h0oooo3`20P8000`30`<00oooo0?ooo`0?ooooo`003Oooool90?ooo`80000000<0
P8200?ooo`3oool0mP3oool00`2d];@0JFUY06UYJ@0306UYJ@030;Bd]03oool0oooo0>@0oooo0P00
00000`20P800oooo0?ooo`0>0?ooo`l0000000<0P8200?ooo`3oool03oooool000gooooo2@3oool2
000000030820P03oool0oooo0?H0oooo00<0];Bd06UYJ@1YJFT00`1YJFT00`2d];@0oooo0?ooo`3T
0?ooo`80000000<0P8200?ooo`3oool03P3oool00`20P80000000000000<000000030410@03oool0
oooo00oooooo000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3f0?ooo`030;Bd]01YJFT0JFUY
00<0JFUY00<0];Bd0?ooo`3oool0i03oool2000000030820P03oool0oooo00l0oooo0`00000>0?oo
o`oooooo000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3f0?ooo`030;Bd]01YJFT0JFUY00<0
JFUY00<0];Bd0?ooo`3oool0i03oool2000000030820P03oool0oooo00l0oooo0`00000>0?ooo`oo
oooo000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3f0?ooo`030;Bd]01YJFT0JFUY00<0JFUY
00<0];Bd0?ooo`3oool0i03oool2000000030820P03oool0oooo00l0oooo0`00000>0?ooo`oooooo
000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3f0?ooo`030;Bd]01YJFT0JFUY00<0JFUY00<0
];Bd0?ooo`3oool0i03oool2000000030820P03oool0oooo00l0oooo00@0P820000000000000P820
3@3oool?ooooo`003Oooool90?ooo`80000000<0P8200?ooo`3oool0mP3oool00`2d];@0JFUY06UY
J@0306UYJ@030;Bd]03oool0oooo0>@0oooo0P0000000`20P800oooo0?ooo`0?0?ooo`040820P000
000000000820P0d0oooo3oooool000gooooo2@3oool2000000030820P03oool0oooo0?H0oooo00<0
];Bd06UYJ@1YJFT00`1YJFT00`2d];@0oooo0?ooo`3T0?ooo`80000000<0P8200?ooo`3oool03`3o
ool01020P800000000000020P80=0?ooo`oooooo000=ooooo`T0oooo0P0000000`20P800oooo0?oo
o`3g0?ooo`D0JFUY00<0];Bd0?ooo`3oool0i03oool2000000030820P03oool0oooo0100oooo0`00
000=0?ooo`oooooo000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3g0?ooo`D0JFUY00<0];Bd
0?ooo`3oool0i03oool2000000030820P03oool0oooo0100oooo0`00000=0?ooo`oooooo000=oooo
o`T0oooo0P0000000`20P800oooo0?ooo`3g0?ooo`D0JFUY00<0];Bd0?ooo`3oool0i03oool20000
00030820P03oool0oooo0100oooo0`00000=0?ooo`oooooo000=ooooo`T0oooo0P0000000`20P800
oooo0?ooo`3g0?ooo`D0JFUY00<0];Bd0?ooo`3oool0i03oool2000000030820P03oool0oooo0140
oooo0`00000<0?ooo`oooooo000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3g0?ooo`D0JFUY
00<0];Bd0?ooo`3oool0i03oool2000000030820P03oool0oooo0140oooo0`00000<0?ooo`oooooo
000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3g0?ooo`D0JFUY00<0];Bd0?ooo`3oool0i03o
ool2000000030820P03oool0oooo0140oooo0`00000<0?ooo`oooooo000=ooooo`80oooo0P20P80<
000000030410@020P800P8200?80oooo1@1YJFT00`2d];@0oooo0?ooo`3T0?ooo`80000000<0P820
0?ooo`3oool04@3oool01010@400000000000030`<0;0?ooo`oooooo000=ooooo`030410@0000000
000001800000l03oool506UYJ@030;Bd]03oool0oooo0>@0oooo0P0000000`20P800oooo0?ooo`0A
0?ooo`040820P000000000000820P0/0oooo3oooool000gooooo00<0P8200000000000004@000000
0`20P800oooo0?ooo`3^0?ooo`D0JFUY00<0];Bd0?ooo`3oool0i03oool2000000030820P03oool0
oooo0140oooo00@0P820000000000000P8202`3oool?ooooo`003Oooool00`20P80000000000000A
000000030820P03oool0oooo0>h0oooo1@1YJFT00`2d];@0oooo0?ooo`3T0?ooo`80000000<0P820
0?ooo`3oool04@3oool01030`<00000000000010@40;0?ooo`oooooo000=ooooo`030?ooo`000000
000001400000l@3oool506UYJ@030;Bd]03oool0oooo0>@0oooo0P0000000`20P800oooo0?ooo`0B
0?ooo`<000002`3oool?ooooo`003Oooool00`3oool000000000000A00000?40oooo1@1YJFT00`2d
];@0oooo0?ooo`3T0?ooo`80000000<0P8200?ooo`3oool04P3oool3000000/0oooo3oooool000go
oooo0P3ooolA00000?80oooo1@1YJFT00`2d];@0oooo0?ooo`3T0?ooo`80000000<0P8200?ooo`3o
ool04P3oool3000000/0oooo3oooool000gooooo0P3ooolA00000?80oooo1@1YJFT00`2d];@0oooo
0?ooo`3T0?ooo`80000000<0P8200?ooo`3oool04P3oool01020P800000000000000000:0?ooo`oo
oooo000=ooooo`80oooo00<0P8200000000000003@0000000`20P800oooo0?ooo`3`0?ooo`D0JFUY
00<0];Bd0?ooo`3oool0i03oool2000000030820P03oool0oooo0180oooo00@0P820000000000000
00002P3oool?ooooo`003Oooool20?ooo`030820P0000000000000d0000000<0P8200?ooo`3oool0
l03oool506UYJ@030;Bd]03oool0oooo0>@0oooo0P0000000`20P800oooo0?ooo`0B0?ooo`040820
P00000000000000000X0oooo3oooool000gooooo0`3oool?00000?<0oooo1@1YJFT00`2d];@0oooo
0?ooo`3T0?ooo`80000000<0P8200?ooo`3oool0803oool?ooooo`003Oooool30?ooo`h00000m03o
ool506UYJ@030;Bd]03oool0oooo0>@0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=
ooooo`@0oooo3@00000A0?ooo`030<30`020P800P82000/0P82000<0`<300?ooo`3oool0dP3oool5
06UYJ@030;Bd]03oool0oooo0>@0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=oooo
o`@0oooo300000000`20P800oooo0?ooo`0?0?ooo`030820P0000000000000/0000000<0P8200?oo
o`3oool0dP3oool506UYJ@030;Bd]03oool0oooo0>@0oooo0P0000000`20P800oooo0?ooo`0P0?oo
o`oooooo000=ooooo`@0oooo00<0P8200000000000002@0000000`30`<00oooo0?ooo`0?0?ooo`03
0<30`0000000000000/0000000<0@4100?ooo`3oool0d@3oool00`2d];@0JFUY06UYJ@0306UYJ@03
0=[JfP3oool0oooo0>@0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooo`@0oooo
00<0`<300000000000002@00000C0?ooo`050820P0000000000000000030`<00g03oool00`2d];@0
JFUY06UYJ@0306UYJNL0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooo`D0oooo
2P00000E0?ooo`040820P0000000000000000=`0oooo00<0];Bd06UYJ@1YJFT00`1YJFWW0?ooo`80
000000<0P8200?ooo`3oool0803oool?ooooo`003Oooool60?ooo`P0000000<0@4100?ooo`3oool0
503oool01@10@4000000000000000000`<300=X0oooo00<0];Bd06UYJ@1YJFT00`1YJFWW0?ooo`80
000000<0P8200?ooo`3oool0803oool?ooooo`003Oooool60?ooo`P0000000<0P8200?ooo`3oool0
5@3oool400000=X0oooo00<0];Bd06UYJ@1YJFT00`1YJFWW0?ooo`80000000<0P8200?ooo`3oool0
803oool?ooooo`003Oooool60?ooo`030820P0000000000000D0000000<0`<300?ooo`3oool05P3o
ool01@10@4000000000000000000`<300=P0oooo00<0Shn?06UYJ@1YJFT00`1YJFWW0?ooo`800000
00<0P8200?ooo`3oool0803oool?ooooo`003Oooool60?ooo`030820P0000000000000D000006P3o
ool400000=P0oooo1@1YJFWX0?ooo`80000000<0P8200?ooo`3oool0803oool?ooooo`003Oooool7
0?ooo`H0000000<0@4100?ooo`3oool06@3oool01010@400000000000010@43G0?ooo`D0JFUYj03o
ool2000000030820P03oool0oooo0200oooo3oooool000gooooo1`3oool00`10@400000000000003
000000030<30`03oool0oooo01X0oooo00D0P82000000000000000000<30`03E0?ooo`D0JFUYj03o
ool2000000030820P03oool0oooo0200oooo3oooool000gooooo1`3oool00`20P800000000000003
000001h0oooo00@0P8200000000000000000e@3oool506UYJNP0oooo0P0000000`20P800oooo0?oo
o`0P0?ooo`oooooo000=ooooo`L0oooo00<0`<300000000000000P0000000`20P800oooo0?ooo`0M
0?ooo`050410@0000000000000000030`<00dP3oool00`2d];@0JFUY06UYJ@0206UYJ@0308n?S`3o
ool0oooo0>H0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooo`P0oooo1000000Q
0?ooo`@00000dP3oool00`2d];@0JFUY06UYJ@0206UYJ@030;Bd]03oool0oooo0>H0oooo0P000000
0`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooo`P0oooo00@0P820000000000000@4108P3oool0
1@10@4000000000000000000`<300=00oooo00<0];Bd06UYJ@1YJFT00P1YJFT00`2d];@0oooo0?oo
o`3V0?ooo`80000000<0P8200?ooo`3oool0803oool?ooooo`003Oooool90?ooo`80000000<0P820
0?ooo`3oool08@3oool400000=00oooo1@1YJFT00`2d];@0oooo0?ooo`3V0?ooo`80000000<0P820
0?ooo`3oool0803oool?ooooo`003Oooool90?ooo`030410@0000000P82001T0oooo00<0P8200000
000000002`0000000`20P800oooo0?ooo`3=0?ooo`D0JFUY00<0f][J0?ooo`3oool0iP3oool20000
00030820P03oool0oooo0200oooo3oooool000gooooo2@3oool00`20P80000000?ooo`0I0?ooo`03
0820P0000000000000/0000000<0P8200?ooo`3oool0c@3oool506UYJNT0oooo0P0000000`20P800
oooo0?ooo`0P0?ooo`oooooo000=ooooo`X0oooo00<000000?ooo`3oool0mP3oool506UYJNT0oooo
0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooool0oooo0`3oool606UYJNT0oooo0P00
00000`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooool0oooo0`3oool506UYJNX0oooo0P000000
0`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooool0oooo0P3oool00`3Jf]X0JFUY06UYJ@0306UY
JNX0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooool0oooo0P3oool00`2d];@0
JFUY06UYJ@0306UYJNX0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooool0oooo
0P3oool00`2d];@0JFUY06UYJ@0206UYJ@030;Bd]03oool0oooo0>P0oooo0P0000000`20P800oooo
0?ooo`0P0?ooo`oooooo000=ooooool0oooo0P3oool506UYJ@030;Bd]03oool0oooo0>P0oooo0P00
00000`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooool0oooo0P3oool506UYJN/0oooo0P000000
0`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooool0oooo0@3oool606UYJN/0oooo0P0000000`20
P800oooo0?ooo`0P0?ooo`oooooo000=ooooool0oooo0@3oool506UYJN`0oooo0P0000000`20P800
oooo0?ooo`0P0?ooo`oooooo000=ooooool0oooo00<0f][J06UYJ@1YJFT00`1YJFW/0?ooo`800000
00<0P8200?ooo`3oool0803oool?ooooo`003Ooooooo0?ooo`030;Bd]01YJFT0JFUY00<0JFUYk03o
ool2000000030820P03oool0oooo0200oooo3oooool000goooooo`3oool00`2?Shl0JFUY06UYJ@02
06UYJ@030;Bd]03oool0oooo0>X0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=oooo
ooh0oooo00<0];Bd06UYJ@1YJFT00`1YJFT00`3Jf]X0oooo0?ooo`3Z0?ooo`80000000<0P8200?oo
o`3oool0803oool?ooooo`003Oooooon0?ooo`H0JFUYk@3oool2000000030820P03oool0oooo0200
oooo3oooool000goooooo@3oool00`3Jf]X0JFUY06UYJ@0306UYJ@0308n?S`3oool0oooo0>/0oooo
0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooood0oooo00<0];Bd06UYJ@1YJFT00`1Y
JFT00`2d];@0oooo0?ooo`3[0?ooo`80000000<0P8200?ooo`3oool0803oool?ooooo`003Oooooom
0?ooo`0308n?S`1YJFT0JFUY00<0JFUY00<0f][J0?ooo`3oool0j`3oool2000000030820P03oool0
oooo0200oooo3oooool000goooooo@3oool606UYJNT0oooo3@00000M0?ooo`oooooo000=oooooo`0
oooo00<0f][J06UYJ@1YJFT00`1YJFT00`2d];@0oooo0?ooo`3S0?ooo`80P820400000000`10@400
P8200<30`00I0?ooo`oooooo000=oooooo`0oooo00<0Shn?06UYJ@1YJFT00`1YJFWV0?oooa@00000
00<0`<300?ooo`3oool05`3oool?ooooo`003Ooooool0?ooo`D0JFUY00<0];Bd0?ooo`3oool0i@3o
oolC000001X0oooo3oooool000gooooon`3oool00`2d];@0JFUY06UYJ@0306UYJ@030=[JfP3oool0
oooo0>D0oooo4P0000000`20P800oooo0?ooo`0H0?ooo`oooooo000=oooooo/0oooo1P1YJFWX0?oo
o`030820P0000000000000l000006`3oool?ooooo`003Ooooooj0?ooo`030=[JfP1YJFT0JFUY00<0
JFUY00<0];Bd0?ooo`3oool0iP3oool00`30`<0000000000000>000000030410@03oool0oooo01T0
oooo3oooool000gooooonP3oool00`2d];@0JFUY06UYJ@0306UYJNX0oooo400000000`20P800oooo
0?ooo`0I0?ooo`oooooo000=ooooooX0oooo1@1YJFT00`2?Shl0oooo0?ooo`3X0?ooo`030820P000
0000000000d0000000<0`<300?ooo`3oool06@3oool?ooooo`003Ooooooi0?ooo`H0JFUY00<0f][J
0?ooo`3oool0j03oool00`30`<0000000000000=000001`0oooo3oooool000gooooon@3oool606UY
JN`0oooo3P0000000`20P800oooo0?ooo`0J0?ooo`oooooo000=ooooooP0oooo00<0];Bd06UYJ@1Y
JFT00`1YJFW]0?ooo`h0000000<0P8200?ooo`3oool06P3oool?ooooo`003Ooooooh0?ooo`D0JFUY
00<0];Bd0?ooo`3oool0k03oool=000001d0oooo3oooool000gooooom`3oool00`2d];@0JFUY06UY
J@0306UYJ@030=[JfP3oool0oooo0>`0oooo3@00000M0?ooo`oooooo000=ooooooL0oooo1P1YJFW_
0?ooo``000007P3oool?ooooo`003Oooooof0?ooo`030;Bd]01YJFT0JFUY00<0JFUY00<0];Bd0?oo
o`3oool0k@3oool00`20P800000000000009000001h0oooo3oooool000gooooomP3oool606UYJO40
oooo2P0000000`20P800oooo0?ooo`0L0?ooo`oooooo000=ooooooD0oooo00<0];Bd06UYJ@1YJFT0
101YJFWa0?ooo`X0000000<0P8200?ooo`3oool0703oool?ooooo`003Ooooooe0?ooo`0308n?S`1Y
JFT0JFUY00<0JFUYl`3oool9000001l0oooo3oooool000gooooom@3oool506UYJ@030;Bd]03oool0
oooo0?40oooo2000000P0?ooo`oooooo000=oooooo@0oooo1P1YJFT00`3Jf]X0oooo0?ooo`3a0?oo
o`030820P0000000000000D00000803oool?ooooo`003Ooooooc0?ooo`030;Bd]01YJFT0JFUY00@0
JFUYm@3oool6000000030820P03oool0oooo01h0oooo3oooool000goooool`3oool606UYJOH0oooo
00<0P8200000000000000`0000000`20P800oooo0?ooo`0N0?ooo`oooooo000=oooooo80oooo1P1Y
JFT00`2d];@0oooo0?ooo`3e0?ooo`D000008@3oool?ooooo`003Ooooooa0?ooo`030=[JfP1YJFT0
JFUY00@0JFUY00<0f][J0?ooo`3oool0m@3oool00`10@40000000000000200000240oooo3oooool0
00goooool@3oool00`2?Shl0JFUY06UYJ@0306UYJ@030;Bd]03oool0oooo0?H0oooo00@0P8200000
0000000000008P3oool?ooooo`003Ooooooa0?ooo`H0JFUYn@3oool01020P800000000000000000R
0?ooo`oooooo000=oooooo00oooo00<0];Bd06UYJ@1YJFT00`1YJFT00`2d];@0oooo0?ooo`3h0?oo
o`80000000<0P8200?ooo`3oool0803oool?ooooo`003Oooooo_0?ooo`030;Bd]01YJFT0JFUY00@0
JFUYn`3oool00`20P80000000820P00R0?ooo`oooooo000=ooooonl0oooo1P1YJFWl0?ooo`030<30
`0000000oooo0280oooo3oooool000goooookP3oool00`2d];@0JFUY06UYJ@0306UYJOh0oooo00<0
00000?ooo`3oool08@3oool?ooooo`003Oooooo]0?ooo`030;Bd]01YJFT0JFUY00<0JFUY00<0];Bd
0?ooo`3oool0o`3ooolQ0?ooo`oooooo000=ooooon`0oooo00<0f][J06UYJ@1YJFT00`1YJFT00`2d
];@0oooo0?ooo`3o0?ooob80oooo3oooool000goooook03oool606UYJOl0oooo9@3oool?ooooo`00
3Oooooo[0?ooo`030;Bd]01YJFT0JFUY00<0JFUY00<0f][J0?ooo`3oool0o`3ooolS0?ooo`oooooo
000=ooooonX0oooo00<0];Bd06UYJ@1YJFT0101YJFWo0?ooobH0oooo3oooool000goooooC`3ooonM
0820P0@0=CDeo`20P80B0820P1D0oooo3oooool000goooooC`3ooooo00000;<000005@3oool?oooo
o`003Ooooom?0?ooool00000/`00000E0?ooo`oooooo000=oooooe40oooo0P0000000`30`<00oooo
0?ooo`0N0?ooo`050<30`0000000000000000010@4008@3oool01@20P8000000000000000000`<30
0240oooo00@0@410000000000000@4108@3oool01010@400000000000010@40Q0?ooo`050<30`000
0000000000000020P8008@3oool01@10@4000000000000000000`<300200oooo00D0`<3000000000
000000000410@00Q0?ooo`050820P0000000000000000030`<008@3oool01010@400000000000010
@40Q0?ooo`050<30`0000000000000000020P8008@3oool01@10@4000000000000000000`<3002D0
oooo3oooool000goooooD@3oool300000280oooo1000000Q0?ooo`040820P0000000000000000280
oooo1000000Q0?ooo`@000008@3oool01@20P8000000000000000000P8200240oooo1000000R0?oo
o`<0000000<0P8200?ooo`3oool07`3oool01020P800000000000000000R0?ooo`@000008@3oool0
1@20P8000000000000000000P8200240oooo1000000U0?ooo`oooooo000=oooooe40oooo00D0@410
00000000000000000<30`00P0?ooo`050<30`0000000000000000010@4008@3oool01@20P8000000
000000000000`<300240oooo00@0@410000000000000@410803oool01@30`<000000000000000000
@4100240oooo00D0P82000000000000000000820P00Q0?ooo`050410@0000000000000000030`<00
803oool01@30`<000000000000000000P8200240oooo00D0P82000000000000000000<30`00P0?oo
o`050<30`0000000000000000010@4008@3oool01@20P8000000000000000000P8200240oooo00@0
@410000000000000@410903oool?ooooo`003OoooomB0?ooo`@000008P3oool3000000030820P03o
ool0oooo01l0oooo00@0P82000000000000000008P3oool400000240oooo1000000Q0?ooo`050820
P0000000000000000020P8008@3oool400000280oooo0`0000000`20P800oooo0?ooo`0O0?ooo`04
0820P0000000000000000280oooo1000000Q0?ooo`050820P0000000000000000020P8008@3oool4
000002<0oooo3oooool000goooooD`3oool01010@400000000000010@40Q0?ooo`050<30`0000000
000000000020P8008@3oool01@10@4000000000000000000`<300200oooo00D0`<30000000000000
00000410@00P0?ooo`050<30`0000000000000000010@4008@3oool01@20P8000000000000000000
`<300240oooo00@0@410000000000000@4108@3oool01@30`<000000000000000000P8200240oooo
00D0@41000000000000000000<30`00P0?ooo`050<30`0000000000000000010@4008@3oool01@20
P8000000000000000000`<300240oooo00@0@410000000000000@4108P3oool?ooooo`003OoooomD
0?ooo`@000008P3oool3000000030820P03oool0oooo01l0oooo1000000R0?ooo`@000008@3oool4
00000240oooo00@0P82000000000000000008P3oool400000240oooo00D0P8200000000000000000
0820P00Q0?ooo`@000008P3oool3000000030820P03oool0oooo01l0oooo00@0P820000000000000
00008P3oool400000240oooo3oooool000goooooE@3oool01010@400000000000010@40Q0?ooo`05
0<30`0000000000000000020P8008@3oool01@10@4000000000000000000`<300200oooo00D0`<30
00000000000000000410@00P0?ooo`050<30`0000000000000000010@4008@3oool01@20P8000000
000000000000`<300240oooo00@0@410000000000000@4108@3oool01@20P8000000000000000000
P8200240oooo00D0@41000000000000000000<30`00P0?ooo`050<30`0000000000000000020P800
8@3oool01@20P8000000000000000000`<300200oooo00D0`<3000000000000000000410@00P0?oo
o`oooooo000=oooooeH0oooo00D0@41000000000000000000<30`00P0?ooo`050<30`00000000000
00000010@4008@3oool01@20P8000000000000000000`<300240oooo00@0@410000000000000@410
8@3oool01010@400000000000010@40Q0?ooo`050<30`0000000000000000020P8008@3oool01@10
@4000000000000000000`<300200oooo00D0`<3000000000000000000410@00Q0?ooo`050820P000
0000000000000030`<008@3oool01010@400000000000010@40Q0?ooo`050<30`000000000000000
0020P8008@3oool01@10@4000000000000000000`<3001h0oooo3oooool000goooooE`3oool40000
0280oooo1000000Q0?ooo`040820P0000000000000000280oooo1000000Q0?ooo`@000008@3oool0
1@20P8000000000000000000P8200240oooo1000000R0?ooo`<0000000<0P8200?ooo`3oool07`3o
ool01020P800000000000000000R0?ooo`@000008@3oool01@20P8000000000000000000P8200240
oooo1000000N0?ooo`oooooo000=oooooeP0oooo00D0@41000000000000000000<30`00P0?ooo`05
0<30`0000000000000000010@4008@3oool01@20P8000000000000000000`<300240oooo00@0@410
000000000000@4108@3oool01010@400000000000010@40Q0?ooo`050820P0000000000000000020
P8008@3oool01@10@4000000000000000000`<300200oooo00D0`<3000000000000000000820P00Q
0?ooo`050820P0000000000000000030`<00803oool01@30`<000000000000000000@4100240oooo
00D0P82000000000000000000820P00Q0?ooo`050410@0000000000000000030`<00703oool?oooo
o`003OoooomI0?ooo`@000008P3oool3000000030820P03oool0oooo01l0oooo00@0P82000000000
000000008P3oool400000240oooo1000000Q0?ooo`050820P0000000000000000020P8008@3oool4
00000280oooo0`0000000`20P800oooo0?ooo`0O0?ooo`040820P0000000000000000280oooo1000
000Q0?ooo`050820P0000000000000000020P8008@3oool4000001`0oooo3oooool000goooooFP3o
ool01010@400000000000010@40Q0?ooo`050<30`0000000000000000020P8008@3oool01@10@400
0000000000000000`<300200oooo00D0`<3000000000000000000410@00P0?ooo`050<30`0000000
000000000010@4008@3oool01@20P8000000000000000000`<300240oooo00@0@410000000000000
@4108@3oool01@30`<000000000000000000P8200240oooo00D0@41000000000000000000<30`00P
0?ooo`050<30`0000000000000000010@4008@3oool01@20P8000000000000000000`<300240oooo
00@0@410000000000000@4106`3oool?ooooo`003OoooomK0?ooo`@000008P3oool3000000030820
P03oool0oooo01l0oooo1000000R0?ooo`@000008@3oool400000240oooo00@0P820000000000000
00008P3oool400000240oooo00D0P82000000000000000000820P00Q0?ooo`@000008P3oool30000
00030820P03oool0oooo01l0oooo00@0P82000000000000000008P3oool4000001X0oooo3oooool0
00goooooG03oool01010@400000000000010@40Q0?ooo`050<30`0000000000000000020P8008@3o
ool01@10@4000000000000000000`<300200oooo00D0`<3000000000000000000410@00P0?ooo`05
0<30`0000000000000000010@4008@3oool01@20P8000000000000000000`<300240oooo00@0@410
000000000000@4108@3oool01@20P8000000000000000000P8200240oooo00D0@410000000000000
00000<30`00P0?ooo`050<30`0000000000000000020P8008@3oool01@20P8000000000000000000
`<300240oooo00@0@410000000000000@4106@3oool?ooooo`003OoooomM0?ooo`050410@0000000
000000000030`<00803oool01@30`<000000000000000000@4100240oooo00D0P820000000000000
00000820P00Q0?ooo`040410@000000000000410@240oooo00@0@410000000000000@4108@3oool0
1@30`<000000000000000000P8200240oooo00D0@41000000000000000000<30`00P0?ooo`050<30
`0000000000000000010@4008@3oool01@20P8000000000000000000`<300240oooo00@0@4100000
00000000@4108@3oool01@30`<000000000000000000P8200240oooo00D0@4100000000000000000
0<30`00G0?ooo`oooooo000=oooooeh0oooo1000000R0?ooo`@000008@3oool01@20P80000000000
00000000P8200240oooo1000000Q0?ooo`@000008@3oool01@20P8000000000000000000P8200240
oooo1000000R0?ooo`<0000000<0P8200?ooo`3oool07`3oool01020P800000000000000000R0?oo
o`@000008@3oool01@20P8000000000000000000P8200240oooo1000000G0?ooo`oooooo000=oooo
oel0oooo00D0@41000000000000000000<30`00P0?ooo`050<30`0000000000000000010@4008@3o
ool01@20P8000000000000000000`<300240oooo00@0@410000000000000@4108@3oool01010@400
000000000010@40Q0?ooo`050820P0000000000000000020P8008@3oool01@10@400000000000000
0000`<300200oooo00D0`<3000000000000000000820P00Q0?ooo`050820P0000000000000000030
`<00803oool01@30`<000000000000000000@4100240oooo00D0P82000000000000000000820P00Q
0?ooo`050410@0000000000000000030`<005@3oool?ooooo`003OoooomP0?ooo`@000008P3oool3
000000030820P03oool0oooo01l0oooo00@0P82000000000000000008P3oool400000240oooo1000
000Q0?ooo`050820P0000000000000000020P8008@3oool400000280oooo0`0000000`20P800oooo
0?ooo`0O0?ooo`040820P0000000000000000280oooo1000000Q0?ooo`050820P000000000000000
0020P8008@3oool4000001D0oooo3oooool000goooooH@3oool01@10@4000000000000000000`<30
0200oooo00D0`<3000000000000000000820P00Q0?ooo`050820P0000000000000000030`<00803o
ool01@30`<000000000000000000@4100200oooo00D0`<3000000000000000000410@00Q0?ooo`05
0820P0000000000000000030`<008@3oool01010@400000000000010@40Q0?ooo`050<30`0000000
000000000020P8008@3oool01@10@4000000000000000000`<300200oooo00D0`<30000000000000
00000410@00Q0?ooo`050820P0000000000000000030`<008@3oool00`10@40000000000000E0?oo
o`oooooo000=ooooof80oooo1000000R0?ooo`<0000000<0P8200?ooo`3oool07`3oool01020P800
000000000000000R0?ooo`@000008@3oool400000240oooo00@0P82000000000000000008P3oool4
00000240oooo00D0P82000000000000000000820P00Q0?ooo`@000008P3oool400000240oooo00@0
P82000000000000000008P3oool2000001D0oooo3oooool000goooooH`3oool01010@40000000000
0010@40Q0?ooo`050<30`0000000000000000020P8008@3oool01@10@4000000000000000000`<30
0200oooo00D0`<3000000000000000000410@00P0?ooo`050<30`0000000000000000010@4008@3o
ool01@20P8000000000000000000`<300240oooo00@0@410000000000000@4108@3oool01@20P800
0000000000000000P8200240oooo00D0@41000000000000000000<30`00P0?ooo`050<30`0000000
000000000010@4008@3oool01@20P8000000000000000000`<300240oooo00<0@4100?ooo`3oool0
4`3oool?ooooo`003OoooomT0?ooo`050820P0000000000000000030`<00803oool01@30`<000000
000000000000@4100240oooo00D0P82000000000000000000820P00Q0?ooo`040410@00000000000
0410@240oooo00@0@410000000000000@4108@3oool01@30`<000000000000000000P8200240oooo
00D0@41000000000000000000<30`00P0?ooo`050<30`0000000000000000010@4008@3oool01@20
P8000000000000000000`<300240oooo00@0@410000000000000@4108@3oool01@30`<0000000000
00000000P82003H0oooo3oooool000goooooI@3oool01020P800000000000000000R0?ooo`@00000
8@3oool01@20P8000000000000000000P8200240oooo1000000Q0?ooo`@000008@3oool01@20P800
0000000000000000P8200240oooo1000000R0?ooo`@000008@3oool01020P800000000000000000R
0?ooo`@000008@3oool01@20P8000000000000000000P82003D0oooo3oooool000goooooIP3oool0
1@10@4000000000000000000`<300200oooo00D0`<3000000000000000000410@00Q0?ooo`050820
P0000000000000000030`<008@3oool01010@400000000000010@40Q0?ooo`040410@00000000000
0410@240oooo00D0P82000000000000000000820P00Q0?ooo`050410@0000000000000000030`<00
803oool01@30`<000000000000000000@4100240oooo00D0P82000000000000000000<30`00Q0?oo
o`040410@000000000000410@240oooo00D0P82000000000000000000820P00d0?ooo`oooooo000=
ooooofL0oooo1000000R0?ooo`<0000000<0P8200?ooo`3oool07`3oool01020P800000000000000
000R0?ooo`@000008@3oool400000240oooo00D0P82000000000000000000820P00Q0?ooo`@00000
8P3oool3000000030820P03oool0oooo01l0oooo00@0P82000000000000000008P3oool400000240
oooo00D0P82000000000000000000820P00c0?ooo`oooooo000=ooooofP0oooo00D0@41000000000
000000000<30`00P0?ooo`050<30`0000000000000000020P8008@3oool01@20P800000000000000
0000`<300200oooo00D0`<3000000000000000000410@00P0?ooo`050<30`0000000000000000010
@4008@3oool01@20P8000000000000000000`<300240oooo00@0@410000000000000@4108@3oool0
1@30`<000000000000000000P8200240oooo00D0@41000000000000000000<30`00P0?ooo`050<30
`0000000000000000010@4008@3oool01@20P8000000000000000000`<300380oooo3oooool000go
ooooJ@3oool400000280oooo0`0000000`20P800oooo0?ooo`0O0?ooo`040820P000000000000000
0280oooo1000000Q0?ooo`@000008@3oool01020P800000000000000000R0?ooo`@000008P3oool3
000000030820P03oool0oooo01l0oooo1000000R0?ooo`@000008@3oool01020P800000000000000
000b0?ooo`oooooo000=ooooofX0oooo00@0@410000000000000@4108@3oool01@30`<0000000000
00000000P8200240oooo00D0@41000000000000000000<30`00P0?ooo`050<30`000000000000000
0010@400803oool01@30`<000000000000000000@4100240oooo00D0P82000000000000000000<30
`00Q0?ooo`040410@000000000000410@240oooo00D0`<3000000000000000000820P00Q0?ooo`05
0410@0000000000000000030`<00803oool01@30`<000000000000000000@4100240oooo00D0P820
00000000000000000<30`00`0?ooo`oooooo000=ooooof/0oooo00D0P82000000000000000000<30
`00P0?ooo`050<30`0000000000000000010@4008@3oool01@20P8000000000000000000P8200240
oooo00@0@410000000000000@4108@3oool01010@400000000000010@40Q0?ooo`050<30`0000000
000000000020P8008@3oool01@10@4000000000000000000`<300200oooo00D0`<30000000000000
00000410@00Q0?ooo`050820P0000000000000000030`<008@3oool01010@400000000000010@40Q
0?ooo`050<30`0000000000000000020P800;`3oool?ooooo`003Ooooom/0?ooo`040820P0000000
000000000280oooo1000000Q0?ooo`050820P0000000000000000020P8008@3oool400000240oooo
1000000Q0?ooo`050820P0000000000000000020P8008@3oool400000280oooo1000000Q0?ooo`04
0820P0000000000000000280oooo1000000Q0?ooo`050820P0000000000000000020P800;P3oool?
ooooo`003Ooooom]0?ooo`050410@0000000000000000030`<00803oool01@30`<00000000000000
0000@4100240oooo00D0P82000000000000000000<30`00Q0?ooo`040410@000000000000410@240
oooo00@0@410000000000000@4108@3oool01@20P8000000000000000000P8200240oooo00D0@410
00000000000000000<30`00P0?ooo`050<30`0000000000000000010@4008@3oool01@20P8000000
000000000000`<300240oooo00@0@410000000000000@4108@3oool01@20P8000000000000000000
P82002d0oooo3oooool000goooooKP3oool400000280oooo0`0000000`20P800oooo0?ooo`0O0?oo
o`040820P0000000000000000280oooo1000000Q0?ooo`@000008@3oool01@20P800000000000000
0000P8200240oooo1000000R0?ooo`<0000000<0P8200?ooo`3oool07`3oool01020P80000000000
0000000R0?ooo`@000008@3oool01@20P8000000000000000000P82002`0oooo3oooool000gooooo
K`3oool01@10@4000000000000000000`<300200oooo00D0`<3000000000000000000820P00Q0?oo
o`050820P0000000000000000030`<00803oool01@30`<000000000000000000@4100200oooo00D0
`<3000000000000000000410@00Q0?ooo`050820P0000000000000000020P8008@3oool01010@400
000000000010@40Q0?ooo`050<30`0000000000000000020P8008@3oool01@10@400000000000000
0000`<300200oooo00D0`<3000000000000000000410@00Q0?ooo`050820P0000000000000000030
`<00:`3oool?ooooo`003Ooooom`0?ooo`@000008P3oool3000000030820P03oool0oooo01l0oooo
00@0P82000000000000000008P3oool400000240oooo1000000Q0?ooo`050820P000000000000000
0020P8008@3oool400000280oooo0`0000000`20P800oooo0?ooo`0O0?ooo`@000008P3oool40000
0240oooo00@0P8200000000000000000:`3oool?ooooo`003Oooooma0?ooo`040410@00000000000
0410@240oooo00D0`<3000000000000000000820P00Q0?ooo`050410@0000000000000000030`<00
803oool01@30`<000000000000000000@4100200oooo00D0`<3000000000000000000410@00Q0?oo
o`050820P0000000000000000030`<008@3oool01010@400000000000010@40Q0?ooo`050<30`000
0000000000000020P8008@3oool01@10@4000000000000000000`<300200oooo00D0`<3000000000
000000000410@00Q0?ooo`050820P0000000000000000030`<00:@3oool?ooooo`003Ooooomb0?oo
o`050820P0000000000000000030`<00803oool01@30`<000000000000000000@4100240oooo00D0
P82000000000000000000820P00Q0?ooo`040410@000000000000410@240oooo00@0@41000000000
0000@4108@3oool01@30`<000000000000000000P8200240oooo00D0@41000000000000000000<30
`00P0?ooo`050<30`0000000000000000010@4008@3oool01@20P8000000000000000000`<300240
oooo00@0@410000000000000@4108@3oool01@30`<000000000000000000P82002P0oooo3oooool0
00goooooD@3oool00`20P800oooo0?ooo`0O0?ooo`040820P0000000000000000280oooo1000000Q
0?ooo`050820P0000000000000000020P8008@3oool400000240oooo1000000R0?ooo`<0000000<0
P8200?ooo`3oool07`3oool400000280oooo1000000Q0?ooo`040820P0000000000000000280oooo
1000000Q0?ooo`050820P0000000000000000020P8009`3oool?ooooo`003OoooomA0?ooo`030000
0020P800oooo0200oooo00D0@41000000000000000000<30`00P0?ooo`050<30`000000000000000
0010@4008@3oool01@20P8000000000000000000`<300240oooo00@0@410000000000000@4108@3o
ool01010@400000000000010@40Q0?ooo`050<30`0000000000000000020P8008@3oool01@10@400
0000000000000000`<300200oooo00D0`<3000000000000000000410@00Q0?ooo`050820P0000000
000000000030`<008@3oool01010@400000000000010@40Q0?ooo`050820P0000000000000000020
P8009P3oool?ooooo`003OoooomA0?ooo`80000000<0P8200?ooo`3oool07`3oool400000280oooo
0`0000000`20P800oooo0?ooo`0O0?ooo`040820P0000000000000000280oooo1000000Q0?ooo`@0
00008@3oool01@20P8000000000000000000P8200240oooo1000000R0?ooo`<0000000<0P8200?oo
o`3oool07`3oool01020P800000000000000000R0?ooo`@000008@3oool01@20P800000000000000
0000P82002D0oooo3oooool000goooooD@3oool3000000030820P03oool0oooo01l0oooo00D0@410
00000000000000000<30`00P0?ooo`050<30`0000000000000000020P8008@3oool01@20P8000000
000000000000`<300200oooo00D0`<3000000000000000000410@00P0?ooo`050<30`00000000000
00000010@4008@3oool01@20P8000000000000000000P8200240oooo00@0@410000000000000@410
8@3oool01@30`<000000000000000000P8200240oooo00D0@41000000000000000000<30`00P0?oo
o`050<30`0000000000000000010@4008@3oool01@20P8000000000000000000`<3002@0oooo3ooo
ool000goooooD@3oool01@20P8000000000000000000P8200240oooo1000000R0?ooo`<0000000<0
P8200?ooo`3oool07`3oool01020P800000000000000000R0?ooo`@000008@3oool400000240oooo
00D0P82000000000000000000820P00Q0?ooo`@000008P3oool3000000030820P03oool0oooo01l0
oooo1000000R0?ooo`@000008@3oool01020P800000000000000000T0?ooo`oooooo000=oooooe80
oooo00D0P82000000000000000000<30`00Q0?ooo`040410@000000000000410@240oooo00D0`<30
00000000000000000820P00Q0?ooo`050410@0000000000000000030`<00803oool01@30`<000000
000000000000@4100200oooo00D0`<3000000000000000000410@00Q0?ooo`050820P00000000000
00000030`<008@3oool01010@400000000000010@40Q0?ooo`050<30`0000000000000000020P800
8@3oool01@10@4000000000000000000`<300200oooo00D0`<3000000000000000000410@00Q0?oo
o`050820P0000000000000000030`<008P3oool?ooooo`003OoooomC0?ooo`050<30`00000000000
00000020P8008@3oool01@20P8000000000000000000`<300200oooo00D0`<300000000000000000
0410@00Q0?ooo`050820P0000000000000000020P8008@3oool01@10@4000000000000000000`<30
0200oooo00@0@410000000000000@4108@3oool01@30`<000000000000000000P8200240oooo00D0
@41000000000000000000<30`00P0?ooo`050<30`0000000000000000010@4008@3oool01@20P800
0000000000000000`<300240oooo00@0@410000000000000@4108@3oool01@30`<00000000000000
0000P8200240oooo3oooool000goooooE@3oool3000000030820P03oool0oooo01l0oooo00@0P820
00000000000000008P3oool400000240oooo00D0P82000000000000000000820P00Q0?ooo`@00000
8@3oool400000280oooo0`0000000`20P800oooo0?ooo`0O0?ooo`@000008P3oool400000240oooo
00@0P82000000000000000008P3oool400000240oooo00D0P82000000000000000000820P00P0?oo
o`oooooo000=oooooeD0oooo00D0`<3000000000000000000820P00Q0?ooo`050410@00000000000
00000030`<00803oool01@30`<000000000000000000@4100240oooo00D0P8200000000000000000
0<30`00Q0?ooo`040410@000000000000410@240oooo00@0@410000000000000@4108@3oool01@30
`<000000000000000000P8200240oooo00D0@41000000000000000000<30`00P0?ooo`050<30`000
0000000000000010@4008@3oool01@20P8000000000000000000`<300240oooo00@0@41000000000
0000@4108@3oool01@20P8000000000000000000P82001l0oooo3oooool000goooooEP3oool01@20
P8000000000000000000P8200240oooo1000000R0?ooo`<0000000<0P8200?ooo`3oool07`3oool0
1020P800000000000000000R0?ooo`@000008@3oool400000240oooo00D0P8200000000000000000
0820P00Q0?ooo`@000008P3oool3000000030820P03oool0oooo01l0oooo00@0P820000000000000
00008P3oool400000240oooo00D0P82000000000000000000820P00N0?ooo`oooooo000=oooooeL0
oooo00D0P82000000000000000000820P00Q0?ooo`050410@0000000000000000030`<00803oool0
1@30`<000000000000000000P8200240oooo00D0P82000000000000000000<30`00Q0?ooo`040410
@000000000000410@200oooo00D0`<3000000000000000000410@00Q0?ooo`050820P00000000000
00000020P8008@3oool01010@400000000000010@40Q0?ooo`050<30`0000000000000000020P800
8@3oool01@10@4000000000000000000`<300200oooo00D0`<3000000000000000000410@00Q0?oo
o`050820P0000000000000000020P8007@3oool?ooooo`003OoooomH0?ooo`050820P00000000000
00000020P8008@3oool400000280oooo0`0000000`20P800oooo0?ooo`0O0?ooo`040820P0000000
000000000280oooo1000000Q0?ooo`@000008@3oool01@20P8000000000000000000P8200240oooo
1000000R0?ooo`<0000000<0P8200?ooo`3oool07`3oool400000280oooo1000000Q0?ooo`050820
P0000000000000000020P800703oool?ooooo`003OoooomI0?ooo`050820P0000000000000000030
`<008@3oool01010@400000000000010@40Q0?ooo`050<30`0000000000000000020P8008@3oool0
1@10@4000000000000000000`<300200oooo00D0`<3000000000000000000410@00P0?ooo`050<30
`0000000000000000010@4008@3oool01@20P8000000000000000000`<300240oooo00@0@4100000
00000000@4108@3oool01@30`<000000000000000000P8200240oooo00D0@4100000000000000000
0<30`00P0?ooo`050<30`0000000000000000010@4008@3oool01@20P8000000000000000000`<30
01/0oooo3oooool000goooooFP3oool01020P800000000000000000R0?ooo`@000008@3oool01@20
P8000000000000000000P8200240oooo1000000R0?ooo`@000008@3oool3000000030820P03oool0
oooo01l0oooo00@0P82000000000000000008P3oool400000240oooo00D0P8200000000000000000
0820P00Q0?ooo`@000008P3oool3000000030820P03oool0oooo01l0oooo00@0P820000000000000
00006`3oool?ooooo`003OoooomK0?ooo`050820P0000000000000000030`<008@3oool01010@400
000000000010@40Q0?ooo`050820P0000000000000000020P8008@3oool01@10@400000000000000
0000`<300200oooo00D0`<3000000000000000000410@00P0?ooo`050<30`0000000000000000020
P8008@3oool01@20P8000000000000000000`<300200oooo00D0`<3000000000000000000410@00Q
0?ooo`050820P0000000000000000020P8008@3oool01010@400000000000010@40Q0?ooo`050<30
`0000000000000000020P8008@3oool01@20P8000000000000000000`<3001T0oooo3oooool000go
ooooG03oool01@30`<000000000000000000P8200240oooo00D0@41000000000000000000<30`00P
0?ooo`050<30`0000000000000000010@4008@3oool01@20P8000000000000000000`<300240oooo
00@0@410000000000000@4108@3oool01010@400000000000010@40Q0?ooo`050<30`00000000000
00000020P8008@3oool01@10@4000000000000000000`<300200oooo00D0`<300000000000000000
0410@00Q0?ooo`050820P0000000000000000030`<008@3oool01010@400000000000010@40Q0?oo
o`050<30`0000000000000000020P800603oool?ooooo`003OoooomM0?ooo`050820P00000000000
00000020P8008@3oool400000280oooo1000000Q0?ooo`040820P0000000000000000280oooo1000
000Q0?ooo`@000008@3oool01@20P8000000000000000000P8200240oooo1000000R0?ooo`<00000
00<0P8200?ooo`3oool07`3oool01020P800000000000000000R0?ooo`@000008@3oool01@20P800
0000000000000000P82001L0oooo3oooool000goooooGP3oool01@20P8000000000000000000P820
0240oooo00D0@41000000000000000000<30`00P0?ooo`050<30`0000000000000000010@4008@3o
ool01@20P8000000000000000000`<300240oooo00@0@410000000000000@4108@3oool01020P800
000000000010@40Q0?ooo`050820P0000000000000000020P8008@3oool01010@400000000000010
@40Q0?ooo`050<30`0000000000000000020P8008@3oool01@10@4000000000000000000`<300200
oooo00D0`<3000000000000000000410@00Q0?ooo`050820P0000000000000000020P8005P3oool?
ooooo`003OoooomO0?ooo`050820P0000000000000000020P8008@3oool400000280oooo0`000000
0`20P800oooo0?ooo`0O0?ooo`040820P0000000000000000280oooo1000000Q0?ooo`040820P000
0000000000000240oooo00D0P82000000000000000000820P00Q0?ooo`@000008P3oool300000003
0820P03oool0oooo01l0oooo1000000R0?ooo`@000008@3oool01@20P8000000000000000000P820
01D0oooo3oooool000goooooH03oool01@20P8000000000000000000P8200240oooo00@0@4100000
00000000@4108@3oool01@30`<000000000000000000P8200240oooo00D0@4100000000000000000
0<30`00P0?ooo`050<30`0000000000000000010@4008@3oool01020P800000000000010@40Q0?oo
o`050820P0000000000000000030`<008@3oool01010@400000000000010@40Q0?ooo`050<30`000
0000000000000020P8008@3oool01@10@4000000000000000000`<300200oooo00D0`<3000000000
000000000410@00Q0?ooo`040820P00000000000000001D0oooo3oooool000goooooH@3oool01@20
P8000000000000000000P8200240oooo1000000R0?ooo`<0000000<0P8200?ooo`3oool07`3oool4
00000280oooo1000000Q0?ooo`040820P000000000000820P240oooo00@0P8200000000000000000
8P3oool400000240oooo00D0P82000000000000000000820P00Q0?ooo`@000008P3oool300000003
0820P03oool0oooo01l0oooo00<0P8200000000000005@3oool?ooooo`003OoooomR0?ooo`050820
P0000000000000000030`<008@3oool01010@400000000000010@40Q0?ooo`050<30`00000000000
00000020P8008@3oool01@10@4000000000000000000`<300200oooo00D0`<300000000000000000
0410@00Q0?ooo`040820P000000000000820P240oooo00D0P82000000000000000000<30`00P0?oo
o`050<30`0000000000000000010@4008@3oool01@20P8000000000000000000P8200240oooo00D0
@41000000000000000000<30`00P0?ooo`050<30`0000000000000000020P8008@3oool00`20P800
00000?ooo`0D0?ooo`oooooo000=ooooof<0oooo00D0`<3000000000000000000820P00Q0?ooo`05
0410@0000000000000000030`<00803oool01@30`<000000000000000000@4100240oooo00D0P820
00000000000000000<30`00Q0?ooo`040410@000000000000410@240oooo00@0`<30000000000000
@4108@3oool01@30`<000000000000000000P8200240oooo00D0@41000000000000000000<30`00P
0?ooo`050<30`0000000000000000010@4008@3oool01@20P8000000000000000000`<300240oooo
00@0@410000000000000@4108@3oool00`30`<00oooo0?ooo`0C0?ooo`oooooo000=ooooofD0oooo
0`0000000`20P800oooo0?ooo`0O0?ooo`@000008P3oool400000240oooo00@0P820000000000000
00008P3oool400000240oooo00@0P82000000000000000008@3oool01@20P8000000000000000000
P8200240oooo1000000R0?ooo`<0000000<0P8200?ooo`3oool07`3oool01020P800000000000000
000R0?ooo`@00000=P3oool?ooooo`003OoooomU0?ooo`050<30`0000000000000000020P8008@3o
ool01@10@4000000000000000000`<300200oooo00D0`<3000000000000000000410@00Q0?ooo`05
0820P0000000000000000030`<008@3oool01010@400000000000010@40Q0?ooo`040820P0000000
00000410@240oooo00D0P82000000000000000000820P00Q0?ooo`050410@0000000000000000030
`<00803oool01@30`<000000000000000000P8200240oooo00D0P82000000000000000000<30`00P
0?ooo`050<30`0000000000000000010@400=@3oool?ooooo`003OoooomV0?ooo`050820P0000000
000000000020P8008@3oool400000280oooo0`0000000`20P800oooo0?ooo`0O0?ooo`040820P000
0000000000000280oooo1000000Q0?ooo`040820P0000000000000000240oooo00D0P82000000000
000000000820P00Q0?ooo`@000008P3oool3000000030820P03oool0oooo01l0oooo00@0P8200000
0000000000008P3oool4000003@0oooo3oooool000goooooI`3oool01@20P8000000000000000000
P8200240oooo00@0@410000000000000@4108@3oool01@30`<000000000000000000P8200240oooo
00D0@41000000000000000000<30`00P0?ooo`050<30`0000000000000000010@4008@3oool01020
P800000000000010@40Q0?ooo`050820P0000000000000000030`<008@3oool01010@40000000000
0010@40Q0?ooo`050<30`0000000000000000020P8008@3oool01@10@4000000000000000000`<30
0200oooo00D0`<3000000000000000000410@00c0?ooo`oooooo000=ooooofP0oooo00D0P8200000
0000000000000820P00Q0?ooo`@000008P3oool3000000030820P03oool0oooo01l0oooo1000000R
0?ooo`@000008@3oool01020P800000000000020P80Q0?ooo`040820P0000000000000000280oooo
1000000Q0?ooo`050820P0000000000000000020P8008@3oool400000280oooo0`0000000`20P800
oooo0?ooo`0`0?ooo`oooooo000=ooooofT0oooo00D0P82000000000000000000<30`00Q0?ooo`04
0410@000000000000410@240oooo00D0`<3000000000000000000820P00Q0?ooo`050410@0000000
000000000030`<00803oool01@30`<000000000000000000@4100240oooo00@0P820000000000000
P8208@3oool01@20P8000000000000000000`<300240oooo00@0@410000000000000@4108@3oool0
1@20P8000000000000000000P8200240oooo00D0@41000000000000000000<30`00P0?ooo`050<30
`0000000000000000020P800<@3oool?ooooo`003OoooomZ0?ooo`050<30`0000000000000000020
P8008@3oool01@10@4000000000000000000`<300200oooo00D0`<3000000000000000000410@00Q
0?ooo`050820P0000000000000000030`<008@3oool01010@400000000000010@40Q0?ooo`040<30
`000000000000410@240oooo00D0`<3000000000000000000820P00Q0?ooo`050410@00000000000
00000030`<00803oool01@30`<000000000000000000@4100240oooo00D0P8200000000000000000
0<30`00Q0?ooo`040410@000000000000410@300oooo3oooool000goooooK03oool3000000030820
P03oool0oooo01l0oooo1000000R0?ooo`@000008@3oool01020P800000000000000000R0?ooo`@0
00008@3oool01020P800000000000000000Q0?ooo`050820P0000000000000000020P8008@3oool4
00000280oooo0`0000000`20P800oooo0?ooo`0O0?ooo`040820P0000000000000000280oooo1000
000_0?ooo`oooooo000=ooooof`0oooo00D0`<3000000000000000000820P00Q0?ooo`050410@000
0000000000000030`<00803oool01@30`<000000000000000000@4100240oooo00D0P82000000000
000000000<30`00Q0?ooo`040410@000000000000410@240oooo00@0P820000000000000@4108@3o
ool01@20P8000000000000000000P8200240oooo00D0@41000000000000000000<30`00P0?ooo`05
0<30`0000000000000000020P8008@3oool01@20P8000000000000000000`<300200oooo00D0`<30
00000000000000000410@00^0?ooo`oooooo000=ooooofd0oooo00D0P82000000000000000000820
P00Q0?ooo`@000008P3oool3000000030820P03oool0oooo01l0oooo00@0P8200000000000000000
8P3oool400000240oooo00@0P82000000000000000008@3oool01@20P8000000000000000000P820
0240oooo1000000R0?ooo`<0000000<0P8200?ooo`3oool07`3oool01020P800000000000000000R
0?ooo`@00000;@3oool?ooooo`003Ooooom^0?ooo`050820P0000000000000000020P8008@3oool0
1010@400000000000010@40Q0?ooo`050<30`0000000000000000020P8008@3oool01@10@4000000
000000000000`<300200oooo00D0`<3000000000000000000410@00Q0?ooo`040820P00000000000
0410@240oooo00D0P82000000000000000000<30`00Q0?ooo`040410@000000000000410@240oooo
00D0`<3000000000000000000820P00Q0?ooo`050410@0000000000000000030`<00803oool01@30
`<000000000000000000@41002`0oooo3oooool000goooooK`3oool01@20P8000000000000000000
P8200240oooo1000000R0?ooo`<0000000<0P8200?ooo`3oool07`3oool400000280oooo0`00000R
0?ooo`040820P0000000000000000240oooo00@0P82000000000000000008P3oool400000240oooo
00D0P82000000000000000000820P00Q0?ooo`@000008P3oool3000000030820P03oool0oooo02T0
oooo3oooool000goooooL03oool01@20P8000000000000000000`<300240oooo00@0@41000000000
0000@4108@3oool01@30`<000000000000000000P8200240oooo00D0@41000000000000000000<30
`00P0?ooo`050<30`0000000000000000030`<008@3oool01020P800000000000010@40Q0?ooo`05
0820P0000000000000000030`<008@3oool01010@400000000000010@40Q0?ooo`050820P0000000
000000000020P8008@3oool01@10@4000000000000000000`<300200oooo00D0`<30000000000000
00000820P00Z0?ooo`oooooo000=ooooog40oooo00D0`<3000000000000000000820P00Q0?ooo`05
0410@0000000000000000030`<00803oool01@30`<000000000000000000@4100240oooo00D0P820
00000000000000000<30`00Q0?ooo`040410@000000000000<30`240oooo00@0`<30000000000000
@4108@3oool01@30`<000000000000000000P8200240oooo00D0@41000000000000000000<30`00P
0?ooo`050<30`0000000000000000010@4008@3oool01@20P8000000000000000000`<300240oooo
00@0@410000000000000@410:@3oool?ooooo`003Ooooomc0?ooo`<0000000<0P8200?ooo`3oool0
7`3oool400000280oooo1000000Q0?ooo`040820P0000000000000000280oooo0`00000S0?ooo`<0
00008@3oool01@20P8000000000000000000P8200240oooo1000000R0?ooo`<0000000<0P8200?oo
o`3oool07`3oool01020P800000000000000000R0?ooo`@00000:03oool?ooooo`003OoooomA0?oo
o`030410@03oool0oooo01l0oooo00D0`<3000000000000000000820P00Q0?ooo`050410@0000000
000000000030`<00803oool01@30`<000000000000000000@4100240oooo00D0P820000000000000
00000<30`00Q0?ooo`040410@000000000000<30`240oooo00@0`<30000000000000@4108@3oool0
1@20P8000000000000000000P8200240oooo00D0@41000000000000000000<30`00P0?ooo`050<30
`0000000000000000020P8008@3oool01@20P8000000000000000000`<300200oooo00D0`<300000
0000000000000410@00W0?ooo`oooooo000=oooooe40oooo0P00000Q0?ooo`050820P00000000000
00000020P8008@3oool400000280oooo0`0000000`20P800oooo0?ooo`0O0?ooo`040820P0000000
000000000280oooo0`00000R0?ooo`040820P0000000000000000240oooo00D0P820000000000000
00000820P00Q0?ooo`@000008P3oool3000000030820P03oool0oooo01l0oooo00@0P82000000000
000000008P3oool4000002H0oooo3oooool000goooooD@3oool2000000030410@03oool0oooo01l0
oooo00D0P82000000000000000000820P00Q0?ooo`040410@000000000000410@240oooo00D0`<30
00000000000000000820P00Q0?ooo`050410@0000000000000000030`<00803oool01@30`<000000
000000000000`<300240oooo00@0P820000000000000@4108@3oool01@20P8000000000000000000
`<300240oooo00@0@410000000000000@4108@3oool01@30`<000000000000000000P8200240oooo
00D0@41000000000000000000<30`00P0?ooo`050<30`0000000000000000010@4009@3oool?oooo
o`003OoooomA0?ooo`@000008@3oool01@20P8000000000000000000P8200240oooo1000000R0?oo
o`<0000000<0P8200?ooo`3oool07`3oool400000280oooo0`00000R0?ooo`040820P00000000000
00000240oooo00@0P82000000000000000008P3oool400000240oooo00D0P8200000000000000000
0820P00Q0?ooo`@000008P3oool3000000030820P03oool0oooo0280oooo3oooool000goooooD@3o
ool01@30`<000000000000000000@4100240oooo00D0P82000000000000000000<30`00Q0?ooo`04
0410@000000000000410@240oooo00D0`<3000000000000000000820P00Q0?ooo`050410@0000000
000000000030`<00803oool01@30`<000000000000000000`<300240oooo00@0P820000000000000
@4108@3oool01@20P8000000000000000000`<300240oooo00@0@410000000000000@4108@3oool0
1@20P8000000000000000000P8200240oooo00D0@41000000000000000000<30`00P0?ooo`050<30
`0000000000000000020P8008`3oool?ooooo`00ooooooooooooocCooooo003ooooooooooooo=?oo
ool00?ooooooooooooldooooo`00ooooooooooooocCooooo003ooooooooooooo=?ooool00?oooooo
ooooooldooooo`00ooooooooooooocCooooo003ooooooooooooo=?ooool00001\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{187.5, 116.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 6.15", "Caption",
  CellTags->"Fig. 6.15"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Find the normal modes",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[\(\[Psi]\_n\),
              "TraditionalForm"], "(", "z", ")"}]}], TraditionalForm]]],
  " and the  frequencies  of oscillation of the rope using WKB analysis.  \
What are the lowest three  mode frequencies in units of radians per sec?"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Use the shooting method to find the first three normal modes and their \
frequencies numerically. Compare the frequencies with those found via the WKB \
approximation."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Use these modes and frequencies to solve the following initial-value \
problem: ",
  Cell[BoxData[
      \(TraditionalForm\`u(z, 0)\  = 
        0, \ \(u\& . \)(z, 0)\  = \ \(\(sin(\[Pi]\ z/L)\)\(.\)\)\)]],
  " Keeping the first 10  modes,  animate  ",
  Cell[BoxData[
      \(TraditionalForm\`y(z, t)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(0\)\(<\)\(t\)\(<\)\(\ \)\(2\)\(\ \)\)\)]],
  "s."
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Perform the analysis of parts (a) and (c)  using the grid method."
}], "Text"],

Cell[TextData[{
  StyleBox["(e) ",
    FontWeight->"Bold"],
  "Perform the analysis of parts (a) and (c)  using the Galerkin method."
}], "Text"],

Cell[TextData[{
  StyleBox["(4)(a) ",
    FontWeight->"Bold"],
  "Water fills a long straight ditch with vertical walls. The water depth as \
function of transverse position ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " across the ditch is"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(h(x)\), " ", "=", 
          TagBox[
            RowBox[{
              StyleBox["{",
                ShowAutoStyles->False,
                FontSize->16], 
              StyleBox[GridBox[{
                    {
                      RowBox[{
                        RowBox[{"0.25", " ", 
                          StyleBox["m",
                            FontSlant->"Plain"]}], ",", "      ", 
                        RowBox[{"0", "<", "x", "<", 
                          RowBox[{"1", " ", 
                            StyleBox["m",
                              FontSlant->"Plain"]}]}]}]},
                    {
                      RowBox[{
                        RowBox[{"0.5", " ", 
                          StyleBox["m",
                            FontSlant->"Plain"]}], ",", "         ", 
                        RowBox[{"1", "<", "x", "<", 
                          RowBox[{"2", " ", 
                            StyleBox["m",
                              FontSlant->"Plain"]}]}]}]}
                    }],
                ShowAutoStyles->True]}],
            (#&)]}], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  "Determine the lowest three mode frequencies for water waves, and plot the \
corresponding wave height ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, t)\)]],
  "using the grid method. The wave height ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, t)\)]],
  " satisfies Eq. ",
  ButtonBox["(4.2.51)",
    ButtonData:>{"Chapter4.nb", "(4.2.51)"},
    ButtonStyle->"Hyperlink"],
  ", and is related to the horizontal fluid displacement ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\)]],
  " by Eq. ",
  ButtonBox["(4.2.50)",
    ButtonData:>{"Chapter4.nb", "(4.2.50)"},
    ButtonStyle->"Hyperlink"],
  ". (Hint: You may find it easier to satisfy the boundary conditions by \
rewriting Eq. ",
  ButtonBox["(4.2.51)",
    ButtonData:>{"Chapter4.nb", "(4.2.51)"},
    ButtonStyle->"Hyperlink"],
  " in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\)]],
  ", and solving for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\)]],
  " rather than ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ")"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " perform the analysis using the Galerkin method."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " perform the analysis using the WKB/shooting method."
}], "Text"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " An electron  of mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " is trapped in the following potential structure: "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(V(x)\), " ", "=", " ", 
          TagBox[
            RowBox[{
              StyleBox["{",
                ShowAutoStyles->False,
                FontSize->18], 
              StyleBox[GridBox[{
                    {GridBox[{
                          {\(\[Infinity], \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \(\(|\)\(x\)\(|\)\(\(>\)\(a\)\)\), \)},
                          {\(0, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(-a\) < 
                              x < 0, \)}
                          }]},
                    {\(V\_o\ x/a, \ \ \ \ \ \ \ \ \ 0 < x < \(\(a\)\(.\)\)\)}
                    }],
                ShowAutoStyles->True]}],
            (#&)]}], TraditionalForm]]],
  " "
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Find the ground state energy and plot the wave function of the electron \
using the grid method, for "
}], "Text"],

Cell[TextData[{
  "\t\t(i) ",
  Cell[BoxData[
      \(TraditionalForm\`\[HBar]\^2/\((m\ \(a\^2\) V\_o)\)\  = \ 1/2\)]],
  ","
}], "Text"],

Cell[TextData[{
  "\t\t(ii) ",
  Cell[BoxData[
      \(TraditionalForm\`\[HBar]\^2/\((m\ \(a\^2\) V\_o)\)\  = \ 2\)]],
  "\t.\t"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Perform the analysis using the Galerkin method."
}], "Text"],

Cell[TextData[{
  StyleBox["(6)(a)",
    FontWeight->"Bold"],
  " Use WKB theory to find the energy levels and corresponding eigenfunctions \
for a quantum particle moving in 1D, and compare the first 3 eigenfunctions \
and energies to those found from the shooting method.  The particle's wave \
function satisfies the dimensionless 1-D  Schr\[ODoubleDot]dinger equation "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            FractionBox[\(\[PartialD]\(\[Psi](x, t)\)\), \(\[PartialD]t\),
              MultilineFunction->None]}], "=", 
          RowBox[{\(\(V(x)\)\ \(\[Psi](x, t)\)\), "-", 
            RowBox[{\(1\/2\), " ", 
              
              FractionBox[\(\[PartialD]\^2\( \[Psi](x, 
                    t)\)\), \(\[PartialD]x\^2\),
                MultilineFunction->None]}]}]}], TraditionalForm]]],
  " "
}], "Text"],

Cell["\<\
For the potential, take the following cases. Make sure that you \
properly account for turning points, if any :\
\>", "Text"],

Cell[TextData[{
  "(i) ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(V(x)\  = \ x/3, \ 0 < x < 1, \ 
            V(x)\  = \ \ \ \[Infinity]\),
            "TraditionalForm"], \(\(otherwise\)\(.\)\)}], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  "(ii) ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\  = \ x\^4\)]]
}], "Text"],

Cell[TextData[{
  "(iii) ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\  = \ x + x\^4\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Find the first three energy levels and eigenfunctions using the shooting \
method."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Find the first three energy levels and eigenfunctions using the grid \
method."
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Find the first three energy levels and eigenfunctions using the Galerkin \
method."
}], "Text"],

Cell[TextData[{
  StyleBox["(7)",
    FontWeight->"Bold"],
  " In problems with turning points, the WKB solution decays exponentially \
beyond the turning point. Beyond a right turning point at ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_R\)]],
  ", this decay is of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x)\  \[Proportional] \ 
        exp[\(-\[Integral]\_\(x\_R\)\%x\) | k(x) | \[DifferentialD]x]\)]],
  ". As a boundary condition on the shooting method, it is more accurate to \
match the shooting solution to this functional form, rather than simply \
setting ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] = 0\)]],
  "at some point ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1 >> x\_R\)]],
  ". To do so, note that this form  implies that ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[PartialD]\[Psi]/\[PartialD]x\  = \ \(-\(\(|\)\(k(
                  x)\)\(|\)\(\ \)\(\(\[Psi](x)\)\ for\ x\)\)\)\), ">>", 
          RowBox[{\(x\_R\), 
            RowBox[{Cell[""], "."}]}]}], TraditionalForm]]],
  "Using this mixed boundary condition in the WKB method, redo Exercise \
(6)(b)(iii)."
}], "Text",
  CellTags->"i:56"],

Cell[TextData[{
  StyleBox["(8) ",
    FontWeight->"Bold"],
  "A drumhead has an elliptical shape, with an edge given by the equation ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2/a\^2 + y\^2/b\^2 = 1\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`a = \(\(10\)\(\ \)\(cm\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\  = \ 20\ cm\)]],
  ". Waves on the drumhead travel with speed ",
  Cell[BoxData[
      FormBox[
        RowBox[{"c", "=", 
          RowBox[{"50", " ", 
            RowBox[{"cm", "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ". Find the frequencies and plot the forms of the lowest three modes using \
a method of your choice."
}], "Text"],

Cell[TextData[{
  StyleBox["(9)",
    FontWeight->"Bold"],
  " A square pool of water with vertical sides has a width and length  of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"L", "=", 
          RowBox[{"5", " ", 
            StyleBox["m",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ",  and nonuniform water depth, equal to ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0.25", " ", 
          RowBox[{
            StyleBox["m",
              FontSlant->"Plain"], " ", "[", \(1 + 3\ \((x/L)\)\^2\), "]"}]}],
         TraditionalForm]]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " measured from one of the sides. Find the frequencies and plot the forms \
of the lowest three eigenmodes for shallow water waves in this pool. The \
waves satisfy the equation for potential flow in water with nonuniform depth, \
Eq. ",
  ButtonBox["(6.2.45)",
    ButtonData:>"(6.2.45)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(10) ",
    FontWeight->"Bold"],
  "A resonance chamber has the shape of a spheroid, with walls satisfying ",
  Cell[BoxData[
      \(TraditionalForm\`r\^2/a\^2 + z\^2/b\^2 = 1\)]],
  " in cylindrical coordinates, where ",
  Cell[BoxData[
      \(TraditionalForm\`a = 1\ cm\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b = 2.5\ cm\)]],
  " . The speed of sound in air is roughly ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{Cell[""], "c"}], "=", 
          RowBox[{"340", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ". Using the Galerkin method, find the lowest resonant frequency of the \
chamber, in hertz, and plot the form of the associated eigenmode. Hints: \
Sound waves in the chamber satisfy potential flow with a von Neumann  \
condition at the walls; see Eq. ",
  ButtonBox["(4.4.40)",
    ButtonData:>{"Chapter4.nb", "(4.4.40)"},
    ButtonStyle->"Hyperlink"],
  " and surrounding discussion. The following cylindrically symmetric basis \
functions match the required von Neumann  boundary conditions:  "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_\(i\ j\)\)(r, z) = \(r\^\(\(\ \)\(i\)\)\) 
          z\^j\ \ \ \((\ \((\(b\^2\) i\  + \ \(a\^2\) 
                      j)\) \((r\^2\/\(\(a\^2\)(2\ b\^2 + \(b\^2\) i\  + \ \(a\
\^2\) j)\) + 
                    z\^2\/\(\(\(b\^2\)(2\ a\^2 + \ \(b\^2\) i\  + \ \(a\^2\) \
j)\)\(\ \)\)\ )\) - 1)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`i, j \[GreaterEqual] \ 0\)]],
  ".\n",
  StyleBox["(11)",
    FontWeight->"Bold"],
  " In the previous problem, it was assumed that the lowest frequency mode is \
cylindrically symmetric. This  is, in fact, only correct when ",
  Cell[BoxData[
      \(TraditionalForm\`b > a\)]],
  ". Find the form and frequency of the lowest frequency mode in the \
spheroidal cavity  for the case ",
  Cell[BoxData[
      \(TraditionalForm\`b = 1\ cm, \ a = 2\ cm\)]],
  ". Note that cylindrical symmetry of the cavity walls implies that the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " dependence of the modes can be written in the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ m\ \[Phi]\)\)]],
  ".  (Hint: for ",
  Cell[BoxData[
      \(TraditionalForm\`m \[NotEqual] \ 0\)]],
  ", the eigenmodes must satisfy Eq. ",
  ButtonBox["(6.1.37)",
    ButtonData:>"(6.1.37)",
    ButtonStyle->"Hyperlink"],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`r \[Rule] 0\)]],
  ".  This limits the values of ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " used in the basis functions.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(12)",
    FontWeight->"Bold"],
  " A hollow waveguide, with perfectly conducting walls and uniform cross \
section as shown in Fig. ",
  ButtonBox["6.16",
    ButtonData:>"Fig. 6.16",
    ButtonStyle->"Hyperlink"],
  ",  runs in the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-direction. This waveguide supports transverse magnetic (TM) traveling \
waves. These waves satisfy the the following wave equation \
(Fourier-transformed in ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "):",
  Cell[BoxData[
      FormBox[Cell[""], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\_ \[UpTee] \%2 E\_z\  \[Congruent] \((\
\[PartialD]\^2\/\[PartialD]x\^2 + \[PartialD]\^2\/\[PartialD]y\^2)\) 
            E\_z = \ \((k\^2 - \[Omega]\^2/c\^2)\) E\_z\)]],
  ",\nwith boundary conditions that ",
  Cell[BoxData[
      \(TraditionalForm\`E\_z = 0\)]],
  " on the walls, where ",
  Cell[BoxData[
      \(TraditionalForm\`E\_z\)]],
  " is the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-component of the electric field, and where waves are assumed to have the \
form ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(\[PlusMinus]\[ImaginaryI]\)\ k\ \
z\  - \ \[ImaginaryI]\ \[Omega]\ t\)\)]],
  ". For the waveguide geometry shown in the figure, find the lowest three \
(nondegenerate) modes and the corresponding dispersion relations ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](k)\)]],
  ",  using the grid method on a 20-by-20 grid. Plot  contours of constant ",
  Cell[BoxData[
      \(TraditionalForm\`E\_z\)]],
  " associated with these modes as contour plots in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " plane."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005?0001Cb000`400?l00000o`00003ooooooom@
ooooo`00oooooom@ooooo`00oooooom@ooooo`00oooooom@ooooo`00oooooom@ooooo`00oooooom@
ooooo`00oooooom@ooooo`00oooooom@ooooo`00oooooom@ooooo`001ooooolC0?ooo`D00000;P3o
ool5000002/0oooo1@00000^0?ooo`D00000:`3oool00`20P800000000000002000000030820P03o
ool0oooo02/0oooo1@00000[0?ooo`030820P0000000000000Wooooo0007oooooa@0oooo1@00000]
0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0:@3oool5000002d0oooo00<0P820
0000000000000`00000[0?ooo`D00000;P3oool5000002/0oooo0P000009ooooo`001ooooolE0?oo
o`030820P000000000000080000000<0P8200?ooo`3oool0:P3oool00`20P8000000000000020000
00030820P03oool0oooo02T0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`0Z0?oo
o`030820P000000000000080000000<0@4100?ooo`3oool0:@3oool00`20P8000000000000020000
00030820P03oool0oooo02X0oooo00<0`<300000000000000P0000000`10@400oooo0?ooo`0Y0?oo
o`030820P?oooooooooo00Oooooo0007oooooaL0oooo1@00000]0?ooo`D00000;03oool5000002d0
oooo1@00000/0?ooo`D00000;@3oool5000002/0oooo2Oooool000Oooooo5`3oool00`20P8000000
00000002000000030820P03oool0oooo02/0oooo1@00000[0?ooo`030820P0000000000000<00000
;@3oool5000002`0oooo1@00000]0?ooo`D00000:P3oool9ooooo`001ooooolH0?ooo`D00000;P3o
ool5000002/0oooo1@0000000`20P800oooo0?ooo`0[0?ooo`D00000:`3oool00`20P80000000000
0002000000030820P03oool0oooo02/0oooo1@00000Y0?ooo`Wooooo0007oooooaT0oooo1@00000]
0?ooo`030820P0000000000000<00000:`3oool5000002h0oooo1@00000[0?ooo`D00000;P3oool5
000002P0oooo2Oooool000Oooooo6P3oool00`20P800000000000002000000030820P03oool0oooo
02X0oooo00<0P8200000000000000P0000000`10@400oooo0?ooo`0Y0?ooo`030820P00000000000
0080000000<0P8200?ooo`3oool0:P3oool00`30`<00000000000002000000030410@03oool0oooo
02T0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`0Z0?ooo`030<30`00000000000
0080000000<0@4100?ooo`3oool09@3oool9ooooo`001ooooolL0?ooo`D00000;@3oool5000002`0
oooo1@00000]0?ooo`D00000;03oool5000002d0oooo1@00000V0?ooo`Wooooo0007oooooa`0oooo
00<0P8200000000000000P0000000`20P800oooo0?ooo`0[0?ooo`D00000;03oool5000002d0oooo
1@00000/0?ooo`D00000;@3oool5000002D0oooo2Oooool000Oooooo7@3oool5000002h0oooo1@00
000[0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0:`3oool5000002/0oooo00<0
P8200000000000000P0000000`20P800oooo0?ooo`0[0?ooo`D00000903oool9ooooo`001ooooolN
0?ooo`D00000;P3oool5000002/0oooo1@00000^0?ooo`D00000:`3oool5000002h0oooo1@00000S
0?ooo`Wooooo0007oooooal0oooo1@00000]0?ooo`030820P000000000000080000000<0P8200?oo
o`3oool0:@3oool5000002d0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`0Y0?oo
o`D00000;@3oool00`20P80000000000000300000280oooo2Oooool000Oooooo803oool00`20P800
000000000002000000030820P03oool0oooo02X0oooo00<0P8200000000000000P0000000`20P800
oooo0?ooo`0Y0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0:P3oool00`20P800
000000000002000000030820P03oool0oooo02T0oooo00<0P8200000000000000P0000000`20P800
oooo0?ooo`0Z0?ooo`030820P000000000000080000000<0@4100?ooo`3oool07`3oool9ooooo`00
1ooooolQ0?ooo`030820P0000000000000<00000;@3oool5000002`0oooo1@00000]0?ooo`D00000
;03oool5000002d0oooo1@00000P0?ooo`Wooooo0007ooooob80oooo1@0000000`20P800oooo0?oo
o`0[0?ooo`D00000:`3oool00`20P800000000000002000000030820P03oool0oooo02/0oooo1@00
000[0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0:`3oool5000001l0oooo2Ooo
ool000Oooooo8`3oool5000002h0oooo1@00000[0?ooo`D00000;P3oool5000002/0oooo1@00000^
0?ooo`D000007P3oool9ooooo`001ooooolT0?ooo`D00000;@3oool00`20P8000000000000020000
00030820P03oool0oooo02T0oooo1@00000]0?ooo`030820P000000000000080000000<0P8200?oo
o`3oool0:@3oool5000002h0oooo1@00000M0?ooo`Wooooo0007oooooa<0ooooo`00000O00000003
0820P03oool0oooo00/0oooo2Oooool000Oooooo4`3ooooo000001l0000000<0P8200?ooo`3oool0
2`3oool9ooooo`001ooooolC0?ooool000007`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007
oooooa<0ooooo`00000O000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3ooooo0000
01l0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooooolC0?ooool000007`0000000`20P800
oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo2000003o0?oooa00oooo1`0000000`20P800oooo
0?ooo`0;0?ooo`Wooooo0007ooooo`030000003oool0oooo0100oooo2000003o0?oooa00oooo1`00
00000`20P800oooo0?ooo`0;0?ooo`Wooooo0007ooooo`8000004@3oool800000?l0oooo403oool7
000000030820P03oool0oooo00/0oooo2Oooool000Oooooo0P0000000`20P800oooo0?ooo`0>0?oo
o`P00000o`3oool@0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001oooool300000003
0820P03oool0oooo00d0oooo2000003o0?oooa00oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wo
oooo0007ooooo`D000003P3oool800000?l0oooo403oool7000000030820P03oool0oooo00/0oooo
2Oooool000Oooooo00<0oooo0000000000000`00000=0?ooo`P00000o`3oool@0?ooo`L0000000<0
P8200?ooo`3oool02`3oool9ooooo`001oooool20?ooo`D00000303oool800000?l0oooo403oool7
000000030820P03oool0oooo00/0oooo2Oooool000Oooooo0P3oool00`20P8000000000000020000
00030820P03oool0oooo00T0oooo2000003o0?oooa00oooo1`0000000`20P800oooo0?ooo`0;0?oo
o`Wooooo0007ooooo`<0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`080?ooo`P0
0000o`3oool@0?ooo`L0000000<0@4100?ooo`3oool02`3oool9ooooo`001oooool50?ooo`D00000
2@3oool800000?l0oooo403oool9000000`0oooo2Oooool000Oooooo1P3oool5000000P0oooo2000
003o0?oooa00oooo2P00000;0?ooo`Wooooo0007ooooo`L0oooo1@0000070?ooo`P00000o`3oool@
0?ooo`/000002P3oool9ooooo`001oooool70?ooo`030820P0000000000000<000001P3oool80000
0?l0oooo403oool<000000T0oooo2Oooool000Oooooo203oool5000000030820P03oool0oooo00<0
oooo2000003o0?oooa00oooo3@0000080?ooo`Wooooo0007ooooo`T0oooo00<0P820000000000000
0P0000000`20P800oooo0?ooo`020?ooo`P00000o`3oool@0?ooo`L000000P20P804000000030410
@03oool0oooo00D0oooo2Oooool000Oooooo2`3oool5000000<0oooo2000003o0?oooa00oooo1`00
00000`20P800oooo0?ooo`05000000H0oooo2Oooool000Oooooo303oool500000080oooo2000003o
0?oooa00oooo1`0000001020P800oooo0?ooo`3oool5000000D0oooo2Oooool000Oooooo3@3oool5
000000030?ooo`000000000000H00000o`3oool@0?ooo`L0000000<0P8200?ooo`3oool00P3oool5
000000@0oooo2Oooool000Oooooo3@3oool00`20P800000000000002000000030820P00000000000
00H00000o`3oool@0?ooo`L0000000<0P8200?ooo`3oool00`3oool5000000<0oooo2Oooool000Oo
oooo3P3oool00`20P80000000000000:00000?l0oooo403oool7000000030820P03oool0oooo00<0
oooo00<0`<300000000000000P0000000`10@400oooo0?ooo`09ooooo`001oooool@0?ooo`/00000
L03oool4000000030820P03oool0oooo00<0oooo00<0P8200000000000000`3oool2000000/0oooo
1`0000000`20P800oooo0?ooo`1h0?ooo`L0000000<0P8200?ooo`3oool01@3oool5000000030?oo
oooooooooooo00Oooooo0007oooooa40oooo2P00001_0?ooo`030820P0000000000000@00000103o
ool5000000030?ooo`000000000000T0oooo3000001h0?ooo`L0000000<0P8200?ooo`3oool01P3o
ool5000000Wooooo0007oooooa80oooo2@00001_0?ooo`P000000P3oool6000000030820P0000000
000000T0oooo1@0000060?ooo`<00000MP3oool7000000030820P03oool0oooo00L0oooo10000009
ooooo`001ooooolB0?ooo`030820P0000000000000H00000KP3oool5000000<0oooo1P0000030?oo
o`040820P03oool00000000000P0oooo0`0000000`20P800oooo0?ooo`060?ooo`80000000<0P820
0?ooo`3oool0L`3oool7000000030820P03oool0oooo00P0oooo0`000009ooooo`001ooooolC0?oo
o`P00000KP3oool3000000030820P03oool0oooo00@0oooo00@0P82000000000000000001@3oool2
000001D0oooo00<0P82000000020P800M03oool7000000030820P03oool0oooo00P0oooo00<0`<30
0000000000002Oooool000Oooooo4`3oool8000006h0oooo0`0000080?ooo`<000001@3oool30000
01D0oooo00<0P820000000000000L`3oool7000000030820P03oool0oooo00X0oooo00<00000oooo
ooooool01oooool000Oooooo4`3oool8000006h0oooo0`0000080?ooo`<000001P3oool2000001D0
oooo00<0P820000000000000L`3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo
4`3oool8000006l0oooo0P0000080?ooo`<000001P3oool2000001D0oooo00@0P820000000000000
0000LP3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000006l0oooo
00<0P8200000000000001`3oool3000000H0oooo0P00000E0?ooo`040820P0000000000000000780
oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo2000001`0?ooo`040820
P000000000000820P0D0oooo0`0000070?ooo`0300000020P800oooo01<0oooo00@0@41000000000
00000000LP3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000007@0
oooo00<000000?ooo`3oool00P3oool3000000L0oooo00<000000820P03oool04`3oool400000780
oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo2000001e0?ooo`<00000
00@0oooo0000000000000000203oool00`000000oooo0?ooo`0A0?ooo`@00000L`3oool700000003
0820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000007P0oooo100000080?ooo`030000
003oool0oooo0100oooo1@00001c0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooo
oolC0?ooo`P00000N@3oool3000000P0oooo00<000000?ooo`3oool03@3oool00`20P80000000000
0004000007@0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo2000001_
0?ooo`030820P0000000oooo00L0oooo0`0000080?ooo`030000003oool0oooo00P0oooo2`00001e
0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooooolC0?ooo`P00000K`3oool30000
00L0oooo0`0000080?ooo`030820P0000000oooo00/0oooo0P20P80300000080P820MP3oool70000
00030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000006l0oooo0`0000070?ooo`80
00002@3oool00`20P80000000?ooo`0>0?ooo`<00000M`3oool7000000030820P03oool0oooo00/0
oooo2Oooool000Oooooo4`3oool8000006l0oooo00<0P8200000000000001P3oool3000000X0oooo
0P00000?0?ooo`<0000000<0P8200?ooo`3oool0L`3oool7000000030820P03oool0oooo00/0oooo
2Oooool000Oooooo4`3oool800000700oooo0`0000040?ooo`<0000000<0P8200?ooo`3oool0203o
ool200000100oooo0P0000000`20P800oooo0?ooo`1c0?ooo`L0000000<0P8200?ooo`3oool02`3o
ool9ooooo`001ooooolC0?ooo`P00000L`3oool6000000`0oooo0P00000A0?ooo`800000M@3oool7
000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000008D0oooo00<0P8200000
0020P800403oool3000007@0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0
oooo200000260?ooo`8000000`3oool00`000000oooo0?ooo`0:0?ooo`<00000M03oool700000003
0820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000008H0oooo0P0000040?ooo`030000
003oool0oooo00T0oooo0`00001d0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooo
oolC0?ooo`P00000Q`3oool2000000<0oooo0P0000090?ooo`@00000M03oool7000000030820P03o
ool0oooo00/0oooo2Oooool000Oooooo4`3oool8000008L0oooo0P0000040?ooo`0300000020P800
oooo00H0oooo1000001e0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooooolC0?oo
o`P00000Q`3oool2000000@0oooo00<0P8200410@00000001020P8000`10@4000000000000020000
00030410@03oool0oooo07<0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0
oooo200000280?ooo`0300000020P800oooo00@0oooo2P00001f0?ooo`L0000000<0P8200?ooo`3o
ool02`3oool9ooooo`001ooooolC0?ooo`P00000R03oool00`000000P8200?ooo`060?ooo`H00000
N03oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000008P0oooo00<0
00000820P03oool0Q03oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8
00000?l0oooo403oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo00<0P8200?oo
o`3oool0403oool800000?l0oooo403oool7000000030820P03oool0oooo00/0oooo2Oooool000Oo
oooo0P00000A0?ooo`P00000o`3oool@0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`00
1oooool2000000030820P03oool0oooo00h0oooo2000001`0?ooo`800000:03oool2000007<0oooo
1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007ooooo`<00000403oool8000006l0oooo0`00
000X0?ooo`@00000L@3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo1000000?
0?ooo`P00000JP3oool00`20P800000000000006000002H0oooo00<0P8200000000000001P00001]
0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001oooool5000000h0oooo2000001X0?oo
o`/000009P3oool00`20P800000000000008000006/0oooo1`0000000`20P800oooo0?ooo`0;0?oo
o`Wooooo0007ooooo`030?ooo`20P800000000<0000000<0P8200?ooo`3oool02P3oool8000006@0
oooo00<0P8200410@00000003000000V0?ooo`030820P0000000000000/000000P20P81V0?ooo`L0
000000<0P8200?ooo`3oool02`3oool9ooooo`001oooool20?ooo`030820P0000000000000800000
00<0P8200?ooo`3oool02@3oool800000680oooo4@00000V0?ooo`030820P0000000000000h00000
I@3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo0`3oool5000000/0oooo2000
001P0?oooa@000009@3ooolC000006<0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007
ooooo`@0oooo1@00000:0?ooo`P00000GP3ooolF000002D0oooo5@0000000`20P800oooo0?ooo`1N
0?ooo`P000003@3oool9ooooo`001oooool50?ooo`D000002@3oool8000005/0oooo6@00000U0?oo
oaP00000GP3oool9000000`0oooo2Oooool000Oooooo1P3oool00`20P80000000000000200000003
0820P03oool0oooo00D0oooo2000001F0?ooo`030820P0000000000001/000009@20P80L00000080
P820F03oool:000000030820P03oool0oooo00P0oooo2Oooool000Oooooo1`3oool00`20P8000000
00000003000000H0oooo2000001E0?ooof<00000E`3oool<000000T0oooo2Oooool000Oooooo203o
ool5000000030820P03oool0oooo00<0oooo2000001F0?ooof000000F@3oool=000000P0oooo2Ooo
ool000Oooooo2@3oool5000000D0oooo2000001I0?oooeX0000000<0P8200?ooo`3oool0F@3oool7
000000030820P0000000000000<0000000<0P8200?ooo`3oool01@3oool9ooooo`001oooool:0?oo
o`D00000103oool8000005/0oooo6@00000U0?oooaP00000GP3oool7000000030820P03oool00000
00@000001`3oool9ooooo`001oooool;0?ooo`030820P000000000000080000000<0P8200?ooo`3o
ool02000001N0?ooo`80P8205000000U0?oooa<000000P20P8000`30`<00oooo0?ooo`1N0?ooo`L0
000000@0P8200?ooo`3oool0P820100000000`20P800oooo0?ooo`030?ooo`Wooooo0007ooooo`d0
oooo1@0000000`3oool0000000000006000006<0oooo4@00000U0?oooa00000000<0P8200?ooo`3o
ool0H`3oool7000000030820P03oool0oooo0080oooo1@0000040?ooo`Wooooo0007ooooo`d0oooo
00<0P8200000000000000P0000000`20P800000000000006000006D0oooo00<0P820000000000000
3000000U0?ooo`h00000J03oool7000000030820P03oool0oooo00<0oooo1@0000030?ooo`Wooooo
0007ooooo`h0oooo3@00001X0?ooo``000009@3oool00`20P800000000000008000006/0oooo1`00
00000`20P800oooo0?ooo`030?ooo`030820P000000000000080000000<0P8200?ooo`3oool02Ooo
ool000Oooooo3`3oool<000006X0oooo00<0P8200000000000001P00000V0?ooo`030820P0000000
000000H00000K@3oool7000000030820P03oool0oooo00@0oooo1@0000020?ooo`Wooooo0007oooo
oa00oooo00<0P8200000000000002000001]0?ooo`80P82000@0@41000000000000000009P3oool0
1030`<0000000000000000020820P700oooo1`0000000`20P800oooo0?ooo`050?ooo`030820P000
000000000080000000<0P820ooooooooool01oooool000Oooooo4P3oool900000?l0oooo403oool7
000000030820P03oool0oooo00L0oooo10000009ooooo`001ooooolB0?ooo`030820P00000000000
00H00000o`3oool@0?ooo`L0000000<0P8200?ooo`3oool0203oool3000000Wooooo0007oooooa<0
oooo2000003o0?oooa00oooo1`0000000`20P800oooo0?ooo`080?ooo`030820P0000000000000Wo
oooo0007oooooa<0oooo2000003o0?oooa00oooo1`0000000`20P800oooo0?ooo`090?ooo`800000
2Oooool000Oooooo4`3oool800000?l0oooo403oool7000000030820P03oool0oooo00X0oooo00<0
P820ooooooooool01oooool000Oooooo4`3oool800000?l0oooo403oool7000000030820P03oool0
oooo00/0oooo2Oooool000Oooooo4`3oool800000?l0oooo403oool7000000030820P03oool0oooo
00/0oooo2Oooool000Oooooo4`3oool800000?l0oooo403oool7000000030820P03oool0oooo00/0
oooo2Oooool000Oooooo4`3oool800000?l0oooo403oool7000000030820P03oool0oooo00/0oooo
2Oooool000Oooooo4`3oool800000?l0oooo403oool7000000030820P03oool0oooo00/0oooo2Ooo
ool000Oooooo4`3oool800000?l0oooo403oool7000000030820P03oool0oooo00/0oooo2Oooool0
00Oooooo4`3oool800000?l0oooo403oool7000000030820P03oool0oooo00/0oooo2Oooool000Oo
oooo4`3oool800000?l0oooo403oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo
4`3oool800000?l0oooo403oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3o
ool8000005D0oooo00<0P820000000000000H@00001F0?ooo`L0000000<0P8200?ooo`3oool02`3o
ool9ooooo`001ooooolC0?ooo`P00000E@3oool00`20P80000000000001Q000005H0oooo1`000000
0`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo2000001E0?ooo`030820P00000000000
06400000EP3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000005D0
oooo00<0P820000000000000H@00001F0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`00
1ooooolC0?ooo`P00000E@3oool00`20P80000000000001Q000005H0oooo1`0000000`20P800oooo
0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo2000001E0?ooo`030820P0000000000006400000EP3o
ool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000005D0oooo00<0P820
0000000000001@00000B0820P0D00000:`20P805000000h0P8201`00001F0?ooo`L0000000<0P820
0?ooo`3oool02`3oool9ooooo`001ooooolC0?ooo`P00000E@3oool00`20P8000000000000050000
0180oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`0Y0?ooo`D000003@3oool70000
05H0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo2000001E0?ooo`03
0820P0000000000000D000004`3oool5000002`0oooo1@00000<0?ooo`L00000EP3oool700000003
0820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000005D0oooo00<0P820000000000000
1@00000D0?ooo`D00000;03oool5000000/0oooo1`00001F0?ooo`L0000000<0P8200?ooo`3oool0
2`3oool9ooooo`001ooooolC0?ooo`P00000E@3oool00`20P800000000000005000001D0oooo1@00
000/0?ooo`D000002P3oool7000005H0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007
oooooa<0oooo2000001E0?ooo`030820P0000000000000D000005P3oool00`20P800000000000002
000000030820P03oool0oooo02P0oooo00<0`<300000000000000`0000000`30`<00oooo0?ooo`06
0?ooo`L00000EP3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool80000
05D0oooo00<0P8200000000000001@00000G0?ooo`030820P0000000000000<00000:`3oool50000
00P0oooo1`00001F0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001oooool00`000000
oooo0?ooo`0@0?ooo`P00000E@3oool00`20P800000000000005000001P0oooo1@0000000`20P800
oooo0?ooo`0Y0?ooo`H000001P3oool7000005H0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wo
oooo0007ooooo`8000004@3oool8000005D0oooo00<0P8200000000000001@00000I0?ooo`D00000
;03oool6000000D0oooo1`00001F0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooo
ool2000000030820P03oool0oooo00h0oooo2000001E0?ooo`030820P0000000000000D000006P3o
ool5000002`0oooo1P0000040?ooo`L00000EP3oool7000000030820P03oool0oooo00/0oooo2Ooo
ool000Oooooo0`00000@0?ooo`P00000E@3oool00`20P800000000000005000001/0oooo1@00000/
0?ooo`030820P000000000000080000000@0P8200?ooo`3oool0oooo1`00001F0?ooo`L0000000<0
P8200?ooo`3oool02`3oool9ooooo`001oooool4000000030820P03oool0oooo00`0oooo2000001E
0?ooo`030820P0000000000000D00000703oool00`20P800000000000002000000030820P03oool0
oooo02T0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`07000005H0oooo1`000000
0`20P800oooo0?ooo`0;0?ooo`Wooooo0007ooooo`030?ooo`000000000000<000003@3oool80000
05D0oooo00<0P8200000000000001@00000M0?ooo`030820P000000000000080000000<0P8200?oo
o`3oool0:P3oool5000000030?ooo`000000000000D00000EP3oool7000000030820P03oool0oooo
00/0oooo2Oooool000Oooooo0P3oool5000000`0oooo2000001E0?ooo`030820P0000000000000D0
00007P3oool5000002d0oooo3000001F0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`00
1oooool20?ooo`030820P000000000000080000000<0P8200?ooo`3oool02@3oool8000005D0oooo
00<0P8200000000000001@00000O0?ooo`D00000;@3oool;000005H0oooo1`0000000`20P800oooo
0?ooo`0;0?ooo`Wooooo0007ooooo`<0oooo1@00000;0?ooo`P00000E@3oool00`20P80000000000
000500000200oooo1@00000/0?ooo`030820P0000000000000P00000EP3oool7000000030820P03o
ool0oooo00/0oooo2Oooool000Oooooo103oool00`20P800000000000002000000030820P03oool0
oooo00L0oooo2000001E0?ooo`030820P0000000000000D000008@3oool00`20P800000000000002
000000030820P03oool0oooo02T0oooo00<0P8200000000000001`00001F0?ooo`P0000000<0P820
0?ooo`3oool02P3oool9ooooo`001oooool60?ooo`D00000203oool8000005D0oooo00<0P8200000
000000001@00000R0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0:P3oool80000
05H0oooo2P00000;0?ooo`Wooooo0007ooooo`L0oooo1@0000070?ooo`P00000E@3oool00`20P800
000000000005000002<0oooo1@00000]0?ooo`L00000EP3oool;000000X0oooo2Oooool000Oooooo
1`3oool00`20P800000000000003000000H0oooo2000001E0?ooo`030820P0000000000000D00000
903oool5000002`0oooo1`00001F0?ooo``000002@3oool9ooooo`001oooool80?ooo`D0000000<0
P8200?ooo`3oool00`3oool8000005D0oooo00<0P8200000000000001@00000U0?ooo`D00000:`3o
ool7000005H0oooo3@0000080?ooo`Wooooo0007ooooo`T0oooo00<0P8200000000000000P000000
0`20P800oooo0?ooo`020?ooo`P00000E@3oool00`20P800000000000005000002H0oooo00<0P820
0000000000000P0000000`20P800oooo0?ooo`0W0?ooo`L00000EP3oool700000080P82010000000
0`10@400oooo0?ooo`050?ooo`Wooooo0007ooooo`/0oooo1@0000030?ooo`P00000E@3oool00`20
P800000000000005000002L0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`0V0?oo
o`L00000EP3oool7000000030820P03oool0oooo00D000001P3oool9ooooo`001oooool<0?ooo`D0
00000P3oool8000005D0oooo00<0P8200000000000001@00000X0?ooo`D00000:03oool7000005H0
oooo1`0000001020P800oooo0?ooo`3oool5000000D0oooo2Oooool000Oooooo3@3oool500000003
0?ooo`000000000000H00000E@3oool00`20P800000000000005000002T0oooo1@00000W0?ooo`L0
0000EP3oool7000000030820P03oool0oooo0080oooo1@0000040?ooo`Wooooo0007ooooo`d0oooo
00<0P8200000000000000P0000000`20P800000000000006000005D0oooo00<0P820000000000000
1@00000Z0?ooo`D000009P3oool7000005H0oooo1`0000000`20P800oooo0?ooo`030?ooo`D00000
0`3oool9ooooo`001oooool>0?ooo`030820P0000000000000X00000E@3oool00`20P80000000000
0005000002/0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`0R0?ooo`L00000EP3o
ool7000000030820P03oool0oooo00<0oooo00<0`<300000000000000P0000000`10@400oooo0?oo
o`09ooooo`001oooool@0?ooo`/00000E@3oool00`20P800000000000005000002`0oooo00<0P820
0000000000000P0000000`20P800oooo0?ooo`0Q0?ooo`L00000EP3oool7000000030820P03oool0
oooo00D0oooo1@0000000`3oooooooooooooo`07ooooo`001ooooolA0?ooo`X00000E@3oool00`20
P800000000000005000002d0oooo1@00000S0?ooo`L00000EP3oool7000000030820P03oool0oooo
00H0oooo1@000009ooooo`001ooooolB0?ooo`T00000E@3oool00`20P800000000000006000002d0
oooo1@00000R0?ooo`L00000EP3oool7000000030820P03oool0oooo00L0oooo10000009ooooo`00
1ooooolB0?ooo`030820P0000000000000H00000E@3oool00`20P800000000000007000002d0oooo
1@00000Q0?ooo`L00000EP3oool7000000030820P03oool0oooo00P0oooo0`000009ooooo`001ooo
oolC0?ooo`P00000E@3oool00`20P800000000000007000000030820P03oool0oooo02/0oooo1@00
000P0?ooo`L00000EP3oool7000000030820P03oool0oooo00P0oooo00<0P8200000000000002Ooo
ool000Oooooo4`3oool8000005D0oooo00<0P820000000000000200000000`20P800oooo0?ooo`0[
0?ooo`030410@000000000000080000000<0P8200?ooo`3oool0703oool7000005H0oooo1`000000
0`20P800oooo0?ooo`090?ooo`030820P000003ooooo00Sooooo0007oooooa<0oooo2000001E0?oo
o`030820P0000000000000D0000000<0oooo0000000000000P00000]0?ooo`D0000000<0P8200?oo
o`3oool06`3oool7000005H0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0
oooo2000001E0?ooo`030820P0000000000000D000000P3oool4000002d0oooo1@00000M0?ooo`L0
0000EP3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000005D0oooo
00<0P8200000000000001@0000020?ooo`030820P0000000000000800000;@3oool5000001`0oooo
1`00001F0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooooolC0?ooo`P00000E@3o
ool00`20P800000000000005000000<0oooo1@00000]0?ooo`D000006`3oool7000005H0oooo1`00
00000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo2000001E0?ooo`030820P0000000
000000D00000103oool01@20P8000000000000000000@41002d0oooo00<0P8200000000000000P00
00000`20P800oooo0?ooo`0G0?ooo`L00000EP3oool7000000030820P03oool0oooo00/0oooo2Ooo
ool000Oooooo4`3oool8000005D0oooo00<0P8200000000000001@0000060?ooo`@00000;@3oool0
0`20P800000000000002000000030820P03oool0oooo01H0oooo1`00001F0?ooo`L0000000<0P820
0?ooo`3oool02`3oool9ooooo`001ooooolC0?ooo`P00000E@3oool00`20P8000000000000050000
00L0oooo1000000]0?ooo`D00000603oool7000005H0oooo1`0000000`20P800oooo0?ooo`0;0?oo
o`Wooooo0007oooooa<0oooo2000001E0?ooo`030820P0000000000000D00000203oool4000002d0
oooo1@00000G0?ooo`L00000EP3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo
4`3oool8000005D0oooo00<0P8200000000000001@0000080?ooo`030820P0000000000000800000
;@3oool5000001H0oooo1`00001F0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooo
oolC0?ooo`P00000E@3oool00`20P800000000000005000000T0oooo00D0P8200000000000000000
0410@00]0?ooo`030820P000000000000080000000<0P8200?ooo`3oool04P3oool7000005H0oooo
1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo2000001E0?ooo`030820P000
0000000000D000002`3oool4000002d0oooo00<0P8200000000000000P0000000`20P800oooo0?oo
o`0A0?ooo`L00000EP3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8
000005D0oooo00<0P8200000000000001@00000<0?ooo`@00000;@3oool5000001<0oooo1`00001F
0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooooolC0?ooo`P00000E@3oool00`20
P800000000000005000000d0oooo1000000]0?ooo`D000004P3oool7000005H0oooo1`0000000`20
P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo2000001E0?ooo`030820P0000000000000D0
00003@3oool00`20P800000000000002000002d0oooo1@00000A0?ooo`L00000EP3oool700000003
0820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000005D0oooo00<0P820000000000000
1@00000>0?ooo`050820P0000000000000000010@400;@3oool00`20P80000000000000200000003
0820P03oool0oooo00d0oooo1`00001F0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`00
1ooooolC0?ooo`P00000E@3oool00`20P80000000000000500000100oooo1000000]0?ooo`030820
P000000000000080000000<0P8200?ooo`3oool0303oool7000005H0oooo1`0000000`20P800oooo
0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo2000001E0?ooo`030820P0000000000000D000004@3o
ool4000002d0oooo1@00000>0?ooo`L00000EP3oool7000000030820P03oool0oooo00/0oooo2Ooo
ool000Oooooo4`3oool8000005D0oooo00<0P8200000000000001@00000B0?ooo`@00000;@3oool5
000000d0oooo1`00001F0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooooolC0?oo
o`P00000E@3oool00`20P80000000000000500000180oooo00<0P8200000000000000P00000]0?oo
o`D00000303oool7000005H0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0
oooo2000001E0?ooo`030820P0000000000000D000004`3oool01@20P8000000000000000000@410
02d0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`080?ooo`L00000EP3oool70000
00030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000005D0oooo00<0P82000000000
00001@00000E0?ooo`@00000;@3oool00`20P800000000000003000000T0oooo1`00001F0?ooo`L0
000000<0P8200?ooo`3oool02`3oool9ooooo`001ooooolC0?ooo`P00000E@3oool00`20P8000000
00000005000001H0oooo1000000]0?ooo`D0000000<0P8200?ooo`3oool01P3oool7000005H0oooo
1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo2000001E0?ooo`030820P000
0000000000D000005`3oool4000002d0oooo1@0000080?ooo`L00000EP3oool7000000030820P03o
ool0oooo00/0oooo2Oooool000Oooooo4`3oool8000005D0oooo00<0P8200000000000001@00000G
0?ooo`030820P0000000000000800000;@3oool5000000L0oooo1`00001F0?ooo`L0000000<0P820
0?ooo`3oool02`3oool9ooooo`001ooooolC0?ooo`P00000E@3oool00`20P8000000000000050000
01P0oooo1@0000000`20P800oooo0?ooo`0Z0?ooo`D000001P3oool7000005H0oooo1`0000000`20
P800oooo0?ooo`0;0?ooo`Wooooo0007ooooo`0300000020P800oooo0100oooo2000001E0?ooo`03
0820P0000000000000D000006@3oool00`20P800000000000002000000030820P03oool0oooo02X0
oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`020?ooo`L00000EP3oool700000003
0820P03oool0oooo00/0oooo2Oooool000Oooooo0P0000000`20P800oooo0?ooo`0>0?ooo`P00000
E@3oool00`20P800000000000005000001/0oooo1@00000/0?ooo`030820P0000000000000800000
00@0P8200?ooo`3oool0oooo1`00001F0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`00
1oooool300000100oooo2000001E0?ooo`030820P0000000000000D00000703oool5000002`0oooo
1@0000030?ooo`L00000EP3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo1000
000?0?ooo`P00000E@3oool00`20P800000000000005000001d0oooo1@00000/0?ooo`D000000P3o
ool7000005H0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007ooooo`030?ooo`000000
0000008000003P3oool8000005D0oooo00<0P8200000000000001@00000M0?ooo`030820P0000000
00000080000000<0P8200?ooo`3oool0:P3oool5000000030?ooo`000000000000D00000EP3oool7
000000030820P03oool0oooo00/0oooo2Oooool000Oooooo0P3oool01@10@4000000000000000000
P82000`0oooo2000001E0?ooo`030820P0000000000000D000007P3oool00`20P800000000000002
000000030820P03oool0oooo02X0oooo00<0P8200000000000002@00001F0?ooo`L0000000<0P820
0?ooo`3oool02`3oool9ooooo`001oooool30?ooo`@0000000<0P8200?ooo`3oool02@3oool80000
05D0oooo00<0P8200000000000001@00000P0?ooo`D00000;03oool00`20P8000000000000080000
05H0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007ooooo`@0oooo1000000;0?ooo`P0
0000E@3oool00`20P80000000000000500000240oooo1@00000/0?ooo`X00000EP3oool700000003
0820P03oool0oooo00/0oooo2Oooool000Oooooo1@3oool4000000X0oooo2000001E0?ooo`030820
P0000000000000D000008P3oool5000002`0oooo2@00001F0?ooo`P000003@3oool9ooooo`001ooo
ool60?ooo`@000002@3oool8000005D0oooo00<0P8200000000000001@00000R0?ooo`030820P000
000000000080000000<0P8200?ooo`3oool0:P3oool8000005H0oooo2@00000<0?ooo`Wooooo0007
ooooo`L0oooo00D0@41000000000000000000820P0070?ooo`P00000E@3oool00`20P80000000000
0005000002<0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`0Z0?ooo`L00000EP3o
ool:000000030820P03oool0oooo00P0oooo2Oooool000Oooooo203oool5000000H0oooo2000001E
0?ooo`030820P0000000000000D000009@3oool5000002/0oooo1`00001F0?ooo``000002@3oool9
ooooo`001oooool90?ooo`@0000000<0P8200?ooo`3oool00`3oool8000005D0oooo00<0P8200000
000000001@00000V0?ooo`D00000:P3oool7000005H0oooo3@0000080?ooo`Wooooo0007ooooo`X0
oooo100000050?ooo`P00000E@3oool00`20P800000000000005000002L0oooo1@00000Y0?ooo`L0
0000EP3oool7000000030820P0000000000000<0000000<0P8200?ooo`3oool01@3oool9ooooo`00
1oooool;0?ooo`@00000103oool8000005D0oooo00<0P8200000000000001@00000W0?ooo`030820
P000000000000080000000<0P8200?ooo`3oool09P3oool7000005H0oooo1`0000000`20P800oooo
00000004000000L0oooo2Oooool000Oooooo303oool01@20P8000000000000000000P8200080oooo
2000001E0?ooo`030820P0000000000000D00000:03oool00`20P800000000000002000000030820
P03oool0oooo02D0oooo1`00001F0?ooo`L0000000@0P8200?ooo`3oool0P820100000000`20P800
oooo0?ooo`030?ooo`Wooooo0007ooooo`d0oooo00<0P8200000000000000P0000000`3oool00000
00000006000005D0oooo00<0P8200000000000001@00000Z0?ooo`D000009P3oool7000005H0oooo
1`0000000`20P800oooo0?ooo`020?ooo`D00000103oool9ooooo`001oooool>0?ooo`@0000000<0
P8200000000000001P00001E0?ooo`030820P0000000000000D00000:`3oool5000002D0oooo1`00
001F0?ooo`L0000000<0P8200?ooo`3oool00`3oool5000000<0oooo2Oooool000Oooooo3`3oool<
000005D0oooo00<0P8200000000000001@00000/0?ooo`D00000903oool7000005H0oooo1`000000
0`20P800oooo0?ooo`030?ooo`030820P000000000000080000000<0P8200?ooo`3oool02Oooool0
00Oooooo403oool;000005D0oooo00<0P8200000000000001@00000/0?ooo`030820P00000000000
0080000000<0P8200?ooo`3oool08@3oool7000005H0oooo1`0000000`20P800oooo0?ooo`040?oo
o`D000000P3oool9ooooo`001ooooolA0?ooo`X00000E@3oool00`20P800000000000006000002`0
oooo1@00000S0?ooo`L00000EP3oool7000000030820P03oool0oooo00D0oooo1@0000000`3ooooo
ooooooooo`07ooooo`001ooooolB0?ooo`030410@0000000000000H00000E@3oool00`20P8000000
00000007000000030<30`03oool0oooo02T0oooo00<0P8200000000000000P0000000`20P800oooo
0?ooo`0O0?ooo`L00000EP3oool7000000030820P03oool0oooo00H0oooo00<0P820000000000000
0P000009ooooo`001ooooolC0?ooo`P00000E@3oool00`20P800000000000008000002d0oooo1@00
000P0?ooo`L00000EP3oool7000000030820P03oool0oooo00P0oooo0`000009ooooo`001ooooolC
0?ooo`P00000E@3oool00`20P800000000000009000002d0oooo1@00000O0?ooo`L00000EP3oool7
000000030820P03oool0oooo00P0oooo00<0P8200000000000002Oooool000Oooooo4`3oool80000
05D0oooo00<0P8200000000000002P00000/0?ooo`030820P0000000000000<000007P3oool70000
05H0oooo1`0000000`20P800oooo0?ooo`090?ooo`8000002Oooool000Oooooo4`3oool8000005D0
oooo00<0P8200000000000001@0000000`3oool0000000000003000002`0oooo1@0000000`20P800
oooo0?ooo`0K0?ooo`L00000EP3oool7000000030820P03oool0oooo00X0oooo00<00000oooooooo
ool01oooool000Oooooo4`3oool8000005D0oooo00<0P8200000000000001@0000020?ooo`030410
@000000000000080000000<0P8200?ooo`3oool0:@3oool00`20P800000000000002000000030820
P03oool0oooo01X0oooo1`00001F0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooo
oolC0?ooo`P00000E@3oool00`20P800000000000005000000<0oooo1@0000000`20P800oooo0?oo
o`0Z0?ooo`D000006`3oool7000005H0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007
oooooa<0oooo2000001E0?ooo`030820P0000000000006400000EP3oool7000000030820P03oool0
oooo00/0oooo2Oooool000Oooooo4`3oool8000005D0oooo00<0P820000000000000H@00001F0?oo
o`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooooolC0?ooo`P00000E@3oool00`20P800
00000000001Q000005H0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo
2000001E0?ooo`030820P0000000000006400000EP3oool7000000030820P03oool0oooo00/0oooo
2Oooool000Oooooo4`3oool8000005D0oooo00<0P820000000000000H@00001F0?ooo`L0000000<0
P8200?ooo`3oool02`3oool9ooooo`001ooooolC0?ooo`P00000E@3oool00`20P80000000000001Q
000005H0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo2000001E0?oo
o`030820P0000000000006400000EP3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oo
oooo4`3oool800000?l0oooo403oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo
4`3oool800000?l0oooo403oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3o
ool800000?l0oooo403oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8
00000?l0oooo403oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool80000
0?l0oooo403oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool800000?l0
oooo403oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool800000?l0oooo
403oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool800000?l0oooo403o
ool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool800000?l0oooo403oool7
000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool800000?l0oooo403oool70000
00030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool800000?l0oooo403oool700000003
0820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool800000?l0oooo403oool7000000030820
P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool800000?l0oooo403oool7000000030820P03o
ool0oooo00/0oooo2Oooool000Oooooo00<000000?ooo`3oool0403oool800000?l0oooo403oool7
000000030820P03oool0oooo00/0oooo2Oooool000Oooooo0P00000A0?ooo`P00000o`3oool@0?oo
o`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001oooool2000000030820P03oool0oooo00h0
oooo2000003o0?oooa00oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007ooooo`<00000
403oool800000?l0oooo403oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo1000
00000`20P800oooo0?ooo`0<0?ooo`P00000o`3oool@0?ooo`L0000000<0P8200?ooo`3oool02`3o
ool9ooooo`001oooool00`3oool0000000000003000000d0oooo2000003o0?oooa00oooo1`000000
0`20P800oooo0?ooo`0;0?ooo`Wooooo0007ooooo`80oooo1@00000<0?ooo`P00000o`3oool@0?oo
o`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001oooool20?ooo`030820P000000000000080
000000<0P8200?ooo`3oool02@3oool800000?l0oooo403oool7000000030820P03oool0oooo00/0
oooo2Oooool000Oooooo0`3oool5000000/0oooo2000003o0?oooa00oooo1`0000000`20P800oooo
0?ooo`0;0?ooo`Wooooo0007ooooo`@0oooo00<0P8200000000000000P0000000`20P800oooo0?oo
o`070?ooo`P00000o`3oool@0?ooo`P0000000<0P8200?ooo`3oool02P3oool9ooooo`001oooool6
0?ooo`D00000203oool800000?l0oooo403oool:000000/0oooo2Oooool000Oooooo1`3oool50000
00L0oooo2000003o0?oooa00oooo2`00000:0?ooo`Wooooo0007ooooo`L0oooo00<0P82000000000
00000`0000060?ooo`P00000o`3oool@0?ooo``000002@3oool9ooooo`001oooool80?ooo`D00000
00<0P8200?ooo`3oool00`3oool800000?l0oooo403oool=000000P0oooo2Oooool000Oooooo2@3o
ool00`20P800000000000002000000030820P03oool0oooo0080oooo2000003o0?oooa00oooo1`00
00020820P0@0000000<0@4100?ooo`3oool01@3oool9ooooo`001oooool;0?ooo`D000000`3oool8
00000?l0oooo403oool7000000030820P03oool0oooo00D000001P3oool9ooooo`001oooool<0?oo
o`D000000P3oool800000?l0oooo403oool7000000040820P03oool0oooo0?ooo`D000001@3oool9
ooooo`001oooool=0?ooo`D0000000<0oooo0000000000001P00003o0?oooa00oooo1`0000000`20
P800oooo0?ooo`020?ooo`D00000103oool9ooooo`001oooool=0?ooo`030820P000000000000080
000000<0P8200000000000001P00003o0?oooa00oooo1`0000000`20P800oooo0?ooo`030?ooo`D0
00000`3oool9ooooo`001oooool>0?ooo`d00000o`3oool@0?ooo`L0000000<0P8200?ooo`3oool0
0`3oool00`20P800000000000002000000030820P03oool0oooo00Wooooo0007ooooo`l0oooo00<0
P8200000000000002@00003o0?oooa00oooo1`0000000`20P800oooo0?ooo`040?ooo`030820P000
000000000080000000<0P8200?ooooooool02?ooool000Oooooo4@3oool:00000?l0oooo403oool7
000000030820P03oool0oooo00H0oooo1@000009ooooo`001ooooolB0?ooo`T00000o`3oool@0?oo
o`L0000000<0P8200?ooo`3oool01`3oool4000000Wooooo0007oooooa80oooo00<0P82000000000
00001P00003o0?oooa00oooo1`0000000`20P800oooo0?ooo`080?ooo`<000002Oooool000Oooooo
4`3oool800000?l0oooo403oool7000000030820P03oool0oooo00P0oooo00<0P820000000000000
2Oooool000Oooooo4`3oool800000?l0oooo403oool7000000030820P03oool0oooo00T0oooo00<0
P82000000?ooool02?ooool000Oooooo4`3oool800000?l0oooo403oool7000000030820P03oool0
oooo00/0oooo2Oooool000Oooooo4`3oool800000?l0oooo403oool7000000030820P03oool0oooo
00/0oooo2Oooool000Oooooo4`3oool800000?l0oooo403oool7000000030820P03oool0oooo00/0
oooo2Oooool000Oooooo4`3oool8000008@0oooo00<0P8200000000000000P0000050?ooo`030820
P0000000000007h0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo2000
00230?ooo`030820P0000000000000@0000000@0P8200?ooo`3oool0P8201@0000000`20P800oooo
0?ooo`1i0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooooolC0?ooo`P00000PP3o
ool5000000<0oooo1P0000030?ooo`030000003oool0oooo07T0oooo1`0000000`20P800oooo0?oo
o`0;0?ooo`Wooooo0007oooooa<0oooo200000220?ooo`@000001P3oool4000007l0oooo1`000000
0`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo200000220?ooo`<00000203oool30000
07l0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo200000220?ooo`<0
0000203oool3000007l0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo
200000220?ooo`030820P0000000000000P0oooo0`00001o0?ooo`L0000000<0P8200?ooo`3oool0
2`3oool9ooooo`001ooooolC0?ooo`P00000Q03oool2000000L0oooo0`00001o0?ooo`L0000000<0
P8200?ooo`3oool02`3oool9ooooo`001ooooolC0?ooo`P00000Q03oool00`20P800000000000006
0?ooo`<00000O`3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool80000
08D0oooo0`0000050?ooo`<00000O`3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oo
oooo4`3oool8000008P0oooo00<000000820P03oool00P3oool3000007l0oooo1`0000000`20P800
oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo200000290?ooo`040820P000000000000?ooo`<0
0000O`3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000008`0oooo
00@0P8200000000000000000O`3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo
4`3oool8000008@0oooo00<000000?ooo`3oool01P3oool3000007l0oooo1`0000000`20P800oooo
0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo200000230?ooo`<000001`3oool3000007l0oooo1`00
00000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo200000230?ooo`<000001`3oool3
000007l0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo200000230?oo
o`<000001`3oool200000800oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0
oooo200000240?ooo`030410@0000000P82000@0oooo00@0P820000000000000@410P03oool70000
00030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000008L0oooo1P0000220?ooo`L0
000000<0P8200?ooo`3oool02`3oool9ooooo`001ooooolC0?ooo`P000008@3oool200000<X0oooo
00<0P8200000000000007`3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo00<0
00000?ooo`3oool0403oool8000001l0oooo1@0000390?ooo`D0000000<0P8200?ooo`3oool06P3o
ool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo0P00000A0?ooo`P00000703oool8
00000<T0oooo2000000J0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001oooool20000
00030410@03oool0oooo00h0oooo2000000G0?ooo`<0P8202P0000000`20P800oooo0?ooo`350?oo
o`030820P0000000000000P0000000<0@4100820P03oool05@3oool7000000030820P03oool0oooo
00/0oooo2Oooool000Oooooo1000000?0?ooo`P000005@3oool@00000<L0oooo400000000`20P800
oooo0?ooo`0@0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001oooool5000000h0oooo
2000000B0?oooa<00000a`3ooolC00000100oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo
0007ooooo`030?ooo`000000000000<000003@3oool800000100oooo5P0000350?oooaL000003@3o
ool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo0P3oool5000000`0oooo2000000=
0?oooaT00000a@3ooolH000000`0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooo
o`80oooo00<0`<300000000000000P0000000`10@400oooo0?ooo`090?ooo`P000002@3oool30820
P1X00000a@20P80K000000030820P030`<00oooo00H0oooo1`0000000`20P800oooo0?ooo`0;0?oo
o`Wooooo0007ooooo`@0oooo1@00000:0?ooo`P000001P3oool00`20P80000000000003o000000<0
0000103oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo1@3oool5000000T0oooo
200000050?ooool00000200000030?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooo
ool60?ooo`D00000203oool8000000L0ooooo`000003000000H0oooo2000000=0?ooo`Wooooo0007
ooooo`L0oooo1@0000070?ooo`P000002P3oooom000000P0oooo2@00000<0?ooo`Wooooo0007oooo
o`L0oooo00<0P8200000000000000`0000060?ooo`P00000303oool00`20P80000000000000G0000
0<H0oooo6000000;0?ooo`X000002`3oool9ooooo`001oooool80?ooo`030820P000000000000080
000000<0@4100?ooo`3oool00`3oool8000000l0oooo0P20P8000`10@40000000000000B00000<H0
oooo4`0000030820P0d0oooo2`0000000`20P800oooo0?ooo`070?ooo`Wooooo0007ooooo`X0oooo
1@0000040?ooo`P000005@3oool@00000<L0oooo400000000`20P800oooo0?ooo`0@0?ooo`d00000
203oool9ooooo`001oooool;0?ooo`D000000`3oool8000001L0oooo3P0000380?ooo`d000005@3o
ool7000000030820P0000000000000<0000000<0P8200?ooo`3oool01@3oool9ooooo`001oooool<
0?ooo`D000000P3oool8000001X0oooo2`0000380?ooo`X0000000<0P8200?ooo`3oool05@3oool7
000000030820P03oool0000000@000001`3oool9ooooo`001oooool=0?ooo`D0000000<0oooo0000
000000001P00000L0?ooo`P00000b@3oool8000001X0oooo1`0000000`20P800oooo0?ooo`050000
00H0oooo2Oooool000Oooooo3@3oool00`30`<00000000000002000000030410@0000000000000H0
00007`3oool20820P0030410@000000000000<T0oooo00<0@4100000000000000P20P8000`30`<00
oooo0?ooo`0J0?ooo`L0000000D0P8200?ooo`3oool0oooo0820P004000000030820P03oool0oooo
0080oooo2Oooool000Oooooo3`3oool<00000?l0oooo403oool7000000030820P03oool0oooo00<0
oooo1@0000030?ooo`Wooooo0007oooooa00oooo2`00003o0?oooa00oooo1`0000000`20P800oooo
0?ooo`030?ooo`030820P000000000000080000000<0P8200?ooo`3oool02Oooool000Oooooo4@3o
ool:00000?l0oooo403oool7000000030820P03oool0oooo00@0oooo1@0000020?ooo`Wooooo0007
oooooa80oooo2@00003o0?oooa00oooo1`0000000`20P800oooo0?ooo`050?ooo`D0000000<0oooo
ooooooooool01oooool000Oooooo4P3oool00`30`<0000000000000600000?l0oooo403oool70000
00030820P03oool0oooo00H0oooo00<0P8200000000000000P000009ooooo`001ooooolC0?ooool0
00007`0000000`20P800oooo0?ooo`080?ooo`<000002Oooool000Oooooo4`3ooooo000001l00000
00<0P8200?ooo`3oool0203oool00`20P800000000000009ooooo`001ooooolC0?ooool000007`00
00000`20P800oooo0?ooo`090?ooo`8000002Oooool000Oooooo4`3ooooo000001l0000000<0P820
0?ooo`3oool02P3oool00`00003oooooooooo`07ooooo`001ooooolC0?ooool000007`0000000`20
P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0ooooo`00000O000000030820P03oool0oooo00/0
oooo2Oooool000Oooooo4`3ooooo000001l0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooo
oolK0?ooo`D00000:`3oool00`20P800000000000003000002`0oooo1000000^0?ooo`D00000:`3o
ool5000002h0oooo1@00000X0?ooo`Wooooo0007oooooa`0oooo1@00000[0?ooo`D0000000<0P820
0?ooo`3oool0:P3oool4000002d0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`0Y
0?ooo`D00000;@3oool00`20P800000000000002000000030820P03oool0oooo02D0oooo2Oooool0
00Oooooo703oool00`30`<00000000000002000000030410@03oool0oooo02T0oooo00<0P8200000
000000000P0000000`20P800oooo0?ooo`0Z0?ooo`050820P0000000000000000020P800;03oool0
0`20P800000000000002000000030820P03oool0oooo02T0oooo00<0P8200000000000000P000000
0`20P800oooo0?ooo`0Z0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0903oool9
ooooo`001ooooolN0?ooo`D00000;03oool5000002`0oooo00<0P8200000000000000P00000]0?oo
o`D00000;03oool5000002d0oooo1@00000U0?ooo`Wooooo0007oooooal0oooo1@00000/0?ooo`D0
0000;03oool4000000030820P03oool0oooo02/0oooo1@00000[0?ooo`030820P000000000000080
000000<0P8200?ooo`3oool0:`3oool5000002@0oooo2Oooool000Oooooo803oool5000002`0oooo
1@00000/0?ooo`@00000;P3oool5000002/0oooo1@00000^0?ooo`D000008`3oool9ooooo`001ooo
oolQ0?ooo`D00000:`3oool00`20P800000000000002000000030820P03oool0oooo02X0oooo1000
000]0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0:@3oool5000002d0oooo00<0
P8200000000000000`00000R0?ooo`Wooooo0007ooooob40oooo00<0P8200000000000000`00000[
0?ooo`D00000;@3oool4000002d0oooo1@00000/0?ooo`D00000;@3oool5000000030820P03oool0
oooo01l0oooo2Oooool000Oooooo8P3oool00`20P800000000000002000000030410@03oool0oooo
02T0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`0Z0?ooo`050410@00000000000
00000020P800;03oool00`20P800000000000002000000030820P03oool0oooo02T0oooo00<0P820
0000000000000P0000000`20P800oooo0?ooo`0Z0?ooo`030820P000000000000080000000<0P820
0?ooo`3oool07P3oool9ooooo`001ooooolT0?ooo`D00000;03oool5000002`0oooo100000000`20
P800oooo0?ooo`0[0?ooo`D00000:`3oool00`20P800000000000002000000030820P03oool0oooo
02/0oooo1@00000O0?ooo`Wooooo0007ooooobD0oooo1@00000/0?ooo`D00000;03oool4000002h0
oooo1@00000[0?ooo`D00000;P3oool5000001h0oooo2Oooool000Oooooo9P3oool5000002/0oooo
00<0P8200000000000000P0000000`20P800oooo0?ooo`0Z0?ooo`@00000;@3oool00`20P8000000
00000002000000030820P03oool0oooo02T0oooo1@00000^0?ooo`D000007@3oool9ooooo`001ooo
oolW0?ooo`D00000:`3oool5000002d0oooo1000000]0?ooo`D00000;03oool5000002d0oooo00<0
P8200000000000000P0000000`20P800oooo0?ooo`0J0?ooo`Wooooo0007ooooobL0oooo00<0`<30
0000000000000P0000000`10@400oooo0?ooo`0Y0?ooo`030820P000000000000080000000<0P820
0?ooo`3oool0:P3oool01@10@4000000000000000000P82002`0oooo00<0P8200000000000000P00
00000`20P800oooo0?ooo`0Y0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0:P3o
ool00`20P800000000000002000000030820P03oool0oooo01T0oooo2Oooool000Oooooo:@3oool5
000002`0oooo1@00000/0?ooo`@0000000<0P8200?ooo`3oool0:`3oool5000002/0oooo00<0P820
0000000000000`00000]0?ooo`D000006P3oool9ooooo`001ooooolZ0?ooo`D00000;03oool50000
02`0oooo1000000^0?ooo`D00000:`3oool5000000030820P03oool0oooo02/0oooo1@00000I0?oo
o`Wooooo003ooooooe3ooooo003ooooooe3ooooo003ooooooe3ooooo003ooooooe3ooooo003ooooo
oe3ooooo003ooooooe3ooooo003ooooooe3ooooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{111.875, 111.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 6.16 Exercise (12).", "Caption",
  CellTags->"Fig. 6.16"],

Cell[TextData[{
  StyleBox["(13)",
    FontWeight->"Bold"],
  " Redo the previous problem but now calculate the first three nondegenerate \
transverse electric (TE) modes for the waveguide using the grid method . \
These modes satisfy ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Del]\_ \[UpTee] \%2 B\_z\  = \ \((k\^2 - \
\[Omega]\^2/c\^2)\) B\_z\)\(,\)\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`B\_z\)]],
  " is the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-component of the magnetic field, subject to von Neumann boundary \
conditions at the surface of the waveguide,",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            RowBox[{
              FormBox[
                OverscriptBox[
                  StyleBox["n",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "^"],
                "TraditionalForm"], "\[CenterDot]", \(\[Del]B\_z\)}], "=", 
            "0"}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(14)",
    FontWeight->"Bold"],
  " A hydrogen atom is placed in a uniform electric field ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["E",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[
            RowBox[{"E", "  ", 
              OverscriptBox[
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "^"]}],
            FontWeight->"Plain"]}], TraditionalForm]]],
  ". The electron eigenfunction  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](r, \[Theta])\)]],
  " (in spherical coordinates) satisfies Schr\[ODoubleDot]dinger's equation,  \
Eq. ",
  ButtonBox["(4.4.35)",
    ButtonData:>{"Chapter4.nb", "(4.4.35)"},
    ButtonStyle->"Hyperlink"],
  ",   with Hamiltonian operator"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`H\&^ = \(-\(1\/2\)\) \[Del]\^2\(-\(1\/r\)\) + \ 
          V(r, \[Theta])\)]],
  ", "
}], "NE3",
  CellTags->"(6.3.33)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`V(
          r, \[Theta])\  = \ \[Epsilon]\ r\ cos\ \[Theta]\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\  = \ m\ E\ a\^3/\[HBar]\^2\)]],
  ", and where distances are measured in units of the Bohr radius ",
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            \(TraditionalForm\`a = 
              4\ \[Pi]\ \(\[Epsilon]\_\(\(o\)\(\ \)\)\) \[HBar]\^2/
                  m\ e\^2\)]]]], TraditionalForm]]],
  ", and energies are measured in units of ",
  Cell[BoxData[
      \(TraditionalForm\`e\^2/\((4\ \[Pi]\ \[Epsilon]\_o\ a)\)\)]],
  ". Use a 20 by 20 grid in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((r, \[Theta])\)\)]],
  " plane with ",
  Cell[BoxData[
      \(TraditionalForm\`0 < r < 5\ a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`0 < \[Theta] < \[Pi]\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Show that for cylindrically symmetric modes the correct boundary \
conditions are ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\[Psi]/\[PartialD]r = \(-\[Psi]\)/2\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\[Psi]/\[PartialD]\[Theta] = 0\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] = 0, \[Pi]\)]],
  ". Use a Dirichlet condition at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 5  a\)]],
  ", and set up the proper grid so that the solution has second-order \
accuracy in the grid spacing."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Determine the change in ground-state energy of the atom as a function of \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  " by taking ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon] = n/10\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0, 1, 2, 3\)]],
  ". (This energy shift is called the Stark effect).  For each case plot the \
ground state eigenfunction vs. ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " along the lines ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Theta] = 0\)\(,\)\(\[Pi]/2\)\(,\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\)]],
  ". Plot the energies vs. ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " and compare with the theoretical result from perturbation theory (see \
below),"
}], "Text",
  CellTags->"i:49"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`E\_1 = E\_1\^\((0)\) - \ 9\ \ \[Epsilon]\^2/4\)]],
  ","
}], "NE3",
  CellTags->"(6.3.34)"],

Cell[TextData[{
  " correct only for small ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n\^\((0)\) = \(-1\)/\((2\ n\^2)\)\)]],
  " is the unperturbed energy of the hydrogen atom. (Hint: You will have to \
ignore the great many positive unphysical eigenvalues, and pick out the \
ground state eigenvalue from the list by hand as it varies with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  ". )"
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " What is happening to the electron wave function as ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " increases? What do you think would happen to the electron if there were \
no boundary at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 5  a\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  " were increased even further?"
}], "Text"],

Cell[TextData[{
  StyleBox["(15)",
    FontWeight->"Bold"],
  " A hydrogen atom is placed in a uniform ",
  StyleBox["magnetic",
    FontSlant->"Italic"],
  " field ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["B",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[\(B\ z\&^\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  ". Neglecting spin effects, the electron eigenfunction for the ground \
state,  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](r, \[Theta])\)]],
  " (in spherical coordinates), still satisfies Eqs. ",
  ButtonBox["(4.4.35)",
    ButtonData:>{"Chapter4.nb", "(4.4.35)"},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(6.4.33)",
    ButtonData:>"(6.4.33)",
    ButtonStyle->"Hyperlink"],
  ", but now the perturbation potential is ",
  Cell[BoxData[
      \(TraditionalForm\`V(
          r, \[Theta])\  = \ \(\(1\/8\) \(\((\[Beta]\ \ r\ sin\ \
\[Theta])\)\^2\)\(\ \)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] = \(\@\(\(4\ \[Pi]\ \[Epsilon]\_o\ \
a\^3\)\/\(m\ c\^2\)\)\) B\)]],
  " is a scaled magnetic field, and we are using the same energy and length \
scales as in the previous exercise. Using a 20-by-20 grid in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((r, \[Theta])\)\)]],
  " plane with ",
  Cell[BoxData[
      \(TraditionalForm\`0 < r < 5\ a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`0 < \[Theta] < \[Pi]\)]],
  ", determine the ground-state energy of the atom as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  " by taking ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] = \(\(n\ /5\)\(\ \)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0, 1, 2, 3\)]],
  ". (This effect is called the Zeemann shift.)  For each case plot the \
ground-state eigenfunction vs. ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " along the lines ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Theta] = 0\)\(,\)\(\[Pi]/2\)\(,\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\)]],
  ". Compare your energies with the perturbation theory result (see below), "
}], "Text",
  CellTags->"i:50"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`E\_\(\(1\)\(\ \)\) = \ 
        E\_1\^\((0)\)\  + \ \ \[Beta]\^2\)]],
  "."
}], "NE3",
  CellTags->"(6.3.35)"],

Cell[TextData[{
  StyleBox["(16)",
    FontWeight->"Bold"],
  " Eigenmode problems involving Hamiltonian operators of the type given by \
Eq. ",
  ButtonBox["(6.3.33)",
    ButtonData:>"(6.3.33)",
    ButtonStyle->"Hyperlink"],
  " are also amenable to the Galerkin method. Consider an operator ",
  Cell[BoxData[
      \(TraditionalForm\`H\&^ = H\&^\_o + V\&^\)]],
  " . The eigenstates  of ",
  Cell[BoxData[
      \(TraditionalForm\`H\&^\_o\)]],
  " are assumed  to be known, and ",
  Cell[BoxData[
      \(TraditionalForm\`V\&^\)]],
  " is some perturbation that changes the eigenstates. We will use the \
Galerkin method to determine the new eigenstates for the problem, choosing \
for basis functions the eigenmodes ",
  Cell[BoxData[
      \(TraditionalForm\`v\_n\)]],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`H\&^\_o\)]],
  ". These eigenmodes satisfy"
}], "Text",
  CellTags->"i:51"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`H\&^\_o\ v\_n\  = \ \(E\_n\^\((0)\)\) v\_n\)]],
  ",\nwhere ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n\^\((0)\)\)]],
  " is the unperturbed energy of the system."
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Show that with this choice, the matrix ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[ScriptCapitalL]",
            FontWeight->"Bold"], "\[Congruent]", 
          RowBox[{
            StyleBox[
              SuperscriptBox["S", 
                StyleBox[\(-1\),
                  FontWeight->"Plain"]],
              FontWeight->"Bold"], "\[CenterDot]", 
            StyleBox["L",
              FontWeight->"Bold",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  " of the associated eigenvalue problem [see  Eq. ",
  ButtonBox["(6.3.11)",
    ButtonData:>"(6.3.11)",
    ButtonStyle->"Hyperlink"],
  "] has the following form:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalL]\_\(m\ n\) = \(\[Delta]\_\(m\ n\)\) 
            E\_n\^\((0)\) + \((v\_m, V\&^\ v\_n)\)\/\((v\_m, v\_m)\)\)]],
  "."
}], "NE3",
  CellTags->"(6.3.36)"],

Cell[TextData[{
  "            ",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Repeat Exercise (14), but this time use the Galerkin method, along with \
Eq. ",
  ButtonBox["(6.3.36)",
    ButtonData:>"(6.3.36)",
    ButtonStyle->"Hyperlink"],
  ". For basis functions take the eigenfunctions of the unperturbed hydrogen \
atom, Eq. ",
  ButtonBox["(4.4.37)",
    ButtonData:>{"Chapter4.nb", "(4.4.37)"},
    ButtonStyle->"Hyperlink"],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`n \[LessEqual] \ 4\)]],
  ", and use the inner product ",
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\) = \[Integral]\[DifferentialD]\^3 r\ \(f\^*\)\ g\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "            ",
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Repeat Exercise (15) using the Galerkin method, using the same basis \
functions and inner product as in (b)."
}], "Text"],

Cell[TextData[{
  StyleBox["(17)",
    FontWeight->"Bold"],
  " ",
  StyleBox["Perturbation theory. ",
    FontSlant->"Italic"],
  "Equation ",
  ButtonBox["(6.3.36)",
    ButtonData:>"(6.3.36)",
    ButtonStyle->"Hyperlink"],
  " can be used to obtain analytic results for the shift in the eigenstates \
in the limit that the perturbation ",
  Cell[BoxData[
      \(TraditionalForm\`V\&^\)]],
  " is weak. ",
  StyleBox[" ",
    FontSlant->"Italic"],
  "We will assume for simplicity that the set  of basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`v\_n\)]],
  " is ",
  StyleBox["orthonormal,",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\((v\_m, v\_n)\) = \[Delta]\_\(m\ n\)\)]],
  ". Recall that eigenvectors ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["c",
            FontWeight->"Bold",
            FontSlant->"Plain"], "n"], TraditionalForm]]],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalL]\)]],
  " are used to determine the eigenfunctions ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_n\)]],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`H\&^\)]],
  " according to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_n = \[Sum]\+m\( c\_m\%n\) v\_n\)]],
  ". Let us assume that these eigenvectors are normalized so that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                SuperscriptBox[
                  StyleBox["c",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "n"], ")"}], "*"], "\[CenterDot]", 
            SuperscriptBox[
              StyleBox["c",
                FontWeight->"Bold",
                FontSlant->"Plain"], "n"]}], "=", "1"}], TraditionalForm]]],
  ".  Also, choose the phase of the eigenfunctions so that ",
  Cell[BoxData[
      \(TraditionalForm\`c\_n\%n\)]],
  " is real. Then if the perturbation ",
  Cell[BoxData[
      \(TraditionalForm\`V\&^\)]],
  " is weak,  we can write the components of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            StyleBox["c",
              FontWeight->"Bold",
              FontSlant->"Plain"], "n"], " "}], TraditionalForm]]],
  "as"
}], "Text",
  CellTags->"i:52"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(c\_m\%n\), " ", "=", " ", 
          RowBox[{\(\[Delta]\_\(m\ n\)\), " ", "+", " ", 
            SubsuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["c",
                    FontSlant->"Italic"]}]], "m", "n"]}]}], 
        TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(6.3.37)"],

Cell[TextData[{
  " where ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["c",
                FontSlant->"Italic"]}]], "m", "n"], TraditionalForm]]],
  " is a small correction, of order ",
  Cell[BoxData[
      \(TraditionalForm\`V\&^\)]],
  ".  Equation ",
  ButtonBox["(6.3.37)",
    ButtonData:>"(6.3.37)",
    ButtonStyle->"Hyperlink"],
  "  is merely a statement that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_n\  \[Rule] \ v\_n\)]],
  "in the limit that ",
  Cell[BoxData[
      \(TraditionalForm\`V\&^ \[Rule] \ 0\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Using Eq. ",
  ButtonBox["(6.3.37)",
    ButtonData:>"(6.3.37)",
    ButtonStyle->"Hyperlink"],
  "  together with the normalization condition ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  SuperscriptBox[
                    StyleBox["c",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "n"], ")"}], "*"], "\[CenterDot]", 
              
              SuperscriptBox[
                StyleBox["c",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "n"]}], "=", "1"}]}], 
        TraditionalForm]]],
  ",  show that ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["c",
                FontSlant->"Italic"]}]], "n", "n"], TraditionalForm]]],
  " is ",
  StyleBox["second",
    FontSlant->"Italic"],
  "-",
  StyleBox["order",
    FontSlant->"Italic"],
  " in the perturbation ",
  Cell[BoxData[
      \(TraditionalForm\`V\&^\)]],
  ", and in particular,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubsuperscriptBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["c",
                  FontSlant->"Italic"]}]], "n", "n"], "=", 
          RowBox[{\(-\(1\/2\)\), 
            RowBox[{\(\[Sum]\+\(k \[NotEqual] \ n\)\), 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"|", 
                    SubsuperscriptBox[
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["c",
                            FontSlant->"Italic"]}]], "k", "n"], "|"}], ")"}], 
                "2"]}]}]}], TraditionalForm]]],
  ". "
}], "NE3",
  CellTags->"(6.3.38)"],

Cell[TextData[{
  "\t",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " The energy levels ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n\)]],
  " are the eigenvalues corresponding to ",
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[
              SuperscriptBox[
                StyleBox["c",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "n"], TraditionalForm]]]]], 
        TraditionalForm]]],
  "; that is,   ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["\[ScriptCapitalL]",
              FontWeight->"Bold"], "\[CenterDot]", 
            SuperscriptBox[
              StyleBox["c",
                FontWeight->"Bold",
                FontSlant->"Plain"], "n"]}], "=", 
          RowBox[{\(E\_n\), 
            SuperscriptBox[
              StyleBox["c",
                FontWeight->"Bold",
                FontSlant->"Plain"], "n"]}]}], TraditionalForm]]],
  ". Taking the ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{
              StyleBox["n",
                FontSlant->"Italic"], "th"}]], " "}], TraditionalForm]]],
  "component of this vector equation, and using Eqs. ",
  ButtonBox["(6.3.6)",
    ButtonData:>"(6.3.6)",
    ButtonStyle->"Hyperlink"],
  " - ",
  ButtonBox["(6.3.8)",
    ButtonData:>"(6.3.8)",
    ButtonStyle->"Hyperlink"],
  ", show that "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(E\_n - E\_n\^\((0)\)\), "=", 
          FractionBox[
            RowBox[{\(V\_\(n\ n\)\), " ", "+", 
              RowBox[{\(\[Sum]\+k\), 
                RowBox[{\(V\_\(n\ k\)\), 
                  SubsuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["c",
                          FontSlant->"Italic"]}]], "k", "n"]}]}]}], 
            RowBox[{"1", " ", "+", " ", 
              SubsuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["c",
                      FontSlant->"Italic"]}]], "n", "n"]}]]}], 
        TraditionalForm]]],
  ", "
}], "NE3",
  CellTags->"(6.3.39)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`V\_\(m\ n\) \[Congruent] \((v\_m, V\&^\ v\_n)\)\)]],
  ". Working only to first",
  "-order",
  " in the perturbation ",
  Cell[BoxData[
      \(TraditionalForm\`V\&^\)]],
  ", use this equation to show that "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`E\_n = 
        E\_n\^\((0)\) + V\_\(n\ n\) + 0 \((V\&^\^2)\)\)]],
  "."
}], "NE3",
  CellTags->{"i:53", "(6.3.40)"}],

Cell[TextData[{
  "\t",
  StyleBox["(c) ",
    FontWeight->"Bold"],
  "Use Eq. ",
  ButtonBox["(6.3.40)",
    ButtonData:>"(6.3.40)",
    ButtonStyle->"Hyperlink"],
  " to derive Eq. ",
  ButtonBox["(6.3.35)",
    ButtonData:>"(6.3.35)",
    ButtonStyle->"Hyperlink"],
  ". (Remember to use ",
  StyleBox["orthonormal",
    FontSlant->"Italic"],
  " basis functions.)"
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Use Eq. ",
  ButtonBox["(6.3.40)",
    ButtonData:>"(6.3.40)",
    ButtonStyle->"Hyperlink"],
  " to show that the Stark shift must be second-order in the applied electric \
field \[Epsilon]. [In order to derive Eq. ",
  ButtonBox["(6.3.34)",
    ButtonData:>"(6.3.34)",
    ButtonStyle->"Hyperlink"],
  "  second-order perturbation theory must be applied. See below.]"
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(e)",
    FontWeight->"Bold"],
  " Taking the ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            StyleBox["j",
              FontSlant->"Italic"], "th"}]], TraditionalForm]]],
  " component of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["\[ScriptCapitalL]",
              FontWeight->"Bold"], "\[CenterDot]", 
            SuperscriptBox[
              StyleBox["c",
                FontWeight->"Bold",
                FontSlant->"Plain"], "n"]}], "=", 
          RowBox[{\(E\_n\), 
            SuperscriptBox[
              StyleBox["c",
                FontWeight->"Bold",
                FontSlant->"Plain"], "n"]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j \[NotEqual] \ n\)]],
  ", show that "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\((E\_n - E\_j\^\((0)\))\), 
            SubsuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["c",
                    FontSlant->"Italic"]}]], "j", "n"]}], "=", 
          RowBox[{\(V\_\(j\ n\)\), "+", 
            RowBox[{\(\[Sum]\+k\), 
              RowBox[{\(V\_\(j\ k\)\), 
                SubsuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["c",
                        FontSlant->"Italic"]}]], "k", "n"], " "}]}]}]}], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j \[NotEqual] \ n\)]],
  "."
}], "NE3",
  CellTags->"(6.3.41)"],

Cell[TextData[{
  "\t",
  StyleBox["(f)",
    FontWeight->"Bold"],
  " To first-order in ",
  Cell[BoxData[
      \(TraditionalForm\`V\&^\)]],
  " this equation implies that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubsuperscriptBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["c",
                  FontSlant->"Italic"]}]], "j", "n"], 
          "=", \(\(V\_\(j\ n\)\)\(/\)\)}], TraditionalForm]]],
  Cell[BoxData[
      \(TraditionalForm\`\((E\_n\^\((0)\) - E\_j\^\((0)\))\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j \[NotEqual] \ n\)]],
  ". This provides us with the first-order shift in the eigenfunction. Use \
this result in Eq. ",
  ButtonBox["(6.3.39)",
    ButtonData:>"(6.3.39)",
    ButtonStyle->"Hyperlink"],
  " to show that, to ",
  StyleBox["second",
    FontSlant->"Italic"],
  "-order",
  StyleBox[" in ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(V\&^\)\(\ \)\)\)]],
  ","
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n = 
        E\_n\^\((0)\) + 
          V\_\(n\ n\) + \[Sum]\+\(k \[NotEqual] \ n\)\(\(V\_\(n\ k\)\) V\_\(k\
\ n\)\)\/\(E\_n\^\((0)\) - E\_k\^\((0)\)\) + \ 0 \((V\&^\^3)\)\)]],
  "."
}], "NE3",
  CellTags->{"i:54", "(6.3.42)"}],

Cell[TextData[{
  "\t",
  StyleBox["(g)",
    FontWeight->"Bold"],
  " Use Eq. ",
  ButtonBox["(6.3.42)",
    ButtonData:>"(6.3.42)",
    ButtonStyle->"Hyperlink"],
  " to derive the Stark shift, Eq. ",
  ButtonBox["(6.3.34)",
    ButtonData:>"(6.3.34)",
    ButtonStyle->"Hyperlink"],
  ". [Hint: Note that ",
  Cell[BoxData[
      \(TraditionalForm\`cos\ \[Theta]\)]],
  " is proportional to the spherical harmonic ",
  Cell[BoxData[
      \(TraditionalForm\`\(Y\_\(1\ 0\)\)(\[Theta], \[Phi])\)]],
  ".]"
}], "Text"],

Cell[TextData[{
  "[Note: Equations ",
  ButtonBox["(6.3.38)",
    ButtonData:>"(6.3.38)",
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["(6.3.39)",
    ButtonData:>"(6.3.39)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(6.3.41)",
    ButtonData:>"(6.3.41)",
    ButtonStyle->"Hyperlink"],
  " are exact and can be employed to create  a recursive procedure for \
finding the shift in energy levels and eigenvalues to ",
  StyleBox["any order",
    FontSlant->"Italic"],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`V\&^\)]],
  ".  This is left as an exercise for the interested reader. The method is \
analogous to that used to solve a nonlinear equation in one variable, \
outlined in Exercise (4), Sec. ",
  ButtonBox["5.2",
    ButtonData:>{"Chapter5.nb", "i:97"},
    ButtonStyle->"Hyperlink"],
  ".  However, in most cases it is easier to simply solve directly for the \
eigenvalues and eigenvectors of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalL]\)]],
  ",  as in  the previous problem. Also, note that in Eq. ",
  ButtonBox["(6.3.42)",
    ButtonData:>"(6.3.42)",
    ButtonStyle->"Hyperlink"],
  " we assumed that the energy levels are not degenerate; ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n\^\((0)\) \[NotEqual] \ E\_k\^\((0)\)\)]],
  "for ",
  Cell[BoxData[
      \(TraditionalForm\`n \[NotEqual] \ \(\(k\)\(.\)\)\)]],
  " Degenerate cases can also be handled, but will not be discussed here. \
See, for example, ",
  ButtonBox["Landau and Lifshitz (1981)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ".]"
}], "Text",
  CellTags->"i:55"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "Subtitle",
  CellTags->{"c:45", "refs"}],

Cell[TextData[{
  "Klaus-Jurgen Bathe, ",
  StyleBox["Finite Element Procedures",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "(Prentice Hall, Englwood Cliffs NJ, 1996)"
}], "Text"],

Cell[TextData[{
  "P. Hunter and A. Pullan, ",
  StyleBox["FEM/BEM Notes",
    FontSlant->"Italic"],
  ", at ",
  "http://www.esc.auckland.ac.nz/Academic/Texts/FEM-BEM-notes.html",
  ". "
}], "Text"],

Cell[TextData[{
  "L.D. Landau and E. M. Lifshitz, ",
  StyleBox["Quantum Mechanics (Nonrelativistic Theory) ",
    FontSlant->"Italic"],
  "(Pergamon Press, Oxford,  1981) "
}], "Text"],

Cell[TextData[{
  "W.H. Press, S.A. Teukolsky, W. T. Vetterling, and B. P. Flannery, ",
  StyleBox["Numerical Recipes",
    FontSlant->"Italic"],
  ", 2nd ed. (Cambridge Press,  Cambridge, 1992)."
}], "Text"],

Cell[TextData[{
  "H. G. Winful, ",
  StyleBox["Nature of \"superluminal\" barrier tunneling",
    FontSlant->"Italic"],
  ", Phys. Rev. Lett. ",
  StyleBox["90",
    FontWeight->"Bold"],
  ", 023901-1 (2003)."
}], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 746}},
ShowPageBreaks->False,
WindowToolbars->{},
WindowSize->{800, 556},
WindowMargins->{{1, Automatic}, {Automatic, 0}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Inherited, Inherited, Cell[ 
        TextData[ {"Chapter 6, Section 6.", 
          CounterBox[ "Subtitle"]}], "Header"]}, {Cell[ 
        TextData[ "Dubin"], "Header"], Cell[ 
        TextData[ 
        "Numerical and Analytical Methods for Scientists and Engineers"], 
        FontWeight -> Bold, FontSlant -> Italic, FontFamily -> Times], 
      Inherited}},
TaggingRules:>{"NextIndexingNumber" -> 71, "IndexEntries" -> {{"i:17", {"Grid \
methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}}, {"i:2", "Galerkin method"}, \
{"i:49", "Stark effect"}, {"i:50", "Zeeman shift"}, {"i:52", "Perturbation \
theory"}, {"i:57", "Galerkin, Boris G."}, {"i:58", "Von Neumann, John"}, \
{"i:59", 
  StyleBox[ 
  "Do", FontWeight -> 
    "Bold"]}, {"i:61", "Jacobi, Carl Gustav Jacob"}, {"i:64", 
  StyleBox[ 
  "Boole", FontWeight -> 
    "Bold"]}, {"i:65", "Courant condition"}, {"i:66", "Courant condition"}, \
{"i:68", "Finite element methods"}, {"i:70", "Unset"}, {"i:1", "Partial \
differential equations", {"numerical solution (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Numerical solution of partial differential equations)"}}, \
{"i:13", "Galerkin method", "module, for time-dependent problems"}, {"i:15", \
"Velocity", "superluminal"}, {"i:16", "Shroedinger's equation", "tunneling"}, \
{"i:17", "Numerical solution of PDEs", {"grid methods (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Grid methods)"}}, {"i:17", "Recursion relation", {"used to \
solve PDEs (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Relaxation methods, Grid methods)"}}, {"i:18", {"Grid methods \
(", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "FTCS method"}, {"i:19", {"Grid \
methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "von Neumann stability \
analysis"}, {"i:20", {"Grid methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "CTCS method"}, {"i:21", {"Grid \
methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "Lax method"}, {"i:22", {"Grid \
methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "implicit methods"}, {"i:23", \
{"Grid methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "Crank-Nicholson method"}, \
{"i:24", "Boundary conditions", {"in grid methods (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Grid methods)"}}, {"i:25", {"Grid methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "explicit methods"}, {"i:26", \
{"Grid methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "CTCS for wave equation in 2 \
dimensions"}, {"i:27", {"Grid methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "operator splitting"}, {"i:29", \
{"Grid methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "for boundary value problems"}, \
{"i:3", "Differential operators", "matrix form by projection onto basis \
functions"}, {"i:30", {"Grid methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "direct soluton of BVP's"}, \
{"i:32", "Recursion relation", {"used to solve PDEs (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Relaxation methods, Grid methods)"}}, {"i:32", "Relaxation \
methods", {
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Grid methods"}}, {"i:32", {"Grid methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "relaxation methods for \
BVP's"}, {"i:33", {"Grid methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "Jacobi method"}, {"i:34", \
{"Grid methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "simultaneous overrelaxation"}, \
{"i:36", {"Grid methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "FFT method"}, {"i:38", {"Grid \
methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "boundary condition at \
origin"}, {"i:39", "Eigenmodes", "numerical"}, {"i:39", "Numerical solution \
of PDEs", {"numerical eigenmodes (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Eigenmodes, numerical)"}}, {"i:4", "Galerkin method", "for \
time-independent boundary value problems"}, {"i:40", "Eigenmodes", \
"numerical, via shooting method"}, {"i:40", "Shooting method", "for numerical \
eigenmodes"}, {"i:41", "Eigenmodes", "numerical, via Galerkin method"}, \
{"i:41", "Galerkin method", "numerical eigenmodes"}, {"i:42", "Eigenmodes", \
"numerical, via grid method"}, {"i:42", "Grid method", "numerical \
eigenmodes"}, {"i:43", "Eigenmodes", "WKB method"}, {"i:43", "WKB method", \
"for eigenmodes"}, {"i:44", "WKB method", {"near turning points (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Turning points)"}}, {"i:45", "Turning points", "effect on WKB \
eigenvalues"}, {"i:46", "Shooting method", "for problems with turning \
points"}, {"i:47", "Eigenmodes", "of drumheads with arbitrary shape"}, \
{"i:48", "Eigenmodes", "of drumheads with arbitrary shape"}, {"i:5", \
"Galerkin method", "basis functions"}, {"i:52", "Eigenmodes", {"perturbed \
quantum (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Perturbation theory)"}}, {"i:52", "Shroedinger's equation", \
{"eigenmodes, perturbed (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Perturbation theory)"}}, {"i:53", "Perturbation theory", \
"first order energy shift"}, {"i:54", "Perturbation theory", "second order \
energy shift"}, {"i:55", "Perturbation theory", "degenerate"}, {"i:55", \
"Recursion relation", "for perturbed energy levels"}, {"i:56", "Shooting \
method", "for problems with turning points"}, {"i:6", "Inner product", \
"choice of, in Galerkin method"}, {"i:60", "Shroedinger's equation", \
"numerical solution"}, {"i:62", {"Grid methods ", "(", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Numerical solution of ODEs)"}, "non-rectangular \
boundaries"}, {"i:63", "Integration", {"over arbitrary regions (using ", 
  StyleBox[ "Boole", FontWeight -> "Bold"], ")"}}, {"i:67", 
  StyleBox[ 
  "Plot3D", FontWeight -> "Bold"], {"over arbitrary regions (using ", 
  StyleBox[ 
  "Boole", FontWeight -> 
    "Bold"], ")"}}, {"i:69", "Grid methods", "alternating direction implicit \
method"}, {"i:7", "Galerkin method", "boundary curves, smooth vs. cusps"}, \
{"i:1", "Numerical solution of PDEs", "", ""}, {"i:11", "Galerkin method", \
"for time-dependent PDEs", ""}, {"i:12", {"Basis functions (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Galerkin method)"}, "for mixed boundary conditions", ""}, \
{"i:14", {"Wavefunction (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Shroedinger's equation, Eigenmodes)"}, "behavior of, in \
reflection from a barrier", ""}, {"i:2", "Numerical solution of PDEs", \
{"Galerkin method (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Galerkin method)"}, ""}, {"i:24", {"Grid methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "boundary conditions, von \
Neumann and mixed", ""}, {"i:28", {"Snell's law (", 
  StyleBox[ 
  "see", FontSlant -> 
    "Italic"], " WKB method, Ray trajectories)"}, "and lensing effect", ""}, \
{"i:31", {"Grid methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "non-rectangular boundaries", \
""}, {"i:36", "FFTs", "for boundary value problems", ""}, {"i:37", {"Basis \
functions (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Galerkin method)"}, "boundary condition at origin", ""}, \
{"i:5", "Function(s)", {"basis (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Basis functions, Galerkin method)"}, ""}, {"i:5", {"Basis \
functions (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Galerkin method)"}, "", ""}, {"i:51", "Galerkin method", {"for \
perturbed quantum systems (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Perturbation theory)"}, ""}, {"i:52", "Energy", {"levels, \
perturbed (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Perturbation theory)"}, ""}, {"i:8", "Galerkin method", \
"module, for time-independent problems", ""}, {"i:9", {"Basis functions (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Galerkin method)"}, "in presence of a convex cusp", ""}}},
CellLabelAutoDelete->True,
LineSpacing->{1.1, 0},
ScriptSizeMultipliers->0.85,
Magnification->1.25,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsection"],
  
  Cell[StyleData[All, "Working"],
    CellBracketOptions->{"Color"->RGBColor[0, 0.2, 1]},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->30,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {2, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 4}},
    FontSize->18,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {2, 12}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", 
                BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 8}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->15,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->12]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{20, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{47, 62}, {0, 14}},
    CellFrameMargins->5,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{34, 62}, {0, 14}},
    CellFrameColor->GrayLevel[0.700008],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{56, 4}, {3, 9}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[0, 1, 1]],
  
  Cell[StyleData["Input", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {3, 8}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10,
    Background->None]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{57, 4}, {5, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Output", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    Background->None]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["Message", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{56, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{40, 4}, {4, 2}},
    ImageSize->{250, 250},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->7,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(6.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE2"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(6.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE2"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE2",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE2", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE3"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(6.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE3"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE3",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE3", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE4"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(6.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE4"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE4",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE4", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UNNEQ"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, None}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE6",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["UNNEQ", "Printout"],
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextTop"],
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{10, 4}, {2, 80}},
    CellHorizontalScrolling->True,
    CellFrameMargins->4,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["TextTop", "Printout"],
    CellMargins->{{2, 4}, {2, 80}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 4},
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["IndentedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Note"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Note", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.39, 0.59}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.325}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.23,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.145, 0.345, 0.145, 0.345}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.195}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.23, 0.13, 0.13, 0.23, 0.13}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 50}, {0, 3}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 50}, {2, 4}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    GridBoxOptions->{ColumnWidths->{0.39, 0.59},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.325,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "i:1"->{
    Cell[1727, 52, 117, 4, 111, "Title",
      CellTags->{"i:1", "c:1"}]},
  "c:1"->{
    Cell[1727, 52, 117, 4, 111, "Title",
      CellTags->{"i:1", "c:1"}]},
  "i:2"->{
    Cell[1888, 62, 71, 1, 39, "Subtitle",
      CellTags->{"i:2", "c:2"}]},
  "c:2"->{
    Cell[1888, 62, 71, 1, 39, "Subtitle",
      CellTags->{"i:2", "c:2"}]},
  "c:3"->{
    Cell[2003, 69, 60, 1, 41, "Subsubtitle",
      CellTags->"c:3"]},
  "i:57"->{
    Cell[2066, 72, 1257, 28, 146, "Text",
      CellTags->"i:57"]},
  "Fig. 6.1"->{
    Cell[46491, 640, 233, 5, 29, "Caption",
      CellTags->"Fig. 6.1"]},
  "i:4"->{
    Cell[46761, 650, 80, 1, 41, "Subsubtitle",
      CellTags->{"i:4", "c:4"}]},
  "c:4"->{
    Cell[46761, 650, 80, 1, 41, "Subsubtitle",
      CellTags->{"i:4", "c:4"}]},
  "c:5"->{
    Cell[46866, 655, 44, 1, 42, "Section",
      CellTags->"c:5"]},
  "(6.1.1)"->{
    Cell[47016, 663, 159, 5, 33, "NumberedEquation",
      CellTags->"(6.1.1)"]},
  "(6.1.2)"->{
    Cell[47742, 691, 161, 5, 29, "NumberedEquation",
      CellTags->"(6.1.2)"]},
  "(6.1.3)"->{
    Cell[48375, 713, 154, 5, 29, "NumberedEquation",
      CellTags->"(6.1.3)"]},
  "i:5"->{
    Cell[48711, 728, 463, 16, 44, "Text",
      CellTags->"i:5"]},
  "(6.1.4)"->{
    Cell[49177, 746, 148, 5, 29, "NumberedEquation",
      CellTags->"(6.1.4)"]},
  "(6.1.5)"->{
    Cell[49427, 758, 232, 7, 29, "NumberedEquation",
      CellTags->"(6.1.5)"]},
  "(6.1.6)"->{
    Cell[50299, 789, 250, 7, 38, "NumberedEquation",
      CellTags->"(6.1.6)"]},
  "(6.1.7)"->{
    Cell[50729, 806, 249, 7, 38, "NumberedEquation",
      CellTags->"(6.1.7)"]},
  "(6.1.8)"->{
    Cell[52387, 862, 300, 8, 33, "NumberedEquation",
      CellTags->"(6.1.8)"]},
  "(6.1.9)"->{
    Cell[52759, 874, 148, 5, 30, "NumberedEquation",
      CellTags->"(6.1.9)"]},
  "i:6"->{
    Cell[53560, 904, 80, 1, 27, "Text",
      CellTags->"i:6"]},
  "(6.1.10)"->{
    Cell[53643, 907, 240, 7, 44, "NumberedEquation",
      CellTags->"(6.1.10)"]},
  "(6.1.11)"->{
    Cell[56480, 996, 399, 11, 40, "NumberedEquation",
      CellTags->"(6.1.11)"]},
  "i:3"->{
    Cell[57395, 1027, 903, 27, 92, "Text",
      CellTags->"i:3"]},
  "(6.1.12)"->{
    Cell[58301, 1056, 208, 6, 32, "NumberedEquation",
      CellTags->"(6.1.12)"]},
  "i:7"->{
    Cell[60370, 1118, 1132, 30, 116, "Text",
      CellTags->"i:7"]},
  "c:6"->{
    Cell[63125, 1192, 47, 1, 31, "Section",
      CellTags->"c:6"]},
  "(6.1.13)"->{
    Cell[63993, 1217, 213, 6, 39, "NumberedEquation",
      CellTags->"(6.1.13)"]},
  "Cell 6.1"->{
    Cell[64487, 1236, 169, 4, 72, "Input",
      CellTags->"Cell 6.1"]},
  "Cell 6.2"->{
    Cell[65274, 1258, 154, 4, 67, "Input",
      CellTags->"Cell 6.2"]},
  "Cell 6.3"->{
    Cell[65853, 1282, 125, 3, 67, "Input",
      CellTags->"Cell 6.3"]},
  "Cell 6.4"->{
    Cell[66519, 1310, 123, 3, 67, "Input",
      CellTags->"Cell 6.4"]},
  "Cell 6.5"->{
    Cell[66844, 1323, 153, 4, 67, "Input",
      CellTags->"Cell 6.5"]},
  "Cell 6.6"->{
    Cell[67201, 1337, 156, 4, 67, "Input",
      CellTags->"Cell 6.6"]},
  "Cell 6.7"->{
    Cell[69157, 1401, 220, 5, 86, "Input",
      CellTags->"Cell 6.7"]},
  "i:59"->{
    Cell[69380, 1408, 699, 22, 62, "Text",
      CellTags->"i:59"]},
  "Cell 6.8"->{
    Cell[70082, 1432, 216, 6, 86, "Input",
      CellTags->"Cell 6.8"]},
  "Cell 6.9"->{
    Cell[71314, 1476, 152, 4, 67, "Input",
      CellTags->"Cell 6.9"]},
  "Cell 6.10"->{
    Cell[71919, 1502, 138, 3, 67, "Input",
      CellTags->"Cell 6.10"]},
  "Cell 6.11"->{
    Cell[72412, 1522, 129, 3, 67, "Input",
      CellTags->"Cell 6.11"]},
  "Cell 6.12"->{
    Cell[73590, 1556, 207, 5, 86, "Input",
      CellTags->"Cell 6.12"]},
  "Cell 6.13"->{
    Cell[73974, 1573, 188, 4, 67, "Input",
      CellTags->"Cell 6.13"]},
  "Cell 6.14"->{
    Cell[176699, 3553, 321, 6, 105, "Input",
      CellTags->"Cell 6.14"]},
  "Cell 6.15"->{
    Cell[578502, 11442, 180, 4, 86, "Input",
      CellTags->"Cell 6.15"]},
  "c:7"->{
    Cell[582845, 11538, 47, 1, 31, "Section",
      CellTags->"c:7"]},
  "Cell 6.16"->{
    Cell[583321, 11555, 92, 3, 67, "Input",
      CellTags->"Cell 6.16"]},
  "Cell 6.17"->{
    Cell[583438, 11562, 251, 6, 97, "Input",
      CellTags->"Cell 6.17"]},
  "i:64"->{
    Cell[732344, 19500, 587, 14, 78, "Text",
      CellTags->"i:64"]},
  "i:8"->{
    Cell[733207, 19526, 121, 4, 27, "Text",
      CellTags->"i:8"]},
  "Cell 6.18"->{
    Cell[733331, 19532, 3019, 76, 298, "Input",
      CellTags->"Cell 6.18"]},
  "Cell 6.19"->{
    Cell[736353, 19610, 3348, 67, 480, "Input",
      CellTags->"Cell 6.19"]},
  "Cell 6.20"->{
    Cell[739864, 19688, 97, 3, 67, "Input",
      CellTags->"Cell 6.20"]},
  "Cell 6.21"->{
    Cell[816202, 21537, 386, 8, 105, "Input",
      CellTags->"Cell 6.21"]},
  "Cell 6.22"->{
    Cell[927675, 25077, 106, 3, 67, "Input",
      CellTags->"Cell 6.22"]},
  "Cell 6.23"->{
    Cell[927990, 25092, 265, 7, 86, "Input",
      CellTags->"Cell 6.23"]},
  "c:8"->{
    Cell[1306110, 32526, 47, 1, 31, "Section",
      CellTags->"c:8"]},
  "Cell 6.24"->{
    Cell[1306945, 32559, 493, 10, 184, "Input",
      CellTags->"Cell 6.24"]},
  "(6.1.14)"->{
    Cell[1450637, 40194, 517, 13, 42, "NumberedEquation",
      CellTags->"(6.1.14)"]},
  "Cell 6.25"->{
    Cell[1452222, 40244, 360, 10, 116, "Input",
      CellTags->"Cell 6.25"]},
  "Cell 6.26"->{
    Cell[1452816, 40262, 601, 13, 162, "Input",
      CellTags->"Cell 6.26"]},
  "Cell 6.27"->{
    Cell[1453927, 40296, 303, 6, 86, "Input",
      CellTags->"Cell 6.27"]},
  "Cell 6.28"->{
    Cell[1486570, 41199, 174, 4, 67, "Input",
      CellTags->"Cell 6.28"]},
  "i:9"->{
    Cell[1509279, 41697, 422, 11, 61, "Text",
      CellTags->"i:9"]},
  "Cell 6.29"->{
    Cell[1510802, 41744, 3392, 82, 295, "Input",
      CellTags->"Cell 6.29"]},
  "Cell 6.30"->{
    Cell[1514753, 41845, 102, 3, 67, "Input",
      CellTags->"Cell 6.30"]},
  "Cell 6.31"->{
    Cell[1547210, 42645, 437, 9, 97, "Input",
      CellTags->"Cell 6.31"]},
  "Fig. 6.2"->{
    Cell[1913168, 49852, 640, 18, 17, "Caption",
      CellTags->"Fig. 6.2"]},
  "Fig. 6.3"->{
    Cell[1943388, 50675, 651, 18, 30, "Caption",
      CellTags->"Fig. 6.3"]},
  "i:11"->{
    Cell[1945031, 50722, 81, 1, 30, "Subsubtitle",
      CellTags->{"i:11", "c:9"}]},
  "c:9"->{
    Cell[1945031, 50722, 81, 1, 30, "Subsubtitle",
      CellTags->{"i:11", "c:9"}]},
  "c:10"->{
    Cell[1945137, 50727, 56, 1, 42, "Section",
      CellTags->"c:10"]},
  "(6.1.15)"->{
    Cell[1945503, 50739, 248, 7, 42, "NumberedEquation",
      CellTags->"(6.1.15)"]},
  "(6.1.16)"->{
    Cell[1945810, 50750, 206, 4, 57, "NumberedEquation",
      CellTags->"(6.1.16)"]},
  "(6.1.17)"->{
    Cell[1946063, 50758, 137, 5, 29, "NumberedEquation",
      CellTags->"(6.1.17)"]},
  "(6.1.18)"->{
    Cell[1946267, 50767, 211, 7, 33, "NumberedEquation",
      CellTags->"(6.1.18)"]},
  "(6.1.19)"->{
    Cell[1946675, 50784, 180, 6, 29, "NumberedEquation",
      CellTags->"(6.1.19)"]},
  "i:12"->{
    Cell[1946888, 50794, 570, 16, 61, "Text",
      CellTags->"i:12"]},
  "(6.1.20)"->{
    Cell[1948206, 50838, 215, 7, 35, "NumberedEquation",
      CellTags->"(6.1.20)"]},
  "Cell 6.32"->{
    Cell[1948673, 50860, 227, 5, 116, "Input",
      CellTags->"Cell 6.32"]},
  "(6.1.21)"->{
    Cell[1976787, 51612, 191, 6, 34, "NumberedEquation",
      CellTags->"(6.1.21)"]},
  "(6.1.22)"->{
    Cell[1977462, 51639, 399, 9, 42, "NumberedEquation",
      CellTags->"(6.1.22)"]},
  "(6.1.23)"->{
    Cell[1978005, 51657, 264, 5, 42, "NumberedEquation",
      CellTags->"(6.1.23)"]},
  "(6.1.24)"->{
    Cell[1978524, 51675, 455, 11, 42, "NumberedEquation",
      CellTags->"(6.1.24)"]},
  "(6.1.25)"->{
    Cell[1979700, 51714, 210, 6, 33, "NumberedEquation",
      CellTags->"(6.1.25)"]},
  "(6.1.26)"->{
    Cell[1980171, 51731, 289, 9, 33, "NumberedEquation",
      CellTags->"(6.1.26)"]},
  "Cell 6.33"->{
    Cell[1985536, 51914, 236, 5, 124, "Input",
      CellTags->"Cell 6.33"]},
  "Cell 6.34"->{
    Cell[1986210, 51938, 106, 3, 67, "Input",
      CellTags->"Cell 6.34"]},
  "Cell 6.35"->{
    Cell[1986724, 51957, 163, 4, 67, "Input",
      CellTags->"Cell 6.35"]},
  "Cell 6.36"->{
    Cell[1987087, 51971, 120, 3, 67, "Input",
      CellTags->"Cell 6.36"]},
  "Cell 6.37"->{
    Cell[1987405, 51983, 127, 3, 67, "Input",
      CellTags->"Cell 6.37"]},
  "Cell 6.38"->{
    Cell[1988097, 52004, 275, 6, 86, "Input",
      CellTags->"Cell 6.38"]},
  "Cell 6.39"->{
    Cell[1988605, 52022, 178, 5, 67, "Input",
      CellTags->"Cell 6.39"]},
  "Cell 6.40"->{
    Cell[1988896, 52034, 262, 6, 86, "Input",
      CellTags->"Cell 6.40"]},
  "Cell 6.41"->{
    Cell[1989253, 52046, 137, 3, 67, "Input",
      CellTags->"Cell 6.41"]},
  "Cell 6.42"->{
    Cell[2020598, 52951, 315, 6, 124, "Input",
      CellTags->"Cell 6.42"]},
  "Cell 6.43"->{
    Cell[2030397, 53253, 161, 5, 67, "Input",
      CellTags->"Cell 6.43"]},
  "Cell 6.44"->{
    Cell[2030655, 53265, 125, 3, 67, "Input",
      CellTags->"Cell 6.44"]},
  "Cell 6.45"->{
    Cell[2030960, 53277, 401, 9, 124, "Input",
      CellTags->"Cell 6.45"]},
  "Cell 6.46"->{
    Cell[2031535, 53298, 299, 7, 105, "Input",
      CellTags->"Cell 6.46"]},
  "i:13"->{
    Cell[2699935, 75761, 109, 4, 27, "Text",
      CellTags->"i:13"]},
  "Cell 6.47"->{
    Cell[2700047, 75767, 5708, 118, 850, "Input",
      CellTags->"Cell 6.47"]},
  "i:14"->{
    Cell[2705792, 75890, 97, 1, 31, "Section",
      CellTags->{"i:14", "c:11"}]},
  "c:11"->{
    Cell[2705792, 75890, 97, 1, 31, "Section",
      CellTags->{"i:14", "c:11"}]},
  "(6.1.27)"->{
    Cell[2706527, 75912, 334, 9, 42, "NumberedEquation",
      CellTags->"(6.1.27)"]},
  "(6.1.28)"->{
    Cell[2706928, 75925, 147, 5, 29, "NumberedEquation",
      CellTags->"(6.1.28)"]},
  "(6.1.29)"->{
    Cell[2707236, 75941, 553, 15, 45, "NumberedEquation",
      CellTags->"(6.1.29)"]},
  "(6.1.30)"->{
    Cell[2708257, 75972, 337, 11, 38, "NumberedEquation",
      CellTags->"(6.1.30)"]},
  "(6.1.31)"->{
    Cell[2708766, 75993, 492, 11, 42, "NumberedEquation",
      CellTags->"(6.1.31)"]},
  "(6.1.32)"->{
    Cell[2709548, 76017, 195, 6, 34, "NumberedEquation",
      CellTags->"(6.1.32)"]},
  "(6.1.33)"->{
    Cell[2710170, 76039, 337, 9, 42, "NumberedEquation",
      CellTags->"(6.1.33)"]},
  "(6.1.34)"->{
    Cell[2710678, 76057, 351, 9, 37, "NumberedEquation",
      CellTags->"(6.1.34)"]},
  "(6.1.35)"->{
    Cell[2711233, 76076, 200, 6, 42, "NumberedEquation",
      CellTags->"(6.1.35)"]},
  "(6.1.36)"->{
    Cell[2712008, 76104, 472, 10, 38, "NumberedEquation",
      CellTags->"(6.1.36)"]},
  "Cell 6.48"->{
    Cell[2712688, 76123, 104, 3, 67, "Input",
      CellTags->"Cell 6.48"]},
  "Cell 6.49"->{
    Cell[2715087, 76206, 3458, 69, 626, "Input",
      CellTags->"Cell 6.49"]},
  "Cell 6.50"->{
    Cell[2719133, 76300, 123, 3, 67, "Input",
      CellTags->"Cell 6.50"]},
  "Cell 6.51"->{
    Cell[4636786, 123676, 342, 7, 112, "Input",
      CellTags->"Cell 6.51"]},
  "i:16"->{
    Cell[5562894, 156004, 1019, 24, 112, "Text",
      CellTags->"i:16"]},
  "i:15"->{
    Cell[5565133, 156064, 650, 13, 95, "Text",
      CellTags->"i:15"]},
  "c:12"->{
    Cell[5566771, 156104, 65, 1, 30, "Subsubtitle",
      CellTags->"c:12"]},
  "Fig. 6.4"->{
    Cell[5589083, 156396, 65, 1, 16, "Caption",
      CellTags->"Fig. 6.4"]},
  "Fig. 6.5"->{
    Cell[5625059, 156896, 65, 1, 16, "Caption",
      CellTags->"Fig. 6.5"]},
  "i:37"->{
    Cell[5639079, 157354, 222, 6, 42, "NumberedEquation",
      CellTags->{"i:37", "(6.1.37)"}]},
  "(6.1.37)"->{
    Cell[5639079, 157354, 222, 6, 42, "NumberedEquation",
      CellTags->{"i:37", "(6.1.37)"}]},
  "i:17"->{
    Cell[5640235, 157401, 66, 1, 40, "Subtitle",
      CellTags->{"i:17", "c:13"}]},
  "c:13"->{
    Cell[5640235, 157401, 66, 1, 40, "Subtitle",
      CellTags->{"i:17", "c:13"}]},
  "c:14"->{
    Cell[5640345, 157408, 72, 1, 41, "Subsubtitle",
      CellTags->"c:14"]},
  "i:18"->{
    Cell[5640442, 157413, 82, 1, 42, "Section",
      CellTags->{"i:18", "c:15"}]},
  "c:15"->{
    Cell[5640442, 157413, 82, 1, 42, "Section",
      CellTags->{"i:18", "c:15"}]},
  "(6.2.1)"->{
    Cell[5641262, 157439, 234, 7, 42, "NE2",
      CellTags->"(6.2.1)"]},
  "(6.2.2)"->{
    Cell[5641982, 157464, 775, 24, 45, "NE2",
      CellTags->"(6.2.2)"]},
  "(6.2.3)"->{
    Cell[5644223, 157533, 651, 19, 48, "NE2",
      CellTags->"(6.2.3)"]},
  "(6.2.4)"->{
    Cell[5644926, 157556, 835, 24, 45, "NE2",
      CellTags->"(6.2.4)"]},
  "(6.2.5)"->{
    Cell[5646247, 157600, 909, 25, 39, "NE2",
      CellTags->"(6.2.5)"]},
  "Cell 6.52"->{
    Cell[5648941, 157689, 397, 9, 172, "Input",
      CellTags->"Cell 6.52"]},
  "Cell 6.53"->{
    Cell[5650427, 157736, 225, 5, 86, "Input",
      CellTags->"Cell 6.53"]},
  "Cell 6.54"->{
    Cell[5651045, 157757, 136, 3, 67, "Input",
      CellTags->"Cell 6.54"]},
  "Cell 6.55"->{
    Cell[5652314, 157804, 359, 7, 146, "Input",
      CellTags->"Cell 6.55"]},
  "Cell 6.56"->{
    Cell[5652915, 157824, 386, 9, 105, "Input",
      CellTags->"Cell 6.56"]},
  "i:70"->{
    Cell[6231709, 171806, 2261, 70, 95, "Text",
      CellTags->"i:70"]},
  "Cell 6.57"->{
    Cell[6233995, 171880, 644, 14, 181, "Input",
      CellTags->"Cell 6.57"]},
  "i:19"->{
    Cell[6536124, 177633, 79, 1, 31, "Section",
      CellTags->{"i:19", "c:16"}]},
  "c:16"->{
    Cell[6536124, 177633, 79, 1, 31, "Section",
      CellTags->{"i:19", "c:16"}]},
  "i:58"->{
    Cell[6536206, 177636, 1708, 44, 157, "Text",
      CellTags->"i:58"]},
  "(6.2.6)"->{
    Cell[6539449, 177725, 1025, 28, 39, "NE2",
      CellTags->"(6.2.6)"]},
  "(6.2.7)"->{
    Cell[6540595, 177760, 121, 5, 29, "NE2",
      CellTags->"(6.2.7)"]},
  "(6.2.8)"->{
    Cell[6541341, 177789, 872, 24, 39, "NE2",
      CellTags->"(6.2.8)"]},
  "Fig. 6.6"->{
    Cell[6593470, 179176, 114, 4, 16, "Caption",
      CellTags->"Fig. 6.6"]},
  "(6.2.9)"->{
    Cell[6594829, 179222, 554, 18, 39, "NE2",
      CellTags->"(6.2.9)"]},
  "i:65"->{
    Cell[6595386, 179242, 1996, 63, 97, "Text",
      CellTags->"i:65"]},
  "i:20"->{
    Cell[6597419, 179310, 60, 1, 31, "Section",
      CellTags->{"i:20", "c:17"}]},
  "c:17"->{
    Cell[6597419, 179310, 60, 1, 31, "Section",
      CellTags->{"i:20", "c:17"}]},
  "(6.2.10)"->{
    Cell[6598083, 179328, 928, 25, 39, "NE2",
      CellTags->"(6.2.10)"]},
  "(6.2.11)"->{
    Cell[6599499, 179370, 144, 5, 32, "NE2",
      CellTags->"(6.2.11)"]},
  "Cell 6.58"->{
    Cell[6600662, 179411, 316, 7, 92, "Input",
      CellTags->"Cell 6.58"]},
  "i:21"->{
    Cell[6622983, 180002, 59, 1, 31, "Section",
      CellTags->{"i:21", "c:18"}]},
  "c:18"->{
    Cell[6622983, 180002, 59, 1, 31, "Section",
      CellTags->{"i:21", "c:18"}]},
  "(6.2.12)"->{
    Cell[6624443, 180040, 969, 25, 39, "NE2",
      CellTags->"(6.2.12)"]},
  "Cell 6.59"->{
    Cell[6627572, 180140, 506, 11, 122, "Input",
      CellTags->"Cell 6.59"]},
  "(6.2.13)"->{
    Cell[6680973, 181388, 527, 15, 33, "NE2",
      CellTags->"(6.2.13)"]},
  "i:22"->{
    Cell[6682259, 181427, 96, 1, 31, "Section",
      CellTags->{"i:22", "c:19"}]},
  "c:19"->{
    Cell[6682259, 181427, 96, 1, 31, "Section",
      CellTags->{"i:22", "c:19"}]},
  "(6.2.14)"->{
    Cell[6683216, 181455, 902, 25, 39, "NE2",
      CellTags->"(6.2.14)"]},
  "i:25"->{
    Cell[6684121, 181482, 1194, 36, 107, "Text",
      CellTags->"i:25"]},
  "(6.2.15)"->{
    Cell[6685702, 181533, 638, 18, 35, "NE2",
      CellTags->"(6.2.15)"]},
  "(6.2.16)"->{
    Cell[6687994, 181613, 1146, 30, 39, "NE2",
      CellTags->"(6.2.16)"]},
  "i:23"->{
    Cell[6689143, 181645, 1147, 39, 61, "Text",
      CellTags->"i:23"]},
  "(6.2.17)"->{
    Cell[6690293, 181686, 979, 27, 44, "NE2",
      CellTags->"(6.2.17)"]},
  "Cell 6.60"->{
    Cell[6691850, 181735, 218, 6, 86, "Input",
      CellTags->"Cell 6.60"]},
  "Cell 6.61"->{
    Cell[6692877, 181773, 234, 6, 124, "Input",
      CellTags->"Cell 6.61"]},
  "(6.2.18)"->{
    Cell[6693254, 181786, 226, 7, 36, "NE2",
      CellTags->"(6.2.18)"]},
  "Cell 6.62"->{
    Cell[6695402, 181856, 174, 5, 67, "Input",
      CellTags->"Cell 6.62"]},
  "Cell 6.63"->{
    Cell[6696716, 181897, 1954, 41, 406, "Input",
      CellTags->"Cell 6.63"]},
  "Cell 6.64"->{
    Cell[6700223, 181995, 988, 20, 258, "Input",
      CellTags->"Cell 6.64"]},
  "Cell 6.65"->{
    Cell[6934586, 187979, 264, 7, 124, "Input",
      CellTags->"Cell 6.65"]},
  "Cell 6.66"->{
    Cell[6936186, 188039, 189, 4, 86, "Input",
      CellTags->"Cell 6.66"]},
  "i:24"->{
    Cell[7034158, 189988, 91, 1, 31, "Section",
      CellTags->{"i:24", "c:20"}]},
  "c:20"->{
    Cell[7034158, 189988, 91, 1, 31, "Section",
      CellTags->{"i:24", "c:20"}]},
  "(6.2.19)"->{
    Cell[7034838, 190007, 361, 12, 43, "NE2",
      CellTags->"(6.2.19)"]},
  "(6.2.20)"->{
    Cell[7035327, 190026, 433, 15, 30, "NE2",
      CellTags->"(6.2.20)"]},
  "(6.2.21)"->{
    Cell[7038068, 190115, 407, 15, 30, "NE2",
      CellTags->"(6.2.21)"]},
  "Cell 6.67"->{
    Cell[7041342, 190230, 366, 9, 181, "Input",
      CellTags->"Cell 6.67"]},
  "Cell 6.68"->{
    Cell[7041909, 190249, 157, 4, 86, "Input",
      CellTags->"Cell 6.68"]},
  "Cell 6.69"->{
    Cell[7042255, 190261, 114, 3, 67, "Input",
      CellTags->"Cell 6.69"]},
  "Cell 6.70"->{
    Cell[7042853, 190281, 148, 4, 67, "Input",
      CellTags->"Cell 6.70"]},
  "Cell 6.71"->{
    Cell[7043486, 190301, 1007, 20, 277, "Input",
      CellTags->"Cell 6.71"]},
  "(6.2.22)"->{
    Cell[7287667, 196746, 400, 14, 43, "NE2",
      CellTags->"(6.2.22)"]},
  "(6.2.23)"->{
    Cell[7288223, 196770, 1012, 28, 43, "NE2",
      CellTags->"(6.2.23)"]},
  "(6.2.24)"->{
    Cell[7289981, 196824, 537, 14, 43, "NE2",
      CellTags->"(6.2.24)"]},
  "(6.2.25)"->{
    Cell[7290555, 196842, 1034, 27, 43, "NE2",
      CellTags->"(6.2.25)"]},
  "c:21"->{
    Cell[7291781, 196879, 66, 1, 31, "Section",
      CellTags->"c:21"]},
  "(6.2.26)"->{
    Cell[7292134, 196892, 272, 7, 45, "NE2",
      CellTags->"(6.2.26)"]},
  "(6.2.27)"->{
    Cell[7292816, 196917, 791, 24, 48, "NE2",
      CellTags->"(6.2.27)"]},
  "(6.2.28)"->{
    Cell[7294423, 196974, 1567, 41, 42, "NE2",
      CellTags->"(6.2.28)"]},
  "(6.2.29)"->{
    Cell[7296714, 197035, 1111, 32, 46, "NE2",
      CellTags->"(6.2.29)"]},
  "i:26"->{
    Cell[7298030, 197078, 94, 1, 29, "Subsubsection",
      CellTags->"i:26"]},
  "Cell 6.72"->{
    Cell[7299676, 197140, 442, 9, 168, "Input",
      CellTags->"Cell 6.72"]},
  "Cell 6.73"->{
    Cell[7413867, 199219, 1652, 31, 493, "Input",
      CellTags->"Cell 6.73"]},
  "Cell 6.74"->{
    Cell[7417220, 199298, 612, 13, 246, "Input",
      CellTags->"Cell 6.74"]},
  "Cell 6.75"->{
    Cell[7420874, 199406, 106, 3, 67, "Input",
      CellTags->"Cell 6.75"]},
  "Cell 6.76"->{
    Cell[7421291, 199423, 267, 6, 126, "Input",
      CellTags->"Cell 6.76"]},
  "Cell 6.77"->{
    Cell[7421734, 199441, 354, 8, 105, "Input",
      CellTags->"Cell 6.77"]},
  "i:28"->{
    Cell[20331361, 473836, 932, 22, 95, "Text",
      CellTags->"i:28"]},
  "i:27"->{
    Cell[20332330, 473863, 84, 1, 29, "Subsubsection",
      CellTags->"i:27"]},
  "(6.2.30)"->{
    Cell[20332627, 473872, 737, 18, 38, "NE2",
      CellTags->"(6.2.30)"]},
  "i:69"->{
    Cell[20336403, 473984, 1914, 49, 140, "Text",
      CellTags->"i:69"]},
  "(6.2.31)"->{
    Cell[20338320, 474035, 1121, 29, 83, "NE2",
      CellTags->"(6.2.31)"]},
  "Cell 6.78"->{
    Cell[20341407, 474115, 242, 6, 88, "Input",
      CellTags->"Cell 6.78"]},
  "Cell 6.79"->{
    Cell[20341995, 474133, 862, 17, 261, "Input",
      CellTags->"Cell 6.79"]},
  "(6.2.32)"->{
    Cell[20342932, 474154, 302, 8, 38, "NE2",
      CellTags->"(6.2.32)"]},
  "Cell 6.80"->{
    Cell[20344304, 474202, 267, 7, 88, "Input",
      CellTags->"Cell 6.80"]},
  "Cell 6.81"->{
    Cell[20344687, 474216, 434, 9, 146, "Input",
      CellTags->"Cell 6.81"]},
  "Cell 6.82"->{
    Cell[20345155, 474229, 3653, 77, 652, "Input",
      CellTags->"Cell 6.82"]},
  "Cell 6.83"->{
    Cell[20349389, 474331, 326, 8, 145, "Input",
      CellTags->"Cell 6.83"]},
  "Cell 6.84"->{
    Cell[20349907, 474350, 381, 8, 128, "Input",
      CellTags->"Cell 6.84"]},
  "Cell 6.85"->{
    Cell[21634432, 498849, 1003, 21, 309, "Input",
      CellTags->"Cell 6.85"]},
  "i:29"->{
    Cell[21938123, 506803, 82, 1, 30, "Subsubtitle",
      CellTags->{"i:29", "c:22"}]},
  "c:22"->{
    Cell[21938123, 506803, 82, 1, 30, "Subsubtitle",
      CellTags->{"i:29", "c:22"}]},
  "i:30"->{
    Cell[21938230, 506808, 64, 1, 42, "Section",
      CellTags->{"i:30", "c:23"}]},
  "c:23"->{
    Cell[21938230, 506808, 64, 1, 42, "Section",
      CellTags->{"i:30", "c:23"}]},
  "(6.2.33)"->{
    Cell[21938501, 506817, 208, 6, 45, "NE2",
      CellTags->"(6.2.33)"]},
  "(6.2.34)"->{
    Cell[21940663, 506897, 1086, 31, 45, "NE2",
      CellTags->"(6.2.34)"]},
  "Cell 6.86"->{
    Cell[21942868, 506970, 263, 7, 130, "Input",
      CellTags->"Cell 6.86"]},
  "Cell 6.87"->{
    Cell[21943246, 506984, 245, 6, 126, "Input",
      CellTags->"Cell 6.87"]},
  "Cell 6.88"->{
    Cell[21943643, 506999, 107, 3, 67, "Input",
      CellTags->"Cell 6.88"]},
  "Cell 6.89"->{
    Cell[21943961, 507012, 2818, 62, 192, "Input",
      CellTags->"Cell 6.89"]},
  "Cell 6.90"->{
    Cell[21946892, 507081, 184, 5, 69, "Input",
      CellTags->"Cell 6.90"]},
  "Cell 6.91"->{
    Cell[21947130, 507090, 125, 3, 67, "Input",
      CellTags->"Cell 6.91"]},
  "Cell 6.92"->{
    Cell[21947492, 507104, 271, 7, 107, "Input",
      CellTags->"Cell 6.92"]},
  "Cell 6.93"->{
    Cell[21948104, 507129, 263, 6, 86, "Input",
      CellTags->"Cell 6.93"]},
  "i:31"->{
    Cell[22104643, 510180, 74, 1, 31, "Section",
      CellTags->{"i:31", "c:24"}]},
  "c:24"->{
    Cell[22104643, 510180, 74, 1, 31, "Section",
      CellTags->{"i:31", "c:24"}]},
  "(6.2.35)"->{
    Cell[22105011, 510190, 843, 29, 48, "NE2",
      CellTags->"(6.2.35)"]},
  "(6.2.36)"->{
    Cell[22107094, 510266, 1115, 32, 57, "NE2",
      CellTags->"(6.2.36)"]},
  "Cell 6.94"->{
    Cell[22109109, 510330, 470, 10, 206, "Input",
      CellTags->"Cell 6.94"]},
  "Cell 6.95"->{
    Cell[22109678, 510347, 523, 11, 145, "Input",
      CellTags->"Cell 6.95"]},
  "Cell 6.96"->{
    Cell[22111902, 510418, 337, 9, 86, "Input",
      CellTags->"Cell 6.96"]},
  "(6.2.37)"->{
    Cell[22114623, 510511, 379, 12, 40, "NE2",
      CellTags->"(6.2.37)"]},
  "(6.2.38)"->{
    Cell[22115060, 510527, 426, 14, 40, "NE2",
      CellTags->"(6.2.38)"]},
  "Cell 6.97"->{
    Cell[22115736, 510554, 548, 13, 190, "Input",
      CellTags->"Cell 6.97"]},
  "Cell 6.98"->{
    Cell[22116473, 510579, 369, 8, 128, "Input",
      CellTags->"Cell 6.98"]},
  "i:68"->{
    Cell[22140974, 511127, 1142, 22, 146, "Text",
      CellTags->"i:68"]},
  "Cell 6.99"->{
    Cell[22143245, 511186, 109, 3, 67, "Input",
      CellTags->"Cell 6.99"]},
  "Cell 6.100"->{
    Cell[22143557, 511199, 3221, 68, 241, "Input",
      CellTags->"Cell 6.100"]},
  "Cell 6.101"->{
    Cell[22146828, 511271, 212, 6, 69, "Input",
      CellTags->"Cell 6.101"]},
  "Cell 6.102"->{
    Cell[22147094, 511281, 126, 3, 67, "Input",
      CellTags->"Cell 6.102"]},
  "Cell 6.103"->{
    Cell[22147339, 511293, 225, 6, 107, "Input",
      CellTags->"Cell 6.103"]},
  "Cell 6.104"->{
    Cell[22147904, 511316, 93, 3, 67, "Input",
      CellTags->"Cell 6.104"]},
  "Cell 6.105"->{
    Cell[22148022, 511323, 394, 8, 105, "Input",
      CellTags->"Cell 6.105"]},
  "Fig. 6.7"->{
    Cell[22302041, 516245, 52, 1, 16, "Caption",
      CellTags->"Fig. 6.7"]},
  "i:32"->{
    Cell[22302581, 516265, 67, 1, 31, "Section",
      CellTags->{"i:32", "c:25"}]},
  "c:25"->{
    Cell[22302581, 516265, 67, 1, 31, "Section",
      CellTags->{"i:32", "c:25"}]},
  "i:33"->{
    Cell[22302673, 516270, 60, 1, 27, "Subsubsection",
      CellTags->"i:33"]},
  "(6.2.39)"->{
    Cell[22306880, 516388, 1985, 51, 46, "NE2",
      CellTags->"(6.2.39)"]},
  "i:61"->{
    Cell[22308868, 516441, 1069, 34, 81, "Text",
      CellTags->"i:61"]},
  "Cell 6.106"->{
    Cell[22310057, 516482, 312, 8, 168, "Input",
      CellTags->"Cell 6.106"]},
  "Cell 6.107"->{
    Cell[22310480, 516497, 312, 6, 126, "Input",
      CellTags->"Cell 6.107"]},
  "Cell 6.108"->{
    Cell[22310984, 516513, 571, 11, 247, "Input",
      CellTags->"Cell 6.108"]},
  "Cell 6.109"->{
    Cell[22311845, 516535, 111, 3, 67, "Input",
      CellTags->"Cell 6.109"]},
  "Cell 6.110"->{
    Cell[22312257, 516551, 235, 6, 107, "Input",
      CellTags->"Cell 6.110"]},
  "Cell 6.111"->{
    Cell[22312795, 516571, 396, 8, 164, "Input",
      CellTags->"Cell 6.111"]},
  "Cell 6.112"->{
    Cell[22313533, 516596, 91, 3, 67, "Input",
      CellTags->"Cell 6.112"]},
  "Cell 6.113"->{
    Cell[22313720, 516607, 225, 5, 105, "Input",
      CellTags->"Cell 6.113"]},
  "Cell 6.114"->{
    Cell[22367525, 518183, 266, 7, 107, "Input",
      CellTags->"Cell 6.114"]},
  "Cell 6.115"->{
    Cell[22368135, 518208, 318, 6, 105, "Input",
      CellTags->"Cell 6.115"]},
  "i:34"->{
    Cell[22620764, 523248, 72, 1, 29, "Subsubsection",
      CellTags->"i:34"]},
  "(6.2.40)"->{
    Cell[22623842, 523341, 2810, 66, 46, "NE2",
      CellTags->"(6.2.40)"]},
  "Cell 6.116"->{
    Cell[22629413, 523480, 4177, 78, 934, "Input",
      CellTags->"Cell 6.116"]},
  "Cell 6.117"->{
    Cell[22633615, 523562, 93, 3, 67, "Input",
      CellTags->"Cell 6.117"]},
  "Cell 6.118"->{
    Cell[22634441, 523591, 256, 6, 124, "Input",
      CellTags->"Cell 6.118"]},
  "i:36"->{
    Cell[22670942, 524686, 59, 1, 31, "Section",
      CellTags->{"i:36", "c:26"}]},
  "c:26"->{
    Cell[22670942, 524686, 59, 1, 31, "Section",
      CellTags->{"i:36", "c:26"}]},
  "(6.2.41)"->{
    Cell[22674163, 524787, 369, 6, 40, "NE2",
      CellTags->"(6.2.41)"]},
  "(6.2.42)"->{
    Cell[22674557, 524797, 417, 9, 40, "NE2",
      CellTags->"(6.2.42)"]},
  "(6.2.43)"->{
    Cell[22676493, 524854, 179, 3, 44, "NE2",
      CellTags->"(6.2.43)"]},
  "Cell 6.119"->{
    Cell[22680925, 525003, 285, 8, 149, "Input",
      CellTags->"Cell 6.119"]},
  "Cell 6.120"->{
    Cell[22681643, 525024, 154, 4, 67, "Input",
      CellTags->"Cell 6.120"]},
  "Cell 6.121"->{
    Cell[22681997, 525038, 134, 3, 69, "Input",
      CellTags->"Cell 6.121"]},
  "Cell 6.122"->{
    Cell[22682368, 525057, 229, 5, 86, "Input",
      CellTags->"Cell 6.122"]},
  "Cell 6.123"->{
    Cell[22800267, 527214, 223, 5, 69, "Input",
      CellTags->"Cell 6.123"]},
  "Cell 6.124"->{
    Cell[22800671, 527229, 118, 3, 67, "Input",
      CellTags->"Cell 6.124"]},
  "Cell 6.125"->{
    Cell[22800992, 527243, 101, 3, 67, "Input",
      CellTags->"Cell 6.125"]},
  "Cell 6.126"->{
    Cell[22801641, 527265, 110, 3, 67, "Input",
      CellTags->"Cell 6.126"]},
  "Cell 6.127"->{
    Cell[22802014, 527281, 303, 7, 117, "Input",
      CellTags->"Cell 6.127"]},
  "Cell 6.128"->{
    Cell[22802512, 527298, 204, 5, 75, "Input",
      CellTags->"Cell 6.128"]},
  "Cell 6.129"->{
    Cell[22803073, 527318, 130, 3, 73, "Input",
      CellTags->"Cell 6.129"]},
  "Cell 6.130"->{
    Cell[22804000, 527346, 325, 7, 88, "Input",
      CellTags->"Cell 6.130"]},
  "Cell 6.131"->{
    Cell[22804969, 527380, 238, 5, 86, "Input",
      CellTags->"Cell 6.131"]},
  "c:27"->{
    Cell[22921417, 529519, 65, 1, 30, "Subsubtitle",
      CellTags->"c:27"]},
  "i:66"->{
    Cell[22925053, 529655, 207, 5, 44, "Text",
      CellTags->"i:66"]},
  "(6.2.44)"->{
    Cell[22925263, 529662, 519, 17, 29, "NE2",
      CellTags->"(6.2.44)"]},
  "i:38"->{
    Cell[22936419, 530044, 355, 11, 40, "Text",
      CellTags->"i:38"]},
  "(6.2.45)"->{
    Cell[22942884, 530263, 1091, 31, 46, "NE2",
      CellTags->"(6.2.45)"]},
  "Fig. 6.8"->{
    Cell[22982263, 530852, 66, 1, 16, "Caption",
      CellTags->"Fig. 6.8"]},
  "Fig. 6.9"->{
    Cell[23022764, 531397, 66, 1, 16, "Caption",
      CellTags->"Fig. 6.9"]},
  "Fig. 6.10"->{
    Cell[23337257, 538118, 68, 1, 16, "Caption",
      CellTags->"Fig. 6.10"]},
  "i:62"->{
    Cell[23339797, 538196, 2571, 80, 136, "Text",
      CellTags->"i:62"]},
  "Fig. 6.11"->{
    Cell[26889242, 587086, 459, 16, 29, "Caption",
      CellTags->"Fig. 6.11"]},
  "i:39"->{
    Cell[26891593, 587167, 113, 2, 40, "Subtitle",
      CellTags->{"i:39", "c:28"}]},
  "c:28"->{
    Cell[26891593, 587167, 113, 2, 40, "Subtitle",
      CellTags->{"i:39", "c:28"}]},
  "c:29"->{
    Cell[26891750, 587175, 61, 1, 41, "Subsubtitle",
      CellTags->"c:29"]},
  "i:42"->{
    Cell[26893899, 587224, 81, 1, 30, "Subsubtitle",
      CellTags->{"i:42", "c:30"}]},
  "c:30"->{
    Cell[26893899, 587224, 81, 1, 30, "Subsubtitle",
      CellTags->{"i:42", "c:30"}]},
  "c:31"->{
    Cell[26894005, 587229, 53, 1, 42, "Section",
      CellTags->"c:31"]},
  "(6.3.1)"->{
    Cell[26894127, 587234, 150, 5, 33, "NE3",
      CellTags->"(6.3.1)"]},
  "(6.3.2)"->{
    Cell[26898003, 587364, 298, 9, 35, "NE3",
      CellTags->"(6.3.2)"]},
  "(6.3.3)"->{
    Cell[26900001, 587433, 305, 9, 35, "NE3",
      CellTags->"(6.3.3)"]},
  "(6.3.4)"->{
    Cell[26900388, 587446, 1507, 42, 93, "NE3",
      CellTags->"(6.3.4)"]},
  "(6.3.5)"->{
    Cell[26902335, 587506, 1534, 35, 93, "NE3",
      CellTags->"(6.3.5)"]},
  "c:32"->{
    Cell[26904507, 587568, 97, 1, 31, "Section",
      CellTags->"c:32"]},
  "(2.4.49)"->{
    Cell[26906839, 587654, 653, 18, 34, "NE3",
      CellTags->{"(2.4.49)", "(6.3.6)"}]},
  "(6.3.6)"->{
    Cell[26906839, 587654, 653, 18, 34, "NE3",
      CellTags->{"(2.4.49)", "(6.3.6)"}]},
  "Cell 6.132"->{
    Cell[26908192, 587703, 1070, 22, 328, "Input",
      CellTags->"Cell 6.132"]},
  "Cell 6.133"->{
    Cell[26909548, 587739, 136, 4, 86, "Input",
      CellTags->"Cell 6.133"]},
  "Cell 6.134"->{
    Cell[26910876, 587781, 278, 7, 124, "Input",
      CellTags->"Cell 6.134"]},
  "Cell 6.135"->{
    Cell[26914169, 587840, 583, 13, 162, "Input",
      CellTags->"Cell 6.135"]},
  "Cell 6.136"->{
    Cell[26947734, 588620, 170, 5, 67, "Input",
      CellTags->"Cell 6.136"]},
  "Cell 6.137"->{
    Cell[26949129, 588663, 121, 3, 67, "Input",
      CellTags->"Cell 6.137"]},
  "Cell 6.138"->{
    Cell[26949693, 588679, 331, 7, 124, "Input",
      CellTags->"Cell 6.138"]},
  "Cell 6.139"->{
    Cell[26950240, 588696, 231, 6, 67, "Input",
      CellTags->"Cell 6.139"]},
  "Cell 6.140"->{
    Cell[26950855, 588721, 468, 10, 124, "Input",
      CellTags->"Cell 6.140"]},
  "Cell 6.141"->{
    Cell[27390461, 597836, 1179, 23, 276, "Input",
      CellTags->"Cell 6.141"]},
  "i:47"->{
    Cell[27557095, 606854, 82, 1, 31, "Section",
      CellTags->{"i:47", "c:33"}]},
  "c:33"->{
    Cell[27557095, 606854, 82, 1, 31, "Section",
      CellTags->{"i:47", "c:33"}]},
  "(6.3.7)"->{
    Cell[27558544, 606904, 540, 16, 65, "NE3",
      CellTags->"(6.3.7)"]},
  "Cell 6.142"->{
    Cell[27559539, 606937, 488, 11, 225, "Input",
      CellTags->"Cell 6.142"]},
  "Cell 6.143"->{
    Cell[27560138, 606955, 468, 11, 183, "Input",
      CellTags->"Cell 6.143"]},
  "Cell 6.144"->{
    Cell[27560810, 606978, 384, 8, 128, "Input",
      CellTags->"Cell 6.144"]},
  "Cell 6.145"->{
    Cell[27589558, 607638, 386, 8, 267, "Input",
      CellTags->"Cell 6.145"]},
  "Cell 6.146"->{
    Cell[27590240, 607658, 212, 6, 69, "Input",
      CellTags->"Cell 6.146"]},
  "Cell 6.147"->{
    Cell[27591219, 607692, 224, 6, 105, "Input",
      CellTags->"Cell 6.147"]},
  "Cell 6.148"->{
    Cell[27592374, 607732, 118, 3, 67, "Input",
      CellTags->"Cell 6.148"]},
  "Cell 6.149"->{
    Cell[27592571, 607741, 110, 3, 67, "Input",
      CellTags->"Cell 6.149"]},
  "Cell 6.150"->{
    Cell[27597333, 607814, 112, 3, 67, "Input",
      CellTags->"Cell 6.150"]},
  "Cell 6.151"->{
    Cell[27598667, 607856, 120, 3, 67, "Input",
      CellTags->"Cell 6.151"]},
  "Cell 6.152"->{
    Cell[27599711, 607893, 105, 3, 67, "Input",
      CellTags->"Cell 6.152"]},
  "Cell 6.153"->{
    Cell[27606112, 608020, 575, 11, 147, "Input",
      CellTags->"Cell 6.153"]},
  "Cell 6.154"->{
    Cell[27607826, 608069, 503, 10, 162, "Input",
      CellTags->"Cell 6.154"]},
  "i:41"->{
    Cell[28164177, 626298, 85, 1, 30, "Subsubtitle",
      CellTags->{"i:41", "c:34"}]},
  "c:34"->{
    Cell[28164177, 626298, 85, 1, 30, "Subsubtitle",
      CellTags->{"i:41", "c:34"}]},
  "c:35"->{
    Cell[28164287, 626303, 53, 1, 42, "Section",
      CellTags->"c:35"]},
  "(6.3.8)"->{
    Cell[28165411, 626330, 149, 5, 33, "NE3",
      CellTags->"(6.3.8)"]},
  "(6.3.9)"->{
    Cell[28165946, 626350, 145, 5, 38, "NE3",
      CellTags->"(6.3.9)"]},
  "(6.3.10)"->{
    Cell[28166699, 626383, 222, 4, 38, "NE3",
      CellTags->"(6.3.10)"]},
  "(6.3.11)"->{
    Cell[28168877, 626457, 985, 31, 32, "NE3",
      CellTags->"(6.3.11)"]},
  "c:36"->{
    Cell[28170672, 626520, 91, 1, 31, "Section",
      CellTags->"c:36"]},
  "(6.3.12)"->{
    Cell[28170913, 626528, 222, 6, 42, "NE3",
      CellTags->"(6.3.12)"]},
  "Cell 6.155"->{
    Cell[28173849, 626611, 1523, 40, 205, "Input",
      CellTags->"Cell 6.155"]},
  "Cell 6.156"->{
    Cell[28175637, 626663, 180, 5, 74, "Input",
      CellTags->"Cell 6.156"]},
  "Cell 6.157"->{
    Cell[28176596, 626693, 111, 3, 67, "Input",
      CellTags->"Cell 6.157"]},
  "Cell 6.158"->{
    Cell[28176972, 626710, 152, 4, 67, "Input",
      CellTags->"Cell 6.158"]},
  "Cell 6.159"->{
    Cell[28177489, 626729, 837, 17, 219, "Input",
      CellTags->"Cell 6.159"]},
  "Cell 6.160"->{
    Cell[28178513, 626757, 95, 3, 67, "Input",
      CellTags->"Cell 6.160"]},
  "Cell 6.161"->{
    Cell[28178928, 626771, 93, 3, 67, "Input",
      CellTags->"Cell 6.161"]},
  "Cell 6.162"->{
    Cell[28179606, 626798, 171, 5, 67, "Input",
      CellTags->"Cell 6.162"]},
  "Cell 6.163"->{
    Cell[28180286, 626822, 284, 6, 86, "Input",
      CellTags->"Cell 6.163"]},
  "i:48"->{
    Cell[28337546, 630645, 82, 1, 31, "Section",
      CellTags->{"i:48", "c:37"}]},
  "c:37"->{
    Cell[28337546, 630645, 82, 1, 31, "Section",
      CellTags->{"i:48", "c:37"}]},
  "Cell 6.164"->{
    Cell[28350389, 631052, 470, 12, 207, "Input",
      CellTags->"Cell 6.164"]},
  "Cell 6.165"->{
    Cell[28353633, 631112, 3853, 82, 559, "Input",
      CellTags->"Cell 6.165"]},
  "Cell 6.166"->{
    Cell[28357610, 631203, 97, 3, 67, "Input",
      CellTags->"Cell 6.166"]},
  "Cell 6.167"->{
    Cell[28357770, 631212, 90, 3, 67, "Input",
      CellTags->"Cell 6.167"]},
  "Cell 6.168"->{
    Cell[28358984, 631245, 162, 5, 105, "Input",
      CellTags->"Cell 6.168"]},
  "i:67"->{
    Cell[28360139, 631268, 485, 15, 44, "Text",
      CellTags->"i:67"]},
  "Cell 6.169"->{
    Cell[28360649, 631287, 914, 19, 279, "Input",
      CellTags->"Cell 6.169"]},
  "c:38"->{
    Cell[29767276, 660241, 63, 1, 30, "Subsubtitle",
      CellTags->"c:38"]},
  "c:39"->{
    Cell[29767383, 660248, 56, 1, 42, "Section",
      CellTags->"c:39"]},
  "i:43"->{
    Cell[29767442, 660251, 268, 6, 44, "Text",
      CellTags->"i:43"]},
  "(3.1.7)"->{
    Cell[29767974, 660270, 336, 8, 45, "NE3",
      CellTags->{"(3.1.7)", "(6.3.13)"}]},
  "(6.3.13)"->{
    Cell[29767974, 660270, 336, 8, 45, "NE3",
      CellTags->{"(3.1.7)", "(6.3.13)"}]},
  "(6.3.14)"->{
    Cell[29768650, 660293, 274, 8, 41, "NE3",
      CellTags->"(6.3.14)"]},
  "(6.3.15)"->{
    Cell[29768948, 660305, 494, 12, 44, "NE3",
      CellTags->"(6.3.15)"]},
  "(6.3.16)"->{
    Cell[29770232, 660343, 275, 6, 43, "NE3",
      CellTags->"(6.3.16)"]},
  "(6.3.17)"->{
    Cell[29770663, 660358, 258, 9, 34, "NE3",
      CellTags->"(6.3.17)"]},
  "(6.3.18)"->{
    Cell[29771177, 660380, 140, 5, 29, "NE3",
      CellTags->"(6.3.18)"]},
  "(6.3.19)"->{
    Cell[29772012, 660406, 242, 7, 42, "NE3",
      CellTags->"(6.3.19)"]},
  "(6.3.20)"->{
    Cell[29774517, 660494, 347, 8, 53, "NE3",
      CellTags->"(6.3.20)"]},
  "Cell 6.170"->{
    Cell[29775058, 660512, 948, 22, 352, "Input",
      CellTags->"Cell 6.170"]},
  "Fig. 6.12"->{
    Cell[30970922, 692753, 165, 4, 17, "Caption",
      CellTags->"Fig. 6.12"]},
  "i:40"->{
    Cell[30972124, 692784, 95, 1, 31, "Section",
      CellTags->{"i:40", "c:40"}]},
  "c:40"->{
    Cell[30972124, 692784, 95, 1, 31, "Section",
      CellTags->{"i:40", "c:40"}]},
  "Cell 6.171"->{
    Cell[30973978, 692833, 389, 8, 116, "Input",
      CellTags->"Cell 6.171"]},
  "Cell 6.172"->{
    Cell[30974547, 692852, 143, 4, 67, "Input",
      CellTags->"Cell 6.172"]},
  "Cell 6.173"->{
    Cell[30975224, 692878, 323, 7, 86, "Input",
      CellTags->"Cell 6.173"]},
  "Cell 6.174"->{
    Cell[30975674, 692894, 396, 9, 107, "Input",
      CellTags->"Cell 6.174"]},
  "Cell 6.175"->{
    Cell[30977866, 692950, 158, 4, 67, "Input",
      CellTags->"Cell 6.175"]},
  "Cell 6.176"->{
    Cell[30978327, 692967, 620, 13, 181, "Input",
      CellTags->"Cell 6.176"]},
  "Cell 6.177"->{
    Cell[31183477, 697579, 853, 20, 295, "Input",
      CellTags->"Cell 6.177"]},
  "Fig. 6.13"->{
    Cell[32369794, 729706, 312, 9, 30, "Caption",
      CellTags->"Fig. 6.13"]},
  "i:44"->{
    Cell[32370526, 729731, 94, 1, 31, "Section",
      CellTags->{"i:44", "c:41"}]},
  "c:41"->{
    Cell[32370526, 729731, 94, 1, 31, "Section",
      CellTags->{"i:44", "c:41"}]},
  "(6.3.21)"->{
    Cell[32371504, 729757, 235, 7, 42, "NE3",
      CellTags->"(6.3.21)"]},
  "(6.3.22)"->{
    Cell[32373001, 729809, 414, 9, 44, "NE3",
      CellTags->"(6.3.22)"]},
  "(6.3.23)"->{
    Cell[32376223, 729914, 242, 7, 33, "NE3",
      CellTags->"(6.3.23)"]},
  "(6.3.24)"->{
    Cell[32376785, 729932, 197, 6, 33, "NE3",
      CellTags->"(6.3.24)"]},
  "(6.3.25)"->{
    Cell[32377235, 729949, 219, 7, 33, "NE3",
      CellTags->"(6.3.25)"]},
  "Fig. 6.14"->{
    Cell[32431892, 731140, 131, 4, 16, "Caption",
      CellTags->"Fig. 6.14"]},
  "(6.3.26)"->{
    Cell[32432348, 731155, 297, 8, 43, "NE3",
      CellTags->"(6.3.26)"]},
  "Cell 6.178"->{
    Cell[32433090, 731183, 345, 7, 149, "Input",
      CellTags->"Cell 6.178"]},
  "(6.3.27)"->{
    Cell[32475342, 732199, 642, 17, 48, "NE3",
      CellTags->"(6.3.27)"]},
  "(6.3.28)"->{
    Cell[32476361, 732233, 671, 18, 51, "NE3",
      CellTags->"(6.3.28)"]},
  "(6.3.29)"->{
    Cell[32478391, 732295, 355, 9, 45, "NE3",
      CellTags->"(6.3.29)"]},
  "(6.3.30)"->{
    Cell[32478900, 732313, 689, 19, 51, "NE3",
      CellTags->"(6.3.30)"]},
  "(6.3.31)"->{
    Cell[32481380, 732381, 240, 7, 35, "NE3",
      CellTags->"(6.3.31)"]},
  "i:45"->{
    Cell[32481623, 732390, 877, 30, 61, "Text",
      CellTags->"i:45"]},
  "c:42"->{
    Cell[32483600, 732458, 87, 1, 31, "Section",
      CellTags->"c:42"]},
  "(6.3.32)"->{
    Cell[32484922, 732498, 242, 7, 58, "NE3",
      CellTags->"(6.3.32)"]},
  "Cell 6.179"->{
    Cell[32485366, 732518, 245, 6, 106, "Input",
      CellTags->"Cell 6.179"]},
  "i:46"->{
    Cell[32486269, 732547, 97, 1, 31, "Section",
      CellTags->{"i:46", "c:43"}]},
  "c:43"->{
    Cell[32486269, 732547, 97, 1, 31, "Section",
      CellTags->{"i:46", "c:43"}]},
  "Cell 6.180"->{
    Cell[32487968, 732592, 122, 3, 67, "Input",
      CellTags->"Cell 6.180"]},
  "Cell 6.181"->{
    Cell[32488216, 732605, 96, 3, 67, "Input",
      CellTags->"Cell 6.181"]},
  "Cell 6.182"->{
    Cell[32488729, 732626, 578, 11, 184, "Input",
      CellTags->"Cell 6.182"]},
  "Cell 6.183"->{
    Cell[32489608, 732650, 137, 3, 67, "Input",
      CellTags->"Cell 6.183"]},
  "Cell 6.184"->{
    Cell[32489929, 732663, 156, 4, 67, "Input",
      CellTags->"Cell 6.184"]},
  "Cell 6.185"->{
    Cell[32490767, 732693, 815, 16, 219, "Input",
      CellTags->"Cell 6.185"]},
  "Cell 6.186"->{
    Cell[32491712, 732718, 134, 3, 67, "Input",
      CellTags->"Cell 6.186"]},
  "Cell 6.187"->{
    Cell[32496446, 732862, 191, 5, 67, "Input",
      CellTags->"Cell 6.187"]},
  "Cell 6.188"->{
    Cell[32496881, 732877, 446, 8, 105, "Input",
      CellTags->"Cell 6.188"]},
  "Cell 6.189"->{
    Cell[32497998, 732905, 280, 6, 86, "Input",
      CellTags->"Cell 6.189"]},
  "c:44"->{
    Cell[32791541, 739685, 65, 1, 30, "Subsubtitle",
      CellTags->"c:44"]},
  "Fig. 6.15"->{
    Cell[32884324, 740930, 53, 1, 16, "Caption",
      CellTags->"Fig. 6.15"]},
  "i:56"->{
    Cell[32892213, 741212, 1167, 29, 103, "Text",
      CellTags->"i:56"]},
  "Fig. 6.16"->{
    Cell[32943627, 741981, 68, 1, 16, "Caption",
      CellTags->"Fig. 6.16"]},
  "(6.3.33)"->{
    Cell[32945618, 742046, 184, 7, 38, "NE3",
      CellTags->"(6.3.33)"]},
  "i:49"->{
    Cell[32947411, 742107, 883, 29, 78, "Text",
      CellTags->"i:49"]},
  "(6.3.34)"->{
    Cell[32948297, 742138, 155, 6, 33, "NE3",
      CellTags->"(6.3.34)"]},
  "i:50"->{
    Cell[32949386, 742177, 2262, 69, 158, "Text",
      CellTags->"i:50"]},
  "(6.3.35)"->{
    Cell[32951651, 742248, 167, 6, 32, "NE3",
      CellTags->"(6.3.35)"]},
  "i:51"->{
    Cell[32951821, 742256, 902, 27, 86, "Text",
      CellTags->"i:51"]},
  "(6.3.36)"->{
    Cell[32953729, 742321, 225, 6, 49, "NE3",
      CellTags->"(6.3.36)"]},
  "i:52"->{
    Cell[32954911, 742364, 2311, 76, 107, "Text",
      CellTags->"i:52"]},
  "(6.3.37)"->{
    Cell[32957225, 742442, 410, 13, 29, "NE3",
      CellTags->"(6.3.37)"]},
  "(6.3.38)"->{
    Cell[32959518, 742528, 760, 22, 39, "NE3",
      CellTags->"(6.3.38)"]},
  "(6.3.39)"->{
    Cell[32961720, 742603, 783, 22, 48, "NE3",
      CellTags->"(6.3.39)"]},
  "i:53"->{
    Cell[32962799, 742639, 174, 6, 35, "NE3",
      CellTags->{"i:53", "(6.3.40)"}]},
  "(6.3.40)"->{
    Cell[32962799, 742639, 174, 6, 35, "NE3",
      CellTags->{"i:53", "(6.3.40)"}]},
  "(6.3.41)"->{
    Cell[32964673, 742714, 784, 24, 35, "NE3",
      CellTags->"(6.3.41)"]},
  "i:54"->{
    Cell[32966475, 742778, 294, 9, 49, "NE3",
      CellTags->{"i:54", "(6.3.42)"}]},
  "(6.3.42)"->{
    Cell[32966475, 742778, 294, 9, 49, "NE3",
      CellTags->{"i:54", "(6.3.42)"}]},
  "i:55"->{
    Cell[32967293, 742810, 1610, 47, 136, "Text",
      CellTags->"i:55"]},
  "c:45"->{
    Cell[32968952, 742863, 60, 1, 40, "Subtitle",
      CellTags->{"c:45", "refs"}]},
  "refs"->{
    Cell[32968952, 742863, 60, 1, 40, "Subtitle",
      CellTags->{"c:45", "refs"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"i:1", 33011733, 744208},
  {"c:1", 33011819, 744211},
  {"i:2", 33011905, 744214},
  {"c:2", 33011992, 744217},
  {"c:3", 33012079, 744220},
  {"i:57", 33012161, 744223},
  {"Fig. 6.1", 33012245, 744226},
  {"i:4", 33012330, 744229},
  {"c:4", 33012422, 744232},
  {"c:5", 33012514, 744235},
  {"(6.1.1)", 33012597, 744238},
  {"(6.1.2)", 33012694, 744241},
  {"(6.1.3)", 33012791, 744244},
  {"i:5", 33012884, 744247},
  {"(6.1.4)", 33012966, 744250},
  {"(6.1.5)", 33013063, 744253},
  {"(6.1.6)", 33013160, 744256},
  {"(6.1.7)", 33013257, 744259},
  {"(6.1.8)", 33013354, 744262},
  {"(6.1.9)", 33013451, 744265},
  {"i:6", 33013544, 744268},
  {"(6.1.10)", 33013625, 744271},
  {"(6.1.11)", 33013724, 744274},
  {"i:3", 33013819, 744277},
  {"(6.1.12)", 33013903, 744280},
  {"i:7", 33013998, 744283},
  {"c:6", 33014079, 744286},
  {"(6.1.13)", 33014164, 744289},
  {"Cell 6.1", 33014264, 744292},
  {"Cell 6.2", 33014353, 744295},
  {"Cell 6.3", 33014442, 744298},
  {"Cell 6.4", 33014531, 744301},
  {"Cell 6.5", 33014620, 744304},
  {"Cell 6.6", 33014709, 744307},
  {"Cell 6.7", 33014798, 744310},
  {"i:59", 33014883, 744313},
  {"Cell 6.8", 33014968, 744316},
  {"Cell 6.9", 33015057, 744319},
  {"Cell 6.10", 33015147, 744322},
  {"Cell 6.11", 33015238, 744325},
  {"Cell 6.12", 33015329, 744328},
  {"Cell 6.13", 33015420, 744331},
  {"Cell 6.14", 33015511, 744334},
  {"Cell 6.15", 33015604, 744337},
  {"c:7", 33015691, 744340},
  {"Cell 6.16", 33015779, 744343},
  {"Cell 6.17", 33015871, 744346},
  {"i:64", 33015959, 744349},
  {"i:8", 33016041, 744352},
  {"Cell 6.18", 33016127, 744355},
  {"Cell 6.19", 33016223, 744358},
  {"Cell 6.20", 33016319, 744361},
  {"Cell 6.21", 33016411, 744364},
  {"Cell 6.22", 33016505, 744367},
  {"Cell 6.23", 33016598, 744370},
  {"c:8", 33016685, 744373},
  {"Cell 6.24", 33016774, 744376},
  {"(6.1.14)", 33016869, 744379},
  {"Cell 6.25", 33016974, 744382},
  {"Cell 6.26", 33017070, 744385},
  {"Cell 6.27", 33017166, 744388},
  {"Cell 6.28", 33017260, 744391},
  {"i:9", 33017348, 744394},
  {"Cell 6.29", 33017436, 744397},
  {"Cell 6.30", 33017533, 744400},
  {"Cell 6.31", 33017627, 744403},
  {"Fig. 6.2", 33017720, 744406},
  {"Fig. 6.3", 33017815, 744409},
  {"i:11", 33017906, 744412},
  {"c:9", 33018003, 744415},
  {"c:10", 33018101, 744418},
  {"(6.1.15)", 33018190, 744421},
  {"(6.1.16)", 33018293, 744424},
  {"(6.1.17)", 33018396, 744427},
  {"(6.1.18)", 33018499, 744430},
  {"(6.1.19)", 33018602, 744433},
  {"i:12", 33018701, 744436},
  {"(6.1.20)", 33018789, 744439},
  {"Cell 6.32", 33018893, 744442},
  {"(6.1.21)", 33018987, 744445},
  {"(6.1.22)", 33019090, 744448},
  {"(6.1.23)", 33019193, 744451},
  {"(6.1.24)", 33019296, 744454},
  {"(6.1.25)", 33019400, 744457},
  {"(6.1.26)", 33019503, 744460},
  {"Cell 6.33", 33019607, 744463},
  {"Cell 6.34", 33019702, 744466},
  {"Cell 6.35", 33019796, 744469},
  {"Cell 6.36", 33019890, 744472},
  {"Cell 6.37", 33019984, 744475},
  {"Cell 6.38", 33020078, 744478},
  {"Cell 6.39", 33020172, 744481},
  {"Cell 6.40", 33020266, 744484},
  {"Cell 6.41", 33020360, 744487},
  {"Cell 6.42", 33020454, 744490},
  {"Cell 6.43", 33020549, 744493},
  {"Cell 6.44", 33020643, 744496},
  {"Cell 6.45", 33020737, 744499},
  {"Cell 6.46", 33020832, 744502},
  {"i:13", 33020922, 744505},
  {"Cell 6.47", 33021010, 744508},
  {"i:14", 33021103, 744511},
  {"c:11", 33021198, 744514},
  {"(6.1.27)", 33021297, 744517},
  {"(6.1.28)", 33021400, 744520},
  {"(6.1.29)", 33021503, 744523},
  {"(6.1.30)", 33021607, 744526},
  {"(6.1.31)", 33021711, 744529},
  {"(6.1.32)", 33021815, 744532},
  {"(6.1.33)", 33021918, 744535},
  {"(6.1.34)", 33022021, 744538},
  {"(6.1.35)", 33022124, 744541},
  {"(6.1.36)", 33022227, 744544},
  {"Cell 6.48", 33022332, 744547},
  {"Cell 6.49", 33022426, 744550},
  {"Cell 6.50", 33022523, 744553},
  {"Cell 6.51", 33022617, 744556},
  {"i:16", 33022708, 744559},
  {"i:15", 33022795, 744562},
  {"c:12", 33022880, 744565},
  {"Fig. 6.4", 33022974, 744568},
  {"Fig. 6.5", 33023068, 744571},
  {"i:37", 33023158, 744574},
  {"(6.1.37)", 33023272, 744577},
  {"i:17", 33023382, 744580},
  {"c:13", 33023479, 744583},
  {"c:14", 33023576, 744586},
  {"i:18", 33023666, 744589},
  {"c:15", 33023762, 744592},
  {"(6.2.1)", 33023861, 744595},
  {"(6.2.2)", 33023950, 744598},
  {"(6.2.3)", 33024040, 744601},
  {"(6.2.4)", 33024130, 744604},
  {"(6.2.5)", 33024220, 744607},
  {"Cell 6.52", 33024312, 744610},
  {"Cell 6.53", 33024408, 744613},
  {"Cell 6.54", 33024503, 744616},
  {"Cell 6.55", 33024598, 744619},
  {"Cell 6.56", 33024694, 744622},
  {"i:70", 33024785, 744625},
  {"Cell 6.57", 33024876, 744628},
  {"i:19", 33024968, 744631},
  {"c:16", 33025064, 744634},
  {"i:58", 33025160, 744637},
  {"(6.2.6)", 33025250, 744640},
  {"(6.2.7)", 33025341, 744643},
  {"(6.2.8)", 33025430, 744646},
  {"Fig. 6.6", 33025521, 744649},
  {"(6.2.9)", 33025615, 744652},
  {"i:65", 33025702, 744655},
  {"i:20", 33025788, 744658},
  {"c:17", 33025884, 744661},
  {"(6.2.10)", 33025984, 744664},
  {"(6.2.11)", 33026076, 744667},
  {"Cell 6.58", 33026168, 744670},
  {"i:21", 33026258, 744673},
  {"c:18", 33026354, 744676},
  {"(6.2.12)", 33026454, 744679},
  {"Cell 6.59", 33026547, 744682},
  {"(6.2.13)", 33026643, 744685},
  {"i:22", 33026731, 744688},
  {"c:19", 33026827, 744691},
  {"(6.2.14)", 33026927, 744694},
  {"i:25", 33027015, 744697},
  {"(6.2.15)", 33027106, 744700},
  {"(6.2.16)", 33027198, 744703},
  {"i:23", 33027287, 744706},
  {"(6.2.17)", 33027377, 744709},
  {"Cell 6.60", 33027470, 744712},
  {"Cell 6.61", 33027565, 744715},
  {"(6.2.18)", 33027660, 744718},
  {"Cell 6.62", 33027752, 744721},
  {"Cell 6.63", 33027847, 744724},
  {"Cell 6.64", 33027945, 744727},
  {"Cell 6.65", 33028042, 744730},
  {"Cell 6.66", 33028138, 744733},
  {"i:24", 33028228, 744736},
  {"c:20", 33028324, 744739},
  {"(6.2.19)", 33028424, 744742},
  {"(6.2.20)", 33028516, 744745},
  {"(6.2.21)", 33028608, 744748},
  {"Cell 6.67", 33028701, 744751},
  {"Cell 6.68", 33028797, 744754},
  {"Cell 6.69", 33028892, 744757},
  {"Cell 6.70", 33028987, 744760},
  {"Cell 6.71", 33029082, 744763},
  {"(6.2.22)", 33029179, 744766},
  {"(6.2.23)", 33029271, 744769},
  {"(6.2.24)", 33029364, 744772},
  {"(6.2.25)", 33029456, 744775},
  {"c:21", 33029545, 744778},
  {"(6.2.26)", 33029635, 744781},
  {"(6.2.27)", 33029726, 744784},
  {"(6.2.28)", 33029818, 744787},
  {"(6.2.29)", 33029911, 744790},
  {"i:26", 33030000, 744793},
  {"Cell 6.72", 33030097, 744796},
  {"Cell 6.73", 33030193, 744799},
  {"Cell 6.74", 33030291, 744802},
  {"Cell 6.75", 33030388, 744805},
  {"Cell 6.76", 33030483, 744808},
  {"Cell 6.77", 33030579, 744811},
  {"i:28", 33030670, 744814},
  {"i:27", 33030756, 744817},
  {"(6.2.30)", 33030853, 744820},
  {"i:69", 33030942, 744823},
  {"(6.2.31)", 33031034, 744826},
  {"Cell 6.78", 33031129, 744829},
  {"Cell 6.79", 33031225, 744832},
  {"(6.2.32)", 33031322, 744835},
  {"Cell 6.80", 33031415, 744838},
  {"Cell 6.81", 33031511, 744841},
  {"Cell 6.82", 33031608, 744844},
  {"Cell 6.83", 33031707, 744847},
  {"Cell 6.84", 33031804, 744850},
  {"Cell 6.85", 33031901, 744853},
  {"i:29", 33031995, 744856},
  {"c:22", 33032096, 744859},
  {"i:30", 33032197, 744862},
  {"c:23", 33032294, 744865},
  {"(6.2.33)", 33032395, 744868},
  {"(6.2.34)", 33032487, 744871},
  {"Cell 6.86", 33032582, 744874},
  {"Cell 6.87", 33032679, 744877},
  {"Cell 6.88", 33032776, 744880},
  {"Cell 6.89", 33032872, 744883},
  {"Cell 6.90", 33032971, 744886},
  {"Cell 6.91", 33033067, 744889},
  {"Cell 6.92", 33033163, 744892},
  {"Cell 6.93", 33033260, 744895},
  {"i:31", 33033351, 744898},
  {"c:24", 33033448, 744901},
  {"(6.2.35)", 33033549, 744904},
  {"(6.2.36)", 33033642, 744907},
  {"Cell 6.94", 33033737, 744910},
  {"Cell 6.95", 33033835, 744913},
  {"Cell 6.96", 33033933, 744916},
  {"(6.2.37)", 33034028, 744919},
  {"(6.2.38)", 33034121, 744922},
  {"Cell 6.97", 33034215, 744925},
  {"Cell 6.98", 33034313, 744928},
  {"i:68", 33034405, 744931},
  {"Cell 6.99", 33034498, 744934},
  {"Cell 6.100", 33034595, 744937},
  {"Cell 6.101", 33034696, 744940},
  {"Cell 6.102", 33034794, 744943},
  {"Cell 6.103", 33034892, 744946},
  {"Cell 6.104", 33034991, 744949},
  {"Cell 6.105", 33035088, 744952},
  {"Fig. 6.7", 33035185, 744955},
  {"i:32", 33035276, 744958},
  {"c:25", 33035373, 744961},
  {"i:33", 33035470, 744964},
  {"(6.2.39)", 33035567, 744967},
  {"i:61", 33035657, 744970},
  {"Cell 6.106", 33035750, 744973},
  {"Cell 6.107", 33035849, 744976},
  {"Cell 6.108", 33035948, 744979},
  {"Cell 6.109", 33036048, 744982},
  {"Cell 6.110", 33036146, 744985},
  {"Cell 6.111", 33036245, 744988},
  {"Cell 6.112", 33036344, 744991},
  {"Cell 6.113", 33036441, 744994},
  {"Cell 6.114", 33036540, 744997},
  {"Cell 6.115", 33036639, 745000},
  {"i:34", 33036732, 745003},
  {"(6.2.40)", 33036829, 745006},
  {"Cell 6.116", 33036925, 745009},
  {"Cell 6.117", 33037026, 745012},
  {"Cell 6.118", 33037123, 745015},
  {"i:36", 33037216, 745018},
  {"c:26", 33037313, 745021},
  {"(6.2.41)", 33037414, 745024},
  {"(6.2.42)", 33037506, 745027},
  {"(6.2.43)", 33037598, 745030},
  {"Cell 6.119", 33037692, 745033},
  {"Cell 6.120", 33037791, 745036},
  {"Cell 6.121", 33037889, 745039},
  {"Cell 6.122", 33037987, 745042},
  {"Cell 6.123", 33038085, 745045},
  {"Cell 6.124", 33038183, 745048},
  {"Cell 6.125", 33038281, 745051},
  {"Cell 6.126", 33038379, 745054},
  {"Cell 6.127", 33038477, 745057},
  {"Cell 6.128", 33038576, 745060},
  {"Cell 6.129", 33038674, 745063},
  {"Cell 6.130", 33038772, 745066},
  {"Cell 6.131", 33038870, 745069},
  {"c:27", 33038962, 745072},
  {"i:66", 33039053, 745075},
  {"(6.2.44)", 33039142, 745078},
  {"i:38", 33039231, 745081},
  {"(6.2.45)", 33039321, 745084},
  {"Fig. 6.8", 33039415, 745087},
  {"Fig. 6.9", 33039510, 745090},
  {"Fig. 6.10", 33039606, 745093},
  {"i:62", 33039698, 745096},
  {"Fig. 6.11", 33039791, 745099},
  {"i:39", 33039885, 745102},
  {"c:28", 33039984, 745105},
  {"c:29", 33040083, 745108},
  {"i:42", 33040174, 745111},
  {"c:30", 33040275, 745114},
  {"c:31", 33040376, 745117},
  {"(6.3.1)", 33040466, 745120},
  {"(6.3.2)", 33040556, 745123},
  {"(6.3.3)", 33040646, 745126},
  {"(6.3.4)", 33040736, 745129},
  {"(6.3.5)", 33040828, 745132},
  {"c:32", 33040917, 745135},
  {"(2.4.49)", 33041008, 745138},
  {"(6.3.6)", 33041113, 745141},
  {"Cell 6.132", 33041221, 745144},
  {"Cell 6.133", 33041322, 745147},
  {"Cell 6.134", 33041420, 745150},
  {"Cell 6.135", 33041519, 745153},
  {"Cell 6.136", 33041619, 745156},
  {"Cell 6.137", 33041717, 745159},
  {"Cell 6.138", 33041815, 745162},
  {"Cell 6.139", 33041914, 745165},
  {"Cell 6.140", 33042012, 745168},
  {"Cell 6.141", 33042112, 745171},
  {"i:47", 33042207, 745174},
  {"c:33", 33042304, 745177},
  {"(6.3.7)", 33042404, 745180},
  {"Cell 6.142", 33042498, 745183},
  {"Cell 6.143", 33042598, 745186},
  {"Cell 6.144", 33042698, 745189},
  {"Cell 6.145", 33042797, 745192},
  {"Cell 6.146", 33042896, 745195},
  {"Cell 6.147", 33042994, 745198},
  {"Cell 6.148", 33043093, 745201},
  {"Cell 6.149", 33043191, 745204},
  {"Cell 6.150", 33043289, 745207},
  {"Cell 6.151", 33043387, 745210},
  {"Cell 6.152", 33043485, 745213},
  {"Cell 6.153", 33043583, 745216},
  {"Cell 6.154", 33043683, 745219},
  {"i:41", 33043777, 745222},
  {"c:34", 33043878, 745225},
  {"c:35", 33043979, 745228},
  {"(6.3.8)", 33044069, 745231},
  {"(6.3.9)", 33044159, 745234},
  {"(6.3.10)", 33044250, 745237},
  {"(6.3.11)", 33044342, 745240},
  {"c:36", 33044431, 745243},
  {"(6.3.12)", 33044522, 745246},
  {"Cell 6.155", 33044616, 745249},
  {"Cell 6.156", 33044717, 745252},
  {"Cell 6.157", 33044815, 745255},
  {"Cell 6.158", 33044913, 745258},
  {"Cell 6.159", 33045011, 745261},
  {"Cell 6.160", 33045111, 745264},
  {"Cell 6.161", 33045208, 745267},
  {"Cell 6.162", 33045305, 745270},
  {"Cell 6.163", 33045403, 745273},
  {"i:48", 33045495, 745276},
  {"c:37", 33045592, 745279},
  {"Cell 6.164", 33045695, 745282},
  {"Cell 6.165", 33045795, 745285},
  {"Cell 6.166", 33045896, 745288},
  {"Cell 6.167", 33045993, 745291},
  {"Cell 6.168", 33046090, 745294},
  {"i:67", 33046183, 745297},
  {"Cell 6.169", 33046275, 745300},
  {"c:38", 33046369, 745303},
  {"c:39", 33046460, 745306},
  {"i:43", 33046547, 745309},
  {"(3.1.7)", 33046635, 745312},
  {"(6.3.13)", 33046740, 745315},
  {"(6.3.14)", 33046845, 745318},
  {"(6.3.15)", 33046937, 745321},
  {"(6.3.16)", 33047030, 745324},
  {"(6.3.17)", 33047122, 745327},
  {"(6.3.18)", 33047214, 745330},
  {"(6.3.19)", 33047306, 745333},
  {"(6.3.20)", 33047398, 745336},
  {"Cell 6.170", 33047492, 745339},
  {"Fig. 6.12", 33047591, 745342},
  {"i:40", 33047684, 745345},
  {"c:40", 33047781, 745348},
  {"Cell 6.171", 33047884, 745351},
  {"Cell 6.172", 33047983, 745354},
  {"Cell 6.173", 33048081, 745357},
  {"Cell 6.174", 33048179, 745360},
  {"Cell 6.175", 33048278, 745363},
  {"Cell 6.176", 33048376, 745366},
  {"Cell 6.177", 33048476, 745369},
  {"Fig. 6.13", 33048575, 745372},
  {"i:44", 33048668, 745375},
  {"c:41", 33048765, 745378},
  {"(6.3.21)", 33048866, 745381},
  {"(6.3.22)", 33048958, 745384},
  {"(6.3.23)", 33049050, 745387},
  {"(6.3.24)", 33049142, 745390},
  {"(6.3.25)", 33049234, 745393},
  {"Fig. 6.14", 33049327, 745396},
  {"(6.3.26)", 33049424, 745399},
  {"Cell 6.178", 33049518, 745402},
  {"(6.3.27)", 33049615, 745405},
  {"(6.3.28)", 33049708, 745408},
  {"(6.3.29)", 33049801, 745411},
  {"(6.3.30)", 33049893, 745414},
  {"(6.3.31)", 33049986, 745417},
  {"i:45", 33050074, 745420},
  {"c:42", 33050160, 745423},
  {"(6.3.32)", 33050251, 745426},
  {"Cell 6.179", 33050345, 745429},
  {"i:46", 33050438, 745432},
  {"c:43", 33050535, 745435},
  {"Cell 6.180", 33050638, 745438},
  {"Cell 6.181", 33050736, 745441},
  {"Cell 6.182", 33050833, 745444},
  {"Cell 6.183", 33050933, 745447},
  {"Cell 6.184", 33051031, 745450},
  {"Cell 6.185", 33051129, 745453},
  {"Cell 6.186", 33051229, 745456},
  {"Cell 6.187", 33051327, 745459},
  {"Cell 6.188", 33051425, 745462},
  {"Cell 6.189", 33051524, 745465},
  {"c:44", 33051616, 745468},
  {"Fig. 6.15", 33051712, 745471},
  {"i:56", 33051804, 745474},
  {"Fig. 6.16", 33051897, 745477},
  {"(6.3.33)", 33051993, 745480},
  {"i:49", 33052081, 745483},
  {"(6.3.34)", 33052171, 745486},
  {"i:50", 33052259, 745489},
  {"(6.3.35)", 33052351, 745492},
  {"i:51", 33052439, 745495},
  {"(6.3.36)", 33052529, 745498},
  {"i:52", 33052617, 745501},
  {"(6.3.37)", 33052709, 745504},
  {"(6.3.38)", 33052802, 745507},
  {"(6.3.39)", 33052895, 745510},
  {"i:53", 33052984, 745513},
  {"(6.3.40)", 33053086, 745516},
  {"(6.3.41)", 33053188, 745519},
  {"i:54", 33053277, 745522},
  {"(6.3.42)", 33053379, 745525},
  {"i:55", 33053477, 745528},
  {"c:45", 33053565, 745531},
  {"refs", 33053663, 745534}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 117, 4, 111, "Title",
  CellTags->{"i:1", "c:1"}],
Cell[1847, 58, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[1888, 62, 71, 1, 39, "Subtitle",
  CellTags->{"i:2", "c:2"}],
Cell[1962, 65, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[2003, 69, 60, 1, 41, "Subsubtitle",
  CellTags->"c:3"],
Cell[2066, 72, 1257, 28, 146, "Text",
  CellTags->"i:57"],
Cell[3326, 102, 43162, 536, 168, 43045, 532, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[46491, 640, 233, 5, 29, "Caption",
  CellTags->"Fig. 6.1"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46761, 650, 80, 1, 41, "Subsubtitle",
  CellTags->{"i:4", "c:4"}],

Cell[CellGroupData[{
Cell[46866, 655, 44, 1, 42, "Section",
  CellTags->"c:5"],
Cell[46913, 658, 100, 3, 27, "Text"],
Cell[47016, 663, 159, 5, 33, "NumberedEquation",
  CellTags->"(6.1.1)"],
Cell[47178, 670, 561, 19, 48, "Text"],
Cell[47742, 691, 161, 5, 29, "NumberedEquation",
  CellTags->"(6.1.2)"],
Cell[47906, 698, 236, 6, 44, "Text"],
Cell[48145, 706, 227, 5, 44, "Text"],
Cell[48375, 713, 154, 5, 29, "NumberedEquation",
  CellTags->"(6.1.3)"],
Cell[48532, 720, 176, 6, 27, "Text"],
Cell[48711, 728, 463, 16, 44, "Text",
  CellTags->"i:5"],
Cell[49177, 746, 148, 5, 29, "NumberedEquation",
  CellTags->"(6.1.4)"],
Cell[49328, 753, 96, 3, 27, "Text"],
Cell[49427, 758, 232, 7, 29, "NumberedEquation",
  CellTags->"(6.1.5)"],
Cell[49662, 767, 634, 20, 61, "Text"],
Cell[50299, 789, 250, 7, 38, "NumberedEquation",
  CellTags->"(6.1.6)"],
Cell[50552, 798, 174, 6, 29, "Text"],
Cell[50729, 806, 249, 7, 38, "NumberedEquation",
  CellTags->"(6.1.7)"],
Cell[50981, 815, 762, 21, 82, "Text"],
Cell[51746, 838, 297, 9, 44, "Text"],
Cell[52046, 849, 338, 11, 44, "Text"],
Cell[52387, 862, 300, 8, 33, "NumberedEquation",
  CellTags->"(6.1.8)"],
Cell[52690, 872, 66, 0, 27, "Text"],
Cell[52759, 874, 148, 5, 30, "NumberedEquation",
  CellTags->"(6.1.9)"],
Cell[52910, 881, 647, 21, 64, "Text"],
Cell[53560, 904, 80, 1, 27, "Text",
  CellTags->"i:6"],
Cell[53643, 907, 240, 7, 44, "NumberedEquation",
  CellTags->"(6.1.10)"],
Cell[53886, 916, 739, 18, 93, "Text"],
Cell[54628, 936, 645, 14, 78, "Text"],
Cell[55276, 952, 190, 4, 44, "Text"],
Cell[55469, 958, 1008, 36, 68, "Text"],
Cell[56480, 996, 399, 11, 40, "NumberedEquation",
  CellTags->"(6.1.11)"],
Cell[56882, 1009, 510, 16, 44, "Text"],
Cell[57395, 1027, 903, 27, 92, "Text",
  CellTags->"i:3"],
Cell[58301, 1056, 208, 6, 32, "NumberedEquation",
  CellTags->"(6.1.12)"],
Cell[58512, 1064, 922, 27, 71, "Text"],
Cell[59437, 1093, 930, 23, 95, "Text"],
Cell[60370, 1118, 1132, 30, 116, "Text",
  CellTags->"i:7"],
Cell[61505, 1150, 736, 13, 112, "Text"],
Cell[62244, 1165, 543, 12, 78, "Text"],
Cell[62790, 1179, 298, 8, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[63125, 1192, 47, 1, 31, "Section",
  CellTags->"c:6"],
Cell[63175, 1195, 815, 20, 83, "Text"],
Cell[63993, 1217, 213, 6, 39, "NumberedEquation",
  CellTags->"(6.1.13)"],
Cell[64209, 1225, 275, 9, 28, "Text"],
Cell[64487, 1236, 169, 4, 72, "Input",
  CellTags->"Cell 6.1"],
Cell[64659, 1242, 612, 14, 78, "Text"],
Cell[65274, 1258, 154, 4, 67, "Input",
  CellTags->"Cell 6.2"],
Cell[65431, 1264, 257, 9, 27, "Text"],
Cell[65691, 1275, 159, 5, 27, "Text"],
Cell[65853, 1282, 125, 3, 67, "Input",
  CellTags->"Cell 6.3"],
Cell[65981, 1287, 387, 14, 44, "Text"],
Cell[66371, 1303, 145, 5, 31, "Text"],
Cell[66519, 1310, 123, 3, 67, "Input",
  CellTags->"Cell 6.4"],
Cell[66645, 1315, 196, 6, 33, "Text"],
Cell[66844, 1323, 153, 4, 67, "Input",
  CellTags->"Cell 6.5"],
Cell[67000, 1329, 198, 6, 34, "Text"],
Cell[67201, 1337, 156, 4, 67, "Input",
  CellTags->"Cell 6.6"],
Cell[67360, 1343, 1794, 56, 44, "Text"],
Cell[69157, 1401, 220, 5, 86, "Input",
  CellTags->"Cell 6.7"],
Cell[69380, 1408, 699, 22, 62, "Text",
  CellTags->"i:59"],
Cell[70082, 1432, 216, 6, 86, "Input",
  CellTags->"Cell 6.8"],
Cell[70301, 1440, 1010, 34, 78, "Text"],
Cell[71314, 1476, 152, 4, 67, "Input",
  CellTags->"Cell 6.9"],
Cell[71469, 1482, 334, 11, 44, "Text"],
Cell[71806, 1495, 88, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[71919, 1502, 138, 3, 67, "Input",
  CellTags->"Cell 6.10"],
Cell[72060, 1507, 192, 3, 65, "Output"]
}, Open  ]],
Cell[72267, 1513, 120, 5, 27, "Text"],

Cell[CellGroupData[{
Cell[72412, 1522, 129, 3, 67, "Input",
  CellTags->"Cell 6.11"],
Cell[72544, 1527, 779, 16, 135, "Output"]
}, Open  ]],
Cell[73338, 1546, 249, 8, 27, "Text"],
Cell[73590, 1556, 207, 5, 86, "Input",
  CellTags->"Cell 6.12"],
Cell[73800, 1563, 149, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[73974, 1573, 188, 4, 67, "Input",
  CellTags->"Cell 6.13"],
Cell[74165, 1579, 102065, 1954, 326, 25826, 1009, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[176245, 3536, 429, 13, 44, "Text"],

Cell[CellGroupData[{
Cell[176699, 3553, 321, 6, 105, "Input",
  CellTags->"Cell 6.14"],
Cell[177023, 3561, 400683, 7850, 342, 199024, 5356, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[577721, 11414, 301, 9, 45, "Text"],
Cell[578025, 11425, 452, 13, 61, "Text"],

Cell[CellGroupData[{
Cell[578502, 11442, 180, 4, 86, "Input",
  CellTags->"Cell 6.15"],
Cell[578685, 11448, 2724, 39, 70, "Output"]
}, Closed]],
Cell[581424, 11490, 962, 28, 74, "Text"],
Cell[582389, 11520, 419, 13, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[582845, 11538, 47, 1, 31, "Section",
  CellTags->"c:7"],
Cell[582895, 11541, 423, 12, 47, "Text"],
Cell[583321, 11555, 92, 3, 67, "Input",
  CellTags->"Cell 6.16"],

Cell[CellGroupData[{
Cell[583438, 11562, 251, 6, 97, "Input",
  CellTags->"Cell 6.17"],
Cell[583692, 11570, 148637, 7927, 370, 116862, 7531, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[732344, 19500, 587, 14, 78, "Text",
  CellTags->"i:64"],
Cell[732934, 19516, 270, 8, 30, "Text"],
Cell[733207, 19526, 121, 4, 27, "Text",
  CellTags->"i:8"],
Cell[733331, 19532, 3019, 76, 298, "Input",
  CellTags->"Cell 6.18"],
Cell[736353, 19610, 3348, 67, 480, "Input",
  CellTags->"Cell 6.19"],
Cell[739704, 19679, 135, 5, 28, "Text"],

Cell[CellGroupData[{
Cell[739864, 19688, 97, 3, 67, "Input",
  CellTags->"Cell 6.20"],
Cell[739964, 19693, 2994, 70, 70, "Print"],
Cell[742961, 19765, 2992, 70, 70, "Print"],
Cell[745956, 19837, 2995, 70, 70, "Print"],
Cell[748954, 19909, 3002, 70, 70, "Print"],
Cell[751959, 19981, 2991, 69, 70, "Print"],
Cell[754953, 20052, 3001, 70, 70, "Print"],
Cell[757957, 20124, 3017, 71, 70, "Print"],
Cell[760977, 20197, 2996, 69, 70, "Print"],
Cell[763976, 20268, 3017, 70, 70, "Print"],
Cell[766996, 20340, 3008, 69, 70, "Print"],
Cell[770007, 20411, 3012, 70, 70, "Print"],
Cell[773022, 20483, 3028, 71, 70, "Print"],
Cell[776053, 20556, 3026, 71, 70, "Print"],
Cell[779082, 20629, 3034, 71, 70, "Print"],
Cell[782119, 20702, 3035, 71, 70, "Print"],
Cell[785157, 20775, 3029, 71, 70, "Print"],
Cell[788189, 20848, 3037, 71, 70, "Print"],
Cell[791229, 20921, 3058, 72, 70, "Print"],
Cell[794290, 20995, 3079, 73, 70, "Print"],
Cell[797372, 21070, 3058, 72, 70, "Print"],
Cell[800433, 21144, 3029, 70, 70, "Print"],
Cell[803465, 21216, 3098, 75, 70, "Print"],
Cell[806566, 21293, 3094, 74, 70, "Print"],
Cell[809663, 21369, 3101, 75, 70, "Print"],
Cell[812767, 21446, 3100, 75, 70, "Print"]
}, Closed]],
Cell[815882, 21524, 295, 9, 21, "Text"],

Cell[CellGroupData[{
Cell[816202, 21537, 386, 8, 105, "Input",
  CellTags->"Cell 6.21"],
Cell[816591, 21547, 110933, 3522, 370, 40683, 2651, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[927539, 25072, 133, 3, 27, "Text"],
Cell[927675, 25077, 106, 3, 67, "Input",
  CellTags->"Cell 6.22"],
Cell[927784, 25082, 181, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[927990, 25092, 265, 7, 86, "Input",
  CellTags->"Cell 6.23"],
Cell[928258, 25101, 377586, 7413, 302, 196266, 5171, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1305859, 32517, 214, 4, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1306110, 32526, 47, 1, 31, "Section",
  CellTags->"c:8"],
Cell[1306160, 32529, 403, 10, 47, "Text"],
Cell[1306566, 32541, 203, 6, 48, "Text"],
Cell[1306772, 32549, 148, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[1306945, 32559, 493, 10, 184, "Input",
  CellTags->"Cell 6.24"],
Cell[1307441, 32571, 142458, 7599, 370, 111484, 7213, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1449914, 40173, 421, 10, 47, "Text"],
Cell[1450338, 40185, 296, 7, 44, "Text"],
Cell[1450637, 40194, 517, 13, 42, "NumberedEquation",
  CellTags->"(6.1.14)"],
Cell[1451157, 40209, 509, 17, 44, "Text"],
Cell[1451669, 40228, 465, 10, 48, "Text"],
Cell[1452137, 40240, 60, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[1452222, 40244, 360, 10, 116, "Input",
  CellTags->"Cell 6.25"],
Cell[1452585, 40256, 216, 3, 72, "Output"]
}, Open  ]],
Cell[1452816, 40262, 601, 13, 162, "Input",
  CellTags->"Cell 6.26"],
Cell[1453420, 40277, 482, 15, 47, "Text"],

Cell[CellGroupData[{
Cell[1453927, 40296, 303, 6, 86, "Input",
  CellTags->"Cell 6.27"],
Cell[1454233, 40304, 31936, 875, 233, 9893, 598, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1486184, 41182, 361, 13, 27, "Text"],

Cell[CellGroupData[{
Cell[1486570, 41199, 174, 4, 67, "Input",
  CellTags->"Cell 6.28"],
Cell[1486747, 41205, 21277, 455, 233, 3338, 230, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1508039, 41663, 462, 11, 61, "Text"],
Cell[1508504, 41676, 772, 19, 78, "Text"],
Cell[1509279, 41697, 422, 11, 61, "Text",
  CellTags->"i:9"],
Cell[1509704, 41710, 226, 9, 36, "Text"],
Cell[1509933, 41721, 866, 21, 95, "Text"],
Cell[1510802, 41744, 3392, 82, 295, "Input",
  CellTags->"Cell 6.29"],
Cell[1514197, 41828, 531, 13, 62, "Text"],

Cell[CellGroupData[{
Cell[1514753, 41845, 102, 3, 67, "Input",
  CellTags->"Cell 6.30"],
Cell[1514858, 41850, 1961, 46, 70, "Print"],
Cell[1516822, 41898, 1998, 47, 70, "Print"],
Cell[1518823, 41947, 1974, 46, 70, "Print"],
Cell[1520800, 41995, 2011, 47, 70, "Print"],
Cell[1522814, 42044, 1972, 46, 70, "Print"],
Cell[1524789, 42092, 2013, 47, 70, "Print"],
Cell[1526805, 42141, 2017, 48, 70, "Print"],
Cell[1528825, 42191, 2037, 48, 70, "Print"],
Cell[1530865, 42241, 1980, 46, 70, "Print"],
Cell[1532848, 42289, 2023, 47, 70, "Print"],
Cell[1534874, 42338, 2013, 47, 70, "Print"],
Cell[1536890, 42387, 2075, 50, 70, "Print"],
Cell[1538968, 42439, 1987, 46, 70, "Print"],
Cell[1540958, 42487, 2049, 49, 70, "Print"],
Cell[1543010, 42538, 2052, 49, 70, "Print"],
Cell[1545065, 42589, 2108, 51, 70, "Print"]
}, Closed]],

Cell[CellGroupData[{
Cell[1547210, 42645, 437, 9, 97, "Input",
  CellTags->"Cell 6.31"],
Cell[1547650, 42656, 331817, 6400, 302, 246553, 5343, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1879482, 49059, 555, 15, 62, "Text"],
Cell[1880040, 49076, 33125, 774, 233, 8539, 466, "GraphicsData", \
"PostScript", "Picture"],
Cell[1913168, 49852, 640, 18, 17, "Caption",
  CellTags->"Fig. 6.2"],
Cell[1913811, 49872, 597, 13, 78, "Text"],
Cell[1914411, 49887, 28974, 786, 233, 9722, 544, "GraphicsData", \
"PostScript", "Picture"],
Cell[1943388, 50675, 651, 18, 30, "Caption",
  CellTags->"Fig. 6.3"],
Cell[1944042, 50695, 655, 11, 95, "Text"],
Cell[1944700, 50708, 282, 8, 44, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1945031, 50722, 81, 1, 30, "Subsubtitle",
  CellTags->{"i:11", "c:9"}],

Cell[CellGroupData[{
Cell[1945137, 50727, 56, 1, 42, "Section",
  CellTags->"c:10"],
Cell[1945196, 50730, 304, 7, 44, "Text"],
Cell[1945503, 50739, 248, 7, 42, "NumberedEquation",
  CellTags->"(6.1.15)"],
Cell[1945754, 50748, 53, 0, 27, "Text"],
Cell[1945810, 50750, 206, 4, 57, "NumberedEquation",
  CellTags->"(6.1.16)"],
Cell[1946019, 50756, 41, 0, 27, "Text"],
Cell[1946063, 50758, 137, 5, 29, "NumberedEquation",
  CellTags->"(6.1.17)"],
Cell[1946203, 50765, 61, 0, 27, "Text"],
Cell[1946267, 50767, 211, 7, 33, "NumberedEquation",
  CellTags->"(6.1.18)"],
Cell[1946481, 50776, 191, 6, 27, "Text"],
Cell[1946675, 50784, 180, 6, 29, "NumberedEquation",
  CellTags->"(6.1.19)"],
Cell[1946858, 50792, 27, 0, 27, "Text"],
Cell[1946888, 50794, 570, 16, 61, "Text",
  CellTags->"i:12"],
Cell[1947461, 50812, 164, 6, 37, "Text"],
Cell[1947628, 50820, 575, 16, 74, "Text"],
Cell[1948206, 50838, 215, 7, 35, "NumberedEquation",
  CellTags->"(6.1.20)"],
Cell[1948424, 50847, 224, 9, 27, "Text"],

Cell[CellGroupData[{
Cell[1948673, 50860, 227, 5, 116, "Input",
  CellTags->"Cell 6.32"],
Cell[1948903, 50867, 27772, 737, 233, 7010, 477, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1976690, 51607, 94, 3, 27, "Text"],
Cell[1976787, 51612, 191, 6, 34, "NumberedEquation",
  CellTags->"(6.1.21)"],
Cell[1976981, 51620, 478, 17, 44, "Text"],
Cell[1977462, 51639, 399, 9, 42, "NumberedEquation",
  CellTags->"(6.1.22)"],
Cell[1977864, 51650, 138, 5, 29, "Text"],
Cell[1978005, 51657, 264, 5, 42, "NumberedEquation",
  CellTags->"(6.1.23)"],
Cell[1978272, 51664, 249, 9, 27, "Text"],
Cell[1978524, 51675, 455, 11, 42, "NumberedEquation",
  CellTags->"(6.1.24)"],
Cell[1978982, 51688, 715, 24, 61, "Text"],
Cell[1979700, 51714, 210, 6, 33, "NumberedEquation",
  CellTags->"(6.1.25)"],
Cell[1979913, 51722, 255, 7, 44, "Text"],
Cell[1980171, 51731, 289, 9, 33, "NumberedEquation",
  CellTags->"(6.1.26)"],
Cell[1980463, 51742, 391, 17, 27, "Text"],
Cell[1980857, 51761, 4013, 132, 112, "Text"],
Cell[1984873, 51895, 660, 17, 78, "Text"],
Cell[1985536, 51914, 236, 5, 124, "Input",
  CellTags->"Cell 6.33"],
Cell[1985775, 51921, 143, 3, 27, "Text"],
Cell[1985921, 51926, 286, 10, 44, "Text"],
Cell[1986210, 51938, 106, 3, 67, "Input",
  CellTags->"Cell 6.34"],
Cell[1986319, 51943, 402, 12, 44, "Text"],
Cell[1986724, 51957, 163, 4, 67, "Input",
  CellTags->"Cell 6.35"],
Cell[1986890, 51963, 194, 6, 32, "Text"],
Cell[1987087, 51971, 120, 3, 67, "Input",
  CellTags->"Cell 6.36"],
Cell[1987210, 51976, 192, 5, 32, "Text"],
Cell[1987405, 51983, 127, 3, 67, "Input",
  CellTags->"Cell 6.37"],
Cell[1987535, 51988, 559, 14, 78, "Text"],
Cell[1988097, 52004, 275, 6, 86, "Input",
  CellTags->"Cell 6.38"],
Cell[1988375, 52012, 227, 8, 29, "Text"],
Cell[1988605, 52022, 178, 5, 67, "Input",
  CellTags->"Cell 6.39"],
Cell[1988786, 52029, 107, 3, 27, "Text"],
Cell[1988896, 52034, 262, 6, 86, "Input",
  CellTags->"Cell 6.40"],
Cell[1989161, 52042, 67, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[1989253, 52046, 137, 3, 67, "Input",
  CellTags->"Cell 6.41"],
Cell[1989393, 52051, 3750, 106, 70, "Print"],
Cell[1993146, 52159, 3813, 108, 70, "Print"],
Cell[1996962, 52269, 3722, 105, 70, "Print"],
Cell[2000687, 52376, 3906, 110, 70, "Print"],
Cell[2004596, 52488, 3809, 107, 70, "Print"],
Cell[2008408, 52597, 3961, 112, 70, "Print"],
Cell[2012372, 52711, 3829, 107, 70, "Print"],
Cell[2016204, 52820, 4120, 117, 70, "Print"]
}, Closed]],
Cell[2020339, 52940, 234, 7, 21, "Text"],

Cell[CellGroupData[{
Cell[2020598, 52951, 315, 6, 124, "Input",
  CellTags->"Cell 6.42"],
Cell[2020916, 52959, 1122, 33, 70, "Print"],
Cell[2022041, 52994, 1124, 33, 70, "Print"],
Cell[2023168, 53029, 1114, 33, 70, "Print"],
Cell[2024285, 53064, 1169, 34, 70, "Print"],
Cell[2025457, 53100, 1149, 34, 70, "Print"],
Cell[2026609, 53136, 1172, 33, 70, "Print"],
Cell[2027784, 53171, 1146, 33, 70, "Print"],
Cell[2028933, 53206, 1208, 35, 70, "Print"]
}, Closed]],
Cell[2030156, 53244, 238, 7, 38, "Text"],
Cell[2030397, 53253, 161, 5, 67, "Input",
  CellTags->"Cell 6.43"],
Cell[2030561, 53260, 91, 3, 27, "Text"],
Cell[2030655, 53265, 125, 3, 67, "Input",
  CellTags->"Cell 6.44"],
Cell[2030783, 53270, 174, 5, 27, "Text"],
Cell[2030960, 53277, 401, 9, 124, "Input",
  CellTags->"Cell 6.45"],
Cell[2031364, 53288, 146, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[2031535, 53298, 299, 7, 105, "Input",
  CellTags->"Cell 6.46"],

Cell[CellGroupData[{
Cell[2031859, 53309, 28584, 773, 233, 8134, 517, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2060446, 54084, 22064, 781, 70, 9872, 627, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2082513, 54867, 21314, 720, 70, 8854, 562, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2103830, 55589, 21129, 697, 70, 8451, 537, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2124962, 56288, 20622, 688, 70, 8389, 533, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2145587, 56978, 20805, 712, 70, 8819, 560, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2166395, 57692, 20802, 715, 70, 8844, 563, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2187200, 58409, 21353, 722, 70, 8873, 564, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2208556, 59133, 21578, 722, 70, 8835, 561, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2230137, 59857, 21813, 727, 70, 8863, 563, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2251953, 60586, 21456, 719, 70, 8798, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2273412, 61307, 20891, 711, 70, 8751, 557, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2294306, 62020, 20710, 713, 70, 8858, 563, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2315019, 62735, 21146, 718, 70, 8848, 562, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2336168, 63455, 21439, 721, 70, 8846, 562, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2357610, 64178, 21718, 724, 70, 8829, 561, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2379331, 64904, 21494, 720, 70, 8816, 560, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2400828, 65626, 21091, 718, 70, 8870, 563, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2421922, 66346, 20718, 715, 70, 8890, 565, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2442643, 67063, 21064, 718, 70, 8876, 564, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2463710, 67783, 21485, 723, 70, 8851, 563, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2485198, 68508, 21834, 724, 70, 8799, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2507035, 69234, 21684, 722, 70, 8795, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2528722, 69958, 21435, 722, 70, 8862, 563, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2550160, 70682, 20846, 714, 70, 8852, 562, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2571009, 71398, 21002, 714, 70, 8818, 560, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2592014, 72114, 21352, 722, 70, 8880, 564, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2613369, 72838, 21762, 725, 70, 8841, 562, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2635134, 73565, 21710, 724, 70, 8821, 561, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2656847, 74291, 21472, 719, 70, 8802, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2678322, 75012, 21181, 734, 70, 9167, 582, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Open  ]],
Cell[2699530, 75750, 402, 9, 61, "Text"],
Cell[2699935, 75761, 109, 4, 27, "Text",
  CellTags->"i:13"],
Cell[2700047, 75767, 5708, 118, 850, "Input",
  CellTags->"Cell 6.47"]
}, Closed]],

Cell[CellGroupData[{
Cell[2705792, 75890, 97, 1, 31, "Section",
  CellTags->{"i:14", "c:11"}],
Cell[2705892, 75893, 282, 5, 61, "Text"],
Cell[2706177, 75900, 347, 10, 44, "Text"],
Cell[2706527, 75912, 334, 9, 42, "NumberedEquation",
  CellTags->"(6.1.27)"],
Cell[2706864, 75923, 61, 0, 27, "Text"],
Cell[2706928, 75925, 147, 5, 29, "NumberedEquation",
  CellTags->"(6.1.28)"],
Cell[2707078, 75932, 155, 7, 27, "Text"],
Cell[2707236, 75941, 553, 15, 45, "NumberedEquation",
  CellTags->"(6.1.29)"],
Cell[2707792, 75958, 462, 12, 61, "Text"],
Cell[2708257, 75972, 337, 11, 38, "NumberedEquation",
  CellTags->"(6.1.30)"],
Cell[2708597, 75985, 166, 6, 27, "Text"],
Cell[2708766, 75993, 492, 11, 42, "NumberedEquation",
  CellTags->"(6.1.31)"],
Cell[2709261, 76006, 284, 9, 46, "Text"],
Cell[2709548, 76017, 195, 6, 34, "NumberedEquation",
  CellTags->"(6.1.32)"],
Cell[2709746, 76025, 421, 12, 47, "Text"],
Cell[2710170, 76039, 337, 9, 42, "NumberedEquation",
  CellTags->"(6.1.33)"],
Cell[2710510, 76050, 165, 5, 29, "Text"],
Cell[2710678, 76057, 351, 9, 37, "NumberedEquation",
  CellTags->"(6.1.34)"],
Cell[2711032, 76068, 198, 6, 27, "Text"],
Cell[2711233, 76076, 200, 6, 42, "NumberedEquation",
  CellTags->"(6.1.35)"],
Cell[2711436, 76084, 569, 18, 44, "Text"],
Cell[2712008, 76104, 472, 10, 38, "NumberedEquation",
  CellTags->"(6.1.36)"],
Cell[2712483, 76116, 202, 5, 52, "Text"],
Cell[2712688, 76123, 104, 3, 67, "Input",
  CellTags->"Cell 6.48"],
Cell[2712795, 76128, 302, 10, 44, "Text"],
Cell[2713100, 76140, 216, 6, 36, "UNNEQ"],
Cell[2713319, 76148, 370, 10, 48, "Text"],
Cell[2713692, 76160, 170, 6, 27, "Text"],
Cell[2713865, 76168, 220, 6, 55, "UNNEQ"],
Cell[2714088, 76176, 996, 28, 97, "Text"],
Cell[2715087, 76206, 3458, 69, 626, "Input",
  CellTags->"Cell 6.49"],
Cell[2718548, 76277, 560, 19, 44, "Text"],

Cell[CellGroupData[{
Cell[2719133, 76300, 123, 3, 67, "Input",
  CellTags->"Cell 6.50"],
Cell[2719259, 76305, 408, 9, 35, "Print"],
Cell[2719670, 76316, 409, 9, 35, "Print"],
Cell[2720082, 76327, 404, 8, 35, "Print"],
Cell[2720489, 76337, 406, 8, 35, "Print"],
Cell[2720898, 76347, 404, 8, 35, "Print"],
Cell[2721305, 76357, 409, 9, 35, "Print"],
Cell[2721717, 76368, 407, 9, 35, "Print"],
Cell[2722127, 76379, 410, 9, 35, "Print"],
Cell[2722540, 76390, 403, 8, 35, "Print"],
Cell[2722946, 76400, 404, 8, 35, "Print"],
Cell[2723353, 76410, 406, 8, 35, "Print"],
Cell[2723762, 76420, 409, 9, 35, "Print"],
Cell[2724174, 76431, 409, 9, 35, "Print"],
Cell[2724586, 76442, 410, 9, 35, "Print"],
Cell[2724999, 76453, 403, 8, 35, "Print"],
Cell[2725405, 76463, 403, 8, 35, "Print"],
Cell[2725811, 76473, 405, 8, 35, "Print"],
Cell[2726219, 76483, 408, 9, 35, "Print"],
Cell[2726630, 76494, 410, 9, 35, "Print"],
Cell[2727043, 76505, 409, 9, 35, "Print"],
Cell[2727455, 76516, 403, 8, 35, "Print"],
Cell[2727861, 76526, 406, 8, 35, "Print"],
Cell[2728270, 76536, 405, 8, 35, "Print"],
Cell[2728678, 76546, 402, 9, 35, "Print"],
Cell[2729083, 76557, 410, 9, 35, "Print"],
Cell[2729496, 76568, 408, 9, 35, "Print"],
Cell[2729907, 76579, 405, 8, 35, "Print"],
Cell[2730315, 76589, 405, 8, 35, "Print"],
Cell[2730723, 76599, 404, 8, 35, "Print"],
Cell[2731130, 76609, 401, 9, 35, "Print"],
Cell[2731534, 76620, 400, 9, 35, "Print"],
Cell[2731937, 76631, 401, 9, 35, "Print"],
Cell[2732341, 76642, 400, 8, 35, "Print"],
Cell[2732744, 76652, 402, 8, 35, "Print"],
Cell[2733149, 76662, 403, 8, 35, "Print"],
Cell[2733555, 76672, 394, 8, 35, "Print"],
Cell[2733952, 76682, 401, 9, 35, "Print"],
Cell[2734356, 76693, 393, 8, 35, "Print"],
Cell[2734752, 76703, 401, 8, 35, "Print"],
Cell[2735156, 76713, 402, 8, 35, "Print"],
Cell[2735561, 76723, 400, 8, 35, "Print"],
Cell[2735964, 76733, 402, 9, 35, "Print"],
Cell[2736369, 76744, 401, 9, 35, "Print"],
Cell[2736773, 76755, 392, 8, 35, "Print"],
Cell[2737168, 76765, 400, 8, 35, "Print"],
Cell[2737571, 76775, 405, 8, 35, "Print"],
Cell[2737979, 76785, 404, 8, 35, "Print"],
Cell[2738386, 76795, 442, 9, 31, "Print"],
Cell[2738831, 76806, 438, 9, 35, "Print"],
Cell[2739272, 76817, 441, 9, 31, "Print"],
Cell[2739716, 76828, 402, 8, 31, "Print"],
Cell[2740121, 76838, 399, 8, 31, "Print"],
Cell[2740523, 76848, 399, 8, 31, "Print"],
Cell[2740925, 76858, 434, 9, 31, "Print"],
Cell[2741362, 76869, 434, 9, 31, "Print"],
Cell[2741799, 76880, 429, 9, 31, "Print"],
Cell[2742231, 76891, 396, 8, 31, "Print"],
Cell[2742630, 76901, 397, 8, 31, "Print"],
Cell[2743030, 76911, 396, 8, 31, "Print"],
Cell[2743429, 76921, 431, 9, 31, "Print"],
Cell[2743863, 76932, 419, 9, 31, "Print"],
Cell[2744285, 76943, 418, 9, 31, "Print"],
Cell[2744706, 76954, 380, 8, 31, "Print"],
Cell[2745089, 76964, 383, 8, 31, "Print"],
Cell[2745475, 76974, 380, 8, 31, "Print"],
Cell[2745858, 76984, 417, 9, 31, "Print"],
Cell[2746278, 76995, 414, 9, 31, "Print"],
Cell[2746695, 77006, 415, 9, 31, "Print"],
Cell[2747113, 77017, 377, 8, 31, "Print"],
Cell[2747493, 77027, 379, 8, 31, "Print"],
Cell[2747875, 77037, 383, 8, 31, "Print"],
Cell[2748261, 77047, 418, 9, 31, "Print"],
Cell[2748682, 77058, 419, 9, 31, "Print"],
Cell[2749104, 77069, 415, 9, 31, "Print"],
Cell[2749522, 77080, 377, 8, 31, "Print"],
Cell[2749902, 77090, 384, 8, 31, "Print"],
Cell[2750289, 77100, 382, 8, 31, "Print"],
Cell[2750674, 77110, 418, 9, 31, "Print"],
Cell[2751095, 77121, 418, 9, 31, "Print"],
Cell[2751516, 77132, 416, 9, 31, "Print"],
Cell[2751935, 77143, 381, 8, 31, "Print"],
Cell[2752319, 77153, 381, 8, 31, "Print"],
Cell[2752703, 77163, 382, 8, 31, "Print"],
Cell[2753088, 77173, 417, 9, 31, "Print"],
Cell[2753508, 77184, 418, 9, 31, "Print"],
Cell[2753929, 77195, 415, 9, 31, "Print"],
Cell[2754347, 77206, 380, 8, 31, "Print"],
Cell[2754730, 77216, 383, 8, 31, "Print"],
Cell[2755116, 77226, 381, 8, 31, "Print"],
Cell[2755500, 77236, 415, 9, 31, "Print"],
Cell[2755918, 77247, 418, 9, 31, "Print"],
Cell[2756339, 77258, 417, 9, 31, "Print"],
Cell[2756759, 77269, 377, 8, 31, "Print"],
Cell[2757139, 77279, 384, 8, 31, "Print"],
Cell[2757526, 77289, 383, 8, 31, "Print"],
Cell[2757912, 77299, 416, 9, 31, "Print"],
Cell[2758331, 77310, 419, 9, 31, "Print"],
Cell[2758753, 77321, 418, 9, 31, "Print"],
Cell[2759174, 77332, 381, 8, 31, "Print"],
Cell[2759558, 77342, 384, 8, 31, "Print"],
Cell[2759945, 77352, 384, 8, 31, "Print"],
Cell[2760332, 77362, 419, 9, 31, "Print"],
Cell[2760754, 77373, 422, 9, 31, "Print"],
Cell[2761179, 77384, 420, 9, 31, "Print"],
Cell[2761602, 77395, 385, 8, 31, "Print"],
Cell[2761990, 77405, 385, 8, 31, "Print"],
Cell[2762378, 77415, 385, 8, 31, "Print"],
Cell[2762766, 77425, 422, 9, 31, "Print"],
Cell[2763191, 77436, 423, 9, 31, "Print"],
Cell[2763617, 77447, 422, 9, 31, "Print"],
Cell[2764042, 77458, 386, 8, 31, "Print"],
Cell[2764431, 77468, 390, 8, 31, "Print"],
Cell[2764824, 77478, 388, 8, 31, "Print"],
Cell[2765215, 77488, 423, 9, 31, "Print"],
Cell[2765641, 77499, 424, 9, 31, "Print"],
Cell[2766068, 77510, 425, 9, 31, "Print"],
Cell[2766496, 77521, 388, 8, 31, "Print"],
Cell[2766887, 77531, 392, 8, 31, "Print"],
Cell[2767282, 77541, 391, 8, 31, "Print"],
Cell[2767676, 77551, 430, 9, 31, "Print"],
Cell[2768109, 77562, 425, 9, 35, "Print"],
Cell[2768537, 77573, 15511, 379, 815, "Print"],
Cell[2784051, 77954, 15495, 379, 831, "Print"],
Cell[2799549, 78335, 15488, 379, 831, "Print"],
Cell[2815040, 78716, 15493, 379, 831, "Print"],
Cell[2830536, 79097, 15484, 379, 831, "Print"],
Cell[2846023, 79478, 15478, 379, 831, "Print"],
Cell[2861504, 79859, 15482, 379, 831, "Print"],
Cell[2876989, 80240, 15471, 379, 831, "Print"],
Cell[2892463, 80621, 15468, 379, 831, "Print"],
Cell[2907934, 81002, 15470, 379, 831, "Print"],
Cell[2923407, 81383, 15459, 379, 831, "Print"],
Cell[2938869, 81764, 15456, 379, 831, "Print"],
Cell[2954328, 82145, 15457, 379, 831, "Print"],
Cell[2969788, 82526, 15453, 379, 831, "Print"],
Cell[2985244, 82907, 15449, 379, 813, "Print"],
Cell[3000696, 83288, 15457, 379, 835, "Print"],
Cell[3016156, 83669, 15451, 379, 813, "Print"],
Cell[3031610, 84050, 15451, 379, 813, "Print"],
Cell[3047064, 84431, 15452, 379, 832, "Print"],
Cell[3062519, 84812, 15449, 379, 831, "Print"],
Cell[3077971, 85193, 15445, 379, 831, "Print"],
Cell[3093419, 85574, 15452, 379, 812, "Print"],
Cell[3108874, 85955, 15443, 379, 813, "Print"],
Cell[3124320, 86336, 15447, 379, 813, "Print"],
Cell[3139770, 86717, 15451, 379, 813, "Print"],
Cell[3155224, 87098, 15442, 379, 813, "Print"],
Cell[3170669, 87479, 15449, 379, 813, "Print"],
Cell[3186121, 87860, 15451, 379, 813, "Print"],
Cell[3201575, 88241, 15440, 379, 813, "Print"],
Cell[3217018, 88622, 15449, 379, 813, "Print"],
Cell[3232470, 89003, 15458, 379, 816, "Print"],
Cell[3247931, 89384, 15433, 379, 813, "Print"],
Cell[3263367, 89765, 15442, 379, 813, "Print"],
Cell[3278812, 90146, 15438, 379, 813, "Print"],
Cell[3294253, 90527, 15428, 379, 813, "Print"],
Cell[3309684, 90908, 15430, 379, 812, "Print"],
Cell[3325117, 91289, 15432, 379, 812, "Print"],
Cell[3340552, 91670, 15423, 379, 812, "Print"],
Cell[3355978, 92051, 15426, 379, 812, "Print"],
Cell[3371407, 92432, 15421, 379, 812, "Print"],
Cell[3386831, 92813, 15415, 379, 812, "Print"],
Cell[3402249, 93194, 15420, 379, 813, "Print"],
Cell[3417672, 93575, 15415, 379, 813, "Print"],
Cell[3433090, 93956, 15416, 379, 813, "Print"],
Cell[3448509, 94337, 15418, 379, 813, "Print"],
Cell[3463930, 94718, 15415, 379, 816, "Print"],
Cell[3479348, 95099, 15421, 379, 813, "Print"],
Cell[3494772, 95480, 15421, 379, 813, "Print"],
Cell[3510196, 95861, 15413, 379, 813, "Print"],
Cell[3525612, 96242, 15425, 379, 813, "Print"],
Cell[3541040, 96623, 15422, 379, 813, "Print"],
Cell[3556465, 97004, 15410, 379, 813, "Print"],
Cell[3571878, 97385, 15420, 379, 813, "Print"],
Cell[3587301, 97766, 15419, 379, 813, "Print"],
Cell[3602723, 98147, 15415, 379, 813, "Print"],
Cell[3618141, 98528, 15420, 379, 813, "Print"],
Cell[3633564, 98909, 15420, 379, 813, "Print"],
Cell[3648987, 99290, 15418, 379, 813, "Print"],
Cell[3664408, 99671, 15420, 379, 813, "Print"],
Cell[3679831, 100052, 15422, 379, 813, "Print"],
Cell[3695256, 100433, 15369, 378, 816, "Print"],
Cell[3710628, 100813, 15407, 379, 813, "Print"],
Cell[3726038, 101194, 15405, 379, 813, "Print"],
Cell[3741446, 101575, 15403, 379, 812, "Print"],
Cell[3756852, 101956, 15405, 379, 812, "Print"],
Cell[3772260, 102337, 15405, 379, 812, "Print"],
Cell[3787668, 102718, 15400, 379, 812, "Print"],
Cell[3803071, 103099, 15404, 379, 812, "Print"],
Cell[3818478, 103480, 15405, 379, 812, "Print"],
Cell[3833886, 103861, 15395, 379, 812, "Print"],
Cell[3849284, 104242, 15407, 379, 812, "Print"],
Cell[3864694, 104623, 15410, 379, 812, "Print"],
Cell[3880107, 105004, 15398, 379, 812, "Print"],
Cell[3895508, 105385, 15406, 379, 813, "Print"],
Cell[3910917, 105766, 15406, 379, 813, "Print"],
Cell[3926326, 106147, 15405, 379, 816, "Print"],
Cell[3941734, 106528, 15413, 379, 813, "Print"],
Cell[3957150, 106909, 15411, 379, 813, "Print"],
Cell[3972564, 107290, 15410, 379, 813, "Print"],
Cell[3987977, 107671, 15415, 379, 813, "Print"],
Cell[4003395, 108052, 15410, 379, 813, "Print"],
Cell[4018808, 108433, 15416, 379, 813, "Print"],
Cell[4034227, 108814, 15421, 379, 813, "Print"],
Cell[4049651, 109195, 15418, 379, 813, "Print"],
Cell[4065072, 109576, 15427, 379, 813, "Print"],
Cell[4080502, 109957, 15425, 379, 813, "Print"],
Cell[4095930, 110338, 15423, 379, 813, "Print"],
Cell[4111356, 110719, 15433, 379, 813, "Print"],
Cell[4126792, 111100, 15437, 379, 794, "Print"],
Cell[4142232, 111481, 15428, 379, 813, "Print"],
Cell[4157663, 111862, 15448, 379, 816, "Print"],
Cell[4173114, 112243, 15434, 379, 813, "Print"],
Cell[4188551, 112624, 15425, 379, 813, "Print"],
Cell[4203979, 113005, 15436, 379, 812, "Print"],
Cell[4219418, 113386, 15434, 379, 812, "Print"],
Cell[4234855, 113767, 15427, 379, 812, "Print"],
Cell[4250285, 114148, 15436, 379, 812, "Print"],
Cell[4265724, 114529, 15432, 379, 812, "Print"],
Cell[4281159, 114910, 15428, 379, 812, "Print"],
Cell[4296590, 115291, 15437, 379, 812, "Print"],
Cell[4312030, 115672, 15430, 379, 812, "Print"],
Cell[4327463, 116053, 15434, 379, 813, "Print"],
Cell[4342900, 116434, 15437, 379, 813, "Print"],
Cell[4358340, 116815, 15436, 379, 813, "Print"],
Cell[4373779, 117196, 15436, 379, 813, "Print"],
Cell[4389218, 117577, 15447, 379, 816, "Print"],
Cell[4404668, 117958, 15444, 379, 813, "Print"],
Cell[4420115, 118339, 15448, 379, 813, "Print"],
Cell[4435566, 118720, 15452, 379, 813, "Print"],
Cell[4451021, 119101, 15451, 379, 813, "Print"],
Cell[4466475, 119482, 15454, 379, 813, "Print"],
Cell[4481932, 119863, 15465, 379, 832, "Print"],
Cell[4497400, 120244, 15463, 379, 813, "Print"],
Cell[4512866, 120625, 15466, 379, 813, "Print"],
Cell[4528335, 121006, 15477, 379, 813, "Print"],
Cell[4543815, 121387, 15473, 379, 813, "Print"],
Cell[4559291, 121768, 15479, 379, 813, "Print"],
Cell[4574773, 122149, 15488, 379, 813, "Print"],
Cell[4590264, 122530, 15483, 379, 813, "Print"],
Cell[4605750, 122911, 15490, 379, 813, "Print"],
Cell[4621243, 123292, 15506, 379, 816, "Print"]
}, Closed]],

Cell[CellGroupData[{
Cell[4636786, 123676, 342, 7, 112, "Input",
  CellTags->"Cell 6.51"],

Cell[CellGroupData[{
Cell[4637153, 123687, 35767, 936, 233, 9957, 612, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4672923, 124625, 39372, 1297, 233, 13915, 978, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4712298, 125924, 40828, 1523, 233, 16573, 1218, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4753129, 127449, 39454, 1516, 233, 16694, 1230, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4792586, 128967, 38300, 1483, 233, 16524, 1209, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4830889, 130452, 37806, 1499, 233, 16937, 1236, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4868698, 131953, 37736, 1492, 233, 16948, 1230, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4906437, 133447, 39037, 1521, 233, 17439, 1249, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4945477, 134970, 40859, 1541, 233, 17585, 1249, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4986339, 136513, 40957, 1485, 233, 16856, 1182, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5027299, 138000, 41427, 1519, 233, 17468, 1218, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5068729, 139521, 41273, 1473, 233, 17148, 1170, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5110005, 140996, 40694, 1451, 233, 17120, 1155, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5150702, 142449, 39316, 1358, 233, 16123, 1067, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5190021, 143809, 36725, 1230, 233, 14661, 952, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5226749, 145041, 34699, 1132, 233, 13753, 868, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5261451, 146175, 34067, 1109, 233, 13749, 853, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5295521, 147286, 33398, 1066, 233, 13307, 813, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5328922, 148354, 33096, 1045, 233, 13284, 795, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5362021, 149401, 32017, 993, 233, 12695, 749, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5394041, 150396, 33001, 1057, 233, 13768, 814, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5427045, 151455, 33246, 1072, 233, 14022, 830, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5460294, 152529, 33028, 1086, 233, 14342, 850, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5493325, 153617, 33697, 1139, 233, 15234, 906, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5527025, 154758, 35842, 1242, 233, 16735, 1001, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[5562894, 156004, 1019, 24, 112, "Text",
  CellTags->"i:16"],
Cell[5563916, 156030, 1214, 32, 129, "Text"],
Cell[5565133, 156064, 650, 13, 95, "Text",
  CellTags->"i:15"],
Cell[5565786, 156079, 345, 8, 61, "Text"],
Cell[5566134, 156089, 588, 9, 95, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[5566771, 156104, 65, 1, 30, "Subsubtitle",
  CellTags->"c:12"],
Cell[5566839, 156107, 507, 13, 64, "Text"],
Cell[5567349, 156122, 21731, 272, 73, 21609, 268, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[5589083, 156396, 65, 1, 16, "Caption",
  CellTags->"Fig. 6.4"],
Cell[5589151, 156399, 1268, 36, 101, "Text"],
Cell[5590422, 156437, 1451, 42, 116, "Text"],
Cell[5591876, 156481, 33180, 413, 174, 33062, 409, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[5625059, 156896, 65, 1, 16, "Caption",
  CellTags->"Fig. 6.5"],
Cell[5625127, 156899, 865, 24, 82, "Text"],
Cell[5625995, 156925, 432, 12, 61, "Text"],
Cell[5626430, 156939, 804, 25, 86, "Text"],
Cell[5627237, 156966, 621, 20, 44, "Text"],
Cell[5627861, 156988, 530, 15, 41, "Text"],
Cell[5628394, 157005, 995, 32, 86, "Text"],
Cell[5629392, 157039, 1481, 46, 95, "Text"],
Cell[5630876, 157087, 1389, 43, 44, "Text"],
Cell[5632268, 157132, 218, 5, 44, "Text"],
Cell[5632489, 157139, 1599, 49, 86, "Text"],
Cell[5634091, 157190, 293, 8, 43, "Text"],
Cell[5634387, 157200, 567, 17, 72, "Text"],
Cell[5634957, 157219, 936, 29, 90, "Text"],
Cell[5635896, 157250, 602, 18, 40, "Text"],
Cell[5636501, 157270, 1430, 44, 50, "Text"],
Cell[5637934, 157316, 711, 21, 65, "Text"],
Cell[5638648, 157339, 428, 13, 64, "Text"],
Cell[5639079, 157354, 222, 6, 42, "NumberedEquation",
  CellTags->{"i:37", "(6.1.37)"}],
Cell[5639304, 157362, 228, 8, 27, "Text"],
Cell[5639535, 157372, 651, 23, 47, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[5640235, 157401, 66, 1, 40, "Subtitle",
  CellTags->{"i:17", "c:13"}],
Cell[5640304, 157404, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[5640345, 157408, 72, 1, 41, "Subsubtitle",
  CellTags->"c:14"],

Cell[CellGroupData[{
Cell[5640442, 157413, 82, 1, 42, "Section",
  CellTags->{"i:18", "c:15"}],
Cell[5640527, 157416, 518, 13, 61, "Text"],
Cell[5641048, 157431, 211, 6, 44, "Text"],
Cell[5641262, 157439, 234, 7, 42, "NE2",
  CellTags->"(6.2.1)"],
Cell[5641499, 157448, 480, 14, 44, "Text"],
Cell[5641982, 157464, 775, 24, 45, "NE2",
  CellTags->"(6.2.2)"],
Cell[5642760, 157490, 948, 29, 64, "Text"],
Cell[5643711, 157521, 509, 10, 78, "Text"],
Cell[5644223, 157533, 651, 19, 48, "NE2",
  CellTags->"(6.2.3)"],
Cell[5644877, 157554, 46, 0, 27, "Text"],
Cell[5644926, 157556, 835, 24, 45, "NE2",
  CellTags->"(6.2.4)"],
Cell[5645764, 157582, 480, 16, 50, "Text"],
Cell[5646247, 157600, 909, 25, 39, "NE2",
  CellTags->"(6.2.5)"],
Cell[5647159, 157627, 1779, 60, 84, "Text"],
Cell[5648941, 157689, 397, 9, 172, "Input",
  CellTags->"Cell 6.52"],
Cell[5649341, 157700, 1083, 34, 106, "Text"],
Cell[5650427, 157736, 225, 5, 86, "Input",
  CellTags->"Cell 6.53"],
Cell[5650655, 157743, 282, 7, 64, "Text"],
Cell[5650940, 157752, 102, 3, 27, "Text"],
Cell[5651045, 157757, 136, 3, 67, "Input",
  CellTags->"Cell 6.54"],
Cell[5651184, 157762, 1127, 40, 61, "Text"],
Cell[5652314, 157804, 359, 7, 146, "Input",
  CellTags->"Cell 6.55"],
Cell[5652676, 157813, 214, 7, 27, "Text"],

Cell[CellGroupData[{
Cell[5652915, 157824, 386, 9, 105, "Input",
  CellTags->"Cell 6.56"],

Cell[CellGroupData[{
Cell[5653326, 157837, 28292, 671, 233, 6999, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5681621, 158510, 27512, 663, 70, 7006, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5709136, 159175, 27105, 658, 70, 7004, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5736244, 159835, 27232, 659, 70, 7006, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5763479, 160496, 27293, 660, 70, 7006, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5790775, 161158, 27398, 662, 70, 7005, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5818176, 161822, 27538, 663, 70, 7004, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5845717, 162487, 27504, 663, 70, 7006, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5873224, 163152, 27632, 664, 70, 7005, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5900859, 163818, 27637, 664, 70, 7006, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5928499, 164484, 27303, 660, 70, 7004, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5955805, 165146, 27539, 663, 70, 7005, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5983347, 165811, 27529, 663, 70, 7003, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6010879, 166476, 27611, 664, 70, 7004, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6038493, 167142, 27548, 663, 70, 7006, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6066044, 167807, 27585, 664, 70, 7006, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6093632, 168473, 27665, 665, 70, 7005, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6121300, 169140, 27583, 664, 70, 7004, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6148886, 169806, 27693, 665, 70, 7005, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6176582, 170473, 27674, 665, 70, 7006, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6204259, 171140, 27423, 662, 70, 7005, 404, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[6231709, 171806, 2261, 70, 95, "Text",
  CellTags->"i:70"],

Cell[CellGroupData[{
Cell[6233995, 171880, 644, 14, 181, "Input",
  CellTags->"Cell 6.57"],

Cell[CellGroupData[{
Cell[6234664, 171898, 28325, 672, 233, 6999, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6262992, 172572, 27798, 666, 70, 7006, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6290793, 173240, 34996, 758, 70, 7032, 408, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6325792, 174000, 69135, 1194, 70, 7151, 424, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6394930, 175196, 70244, 1208, 70, 7162, 424, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6465177, 176406, 70783, 1215, 70, 7158, 424, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[6535987, 177625, 100, 3, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6536124, 177633, 79, 1, 31, "Section",
  CellTags->{"i:19", "c:16"}],
Cell[6536206, 177636, 1708, 44, 157, "Text",
  CellTags->"i:58"],
Cell[6537917, 177682, 1435, 36, 39, "UNNEQ"],
Cell[6539355, 177720, 91, 3, 27, "Text"],
Cell[6539449, 177725, 1025, 28, 39, "NE2",
  CellTags->"(6.2.6)"],
Cell[6540477, 177755, 115, 3, 27, "Text"],
Cell[6540595, 177760, 121, 5, 29, "NE2",
  CellTags->"(6.2.7)"],
Cell[6540719, 177767, 619, 20, 61, "Text"],
Cell[6541341, 177789, 872, 24, 39, "NE2",
  CellTags->"(6.2.8)"],
Cell[6542216, 177815, 1377, 33, 150, "Text"],
Cell[6543596, 177850, 1035, 34, 54, "Text"],
Cell[6544634, 177886, 48833, 1288, 233, 17077, 891, "GraphicsData", \
"PostScript", "Picture"],
Cell[6593470, 179176, 114, 4, 16, "Caption",
  CellTags->"Fig. 6.6"],
Cell[6593587, 179182, 1239, 38, 54, "Text"],
Cell[6594829, 179222, 554, 18, 39, "NE2",
  CellTags->"(6.2.9)"],
Cell[6595386, 179242, 1996, 63, 97, "Text",
  CellTags->"i:65"]
}, Closed]],

Cell[CellGroupData[{
Cell[6597419, 179310, 60, 1, 31, "Section",
  CellTags->{"i:20", "c:17"}],
Cell[6597482, 179313, 598, 13, 78, "Text"],
Cell[6598083, 179328, 928, 25, 39, "NE2",
  CellTags->"(6.2.10)"],
Cell[6599014, 179355, 482, 13, 68, "Text"],
Cell[6599499, 179370, 144, 5, 32, "NE2",
  CellTags->"(6.2.11)"],
Cell[6599646, 179377, 991, 30, 37, "Text"],

Cell[CellGroupData[{
Cell[6600662, 179411, 316, 7, 92, "Input",
  CellTags->"Cell 6.58"],
Cell[6600981, 179420, 21154, 552, 233, 5939, 360, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[6622150, 179975, 654, 17, 61, "Text"],
Cell[6622807, 179994, 139, 3, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6622983, 180002, 59, 1, 31, "Section",
  CellTags->{"i:21", "c:18"}],
Cell[6623045, 180005, 1395, 33, 139, "Text"],
Cell[6624443, 180040, 969, 25, 39, "NE2",
  CellTags->"(6.2.12)"],
Cell[6625415, 180067, 212, 6, 44, "Text"],
Cell[6625630, 180075, 725, 21, 33, "UNNEQ"],
Cell[6626358, 180098, 1189, 38, 48, "Text"],

Cell[CellGroupData[{
Cell[6627572, 180140, 506, 11, 122, "Input",
  CellTags->"Cell 6.59"],
Cell[6628081, 180153, 52333, 1215, 233, 13241, 728, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[6680429, 181371, 541, 15, 44, "Text"],
Cell[6680973, 181388, 527, 15, 33, "NE2",
  CellTags->"(6.2.13)"],
Cell[6681503, 181405, 719, 17, 78, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6682259, 181427, 96, 1, 31, "Section",
  CellTags->{"i:22", "c:19"}],
Cell[6682358, 181430, 855, 23, 92, "Text"],
Cell[6683216, 181455, 902, 25, 39, "NE2",
  CellTags->"(6.2.14)"],
Cell[6684121, 181482, 1194, 36, 107, "Text",
  CellTags->"i:25"],
Cell[6685318, 181520, 381, 11, 44, "Text"],
Cell[6685702, 181533, 638, 18, 35, "NE2",
  CellTags->"(6.2.15)"],
Cell[6686343, 181553, 990, 34, 31, "Text"],
Cell[6687336, 181589, 655, 22, 61, "Text"],
Cell[6687994, 181613, 1146, 30, 39, "NE2",
  CellTags->"(6.2.16)"],
Cell[6689143, 181645, 1147, 39, 61, "Text",
  CellTags->"i:23"],
Cell[6690293, 181686, 979, 27, 44, "NE2",
  CellTags->"(6.2.17)"],
Cell[6691275, 181715, 508, 16, 61, "Text"],
Cell[6691786, 181733, 61, 0, 27, "Text"],
Cell[6691850, 181735, 218, 6, 86, "Input",
  CellTags->"Cell 6.60"],
Cell[6692071, 181743, 705, 23, 44, "Text"],
Cell[6692779, 181768, 95, 3, 27, "Text"],
Cell[6692877, 181773, 234, 6, 124, "Input",
  CellTags->"Cell 6.61"],
Cell[6693114, 181781, 137, 3, 27, "Text"],
Cell[6693254, 181786, 226, 7, 36, "NE2",
  CellTags->"(6.2.18)"],
Cell[6693483, 181795, 1059, 30, 98, "Text"],
Cell[6694545, 181827, 832, 25, 64, "Text"],

Cell[CellGroupData[{
Cell[6695402, 181856, 174, 5, 67, "Input",
  CellTags->"Cell 6.62"],
Cell[6695579, 181863, 402, 8, 84, "Output"]
}, Open  ]],
Cell[6695996, 181874, 717, 21, 44, "Text"],
Cell[6696716, 181897, 1954, 41, 406, "Input",
  CellTags->"Cell 6.63"],
Cell[6698673, 181940, 1525, 51, 61, "Text"],

Cell[CellGroupData[{
Cell[6700223, 181995, 988, 20, 258, "Input",
  CellTags->"Cell 6.64"],

Cell[CellGroupData[{
Cell[6701236, 182019, 32685, 743, 233, 7134, 422, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6733924, 182764, 28721, 693, 70, 7148, 422, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6762648, 183459, 26067, 661, 70, 7138, 422, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6788718, 184122, 25414, 653, 70, 7141, 422, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6814135, 184777, 24309, 639, 70, 7142, 422, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6838447, 185418, 24466, 641, 70, 7149, 422, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6862916, 186061, 23958, 635, 70, 7147, 422, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6886877, 186698, 24004, 635, 70, 7149, 422, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6910884, 187335, 23303, 627, 70, 7144, 422, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[6934214, 187966, 146, 3, 44, "Text"],
Cell[6934363, 187971, 198, 4, 44, "Text"],

Cell[CellGroupData[{
Cell[6934586, 187979, 264, 7, 124, "Input",
  CellTags->"Cell 6.65"],
Cell[6934853, 187988, 133, 3, 46, "Output"]
}, Open  ]],
Cell[6935001, 187994, 1160, 41, 44, "Text"],

Cell[CellGroupData[{
Cell[6936186, 188039, 189, 4, 86, "Input",
  CellTags->"Cell 6.66"],
Cell[6936378, 188045, 97731, 1937, 344, 26949, 1059, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[7034158, 189988, 91, 1, 31, "Section",
  CellTags->{"i:24", "c:20"}],
Cell[7034252, 189991, 583, 14, 61, "Text"],
Cell[7034838, 190007, 361, 12, 43, "NE2",
  CellTags->"(6.2.19)"],
Cell[7035202, 190021, 122, 3, 27, "Text"],
Cell[7035327, 190026, 433, 15, 30, "NE2",
  CellTags->"(6.2.20)"],
Cell[7035763, 190043, 1208, 35, 79, "Text"],
Cell[7036974, 190080, 1091, 33, 80, "Text"],
Cell[7038068, 190115, 407, 15, 30, "NE2",
  CellTags->"(6.2.21)"],
Cell[7038478, 190132, 1660, 56, 78, "Text"],
Cell[7040141, 190190, 1198, 38, 61, "Text"],
Cell[7041342, 190230, 366, 9, 181, "Input",
  CellTags->"Cell 6.67"],
Cell[7041711, 190241, 195, 6, 27, "Text"],
Cell[7041909, 190249, 157, 4, 86, "Input",
  CellTags->"Cell 6.68"],
Cell[7042069, 190255, 183, 4, 44, "Text"],
Cell[7042255, 190261, 114, 3, 67, "Input",
  CellTags->"Cell 6.69"],
Cell[7042372, 190266, 456, 11, 64, "Text"],

Cell[CellGroupData[{
Cell[7042853, 190281, 148, 4, 67, "Input",
  CellTags->"Cell 6.70"],
Cell[7043004, 190287, 445, 9, 97, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7043486, 190301, 1007, 20, 277, "Input",
  CellTags->"Cell 6.71"],

Cell[CellGroupData[{
Cell[7044518, 190325, 29318, 736, 233, 7570, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7073839, 191063, 27748, 716, 70, 7592, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7101590, 191781, 26887, 706, 70, 7585, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7128480, 192489, 26725, 704, 70, 7589, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7155208, 193195, 26012, 695, 70, 7585, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7181223, 193892, 26514, 701, 70, 7589, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7207740, 194595, 26151, 697, 70, 7590, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7233894, 195294, 26230, 698, 70, 7584, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7260127, 195994, 25777, 692, 70, 7585, 463, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[7285931, 196690, 133, 3, 27, "Text"],
Cell[7286067, 196695, 752, 20, 78, "Text"],
Cell[7286822, 196717, 842, 27, 70, "Text"],
Cell[7287667, 196746, 400, 14, 43, "NE2",
  CellTags->"(6.2.22)"],
Cell[7288070, 196762, 150, 6, 29, "Text"],
Cell[7288223, 196770, 1012, 28, 43, "NE2",
  CellTags->"(6.2.23)"],
Cell[7289238, 196800, 740, 22, 70, "Text"],
Cell[7289981, 196824, 537, 14, 43, "NE2",
  CellTags->"(6.2.24)"],
Cell[7290521, 196840, 31, 0, 27, "Text"],
Cell[7290555, 196842, 1034, 27, 43, "NE2",
  CellTags->"(6.2.25)"],
Cell[7291592, 196871, 152, 3, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[7291781, 196879, 66, 1, 31, "Section",
  CellTags->"c:21"],

Cell[CellGroupData[{
Cell[7291872, 196884, 41, 0, 27, "Subsubsection"],
Cell[7291916, 196886, 215, 4, 44, "Text"],
Cell[7292134, 196892, 272, 7, 45, "NE2",
  CellTags->"(6.2.26)"],
Cell[7292409, 196901, 404, 14, 45, "Text"],
Cell[7292816, 196917, 791, 24, 48, "NE2",
  CellTags->"(6.2.27)"],
Cell[7293610, 196943, 695, 24, 28, "Text"],
Cell[7294308, 196969, 112, 3, 27, "Text"],
Cell[7294423, 196974, 1567, 41, 42, "NE2",
  CellTags->"(6.2.28)"],
Cell[7295993, 197017, 718, 16, 89, "Text"],
Cell[7296714, 197035, 1111, 32, 46, "NE2",
  CellTags->"(6.2.29)"],
Cell[7297828, 197069, 165, 4, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[7298030, 197078, 94, 1, 29, "Subsubsection",
  CellTags->"i:26"],
Cell[7298127, 197081, 185, 4, 44, "Text"],
Cell[7298315, 197087, 281, 8, 43, "Text"],
Cell[7298599, 197097, 416, 12, 44, "Text"],
Cell[7299018, 197111, 185, 6, 27, "Text"],
Cell[7299206, 197119, 48, 0, 27, "Text"],
Cell[7299257, 197121, 199, 7, 36, "Text"],
Cell[7299459, 197130, 192, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[7299676, 197140, 442, 9, 168, "Input",
  CellTags->"Cell 6.72"],
Cell[7300121, 197151, 111809, 2005, 302, 24367, 921, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[7411945, 199159, 1919, 58, 86, "Text"],
Cell[7413867, 199219, 1652, 31, 493, "Input",
  CellTags->"Cell 6.73"],
Cell[7415522, 199252, 56, 0, 27, "Text"],
Cell[7415581, 199254, 1559, 40, 48, "Text"],
Cell[7417143, 199296, 74, 0, 27, "Text"],
Cell[7417220, 199298, 612, 13, 246, "Input",
  CellTags->"Cell 6.74"],
Cell[7417835, 199313, 653, 20, 61, "Text"],
Cell[7418491, 199335, 939, 27, 85, "Text"],
Cell[7419433, 199364, 1231, 32, 48, "Text"],
Cell[7420667, 199398, 204, 6, 34, "Text"],
Cell[7420874, 199406, 106, 3, 67, "Input",
  CellTags->"Cell 6.75"],
Cell[7420983, 199411, 305, 10, 44, "Text"],
Cell[7421291, 199423, 267, 6, 126, "Input",
  CellTags->"Cell 6.76"],
Cell[7421561, 199431, 148, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[7421734, 199441, 354, 8, 105, "Input",
  CellTags->"Cell 6.77"],

Cell[CellGroupData[{
Cell[7422113, 199453, 257363, 4385, 302, 223328, 3960, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7679479, 203840, 268989, 4774, 70, 228101, 4264, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7948471, 208616, 283162, 5136, 70, 232076, 4500, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8231636, 213754, 295574, 5442, 70, 235408, 4694, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8527213, 219198, 299871, 5668, 70, 238599, 4906, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8827087, 224868, 302574, 5848, 70, 241217, 5085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9129664, 230718, 311534, 6090, 70, 244236, 5254, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9441201, 236810, 321804, 6345, 70, 247127, 5418, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9763008, 243157, 324630, 6489, 70, 249115, 5552, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10087641, 249648, 325897, 6606, 70, 250754, 5673, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10413541, 256256, 333352, 6817, 70, 253329, 5824, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10746896, 263075, 344256, 7071, 70, 256133, 5978, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11091155, 270148, 345088, 7168, 70, 257435, 6081, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11436246, 277318, 345782, 7293, 70, 259854, 6227, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11782031, 284613, 355119, 7530, 70, 262363, 6380, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12137153, 292145, 363979, 7753, 70, 265095, 6527, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12501135, 299900, 367280, 7941, 70, 267667, 6706, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12868418, 307843, 367929, 8064, 70, 270171, 6852, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13236350, 315909, 380017, 8360, 70, 273624, 7041, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13616370, 324271, 388473, 8590, 70, 276471, 7202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14004846, 332863, 387697, 8664, 70, 277623, 7300, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14392546, 341529, 386620, 8684, 70, 277891, 7337, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14779169, 350215, 394381, 8785, 70, 278479, 7349, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15173553, 359002, 397103, 8826, 70, 278686, 7359, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15570659, 367830, 392439, 8754, 70, 277869, 7334, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15963101, 376586, 389060, 8721, 70, 278111, 7346, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16352164, 385309, 396862, 8810, 70, 278303, 7341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16749029, 394121, 399169, 8837, 70, 278431, 7341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17148201, 402960, 393746, 8787, 70, 278403, 7358, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17541950, 411749, 390075, 8744, 70, 278268, 7359, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17932028, 420495, 399139, 8873, 70, 278948, 7384, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18331170, 429370, 400683, 8900, 70, 279411, 7398, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18731856, 438272, 398507, 8855, 70, 278786, 7372, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19130366, 447129, 394899, 8822, 70, 278681, 7382, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19525268, 455953, 401517, 8931, 70, 279350, 7418, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19926788, 464886, 404546, 8946, 70, 278989, 7391, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[20331361, 473836, 932, 22, 95, "Text",
  CellTags->"i:28"]
}, Closed]],

Cell[CellGroupData[{
Cell[20332330, 473863, 84, 1, 29, "Subsubsection",
  CellTags->"i:27"],
Cell[20332417, 473866, 207, 4, 44, "Text"],
Cell[20332627, 473872, 737, 18, 38, "NE2",
  CellTags->"(6.2.30)"],
Cell[20333367, 473892, 69, 0, 27, "Text"],
Cell[20333439, 473894, 1368, 37, 86, "UNNEQ"],
Cell[20334810, 473933, 638, 23, 45, "Text"],
Cell[20335451, 473958, 949, 24, 117, "Text"],
Cell[20336403, 473984, 1914, 49, 140, "Text",
  CellTags->"i:69"],
Cell[20338320, 474035, 1121, 29, 83, "NE2",
  CellTags->"(6.2.31)"],
Cell[20339444, 474066, 1960, 47, 179, "Text"],
Cell[20341407, 474115, 242, 6, 88, "Input",
  CellTags->"Cell 6.78"],
Cell[20341652, 474123, 340, 8, 64, "Text"],
Cell[20341995, 474133, 862, 17, 261, "Input",
  CellTags->"Cell 6.79"],
Cell[20342860, 474152, 69, 0, 27, "Text"],
Cell[20342932, 474154, 302, 8, 38, "NE2",
  CellTags->"(6.2.32)"],
Cell[20343237, 474164, 1064, 36, 48, "Text"],
Cell[20344304, 474202, 267, 7, 88, "Input",
  CellTags->"Cell 6.80"],
Cell[20344574, 474211, 110, 3, 27, "Text"],
Cell[20344687, 474216, 434, 9, 146, "Input",
  CellTags->"Cell 6.81"],
Cell[20345124, 474227, 28, 0, 27, "Text"],
Cell[20345155, 474229, 3653, 77, 652, "Input",
  CellTags->"Cell 6.82"],
Cell[20348811, 474308, 553, 19, 27, "Text"],

Cell[CellGroupData[{
Cell[20349389, 474331, 326, 8, 145, "Input",
  CellTags->"Cell 6.83"],
Cell[20349718, 474341, 152, 4, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20349907, 474350, 381, 8, 128, "Input",
  CellTags->"Cell 6.84"],

Cell[CellGroupData[{
Cell[20350313, 474362, 151810, 2655, 404, 28339, 1126, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20502126, 477019, 141266, 2527, 70, 28220, 1127, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20643395, 479548, 28412, 1130, 70, 28287, 1126, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[20671810, 480680, 28605, 1134, 70, 28480, 1130, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[20700418, 481816, 134495, 2443, 70, 28532, 1130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20834916, 484261, 134347, 2440, 70, 28555, 1130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20969266, 486703, 133455, 2430, 70, 28533, 1130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21102724, 489135, 133797, 2433, 70, 28588, 1130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21236524, 491570, 132855, 2423, 70, 28504, 1130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21369382, 493995, 132605, 2419, 70, 28542, 1130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21501990, 496416, 132027, 2412, 70, 28515, 1130, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[21634044, 498832, 363, 13, 27, "Text"],

Cell[CellGroupData[{
Cell[21634432, 498849, 1003, 21, 309, "Input",
  CellTags->"Cell 6.85"],

Cell[CellGroupData[{
Cell[21635460, 498874, 32855, 784, 233, 8982, 484, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21668318, 499660, 30806, 759, 70, 8978, 484, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21699127, 500421, 29213, 739, 70, 8985, 484, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21728343, 501162, 27679, 720, 70, 8974, 484, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21756025, 501884, 26809, 709, 70, 8983, 484, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21782837, 502595, 26306, 703, 70, 8986, 484, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21809146, 503300, 26175, 701, 70, 8985, 484, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21835324, 504003, 25908, 698, 70, 8989, 484, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21861235, 504703, 25819, 697, 70, 8989, 484, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21887057, 505402, 25647, 695, 70, 8975, 484, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21912707, 506099, 25171, 689, 70, 8989, 484, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[21937905, 506792, 157, 4, 44, "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[21938123, 506803, 82, 1, 30, "Subsubtitle",
  CellTags->{"i:29", "c:22"}],

Cell[CellGroupData[{
Cell[21938230, 506808, 64, 1, 42, "Section",
  CellTags->{"i:30", "c:23"}],
Cell[21938297, 506811, 201, 4, 44, "Text"],
Cell[21938501, 506817, 208, 6, 45, "NE2",
  CellTags->"(6.2.33)"],
Cell[21938712, 506825, 428, 12, 45, "Text"],
Cell[21939143, 506839, 712, 25, 48, "UNNEQ"],
Cell[21939858, 506866, 511, 20, 28, "Text"],
Cell[21940372, 506888, 288, 7, 44, "Text"],
Cell[21940663, 506897, 1086, 31, 45, "NE2",
  CellTags->"(6.2.34)"],
Cell[21941752, 506930, 519, 19, 46, "Text"],
Cell[21942274, 506951, 591, 17, 62, "Text"],
Cell[21942868, 506970, 263, 7, 130, "Input",
  CellTags->"Cell 6.86"],
Cell[21943134, 506979, 109, 3, 27, "Text"],
Cell[21943246, 506984, 245, 6, 126, "Input",
  CellTags->"Cell 6.87"],
Cell[21943494, 506992, 146, 5, 27, "Text"],
Cell[21943643, 506999, 107, 3, 67, "Input",
  CellTags->"Cell 6.88"],
Cell[21943753, 507004, 205, 6, 27, "Text"],
Cell[21943961, 507012, 2818, 62, 192, "Input",
  CellTags->"Cell 6.89"],
Cell[21946782, 507076, 107, 3, 27, "Text"],
Cell[21946892, 507081, 184, 5, 69, "Input",
  CellTags->"Cell 6.90"],
Cell[21947079, 507088, 48, 0, 27, "Text"],
Cell[21947130, 507090, 125, 3, 67, "Input",
  CellTags->"Cell 6.91"],
Cell[21947258, 507095, 209, 5, 44, "Text"],

Cell[CellGroupData[{
Cell[21947492, 507104, 271, 7, 107, "Input",
  CellTags->"Cell 6.92"],
Cell[21947766, 507113, 131, 3, 46, "Output"]
}, Open  ]],
Cell[21947912, 507119, 167, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[21948104, 507129, 263, 6, 86, "Input",
  CellTags->"Cell 6.93"],
Cell[21948370, 507137, 156224, 3037, 370, 20450, 1356, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[22104643, 510180, 74, 1, 31, "Section",
  CellTags->{"i:31", "c:24"}],
Cell[22104720, 510183, 288, 5, 61, "Text"],
Cell[22105011, 510190, 843, 29, 48, "NE2",
  CellTags->"(6.2.35)"],
Cell[22105857, 510221, 1049, 35, 80, "Text"],
Cell[22106909, 510258, 182, 6, 27, "Text"],
Cell[22107094, 510266, 1115, 32, 57, "NE2",
  CellTags->"(6.2.36)"],
Cell[22108212, 510300, 277, 7, 46, "Text"],
Cell[22108492, 510309, 614, 19, 47, "Text"],
Cell[22109109, 510330, 470, 10, 206, "Input",
  CellTags->"Cell 6.94"],
Cell[22109582, 510342, 93, 3, 27, "Text"],
Cell[22109678, 510347, 523, 11, 145, "Input",
  CellTags->"Cell 6.95"],
Cell[22110204, 510360, 540, 16, 47, "Text"],
Cell[22110747, 510378, 1152, 38, 47, "Text"],
Cell[22111902, 510418, 337, 9, 86, "Input",
  CellTags->"Cell 6.96"],
Cell[22112242, 510429, 512, 13, 61, "Text"],
Cell[22112757, 510444, 143, 5, 36, "Text"],
Cell[22112903, 510451, 187, 6, 37, "Text"],
Cell[22113093, 510459, 200, 7, 32, "Text"],
Cell[22113296, 510468, 1324, 41, 78, "Text"],
Cell[22114623, 510511, 379, 12, 40, "NE2",
  CellTags->"(6.2.37)"],
Cell[22115005, 510525, 52, 0, 27, "Text"],
Cell[22115060, 510527, 426, 14, 40, "NE2",
  CellTags->"(6.2.38)"],
Cell[22115489, 510543, 244, 9, 27, "Text"],
Cell[22115736, 510554, 548, 13, 190, "Input",
  CellTags->"Cell 6.97"],
Cell[22116287, 510569, 161, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[22116473, 510579, 369, 8, 128, "Input",
  CellTags->"Cell 6.98"],
Cell[22116845, 510589, 24114, 535, 370, 3856, 280, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[22140974, 511127, 1142, 22, 146, "Text",
  CellTags->"i:68"],
Cell[22142119, 511151, 969, 26, 78, "Text"],
Cell[22143091, 511179, 151, 5, 27, "Text"],
Cell[22143245, 511186, 109, 3, 67, "Input",
  CellTags->"Cell 6.99"],
Cell[22143357, 511191, 197, 6, 27, "Text"],
Cell[22143557, 511199, 3221, 68, 241, "Input",
  CellTags->"Cell 6.100"],
Cell[22146781, 511269, 44, 0, 27, "Text"],
Cell[22146828, 511271, 212, 6, 69, "Input",
  CellTags->"Cell 6.101"],
Cell[22147043, 511279, 48, 0, 27, "Text"],
Cell[22147094, 511281, 126, 3, 67, "Input",
  CellTags->"Cell 6.102"],
Cell[22147223, 511286, 91, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[22147339, 511293, 225, 6, 107, "Input",
  CellTags->"Cell 6.103"],
Cell[22147567, 511301, 150, 4, 46, "Output"]
}, Open  ]],
Cell[22147732, 511308, 169, 6, 27, "Text"],
Cell[22147904, 511316, 93, 3, 67, "Input",
  CellTags->"Cell 6.104"],

Cell[CellGroupData[{
Cell[22148022, 511323, 394, 8, 105, "Input",
  CellTags->"Cell 6.105"],
Cell[22148419, 511333, 123900, 4172, 426, 51005, 3268, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[22272334, 515508, 742, 25, 62, "Text"],
Cell[22273079, 515535, 28959, 708, 244, 7771, 442, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22302041, 516245, 52, 1, 16, "Caption",
  CellTags->"Fig. 6.7"],
Cell[22302096, 516248, 448, 12, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[22302581, 516265, 67, 1, 31, "Section",
  CellTags->{"i:32", "c:25"}],

Cell[CellGroupData[{
Cell[22302673, 516270, 60, 1, 27, "Subsubsection",
  CellTags->"i:33"],
Cell[22302736, 516273, 718, 16, 95, "Text"],
Cell[22303457, 516291, 439, 9, 61, "Text"],
Cell[22303899, 516302, 641, 23, 44, "Text"],
Cell[22304543, 516327, 2141, 52, 46, "UNNEQ"],
Cell[22306687, 516381, 190, 5, 31, "Text"],
Cell[22306880, 516388, 1985, 51, 46, "NE2",
  CellTags->"(6.2.39)"],
Cell[22308868, 516441, 1069, 34, 81, "Text",
  CellTags->"i:61"],
Cell[22309940, 516477, 114, 3, 27, "Text"],
Cell[22310057, 516482, 312, 8, 168, "Input",
  CellTags->"Cell 6.106"],
Cell[22310372, 516492, 105, 3, 27, "Text"],
Cell[22310480, 516497, 312, 6, 126, "Input",
  CellTags->"Cell 6.107"],
Cell[22310795, 516505, 186, 6, 27, "Text"],
Cell[22310984, 516513, 571, 11, 247, "Input",
  CellTags->"Cell 6.108"],
Cell[22311558, 516526, 284, 7, 44, "Text"],
Cell[22311845, 516535, 111, 3, 67, "Input",
  CellTags->"Cell 6.109"],
Cell[22311959, 516540, 295, 9, 44, "Text"],
Cell[22312257, 516551, 235, 6, 107, "Input",
  CellTags->"Cell 6.110"],
Cell[22312495, 516559, 114, 3, 27, "Text"],
Cell[22312612, 516564, 180, 5, 30, "Text"],
Cell[22312795, 516571, 396, 8, 164, "Input",
  CellTags->"Cell 6.111"],
Cell[22313194, 516581, 314, 11, 27, "Text"],

Cell[CellGroupData[{
Cell[22313533, 516596, 91, 3, 67, "Input",
  CellTags->"Cell 6.112"],
Cell[22313627, 516601, 56, 1, 50, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22313720, 516607, 225, 5, 105, "Input",
  CellTags->"Cell 6.113"],
Cell[22313948, 516614, 53413, 1559, 233, 24749, 1201, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[22367376, 518176, 124, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[22367525, 518183, 266, 7, 107, "Input",
  CellTags->"Cell 6.114"],
Cell[22367794, 518192, 132, 3, 46, "Output"]
}, Open  ]],
Cell[22367941, 518198, 169, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[22368135, 518208, 318, 6, 105, "Input",
  CellTags->"Cell 6.115"],
Cell[22368456, 518216, 252259, 5026, 536, 36755, 2361, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[22620764, 523248, 72, 1, 29, "Subsubsection",
  CellTags->"i:34"],
Cell[22620839, 523251, 1702, 48, 103, "Text"],
Cell[22622544, 523301, 717, 19, 31, "UNNEQ"],
Cell[22623264, 523322, 161, 4, 44, "Text"],
Cell[22623428, 523328, 411, 11, 61, "Text"],
Cell[22623842, 523341, 2810, 66, 46, "NE2",
  CellTags->"(6.2.40)"],
Cell[22626655, 523409, 1460, 40, 143, "Text"],
Cell[22628118, 523451, 1292, 27, 163, "Text"],
Cell[22629413, 523480, 4177, 78, 934, "Input",
  CellTags->"Cell 6.116"],

Cell[CellGroupData[{
Cell[22633615, 523562, 93, 3, 67, "Input",
  CellTags->"Cell 6.117"],
Cell[22633711, 523567, 213, 4, 35, "Print"],
Cell[22633927, 523573, 132, 3, 46, "Output"]
}, Open  ]],
Cell[22634074, 523579, 342, 8, 44, "Text"],

Cell[CellGroupData[{
Cell[22634441, 523591, 256, 6, 124, "Input",
  CellTags->"Cell 6.118"],
Cell[22634700, 523599, 35794, 1069, 233, 16768, 830, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[22670509, 524671, 384, 9, 61, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[22670942, 524686, 59, 1, 31, "Section",
  CellTags->{"i:36", "c:26"}],
Cell[22671004, 524689, 828, 17, 112, "Text"],
Cell[22671835, 524708, 426, 12, 48, "Text"],
Cell[22672264, 524722, 715, 25, 48, "UNNEQ"],
Cell[22672982, 524749, 1178, 36, 62, "Text"],
Cell[22674163, 524787, 369, 6, 40, "NE2",
  CellTags->"(6.2.41)"],
Cell[22674535, 524795, 19, 0, 27, "Text"],
Cell[22674557, 524797, 417, 9, 40, "NE2",
  CellTags->"(6.2.42)"],
Cell[22674977, 524808, 466, 14, 47, "Text"],
Cell[22675446, 524824, 1007, 26, 46, "UNNEQ"],
Cell[22676456, 524852, 34, 0, 27, "Text"],
Cell[22676493, 524854, 179, 3, 44, "NE2",
  CellTags->"(6.2.43)"],
Cell[22676675, 524859, 21, 0, 27, "Text"],
Cell[22676699, 524861, 797, 23, 41, "UNNEQ"],
Cell[22677499, 524886, 240, 7, 44, "Text"],
Cell[22677742, 524895, 151, 5, 27, "Text"],
Cell[22677896, 524902, 185, 6, 27, "Text"],
Cell[22678084, 524910, 350, 11, 46, "Text"],
Cell[22678437, 524923, 1230, 37, 105, "Text"],
Cell[22679670, 524962, 990, 28, 97, "Text"],
Cell[22680663, 524992, 259, 9, 44, "Text"],
Cell[22680925, 525003, 285, 8, 149, "Input",
  CellTags->"Cell 6.119"],
Cell[22681213, 525013, 371, 7, 61, "Text"],
Cell[22681587, 525022, 53, 0, 27, "Text"],
Cell[22681643, 525024, 154, 4, 67, "Input",
  CellTags->"Cell 6.120"],
Cell[22681800, 525030, 172, 4, 44, "Text"],

Cell[CellGroupData[{
Cell[22681997, 525038, 134, 3, 69, "Input",
  CellTags->"Cell 6.121"],
Cell[22682134, 525043, 35, 1, 46, "Output"]
}, Open  ]],
Cell[22682184, 525047, 159, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[22682368, 525057, 229, 5, 86, "Input",
  CellTags->"Cell 6.122"],
Cell[22682600, 525064, 117386, 2139, 302, 26136, 1008, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[22800001, 527206, 263, 6, 46, "Text"],
Cell[22800267, 527214, 223, 5, 69, "Input",
  CellTags->"Cell 6.123"],
Cell[22800493, 527221, 175, 6, 27, "Text"],
Cell[22800671, 527229, 118, 3, 67, "Input",
  CellTags->"Cell 6.124"],
Cell[22800792, 527234, 175, 5, 27, "Text"],

Cell[CellGroupData[{
Cell[22800992, 527243, 101, 3, 67, "Input",
  CellTags->"Cell 6.125"],
Cell[22801096, 527248, 81, 1, 46, "Output"]
}, Open  ]],
Cell[22801192, 527252, 446, 11, 62, "Text"],
Cell[22801641, 527265, 110, 3, 67, "Input",
  CellTags->"Cell 6.126"],
Cell[22801754, 527270, 257, 9, 27, "Text"],
Cell[22802014, 527281, 303, 7, 117, "Input",
  CellTags->"Cell 6.127"],
Cell[22802320, 527290, 189, 6, 27, "Text"],
Cell[22802512, 527298, 204, 5, 75, "Input",
  CellTags->"Cell 6.128"],
Cell[22802719, 527305, 351, 11, 29, "Text"],
Cell[22803073, 527318, 130, 3, 73, "Input",
  CellTags->"Cell 6.129"],
Cell[22803206, 527323, 366, 6, 61, "Text"],
Cell[22803575, 527331, 400, 11, 44, "Text"],

Cell[CellGroupData[{
Cell[22804000, 527346, 325, 7, 88, "Input",
  CellTags->"Cell 6.130"],
Cell[22804328, 527355, 135, 3, 46, "Output"]
}, Open  ]],
Cell[22804478, 527361, 310, 7, 44, "Text"],
Cell[22804791, 527370, 153, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[22804969, 527380, 238, 5, 86, "Input",
  CellTags->"Cell 6.131"],
Cell[22805210, 527387, 116146, 2125, 302, 26186, 1010, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[22921417, 529519, 65, 1, 30, "Subsubtitle",
  CellTags->"c:27"],
Cell[22921485, 529522, 219, 6, 27, "Text"],
Cell[22921707, 529530, 613, 22, 40, "Text"],
Cell[22922323, 529554, 271, 11, 27, "Text"],
Cell[22922597, 529567, 270, 8, 44, "Text"],
Cell[22922870, 529577, 288, 8, 44, "Text"],
Cell[22923161, 529587, 300, 9, 44, "Text"],
Cell[22923464, 529598, 632, 19, 36, "Text"],
Cell[22924099, 529619, 428, 14, 44, "Text"],
Cell[22924530, 529635, 115, 4, 27, "Text"],
Cell[22924648, 529641, 402, 12, 37, "Text"],
Cell[22925053, 529655, 207, 5, 44, "Text",
  CellTags->"i:66"],
Cell[22925263, 529662, 519, 17, 29, "NE2",
  CellTags->"(6.2.44)"],
Cell[22925785, 529681, 1562, 43, 65, "Text"],
Cell[22927350, 529726, 813, 22, 49, "Text"],
Cell[22928166, 529750, 1451, 49, 58, "Text"],
Cell[22929620, 529801, 640, 22, 39, "Text"],
Cell[22930263, 529825, 367, 9, 52, "Text"],
Cell[22930633, 529836, 663, 20, 31, "Text"],
Cell[22931299, 529858, 337, 12, 29, "Text"],
Cell[22931639, 529872, 395, 13, 41, "Text"],
Cell[22932037, 529887, 179, 8, 27, "Text"],
Cell[22932219, 529897, 176, 8, 27, "Text"],
Cell[22932398, 529907, 506, 17, 44, "Text"],
Cell[22932907, 529926, 367, 11, 44, "Text"],
Cell[22933277, 529939, 1042, 34, 88, "Text"],
Cell[22934322, 529975, 284, 10, 27, "Text"],
Cell[22934609, 529987, 1257, 35, 40, "Text"],
Cell[22935869, 530024, 547, 18, 44, "Text"],
Cell[22936419, 530044, 355, 11, 40, "Text",
  CellTags->"i:38"],
Cell[22936777, 530057, 1967, 69, 89, "Text"],
Cell[22938747, 530128, 977, 34, 44, "Text"],
Cell[22939727, 530164, 2188, 65, 147, "Text"],
Cell[22941918, 530231, 963, 30, 61, "Text"],
Cell[22942884, 530263, 1091, 31, 46, "NE2",
  CellTags->"(6.2.45)"],
Cell[22943978, 530296, 761, 23, 66, "Text"],
Cell[22944742, 530321, 773, 23, 63, "Text"],
Cell[22945518, 530346, 2605, 77, 214, "Text"],
Cell[22948126, 530425, 34134, 425, 136, 34014, 421, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[22982263, 530852, 66, 1, 16, "Caption",
  CellTags->"Fig. 6.8"],
Cell[22982332, 530855, 875, 27, 66, "Text"],
Cell[22983210, 530884, 1210, 32, 95, "Text"],
Cell[22984423, 530918, 38338, 477, 151, 38218, 473, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[23022764, 531397, 66, 1, 16, "Caption",
  CellTags->"Fig. 6.9"],
Cell[23022833, 531400, 1224, 36, 95, "Text"],
Cell[23024060, 531438, 313194, 6678, 302, 194036, 5202, "GraphicsData", \
"PostScript", "Picture"],
Cell[23337257, 538118, 68, 1, 16, "Caption",
  CellTags->"Fig. 6.10"],
Cell[23337328, 538121, 1519, 48, 78, "Text"],
Cell[23338850, 538171, 944, 23, 95, "Text"],
Cell[23339797, 538196, 2571, 80, 136, "Text",
  CellTags->"i:62"],
Cell[23342371, 538278, 2539, 80, 119, "Text"],
Cell[23344913, 538360, 363, 11, 46, "Text"],
Cell[23345279, 538373, 744, 23, 29, "Text"],
Cell[23346026, 538398, 336, 11, 45, "Text"],
Cell[23346365, 538411, 3542874, 48673, 152, 3504985, 48201, "GraphicsData", \
"PostScript", "Picture"],
Cell[26889242, 587086, 459, 16, 29, "Caption",
  CellTags->"Fig. 6.11"],
Cell[26889704, 587104, 1181, 34, 95, "Text"],
Cell[26890888, 587140, 340, 9, 44, "Text"],
Cell[26891231, 587151, 313, 10, 36, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[26891593, 587167, 113, 2, 40, "Subtitle",
  CellTags->{"i:39", "c:28"}],
Cell[26891709, 587171, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[26891750, 587175, 61, 1, 41, "Subsubtitle",
  CellTags->"c:29"],
Cell[26891814, 587178, 1047, 21, 146, "Text"],
Cell[26892864, 587201, 221, 4, 44, "Text"],
Cell[26893088, 587207, 774, 12, 129, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[26893899, 587224, 81, 1, 30, "Subsubtitle",
  CellTags->{"i:42", "c:30"}],

Cell[CellGroupData[{
Cell[26894005, 587229, 53, 1, 42, "Section",
  CellTags->"c:31"],
Cell[26894061, 587232, 63, 0, 27, "Text"],
Cell[26894127, 587234, 150, 5, 33, "NE3",
  CellTags->"(6.3.1)"],
Cell[26894280, 587241, 1957, 62, 78, "Text"],
Cell[26896240, 587305, 1760, 57, 80, "Text"],
Cell[26898003, 587364, 298, 9, 35, "NE3",
  CellTags->"(6.3.2)"],
Cell[26898304, 587375, 468, 17, 50, "Text"],
Cell[26898775, 587394, 860, 25, 78, "Text"],
Cell[26899638, 587421, 360, 10, 44, "Text"],
Cell[26900001, 587433, 305, 9, 35, "NE3",
  CellTags->"(6.3.3)"],
Cell[26900309, 587444, 76, 0, 27, "Text"],
Cell[26900388, 587446, 1507, 42, 93, "NE3",
  CellTags->"(6.3.4)"],
Cell[26901898, 587490, 434, 14, 44, "Text"],
Cell[26902335, 587506, 1534, 35, 93, "NE3",
  CellTags->"(6.3.5)"],
Cell[26903872, 587543, 294, 9, 44, "Text"],
Cell[26904169, 587554, 301, 9, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[26904507, 587568, 97, 1, 31, "Section",
  CellTags->"c:32"],
Cell[26904607, 587571, 111, 3, 27, "Text"],
Cell[26904721, 587576, 126, 4, 42, "UNNEQ"],
Cell[26904850, 587582, 898, 30, 65, "Text"],
Cell[26905751, 587614, 953, 33, 45, "Text"],
Cell[26906707, 587649, 129, 3, 27, "Text"],
Cell[26906839, 587654, 653, 18, 34, "NE3",
  CellTags->{"(2.4.49)", "(6.3.6)"}],
Cell[26907495, 587674, 359, 13, 44, "Text"],
Cell[26907857, 587689, 332, 12, 29, "Text"],
Cell[26908192, 587703, 1070, 22, 328, "Input",
  CellTags->"Cell 6.132"],
Cell[26909265, 587727, 258, 8, 27, "Text"],

Cell[CellGroupData[{
Cell[26909548, 587739, 136, 4, 86, "Input",
  CellTags->"Cell 6.133"],
Cell[26909687, 587745, 846, 18, 178, "Output"]
}, Open  ]],
Cell[26910548, 587766, 303, 11, 27, "Text"],

Cell[CellGroupData[{
Cell[26910876, 587781, 278, 7, 124, "Input",
  CellTags->"Cell 6.134"],
Cell[26911157, 587790, 2619, 34, 312, "Output"]
}, Open  ]],
Cell[26913791, 587827, 353, 9, 47, "Text"],

Cell[CellGroupData[{
Cell[26914169, 587840, 583, 13, 162, "Input",
  CellTags->"Cell 6.135"],
Cell[26914755, 587855, 32469, 747, 233, 7652, 436, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[26947239, 588605, 298, 5, 61, "Text"],
Cell[26947540, 588612, 169, 4, 44, "Text"],

Cell[CellGroupData[{
Cell[26947734, 588620, 170, 5, 67, "Input",
  CellTags->"Cell 6.136"],
Cell[26947907, 588627, 276, 4, 65, "Output"]
}, Open  ]],
Cell[26948198, 588634, 579, 15, 64, "Text"],
Cell[26948780, 588651, 346, 10, 44, "Text"],
Cell[26949129, 588663, 121, 3, 67, "Input",
  CellTags->"Cell 6.137"],
Cell[26949253, 588668, 437, 9, 61, "Text"],
Cell[26949693, 588679, 331, 7, 124, "Input",
  CellTags->"Cell 6.138"],
Cell[26950027, 588688, 210, 6, 44, "Text"],
Cell[26950240, 588696, 231, 6, 67, "Input",
  CellTags->"Cell 6.139"],
Cell[26950474, 588704, 356, 13, 44, "Text"],

Cell[CellGroupData[{
Cell[26950855, 588721, 468, 10, 124, "Input",
  CellTags->"Cell 6.140"],

Cell[CellGroupData[{
Cell[26951348, 588735, 27854, 703, 233, 7775, 450, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26979205, 589440, 58073, 1314, 233, 12371, 745, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27037281, 590756, 89663, 1878, 233, 15715, 960, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27126947, 592636, 117900, 2354, 233, 18210, 1118, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27244850, 594992, 144643, 2811, 233, 20677, 1275, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[27389520, 597807, 418, 11, 44, "Text"],
Cell[27389941, 597820, 495, 12, 64, "Text"],

Cell[CellGroupData[{
Cell[27390461, 597836, 1179, 23, 276, "Input",
  CellTags->"Cell 6.141"],

Cell[CellGroupData[{
Cell[27391665, 597863, 27047, 671, 233, 6793, 416, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27418715, 598536, 6878, 412, 70, 6659, 406, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[27425596, 598950, 6878, 412, 70, 6659, 406, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[27432477, 599364, 6878, 412, 70, 6659, 406, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[27439358, 599778, 6879, 412, 70, 6660, 406, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[27446240, 600192, 6875, 412, 70, 6656, 406, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[27453118, 600606, 6877, 412, 70, 6658, 406, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[27459998, 601020, 6876, 412, 70, 6657, 406, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[27466877, 601434, 6878, 412, 70, 6659, 406, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[27473758, 601848, 6905, 414, 70, 6686, 408, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[27480666, 602264, 6913, 414, 70, 6694, 408, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[27487582, 602680, 6908, 414, 70, 6689, 408, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[27494493, 603096, 6910, 414, 70, 6691, 408, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[27501406, 603512, 6907, 414, 70, 6688, 408, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[27508316, 603928, 6909, 414, 70, 6690, 408, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[27515228, 604344, 6912, 414, 70, 6693, 408, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[27522143, 604760, 6909, 414, 70, 6690, 408, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[27529055, 605176, 6913, 414, 70, 6694, 408, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[27535971, 605592, 6907, 414, 70, 6688, 408, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[27542881, 606008, 6912, 414, 70, 6693, 408, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[27549796, 606424, 6909, 414, 70, 6690, 408, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Open  ]],
Cell[27556732, 606842, 326, 7, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[27557095, 606854, 82, 1, 31, "Section",
  CellTags->{"i:47", "c:33"}],
Cell[27557180, 606857, 329, 7, 61, "Text"],
Cell[27557512, 606866, 99, 3, 27, "Text"],
Cell[27557614, 606871, 280, 9, 30, "Text"],
Cell[27557897, 606882, 644, 20, 61, "Text"],
Cell[27558544, 606904, 540, 16, 65, "NE3",
  CellTags->"(6.3.7)"],
Cell[27559087, 606922, 449, 13, 45, "Text"],
Cell[27559539, 606937, 488, 11, 225, "Input",
  CellTags->"Cell 6.142"],
Cell[27560030, 606950, 105, 3, 27, "Text"],
Cell[27560138, 606955, 468, 11, 183, "Input",
  CellTags->"Cell 6.143"],
Cell[27560609, 606968, 176, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[27560810, 606978, 384, 8, 128, "Input",
  CellTags->"Cell 6.144"],
Cell[27561197, 606988, 26659, 591, 370, 4354, 311, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[27587871, 607582, 1622, 52, 98, "Text"],
Cell[27589496, 607636, 59, 0, 27, "Text"],
Cell[27589558, 607638, 386, 8, 267, "Input",
  CellTags->"Cell 6.145"],
Cell[27589947, 607648, 290, 8, 44, "Text"],
Cell[27590240, 607658, 212, 6, 69, "Input",
  CellTags->"Cell 6.146"],
Cell[27590455, 607666, 761, 24, 44, "Text"],
Cell[27591219, 607692, 224, 6, 105, "Input",
  CellTags->"Cell 6.147"],
Cell[27591446, 607700, 925, 30, 61, "Text"],
Cell[27592374, 607732, 118, 3, 67, "Input",
  CellTags->"Cell 6.148"],
Cell[27592495, 607737, 51, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[27592571, 607741, 110, 3, 67, "Input",
  CellTags->"Cell 6.149"],
Cell[27592684, 607746, 4492, 58, 502, "Output"]
}, Open  ]],
Cell[27597191, 607807, 117, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[27597333, 607814, 112, 3, 67, "Input",
  CellTags->"Cell 6.150"],
Cell[27597448, 607819, 37, 1, 46, "Output"]
}, Open  ]],
Cell[27597500, 607823, 1062, 26, 104, "Text"],
Cell[27598565, 607851, 99, 3, 27, "Text"],
Cell[27598667, 607856, 120, 3, 67, "Input",
  CellTags->"Cell 6.151"],
Cell[27598790, 607861, 896, 28, 64, "Text"],

Cell[CellGroupData[{
Cell[27599711, 607893, 105, 3, 67, "Input",
  CellTags->"Cell 6.152"],
Cell[27599819, 607898, 4834, 76, 578, "Output"]
}, Open  ]],
Cell[27604668, 607977, 1441, 41, 95, "Text"],
Cell[27606112, 608020, 575, 11, 147, "Input",
  CellTags->"Cell 6.153"],
Cell[27606690, 608033, 1111, 32, 78, "Text"],

Cell[CellGroupData[{
Cell[27607826, 608069, 503, 10, 162, "Input",
  CellTags->"Cell 6.154"],

Cell[CellGroupData[{
Cell[27608354, 608083, 184818, 5864, 320, 89804, 4686, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27793175, 613949, 191731, 6398, 320, 105023, 5323, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27984909, 620349, 179195, 5941, 320, 93990, 4885, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[28164177, 626298, 85, 1, 30, "Subsubtitle",
  CellTags->{"i:41", "c:34"}],

Cell[CellGroupData[{
Cell[28164287, 626303, 53, 1, 42, "Section",
  CellTags->"c:35"],
Cell[28164343, 626306, 404, 7, 78, "Text"],
Cell[28164750, 626315, 524, 8, 95, "Text"],
Cell[28165277, 626325, 131, 3, 27, "Text"],
Cell[28165411, 626330, 149, 5, 33, "NE3",
  CellTags->"(6.3.8)"],
Cell[28165563, 626337, 380, 11, 48, "Text"],
Cell[28165946, 626350, 145, 5, 38, "NE3",
  CellTags->"(6.3.9)"],
Cell[28166094, 626357, 249, 9, 30, "Text"],
Cell[28166346, 626368, 195, 6, 36, "Text"],
Cell[28166544, 626376, 152, 5, 27, "Text"],
Cell[28166699, 626383, 222, 4, 38, "NE3",
  CellTags->"(6.3.10)"],
Cell[28166924, 626389, 390, 13, 32, "Text"],
Cell[28167317, 626404, 879, 28, 30, "Text"],
Cell[28168199, 626434, 675, 21, 65, "Text"],
Cell[28168877, 626457, 985, 31, 32, "NE3",
  CellTags->"(6.3.11)"],
Cell[28169865, 626490, 770, 25, 52, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[28170672, 626520, 91, 1, 31, "Section",
  CellTags->"c:36"],
Cell[28170766, 626523, 144, 3, 44, "Text"],
Cell[28170913, 626528, 222, 6, 42, "NE3",
  CellTags->"(6.3.12)"],
Cell[28171138, 626536, 305, 9, 44, "Text"],
Cell[28171446, 626547, 1956, 52, 181, "Text"],
Cell[28173405, 626601, 441, 8, 78, "Text"],
Cell[28173849, 626611, 1523, 40, 205, "Input",
  CellTags->"Cell 6.155"],
Cell[28175375, 626653, 237, 6, 48, "Text"],

Cell[CellGroupData[{
Cell[28175637, 626663, 180, 5, 74, "Input",
  CellTags->"Cell 6.156"],
Cell[28175820, 626670, 376, 6, 148, "Output"]
}, Open  ]],
Cell[28176211, 626679, 382, 12, 46, "Text"],
Cell[28176596, 626693, 111, 3, 67, "Input",
  CellTags->"Cell 6.157"],
Cell[28176710, 626698, 237, 8, 27, "Text"],

Cell[CellGroupData[{
Cell[28176972, 626710, 152, 4, 67, "Input",
  CellTags->"Cell 6.158"],
Cell[28177127, 626716, 163, 2, 84, "Output"]
}, Open  ]],
Cell[28177305, 626721, 181, 6, 27, "Text"],
Cell[28177489, 626729, 837, 17, 219, "Input",
  CellTags->"Cell 6.159"],
Cell[28178329, 626748, 159, 5, 27, "Text"],

Cell[CellGroupData[{
Cell[28178513, 626757, 95, 3, 67, "Input",
  CellTags->"Cell 6.160"],
Cell[28178611, 626762, 280, 4, 65, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28178928, 626771, 93, 3, 67, "Input",
  CellTags->"Cell 6.161"],
Cell[28179024, 626776, 250, 7, 156, "Output"]
}, Open  ]],
Cell[28179289, 626786, 314, 10, 44, "Text"],
Cell[28179606, 626798, 171, 5, 67, "Input",
  CellTags->"Cell 6.162"],
Cell[28179780, 626805, 481, 13, 61, "Text"],

Cell[CellGroupData[{
Cell[28180286, 626822, 284, 6, 86, "Input",
  CellTags->"Cell 6.163"],

Cell[CellGroupData[{
Cell[28180595, 626832, 35477, 868, 233, 9185, 539, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28216075, 627702, 36092, 921, 233, 10025, 595, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28252170, 628625, 41461, 969, 233, 9705, 572, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28293634, 629596, 43851, 1042, 233, 10233, 622, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[28337546, 630645, 82, 1, 31, "Section",
  CellTags->{"i:48", "c:37"}],
Cell[28337631, 630648, 903, 25, 98, "Text"],
Cell[28338537, 630675, 181, 6, 30, "Text"],
Cell[28338721, 630683, 268, 11, 30, "Text"],
Cell[28338992, 630696, 4709, 152, 121, "Text"],
Cell[28343704, 630850, 6660, 198, 85, "Text"],

Cell[CellGroupData[{
Cell[28350389, 631052, 470, 12, 207, "Input",
  CellTags->"Cell 6.164"],
Cell[28350862, 631066, 2681, 41, 236, "Output"]
}, Open  ]],
Cell[28353558, 631110, 72, 0, 27, "Text"],
Cell[28353633, 631112, 3853, 82, 559, "Input",
  CellTags->"Cell 6.165"],
Cell[28357489, 631196, 118, 5, 27, "Text"],
Cell[28357610, 631203, 97, 3, 67, "Input",
  CellTags->"Cell 6.166"],
Cell[28357710, 631208, 35, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[28357770, 631212, 90, 3, 67, "Input",
  CellTags->"Cell 6.167"],
Cell[28357863, 631217, 685, 9, 103, "Output"]
}, Open  ]],
Cell[28358563, 631229, 396, 12, 47, "Text"],

Cell[CellGroupData[{
Cell[28358984, 631245, 162, 5, 105, "Input",
  CellTags->"Cell 6.168"],
Cell[28359149, 631252, 975, 13, 141, "Output"]
}, Open  ]],
Cell[28360139, 631268, 485, 15, 44, "Text",
  CellTags->"i:67"],

Cell[CellGroupData[{
Cell[28360649, 631287, 914, 19, 279, "Input",
  CellTags->"Cell 6.169"],

Cell[CellGroupData[{
Cell[28361588, 631310, 352565, 7245, 302, 201354, 5374, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28714156, 638557, 349818, 7231, 302, 200008, 5377, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29063977, 645790, 351887, 7222, 302, 201159, 5357, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29415867, 653014, 351336, 7219, 302, 200858, 5357, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[29767276, 660241, 63, 1, 30, "Subsubtitle",
  CellTags->"c:38"],
Cell[29767342, 660244, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[29767383, 660248, 56, 1, 42, "Section",
  CellTags->"c:39"],
Cell[29767442, 660251, 268, 6, 44, "Text",
  CellTags->"i:43"],
Cell[29767713, 660259, 258, 9, 44, "Text"],
Cell[29767974, 660270, 336, 8, 45, "NE3",
  CellTags->{"(3.1.7)", "(6.3.13)"}],
Cell[29768313, 660280, 166, 5, 27, "Text"],
Cell[29768482, 660287, 165, 4, 44, "Text"],
Cell[29768650, 660293, 274, 8, 41, "NE3",
  CellTags->"(6.3.14)"],
Cell[29768927, 660303, 18, 0, 27, "Text"],
Cell[29768948, 660305, 494, 12, 44, "NE3",
  CellTags->"(6.3.15)"],
Cell[29769445, 660319, 784, 22, 69, "Text"],
Cell[29770232, 660343, 275, 6, 43, "NE3",
  CellTags->"(6.3.16)"],
Cell[29770510, 660351, 150, 5, 27, "Text"],
Cell[29770663, 660358, 258, 9, 34, "NE3",
  CellTags->"(6.3.17)"],
Cell[29770924, 660369, 250, 9, 27, "Text"],
Cell[29771177, 660380, 140, 5, 29, "NE3",
  CellTags->"(6.3.18)"],
Cell[29771320, 660387, 689, 17, 82, "Text"],
Cell[29772012, 660406, 242, 7, 42, "NE3",
  CellTags->"(6.3.19)"],
Cell[29772257, 660415, 684, 22, 61, "Text"],
Cell[29772944, 660439, 1067, 35, 86, "Text"],
Cell[29774014, 660476, 500, 16, 54, "Text"],
Cell[29774517, 660494, 347, 8, 53, "NE3",
  CellTags->"(6.3.20)"],
Cell[29774867, 660504, 188, 6, 27, "Text"],
Cell[29775058, 660512, 948, 22, 352, "Input",
  CellTags->"Cell 6.170"],
Cell[29776009, 660536, 464, 11, 61, "Text"],

Cell[CellGroupData[{
Cell[29776498, 660551, 30787, 788, 233, 9059, 515, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29807288, 661341, 29382, 770, 70, 9035, 514, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29836673, 662113, 27148, 787, 70, 9904, 570, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29863824, 662902, 28378, 802, 70, 9898, 569, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29892205, 663706, 29426, 772, 70, 9079, 516, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29921634, 664480, 30198, 780, 70, 9062, 515, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29951835, 665262, 28637, 759, 70, 9015, 512, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29980475, 666023, 27943, 797, 70, 9921, 570, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30008421, 666822, 27510, 786, 70, 9812, 563, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30035934, 667610, 29459, 770, 70, 9027, 513, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30065396, 668382, 30463, 780, 70, 8982, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30095862, 669164, 29464, 769, 70, 9012, 512, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30125329, 669935, 27388, 785, 70, 9795, 563, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30152720, 670722, 28015, 802, 70, 9993, 575, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30180738, 671526, 28905, 761, 70, 8996, 511, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30209646, 672289, 30439, 784, 70, 9076, 516, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30240088, 673075, 29761, 773, 70, 9013, 512, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30269852, 673850, 28804, 809, 70, 9940, 572, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30298659, 674661, 27530, 790, 70, 9881, 568, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30326192, 675453, 29905, 776, 70, 9044, 514, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30356100, 676231, 30850, 789, 70, 9070, 516, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30386953, 677022, 29773, 773, 70, 9013, 512, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30416729, 677797, 27345, 792, 70, 9955, 573, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30444077, 678591, 28690, 808, 70, 9947, 572, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30472770, 679401, 29566, 771, 70, 9037, 513, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30502339, 680174, 30827, 786, 70, 9014, 512, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30533169, 680962, 28757, 760, 70, 9010, 512, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30561929, 681724, 27997, 796, 70, 9886, 568, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30589929, 682522, 27599, 786, 70, 9775, 561, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30617531, 683310, 29727, 772, 70, 9008, 512, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30647261, 684084, 30432, 778, 70, 8947, 508, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30677696, 684864, 29627, 772, 70, 9025, 513, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30707326, 685638, 27344, 784, 70, 9804, 563, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30734673, 686424, 28056, 797, 70, 9884, 568, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30762732, 687223, 29295, 770, 70, 9074, 516, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30792030, 687995, 31353, 795, 70, 9083, 516, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30823386, 688792, 29792, 772, 70, 9000, 511, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30853181, 689566, 28933, 813, 70, 9975, 574, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30882117, 690381, 27818, 798, 70, 9958, 573, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30909938, 691181, 30132, 779, 70, 9044, 514, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30940073, 691962, 30834, 788, 70, 9050, 515, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[30970922, 692753, 165, 4, 17, "Caption",
  CellTags->"Fig. 6.12"],
Cell[30971090, 692759, 625, 12, 78, "Text"],
Cell[30971718, 692773, 369, 6, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[30972124, 692784, 95, 1, 31, "Section",
  CellTags->{"i:40", "c:40"}],
Cell[30972222, 692787, 688, 15, 95, "Text"],
Cell[30972913, 692804, 1062, 27, 95, "Text"],
Cell[30973978, 692833, 389, 8, 116, "Input",
  CellTags->"Cell 6.171"],
Cell[30974370, 692843, 174, 7, 27, "Text"],
Cell[30974547, 692852, 143, 4, 67, "Input",
  CellTags->"Cell 6.172"],
Cell[30974693, 692858, 528, 18, 44, "Text"],
Cell[30975224, 692878, 323, 7, 86, "Input",
  CellTags->"Cell 6.173"],
Cell[30975550, 692887, 99, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[30975674, 692894, 396, 9, 107, "Input",
  CellTags->"Cell 6.174"],
Cell[30976073, 692905, 1409, 31, 248, "Output"]
}, Open  ]],
Cell[30977497, 692939, 214, 4, 44, "Text"],
Cell[30977714, 692945, 149, 3, 44, "Text"],
Cell[30977866, 692950, 158, 4, 67, "Input",
  CellTags->"Cell 6.175"],
Cell[30978027, 692956, 275, 7, 44, "Text"],

Cell[CellGroupData[{
Cell[30978327, 692967, 620, 13, 181, "Input",
  CellTags->"Cell 6.176"],

Cell[CellGroupData[{
Cell[30978972, 692984, 36604, 803, 233, 6879, 431, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31015579, 693789, 37206, 857, 233, 7762, 488, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31052788, 694648, 38930, 873, 233, 7724, 483, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31091721, 695523, 43462, 971, 233, 8575, 535, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31135186, 696496, 47903, 1071, 233, 9475, 591, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[31183116, 697571, 358, 6, 55, "Text"],
Cell[31183477, 697579, 853, 20, 295, "Input",
  CellTags->"Cell 6.177"],
Cell[31184333, 697601, 225, 7, 27, "Text"],

Cell[CellGroupData[{
Cell[31184583, 697612, 30787, 788, 233, 9059, 515, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31215373, 698402, 29408, 770, 70, 9033, 514, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31244784, 699174, 26976, 785, 70, 9881, 569, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31271763, 699961, 28376, 798, 70, 9832, 565, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31300142, 700761, 29288, 768, 70, 9043, 514, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31329433, 701531, 30091, 779, 70, 9064, 515, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31359527, 702312, 28590, 760, 70, 9041, 514, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31388120, 703074, 28029, 797, 70, 9885, 568, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31416152, 703873, 27170, 782, 70, 9808, 563, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31443325, 704657, 29505, 770, 70, 9029, 513, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31472833, 705429, 30467, 780, 70, 8986, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31503303, 706211, 29141, 765, 70, 9005, 512, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31532447, 706978, 27162, 785, 70, 9849, 567, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31559612, 707765, 28115, 803, 70, 9988, 575, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31587730, 708570, 28695, 758, 70, 8976, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31616428, 709330, 30111, 780, 70, 9064, 516, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31646542, 710112, 29428, 771, 70, 9061, 515, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31675973, 710885, 28588, 803, 70, 9857, 567, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31704564, 711690, 27411, 789, 70, 9879, 568, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31731978, 712481, 29859, 776, 70, 9059, 515, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31761840, 713259, 30847, 789, 70, 9075, 516, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31792690, 714050, 29267, 769, 70, 9054, 515, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31821960, 714821, 27172, 792, 70, 9984, 575, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31849135, 715615, 28426, 800, 70, 9845, 566, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31877564, 716417, 29421, 771, 70, 9058, 515, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31906988, 717190, 29987, 775, 70, 9013, 512, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31936978, 717967, 28379, 757, 70, 9037, 514, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31965360, 718726, 28042, 798, 70, 9915, 570, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31993405, 719526, 27332, 783, 70, 9780, 562, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32020740, 720311, 29560, 770, 70, 9007, 512, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32050303, 721083, 30536, 779, 70, 8946, 508, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32080842, 721864, 29135, 768, 70, 9072, 516, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32109980, 722634, 26938, 780, 70, 9807, 564, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32136921, 723416, 28129, 798, 70, 9880, 568, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32165053, 724216, 28998, 770, 70, 9141, 520, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32194054, 724988, 30128, 780, 70, 9068, 515, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32224185, 725770, 29095, 764, 70, 8995, 511, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32253283, 726536, 28461, 806, 70, 9957, 573, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32281747, 727344, 27511, 796, 70, 9971, 575, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32309261, 728142, 29750, 771, 70, 8982, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32339014, 728915, 30765, 788, 70, 9057, 515, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[32369794, 729706, 312, 9, 30, "Caption",
  CellTags->"Fig. 6.13"],
Cell[32370109, 729717, 380, 9, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[32370526, 729731, 94, 1, 31, "Section",
  CellTags->{"i:44", "c:41"}],
Cell[32370623, 729734, 691, 15, 78, "Text"],
Cell[32371317, 729751, 184, 4, 44, "Text"],
Cell[32371504, 729757, 235, 7, 42, "NE3",
  CellTags->"(6.3.21)"],
Cell[32371742, 729766, 631, 21, 65, "Text"],
Cell[32372376, 729789, 622, 18, 69, "Text"],
Cell[32373001, 729809, 414, 9, 44, "NE3",
  CellTags->"(6.3.22)"],
Cell[32373418, 729820, 137, 5, 30, "Text"],
Cell[32373558, 729827, 1078, 32, 95, "Text"],
Cell[32374639, 729861, 213, 6, 33, "UNNEQ"],
Cell[32374855, 729869, 418, 13, 30, "Text"],
Cell[32375276, 729884, 219, 6, 42, "UNNEQ"],
Cell[32375498, 729892, 722, 20, 48, "Text"],
Cell[32376223, 729914, 242, 7, 33, "NE3",
  CellTags->"(6.3.23)"],
Cell[32376468, 729923, 314, 7, 44, "Text"],
Cell[32376785, 729932, 197, 6, 33, "NE3",
  CellTags->"(6.3.24)"],
Cell[32376985, 729940, 247, 7, 30, "Text"],
Cell[32377235, 729949, 219, 7, 33, "NE3",
  CellTags->"(6.3.25)"],
Cell[32377457, 729958, 384, 12, 44, "Text"],
Cell[32377844, 729972, 54045, 1166, 233, 11597, 637, "GraphicsData", \
"PostScript", "Picture"],
Cell[32431892, 731140, 131, 4, 16, "Caption",
  CellTags->"Fig. 6.14"],
Cell[32432026, 731146, 319, 7, 61, "Text"],
Cell[32432348, 731155, 297, 8, 43, "NE3",
  CellTags->"(6.3.26)"],
Cell[32432648, 731165, 417, 14, 44, "Text"],

Cell[CellGroupData[{
Cell[32433090, 731183, 345, 7, 149, "Input",
  CellTags->"Cell 6.178"],
Cell[32433438, 731192, 41355, 986, 233, 9866, 593, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[32474808, 732181, 531, 16, 47, "Text"],
Cell[32475342, 732199, 642, 17, 48, "NE3",
  CellTags->"(6.3.27)"],
Cell[32475987, 732218, 371, 13, 44, "Text"],
Cell[32476361, 732233, 671, 18, 51, "NE3",
  CellTags->"(6.3.28)"],
Cell[32477035, 732253, 902, 27, 66, "Text"],
Cell[32477940, 732282, 448, 11, 61, "Text"],
Cell[32478391, 732295, 355, 9, 45, "NE3",
  CellTags->"(6.3.29)"],
Cell[32478749, 732306, 148, 5, 27, "Text"],
Cell[32478900, 732313, 689, 19, 51, "NE3",
  CellTags->"(6.3.30)"],
Cell[32479592, 732334, 1204, 33, 64, "Text"],
Cell[32480799, 732369, 502, 8, 35, "UNNEQ"],
Cell[32481304, 732379, 73, 0, 27, "Text"],
Cell[32481380, 732381, 240, 7, 35, "NE3",
  CellTags->"(6.3.31)"],
Cell[32481623, 732390, 877, 30, 61, "Text",
  CellTags->"i:45"],
Cell[32482503, 732422, 1060, 31, 83, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[32483600, 732458, 87, 1, 31, "Section",
  CellTags->"c:42"],
Cell[32483690, 732461, 1229, 35, 109, "Text"],
Cell[32484922, 732498, 242, 7, 58, "NE3",
  CellTags->"(6.3.32)"],
Cell[32485167, 732507, 174, 7, 27, "Text"],

Cell[CellGroupData[{
Cell[32485366, 732518, 245, 6, 106, "Input",
  CellTags->"Cell 6.179"],
Cell[32485614, 732526, 54, 1, 46, "Output"]
}, Open  ]],
Cell[32485683, 732530, 549, 12, 78, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[32486269, 732547, 97, 1, 31, "Section",
  CellTags->{"i:46", "c:43"}],
Cell[32486369, 732550, 1191, 24, 146, "Text"],
Cell[32487563, 732576, 275, 7, 44, "Text"],
Cell[32487841, 732585, 102, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[32487968, 732592, 122, 3, 67, "Input",
  CellTags->"Cell 6.180"],
Cell[32488093, 732597, 51, 1, 51, "Output"]
}, Open  ]],
Cell[32488159, 732601, 32, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[32488216, 732605, 96, 3, 67, "Input",
  CellTags->"Cell 6.181"],
Cell[32488315, 732610, 41, 1, 69, "Output"]
}, Open  ]],
Cell[32488371, 732614, 355, 10, 44, "Text"],
Cell[32488729, 732626, 578, 11, 184, "Input",
  CellTags->"Cell 6.182"],
Cell[32489310, 732639, 295, 9, 27, "Text"],
Cell[32489608, 732650, 137, 3, 67, "Input",
  CellTags->"Cell 6.183"],
Cell[32489748, 732655, 178, 6, 27, "Text"],
Cell[32489929, 732663, 156, 4, 67, "Input",
  CellTags->"Cell 6.184"],
Cell[32490088, 732669, 676, 22, 44, "Text"],
Cell[32490767, 732693, 815, 16, 219, "Input",
  CellTags->"Cell 6.185"],
Cell[32491585, 732711, 102, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[32491712, 732718, 134, 3, 67, "Input",
  CellTags->"Cell 6.186"],
Cell[32491849, 732723, 167, 3, 50, "Message"],
Cell[32492019, 732728, 167, 3, 50, "Message"],
Cell[32492189, 732733, 166, 3, 50, "Message"],
Cell[32492358, 732738, 167, 3, 50, "Message"],
Cell[32492528, 732743, 166, 3, 50, "Message"],
Cell[32492697, 732748, 2638, 80, 122, "Output"]
}, Open  ]],
Cell[32495350, 732831, 647, 13, 95, "Text"],
Cell[32496000, 732846, 342, 9, 61, "Text"],
Cell[32496345, 732857, 98, 3, 27, "Text"],
Cell[32496446, 732862, 191, 5, 67, "Input",
  CellTags->"Cell 6.187"],
Cell[32496640, 732869, 238, 6, 44, "Text"],
Cell[32496881, 732877, 446, 8, 105, "Input",
  CellTags->"Cell 6.188"],
Cell[32497330, 732887, 643, 14, 95, "Text"],

Cell[CellGroupData[{
Cell[32497998, 732905, 280, 6, 86, "Input",
  CellTags->"Cell 6.189"],

Cell[CellGroupData[{
Cell[32498303, 732915, 38505, 968, 233, 10300, 615, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32536811, 733885, 40702, 1026, 233, 10858, 653, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32577516, 734913, 46301, 1079, 233, 10192, 629, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32623820, 735994, 51396, 1163, 233, 11010, 660, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32675219, 737159, 57017, 1226, 233, 10820, 651, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32732239, 738387, 59229, 1290, 233, 11408, 695, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[32791541, 739685, 65, 1, 30, "Subsubtitle",
  CellTags->"c:44"],
Cell[32791609, 739688, 727, 18, 78, "Text"],
Cell[32792339, 739708, 123, 4, 27, "Text"],
Cell[32792465, 739714, 127, 4, 27, "Text"],
Cell[32792595, 739720, 483, 14, 44, "Text"],
Cell[32793081, 739736, 183, 5, 27, "Text"],
Cell[32793267, 739743, 411, 13, 44, "Text"],
Cell[32793681, 739758, 144, 4, 27, "Text"],
Cell[32793828, 739764, 140, 4, 27, "Text"],
Cell[32793971, 739770, 593, 17, 61, "Text"],
Cell[32794567, 739789, 257, 7, 41, "Text"],
Cell[32794827, 739798, 453, 16, 32, "Text"],
Cell[32795283, 739816, 431, 13, 44, "Text"],
Cell[32795717, 739831, 88604, 1097, 156, 88486, 1093, "GraphicsData", \
"Bitmap", "Picture",
  Evaluatable->False],
Cell[32884324, 740930, 53, 1, 16, "Caption",
  CellTags->"Fig. 6.15"],
Cell[32884380, 740933, 428, 12, 44, "Text"],
Cell[32884811, 740947, 243, 6, 44, "Text"],
Cell[32885057, 740955, 487, 15, 44, "Text"],
Cell[32885547, 740972, 141, 4, 27, "Text"],
Cell[32885691, 740978, 145, 4, 27, "Text"],
Cell[32885839, 740984, 261, 8, 44, "Text"],
Cell[32886103, 740994, 1190, 32, 43, "Text"],
Cell[32887296, 741028, 1050, 34, 78, "Text"],
Cell[32888349, 741064, 123, 4, 27, "Text"],
Cell[32888475, 741070, 127, 4, 27, "Text"],
Cell[32888605, 741076, 201, 7, 27, "Text"],
Cell[32888809, 741085, 782, 22, 63, "Text"],
Cell[32889594, 741109, 177, 5, 27, "Text"],
Cell[32889774, 741116, 137, 5, 31, "Text"],
Cell[32889914, 741123, 140, 5, 31, "Text"],
Cell[32890057, 741130, 123, 4, 27, "Text"],
Cell[32890183, 741136, 385, 7, 61, "Text"],
Cell[32890571, 741145, 535, 15, 41, "Text"],
Cell[32891109, 741162, 135, 3, 27, "Text"],
Cell[32891247, 741167, 267, 9, 27, "Text"],
Cell[32891517, 741178, 99, 4, 30, "Text"],
Cell[32891619, 741184, 112, 5, 30, "Text"],
Cell[32891734, 741191, 158, 5, 27, "Text"],
Cell[32891895, 741198, 154, 5, 27, "Text"],
Cell[32892052, 741205, 158, 5, 27, "Text"],
Cell[32892213, 741212, 1167, 29, 103, "Text",
  CellTags->"i:56"],
Cell[32893383, 741243, 749, 22, 65, "Text"],
Cell[32894135, 741267, 969, 29, 82, "Text"],
Cell[32895107, 741298, 1235, 32, 118, "Text"],
Cell[32896345, 741332, 1557, 43, 139, "Text"],
Cell[32897905, 741377, 662, 22, 63, "Text"],
Cell[32898570, 741401, 1175, 31, 122, "Text"],
Cell[32899748, 741434, 43876, 545, 150, 43754, 541, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[32943627, 741981, 68, 1, 16, "Caption",
  CellTags->"Fig. 6.16"],
Cell[32943698, 741984, 1010, 30, 66, "Text"],
Cell[32944711, 742016, 904, 28, 45, "Text"],
Cell[32945618, 742046, 184, 7, 38, "NE3",
  CellTags->"(6.3.33)"],
Cell[32945805, 742055, 915, 27, 69, "Text"],
Cell[32946723, 742084, 685, 21, 61, "Text"],
Cell[32947411, 742107, 883, 29, 78, "Text",
  CellTags->"i:49"],
Cell[32948297, 742138, 155, 6, 33, "NE3",
  CellTags->"(6.3.34)"],
Cell[32948455, 742146, 495, 13, 65, "Text"],
Cell[32948953, 742161, 430, 14, 44, "Text"],
Cell[32949386, 742177, 2262, 69, 158, "Text",
  CellTags->"i:50"],
Cell[32951651, 742248, 167, 6, 32, "NE3",
  CellTags->"(6.3.35)"],
Cell[32951821, 742256, 902, 27, 86, "Text",
  CellTags->"i:51"],
Cell[32952726, 742285, 247, 8, 56, "Text"],
Cell[32952976, 742295, 750, 24, 47, "Text"],
Cell[32953729, 742321, 225, 6, 49, "NE3",
  CellTags->"(6.3.36)"],
Cell[32953957, 742329, 745, 25, 65, "Text"],
Cell[32954705, 742356, 203, 6, 27, "Text"],
Cell[32954911, 742364, 2311, 76, 107, "Text",
  CellTags->"i:52"],
Cell[32957225, 742442, 410, 13, 29, "NE3",
  CellTags->"(6.3.37)"],
Cell[32957638, 742457, 651, 23, 52, "Text"],
Cell[32958292, 742482, 1223, 44, 48, "Text"],
Cell[32959518, 742528, 760, 22, 39, "NE3",
  CellTags->"(6.3.38)"],
Cell[32960281, 742552, 1436, 49, 44, "Text"],
Cell[32961720, 742603, 783, 22, 48, "NE3",
  CellTags->"(6.3.39)"],
Cell[32962506, 742627, 290, 10, 32, "Text"],
Cell[32962799, 742639, 174, 6, 35, "NE3",
  CellTags->{"i:53", "(6.3.40)"}],
Cell[32962976, 742647, 380, 16, 27, "Text"],
Cell[32963359, 742665, 452, 14, 44, "Text"],
Cell[32963814, 742681, 856, 31, 27, "Text"],
Cell[32964673, 742714, 784, 24, 35, "NE3",
  CellTags->"(6.3.41)"],
Cell[32965460, 742740, 1012, 36, 55, "Text"],
Cell[32966475, 742778, 294, 9, 49, "NE3",
  CellTags->{"i:54", "(6.3.42)"}],
Cell[32966772, 742789, 518, 19, 44, "Text"],
Cell[32967293, 742810, 1610, 47, 136, "Text",
  CellTags->"i:55"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[32968952, 742863, 60, 1, 40, "Subtitle",
  CellTags->{"c:45", "refs"}],
Cell[32969015, 742866, 231, 8, 27, "Text"],
Cell[32969249, 742876, 199, 7, 27, "Text"],
Cell[32969451, 742885, 186, 5, 27, "Text"],
Cell[32969640, 742892, 208, 5, 44, "Text"],
Cell[32969851, 742899, 222, 8, 27, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

